(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[   4761849,      65239]*)
(*NotebookOutlinePosition[   4762729,      65267]*)
(*  CellTagsIndexPosition[   4762685,      65263]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Ground State Configuration of Charged Balls", "Title"],

Cell["\<\
This experiment was first done by G. E. Blonder at AT&T Bell \
Labs.\
\>", "Text",
  FontSize->18],

Cell[CellGroupData[{

Cell["Experimental Set Up", "Section"],

Cell[CellGroupData[{

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000;d0001n1000`40O003h00O0T7]0T8=00=63D8<
AP`00dH<00=5jdH;AP/00TG[0TH;00E5jdGZAP]62dG[00M62`9630923003APe634H<00963009BPa6
34X;BPY:2DGYALQ5ad6W00E5a`03ALI5adFV0091YP91QP03AJM1Yd6W00A1Y`=5Y`91Y`04@HM1QT67
@HL4?HL00cV7>FHeIP02=DD2<B@0334S=B<e@cUU>FHiJ3F:>HXmbd7/APe6;@A:;0A:;@03CTe:;DX]
00E:;@A:C@I>C@0?CRe>;59<BRe5jcfZ=FTiQcg8APY623g7>JM1bTX<009BK09>C@0:CRe:;DH=ANe1
k3g<?J/iZSV[>JX3>HT01cVY?JU1bDG[AP]634h/00U:;@03BRi:3TX^00Y:;@M:;P03BTi:;Th]00A>
;@9:;@03BRi:CTX^00A:;P9>;PM>CPE:;`=>C`03CTi>CDi=00=>C@03CTi>;Di>00E>C`03CU1>Kdi?
009>CP9>C@04DTi>Cdi>CTl6CU001Ti_CTm>CTi?CVm>D0=>C`05CU1>Cdi@CU1BL@02EW400eJ@EW5F
L@03DW4<DW02DTl4DW09DVl00e9`EW1BL00>DW02DVl00e9?DW1BL004DU000di@DW1BL@02EW43EY40
3eJ@EXm>CTH>?J`iRcf[@Na63Di<DVeFSeJ@F[1JT@02EY000eI`EW5FL@02EW400e9`EY1J/@02F[42
F[84F[42EY4:F[400eZ`F[5J/005F[07F[45FY45FY0@EY03EXl01EI_DVmFKeI_EXl00UI_00EFSeJ>
EXiFSUI_00=FKP03EVmFSeI_00UFK`03DVmFKeI^00=FK@9BKP9FSP05EXmFKUI_EVmBK`03EVl0159_
DViBKUI^1E9_2e9^1E9_0U9^1EI]00=BKU9]DVh01E9^00=BKe9^DVl01E9_1e9^00=BKE9^DVh0259^
0e9>0e9^1U9]0e9_00ABKU9>DTiBCP=BKP=BK@03DTeBCU9>009>C@03CTi>CDi]00=BK0a>C003CTe>
;4i=01=>C005BRa>:dh[BR]:;00=BR/3AR/00dX[AR]6:`02AR/5AR`014X[APa62dH;0TX;00=:2TH:
APX01TH;34H:0dGZ14GY0d7Y1D7Z00=5jT7Z@NT01d7Y00A1jT7Y@NU1b@8mb@03?LQ1bD780091b003
@LTmb3g900<mb@Hmb0Lmb@8ib@PiZA0iZ007>JLiQcV7>HLeQcF6>HD00Cf50000147]ANe63DH=0TH<
00A62dG[AN]9j`=9jP06AN]:2dX;BNY5jTWY0dWZ00=9jdH;BP/00TX;0TX:00=:2dX<CP`00Th<00Y:
34h<CP]>2dh:DPUF2588DNMAaP99YPA9Y@==Y09=Y@99Q@99Q003CHE9QDV500=9Q@9=Q@99Q@04BHI9
QDUTBF@3BFD3AFD2@FD013e5?D@i93TS0STR00Xm0CdR@FA1QD68?FTiJ3fZANa:30U>;0U>;@03CTe>
;Dh]009>;@9>C@9B;@0@DRaF;58[CR]9jTFY@HQ1QdG9APY:2DG8@LQ5jE8:EV/3DT`0458/CRa>3DW/
ANe5k47;@JXmZSf9?FPiJ3f8@LU5bTGZ0TWZ00A:2dh<CPa>:`9>;004CPa>;4h/CP`6CPd00dh]CRa>
;002CR`5CRd7CRh2CRd00dh/CRe>;@04CRd5CRh2CRd00e8^DTiB;@02DRd00dh]DRi>;`03CRh01Dh_
CRi>;dh_CTh00e9=00EBCU9=DTeBCU9?00ABCPABC`9BCP03DTeFCE9=009BCPUBC`=BCP06DTmBCU9?
DTmBD59?0U9@00EFLEZ@FY5JT5ZA00AJL0AFL0=FK`9FL003DTmFCeI?009FCP03ETmFD5I?00=FK`03
EViFKeI>00MFK`04EW1FLEI`EW05EVl3EW02EVl2ETh00eI_EW1FD003ETl00eI_EW1FL002FW03FY40
3EZBFY5JSe9>CNe5Zd6:@HU5jdX<DTaFKEZ>009JT004G[1JT5Z@FY03FW02FY4015Z@FY5JT5jA0Ujb
0Uja00AN/5jAFY5NT@EN/005G[5NTEjAG[1JT002F[000ej`FY1JSP02GXh2GZl3G[07FY02FXl3FVl4
FXl2FVl2FXl4FY04FVl2FXl00eY_FViFKP02EVh00eY^FVmJKP02FVh015Y]FXiJSEZ>1UY^0eI^1eY^
00=JKeZ>FXh01UI]25I^00AFKeI]EVeJK@=FKP04EVmFKUI^EVh3EVd3EVh00eI]EViFKP03EVl015I^
EVmFKUI^0UI]0eY/15I]1UI^00=BCUI>EVl025I^0eI]00AFKUI=ETeFC@9FKP03ETeFKUI^00=FC@AF
KP04EVeFC5I<ET`2EVd2EVh00e9^ETeBC@05ETd3EVd00eI<ETeFC@02DTd00e9>DTeBC@0>DT`00e9;
CRa>;003CT`7CR`3CT`3CR`2CT`3CR`4CR/3CRX2CR/00dh;CPY>:P02CRX2CR/>BP/00dX:CP]>2P02
CPX00dX:BPU:2P02BPX:APX4ANX00dWYANU5j@04ANT014WYANU5j4GX0TG800A5bDGYANU5jP95j`03
ANY5jDG800=5b095j003ALQ5bDG90091b@A1b003@LM1b47800I1b003@LU1Z46X00E1Z004?JQ1Z3fX
?JP2?LT4?JP3?JT4?JP5?JL013VW?JLiYcfW1Cf700<mYcf7>HL00cfW0Cf60Cf70000147^APe63DH=
0TH<00=62dG[AN/00TG[00A9jdX;AP]62`=5j`05BNU5jDWZBNY:2P02BP/00dX<BP]:2`03BP/2BP`2
CP`02DX<CP]>2Th9BPUF1e7VDLMAaP02BJH5BJD014fUCJA=Y4fT0TV400=9QDf5CHD00dV514f500==
QTV5BHH00TV500A9I4UUBFE9I@A5I@0B@FE1ACe4?B@i8cT2>B4i0CdRAHE9aTFW?HPeACf7@NY:2dX]
24h/2Th]0Ti=00ABCDi=DTeBC@9B;@9B;009DR]BC4X:ALTiIce5ANY>C58Z0091Y`0=ALMF2EI;ET]B
BeI;DTa>;Dh=CNa5k4G[ALX00T7:00@mRC4V=DM1ZP95j`95jP05AN]9jdh<CRaB:`02CP`2CR`00dh<
CPe>3@02BPd3CPd014X=CPe>3Dh/0TX=00=>;4h]BRd00dh]1Dh^0Th]00=>;4h]CRd014h]1Dh^0Th]
0U8]00=B;58]DR`00U8^0Ti>14h^0Th_00=>CU9=DTd00e9=00ABCU9=DTiFCP=BCPABC`03DTiFCUI=
009FC@03DTmBCU9?00QBC`9BCP0:DTeBCU9?DTmBD59`ETiFCeI@EW03FY02FVl015Y`FVmJKeY_0UI`
00AJKeY^EW1FL0=FK`9FC`04ETiFCeI?EU02ETl2EVl5EVh4EVl2EW000eIaEW1FL002ETl01UI>EVmF
L5I`EW5FL0AFK`04EViFL5I@ETl2ETh2EVh2FVl04UZ?FY1JTEZBFY=JTUZ@ETiAk3eX=BHmR4GZBPaB
C5I]FXmJ/09N/003FY1JSeZ?00=JT003GY1JT5Z@009JT0=JT@9N/@UN/004G[5NTEjAG[03F[02GZl2
FZl4GZl3G[04FY03FXl00ei_FViJKP02FVh015Y_FViJSej?15Z?0eZ@00MJSeY_FXmJT5Z?FVmJK@03
EVh015Y^FVmJKeY^1eY]00=JK5Y]FVd00UY]15Y^0UY_0UY^00AFCUI^FViJKPMJK@9FK@03EViFKEI^
00AFKP0:EVeFKUI]EViJKUI^EVmFKUI]EVh3EVd00eI^EVeFK@03EVd7EVh2EVd7FV`00eI]FVeFK@02
EVh00eI<DTeFKP09EVh01EY]EVeFKEI]ET`03UI^00=FKEI/EV`00UI/00AJK5I]EVeBCPMFC@03ETaJ
JeI]009FK@9FC003EVeBCE9<00mBC0=BB`A>C09>;0=>;@04CRa>C4i<CT`3DT/2CT`3CR`2CR/00dh;
CR]>:P02CRX3CR/5CRX00dh[BP]:2`02CR/:BP/2BPX00dh9BPU:2@02BPT<BPX00dH:ANY5j@02ANX3
BNT00dWZBNU5j@03BNP00dGYALM5b002ALP00dGYANY5j@02ALX2ALT3ALP3ANP2ALP4ALT2ALP00d78
ALQ1b002@LP00d77@LQ1b002@LP2@JP00d79@LQ1b004@JL0146X?JPmZ3fX147823fX1cfW13f700@m
Z3f7?HLmY`<iY`03?JLmYSf5004mR00000=23TH>APd00dH=00E634W/ANa5k4H;00E63003ANa5jdX:
00A:2`=:3005APa:34X;BP]>2`05BP`2CP/2CPX02EH8DNMAae77CJI9YTVUBJI=YP02BJH3CJD00dfV
BJE9Q@07BHD3CHD2BJH3BHH01DUUBFI9QTEUBFD00TEU0T5U00E1ACe5?D@mACdT00<m8`08@HI9aTG8
@HTmIcf9@N]630=>;@=>;0i>;@A>C@04CTi>CDi=DR`2DT/0:U9<CPY5bCE7>BE5bDi=DRY5b46WAJMF
25YZET]FC59=DTi>;Dh=BPa5kDG;@L]1bSg;?JY1RD6Z@L]:34X=AN]5bdG[ANa:34h/DR]B34h<CRe>
30=>3@=:3@03BPi:3DX=00=>3@9:;@I>;@E>;P04CRe>;Th^CRd2CRh00dh]CRi>;P05CRh2CRd5DRd2
DRh3CTh3CRh2CRl014i>DTeBCU9>0e9?00QBCU9?DTmBD59?DU1BCe9>0e9?00AFCeI>ETiBCPeBC`03
DTiBCe9?009BD09BC`07ETmFL5I`FY1JTEZ@FW000UZA0UY_0eI`0UY_0eI`00IFKe9?DTmBCeI_EW03
EU02EW03EVl00eI^EVmFK`09EW02EU000eI?EW1FL00:EW07EVl055Z?FY5JTEZBFW=JTUZ@ETiAk469
=BLiIdGYBPaBC5I]FXmN/UjaG[02FY000eZ?FY1JT006FY000ejAFY5N/P02G[49G[0015jaGY5NTEZ`
0eZa1EZ`00=N/5j_G[000Uj`1UZ@0UZ?0Uj?0ei_15Z?0UZ@0UZ?0eZ@00IJSeZ@FY1FT5Z@FXl8FVl0
0eY^FXiJKP02EVh4FVh01eI^FViJKUY^FVmFKeY_00=JKP9FK`04EViJKUY^FVd3FVh3EVh2EVd4EVh3
EVl01EI^EVmFKUI_EVh00UI_1EI^00MJKEI^EViFKUI]EViFK@09EVh00eI]EViFK@02EVd3EVh00eY]
EViFK`03EXl00eI_EViFKP02EVh7EVl2ETh00eI^ETiFKP02EVh00e9_ETiFCP08EVh5EVd2EVh01E9^
DTiBCUI=DTd015I=00EJK5I^ETeFKUI<00=BC@UBC09BC@=BC09BC@9BC0A>C003CRa>;Dh]009>;@03
CTe>C4i<009>C0=BB`=>C004CRa:;4h/CR`5CR/00dh/CR]>:`07CR/2BP/3BP`5BP/3BP`2BP/3CPX3
BPX2BP/014X:BP]:2dX;0dX:0TH:00E62dX;AP]62TGZ00=9jP04ANY5jDGYBNT2BNP3ANT00dWYBNY5
jP05ANT014G9ALQ5bDG90TGY00A5j4GYANQ5j@A5b@03ALQ1bD7800=1b@E1b003@JQ1bD7900=1b0=1
Y`03@JPmZ3fX00lmZ0@mY`LmQ`DiZ003>JLmQcf6004mR00000=1kTH>APd014H=0TX<1TH<00E63DG/
AN]:2dH;009:2`03BN]:34X<00963@06BPe>34X;CP]:2dh;0dX<0Th;0TX;00U=jE7XDLQAaU6VCJI=
YDf6CJH00dVV14fV00A=QTV6BHE9QPA9Q@==Q@99YP=9QP99IP03BFE5IDEU0095I@06ADA1I3e5?B@m
9CdT0cTT00dmA45UBLI5Z469?HU1bT7/CReBCDh/CPe>;002CRd3CRh2CRd3CR`6CRd00e8]DRa>C@02
DTd3DT`06e9;ETYFJeHZALTiASDTALQ>CE8ZALU1R466EPMJJUY/ETeFCe9?DTi>;Dh<ANe5c4G;@JY1
b`02@JT0147:BPa>;DG/14G;00=:34X=CR`00Th/0dh=00A:3DX>BPi:3PA:3@M>3@A>;@I>;P9>3P03
CRi>;Dh^00Q>;PA>;@EB;P03CTiB;U8^00YB;P03DTiBCe9?009BC`=BD0EBC`AFCa1BC`03EVmFL5I`
009FC`04EU1JL5Z@FY42FW02FY400eZ@FW1FL002EW001UY`FVmFLEI`EVmFCP=FC`9FK`0:ETmFD5I@
EW1FLEI`EW5FL5I^EVl9EW03EU001UI?EW1JL5I`FVmFD0QFL009FW1FKeI>ETiFKeY_FXmNTEZA009J
T`0>FY9JT5I^DPa5bcUY>HM5jDX<DTaFKEj?G[5N/09NT003G[1NT5Z?009JS`05GY1JT5Z@FY1NT002
GY400ejbG[5N/@0;G[42G[03F[0015Z@F[1J/5Z`1Ej`1eZ@0Uj@1Ej?0Uj@25Z@0eZ?15Z@0eZ?25Y_
00=FT5Y_FVh00eY^0UY_0UY^00=JKeI_EVl035Y^0eY_00=FKeI^EXh015J>00IJKUI^EViFKUI_FVl8
FVh4EVh00eI]EViFK@04EVd:EVh015I_ETiFKUY]0eI^0eI_0UI^15I_15I`00EFD5I?ETmFCUI_00=F
KP9FCP03EVmFKUI^00YFKP9FC@AFKP9FC@03ETaFCEI=00EFC@QFC003EVeFCEI=009FC@9BC@03DTaB
Be9<00ABC@9BC003CTa>CE8/009B;@03DTeBCU8/00MBB`9BC004CTaBC4i<CT`3CR`?CR/01TX;CP]>
2dh;BP]>2PA>2`=:2`03CPY:2Th:009:2P=:2`04BPY:2dX:BP/8BPX2APX2BNX014WYBPY9jDWY0dWX
0TWY00=5jDWYANT00TGY00=5jTGYANT00dGY0dG900=5jDGXANP00TGX00=5bDG8ALP00TG91T7900A5
bDG8@LQ5Z0I1b0=1Y`M1Z004?JQ1Z46X@JP3?JP00cg9?JPmZ002?JP3?JL01cfX?HLmQcf7?JLmQcfW
008mZ08mQ`04?JPmQcf7?HH1>HT00003?Ni23TH=00M63@9:3003APa63DG]00963@A:30=630=:3006
BPe:34h<BP]:34h<0TX<00]:3DX<BP]>2dX;CPU=jE7XDLMAYTfV00==Y@9=YP03CJM=YTfV009=YP03
CHI9QTV600E9YP99Q@03CJI9YTVV00A9QP03BFI9IDV60095Q@04AFE5A455@DD2?DD2>BD03CTS>@<i
8d5UAJM1Z469?HQ1bT7/APe>;Dh=009>;003CRe>;Th^009>;P9>;@03CRaB;4h/00I>;@05DTeB;58/
DTaBC@02DRd2DT`05UI<ETYJ:4G8=BHi9D79CRa>:DG9?FQ1QUH8EV]FK5I^ETmBCe9=CRe>34W]0TG<
0T6[0d6Z00A1bTG:@N]1b`8mR@04@Na:3DX=CR`2CRd01Dh/CPe>3DX>APh00TX>0TX=00=>34X=BPd0
1Th=0Th]0Th^0dh_0dh^00=>3Th^CRh01Th^00=:;Th^CRh024h^0Ti>0e9?1E9>00=BCe9>DRh01E9>
00=FCe9@DU000U9@0e9?0e9@3eI?0e9?0eI_00EFL5Y_EU1FL5Y`00MJT@04FW1JLEYaFW42FW000eJA
EW1FL005EVl015I`EU1FD5I`0eIa1eI`1UIa00=FTEZBFY801EY`0UYa00AJTUZAEW1FL09FT@05EW5F
L5I`FViJK`02FY001Ej`G[5N/UjcF[<00Ujb00YJTE8/AL`iJ3f8ANY:34h/EVeJSP=N/004GY1JTEZ@
FY03FXl3FY000ej@G[5NT@02G[8;G[4015j`G[5N/Eja0Uj`00AJ/5ZaG[5N/@EN/003GY5JTEZA00IJ
T003GY1NSej?009NS`03GY1JT5Z@00QJT09JS`EJT0=JS`EJK`06FXmJKeJ@FXmJL5Y_0UY^00EJKeZ?
FXmJKeY`00AJK`9JKP03EViJKUY^00=JK`EJKP03EVmJKUJ>00AFSP03FViFKUY^00aJKP9FK`03EViJ
KEY]00EJK09JK@IFKP9JKP9FK`AFKP05FViFKeI_EVmFL004EVl015I^EVmFKeI`0eI?00=FCUI^EVl0
0eI^0eI_1EI^0UI_1EI^00IFCEY=EViBKeI_ETh2ETd00eI<ETeFC005ETd2ET`01EI;ETaFC5I<ET/0
0UI<0UI=0eI>00AFCEI<DT]BC0=BC@0;DTiBCE9=CTa>CE8/DReBCE9>DReBC002DR`3DR/2DT/4DT`0
0di<CRa>;002CR`?CR/01Dh/CP]:34h;BP/01Dh;0dX;00Q:2TX;BP]:2dX:BP]:34X;0TX:0TX;14X:
0dX;1DX:1DWY00A9j4WYBNU9j@95j@07ANY5jDGZANY9jDGYBNT00dGY00=5bD78ALP014GX0dG800U5
bDG8@LU5bD79ALU5jTGYALP00dFX0T7800M1bD78@LQ1b4FX@JM1b002@JP00d6W@JQ1Z002@JP2@LP2
@JP8?JP00cfY?JPmZ002?JP4?HL3?JP01Sf8?JPmZ3fW?HLmQP4iR@0000=1kTH>APd01dH=0dX<00A6
3DG]BPe:3@9:3004APa:34H=APd2BP`2BP/014X<CNa9k4W/14X<00=63DX<BP/00Th;00I>2TgYDNQA
ae6VBHD4CJD00dfVCJM=YP03CJH3CHH5BJH2BHD00dfUBJI9Q@02BHD014V6BFE9IDUU0TV600A5QDEU
ADE1A@91AP8mA@0@>B@i8cTS>B=1ID66@JPmR3UW@LU5jdH<BPe>3Dh/DR`2CRd3CRh2CRd3CR`5CRd2
CR`3DR`05U8]CReB;E9>DTeBC58ZERM5YcDV>BE1YdX9ERM5bCU8@HMF25I;EVaFKEI^0UI=00EB;4h<
BNa5k4G<0095b`0<AJY1ZT6Y@JY1bD6Y>FLiJD7;ANe>3DX]0dh]0Th=0TX=00E63TX>BPi63DX=00=>
30=:3@08CPe>34h<CPa>3Dh^CRe>;P9>;`9B;P9>;P04CRe>;Th^CRh3CRd2BRh9CRh2DRh0159>DTmB
Ce9?0U9>0eI?0U9>00=BCe9>DTl0159>00ABCe9@DW1BD09BC`04ETmFD5I@EU0?ETl3DTl2EVl00eI>
EVmJK`02FW000eZAFW1JL003FY400eIaFW1FL@05FW02EW04EVl3EW02EU001eY_EW1FL5IaFW5FL5Y`
00AFL09FL@=FLPAFL@03FW1JT5Z@009JT@04GY5JTEZAFY42EW43EY4015I`EVmJKeY_0UZ?01EN/5ja
G[9N/ejCGY9N/UZbCPe1bSeX?HM5jDH<CRaFC5Z>FZmN[ej?GY000eZ@15Z?0ej@00ANTEjbG[9N/PeN
/@9NT@=N/003F[5N/5ja00EN/003GY5JTEZA00IJT003GY1NSej?009NS`03GY1JT5Z@00QJT09JS`EJ
T09JS`=JK`9JKP=JK`03FXmJKeY`009JK`03FViJSUZ?00AJK`03FW1JKeY_00EJKP9JK`03FW1JKUY^
00IJKP07FXiFSeJ>EXiFKUY^FXh00UY_00=JKUY]FVh01eY^00EJKeI_EViFKEY]00EJK006FVeJK5I]
EViJKEY^0eI^00AFKEI^EViFKPEJKP9FK`06EW1FKeI_EVmFKUI]0UI^00IFKeY_FViFCUI=EVd3EVl0
15I^EVmFKeI_1EI^0UI_00UFKUI]EVeJKEY/FTaJCEY]EVl00UI>0UI=00EFC5Y/FV]FKEI^009FC@04
ETaFJeI[EV/3ET`3ET/00eI<ETeFCP02ETh00eI=ETaFB`02DT`2DTd00e9>DTeBC@03DT`00e9=DTiB
C@02DT`2DR`4DR/00e9;DTaBC002DT`00di<CRa>;002CR`?CR/01Th/CP]>2dh;BP]>2`9>2PA>2`03
BP]:2TX;00E:2`U:2P=:2`9:2P03APY:2DX9009:2@M9j@05BNY5jDG9ANU5jP04BNT00dWXANU5j@02
ANT4ANP00dG8ANQ5j006ALP00dGXALQ5a`02ALP2AJP0146W@LM1b4770T7800=1Yd77@JL00d6W0T6X
1T7800<mZ46W?JP00SfX00=1Z3fW?JL00cfX0cfW0Sf70SV700<iR3f8?HP00SfX00<mYcf7?HH00CV9
00000d7_@Pi63@07APd3BP`01TH=@Na5k4X<APe:30E63@9:309=k0A:3004APe:3DX=APd2BP`2BP/0
1Dh:CNYAjE77DLH00TfU00A9YDfVCJE=YP9=Y`03BJM9YTfW00=9YP03BHI9YTVV0099YP99Q@04CHI=
YdfVBHL3BHH3BFD2BHH00dV5AFE5IP02@FL3?DD033TT>B<m8d54@FE1Qcf8>FM1ZTG[APa:3@=>;09>
;@=>;Pe>;@04CTeB;58]DT`2DTd044h^DRaB:UiXALPiASD4?HM:2Ei7ALPiB45VDPQBBeI/0U9^0UI=
00EB;4h<BNa5k4G<0095b`04AJY1Zd6Y?HT2?HP01CfX@LY5k4X=CPd00Th]00=:;TX]BPd00Th=00A:
3DH>APe63@9:3P04BPe>34h<BPd4CPd014h<CPe>;Dh>0Th^0Th_1dh^00AB;U8]CRe>;@Q>;P03CRm>
;Ti>009B;P9BCP03ETiBCe9?00=FC`MBC`=FC`03DTmBD59@009BD0AFD005DU1FD5I@EW1FL@02EW02
EU000eI`EVmFC`02ETl00eI_EW1BL002DTl00eI_EW1FL002EW02FW42FY4015YaFY5JTEYa0UIa00=F
TEIaFY400eY`1eI`00=FKeIaFW401UYa00AFL5Y`FW1FL09JL09FL@=FTP9JTPMJT@9N/P9J/P9JT@9J
/P03F[=JTUZB00AJT@03G[5N/Ujc009N/`0@GY9N/UJBBNi1ZcUX?JU1jTX^CRaFBeZ>FZmN[ej>GY02
FY02FVl3FY0015j@GXmNSej@0eja00EN/UZbF[9N/Ejb00YN/@04G[1N/EjaF[42G[45G[000ejAFY5J
T@03FY03G[001Ej@FY1NT5j@GXl02eZ@00=JSeZ@FY0015Z@00=JTEZ@EW000UY`0UY^00=JKeZ?FVl0
0UY_0UY`25Y_00EJL5Y_EVmFKeY_00=JKP9JK`03FW1JKUY_00AJKP9JK`03FXiFT5J?00EFS`04FVmJ
SeY^FVl7FVh00eY_EVmFK`02EVh015Y]FViJKEY^0eY]00AFKUY^FViJKP9FKP03EVmFKUI_00=FKP=J
KP04FVmFKeI_EW03EVl3EVh3FVh015I^FVeJKEI^0eI_00=FKUI_EVl00UI_00=FL5Y_EW000UI`0UI_
0UI]0eY/0UY]00EFKeI>ETiFCEI]00=JK006EViFCEI>ETiFCEI[0UI<0UI=00EBCEI<EVeFC5I=00AF
CP03ETeFC5I;009BC09BC@03DTiBCE9=009BC09BC@06DTaBCU9<DTeB;4h/0U9<0U8/159<0Ti<24h/
00=>:dh/CR`01dh/00A>:dh/BPa:309:2`E>2`9:30I:2`]:2P9:2`A:2P06BPU:2TH:APY62DGZ0dWY
00M5jTWZAP]9jTGZBNU5j@04BNT5ANT03DG9ANQ5bDG9@NQ5j4GYALU5adG8@LQ5b47800=5b095b@05
AJQ1bD79@LQ1b@04@LP00d77@JM1Y`02@JL2?JP7@LP01D6W?JPmZ3fX@JP00SfW0SfX0SVX00@iYcfW
>JLiY`<iZ0@mZ08mR04mQ`4iRP0000=1kdH>APd01DH=0TX=1DX<00=>2dX<APd01DX<00=63Dh<CN`0
0dW/0Th<00=:34X=BP`00TX<0TX=0Th<00E>2TgZDNUAae76009=YP03BJI=YDfV00==YP04CJM=YTfV
CHH7BJH2BHD014f6BJI=YTV70TV60dV50TV60TV500E5IDEV@FM1IT55008mA00<?B<i8cdS@DA1ID67
?HLiIcf9ALY:34h]0dh/0Th]00AB;Dh^CRe>;@e>C@9B;09BC00NDTiB;U8]DR]JB4GZ>DLa13UWBNQN
ATG7?FU1IU88ET]JSEI]EViFCEI<DRa>34W/ANa5c4G;@L]1bT6[0T7;00A1bTG:ALY5j`9:3007CRa>
;Dh]CRi:;TX>CPd014X=0Th=00A:3Dh<CPa>30M>3@=>;@04CRi>3Th>CPh3CRh01Dh_CRi>;U8^DRd0
0U8^00=>;di?CRl00dh^00A><4h_CRm>;@=B;P05DTiFCUI^EVmFL002ETl015I@ETmBCe9?0UI?00=B
CeI?ETl00eI?0UI_00=FD5I`EU000UI@00=FCeI@EU000UI`0eIA15I`00IFKeI?ETmFCeI_EW02EVl2
EW001eY`EW1JL5Y`FW5JTUjB00=JT@=FL@06EY9JTEZAFY5JL5Y_0UY`00=FL5Y`EW000UY`0UZA00=J
L5YaFW400UZA00AJLEY`FY5JT@AJL09JT@EJTP9J/PEN/P03GY5N/Ujb00=N/P9J/P03F[=N/eZB00=J
TP04G[9N/ejcG[<2H[<03f:aI_9JLTW_>FTa9CUW@LY:;E8[ETYN[Ej`GZmNS`03FY02FXl3FY04GY00
0ej`G[5N/@04G[8EG[4015j`GY5JTEZA0Uj`0Uj@0ej`00ENTEj@GY1NT5j`015JT003FY5JT5Z@009J
L09JK`eJS`]JK`AJKP03GVeNKUi^009JKP9JK`MJS`=JK`=JKPQJK`9FK`9JKP03FVaFKEI^00AFKP03
FViJKEY^00=JKP04EVmJKUY^FVd5FVh015Y`EVmFKeI_0UI^00=JKEY^FVd00UY]00AJKUY]FViJKPAF
KP05EVmJKeI_EViFK`02EW0015IaEW1FL5I_0UI]00=FC5Y/FVd00UY]0UI^0UY]00=JK5Y[FV`00eI=
0UI>00=FKUI/ET`01eI=0eI>00=FCEI>ETd00UI<00=BK5I<ET`00U9=0U9<00=BBe9<DT`00U9<1E9=
00=FC59<DT`00U9<00=>C59<DT`00Ti<0e9;0U8[00=>;58[CR`00e8[1dh/1dh[0dh;00A>2Th[BP]:
2`E:2P9>2Q5:2P962P05APU5jDWYBNU5j@03ANX00dX:BNY9j@07BNT01DWXANU5j4G9ALP00TGY00I5
j4GW@JI1YdG8ALL2ALP00d78ALQ1b003ALP00d79@JTmZ004@LP3@LL0146W@LM1b46W1T7800E1bD78
@LM1acfW008mZ003@JPmYcfW008mY`03?JPmYcfW00@mY`03?JPiZCfX008mZ0<mR04mQ`4iR@0000Hm
kdH>BPe6;TX=BPh2APd2BPd3BP`3CP`00dX<BPe:3@02BN`01TH<CPa:3DX<CPaB2`9:300EBPe:34X=
BPe:34h<BPa:3Dh=CPa:3Dh;CNYAjE77DLI=YdVWCJM=YTfW00==YP04CJM=YTf6CHH2BJH2CJH3BJH2
BHD014f6BJI9YTV70TV60dV50dV601=9QDEUAFI5Id5V@DE1A3dT?B<i93TS@FA5QDFW@HPmR3f9AL]>
3006CRd0158]DRiB;E8]3Ti=0U9=01=FC59=DTiB;E8[ERY5jcUX=@DiIdWYFTM9j3eX?DEAj5I;FVaF
K@02ETd015I<DReB;4g]0TG/00A5bd7;@LY5b`A5k005AN]:34h<CRa>;@02CRh00dX^BPi:3P02BPh0
1DX=CPe>3Dh=CP`00dh=00=>34h=CPd024h]1Th^1Dh_00AB;U9?DTm>D0A>C`03CRm>D4h`00=BC`AF
C`05EVmFL5I`EW1FC`06EU000eI_EW1FL005EVl2EW001EIAEU1FD5I@EW001eIa0eYa00=JL5I`FVl0
0UI?00=FL5IaFW400eYa0eY`00=JTEZBFY800UZB00AJTeZBFY5JT@9JTP=JT@05FVmJL5Y`FW1JK`02
FW04FY42FW43FY82FY4015Z@FY5JTEZA0UYa0eZB00=J/UZBFY800eZb0ejb0UjB1Ejb00AN/eZbF[=J
/P=N/P9N/`9N/P0@H[9V/VKBH[5VdUI@ALh`iBcS:>@]1CfYCP]FBUZ_G]82G[400eZ@F[1JT002FXl0
0eY_FY1JT003FY02G[02G[45G[8FG[42GY400ej`GY5NT@02GY02G[02G[400ejAGY1JT00AFY000eZA
FY1JT002FY000eZ?FY1JT002FXl2FY000eZAFXmJS`08FXl6FVl00eY^FVmJKP03FVh00ei]GViNK@02
FVh6FVl3FXl4FVl00eY^FVmJK`09FVl2FVh2FVd015I^EVmFKUI_0UI^00=JKEY^FVh025Y^1eY_00AJ
KUY_FViJK`9JKP03FVeJKUY]00AJKP9JK`9JKP04EVmFKUY_FVl3EW02EVl3EVd7EVh2FVd00eY/FVeF
K@02EVh2ETh00eI^EVaFK@07ETd5ETh015I^EVeFK5I/15I<0UI;00=BBe9<DT`00U9<1E9=0UI<00AB
C58]DTeBC@9BC09>C006DT]B:e8[DT]B:dh/1U8[14h/0Th<00=>2dh[CR/00dh[0dX;14h[00A:2dX:
BPY:2P9>2P9:2P=:2`e:2PA62P03BPY:2DWZ00A:2P95jP95j@=9j@04BNQ9jDWYBNT7ANT3ANP3ALP3
@LP4ALT2@LX3@LT2@LP5@LL:@LP01D6W@LM1bD79@LP00SfX00<mYcfX?JP013fW00DiZ3fW?JLmZ3VY
008mZ@05?JPmQcf8?HPmQ`01?HT00007@Nm63TH=APe:;DH=BPd00dH=00=:3DX<BP`00dX<00=>34X=
BPd00TW/00M:34h<BPe:34g/BPa>3003BP`2AP`00dX<CPa>3002CPd02Dh<BPa>2dgZDNQAaeG6DLM=
Y`05CJH01Dg5CJI=YTVVBHH014VV0Tf600=9YTV5BHD00Tf600==YTfWCHH00TV500A9IDV5BHI9Q@99
QP0AAHE5IDEV@FI1AD54?B@m8cTT?BA1A4VUBLM1R3V8?JY5j`03CR`4CRd3DRd00e8/DReB;@05DTd2
DRd4DR`2DT`3ET`045I=ETaF:UHZAP/mR3DU>FQ:2UY8ANTmQce4CNU>2eI;0UI<00MFCE9=DReB;4h=
BNa5k@03@L/01TG;ANa5k4G/BNa:2`9>3005CRa>;Dh]CRe>;P02CPh014X>ANe>3Dh]0Th=00E>34h=
CPe>358/00=>;@=B;@E>;@03DRe>;E8^009>;`05CTm>D4i?CRmB;`03DTh2DTl01Ti@DRmB;e8_DTmB
D09BC`EFC`03ETiFL5I`009FK`MFC`03EVmFL5I`00IFL09FD@9FD003FW5JL5Ya00AFL@AJL@9JT@03
FY1JL5Y`009FL@09FW5JTEYaFW5JL5Z@GY1N/EZA009N/P9JT`03F[9N/ejc009J/P03FY9JTEZ@00AJ
K`05FY1JL5Y`FY5JT002FY42GY800eZBFY5JT@02FY43FY000eZAFW5JL@06FY83F[8;G[8015jcF[=N
/Ujb0UjB0ejb011N/F:bH[5VdF:aGXmB;Sf;<<@/`RS49<@]1DGYETYJKP9J/0AJT09JS`03FW1JKeZ@
00=JT09N/09N/@EN/QMN/@03G[1NT5j@009NT0AN/0ANT0]JT005FY5JT5Z@FY1JS`02FY02FXl9FY00
15ZAFXmJSeY_25Z?0eY_1eY^00ENKEj=GXeNK5Y]009JKP03FVmJSeZ>00AJS`YJK`03FViJKEY^009J
K@9JKP05FXiJKUY^FViJK@02EVl00eI^EVmJKP02FVh015Y]FViJKeY^0UY_00=JKUY_FVl02EY_00EJ
KUY_FViJKUY]009JK09JK@9JKP05EVmJKUY^FViFK`03FVh00eY_EW1FK`02EVh00eI]FVeJK@02FVh5
EVh4FVd00eY/FVeJKP02EVh015I]FVaFKEI]15I^00=FCEI<ETd00UI>0UI=00EFKEI<EV]FK5I<009F
B`03ETaFBeI;00=FB`=BC09BC@EFC003DTeB;E9<00=BC003CTaBBe8[00=B:`03CRaB:e8[00=B:`03
CR]>;4h/009>;09>:`9>2`a>:`M>2P03CP]>2Th:00=>2P=:2P03CPY:2TX:00I:2P03APY:2TH:00=:
2@03APU:2DGZ0095jP95j@03BNU5jDWY00E9j@A5j@95b0A5j003ALQ1b4G80095b004@LQ5b4G9ALT4
@LT3@LP5@LL00d78@LM1b003@LL3@LP01D6W@JI1YcfW@JP01SfX0cfW00TmZ3fW?JLmYcfY>JTmZCfX
?JL00Sf80Sf70Cf900001T7_APi63DH>BPe6;P=63P03BPi:3DX=00E:300;BPe:34g]CPa>3DX=APe:
3Dh<BPa63@02BP`00dh<BPa>3002CP`014X<BPe>3Dh<0Th;00E>2UGXELMEaU77009=Y`09CJI9YTfV
CJMAaU77ELM=adfW009=YP99YP05CHI=YTfVBJI=Y`03CJH014fWCHE=QDV50TUU0TV600E9QdVWAHI5
QTEV0091IP0=@DDmACTT>B@m9453AH=9Yd67>FPiRTG[CP`00Th/14h]0U8/00AB;E8/CReB;@ABC@03
CTiB;Th]00=B;@05CReB;E8]ETaFCP02ETd03UY=ET]FBdX=?HTa9cEYBP]JBDX;ALY1ITgYCP`2ET/0
2eI<ETeFCU8]CRe>3DX<ANe5k4G;AN/00TG/00A9k4g/CPa>309>;0A>;@03CRi>3TX>009:3P9>;@=>
3@I>;@EB;PEB;@04CReB;Ti?CU03DU03CU001E9@DTmBD59?DU001E9?00ABD5I@EU1FD09FC`9FK`=F
L004EVmFL5I`EW03EU02EW000eIaEY5FT@02EW000eY`FW5JL@02FY801UZAEW5JTEZAFY9JT@9JTP05
FY=JTUZCG[=J/`02FY800eZAFW5JL@02FY801eZCFY9JTUZCFY5JT5jA00=N/P9N/`=Ne09J/`9J/P9J
T@03FY1JTEZA00IJT@05FY9JTEjBFY9J/P02G[82FY401EjAFY5JT5ZAFY800eZC00IJTUjbG[9J/Ujb
F[<2G[<00ejbG[=N/P04G[800f:cG[9N/`03G[800ejcGY=N/P02G[800ejaGY5R/P03I]802VK@ETi5
Zc2S<>@Xa2d6?JU>2U9;0eI_0UZ@00YFT5I`EVmFKeIaFW1JTEZ@FY5JT09N/09N/@MN/QIN/@08G[1N
TEjaG[5N/5jaG[1NT@9JT@03GY1JT5Z@00AJT0=JT@03FY1J/5Z`00=JT@eJT09JT@=JT0YJS`03FVmJ
L5Y_00AJK`9JS`06FVmNKEi]GVeJSeY_0UY^00=JKeZ?FXh00UZ?00QJKeZ?FXmJSeY_EVmJKeZ?15Y_
2eY^00YJKeI_EViFKUI_FViJSeY^FVmJKPAJK`9JL0=JK`QJKP03EViJKeY^00AJKP03FVmJKUY_00=F
K`04FVmJKUY^FVh3FVl2EVh015Y]EViFKUI_1EI^15Y^00AFKUY]FVeJK@9FKP03FVeJK5I]00=FK@=F
KP03ETeJCEI=00EFC@=FC006DTaFC5I<ET]FC5I;159<0e9=1EI<00MBCE8]DTaBC59=DTa>C006CR`0
0e8[CRaB:`03DR/6CR`2CP/3CR/3CR`2CR/2BP/4CR/5BP/01DX<BP]>2dh:CP/014X;00=>2TX:BPX0
1DX:1DH:0dGZ00A:2DWZANY5jP99jP95jPE9j@=5j@04ANQ5b4GYANT2ANP2ANT00dX9ANU5b006ALP2
ALT014G8@LQ1bD790d7800A1ad6W@JQ1Z0I1b091b@04ALU1Yd6W@JP=?JP3>JT00cfX>JPmZ002?HP2
?HL1?HT00003@Nm63TX=009:3@03BRi:3DX=00I:3@=:3004BPe>34X=CP`4BPd5BP`2CP`04Dh;CPa>
34h<CPe>34h;CPYB2U89ENMAaeG6DLM9YdV6CJD00TfV00==Ye76CJL00dfV0TfU0TfV00E=QTfVCJI=
YTfW009=QP07CJI9YU6TCHA9QDUUBHH01DF60dEU00=1ID55?DD00SdT00/i8cdRAF=5QD67>FLeJ47;
BPa>;Dh/00=>;@AB;0=BC003DTeBCTi>009>CP9B;PAB;@0MDRiB;EI=ETiFCEI<ET]F:UY[APdmZS4V
=FU:35YZBRa5jdF7CNUB:eI;FTaJK5I=ETiBCE8]CPe:3003AN`01dG[ANa5k4G/BP]:34h<009>;003
CReB;E8]009B;@04CPe>;Th^CRh2DRd0158/DPeB;Dh]0e8]3E8^00=BCU9?DTl00UI_159@00IBDE9@
EW5FL5I@ETl2DTl02eI?ETiFKeI?EU1FCe8]FViJKeY`EW000UY`00AJKeI?ETmFD09FC`06FW1FL5I`
FW1JT5Ia2EZA1Ejb00=JTUYbFY<00UjC0eZC1EjB0eZC00AJTUjAGZmN/@9NT@=N/P07G]=RdekDG[AN
/ejbF[800eZA0UY`25ZA0UjB00=N/UZAG[800Ujb0eja0ejb00ENTUZBG[9N/Uja00IN/P=N/`03G[9R
/V;B009R/P03G[9RdF;C009N/P04G[=N/V:bG[82H[0046KBI_=_=G=fMgEVlTW;<>@/Y346?HY:35j:
ETaFKeI`1EI_0eI`00AJL5ZAFY1JT@9N/0=N/@UN/P9N/@IN/PeN/@AN/004G[5N/5jAG[42GY46FY00
0eZAGY5JT@0HFY0;FXl015Y`FVmJKeY`0UY_2EZ?00=JKUZ>FXh03EZ?00=JKeY^FVh00eY^00IJKEY^
FVeJKUY_FVh2FVl01EY^FXiJSUZ>FXl00eY_0eY^0UY_0UY`00=JKeY^FXh01EZ=0UY]00=JKUY_FVl0
0UY_00=JSeZ>FVh025Y_00AJKUY_FVmJK`9JKP03EViJKUI^00IJKP03FVeFKUY^009JKP03FVmJSUY^
009JKP9JK@EJK003EVeFKUI^009FC@9FK@03ETaFKUI^009FC@9BC@04DTaFBeI[EV/4ET/00e9<ETaB
C@04ETd6ET`00eI=DTeBC007CT`2DT/7DR/0158/CRa>;4h;14h[0dh/1Dh[0TX;1Dh[2Dh;00=:2dh:
BPX01dX:0TH:0TH;00I5jdH;APY:2DH:BPT2BNX2BPX2BNT2ANT02DGXBNU5jDWYANU5j478ALQ5j@07
ANP014GYBNQ:2DGX14G80TG70dG80T7800=1ad6W@JL00T6X1d7800=1Z46W@JL00T6X00<mZ46X?JP0
23fX00<mZCVX>JP00cVX0cfX0CfW0Cf70Cf900000d7_APi:3@04BPd3BPh4BPd3BP`5BPd2BPh2BPd2
BP`00dh<BPa>3004CP`00dh=CPa>3002DP/2DPX015H8DNQAae770TfW0TfU00AAYTg7CJM=Y`==YP9=
Y@03CJI9YTfV00==YP09CJM=QU65EJEEj5FUCHA9QDUU0095IPA1IP91I@0?@FA1ID55?D@m93TT>@@m
8TF4@HI1QcUW?HU5bdH;00A>;@=>C@=B;09BC003DTiBCDi>009>CP9B;P03DReFCU8]009B;@0FDTeF
CU9>ETiB;5H/ER]FJdH^?JX]1SEYBPaFJdX]@LY5ZDgYDR]FC5Y=ETd3ETh01E9=CRe>34X<AP`00TG/
00I9kDW/APa:34X=CP`3CRd00e8/DReB;@03DRd2DRh0258]EReF;EH]ETiBCU8]DRh5ERh00eH_ETmF
D009ETl4EU000eIAEW5FL@02EW44EW0015I@ETmJKeY`0UY_00=JD5I@FW001UY`00=JKeY`EW000UY`
00EJLEZAFW5JLEY`00AJT@04FY9JTEZBFY46G[82G[<025jdGY=JTejBFY=N/UZCGY<2GY800ejcG[9J
T`02FY<015jBGY5N/Eja0UjA00AN/UjcH]=Rd`9Re003G]AN/ejb009N/P9JT@9JL0MJT@9NT@03GY9N
/Ujb00AN/P9N/@03G[=Rdejc009N/`05H[=Rdf:bH[9R/`05H]<2H]@00f;CI]=Vd`03I]<2H]<01VKc
H]AR/f:bH]=RdP9V/@0@I]9_=GMgNkYgMf/EDPdmJCDW?FU=kEI^GXiJKUY`EW42EW03EVl3EW0015Y`
FY5JT5ZA0Uj`0eja2Ejb00=N/EjbG[401Ejb00=N/F:aG[403Eja0ej`0eja00ANTEZ@FY5JT@=JT0=N
T@9JT@03FY1J/5Z@00=J/003FY1J/EZ@00MJT003G[1JTEZ@00EJT0UJS`9JT09JT@=JT0EJS`=JT0AJ
S`03FXiJSeZ?00YJS`EJK`AJSP9JKP06FXiJSeZ?FXmFSeJ@15Y_0UZ?00EJSUZ?FXmJSeY_00=JS`04
FXeJSUZ>FXh2FXd00eY]FViJK`03FVl015Z>FXmJSeZ?1UY_0eY^1EY_00EJKUY_FVmJKeY^009JK`AJ
KPEJK`9JKP9JK@06FVaJKEY]FVeJK5Y]1UI^00=FKEI^EVd00UI=00=BCEI=ET`00UI/0UI[0eI;0UI<
1EI=0UI<00=F:eI<ET`00UI<1E9<1Ti<00=BBe8[DR/0158[00=B;4h/CR`014h/00A>:dh/CRa>;0I>
:`9:2`A>:`=>2`=:30A>2`9:2`M:2PE62`05ANY62TH:APY62@02ANX014WZBPY:2DX93DGY0dGX00=5
jDGXANT01TG800=5adG8ALL00TG800A5Z478@LQ1a`a1b0E1Z003?JLmZ3fX008mZ@05?LTmZ3fX?JTi
Z@04>JP00cfX?JTmZ003?JP1?JL1?HT00004?Nm63TH=APd3BPd3BPh4BPd4BP`4BPd014h=BPe>34X=
1TX<0Th<00A>;4h=CPe>30A>2`04DPUAj578CLP2CJL2CJH0156VCLM=YdfW0TfV0dfU00==YTVUCJH0
14fV00]9QTf5DJE=YU6UCHA9QDUUAFE1IT55008m9003@DE1A45400=1I007@DE1A3e4?BA1@dF3@HH0
0SeW00<mRDG[CP/014h]0di=158/00AF;5I<DTeBC@9>CP9B;P9B;@9BCP0HETiBCE8]DTiFCU8]EReF
:eI;BRlmZc4W=DQ5k59<CRe1c4G:CNU>35H/FTeJKEI_0UI>00]B;E8/CP]>2dX;APa5k4G]BNa:34h<
009>3@9>;@AB;0AB;@03DRiFCUI>00EFCP05ERmF;UI>ETiF;P02ETl00eH_DTmFC`08ETl3EU0015I_
EW5FLEIa0eI`00=FLEYaEW400UY`0UY_00IJKUY_FW1JLEY`EW49FW001UZAGY5JTEjAFY5JL@AJT@03
FY9JTEZB00MN/P=N/`03GY=NTUjB009N/P9N/`04GY=N/UjbG[82GY8015ZBFY5NTEj`0eja00MR/UkC
H[=R/f;DG]ARe002G[<3G[83GY45FY44GY4015jaG[9N/Ujc0UkC00=Rdf;BH]801f;C00MVdV;BH]9R
dfKdIaE[5@02I_@026/FI_EVdfKdJ_EZm6;CH]82I]<00f;CI]=R/P03H[4026KBI_9[4g=ELgI[4eI_
ERh2DPd00eH^FViFK`02FVl3FY0015I`FVmFL5I_0eI`0UY`0UZ@00=N/5jaG[401Uja0Ujb00IN/ejb
G[9N/F:aG[44G[800ejaH[5N/@0?G[400ej`G[5N/@03G[400ejAFY5JT@02FY0015j`GY5N/EjA0UZA
1UZ@00=JSeZ`F[0025Z@00ANTEZ@FY1NT09JT0aJS`EJT09JS`IJT09JS`9JSP03FViJKeZ?00IJS`MJ
K`03FXmJSUY^009JKPIJSP03FXmFSeJ@009JS`9JK`05FXiJSeZ>FXeJSP05FXl4FXh01EZ=FVeJSEZ>
FVh00eY_00EJSeZ>FXeJSUY^009JK`=JKP03FVeJKUY^00=JKP=JK`MJKP=JK@05FViJSUY_FVmJKP02
FVd2FV`4FVd01EY/EVeFKEI]FVd00eI^00AFC5I]EVaFK@=FKP03EVeFK5I/009FJ`=FB`9FC0AFC@IF
C003ERaBC59<009BC0Q>C003DT]B:e8[00IB:`=>;0e>:`9:2`=>:`03CPY>2dX;00=:3004CP]:34h;
CP/2BP/2BPX2CPT3BPX3APX014X:BP]:2TH;0dH:0dGZ00=9jDX9BPT00TX92dGY00=5j4GYANT014GX
2dG800=1b479@LP00T781T6X00<mZ46W@LP02D6X0cfX00=1Z3fX?JP00SfX00<iZCVX>JP00SVX0cfX
0Sf70Cf900001Sg_@Ni63DH=BPe:;PY:3P9:3@E>3@9:3@03BPi:3DX=00E:3@05CPe:3DX=CPe>;@02
CR`2CP/0158:CNYAjDg80Tg700A=YTfWCJM=a`9=Y`9=YP==Y@==YP03BJI9YdfV00E=YP9=Q@05BHE9
IDEU@FI1A@03@B@00d54AD=5I002@FD03D5V@DDmAD55@D=5Hd5V?FHmId6YAN]>;4X^009>;@A>C@=B
;@04DRaF;58]DRd3CTh5DRh01E9?DTiBCU9>DRh00U9>015F;5H[EVa:;SfZ=@DeAdG[DR]:;DG/ALY9
jTh/ETaFCUY_009FK`09ETmBCU8]CRa>3DX=APi1c4G]009:3@=>3@9>;@09DReB;58]DRiBCUH_DRiB
;E9>00EFC`=F;`05ETiF;eH_ERmFD002DU400e9@ETmFD007EU001EI`EU1FL5I_EW000UIa00AFL5IA
EW5FL@9FLP9JL@9JL003FVmJL5Y`009JL004EW5FL5Y`FW04FW42FY401eZBFW9JLUYbFY9NTUZC00IJ
TPAN/P03G[=Ne5jc009N/`=N]003G[=N]5jc00=N/`09G[9N/ejbGY5NTUjbG[=N/Uja009N/P04G]=R
dekDG]@4H]@015kDG[=N]5jc0Ujb0ejc1Ejb00IR/V:aH[5N/V:cH]@2IaD016;dH]=Rdf;B0V;C00=R
e6;CH]<01F;C00=ZmF/EJaD00VKe00=Rm6KeI_@00V;C00UR/f:bH[9N/UkBH]9N/UjAFY000Uj@00mN
[ejaH]5RdV;AG[5BCdW[CReFLEjbG[=JTEjbG[400Ujb00INT5ZAFY5JTEJ@EVl2EW001EJAEW5FLEZ@
FY400eja00=N/UkBG[800eja00INdUjcG[=N/ejbG[42H[44G[801EjaH[5R/EjaH[4045ja00=N/5ja
G[400eja1UjA0UZA0eZ@00EJ/EjaFY1JT5Z`00UJT003FY5JT5Z@009JT0]JS`AJT0=JT@QJT0AJS`04
FVmJT5Z@FY06FXl;FVl00eZ?FXiJSP03FXh00eZ?EXmFS`02EXl01eZ>FVmJKeY_FXiJSeZ>00EJS`03
FXiJSeZ?00=JSP03FViJKeY^00=JK`03FViJSUZ>009JSP03FVmJKUY^00EJKP9JK`EJL0AJK`03FViJ
KeY^00AJKP03EVmJKeY_009JK`9JKP05FVeFKUY^FViJK@03EVh015I]EViFKEI^1EI]0UI^00=BKU9]
DVd00UI]0UI[00=FBeI<ET`01EI=15I<0e9<00=BCE9<DT`024i<1Dh/00EBC58/DRa>;4h]00A>;003
CR]>;4h[00A>:`=>;09:309:2`=>:`03BP]:34X<00E:3005CP]:2dX;BPY:2`03CPT6BPX2AP/5APX2
ANX01dH9BPY62TH:APU5jDGX00U5j@U5j0=5b003@LQ1bDG80095b@=1b@03@LQ1bD7900=1b@M1b003
?LU1Z3fX00E1Z004@LQ1Z46X@JP2?JP00cg9?JPiZ@04>JP00cfX?HPmR002?HL1?HT00003?Nm5kTH=
009:3@06BPi:;TX^BPe:3TX]0dX>0TX?00E:3TX=CPe>3Dh<009>3@=:3PI:3@=>3@9>3003CRa>34h<
009>2`0<DPYAjU7YDLQ=adVVDLE=YTfWCLM=Ydg70TfV00==YDfVCJD02DfV00=AYTfVCJD00Tf500E9
I4ET@DE1ACdT008m8`0<@DA5@dV5AHE5ID5U@DDmA453@D95Q4FV0T6700A5ZDGZBPa:;P9>;@05DTeB
;E8]CTiB;P05DRd01E8^CTiBCe9?DTh00e8^00=BCE9>DTh00e9>0UI>015FC5I;EVa6;TG:>@@mIdGZ
FV]:CDG[@HM5bDh<ETeJKUY_009FK`9FC`03DRiB;Dh>009:3P04ANi9kDW^BPh3CPd01Dh]DReB;E8^
DTh01eI>0UI?00=FD5I?ERl00eI?00AFD5H_ES1B<@=BD@9FD0EFD@9FD003ETmFCUI?00=FL005EW5F
D5I@EU5FL@02FW82FW400eY`GY1JL004FW000eI`FW1JL002FY42FW42FY400eYaFY9NTP04GY<01Ejc
GY=JTUZBGY8015jb00EN/ekCH]=Ne5jc00AN]003G[EN]5jc009N/`03G[9N/ejc00=N/P06H[9N/Ujb
G[9NdUkC0f;C00ARe6;CH]=Rd`=Re005G[=N]5jdH[ARd`03G[<3G]<015jbH]9RdVKB0V:b00=N/V;C
G]<00V;d0V;C00ARdV;CH]=Rd`9Vm004H]9N/UjbG[83H]82G[800ejcG[9N/P03G[82GY800ejAFY5J
/@03FY003UZ?FXiJSUj_H]5VdUjaFTi9jd6/CRiJTF;CI_<2H]<015kCH]=Rdejb0UjA0UZA00EFT5Z@
FY5JTEIa009JT@03FY1NTEja00=N/P03G[=NdUja009N/@07G]9NdekCG]=N/UjaG[800f:a0ejb16:a
2Eja1Ujb00AN/Ej`G[1N/0EN/@03GY5N/Ej`00IN/004G[5N/5j`G[09FY05GY03FY001Ej?FXmJSeZ?
GXl015Z@0Uj@0UZ@15ZA1UZ@0eZ?0UZ@00INT5Z@FY1JT5Z?FY0=FXl00eY_FXmJS`0;FXh5FXl7FXh2
FXl00eY_FXmJK`04FXl2FXh01UY^FXiJSeZ>FXmJKPEJK@04FViJKeY_FVl3FW001UZ@FW1JL5Y`FVmJ
L0AJK`04FXiJKUY]FVh5FVl015Y^FVeJKUY_0UY^0eI^15I]00UFKUI]FVeFKEI/EVeFC59>DVh00UI^
00AFC5I;ET]FB`9FC0QFC@9FC003DTeBC59<009>C0EBC0AB;09>C@09CRe>;4h/DRa>;E8]CRe>;58/
00A>;0E>:`9>;09:3003CRa>:dX;00=>:`9:2`=:3008CP]:34h;CP]>2TX:CPY:2P9=j@=>2@I:2PE6
2P=:2P03APY:2DH90099j@03ANQ1b4GY00I5j@]5j095b0=5b@=1b@03ALQ1b4G80091b@03@LY1bD79
00E1b003@LU1b46X0091Z091Y`E1Z091Y`03@JPmZ3g900@mZ0@mY`03?JPmQcfW004mR@0000@mkdH?
BPe63PA:;P=:3P03ARm:3TH?00A:3P06BPe:;Dh=CPe>;DX^0TX>00=>;4h]CPd014h=1Dh<00AB358;
DP]B2`9B2P06DNUAj4g8DLMAaU770Tg700=Aadg7DLH00U6V34fV00UAYU6UDHE=QDeTBFA1A3dT>@@0
0Sd300M18dE4AFE5IDEV@FE1A@02@D@02d52AHE5Qd67@HQ5ZDG;APa:;Th^DRh00e8]00=>CU9=DRh0
0e8]0U8^0Ti>1E9?0e9>159?01]FCeI>ETeFK4i>AL/mAT68BP]NRe:>AN/mIT79BReBC5I_FVmFL5Y_
EW1FCe9>DRe>3TX>APh00TG^0TW^0Th=0U8]00AB;U9>DTiBCP9FCP9FC`9FCP06ETmFKeI_EVmFL5I@
0UI?00=FKeI`EU400eIa0UIA00=FL5IaEW401UIa00=FL5Y`FW400eY`00EJLEY`FW5JLEYb009JTP9J
T@9NT@05GY1NTEjAFY5N/P03FY800ejbFY9NTP02GY83G[<3GY<00ejcG[AN/`02G[<2G[801F:aG[5N
/UjcG]<00V;C00=Rm6;DH]@00V:d0V;E00ERe6;eH_ANe6:c009Rd`05H]ARdekDFY9N/`02G[801ekB
H_ARlf;dI_AVe6KC009Ve09Re09Re@06H]AR]5kDH]ANeF;E0f;e0V;d0V;C00MRdUjbG[5N/F;CH]AN
d`03G]82G]<00f;BG[5N/@02G]800ejbG[5N/@03G[401ejbGY9JTEYaFY5JT5ZA009JL@04EW5JTEZa
EY03EVl03eY_FViNSf;@I_9R/5Y>DN]9Zdh<EW1N/F;dG]9Rd`02H]@016;CH]ARe6;C0ejb00=J/UZa
F[400eZA00AJ/UjaG[5N/@9N/P9NdP03G]=NdUkB009NdP=Nd`04G[=N/UjbG[82H[800f:cG[9N/P02
G[4016;AG[5N/Eja0UkB00EN/EjbG[9N/Uja00MN/PQN/@03G[9N/Ej`009N/@MN/003FY1JTEZA00MJ
T003GY1N/5j@009NT0=JT0EJS`9JT003FY5JT5j@00=JT0AJT@UJT003FXmJT5Z?009JK`=JT003GXmJ
SeZ?009JT003FXmJKeZ?00EJS`=JT0IJSP05FXeJSUZ>FXmJSP07FXl5FXh@FXl015Y_FViJKUZ=0eZ?
00=JSUY_FVl01eY`00=JKeY`FVl00eY_0UY^00UJKEY^FViJKeY^FXmJKeZ>FVd00eY^15I^0eI]15I^
0eI]00IFK59]DViBKUI=FV`3ET/01UI]ETeBCUI=EViFC0AFC@=BC@UBC004CRaBC59<DRd3CTd2CR`2
DR`2CRd00dh/DRa>;003CR`3CR/9CR`4CR/2BP/2BP`4CP/4CPX00dh9DPU>2@02CPT;BPX3APX02DH9
BPU:2TWZBNU:2DH:ANU5jP05ANT9ANP4ALP7@LT00d78ALQ1b004@LT5@LP00d79@LQ1b@02@LT01478
@JM1Z46X0T7800I1Z46W@JM1b3g8?LT2?JP3?JL013fX?JLmZ3fX0SfW0Cf9000013g_APm:3DX>0TX^
0TX]0dX>00=6;dX>BPh014X>0TX]00M>34h=CPe:;Dh>CPe>;003CPd00dh]CPe>3006CP`01U8<DP]B
2e8;DNYAj@9=b0M=a`05DLI=YTfVCJI=Y@02CJH00dVVBJM=Y`03CJH2CJL2CJH01Df5CHA9HdES?B<0
0ST300LhhSd3?B=1A4E5AFE5IP02@FD03455@DA1@dF5AHM1QceW@HQ5bTX=BRi>;@AB;@04DTeBC58]
DTd4DRh3CTh4DTh3DTd00e9?CU1BD003DTl03UI>EVe>;TG;>BDi9TG8FVUFSDWZ@HI1bDi=EV`2FVl0
25I`FY1FL5I_DTiB;4h=BNd4ANd01DW]CPe>3E8/DRh00U9>0UI?0eI>0eI?0UY_00AJKUY_EW1FK`9J
K`05FViFCeI@FW1JL@02EW4015IAEW1JLEYa0eIa00=JLEZAFW400eYa00AJL5ZAFY5JTP=JT@03GY9N
/Ujb009R/PAN/@AN/P04FY9N/UjbG[<5G[8015jcGY9NTV:c0ejc00ER/ejbH[9RdV:a009N/09N/P0;
H[=Rdf;CH]9RdekCG[=N]5jcH]=Rm003H]<01f;DJcM_F6/FH]ANe6;D00=Rd`06H_=[5FmGKeM[5V/E
0VKd00=VmFKdH_D00VLF00i[5V;EG[=J/eZCG[=Vm6/fJaARdejbG[5N/6:a0Uj?0UZ@00=N/F;CG[40
0UZA0ej`01IJT5Z?EViFKUZ?G[1N[eI_ETiF;EH^ETmJL5jaH]9RdeZADRmB;UI>ETeFKP9BC@9B;@0;
DRaJK6:^HZmJK57/@J]5c5I=FY1Nd@02G]800ejbG[=N/P05G[802EjaFY5JTEZ@F[5JT5ZAF[9J/@02
G[47H]83G]84G]<015jbG[=N/Ujb16:b16:a0Uja00=NdEjaG[400ejb00=N/EjbG[401Ejb00=N/Ejb
G[4025ja25j`0UZ@00AJTEZ@FY1JS`EJT0ENT00=FY1NT5j@GXmJSej>GXmJSUj@FY1JTEZ@GY001UZ@
00=JTEZ@FY0015Z@0eZ?00EJSUj?FXmFKeY_009JT004GXmNSUZ>FXh5FXl00eZ>FXmJS`02FXl3FY09
FXh015Z?FXiJSeZ>1EZ?0UZ>0Uj>00=JSUZ?FXl01eZ?00=JSUZ?FXh015Z?00AJKeY^FXiJS@=JSP03
FVaFKEY^009JK`03FW1JT5Y`009JL007FVmJL5Y_FVmJKUZ>FXd015Y]00QJKUZ>FVmJKeY^FXeJSUY]
0UY^0eI^0eI]15I^00UFKEY/EVaJJe9<ETeFKUI=ET`00eI;00YFC5I^DTiFCEI<ET]FC5I=ETaFC@=B
C@9BC004DT]BC59<DT`5DT/0259<DReB;E8/CTe>;59<DT/2DR`00dh/CR]B:`04CR`3CR/9CR`5CR/3
BP/5CP/3CPX3CPT2CPX6BPX7APX01dX:APY:2DX:BNY9jDX800U5j@E5j003ALQ5j4GX0095j004ALQ1
b478@LP5@LT01T78ALQ1ad77@LQ1b@e1b005@JQ1b478@LQ1Z003@JL00cg8?LTmZ007?JL00cfX?JM1
YP01?HT00004?O123dH>ARh2BRh2BRd3BPh3ARl01TX?APm:3TX>BRi:;@9>3@05CRe>;Th^CPi>3@02
BRd00dX^CPi>;P07CPd01dh<DPa>358;DPYAjDgY009=b0A=a`AAa`03ELIAYTfU009=YPU9Y`05CJI=
QTf5BFA5I002?DD2?BD00cdT?B=1A@03AFH00d5V@FM1I@03@FD2AHL023eW@HU5bdX<CTi>;U8^DRd2
DRh00di>DTeB;P02DTh3DRh2CTh5DTl3CTh0159?CU1BD59?0U9@00ABCe9>BRi5k08e1P07>DA:24i=
CPY1ISf9CVh00UZ?00MJL5Z@EY1FTEI`DTiB;002CPd00dX>BPe:3@02CPd00dh]DReB;@02DTh3ETl0
15I`EVmFCeI_0UI`25Y`0UY_00AFL5YaFY5JTPAJT@05GY9NTejCFY=JTP03G[84GY4035ZaG[=Re5kD
FY9NTEjbH]ARdUjbGY5NTP9NT@9N/P04G[=Ne5jcG[<2G[800eZAF[9N/P03G[82GY802EjAGY9NTejc
GY=N/ejCGY9NT002G[401EjbGY5N/UjbG]<00V;C00ANdekDH_ENe09N/`0bG[9NTUkCJeMg^WNkKeQR
mF;DI_I[5fKeH]9Vlf/eJeM_F6LgIaIVmF/FJcMW5F;eI_EVmV;DH]EN]5ZCFY9N/V;CIaEVlf;BGY1J
KeY^ETiJCEI<EReFCUZ@F[9J/EY`FVmN/@9RlP03FXmFCE8/009B;005G[1Rd5ZaCRa9k002BNd01U8=
EVmFT5ZBETm9kP95c00DANa63Dh=CRi>;Dh=BPa634X<APe5k46[?HY>3EI_F[9NdV;CG]9Nd`MN/P04
FY5JT5ZAF[03F[43G[42G]800f;CH]9RdP03H]82G]801ekCG]9N/UkBG]=NdUkC009N/`04G[9R/V:a
H[82H[400f;AH]9N/@04G[4015kBG[9N/Uja15jb00EN/ejbG[9N/UZb00YN/@04G[1N/EjaG[43G[00
0ejaFY1JT00>FY03GY0015Z@GXmJSeZ?0UZ@00=JTEZ@FY401UZ@0UZA1eZ@0UZ?00=JT5jaF[400UZ@
00=JSeZ@FZl00UZ>0UZ?0eZ@00=JKeY`FXl00UZ?0eZ@15Z?00=JSUZ?FXl02eZ?00MJSUZ?FXiJSUZ?
FY1JS`03FY04FXl00eZ>FZmJ[`03FXl00eY_FXmJS`02FXl00eZ>FViJS`02FXl00eY_FXmJK`02FY02
FW001EYaFW1JL5Y`FVl00UZ>0UZ=00=JKEY^FVh015Y_00=JKUY]FVh01eY^0UI]00=FKUI]EVd00eI]
00YJKEZ=EVeFKEI^ETeFC5I;FV]FB`9FC09BCP06DTeFC5I<ETeFC5I=159=1e9<0e9;00ABCE8]CReB
;@=>C@IB;11>;0M>:`03BP]>2dh;00=>2P03BP]:2TX:00Q:2P05BP]62TH;AP]62P03BPX2APX01dX:
APY:2DX:BNY9jDX90095j@03ANY5jDGY00A5j@=5j003ANU9jDGX00=5j003ANU5b4G900M1b@04@LQ5
b4G8@LL4@LP00d79@LQ1b002@LP2@LT7@LP013g8@JQ1Z46W0SfX00<mbCfX?JL01SfW00<mZ3fW@JH0
0Cf900000cg@@Q1:3P03BRh00dX]BRi:;P04BRh01DX_BPi:;dX_BPl00TX^0Th=0dh^1Dh>0Th^0dh]
0dh=0Th]00AB;58<DP]B2P9Aj@9=b003BJQ9Ydg6009Aa`==a`9AYPM=YP06CJM9YdVWCJM=YU6U0TfV
01Q9QDV6AFI1ID56?BDm0dETAFE9QdVWBHM5Id5X@FI1ID54AHI9Z4FWAHQ1ZTG;CP`2CRh3DRh00e9>
DTmBCP06DTh3DTl4DTh7DTl3DU003e9?CRm5kCeZ<@Le94GWCTa=jCTT=DM63UI]EVmJT002FY4015ZB
EW5BCUH/0dh=00A>34h=CPe>;@9B;@04ETaFCUI?EU02FW03FVl00eI`FW1JL002FW000eZ@G[9N/P03
FY43FW000eZAGY5N/P02GY400ej@GY5JT@02FY8025jcH]=N/ejAFY1JKeY`FY02G[04FY4015Z@G[1N
/UZA0eY`00=JKeY`FVl00UZ@1EZA2EY`0UYa00IFDEIBEU9JDEYaFW02GY001EZAFW1JL5ZAF[800Ujb
00ARlfKdH]=JTP=JL@06GY5N/f;dIcE[EVLD0Ujb00QNTUZBGY9NdVKdH_9N/EZa0UJB00IJTF;BI_AV
lUjaFY02FW001EI?DRiBD5ZAH]<00VKd01a[56KcGXmF;5H;ERa=jdg/CPeFCEj?FVmB;EH=FTeNSUj<
EVeB;4G[?JU5jdh<DReF;DX=AN]1Z`8mR@03>HTiRSV:008mZP05?HY1ZD6Z?HTiR@02?JT03479?JPe
AS44<@<a9S46=DM9k5J@G[5JT@9J/@03G[5J/UZA00MJT@9JT003G[1N/Eja00AN/@=Rd`URdP9Rd@05
G]9RdUkBH]9NdP02H[82H[400f;AH]9RdP02H]84G[43G[83G[47G[8AG[4=G[07GY000eZ@GY1JT002
FY000ej@FY1JT00;FY000ej@FY1JT002FY000ejAG[1JT003FY000ej@GZmNS`03GXh00eZ?GY1JT009
FY03FXl01Ej?FXmJSUZ?GXl015Z@00IJSeZ>FXiJSUZ?FXh2GXh00eZ?GY1NT004FY000ej?FXmJSP03
FXh3GXh2FXh@FXl01eZ@FY5JLEZAFW5JL5Y_00=JSP04FXeJSUZ?FXh4FVl00eY^FVeJKP06FVh2FVd5
FV`2EVd3FV`01EI/ETaFC5I<FT/00eI;00AFJeI]ETaBC@=FC0AFC@04DTeFCEI=ETd4DTd0259<DT]B
Be9;DTaBCE9>DRd2CRd00e8]DRaB;003DR`00dh/DR]>;002CR`3DR/7CR`2DR/00dh:CP]>2`05CR/2
CP/5CPX014X:CPY>2Th:1DX:0TH;00=:2dX:BPX024X:0TX900=9jDH9APX00TGZ1dGY0TGX00=1adGX
ANP01DGY14G900A1bDG9@LU1b095b1E1b091Z003@JLmZ3fX008mZ0<mY`8mZ08mY`91Y`51YP4mR000
00<idD8@BRh01TX^00=:3TX^BRh00Th^0TX^00E:3TX?BPi:3TX]00E>;P04CPi>3Dh=CRd3CRh014h]
CPe>3Dh=0dh]0U8/0U8;00=B2TgYDNP00U7800AAadg7CLQAa`9=a`05DLM=adg7DJM=Y`02CJH0156V
CJIAYTg70U7700=AaE6VCJH00dVW01]9QTV7BHM9QTEVAFE9IDV6BHM=Z4V7AHM5Id5VAFE5I4F6CLU9
Z4F9@H]5k4h<DRe>;U8_DRh00U9>0e9?00=BCU9?DTh00U9>0e9?1E9>0U9?01EBD59?DTmBCe9@DTmB
D4i>CTm>3DG]>HY1ZDX:CRe>2SU6;@Hmc4h]EVl00UZ?00EJKeI`EU1B;U8]009>;@9>3@=>;@03DRaB
;EI<009FCP04ETmJKeY`GY03G[402EZ@FY5JTEZAFY1JTEjAFY9JT@03FW0025Y_FY1NTEZAFW1JKeY^
FW03FW401EjAFY5JTEY`FVl00UI_00EJKeI`EVmFCUI?009FL003ETiFKUZ@009JL004EW1JL5Y_ETl2
ETh01EY_EW1JL5Y`FVl00UI?00UFL5I@EU1FD5Y@FTmJL5jAFY400UI@00iFDEIaGY9NTEY_FViNKEj?
FVmJL5Z@FY5N/UY`0UY_00YN/EjbGY9JLEI@ETmFKeZ`F[5FT@9FL09FC`9FCP0<FVmJdeZaDRi>;EJB
F[9N/UZbEY5BCdh>0TX>0Th=00m9kTX>CPm>D59aFY9FT5I`CPi5k46Z@HY5ZT7;AL/00TG/00E1c3f:
>FTiJ3f9008mZ@04>HPiJ3UX=DH2<BH3=DH2=DL0234V;@Da1SE8<DLa9S4W=DL2>FP2=DL02cUX=DDa
12cS:<8XXRR2<@M1ZeY^F]<01EZA00=JTUZAFY400UY`00MJLEZAFW5JLEZAG[9N/004G[42H]83H]<8
H]83H[42H[801F:cH]=Rdf;BH[800V:a00ARdUkBG]9NdPEN/@=N/P=N/@MN/P9NdQ1N/@04G[1N/Eja
G[42GY4015Z@GY5NTEja0ej`00ANT5j?GXmNT0=JT005GY1JT5j@GY5NT00;FY02FY400ej@FY1JT002
FY000eZaG[1NT@02FY43FY001ej?GXiNSej?FXmJSUZ?00AJT003FXmJT5Z@00=JT005FXmJT5Z@FXmJ
SP02FXl5FY02FXh2GXl3GXh015j?FY1JT5Z?1EZ@00=JSej?GZl015j>0UZ>2eZ?00EJKeZ?FXmJSeY_
009JT0=JT@03FY1JSeZ>00AJSPEJS`04FVmJKUY]FXh4FVl2FVh2FVd3FV`2FVd015I^EVeFC5Y[0eY/
0UY<00=JBeY[ET/015I<00ABCEI<ETaFC0EFC@=FC003ETeBCE9=009BC@ABC006DTeBCU8]DReB;58]
0e8/1dh/258[00=B;58[DR/00U8:0U8[2Dh[14X;00=>2TX:BPX014X;00=:2Th:AP/00dX:00=62TX:
BPX00dX:00=62dX:APX00TH:00I5jTH:ANY5jTGYAPT2ANT00dWYANU5j@04ANP6ANT00dG8ALU5b@02
ALT01479ALU5b4G95T7800Q1Z478?JLmb3fX>JLmYcfX0cfW0cfX0T6W0D6V0D6Y000013Wa@Q5:;TH_
0TX^00=6;TX^BRh00dX^1Dh^00=:;Th^BRh00Th^00=:;Dh^CRh00dh^0Th]14h^1Th]00U>3E8/DPaB
2e8:DNUEie77CLP00Tg700=Aadg7CLL00U770TfW00==YU6VDJH0156V0TfV00A=aUG4DJE=YP=9Y`03
CJIAae77009=Y`06BHM9QTV6BFI5ITEU0TEV00a1ITEUADA9QDg8BJQ5RD6;ALa:34h=DRd3DRh0159=
DTiBCU9?1E9>0e9?1E9>0U8_00=>D59?DTl00U9?01EBCU9?DTiBCUI>DRe>34X<BP]B;EH[?FPXiCf[
DReJSeZ>FViFKUI>DTh00Th]00E>;Th=BPe>3E8]009B;09FC004DTaB;EI=ETh2FVl4FVh02eZ?GY1J
T5Y^ETiFKeI^EVmFCU8]ERd00UI=0eI^00IJKUY/FT]FC5I>FTl2FVl00eY>EReF;@03ETd2DTd3DR`0
1e8]DTeBCEI<DTaFC5H]009B;@0GETeFCUI<ERaB3Dh=DReFKeY^ETiB;Dh=CRiBCe8^ETmJKej@G[1N
/EY_DTmB3P03DPd014h<DPaF:eH/0U8<00AF;E9>CRe:3P9>3@04DPaB;E8]CPd2BPh2CPd06TH=@La1
c4G]CNeB3Dh=DPaJSUkdFY5>;UI`H]9R[e8]ANdmZcEZ=DTaB3UY@L]1c47;?HX2<DT01cF:?Ja1bcV:
=DPe9c4V008a1@09=BHiIcV9>FP]1RT5<@Ha9Rd600D]1@08;@H]1C46<@H]1C45<BH]1@8]9P07;@HX
iBST:>D]1C45<@H00Rd500da9S57=DH]9S44;@DXa2cW=D]B;Uj^F[5JT@02FW000eIaFW5JT@02FY40
0eY`FW5JL@02FW42FY401UjbG[5N/5jaH]9Rd@aRdP05H]5R/F:aH[5R/P03H]<016:cH[9R/V;A0V;B
0UkB1Uja0ejb0eja00=N/UjcG[800Ujb00=N/EkBG]402Uja0ej`1Eja0Uj`00AN/EjAGY5N/09NT@04
G[5N/5j`G[03GY02G[000ej@FY1NT004GY04G[04FY000eZAFY1JT002FY03GY001EZ@G[1N/5j`GY40
0UZA0ej@00MNSej>GXmNSej_GXiJSP04FXl2GY001Ej?FViJL5j@GXl00UZ@00AJSeZ>FXmJS`EJT09N
S`ENSP03GXmNT5Z@00IJT003GZmNSej>00ANSP9JSP=JS`=JT003FXmJSEY^00=JKPIJS`=JT09JS`EJ
SP=JS`9JSP03FVmJKUZ=00=JKP04FXiJKeY^EVh2EVd3FV`00eY^FVeJK@09FV`2FV/4ET`0159]EVaF
KEI<1EI=0eI<00=FCE9=DTd00U9=1E9<00ABCE8]DRaB;09BC09B;0=>;0=>C003CRaB:e8[00QB:`=B
:P9B:`e>:`03CPY:2TX:009:2`962`07BPY>2TX:CPY>2DX:APX01DX:00A62dX:BPY:2P=62P95jP=9
j@07APU:24WYANQ5adGWANP01DGY0TGX00=5b4G9ALT00dG90dG80TG70d772D7800=1Z478ALP01D78
0T6W00E1acg8?JPiZ3VW00@mY`<mZ003?JM1Yd6V0051R@0000@idT8AARm6;`E:;P=:;`A:;P04CRi:
;TX^BRh9CRh01Dh]CRi>;Th^BRh00Th^14h]00Y>3E8]DPaB358:DNYEie77CLQAb0EAa`08ENMEaU6V
BHI=YUFUDJIAY`9=a`9=Y`08CJIAaE6UDLM=b578CLM=YP9=Y`05CLQ=Z4VWBHM9I@03AFD03T56@FI1
ITEV@DA5IDVXAHPmJCeZAL]9k4h=DR`2DRh0159>DRiB;U9>0e9?0e9>0di@1E9>00AB;e9>DTmBCP9B
C`ABCP9FL00ADTm>;Dh]ETaB;58;>DL]1cfZDReJ/5Z>FXmFKUI>DRe>;@02BPh00dX=BPi:3@03BPd0
1dh=DRe>;58]ETaBC5H/009FC004FVeFCEI<ET/4ET`015I=EVeFCEI<0U8/0UH[00QFC5Y]EViFCEI]
FVaJC5H/0UI=00MB;58<DPaB2eI<DTa>;@02CRh03Dh>BPi:3Th=DReBCU8]CPe:3DW]BPe>3Th=009:
3@08ANe9kDW]CPeB;Th>APi5k@91k@06APmBD4h_ANe9kDX=0Th_01I5kT7<?J]1bd7/AL]1ZSf8@JQ5
bDG:AN]63DX>CRm63D7<>HXmZd7<?J/iRP91c00@?J/eB34X>FTmZdG<ANe5kTW]ETeNdEjaDTm5kT6/
?HX2=DP02c4W;>HXa2cU<DPiRSV[=FTa9bSU;@L00RdW00@]1Rd5;>D]1P8/i@0=;>@Xi2SS:>@XiBT5
;@HY1RSU:@H]1bT6:@D00Rd600<Y1RcU;@H00Rd600@/iBd6<BLaB08]9`8a9`04;BLa9c4V<BL3=DP0
2SUY?HXiZcUY<@L]1cE:@NmBTUJ>0UZ@0UY`00=FL5YaFY400eZA00AJTUZCFY=JT`9JTP04G[9N/Ejb
G[82G]8;H]<00f;BH[9R/@02H[42H]84H[82G]801UkCG]9NdUkBG[9N/@=N/P05G[5N/UjbG[9N/@07
G[800ejaG[9N/P02G[8CG[45GY4025jaG[1N/5j`G[5N/5jaG[03GY49G[03GY42FY44FY0015Z?FY1J
T5Z`0ej`00=NTEZAFY400ej@15j_00=J/5Z?FY000UZ@0UZ?0Uj@00EN/5jaG[5NT5j?00=JT003FXmJ
T5Z@00=JT004GXmJT5Z@FY05GXl2GY000ej`FY1JT003FY03G[02GXl<FXl01Ej>FViJKUY^FXh015Z?
0eZ@00=JSeZ@FXl01EZ?00AJSUZ?FXmJS`AJSP06FXeJSUZ>FXmJSUI_0UY^0UI^0UY]00AJKUI^EViF
KP]FK@06EViFCEI=ETaBKEI/0UI]2EI=2U9=00MB;E8/DTaBCE9<DTeBC002DR`5CT`00e8[CRaB:`0<
DR/2CR/8CR`3CR/8BP/00dX:CPY>2P02BPX00dH;BPY62P03BPX00dH;APY62P04APX02DGZAPU:2DX9
APU62TGXANU>2@02BNP8ANT00dH9BPY5j@04ALT00dG8ALU9j@02ALP3@LP2@LT2@LP2@LT3@LP00d79
@LQ1b004@LP00cfW@JLmb002?JP00cVY>JPmZ003?JL4?JP1?JL1@JH1?HT00003>M524DH?00I:;P=:
;`A:;Pi>;P03CRe>;Th]00=>;P9>;@9B;@9B;005ERaB35H;ENYEi`03DLP03U77ELMAae77ELMAaUG5
DLIAYTfUEJ==YDfWDJL3DJH01DfWDJIAYTfWCLP00TfW00==YTfWCLL00TfX00M9Z4V7BFI9ITF6AFE5
IP02@FH034EV@DA5IDEW@FPmJ3eY@L]9k4h<DRaB;@MBCP9BC`9BCP9>C`03CU1BCe9?00ABC`04ETiB
CUI=ETh2DTh00eI>DTiBCP02DTh2DTl0258^FViB;4W[?FPiB46ZCP/2FXd01UI]ETeFCEI=DRe63@95
k005@Ne1bd7;@L]5b`02AN`01dX=CPeB358/ER]F2e8;00=B3007ER]FC5H/DP]F;58/CP/00Th<00Y9
k4W[DRaFBeI<DPa:34h<DReB309:3095k099b`05CN]F;5X]CPa1j`02@L`0247;@J]1Zd7;AN]:3DG/
@L/2?HX01CfZ@L]5jdG[AL/00T7;00=1Zd6Z@JX00T6Z00<mRSV:>HX00cV:00<mRSV9>FT00cEY00da
B2dX=FPiRCf9>DHeACDT>D=1Yd68>FLmR@02?JX01SE9:@LXiC4W=FPiJ08aB00A<DTa:347=BLeB3DW
<BL/iRd5?JU5jcV8:>DPYRC59<@Ta@029<@2:<@00bS39<@Xa002:>D2;>D01RcV;>DXiBcU:<DXa08X
a@0::>D/iC46<BLa1c4W<BPa9bdW;BP3<BP00cE8=DTeJ002=DP01SE:>FXiJCUZ@J/mZ`8iRP03?H]1
c4G]00=5k@04BNe5kDW]CPh2BPh02D7^?H`eBCU[ANi>;UJAEVmFL002FW001eI@EW1FL5YaFW1JTEZB
00=JT`04GY=N/UjbG[<4G]<=H]<00f;BH]5RdP05H]82H[400f:bH]9Rd`04G]<016;BG]9N/Ujb15ja
00=RdUkBG[800Ujb0Ujc00AN/UjaG[5N/@9N/P=N/@03G]5N/Eja00MN/@9N/0EN/@05F[5NTEjAG[1N
/@06G[03GY000ejAG[1N/007G[000ejAG[5NT@02FY47FY001Ej`GY1NT5j@G[000Uj@15j?00AN[Uj_
G[1J/0QNT09N/09NT0=NS`ANT005FXmJSUZ>GXiNS`02GY0015j_GXmNSej`15j@00AN[ej?FXmJT0AN
/0=NT0AJT003GXmNSUj>00=NSP03FXiNSUZ>009JSP03GXiJSeZ>009NT004FY1N[ej?FXl6FY000eZ?
FXiJSP09FXh015Z?FXiJSUY^0eY_1EY^3eI^15I]00=JK5I<ETd01UI=00=FC5I=DTd0259=0eI<1E9<
00AFBe9<DT]BC09BB`AB:`03ERYB:e8[00=B:`=B:P9B:`03CR]>;4h/00M>;0A>:`=:2`9>:`=>2PA:
2P03BP]:2TX:00U:2P962PA:2@962P03APU9jDWY00M5j@=5j095j@95bP07ANY5bDG9ALU5b4G9@LP0
0TG92T790T7814770d7800E1YcfW?JDiQCV600<mY`04@JM1Z3fX?JP3@JL1?HT00004>M924TH?BRh2
CRh3BRh3BRl4BRh@CRh014h]CRi>;Th^0Th]00YB;E8/DRaB;EH]ERaF2eH:ENQAj09Ab0EEa`9EaP07
DLIAYU6VDLAAYTfWDJL00e6V0TfW00==ae76CJL00TfW00I=YTfWCLM=b4fXBJP2BJL014fWCLQ9YdF7
0dF600e1AD5VAHM1R469?HY5bdH<CPe>;4i=DTeBC`07DTh2DTl2CU000e9@DTmBC`03DTl00e9`DTmF
C`05ETh5ETl2DTl03dh_CRe>34G/@JU1QdWZCReFKEZ>EViB;Th]BPe5j`02@L/013f[?JXmZSfZ0T6Z
00E1bT7;AN]9jdX<0099j`=5j`95b`=5j`91bP03ALY1bD7:00=1bP03@LU1bT6Z008mR@0I?JY1ZT6[
@JXmRCeX?DLmIdG:DRaB;T6Z=DLiRCf9>DLeAcU6>FPmR3f9?FPe9SD7>FT00d6Z00<mZSf:?HX00SeY
00dmJ3U7=DHiJ3UY=FXeJC58;BH]9c4W;BH]1@03;BH2:@H01CEY>HXa9bd5;>D00Rd40RcT0RS300@X
i2d5:@HY1P8Xi008:>D]1BT5:@HXiRSU:>H/i@8]1P06<@H]1BcT:>@XhbST0RSU00<XiRcV;@L00S4X
00@e:34W<@Ha9P@e9`0:>DPmRT6:?FXiBCeZAJ]1Rcf:@J/3AL`06dG=ANe5kTh>CPm>3TW^CNiB3UH^
ETiFCEH^ERmFDEYAERmB3UH_FTmJL5I?FW1NTEjBGY5JT@02FW000eI`EW5FL@02EW402E9@CPm9kT7>
CNiFD5JAEY1JT003FW001EYaFW1JL5Y`FY400eZB00ANTUjcG[=N/`MNd`URd`07G]AN/ejbH]5Rdf;B
H]<00f;B00ERdf:bG[9R/f;C00ANd`04G]9N/UjbG]83H]83G]87G[82G[43G[85G[400ejbG[5N/@05
G[400ej`G[5N/@03G[400eZbF[5N/@06G[43G[03G[4015j`G[5N/Eja0ej`0UjA0UZA0eja00AN/5ja
G[5NT@9JT09N/09NT09N/0ENT0AN[`04G[5NT5j@GY03G[001UZ@G[1N/5j`GY1N/0ANS`08GXiNSej?
GY1NSeZ>GXmJT0=NT0AN[`04G[1NT5j@GY02GXl3G[000ejAG[1NT002GY05FY04GXl2GXh01eZ>FXmJ
SeZ?FXiJSej?009NT09JT09NS`IJT003FXmJSUZ>00UJSP03FXmJSUZ>009JSP03FViJKeY^00EJKPMF
KP03EVmFKUI^00IFKP05EVeFKUY/EVeFC006ETd2ET`2ETh7ETd2ET`00e9<DRaBC002DTd00eI<DTaB
C003DT`0159;DRa>;58/0U8[00=>;58[CR`00U8[158Z0U8[2Th/00=>:dX;BP/00TX;1Dh[1TX;00=6
2dX;BPX014X:00=:2dX:BPX014X:00=:2DH9APT00dH:2TGY00=5j4GYANT014GZ0TGY0TG900=5jDGX
ALP00TG92T79147800U1ad78@LQ1b3fX?JLmQCUT>HH00SfW00<mZ46X@JP00SfX00=1Z3fW@JL00Cf9
00001CFb@Q563TX>CRd014X^00=>;TX^BRh014X^44h^1Th]1E8]00UF;5H;DNYEjE7YDLQAae76DLL0
1EG700IEaU75BJEAYE6VDJL3DJH02DfVCJMAYU6VDLEAYTfWBHI=YP03DLL3CJP014fWCJI9YdV70TF6
0TF500Q5ID5V@FI1QT69@JY5bdh;0Th/00AB;59<DTiFCP9BCP06ETiBCE9=DTeBCU9?0U9@00=BCe9>
DTl01E9?00AFCeI>ETiFC@9FCPIFC`0<DU1B<58_DRa>34gZ@HI5bDGZAP]1jd7:0SfZ00PmZCf9>HPe
Ac57<BLeAcUW0SUX00<iR3f8?HT00T6Y00Q1R3f8?HPmR469?HTiIcE70SEW00@eISEW>FLmQ`8iI`0:
>FPeAS4U=DLa9C4V=DPaB3E7=DP2<BH01cDV=@De9CTU?DHmIcDU008]1003<@Da1345008e9@0;=DDe
9S45;@D]1SDV?HPmRCf8=DLa9P02;@H01C45<BDa1Bd4;>@00Rd500D]9Bd6:@DTi2C400@Xi004;>@a
1C45;>@3:<D4:>H04bcV;>DXa2cU;@Ha9c4V<BLe9SE7<BL]9c4W<DPiJCf:>FXeBCf:0091b`DmZ`03
ALa5cDG=0095cP0;ANi9kDg]DNeF3EX^ERiF3U7^EPiJ;`03FRh00eY@GU5JD002GW003UY_FTmFCeY`
GW5NTEjBGY=R/ejbFY5JL5j@GY42FVl015jAFY9JLEIA0UI@00EJL5jaGXmJKeY`00=NT004FVmJLEYa
EW42FY802EjbGY9JLEI@EU5FLEY`EY1JS`04FY0015ZAFW1JL5I_0UZA00EJTUjbG[9N/Ujc009Nd`06
H]=NdekCG]=RdekC2F;C00ENe5jcG[9RdF;C009R/P04H]5RdV;AH[82G[82H[8015jbG[=NdUkB0ejb
00ENdV;BH]9RdV;C009NdP=RdP9N/@=N/P04G[5N/UjbG[85G[400ejbG[5N/@05G[42G[0AG[43G[04
G[42G[02G[43FY4015j`G[5N/5jA0ej@0ej`0Uj@00=N/5jaG[000ej`00=NT5j_GZh00Uj_0Uj`0ej@
00=NSej`G[000ej`0Uj_0Uj?0ej>0ej?00ANSUj?GXmN/0=NT0EN[`0;GY1JSej@GXmN[Uj_GXmJT5ZA
G[1N[`02GY07FY000eZ?GXmN[`02GZl00ej>FXiJSP02FXh00ej>GXmNS`02FY0015j?GXiNSeZ>15Z@
00=JSeZ>FXh015Z>0UZ=00ANSEZ=FXeJS@=JSP9JS@06FViJKEY^FViJKeY^0UY]0eI^0eY^2EI^00MF
C5I]FV]JJeY/EVeFKP04ETd01UI<ETeFCUI>ETeFC09FC@IFC0ABC@04DTaFC5I<DTd2DT`5DR`00e8[
CRaB:`03DR/5DRX2DR/:CR`2BP/3CR/3CPX01TX;BRY:2dX;CR]::P962`03BP]:2TX:00=:2P06BP]:
2TX:BPU62DX:0TX900Q62DX9BPY62TGZANU9jDGX0TGY00=5j4GYANT01DGY00a5bTGZALY5bDG8ALM5
b4G9ALQ5j4G8@LP5@LT00d78@LU1b@02@LT3@LP00d77@LQ1a`02@LL02478?JPmZ3f6>FDmQCfW@JH4
@JP013fX@JPmYd6W0CfZ00001SFa@Q563TX=CPi>;P9:;P=>;P9:;P=:;`9:;Q1>;P=>;@9B;@=B;P04
DReB3E8;DPX2DNT00e78DLMAa`07DLL2DLH0256VDJMAYe6WDJI=YdfVCJL2DJH00eG6DJIAY`03CLL0
0e77CLM=Z002DLP014g8BJM9YdV70dF600=5QDEV@FH00T5W00PmJ3eYALY>2e8]CRaB;59=1E9>00=B
CE9>DTh00U9?0e9@1E9?0U9@00ABCe9>DTiBCPIFC`0=DTmFCe9?DU1BCe9>EVeF:TW9ANTmZSEW<@D0
0Rd500@a9S57=DHaA`@]9P<a9P06<BLeAc4W;@Da1CDV0SE700<iB3E7<BL00S4W00daAS57<BHa9S56
<BD]12d5<BHa9c4U;BH]1@02<BL00c4X<BLa9`02;@H2;@D022SS:<</hbS3:<8/hc45<BD2;@D00bcT
:></h`02;>@3:>D4:>@022SU:@D]1RSU:>@]1S4V;@H2:>@00bSU:@H]9`02;BP03c4W<BHe9cU8=BLe
1SU8@FU1RSU8=BPiJCf;@Ja5c@04AL`01TG=ANe9kDG]ANa5k@=>3P=B3P0EDRiB;eH_EW1JL5IaDTmB
;eI`EW9JLUYaFU5JLUjBGW5JL5iaHY5R/UjA009NTP09FY=NTUibFU1NDEYaGY9NTeYb00=JL@06G[9N
TUZAFW5NLEjB0UjC0Ujc00QN/UjAGY5JKeY`FW5JTUjC0ejc00YR/V:cH[9N/UjBGY5NL6:AH[5Rd`AR
e09Rd`03G]=N/ejc009N/P04F[9J/EZAGY42G[42G[82GY401EjbG[5N/UjbG[<00f;C00=Re5kCG]@0
0UkD00=Re5kCH]<016;C00QNdejcG]=RdekCG[=N/V:b0ekC00=N/UjcG[800ejb0V:b00=N/UjcG]80
15jb00ENdV;BH]9RdV;C00ANdP03H]9N/Ujb00EN/PMN/@03G[9N/Eja01YN/@04G[1N/EjaG[82G[40
0ej`G[5N/@02FY400ejAG[1N/@03G[4015jAGY1N/5ja0ej`15ja1Ej`0Uj_00AN/5j@GY1NS`9NT0MN
/09NS`=NSP07GZmNSej?GXiNSej_G[001Ej_0ej`0eZ@00IJSej>GXmN[ej`FY45G[000eZ@FY5JT@02
FY400ej`GZmN[`02GXh01EZ>FXmJSej?GXh00ej_1Ej?0UZ>15Z@00=JSeZ>FXl015Z?0UY^00=JSEZ?
FXh015Z?00=JSUY^FVh00eY^00IFKeY^FVmJKUI_EVh4FVh4EVl3EW02EVl01EI]EViJK5Y/FVd00UI^
1UI=0UI>15I=0UI<00AFCEI<ETaFC09BC003DTeBC59=009BCP03DTeBC59<00AB;003DTa>;4h/00A>
;0=B:`9B:P9B:`]>;09:2`9>:`03CPY:2dX;00E:2`04BPY:2dX:BP/5BPX00dH;APY:2P02BPX00dH:
APU:2@02APT00dGYANY5jP03BNT:ANT01DGZANU5bTG9ANT01TG800A1b4G8ALQ5b@I1b@Q1b004@LM1
b478?JP2?JL00cf7?JM1Y`03@JP01D78?LTmZ3fW@JL00CfZ00001CFa@Q1>;DX=CPh00Th^00A:;Th^
CRe>;P9:;P03BRm:;TX_00A>;`A>;PM>;@03CRi>;Dh]00EB;@AB;P06DPeB2e8:ENUAjE782E7700=A
aU6VDJH0156W00I=YU6VCLMAYUFVEJD2DJH00dfVDLI=a`05DLL01E78CJQ9Z4V7AHL00dF60TEV0T5W
0SeX00I1ZDX:CRa>;59<ET`2DTd0159>DTeBCU9=0U9>159?00ABD5I?ETmFC`9BC`03DU1FCeI@00iF
C`07ETiBC5I:CPY5jSE7:>@00RBR00@X`RSS;@@a9@8a9P06<BLeASE7<BH]1Rd50RSU00<Xi2SU;@H0
0S4V00HeASE7<@H/iRd6<BL2<BH01Bd6;>Da9S4V;@D00RSU1Bd50Rd600@XiBS5:<D/i@8]1@<Xi0</
i007<@D]1RcU:>DXi2cU<BD00SE700Pa1bd7;@La9cE9<BPa9cE80SUY00LeJCUZ?HY1[47<@L]1Z`02
@L`2?J`02d7<ALa5k4G]BNe=kE7]FPiN;UX^FRd01EY>00INKUi_FTiJCeYAFW42GY4015Y?ETmFCeI`
0eY`15Ya0eYb00MNTUjCFW9JLUYcGW=NT`05GY83GY43GY800ejcH[=R/`02H[<4H[@3H[<00f:bH[=R
/`02H]@01V;EI_EVmFKeH_ERe0AVm0AVe003I]EVmF/E00AVm@04I_A[5FlfKcH2KcL01F/FJaE[=F/f
JaD00VKd00=Re6;CG[800Ujb00AN/EjbH]=Nd`9N/P9N/@03H]1NdF;B00ARdP9Rd`03G]=Re6;D009R
d`9RdPIRd`03H]9N/Ujc00IN/P=N/`9N/P9R/P9N/P04G[5N/UjbG[82H[801F;AH]9RdV;BH[800f;C
00ERdUjbG[5N/Uja009RdP05G[5NdF;AH]5Nd@02G[4025kAG]9N/EZaG[5N/UjaG[89G[400ejbG[5N
/@0AG[44G[06G[42G[000ejaG[1N/003G[05G[44G[000ej_G[1N[`03GY04G[03G[400ej`GZmN[`02
GZl2GZh2GXh00ej^GZmN[`03GZl2GZh00ej_G[1N/002GY001EZ@FVmJKUj>GZh00Uj_00=N/5j@GY00
1Uj@0UZA00=N/5j_GXh00ej>0UZ>00=JSeZ>GXh00Uj>0Uj_00=N[Uj?GXh00Uj>0Uj@0UZ@00=NSej>
GXl00ej@00EJSej?FXiJSEZ>00EJS`06FVmJKUY^FViJKEY/0UY^00AJKeY^EVmFKPAJKP03EVmJKeI`
009JL005EW5FL5I_EVmJK004ETd4EVh:ETd01UI<ET]FC5I<ETeFC0=BC005DTeBCU9>DTiBC@02DT`4
DR`2DT`2DR`00dh/DR]>;002CR/2DR/00e8ZDR]B:`0;CR`01Dh[BP]:2dh[CPX00TX;00=:34H<AP/0
0TH;0TX:0dh:1dX:14H:1DGY00A62DWYANU9j@m5j@04ALQ5adGXANT7ALP00d79ALU1b@02@LT00d78
@LU1b002@LP00d79@LQ1b003@LL8@LP01T6X@LPmbCfX@JQ1Y`4mZP0000@e/D7`CRe:;@9:;P05CRi:
;Th^CRe>;P02BRh00dX_BRi>;`05CRl3CRh00dh]DReB;@02DRd01E8^CRe>;Th]DRh01E8]158^00EB
;E8;DPYEjE7Y009Ab0UAa`AAY`9AQ`06DJMAYU77DLIEYUW6156V00AAaeGWDLMAa`9Ab006CLQ=Z4VX
BJQ9QdF70TF60TEV0TF700Q1R3f8AJU9je9=DRaBC5I<0U9=0e9>00=BCE9>ETh00U9>0U9?25I?00=F
D5I?ETl00eI?00=BCeI?ETl01eI?00iFCE9;CRa:2d7:<@DTPBAQ988/i345<@@a9SDV0S4V00LeAS4V
<BLa9Rd6;BHa9P02<BL00c4V;@Da1@02=DL2<BH01C46;@D/iBd5;BH00S450bd50Rd600X]9Rd6;@Ha
9S47<@Ha1cDX=DTiB@8iJ@03>HTiJCUY008mR@03@HY1ZT6Z00=1Z`08AJ]5bdG<ALe9kDW_ANi63`9>
3P09CNe>3EH^ETmJDEYaFW1JCeY=009F;P05FU1JLUYbFW5JD003FTl015Y@FU5JDEib0UjB0eYa0UjA
00UJKeY@FW1JLUjCG[=NTUZAGY800eZB0ejb0Ujc0V:c0V:d00IN]6:cG[=NTV:cH[@4H]@4I]@00fKC
H]=Re002I]D2I_D00fKfJ_I[5P05JaL2JcL4JaH01VlhLgUcFFlhJcM_F09cN@04KeM_=flgKeP2LeP0
0fmHKcQ_E`02LeP00g=ILeQcF003LeP2KeL02FlgKcQ_=flfLeQ_Ef/fJaEVm@02H]@2H]<02V;BH]=R
df;CH[=N/V:bH]9RdF;B0V;C00=RdV;CH]<00f;C0V;D2V;C00ARdV;CG]=Nd`9R/`03H]=R/ejb00=N
/`9N/P=R/P03G[9N/Ejb009N/P9R/P03H[5RdF;A009RdP=Rd`04G]9R/V:bG]84H]84H]4015kAG[5N
dEkB0UkC0ekB0ejb1eja0ejb4Uja0ej`2Uja0ejA35ja00AN[ej@GY1N/09N/@03G[1N/Eja00=N/@9N
/0EN[`03G[1N[ej`00EN[`04GZiN[ej`GZl2G[0015jAFY1NKej>0Uj_00=N/5j_GY001Uj@00ENTEZA
FY5NTEj_009NSP03FXiNSUZ>009NS`=NSP=N[`03GZiN[ej>009NSP9NS`=JT0ENS`=JS`03FXiJSeZ?
009JS`03FY1JSei_00AJKP08FVeJKUY^FViFKUI_EViJKP9JK`03FViJKeY^00AJK`03EW1JL5Y_009J
K@03FViFKUI^00EFKP03ETeFKUI=009FKPEFC@=FC004ETeFC5I<ET`2ETd3DTh01E9=DTaBC59<DR`0
1E9<0U8/0dh/0dh[0U8[1dh/00=B:dh/CR`014h/00=:34X;CPX00TX;0Th[00I>;4h[CR]:2TX;BPX3
CPX6BPX4APX014H9BPY:2TX:0TH:00A62DH:BNU9j@Q5j@03ANQ5jDGY00=5j@04ANQ5b4GXALT5ALP2
@LP5@LT2@LP5@LT6@LP2@LT00d78?LTmb@06?JP1?JL1?JX00006=I11kTh/BRe:3TX^1Dh^14X^00=:
;dh_CRl00dh_0dh^0Th]158]00A>;Dh^CRe>;@EB;@AB;P05DRaB2e8:ENUAj@02DLP9DLL02Dg7DJMA
Ye6VDHIAQe6WDJI=a`03EJD4DJH4CLL3CJL0156WCJM9YdV70TF700=5QD5TAFD00TF700E1R469ALU6
2e9=009B;003DTaBCE9=00EBC@03ETeFCU9>009BC`03ETmFCUI?00IFC`03ETiFCeI?009FC`04DTmF
CUI>ETh4ETl00eI_DTmBCP02EVd02eI/CRe1bS4W:<@XXbBR:<<a134V=BH00S450Rd500La9SE7=DPe
Ac4W<BHe9`02=BH2>DH013E6>DPmJCU80cE800<iJCV9?HX00SfZ0T6Z00<mZSf[?HX00T6[00]1c4G<
ALe5cDG]BNi>3U8>BPe>3E8>00=B3@03ERiJCUI>009F;P0;FTeJKUi_GVmNL5Y@EU1FDEYaGW5NL003
FW001EYaEU5NTEjbGW000UY`15Ya00ANTUiaGW5NL@=NLP07GW=NTejBGY9NLUjBH[400V:b00ANTUjC
H[=R/`9Rd`9Re006G]ARe6;DH_ARe6Kd0fKe00AVmVKeI_IVmPAVm@03J_I[5V/F00=[5P05KcI[5Vlf
KcM_5P03JaL2KcP00fmHLeUcF002MgT2LeT00fmHKcQ_>003LeP016mGLeQcNG=H0fmH0g=h00EcF6mH
KcM_Eflg009[5P05KcM_F7=HLeQ_F003KcL00fmGLeM_=`03JaH016/EKcI_=V/F0fKe00ERm6;CH]=V
df;c00IRd`05H]9Rdf;CH]=RdP03H]<016;BH]=Re6;D0V;C0f;B1F;C00ARdUkBG]9Rd`ARdP04H[9R
/f:cG[84H[800f:aG[5N/@03G[4016;AH[5RdF;A1F;B00ARdekBH[9Rd@ARdPERd@9Nd@9N/@04H]9N
dUkBG]84G[400ej`G[5N/@06G[400ejbG[5N/@04G[400ej`G[5N/@07G[42G[0<G[4015jAGY1NT5jA
0Uja00=N/5jaG[401eja15j`0Uja0Uj`0Uja0Uj`00=N[ej`GZl015j_00=N/5j_G[002Ej_00ANT5j`
G[1NT0=NSP04GZiN[ej_GZl2G[05GY001eZAGY5NTEj@GXmNSUZ>00ANSPQN[`ENSP03GZmN/5Z@009N
S`07GXiNSej?FXmNT5j?GXh00eZ?0UZ@00=JSei_FVh00eY^00=JKEY^FVd01UY^0UY_00AJKUY]FViJ
KPEJK`=JK@YFKP03ETeFC5I=00=FC@05ETaFBeI;ET]FC003ETd00e9=DTaBC@05DTd3DT`00e9;DTaB
C@02DT`0158/CRa>;4h/0dh[0U8[3Th/00=:34X;CPX00TX:00M:2dhZCR]:34X;BRY:2`02BPX00dh:
BPY:2P07BPX2APT00dX9APU:2@04APX01TH9BNU9jDWXANU9j@E5j@07BNQ5j4G8ALQ5j4WYANP024G8
00A5bD78@LU1b@95b@04@LQ1ad77@LP4@LT5@LP01477@LQ1b4780Sg900A1b3fX@JLmY`91Z051Y`4m
ZP0000@eT47>CRe:;P9:;`9:;P07CRi:;dX^BRm:;TX_BRh00TX_00A>;dX_CRm>;`=>;P9>;@05DReB
;U8^DRi>;@04CRh3DRh00e8]DRiB;P02DRh00e8/DP]B2`02DNT2DLP7DLL2DLP01Tg8CLM=Z56WDHEE
Y@9AYP03DLMAYUFU009AYP03DJM=adg7009=a`0?CLQAadfWCJQ=YdVWBJQ9YdV7AHM5QTF5AFE1ITF7
0091R007@HU1ZDH<CTe>;E8/DTd00U9>00=BCE9>DTh00e9>00ABCe9>DTmBC`IFC`04EU1FCeI?ETh4
ETl3DTl4ETl3DTl02E9_ETeFKUI^E[1BCd7^>HX/i@02:<D00c4V=DLiI`02?HT00cV9?HTmRP02?JX0
146Z?J]1Zd6[0dFZ0dG;0dG<0115kDX>BPi:3Th_DRm>;e8_ERiB;U8>CPiB;UI>ETmFCP9F;`03DPiF
<5YA009NL@08ETmF;eY?ETmB;U9?EVmBD09FD09FL004FW1JD5Y@FW42FW82FW42GY8015ZAGW5NTUjC
0Ujc00=N/V:cH[<00ejc0V;D0V:c00QRdf;DH[AR]6JdI]EVe6KE0VKD00=ZmF/FJaD00f[e0f/E1F/g
00a[=V/gKcM[=f/FJaM_>6mILeU_FG=iKeT2KcP01VlgKcQ_=f/gKeQcF@9cF0=_=`A_>003KeQcFFmI
00=cF007KcQ[=f/GKcM_>6lgKcP00V/g00I_=f/gJcI[=VlgJcL3JcH5JcL016/FJcM_=f/g0f/f0f/g
00=[=V/gJcL00f/F00A[5F/FJaEVm@=Vm0=Rm1eRd`ANd`QRd`03H[=R/V:b009R/PIN/P9R/P9RdP03
H]5RdV;B009RdP03H]=NdV;C00IRdP=Rd@03H]9N/Eja00AN/@03G]9N/Uja00aN/@03G[9N/Eja00mN
/@03G[1N/Eja00]N/@04GY5NT5j@GY0@G[400ejAG[1N/@02G[42G[02G[48G[03GZl6G[000ejaG[1N
[`02GXl01Ej>GZiN[Uj`GZl00Uj`00EN/Ej`GY5NT5jA009N/@=NT004G[1NSej?GXh2FZl3GZl01ej?
GZmN[ej_GZiNSej>00=NS`05GZiN/5j`G[1NT004GXl00eZ?GXmJS`03FXl3FY000ej@FXmJK`03FVl2
FVh015Z>FY1JSeY_0eY^0UY_00=JKUY]FVh015Y_0eY^0eI^0eI>00=FCEI^EVh015I^00=FC5I=ET`0
0eI<0UI[00=FBeI<ET`00eI=2E9=159<00EBCE9<DTa>;4h]009>;09>:`9B:a1>;005CR]:2dX;BP]>
:`03BP`7BP/01TH;BP]:2dX;BPY:2`E:2PA62P07APU5jDGYANU9jDGYBNT01TGY0TWY00A5jDWXANU5
b@M5b003ANQ5jD7Y0091b@95b@04@LU1b478@LP4@LT6@LP00d79@LQ1b002?LT2@LP01D6W?JLmZ3fW
@JL00CfZ000013F@@Li>;DX>0Th^0dX^00M:;dh_CRi>;TX_BRi:;`05CRl3CRh2CRd00e8]DRiB;`02
DRh2CRh03dh_DRmB;U8_DRiB;E8^ERiB;UH^ERaF2eG[ENUAj@02DLP2DLL00eG7DLMEa`02DLL2DLP0
1dg8DLM=Z4fWDJIEYE6V009AaP9AYP=AY`05CJQ=Ydg7DLM=a`02CJL00dV7AFE5I@03AFH2AHH02TF5
AFE1ICe6?DLmJ46X@LU:2dh]0U8]0U9>0eI?0e9?3EI?00=FCUI=ETh01eI?1U9?00eBKeI=DTiBCe9>
FXmFL4G^?H/a:CUZ?H]1b`05AN`2BPd01dH=BPe:3Dh=BNe>34h=009B3@=F;@0BDPeB;EI?ETmB3E8^
ETmFCU9?DRiFCeY_ETmFCUY_FViJCUH^0UH_00=F<5I@EU400UYA00EJD5YaFW1JD5I@00AJL@=JTP9N
T`=N/`03G[AN/ejc009N/P04H[=R]6;DH]@2I_D016KdI]AVe6KD0VKE00=VmV/FJaD016[e00][5F/F
KaI_=VlgKcI[5VlgLeQ_Ef/f00E_=P03KcM[5V/F00A[5P05JaEZmF[fJaI_=`02LeP01VlgJcM[=flg
KeQ[=P=[5P9[=`=[5P03KcM_=V/F00=[5P06JcM[=V/FJcM_=f/f2V/F00=[=V/EJaD01V/E0V/F00=Z
mV/FJaH00V/F16/E00AW5FLDI_AVm0=Vm@03J_EVmFKd00=Vm09Vl`03I]=Vm6Kd00=Re09Rd`9VdP03
H]9Rdf;C00MRd`03H[=Rdf;B009RdPERd`=RdP06H]=NdejbG]=Rdf;B1f;C00]R/V:cH[=N/V:cG]=R
/ejbH[9NdV:b009RdaERdP=Rd@03H]9RdEja00IN/@03H]5N/Eja01EN/@9N/0aN/@07G[1N/Ej@GY1N
TEjaH[003Uja00ANTEj`G[1N/09N/@04G[1N/EjaG[49G[000ej_G[1N/@05G[02GZl3GZh3GZl00ej@
G[1N/006G[001ejaG[1N/5j`FXmNT5j?00IN[`9NS`03GZiN[ej^00=NS`06G[1N[ej_G[1N[ej`0Uj@
00IN[ej?GXmNSej^GZl2GXl00ej_GXmNS`02GZl00eZ@GY1JL002FW000eZ@FY5JS`03FXl025Y_FViJ
KeY_FXmJSUZ=FXh2FVh00eY]FViJK@04FVh00eI^ETiB;@02ETd00eY]EViJK@02ETd00eI^EVeFK@05
EV`4EV/015I]EViFCEI=259=1E9<00=BCE9<DT`00U8/00ABC59;CTaBB`9B:`e>;006CR]>;4h;CP]>
2Th;0TX;0TX<00=:2dh;BP/00TX;0dX<14X;00=>2TX:BPX014X:00=62TH9APX014H900=:2DWYANP0
0TGX0dGY00A9jDGYANU5j@95j0A5b005ANU5bDG9ALQ5j002@NT3@LT01TG9@LU1b4G8ALM1b0=1b@=1
b003@LM1b47800M1b003@LLmQcfX008mY`4mZP0000TaT47?APe:3TX^CPi:3TX_BRh00TX_0dh_0Th^
0dh_0dh`0Th_0Th]00=B;E8^DRh00U8^0Th^0Th_00A><58_DRmB;P9F;P07ERmF;UH/EP]EjUGYDNT0
15780eG70U7700EAb4g8CLQAb579009Ab003ELIAYe6V00=AYP06DJM=Z4fXCJQ=YdW80Tg700==YdV7
AHL00TEV0TV700m9YdV7AHM5QT5V@FDm93TV>DI1R479BP]>;58]DTh00UI?0eI>45I?00AFCUI=ETiF
CPEFC`MBC`03DVmBCU9>009BCP08ETiFL59>BPi5kDG=ANi>;`9FKP0=DTeB;U8]CPeB3E8]DTiB;U8]
ETiB;U8]ETh015I?0UI@15I`00MFD5I?FW1JLEIAEU1FL@02FW400eY`GY5NT@02GW401EjBGY=N]5jc
GY<00ejB15jc011N]6:dG[AR]F;EI_IVmF;DI_EW5VLGIaIRe6KDI_E[5PE[5`=[5P9VmP0<JaI[5flg
JaM[5V/EJaI_5flgKcQ_F6lg0VmG00E_F6lhJcM[=V/F00E[5@05JcI_=V/FJaEZm@04I_D01F[eJ_I[
5V/FJ_D00f[f0V/F00=[5F/FJaH016/F00=[5F[eJaH01V/F0V/E26/F00I[5FKfI_IZmF/EJaH2IaD5
Ja@4J_D01V/FJaE[5F[eI_EVm0=W5@=Vm0EVm@AVm09Vl`04I]=Ve6;DH]D2H]@2H]<01FKBI]=Vdf;D
G[<00V;C00MRe6KCI]=Rdf;DI]ARe002H]<00f;BH]=Rd`04H]<2H]83H]<00f;DH]=RdP07H]<00ekB
G]=N/P03G]8026:cH]9R/EkBH[9Rdf:cH]<DH]82H[82H]82H[400ejaG]9N/@0<G[400f:aG[5N/00;
G[401EjbG[5N/UjaG[803Uja00=N/V:aH[400V:a3eja00=N/5jaG[400eja00=N/5jaG[400Uj`0eja
00=N/5jaG[000eja0ej`00=N/F:aG[400ej_00=N/6:`G[400ej`00=N/Ej`G[400ej`15ja00=NSej@
G[000Uj`0ej_00IN/5j_GXmNSej_GZh2GXl4GZl5G[001Ej@G[1NSej?GXh00Uj_00=N/5j?GXl00ej_
00YJ/5Z@GY1NT5Z@FXmJT5Z?FVmJSP9JK`=JS`04FVmJSUZ=FXh2FVh00eY]FViJKP04FVh025Y_FW1F
KeI>ETeJKEI^FVd2ETd2EVh00eI]EVaFK002EV`3EV/2EV`00e9]DViBKP02DTh8DTd5DT`0159=DRa>
;58/0U9<00A>C59;DR]B:`=>;09>:`I>;004CR]>;4h[CR/2CPX2CRX02Dh[BRa:34X<AP]>2dhZBR]:
2`07BP`2BP/6BPX8APX5ANT00dGZANU5j@02ANT00dGXBNU9j@04ANT01DGZANU5jDGX@NT01T7900A5
b478ALQ5b0A1b@91b003@LM1b47800I1b004@LU1b478?LT2?JP1?JX00003<I11kdX]009:;P06BPi>
;TX^BRi:;dX`0dh_0dh^0dh_0Th`0Th^0U8^158]00=B;Th^CRh00dh_0U8_0U8^00MB;E8^DRiF;5H;
ENYEj002ELL00e78DLMAb002DLL01EG7DLMAae78DLL01E7800=Eae6VDJH0156V0TfW00=9YdfWCLL0
0U7700==adfXCJP00TfW00A9YdfWBJM9Y`95QP0:@FHmACTT<>@e9CeW@LU62dh<DRd2ETh01UI?ETiB
CUI>ETmFCPMFC`=FCPAFC`06ETiFCEI=ETeFCUI?159>1E9?0U9_0U9>00AFCE9>ETiBCP9JKP08DRa>
3DX>CPeBCEI^FViFCP9B;@03DTiFCeI_009FC`9JC`03ETmJKeI`00=JL008FY5JL5YaFW5JTEjAGY9N
T@9NTP04FY=NTUjBGY83G[8016:cH]ARe6:d0f;E00UVeFKeI_EZmFKEH[ARe6;EH_D00VKf0V;E00QV
mVLFJaIW5FKeIaI[5VKf0fKe00EW5V/FIaI[5VKf00=Vm@=VmP07JaIZmVKeI_EZmF/EJ_D00fKe00IZ
mF/EJaEVmVLFI_H2I_D4I_@016/DIaAZm6Kd16Ke1FKd0VKe0VKE00=Ve6KdI_@00VKd00=Rm6KeI_D0
2fKe00EVm6KDI_AZmF/E00AZm@MVm@=Vm003I_=Vm6Kd00AVm003J_AVmFKe00=Vm@9Vm005I_EVm6Kd
I_AVl`02I_@016KeI_AVe6Kd16Kc0VKC00QVe6;DH]ARe6;CI]=VlfKB0VKC0V;D0V;C0VKC00ARdfKC
I]=VdPmRdP9Rd`03H]9Rdf;C00ERd`9NdP9RdP0:G]5RdV:bG[5R/EjaH]5Rdf:cH]<2H]400fKBH]9R
dP09H]84H]400ekAH]9R/P02H]84H]400ekBG[5N/@0:G[42H[400ejaG[1N/@02G[000ekAG[5N/@0J
G[43H[400ejaH[5N/@0:G[401F:`G[1N/5jaG[000Uja0ej`00=N[ej`G[401Eja00=N/5jaG[001Eja
00QN/5jaG[1N/6:`H[5R/6:a1eja00=N/5j_G[0025j`0ej_00=N/5j_GXl00Uj?00AN[Uj>GXiNSP9N
[P=N[`=N/09NT09NS`9NSP05GZiN[ej>GXiN[P03GZl4GY001Ej_FY1JSeI<FVd015Z?0UY_00=JSUZ=
FXd00eZ=0UY]00=JKUY]FVh01UY^00=JKEI^FVd00UI=0UI^00=FKEI/EV`01eI/00AFKEI<DViBKPAB
CPEBC@IBC0=BC@9BC004CTaBBe8[DR/2CR`4CR/00dh/CR]>;002CR`014h[CRa>:dhZ0e8Z00=>:Th[
CR/00Th[00=>2dh:CPX00Th:0TX;00M:34X;BP]:2dX<BP]62`02BPX4BPT00dH:ANY5jP05APX00dX:
BNY5jP03ANX2ANT01DGXANU5j4GXBNT01dGY00=5j4GYANT00d790TG90T780TG80d7900=5bD78@LL0
0T7700=1Yd78@LP01T780cfX0D6X0CfZ0000136A@NmBCTh]0dh^0TX^0dX_0Th_00=>;Th_CRh01Th_
00E><4h_CRm>;e8_00=B;P9>;P=>;`AB;`09DRiB;e8_EReF2eG[ENQEaeG800=Ab09Eb005ELMAae77
DLQEb004DLP00eG8ELMAY`05DJH2DJL5DLL3DLP015GXELQAb4fX0TVW0TF700]1IceV=B@a13D4?HM1
bTX<CPeB;E9>009FC`9BC`9FC`03ETiFCeI?00=FC`03DTiFCeI?00=BC`=FC`05ETiFCE9=ETeFCP05
DTh9DTl01E9>DTmBCUI?ETh00UI?00=BCeI?EU000UI`00=JKeY`FW000UI`0UZA00IJTUZAGY5NTEZA
GY43G[800ejcG[9N/P02G[801EjcH]=RdejbH]@00V;e00=Re5jcH[<00V:c0f;D0V:d00=Re6;EH]@0
16;D00EVmFKfI_IVmVKe00=Re@9ReP03H_IRmF;e00mVm@9VmP04H]EVe6KDI]@4I]D016KeI]ERe6KD
0VKe00MVmVKeI_EVm6;dI_AVm@02I_@00f;BH]=Vm@03I_D5I_@4I_D2I_H3I_D3I_@00f;DI]AVm@07
I_D01fKfJ_EVmFKeJ_E[5F/F009[5@03J_EVmFKe00UVm@EVm0QVm@9Vm0=Vm@04I_AVmFKdI_@3I_D0
0fKEH]=Vd`03I_<00fKdI_=Rd`02H]@2I_@2I_<016KCI]ARe6;d0f;D00IVe6KCH]=RdfKCI]82H]85
H]<8H]82H]<00f;BH]=Rd`03H]<016;BH]=RdekC0UkB00QRdF;BG]9NdV;BG]9R/Ujc0V:c00=VdV;B
H]802V;B00ANdV:bG[9R/@=RdP03G]9Rdf;B00=RdP03G[5NdUja00UN/@AR/@9N/@9RdP03G]5N/Eja
00IN/@=N/Q=N/@03H[5N/Eja00iN/@03G[1N/Ej`00AN/1EN/@04G[1N/F:aH[48G[4:G[03GZl3G[02
FY02GXl00ej>GZiN[P04GZl3G[04GZl01Uj>GZmN[ej_GXiN[PAN[`04GXmJSeZ?GZl2GXl6FXl4FVl4
FXh5FVh00eI^EVmJK`04FVh7EVh00eI]EVaFK@07EVd2EVh3DVh8DTh2DTd4DT`4DTd4CT`4CR`3CR/7
CR`7CR/01Dh;CR]>:dh[CP/00Th:00E>2dX;BP]:34h;009:2`04BPa:2dH;APX3BPX2BPT00dh9BPY:
2P02BPX2APX00dGZBPY:2P04ANX5ANT5ANX4ANT014GXANU5jD7Z0TG900=1b479ALP00TG80TG90d79
2D7800=1bD78@LP013fX0D6X0CfZ00000c6A@LmB;003CRd01dh^BRi:;TX_BRi>;Th_00E>;PE>;`05
CS1>;dh_CRmB;`05DRh2CRl00di@DRmB;`03DRd02U8^ERmB;EH/EP]Ej4g8CJUAbE780UG800=Ab577
DLP00UG800=EaeG8DLP00U6W00=Aae6WCJL00TfW00EAYdg7DLMAae76009Aa`03DLQAae7700AAa`05
DLI=adVXBJQ9Q`02AHL00d5W?FHi9@02=BD01d67@LY:34h]DReBCUI>00AFC`03ETiFCEI>00MFC`07
DTmFCeI?ETmBCeI?ETh00eI=00MFCUI?DTiBCUI>DTeBCP09DTl01UI?ETiFCUI>ETmFK`9FL005FW5J
TEjcH]9N/P02FY400ejAG[9NT@02FY42GY400ejBG[9N/`02H[<00ejcH[=R/`06G[8015kCH]=Rdf;C
0Ujc0V;D00=Rdf:cH[<00Ujc0f;C00ARe6;CH]ARd`ERe004H]=Re6:dG[@2G[D00ejdH]ARd`06H]<7
H]@01F;CH]ARdf;CH]@00V;C0V;D00AReF;DH]EVe0EVe@9Vm@EVm0EVm@9Ve0EVm09Vm@IVmP05I_AZ
lfKdI_ARe004I_D2I_H2J_D00fKeI_IZm@03JaD016/FJaE[5F[e0VKe0V[e4VKe00EVm6KeI_EVm6Kc
00=Vm@03I_AVmFKe00UVm@9Vm0=Vl`04H_=VlfKcI_<4I_@00f;dI_AVm002I]@4I]<00fKBH]=Vd`03
H]<016;BH]=RdV;B0fKB00=R/V;BH]800f;B0f;C0f;B0V;C00ANdf;DG]9Rd@9N/@9N/P08G[=R/f:c
H]=R/f;CH]9Vd@]RdP03H[9R/F;B00URdP04H]5N/F:aH[45H]4016;BH]5RdF;A16:a1eja00=N/5ja
G[401Eja00=R/EjaG[403Eja2F:a00AN/F:aH[5R/@UN/@04H[5N/5j`G[02G[43H[400ejaH[5Nd@04
G[42H[400ej`G[5N/@05G[400ej`G[5R/@08G[45G[09GZl5G[000ej@GXmN[P02GZh00ej_GZiN[`04
GZl3GZh:GZl2GZh4GXh2FXh<FXl4FVl015Y^FVeJKUZ>15Y_0UY^00AFKUY^FViJKP9JK@04FTaJK5I]
FVd:EVh3DVh2DTh3DTl00e9>DTeBC@04DT`4DTd00di<DTa>C00:CT`3CR`3CR/4CR`6CR/4CP/2BP/0
0dX<CP]:2`02BP/5BPX014H:BPU>2Dh90TX91DX:00A62TH;BPY9jPI5j@I5jPQ5j@04ALU1bDG9ALT3
ALP014G9@LU1bD790T6X00=1bD78@LP02D780d6X0D6W0CfZ00000c5`?Li>;002CRd>CRh4CRl01Dh`
CRm>;e8_DTl00U8^00=B;Dh]DRh00Th_00A>D58_DTmFCP9F;@06ERiF;e8^EReF:eGY0UG90UG800=A
b5G8ELP00UG70UW700IEae78ELQEYe6WDLL2CLL014fXBLQ=Z4g80dg700EAadg8DNQAb5G800=Ea`9A
a`04CLQ9Z4VXBHL2AHL02d67?FHe9CTU>DLmR46ZAPa>;U9=DTh00eI>00AFCeI>ETiFC@9FCPEFC`03
ETiBCeI?009FC`9BC`03ETiFCEI>009FCP9FC`03DTiFCU9=00MBCP=BC`08ETmFCUI>ETiFKeI`EW5J
TP9N/`=Re006G[9J/UjbFY5NTEZA15jB00=NTEjbG[800UkC0Ujb0Ujc00AN/UjAG[9N/PUN/`9N/P9N
/`03G[9N/ejb00YN/`03G[AR]5jd00AR]0MRd`9Re003G]ARe6;D009Re003H]=Re6;C00ARd`9Re003
H]EVe6KE009Ve@9Vm@=Ve@04I_EVm6KdI_<2I_@4I_D00fKEI]AVe002I_@7I_D4I_H01F[dJaAZm6Kd
I_D00V/E00=ZmFKfJ_D00V[f00=[5V/EJaH01F/F00=[=V/FJaH00f/F00=[5F[eJ_D01FKe00=VmVLF
IaH00fKe0V[e0fKe00EVm6KeI_EVmFKd00=Vm@03I_AVmFKd009Vm0=Vm@9VmP=Vm@9Vm007I_EW5FLF
IaEVm6KcH_@016Kd16KD1fKC0V;C00=Re6;CH]<00fKB0VKC00=R/F;AH]800f;B0V;C0V;B00=Rdf;B
H]<00ekC00=NdV;BH]800eja0Ujb00=Ndf:cH]<00V;B00=VdFKBH]802F;B0V:b00=RdV;CH]801f;B
00ARdF:aH]5RdP=R/@03H]9RdF;B00ARdP9N/@04H[5N/F:aH]44H[400ej`G[5N/@02G[4015kBG[5R
dF:a3Uja00MRdV;AH[9R/UjbH[5Rd@04H[400f;BH]5Rd@02G[800f:aG[5N/@02G[84G[4015kAG[5R
/F;A1F:a00=NdEjaH]4016:a00=Rd6:aG[400eja00=RdUjaG[401Uja00ER/EjaG[5N/Ej`00=N/@=N
/0MN[`9N/09N/@03G[1NTEj`00AN[`04GZiN[ej?GXl>GZl2GZh4GXh3FXh=FXl01UY_FW1JL5Y_FVeJ
KPEJK`03FW1JKeY^00AJKP03FTeJKEY/009FK@aFKP03DViBCE9>00ABCP9BC@ABC0ABC@9BC0Y>C0A>
;0=>:`E>;0I>:`=>2`03CR]>:Th[009>:`03CP]:2dX:00=:2P=>2P05CPU:2DX9BPU:2P04APX2AP/0
14X:BNY9jDX90dWY0TGY00=5jTWZANX00TGZ00A5jDWYBNU5jPA5j@=5jP06ANU5b4G9ANU1jD7:0dG:
00=5b479ALP00T7800=1bDG8ALP014781D6X0Cf[00000c5`@LiB;002CR`01Dh]CRi>;Th]CRh00dh]
1Dh^00=>;Dh^CRl00Th_00A><58_CRmB;P=B;@9B;004DReB;U8^DTl2DTh00eI>DReF;@02ERd01e8]
ERaF:eH9FNUEjEG8009Ej0MEa`06DLQEb577ELIAadg70TfX00A9b4fXCLQ=a`9Aa`04CLM=b57XDLP2
ELL3DLL01E78CLQ=adVXBJL00TF700Y1Qd5V>BDe9CU7?FQ1ZDG/CReBC@EFCPEFC@9FCP9FC`03ETiF
CEI>009FCP05ETmBCe9?ETiFC@03ETh2DTd00eI>DTeFC003DTd00e9>DRiBCP02DTh2DTl015I?ETiF
CUI?0UI_00EFL5ZAFY9N/EZb00UJT@9NT@03FY5NTEZA00IJT@9JL@9JL0YJT@ENT@06G[9N/ejcG[=N
/UjB1Ujb00=N/ejbG[<00Ujc0V:c00=R/V;CH]<01F;C00=N/ejdH[@02F;C00ER/f:dH]ARe6KD00=V
e@04I_AVmFKfI_H2I]D2I_@2I]<3I]@00fKdI]AVe002I]@3I_@3I_D00fKdI_EVm@02I_H2I_D016[d
Ja=[56/D1V/E00AZmV/FJ_E[5@Q[5P05JaE[5V/FJaIZm@02I_D016KdI_EVmFKf0VKe00=W5FKeI_D0
0VKe16[e0VKe00AZmF/EJ_EZm@=Vm@9Vm09Vl`03J_=Vm6Kd00EVm@9Vm004I_=Rdf;dH_D2H_@5I_<5
I_@3I]@01fKCI_=VlfKCH]=Re6;d009Rd`ARdP03H]=R/V;B00YRdP04G]9RdekCG]<3G]801f;BG]5R
d5jaH[5R/V:c009RdP03I]9VdF;A00URdP05H]=VdVKBI]=Rd`0:H]85H]42H]82H]44H]83G[400f:a
H]5R/@02H[4016:`G[1N/Ej`0eja00IRdV;AH]5R/F;AH]82G[4015kAG[5NT5j`0eja00MRdV;AH]9R
dV:bG[9R/P05H[42H]401f:aH]5NdUjbG[5R/F;B009N/PAN/@04G]5RdF;@H]43H[400f:`H]1Rd003
H]03H[401F;?H[1R/EkAH]400V:a0eja00=N/5jaG]400eja00=N/5jaG[4015ja00=N/5j?GZl00Uj_
0Uj`0ej_00AN/5j_G[1N/09N/@06G[1N[ej_GZmN/5j^0ej?00=NSUj_GZl02Ej_00=N[Uj>GXh00Uj>
0Uj^0Uj>0UZ>00=JSeZ>FXl02eZ?00=JL5Y_FVh00UY]1EY^00=JKeI_EVh00eY]0UY^00=JKEY/EVd0
0UI]00=JKEI]FVd00UI]0eI^00EFKEI^EViBKU9=009BCPEBC@]BC0Q>C003CRa>Bdh[00E>:`E>;0=>
2`=>:`04CRY>:dhZCR/3BRX00dh[CP]:2`04BPX024h:BPY>2Th9BPU:2TX9BPX4APX01TX;AP]:2TWY
CPQ:2@E9j@=5j@03ANQ5jDGZ0099j@M5j@03ALU5b4G80095j006ANU5bDG9ALU1bDG80TG90T7900A1
b4G8ALQ5b091b091Z004@LQ1ad6W@JP1?J/00003;G0mcTh/009>;004CRe>;Th^CRd3CRh00dh]CRi>
;P03CRh01E8^CRi>;Th`CRl00dh`00=B;U8]DRd00U8^00IB;E8^CRmB;U9?DTh3DRh01e8]EReF;EH]
ERaF:eH:00=Ej@9Aj004ELQAb5G8ELP2ELL01EG8DLQAb577ELL00U7700==adfXBLP00Tg800A=ae77
CLM=b09=b@03DLQEb5G800AAb004DNU=b4W9BJP2AHL02TF6@FHiACTV=BHiId6YANa:3E8]15I>00=B
CUI=ETd00eI=0UI>0UI?00=FCUI=ETh00eI?0e9?00=FCUI?DTh00U9>0U9?00=BCUI<DTh01E9>00=F
Ce9?DTl00U9?0eI?0eI_00EFL5JAFY5JTEY`009JT@05EW5JLEZAFW5JT@05FW07FY400eYaFW1FK`02
FW0:FY4015ZBGY9NTUjb0Ujc00=J/eZCFY<00UjC00=N/eZcG[<00Ujb00=N/ejbGY<00ejc00=R/f;C
H[<00V:c00ERdekDH]=Rdf;D009Re@03H]ARdf;C00MRd`03H[ARe6;D00=Ve003I]EVm6;f009VmP06
I]EVmFKeI]AVlfKD16Kd0VKD00AVmFKEI_EVm@9VmPAVm@9VmPAVm@04J_AZmF[eJaD4JaH01V/EJ_IZ
mV[fJaE[5PA[5`I[5P04JaEZmFKeI_H3I_D00fKfI_EW5@03I_D2I_H01F[eJaI[5V/FJaD00f[e0V/E
00=Zm6KeI_@00fKd00=Zlf[dI_@00fKd0fKe00=Vm6KeI_D00VKe0f;e0V;d0VKd00=Rm6;eH_D01F;e
00QRe6KdI_=VmFKdI_ERmF;E0V;D00IRdf;BH]5RdV;CH_@2H]<7H]84H]<2G]82G]<3G]82H]4016;@
H[5RdV;C0V;B00=VdFKBH]802V;B26;C0V;B0V;C0f;B0f;A0V;B0V:b00ANdV;BH]9RdP=N/@03H[5R
dV;A00=R/003G[1N/Eja009N/@9N/P9RdP9Rd@UN/@ERdP03H]=RdV:b009R/P9R/@05H]5RdV;BH]9N
/@02G[800f;BH]5RdP02G[83G[400f;BH]5Rd@03H]44H[4015kAH[5R/F;@0f;A00=Rd6;AH]400V;A
0V:a15ja0UkA1eja00EN/5jaG[5N/5j@00AN/09N[`IN/0=N/@07HZmN[ej`GY1N[ej`GZl00Uj?0ej`
0Uj_0Uj`1Uj_0Uj?0ej_00INSeZ>FXiJSUZ?GY0<FXl00eZ@FVmJS`03FVh025Y_FViJKUY^FVmFL5I_
FVd3EVh2FVh00eY]EVeFK@0<EVh00e9^DTiBCP02DTh4DTd5DT`01EI;DTaBC59<DTd00U9<1Ti<00=>
;4h]CR`00dh/0dh[1Dh/0dh;00=>:dh/CR`00Th[0dhZ00=>:dX;BP/01TX;0dh:1DX:0TH;0dH:00=5
jTH:BPX00TX90TWY00A5jDWYBPU62PA5j@03ANY9jDGY00M5j@05ANQ5b4G7ALQ5j002ANT01dG8ALU1
bDG9@LU5bD7900E1b0=1b@05ALU1b478@JLmZ001?J/00003;Dlm[Th/009>;003CPe>3Th^009>;P=>
;@E>;P=B;P05DRm><4haCS5><004DRh01E8]DRiB;Th_DRh00e9>0UI>15H]00=F;5HZFPT00eGY00AE
j57XENQAj@9Eb003ELMEb5G7009Ab09Ea`0;DLMAYU6WDJM=Z577CLMAaTfWDLM=b@02DLT02578ELQA
b5G7DLMAb4g8CJP2BJP03DV7AHM5IdEV@FDmASTU>DI1Qd6YAP]:3Dh/009FC@AFKPAFC@07ETiFCeI?
ETmFCUI]ETh00eI?00AFKeI?ETmFC`9BCP9BC`9BD003DTiFCE9>009BC`03ETiFCeI?009FC`03DTmF
CeI?00AFCP04EVmFCeI_DW02EW000eY_FW1JL003EW42EW0:FW02FY45FW0:FY42FY82GY82FY<2GY@3
GY<01EjBG[9N/UjbG[400Ujb0ejc0V:c0V;C00ARe6:dH]ANe0=Rd`=Re0QRd`06H[=R]6;DH]AVe6Kd
0VKD00=Vm6;eI_H00VKf0VKe00=Vm6KcI_<01FKd16Ke16Kf1FKe00EVm6LEJ_EZmF[d009Zm@03JaE[
5V/F00=[5P9[5@A[5PA[5`I[5P03JaEZmFKf009Vm@9Zm@=Zm0AVm@03J_E[5F/E00A[5@9[50=Zm0=W
509Vm005J_AVm6KdI_AVl`03I_@00fKcI_AVm@03I_D6H_D00f;dH_ERm@05H_D01fKeH]AVm6KdH]=R
m6;e009Re@05G]ARe6;BH]5RdP02H_<2H]<;H]800ekCG]9NdP02G]803F;BH]5R/F:`H/mR/6;AH]9R
lV;BH]5RdV;C00YRdP03H]=VdV;C00ARd`03H]9Rdf;B00ARd`MRdP03H]=RdV;B009RdPERd@=Rd09R
/004H[5N/5jaG[42G[801F;BH]5RdF;AG]4016:a0f;A0f;B00=RdF;BH]800f;B0V:b0V:a2V;B00=N
dV;BH[400V:a1F;A1F:a00AN/F:aH[5Rd0QRd@9R/@03G[5RdV;B00=Rd@03G]5N/Eja00=N/@=N/006
G[5N/5jaH[5R/5j`0Uj_25j`00IR/Ej`G[1N[ej`GY04GXl00ej@G[1N/002G[06GZl01Ej`GZmNT5j@
GXl00Uj@00=N[ej?GXh00Uj>00IJSej@FXmNT5Z@FXl2FY03FXl00ej?FXiJSP02FXl00eY_FViJKP05
FVh00eY_FW1JK`02FVd3FVh015Y]FVaJKEY^3EI^00AFC5I]ETaFC09BC003ETaBC59;00=BB`=FB`9B
C09BC@9BC003DTeBC59<009BC004DRa>;Dh]CRd2CR`4CR/4CR`014h[DR]B:dh[0Th/0Th[0dhZ00=>
:dX;BP/00dX:00=:2dh;BP/00Th:00I>2DX:CPY:2dX:BP/2AP/2APX2BPX00dX9BPY:2P02BPT4BNT0
24H9BNU5jDGYANY9jDGYBNT4ANT3ANP01TGWALM5adG7ALQ5j095b0=5b@03@LU5bDG80091b003@LM1
b4770091Z006?JQ1Z478@LQ1Z4780Cg;000012e?@Je>;58]0Th]14h^0dh]1Th^00E>CU9=CTi>Cdi@
009><006CRi>CTi>CTiB;Th_0U8_159>0UI>00QF;EI>FRiF;UH]FPYJ2EWZ15GY00EAj57YDLQEb5G7
009Eb009DLQAbE78ELMAaU6VDJM=Ydg7009Aa`04DLIAYdg7CLT2DLT2ENP2ELL01U77CJM9Z4VXBJM9
Z099Q`0;AFM5ITEU?FHi9Ce6@HM1ZDH;CReBC007EVh3ETd00eI>ETmFC`02ETl00eI^ETiFC`03DTl2
ETl3DTh2DTl2DU03DTh2DTl00e9>ETmFC`05ETl2ETh3EVl00eI>EVmFL002EW03FVl00eI`EW5FL006
EW04FW02FW43FY44FW0:FY43FY800ejBFY9NTP03GY<2G[801EjAGY9N/UjbG[400Ujb00=J/ejcH[<0
0V:c00AR/V;CH]ARe09Ne09Re09Rd`9R/`MRd`9Re003H]EVmF;e00=Vm004I]AVm6;eH_D3I_H00fKe
I_AVm003I_@2I_D00fKdI_EVm@05I_D2J_D2J_@3J_D016LFJ_E[5F[e0V/E00=[5V/EJaH01F/F0V/E
0V/F0f/G1f/F00E[5F[eI_IZmFKe009Zm@=Zm005J_E[5F/FJaI[5@02J_D2JaD00f[eJaE[5@02JaD0
0f/DI_EW5@03IaD01VLDI_AVm6KcI_AVl`UVm0IRm004H_=Rm6;dH]@2H_D6H_@00f;cH_ARe002G]@0
15kCH_ARm6Kd16;c00=Rm6KdI_@00fKc00=Vdf;BH]800V;C00=Rm6LEIa@00V;d00ARdfKcH]5Vd@9Z
l@03Ja=VlfKc009VlP03H]5RdV;B00ARdP9VdPARdP03H]=VdVKC009Rd`ERdPERd`03H]9Rdf;B009R
dP9Rd`03H]9RdF;A00=Rd@03H]9RdF;A009Rd@9Rd003H[1R/F:a009Nd@9N/@9RdP=Rd@03H[5R/6:`
009R/@9Rd@05H]9RdF:bH[9NdP03H]800f;CG]9NdP02H]47H]801F;CH]9RdV;CH]800f:a0f;A00=R
d6;AH]400V;A00ARdUjaG[5N/@ERd@9Rd0=Rd@9R/@9Rd@9RdP=Rd@03G]5N/Eja009N/@04G[1R/5ja
G[03G[43G[000f:`HZmR/003H[0=G[0015j@G[1N/5ja0Uj`1Ej_00AN/5j_GY1NT09NS`9NT004GXmN
SUj>GXh2FXl3GXl00eZ?FY1JS`04FXl01Ej?FXiJSUZ>FVl00UY^1EY_0UY`00=JKeY^FVh015Y^00=J
K5Y]EVh02UI^00=FKeI>EVh00eI<00EFKE9<DTaBC5I<00MFB`9BC005DTeFC5I<DTaBC@02DT`0159;
DTaB;58]0Th]00=>;58[DR/00e8[14h/00A>:e8[DR]B:`9>;0A>:`06CRY>:dX;CR]>2TX:1Th:00Q>
2Dh:CPY>2TX:BP]62TH;0TH:0TX:00A:2DX:BPU:2@9:2P03APY62DH900A5j@03ANY5jDGZ00Q5j@03
ANQ5b4G800E5b0I5b@91b003@LM1b4780091b091b@A1b051Z`0000D];Sf/BRaB;Dh]00E>;P=>;@E>
;P08CRe>CE9=DTe>CDi?CU1>;`A>CPYBCP07ETiF;UH^ERiF;EH;FPT00UGZ00EEjE7YDNUEj57Y009E
j003ELMEb578009Ab0=Ea`07DLIAYU6WCJMAYe77DLH00U7700E=b578DLUEb5W7009Ea`03DLM=Z4VW
0099Y`03BHQ9QdUV0099QP0:AHDmISU6>BDmIT6XAP]>;E9<ETd9EVh00eI>ETmJC`02ETl3ETh0259>
ETiBCUI>DTeB;E9=ETd2ETh2ERl3DTh00e9?DTiBCP04ETh00eI?ETiFCP02ETh5EVh2ETh4ETl01EI_
EW1FKeI^EVl00UY_0UI`00=JL5Y_FVl00UY`00=JLEY`EW400UY`0eY_00=JL5ZAFY401eZA00EJTUjB
GY9NTEZB009NTP05GY=N/ejbG[9N/@03G[82G[4015jbF[=N/ejc0V:c00=R/V:cG[<00V:d00MNe6:d
H]=RdUjbG[=R/`04H]<00f;BH]=Rd`05H]@2I_@016KDI]=Vm6Kd1VKe26Kd00=ZlfKdI_@00fKe00=Z
mF/EJ_D00f/E00A[56[eJ_EZm@=[5@03IaEW5VLF009W5P03IaE[5V/E009W5@=[5P9[5`03JaIW5VLF
009[5P=W5P03IaEVmVKe00=Vm@04J_A[56[dJ_@2I_@3JaD4IaH026/EJcE_=W=FKcIW5F;dI_D2JaH7
JaD2I_@016/eJcI[=FLE0V/f00E_=F/dIa=W5F/e009W5@=[=P04JcM[=V/fJcH3KcH2KeH026mGJcIW
5FKeIaE_EW=gKeH2JaD00f/eJaA[=007KcD01VlfJaAVlf/DKeI[=0=Vm09W4`0>Ja5_4F/AJa5Vl6Ka
Ja5[4V[aI_9Vdf;BI]9Vd`=RdP05H]=RdV;CH]9Rd`02H]800fKBH]9RdP06H]83H]<5H]82H]<00f;B
H]5R/@03H]43H]82H]47H]02H]400f;BH]5Rd@02H]42H[42H[0016:aH]9RdV;A0V;B0V:b1F;B0f;A
36;B0V:a0V;A00MVdF;AI]1Vd6;@H]5R/@02H]800ejaH]5Rd@04H]49H]000ekAH]9Rd@03H]4015kA
G[5N/Eja0ej`00=N[ej`G[000ej@00=N[f:`HZl016:_15j_0ej`0V:`0f:_0V:`0Uja00=N/5j_G[00
1Ej_00AN/5j_G[1NT0ANS`05GXiN[Ej>GXiJSP03GXh015Z>GXiNSeZ>15Z?00MJSUj>GXiJSEY^FVeJ
KP02FVl00eY^FVmJKP05FVl025Y^FVmJKUY]FVaJKEY^FVd3FVh2FVd4EVh00eI_ETiFKP02ET`00eI[
ET]FB`0:ET/0159<ET]FC5I<1E9<0e8[0U8/00A>C58[DR]>:`=B:`A>;09>:`04DR]B;4h/CR`4CR/2
CRX014h[BP]>2TX:1Dh:00E:2Th:CPY>2dX;009:2P04APY62dH:APX2BPX01dh9BPU:24WYBNY:2TX9
00962@M5j@03BNU5jDGY00E5j@95j0A5b004ALM5b4G9ALX3ALT2ALP3@LL4@LP00d79@LQ1b002@LL1
@JX00003;BhmS4X<009>;@=:;P]>;P04CTiBCE9?DTl3CU03CTh3DTl7DTh00e9?DTiF;P02ERh01EH]
EP]EjUGZDNX00U7Y00=AjU7YDNT00U7Y00AEj5G8ELQEb09Ab003ELMAae6W009AY`07CJMAYe77DLIA
b577DLP00U7900AEb5WXGPMIj09Ea`9Aa`0@CJM9R4V7AFI5IdVWAHDmISU6>DDiIT6XAP]>;Di=DTh2
DVl015I^DVmBKe9_0eI^00AFCUI?FTmFCP9FC`EBC`9BCP9FCP07ETeB;EH]EReF;e9@DTl00e9@0U9?
0eI>00MFCeI>ETiFCe9?EVmBK`03EVh015I_ETiFCeI?1EI_00AFKUI_FVmJK`=FL00;EVmJKeI`EW1J
LEY`EW1JL5IaETmJK`02FW000eZ@FY5JT@04FY82FY43FY801ejbFY=NTUjBG[=J/UZa00=N/@08G[9J
/UjbG[5N/UZcG[=J/`ENd`03G[=R/f:c00]Rd`ERe003H]=Re6Kc009Vm004I]AVm6KdI_@5I_D3I_@0
0fKeI_AVm004I_@5I_D01VLEJaI_=flgJaEZm09[5@9[=P03IaI[=V/g009[=`03JcI[=fmG009_F09[
=`04JaI[=VlhJcL3KeP01VmGJcM[=fmHLgU_F09[=`04KcQ_F6mHKeP2LeL02G<fKcI_5FlgLeMcNG=h
LeQcN002LgT01VmHLeMcF7=hLgUcN0=cN@=cN09gV@09LgQcEVmFKeMcF7=hKgQcN6mh009cM`03KeE_
=6/c009[E003JeE[=F/f00=[=P0KKeI[=F]FKeE[=6LBI_=W4fLfIaENle[BF]5NdE[AG/mNd5k?G]5N
ceZ>EViFCUI^F[5NdUZ`009FKP0<EVmFL5I`EXmFKe9@BRm>Cdi@BRm63D7;0T7:00U1jdX^EVeJJeY8
HZmVlVKdH]802F;C0f;B00=VdfKBI]<00f;C00ARdV;CH]=RdP=Rd`04H]9Rdf;BH]<2H]8016;AH]9V
dV;A0f;B00=RdF:aH]4016;A16:a00ERdF;BH]5RdV;A009R/@05H]9VdV;AH[5Rd@03H]800f;CH[9R
/P05H]83H]45H]83H]<3H]800f;CH]5Rd@02H]82H]400fKAH]5Rd@02H]400f;BH]5Rd@0<H]42H[40
16;@H]5NdEkA0V;@00=N/5kAH]401Eja0Uj`00ANT5jaH[1N/@9N/004H[1R[f:`H[02HZl2GZl4G[00
0ejaH[5R/003H[03G[02GZl3G[03GZl3G[04GY000ej?GXiN[@03GZl5GXh2FXh3FY04FXl00eZ>FViJ
KP02FVl01EY`FVmJKeY^FVl01EY^00=JSeY_FVl01UY^00=NSeY^FVh015I^00=FKeI>EVh00UI<1EI;
00=BBeI;ET`015I;00=BBe9=ET`00UI<0U9=0e9<0e8[00=B;4h/CR`00Th/158[34h/1Th[14X;00=:
2Th:CPX00TX:0dX;0TX:00A62TH;AP]62`=:2P9>2@04CNU9jTX:BPT2APT3APX00dGYAPU5j@02ANT0
0dGZANU5j@02ANT01DGXANU5jDGYANP01dG80TG900=5b4G9@LP01d7800E1bD78@LQ1b4770051ZP00
00<];Sf<BP/00Th/00=>;DX^CRh024h]158^0e9>00=>CU9>DTh01U9>1EI>00aBCU9?DTmBCe9>ETiB
;EH]ER]F2U7ZDLT2DNT00e7ZENUAj@02DNT2ENP5ELL01U77DJMAYe6WCJMAY`=Aa`04ELMAb5G8ELT2
ELP00eG7ENQIa`02ELH2CJL01dV7AFI5ITF7BHM5QCeV008iAP06>FI1bDGZBPeB;E9>0UI_00AFKU9_
EW1FK`=FKP04EVmJCUY=FTd2ETh2ETl00e9?DTiBCP02DTh3ETh01eI=ETaF;EI>ETmBCe9@009BD@03
DU1BCeI>00IFCP03DTmFKe9_00=FKP9FK`=FL09FK`=FKP08EVmJKeY_EVmFL5Z@EW1JKP=FL003EVmF
L5I_009FD004FU1JL5Y`FY03FY401EZBFY5JTEZAFY000UjA00MJTUZCF[=N/ejbG[5J/P07G[44G[80
0ekCG]9Nd`04G]<3G]800f;BH]=Nd`02H]<01f;cH]=Rdf;CH_ARmF;D009Rd`08I_AVlfKCI_=Vm6Kc
I_AZm09Vm@04I_IVmFKeJaH2KcL2KcH036/FJ_AVm6/DJcE[56KeJaE[=VlfJaI_=P9_F008JcM[=Vlg
LeIgN7=hKeQ_E`9_F003KgQcN7=h009cN003KgQcN7=i00McN@06LgQcVG=hKeM[=f]H0fmH0Vmh0Vmi
00QcNG>ILgQcEVlEJaE[=Fle16/f00A[=flfJcIW5@9Rd`=Rl`0II_ARlfLDH_ANdUZaFY5J/EjaG[1J
SU9>CTiBCU9^CViBKU9]CTe634H:AR]:;4H]@Pd00d7/00U1jcVZ>JXmbT79@LPmb3V7<FL012e600L]
IRe6:BD]92e5;D@Y9003:@<02RST:@@Ti2328:4P`BCS8<8HPAbR0R320QbR00<DPAAQ56800aAQ00PD
HQAQ564LP34S@LMJBF;@0VKc0f;C00ERdV;CH]9RdVKB00ERdP=VdP07H]9VdVKBI]9RdVKBH]8016;C
1V;B00=VdV;AH]401F;A0f;B0f;A0V;B1F;A0f;B16;A4V;B0f:b2F;B0V;A00=VdF;AH]401F;A00AR
d6;AH]5Rd@ERdPERd@URd007H]5R/F:aH[5N/F:aG[401F:`0V:a16:`16:_00=N/6:_H[0016:a00AR
/5j`GZmN[`9N[P04GZmN/5j`G[03HZl01Ej`G[5N/5j`GY000Uj?0Uj>00AN[Ej>G[1N[`EN[P9NS`AJ
T0IJS`EJK`9JKP03FVeJKUY]009JK@03FViJKeY_00UJKP04EViJKUY^FVh2EVl00eI^FV]FB`03FV/2
EV/6ET/2ET`2ETd6ET`00e9;DR]B:`03DR/014h/DRaB;58[0U9;0U8[2dh/1dh[00I:2dh:CPY>2TX:
CPX2BPX2BP/2CPX2BPX3AP/3BPX2CPT01TgYCPU:2DX9APY:2P962P962@e5j@03ANQ5bDG800I5b003
ANQ5b4G800=1b@M1b003@LM1b4770051ZP0000HY;cf<CRaBCE9<DR`2CRh3CRd2DRh2DRd2DRh0159>
DRiB;U8^0U8_00=>D59>DTl0159>0UI>0eH]0UI>00=BCU9?CTl00U9?00QBCU9?EReF2eH:ENYAbU7Z
0U7Y00AEjE7ZDNUEj@=Ej006DLQEaeG8ELMEb5FW0U6W00AAb577DLMAa`9Ea`9Eb005ELUEb5G8FLME
j003ELL054fWBHM5AT56AFM5R4FXAJLmISTV>BDiId7:AP]>358]DTiFCUI_ETh3DW0015I_DVmFKUI_
0UY>00IJCEY?ETiBCUI?DTl3DTh2DTl0159>ETiFCUI<0UI>0U9?0U9@00=BDE9@DTl01UI>00=FCe9`
DVl00e9_00=FKUI_EVl00eI`00=FKUI_EVl00UI_00AFL5I_EW1FK`9FL003EW5FKeI`009FL0AFK`=J
KP04FXmJT5kBG]84FY4025Z@GY1NTEj@FY5J/UZcF[82G[802EZbG[5J/EjaG[9RdV;CG]9N/P03G]<0
1ekBH]9Rm6;dIaES5F;d009Ne006H_AS5FLEIaIS5F;d0V;c00IVm6LEIaEW5V/EJaH3JaD01FleKcI_
=VlfLcH00W<g00YcEg=HMgQgNG=HKeQ_=flfKcMcF09_E`03LeIcEfmG009_F003KeM_=VmF009_E`05
KgQcN7=gLgQ_EP02JcH01f]GKgQ_NFmhJeM[=VLE009W=P04IcES55kcF]@2G_@2G]@015kCG_ANdeZb
0eJ@00]F/eJbCW5:D4Y?CTm:D4i`CY5BL4X`00E63P06@Pi1kCW;>J/i[3V[0SF[0SV[00leRReX:BLY
1bD79BLUB2DX8@HLiAcT8>@Q1B3T7<@00aRR0QS200THXQS27<<H`QB0460DXaS45:<00Q1Q00TDHAB0
560DP1R0440800`P460010a000@@H1AQ584HP@<DP@03564@H0a000<@H0D@@003460@HA1Q00<@H@04
364<H0a0464248802`aR344<@1QP8:0eA4h;GZmRdEkAG]<00V;C00=NdV;CH]800V;A16;B00=Rdf;B
H]8016KB0f;B1F;C00ARdV;CI]9VdP9RdP9VdP=Rd@=RdP04I]9RdV;BH]83H]42H]84H]43H]800fKB
H]5Rd@03H]800fKBH]9RdP0=H]82H[86H]82H[800f;AH]9Vd@02I]42H]400f;BH]5Rd@02H]400f;@
H]5Rd@05H]83H]400f;BH]5Rd@04H]03H[02H]04H[400ekAG[5Nd@02H[400f:`H[5R/@03H[42H[03
HZl3H[000f:_H[1R/004H[4016:`G[1N/5j_0V:_0f:`0f:_00ER/5jaG[5N/5j@00=NS`=NSP07GXmN
[ej^GZmN[Uj_GZh00Uj?1EZ@1EZ?00=JT5Y`FW0015Y_0UZ>00IJKEY^FViJSeY^FVl:FVh00eI^EVmF
KP02EVl015I^FVeFC5Y:0UY;1UI;00AFK5I<DTaFC0=FC@04ETaFCEI=ETd2ET`01E9;DTaBBe9;DR/0
0e8/00=BBdi<CR`03Dh/00=>:dh/CR/024h[00A:2dX:CPY:2P9>2P03BP]:2TX:00=:2P04BP]:2TX;
BPX2CPT024gYCPU:2DX:APY:2TX9BNT3ANX014GYAPY62DH91dGY00=9jDGYANT00TG900A1YdG8ALU5
b@95j007ANU5adG8@NU5bD79@LP00d790TG90T780D6W0CfZ00001RT_?Ha>;58/DTaB;09>;P=>;@9>
;P05DReB;4h]DTeB;P02DRd0158^DRmB;di@259>1EI>0U9>00=BCe9>DTh00UI=00AF;EH;EPYEjP9A
jP=Ej@03DNYEjEGY00=Ej004ELQEae78DLL2DLP2EJL00e77DLIAa`02DLH00e77DLQEb003ELP2ENP3
ELL00e6XBJQ9R002AHP02dVXBLU5QSe5=@@i93eV@LU5jdX<DR`00eI>00ABCU9?DU1FL0AFKP=JC@06
FTiFCU9>ETmFCUI=0U9=0U9?00QBCU9=DTeFC5H/DReB;U9>0U9?0U9@00=FKeI^EVh00UI=0UI>00=F
CeI_EVl00e9_00]FKUI_DVmBL5I`EVmFKU9^EVmFL5I_00=FL09FK`EFL006EVmFCeI>ETeFKUI<0UY]
0UZ=00]Nd6;AG[1JT5ZaG[5R/Ej_HZmR/6;B009NdP09I_AW56/DIaERlekBH_=[5F/d00=[5@03JcI[
=F/e009[=@U[=P9[EP0=IaERm6LDKeI[56KcJcI_EflfIaAVm6/DJa<00VLC1VKc00IVm6KcI_AR/UZA
EW44FY402UZ@G[1N/EZ?DTi>3U9=EVaNSUI]0Th]00AB;E8/DRe>3@=63@0;@Pe1k47/@Ndmc35Z<FTe
RCF8=HTaJ@04;DP01BU79BHU1RD58@D00bD500lU1R3U6<@HY1S46<<DXaB2468@@Q11564HPQbS6:80
0QB20QB100TDHA1Q344@PQBS5:@H`aRS58400Q1Q0QB300@@Pa245:@DX`8HX`086<<LXab2688DXQRR
6:<DHP8<HP0458@HaARU5:@258@03ABT6:@HY1c46<<LXaRS58<@PA1Q468DPQB3008@PP0=5:8H`ac3
7:<HXQRS7<<HXaBS588HXac47<<00QRR00DL`ac26:<HXac3008La0077>@La1c47<<HXQRS6:@00Qc4
00THYAB4468LXR2Q:@9>35j=G[000Uja0Ujb00AN/EjbG[5N/@9R/@03H]5RdV;B00=RdPAVdP=RdP03
H]=RdV;C009Rd`ARdP9VdP03H]=VdVKA009Vd@=RdP03I]5RdF;A00]Rd@05H]9RdfKBH]5Vd@05H]80
0fKBH]=RdP07H]8016;AH]9RdV;B0V;A0VKB00ARdF;BH]9RdP=VdP03H]5VdFKA009Vd@03I]9RdVKA
00QRd@ARdP9VdP05H]9VdF;AI]5Rd@0?H]000f:aH[1R/@04H[48H[03HZl2H[02G[400f:`HZmR[`09
HZl4H[000ej?GXiNSP06GXh2GZh2GXh01Ej^GZmNSej?FXl01UZ@00=JSeY_FY0015Y_00=JSeZ>FXd0
0UZ=0UY^0eY_0eY>00EJKeY^FViJKUI^00EJKP03EViJKUY]009JK0=JB`=FB`9FJ`=FB`03DTaFBeI=
00QFC@05ET]BC59;DT]FB`02DT/0158[DT]>C4i<1Dh/00=>:dh/CR/01dh/14h[00=>:Th[CR/00dh[
0dh:1dX:0Th:00E:2TX;BP]:2TX90099j@A:2P03APU5jDGZ00=5j@05APY:2DH9ANU9j@0:ANT2ALP0
0dGYALQ5i`02@LL2ALP01478ALQ5b4G80d790dG90TG80D6Z00001RD>>Ha:34h]DReB;0A>;P06CRe>
;Th^DRi>;4h]0U8^0e8]0U8_00=>D59?DTl00e9?00=BD59?CU000U9?0eI?0U9?00YBCUI>ETmFCUY?
ERiF:eH:EN]Aj`AAjP=EjP9Ej@9Ej09Ab003ELQAb579009Ab0EAa`9Ab09Ab@04ELUEjEGYENT2FLL0
4EG7DLU=bDfYCJY=bdFZAHQ1ISTU=@@e0cUV?JU5jdX=DRd00UI>00IFCeI`DW1BD59`EVl2ETh015I_
FTiJCEY>0UI>0UI?0UI>0e9>00EBCe9>DTeBCE9<009B;@9B;P9BCP9BC`03DVmFKU9^00=FCP05ETmF
CUI^EViFT002EY42EY0025I_DTmFT5ZaF[1J/EJAEY02FY0015ZAG[5N/Eja0UkB0V;A00INdEjbG[5N
Sej_G[02H/l01F;>H/eRcFK`Ia800VLD00ARlfKbH]5Rc`9Vc`0>Ia9[56/dI_=RdF;@Ia=[=VLEH_=R
dFKAH]=RdP9Rd`04G]=RdUkBH]43H]8016;dHaERm5kB0UJA00iFT5:AEY5F/EJAEW1>Cdh_APi1kTH?
AS16;d7]0Sg<13W<00Hi[3F:<DTeRSV[=HX2<DT2<FT00c5X;BPY1`02:BL01B34688LXbCU9@D00bCS
0RCT00/LXab1788LXQbS6:8DXQAQ464DH1B1008DPP03464DPARQ008L``076:<DXaRS7<@M1R3U7<@0
0QRS0ac400THY1BS6<@Ha1C548<<P`aS24800PPQ00T<HQB38>@Q1B3U7<@L`aRS68<00aB300@HaB47
8@HLi@8Ha0038>DQ1b3V008Q1`8Q1P0>8@LU9R4W:@HTa2D68@HU1RCU:>@LXac58>DY9`8U1P@PiP08
8@LU1RD79@DPiAcU7<DLa08La@DLi@<Pi0037>@Pi1cT008Li@057>@LiAcT7>@Pa0028>@28>D27<D3
7>@011c47>@Li1cT0ac40Qc500LHXac37:4]94G[GZiJT002FY42G[83G[42G[801F:bH]9RdV;BH]<0
0V;c0f;B00QVdf;BH]=RdV;CI]=Rdf;B0f;C00ARdV;CI]9Vd`9Rd`03I]9RdV;B00URdP9Rd@04I]9V
dFKBI]83H]400f;BH]5VdP02I]85H]800f;CH]9RdP0=H]82I]86H]800fKBI]5Vd@04I]42H]42H]83
H]4:H]800fKBI]5Rd@08H]400f:aH]5Rd@03H]402f;@H[5R/EjaH[5RdF:`H[5R/6:aH[000V:a00UN
/6:`H[1R/5j`H[1R/F:`H[401F:`0ej`1F:_0V:`00=N/6:`GXl00Uj?00QNSUj?GXiNSUj^GZmN[Uj_
0Uj?00=N[Uj_GXl025Z@0UZ?00=JT5Y_FVl015Y_0UZ>0eY^1eY_00=JKUY_FVh025Y^0UY]00=JKUY/
ET`01eI<0UI;0U9<2EI=0U9=0U9<0U9;0U8/00=BC4i<CR`04Dh/2Th[1TX;00=:2Th:BPX00TX:0TH;
00E62TX:BPY:2TX9009:2P05AP]62TX:APY5j@02ANX00dH:APU62P03BNT9ANT00dGXANU5b@02ANP3
ANX00dGYALU5b007@LT3ALP1ALX000059@hiK4X;CRe>;002CRd3CRh024h]DRiB;U8^DRaB;E8^DRd2
DRh3DTh3DTl3DTh00e9?DU1BD002DU03EU001E9@ETmFCUI=ETh00UI?00=JCUH[ERX00UG[00=EjUGY
ENT015GY00AIj5GYENQEj0=Eb004DLUAb578DLL2DJL01E77ELMAae77DLP015G90U7900MEb5WXENUE
jEG9DLU9ZP02AHT02TF8AHM1ASdT<<8iASfYAN]:3E8]0UI>00=FCeI_EU000UI`15I?0UY?0eI>01]B
CUI_EVmBCE9>EVmFT5Z@EVmFSeZ?FXeJSeI^DReFKUZ@FViJKejaG[1RcekAFXmFKeZAH]400f;@00mR
dUjaEW1NT6;BH]1NdF;cG]9RlF;bG[1FTEJ@FY0015Z`15j`00MRd5jaFY1BL5Z@H]1N[`02EXl025J>
DVeFSeJ@DW1FT59`CTh2BRd00dh]CTe>;@02CTd034X<ANa634H<@L/mZSVZ?JXmZCVZ>HXaJP8eJ@07
<DPaAc56<DHaABdV:@D00R3U00LTiBD58>@PhacT7><H`P0258826:803AR2568<HPa1364<HPa12248
@A1R6:8HXaRR008DPP066:<LXac47:@HPac40R3U00DLa1c57<DLa1RS008HPP046:<La23T8>@28<@0
2b3U8>@LY1R37:<L`aR2368@PQRR7:<00QRS00LHY1RS7<@U1BDW:BHU9`028>H01BDX;FTaJBeY:DP0
12TX00LU1bDW:BPU9b488>LLj0026<H031AT5:DHaRDW;DH]J2TW:BHU1B3U7<DHa08Li@088@HQ1BTU
9@DPib3V9BHY:08Y9`039@HQ1RD600<Q1P8Ti@0;7<DHaR3U9@DY12348>DQ1BDU9@DQ1@048>D01BD6
9@LU9bD69@D00b3U1AcU00@PiAcU8>@Pi08Li0@Pi0047>@LiAcT7>@28>@00acT7>DLi@027<D011c4
8>@Li23T0QcT00<L`acS7<@011c400HP`RCQ<DE5jV:]G[43FY4015jbGY5N/Eja0Ujb00YR/V;BH]9V
dV;BI]=RlfKcH_=Vl`9Vd`03H]=RdV;B00MVdP03I]=VdVKC009Vd`03I]9RdVKB00QVdP04H]9VdFKA
I]45I]800fKAI]9Vd@04I]83H]83I]801F;BI]9RdV;AI]400fKB00=RdVKBH]400V:a00=VdVKcI]80
0f;B1fKB1FKA00AVdV;BH]9Rd@ARdP=VdP03H]9VdF;A00EVdP03I]5RdF;B009RdP05H]5R/F;AH]5V
d003H]4016;@H[5R/6:`0f;@00=R/F;AH[400V:a16:`16:a00=R[f:`HZl00V:`0f:a00=N/5jaH[00
0V:`1f:_15j?00=N[Uj_GZl00ej_00EN/5j?GZiN[ej?009NT004FY1NT5j@FXh2GY000eZ@FXmJS`08
FXl01UZ>FViJKEY^FXiJK`EJKPIJK`03FViJKEY^00EJKP03EViFCEI=00=FC@04EViFCEI<ET/2ET`8
ETd4DTd00e9<DT]BC003DT`2DR`00dh/DR]>;00<CR`014h[CRa>;4h/0Th[0dhZ14h[00=:2dh[CR/0
1Th:00A:2TH:APY62P9:2P0;APY62DX9BPY:2dX:BPU5jDH9ANU62P02APT01DH:BNU9jDWYANT00TGX
1TGY1DGX1DG900A5b479ALU1b@95b005@LQ1YdG8ALQ5a`01AJT000059>hiJdGZARe>3@02CRd3CRh0
14h]CRi>;dh^0Ti=1E8^0U9>0e9?00=BCUI>DTh01E9@0U8_00EFD59@EU1FCeY=009FCP05ETmF;UH/
ERYF2`02EN/2ENT01EWYENUEjEGYFNP015GX0UGY00AAjE78DLMAaP=AY`03DLM=b57800MAb@05ELUJ
2UX:ENY=b@02BJT03TF9BHQ5R4VW@FHm9CC2>BDmRDG[BPeB;U9?ETh2ETl2EW000eI@FTmJC`03FTl0
25j@G[1N/5j`G[5N/5jaF[43EY001eJ?EY1JSeZ@FXmN/5Z@00=FL003FY1JLE9`009BL09BL@04EY=N
deZBDW42EY84CU0025:AEY5BTTi@BRi63DH^ARd2ARl01T8>?N`mk3g/>JXeR@8iZ@03<HTaAbe7008a
B08aA`0@<DH]ARTV:@DY9BTV9BHPiAc37:<L`QbR7<8P`Qc2688358800aB33448800322001P@02208
80a1364<@0888004488HPQ1Q200210001`0010000000120880@P00800008100480Q03688@@@00004
0088@@88800G344@HQB47<DLiAc47<DQ1RDW8@HLiB3U8@HU9be8;FXYBBDX9@LQ1b3V9@HY1P0::BL0
1bT69>DLaAc55:@DXaS5008PiP058>DY1RdW;DP]A`02:DP0<bDX:DT]JSF:=J/aRbe[:DTU:BDX:BPY
9bU8:BPU:2D78>LLaQRU58DLaR3W:DP]IbeX:BLY1RTU8@HLiAcV7>DLiR3V9@HY9RD69@LU9bTW:DPY
:2T7:@HU1RD78>HU1B469@HPiP027<H28@H012DU8>DLaAcU0R4500HLiAcV8>DPiB459@L29BL29BH0
0bD59>DPi@038>D28@D00b3U7>DLi@027>@00acU8>@Pi0028>@27>@67>D47>@01R3T8>DPi23U7>@P
i08Ph`0:8>@La1c46:8LXBSQ;B55jUj]G]84FY4015jAG[5N/Eja0Ujb00=Rdf;BI]800V;B1F;c00AR
df;cI_=RdPMVdP03I]=Rdf;C00=Rd`03I]=VdVKB00MVdP06H]9RdFKAI]9VlVKc1FKB00=VdFKBI]80
1FKB00ARdfKCH]=Rd`9RdP03I]5VdVKB00AVdP=Rd@04I]9VdfKBI]<3H]<00fKCI]9VdP03I]82I]40
1fKaI]5VdFKBI_=Zm6Kc00=RdPEVdP04I]5RdF;AH]84I]8026KAI]9RdV;BH]5RdV;AH]84H]4016:a
H[1R/6:a0f;@1F:a16:`16:a00=R/6:_HZl00V:`16:a00=NdEj`H[400V:`00=R[f:`H[0016:`0Uj?
2ej_00ANSej@GY1JT09NT003GXmNT5j@009JT0EJS`9JT09JK`03GVmJSeY^009JKP03FVmJKUY^00EJ
KPAJK`03FViJKEY^009JKP03EViFKeI_00=FKP9FCP=FC@04FVaFC5I<ET`8ETd5DTd3DT`01E9=DRa>
;4h/DR`02Dh/00=B:dh/DR/01Th/0Th[00=>:Th[CR/01dh[0dh:00=>2dh:CPX00dX:00A:2dh:BPY:
2`=:2P03AP]62TGY00=5j@06APY:2TX9BPY9jTGZ0TGY0TGX1TGY1DGX00=5b4G9ALT00TG900=5b4G9
ALT01DG90TG80DG70DFY00001BC]>FY:2Th]CR`00U8/0Th]00A>;Th]CReB;P=>C@03CReB;E8^00EB
;PEBCP9BC`03CU1BD59@009BD004EU1BD5I@ETl2ETh01UI=ETiF;UH/ERYF2`9Ej`IEj@03FNQEj5GX
009Ej09Ej@06DNQEb577ELIEYU6W0U7800]AbE78DLQAb4g9BJU5R4EXAHQ9Z4W9009=b0=9Z099R00?
AHM=YdF7?DHdhcU5@JQ5jdh=DRmFL5Y^FTeJKUI_00EJK`0:FTiNKej>GXeJSeY_EW1BKdi?BRh3APd0
24X]ARe6347[@L]1jd7ZANX2AN/00d7:?HTeJ003<DP01C5X;FPaJ35X;BL00bTV00HY1BCT9>@TiB3T
8>D28>@00bD48@@DX`0246801A2358<@P`aQ24400PPP00<480@010000`@00P@P2@0000<400PP2400
0PQ000<88000000020000`@000X<@11Q344880a1468DPQ1Q340<80888004200400@0220336423440
1a225:<DY1B3444@@Q1R008<HP06348@HQS48>HPibD81BD600/Q9bD7:@LY9bU8<HTaRbU:9BTU:2D8
008U1`05:@HY9bTV9@HY9P05:BL01bdW:@HY1BCV8>HHaARU008Ha@037<DU1RTW00<]B00:;FT]B2TX
:DP]JC6:=J/aRbe::BT29@P03RTX:DL]J2e8:BLU1R3V7<DDPaBT8>HU1RDV:BD29BH01BD6:BHU9bD5
8>D00QS5010LiB459@DTiRD7:@L]AbeY;DLY1BTV9@HU1b3V9@DU1P8U1`0@8@HQ1b479BLY9B3U7>DL
iQcU6<DLaAcV8>DQ1BD59BH2:BL012e7:BHY92D40bCU00TU1BD49@DQ1AcU7<DHXacT8>D0123T0acT
00DLiB3U8>DPiB3T008Ph`036<4Lhb3T00@Pi0037>@Lhac3008L``096:<DPAbQ:<0]84X:GZeNdEZa
00=JT@03FY1JTEjA009N/@03G[9Rdf;B00=VdP06I]=VlVKcI_=Rlf;b0VKb00=RdVKBI]801FKB00=R
dfKCH]<00VKC1VKB00=VdFKBI]800VKB00IRdFKAI]5VdFKbI_<3I]83I]47I]82I]<2H]<3H]87I]80
0fKAI]9VdP04I]800f;CH]9Rd`02I]82I]400fKBH[1Vd002I]400fKBI]5VdP02I]84H]84I]83I]40
16;AI]9VdFKB0VKA0f;A00QVdF;BH]9RdF:aH]5Rd6;A0V:a00=R/6;@H]000V;@00=R/F:`H[400V:a
0f;@1f:`00=R[f:`HZl016:a00=NdF;@H[400V:`0V:_1f:`00=N/5j_GZl00ej_0Uj^0ej_00=NSej@
GY000Uj@00ANSej>GXmNS`9JT0=JS`04FXiJT5Z@FY04FVl6FVh2GVh00eY<FTeJKP04FVl00eY^FVeJ
K@03EVh2EVl00eI^EVeFKP02ETh2ETd00eY/FTaFC002ET`5ETd00eI<ETeFC@05DTd3DT`5DR`014h/
CTa>C4i<14h/1E8[1Dh/0Th[0ThZ0Th[0dhZ00=>:dh;CP/00dh:00=:2dX:BPX024X:00I:2DX:BPY:
2TX9ANP2BPT2BNT014X9BPY9jTGZ0TGY0TGX1dGY00I5j4GYANU5j4GYALP2ALT00d79ALQ5b@02ALT0
0dG8@LQ5b003ALP1ALH1AJT000099>diJTX:CTeB:dh<CRe>;Th]00E>;P03CRe>;U8^00UB;P03DTiB
Ce9>009BC`9>D003CU5BDDh`00=BD0=FC`9FCP04ERiF;5H[EP/2EN/00eGZENUEj@05ENT2FNP025GX
ENUEjEGYENQAb5G6EJH2DLP08U79ENUIb5G7ELQ=bDVY@FLm9SdU@DI5QdVXCJMAadVWBHQ9IdF8BJU9
b4W9?DLi9CU7@JU5jdg]DRiBD5Y_FTmJKUI_0UI?0UY_00eNKeY<GVe>3T6[=FTaB2dV;BDY9RTU9@DP
i0028>D28@D021c56:@HY1S46:<DPQAR444246801`PQ22088@PQ244880@0008000<400L0008400l0
000510088@Q11200000510002`@Q2248@@aR468@PQ234688800010000`Q100D48@Q246<@Pa22008D
P`036:<HY1BS008DP`055:@HY1RS5:<HY0025:@246801Pa2368DXaBT6:<DP`8DY00>48<DY1RT7:@D
P`a146<@PaRT7<DPiBDX9@PU1`8U1P0>8>HQ1R468BPQ1bD79BL]JBf:<J/UBRDY9BPQ208Q1`8U1`8U
1P0;:@HY9bTW;DP]AbU7;BHY9bT79@LTiP038>H29>H0>2TW:DP]BBe9<H/]JBe8:BP]BC5Z=JXaS2e[
;DXY:RDZ9BTY:2U8:FXY:BDW9@HPiR367<DLaR3W9@LQ9bD68>DQ1RTW;FPaRRe79>@Ha1BT7<HLiR3U
8<DTiRdW;DPYBBe8:BLY9RD78>LPiRD69BL29@P022477@PM1b479BHPiB3V7>H27<D00acU7>HQ1P02
9@L00bDW9@LY9`02:BH2:BD59@D02bDU9B@LiAS46:<Pi1cU8>DPi1cT8>@00acT00@LiB3U8>DPi@HP
i08Pi@047>DLi1cU8>@27<<02Ac47>@L`R31:<0iHTX[FXeNd@02FY4015Z@FY5JTEZA0Ujb00EN/Ejb
H[9RdVKB009Vd`04I_=VlVKcI_<3H_<00fKCH]9VdP04I]82H]83H]<2I]<00fKcI]9VdP02I]<00fKc
I_9VdP02I]82H]400fKAI]9Vd@05I]83I]401FKBI]5RdV;BI]<00VKB0fKC00=Rdf;BH_<00V;b2FKB
1FKC00IRdfKCI]9VdV[cI_<2I]85I]400fKBI]5VdP03H]800fKBI]5VdP06I]85I]42H]45H]84H]48
H[4016:`H[5R/6:a0f;@00=RdF:`H[000f:`00AR/F:_H[1R/0=R/@9N/@04H[5N/6:`H[03HZl00ej`
H[1R/002H[42G[4025j`GZmN[ej`GZmN[Uj_G[04GZl01Ej?GY1NT5Z@GXl00eZ@00ENSeZ?FXmJSej>
00=JT0AJS`06FXeJKUY^FViJKEY^0Ui^00=NSUY^FVh01EY_0UY^0eI^0UI_0eI^00IFCUI_FVeFCEY=
FT`2ET`00eI]EViFC@07ETd4DTd0159<DT]BBe9<0U8]0U8/00E>;4i<CTa>C4h/00=>;@E>;003CRe>
;4h/009>;0]>:`05CP]>2TX;BPY>2P02BP/8BPX00e8:CPU>2@03BPX00dX9BNU:2@03BPX014GZAPY5
jTGY1dGX0TGY0TGX00A5jDGXALQ5b0I5b@05ALY5bDGZANU5b@02AJP1ALL1AJT000069>diJDX9CRaB
:dh<0e8]1Dh]0U8^0U8]1U8^1e9>00=BCe9@DU400U9A0U9@0UI?0UI>00QJCUI>ERiF;EH[EP]EjeGZ
0eGY00=EjUWYFNT01EWY0UGX00EAj5G8DNMEaU77009Ab00NELQEjEGXELQIb579BJU1IcdV?BDmAT67
BJQ9aeG6CJI=QdEVAHQ9Z4W7@JPmIcTU>DM1ZDGZBNaB;U9?0UI?00AJKUY_FTiJC`=JCP9J:`04@HXL
HP@00002220010@P240880@00`0000<4000000006`0000<480Q0220010@000H480PQ12488@Q234<2
34801@a1244<HQ1R48<0111S00<@HQ1S46<00a1S0Q2300<@Q12358<00Pa200<@HaB35:<00aB30QBT
00@HY1RS6:<HX`DHY08DP`8HY0057<@Ha1BT468@H`025:@26<@01QBS58@DQ12458<HY08La08DY@09
6:DLaB3U9BHU:2TX9@HU1B46008PiP0;8@HQ:2CV8<DU9RU8;FT]JRE:9BTY:0029BP29@L29>L01RD6
:@HU1Re7;DP]I`8]A`8Y9`04:@LU1bCV9>H29>L012SV:BL]JBeY0Re:00T]BBe8;DP]JS6;>L/e[C5[
;DX00RTZ00<Y:BDY9@P00bD8018Y1bD79@LPibD89BPYB2E99BPU1bTX;DPaRSF[<FPY1BCU7<D28>H0
4BCU:@H]9Re8;DT]JC5X;DLY9R3V7<HPiRD59BLU:2D89@L00R4700HQ1R3V7<DLaAcV8@H29BH00b4W
8BPU:0039@L00bD69BHU9@03:@D012T49@DU1BD50RD400DPiAS57<DPi23U008Pi0047>DLi1cT7>@2
8>@48>D58>@28>D00acU7<@La0027<<27><28><02RC19:0e@4GYGZaNdEZAF[5J/5Za0UZb0Ujb00AN
/F:bH]5RdP9Vd`9Vl`03I_9VdVKB00=Vd`9VdPAVl`=VdP03I]=VlfKc00EVl`03I]=VlfKc00IVdP=V
d@AVdPIVd@AVdP9Vl`=Vd`03I_=VlVKb00MVlP=VdPMVd`9VdP03I]5VdVKA00=Vd@9VdP03I]5VdVKB
00AVdP9Vd@IVdP03H]9RdFKB00QVd@9Rd@9RdPERd@=R/@03H]5R/F;@00IRd005H]5R/Ej`G[1Rd@03
H[401F:`HZmR/6:`H[400Uja00AN/6:`H[1R/0ER[`9R/0AN/@05G[1N[ej`GZmN[P05GZl015j^GZmN
[ej?0Uj`0UZ@00ANSej>GXiNSP9JSP03FY1JTEZ@00=JS`03FXiJSEY]009JK@AJKP04FVeJKUY^FVl=
FVh3EVh01EY]ETeJCEY<FV/00UI/00=FKEI<ETd01eI=0U9=00IBC5I;ET]FBeI<DRd2DR`00dh/DT]>
C002CT`0159<CTe>CDh]24h/1dh[0Th;0dh[00=>:Th:CPX01Dh:00=>2DX:BPX024X:0dH:00=:2DWY
BNT00TWZ00M9jDWZAPY9jDGYANQ5j@0;ANP01d77ANQ5jDG9@LU5bD7900M5b@95b051ZP0000HTkCUZ
BPYBCEI<DR`;DRd7DRh00e8]DTiFCP02ETh2DTh00e9?DU1BD002DU001U9?ETmFCeI?ETiFC`9FCP06
FTiJ;EX/FP]F2UG[15GZ1UWY00AEjEGXENQAj09Ej003DNQEjEGY00AEj@9Ij@07ELU=ZDVYBJU9bTg9
BLX00TW900EAYdfWCHM5AD5V0095Q`0;?HLiAS44=BHmZDGZBPeB;E9?ETmFL005FVh01UY?FU1JKei<
?DPH8@<000@4800710000000100880@P000030@000H8@Pa2248480@0120212400`@P2248@@023482
36400a1R368<H@023643344224401@a236<<H`aS48<00PaR00<@HQB248<01a1S00<<HPa146<00Q23
00P@Ha2358<@HaB35:@LaAcU11BT11RT0QbT00@HY1c57<DHY@8HY0097<DLa1cU7>DHaAB448<DY1RU
00<DY00B48@<Ha1T468HY1cU8@HQ1acV7<HPiRD59BHYAbDW9@LU1R460QcV0R3V0RCU00@U1RDW:DLU
:0DY:0089BPU1b3W8>HU1RT7;BL]B0<]J@8]B08Y9`08:@PU1bT79@PY1bSV:BP]JP8YJP0;;DXYBBe9
;DT]JS6;=J/e[Be[;DXYBP02:BT00bD88@LPiP029@L01BTW;DTaJBe9:DT00ReZ00PUBBD79>H]BBeY
<HXeZbe80RT60RCV00hU1bT7:BPaAc5Y;DTaRS69:DPY9b468>HU1bDW0RDX00DU22D79@PQ1b3V008L
iP069@HU1bDV:DLYJ2E90RDX0RD800HU1b479@LU9RT5:BD2:@D01bD59@HU1BD59@@PiAc500<Pi@8P
i0038>DLiAcU008Li@HPi@078>@PiB3T8>@Q1B3U7>D011c411c300LP`RBP<B55jEj[F[1JT@03F[42
F[82G[801F:bH]9RdFKBI]<00VKD00=VdfKcI_<00fKc00=RdfKCI]<016Kc0fKB1FKc00=VlVKcI_<0
1FKc16KB0fKA1FKB1FKA0VKB0VKb0VKc00EVdfKDI]AVdfKc00QVlP=VdPMVd`=VdP9Vd@=VdP05I]5V
dVKAI]9Vd@05I]800fKAI]9VdP03I]82I]43H]47I]400fKBH]9RdP03H]86H]45H[43H]401f;@H_9R
lV;AG[5NdF;A009R/@AR/004H[5N/EjbG[43H[02HZl01Ej_HZmR[f:_H[000Uja00=R/EjaG[400Uj`
0ej_00IJ[ej_GZmN[ej^GZl5G[001eZAFY1NSej?GXiNSeZ?00=JT0=JS`=JSP9JK@04FViJKeY_FVlA
FVh3EVh01EY]ETeJCEY<FV/00UI/00AFKEY/ETaFC0IFC@0:ETiBCEI=ETaFBe9;DTeB;Dh]CR`5CT`2
CTd2CRd<CR`4CR/4CP/00dh:CP]>2P06CPX2BPX5BP/4BPX2BPT2BPX4BNT01dX:ANY9jTWZANU9jDWX
00=5j004ANU5jTX:APT4ANT014GXANU5bDG:0TGZ00E1bT79@LU1bDG900A1b@51ZP0000@PkCU:ANUB
C@9B;003DRe>;E8]00UB;@AB;P9B;@03ETaBCEH/009FCP9BCP=BC`04ETmBCe9>DTh4ETh025Y?FTiJ
CEY=EReJ2eH:EN/4ENX5FNT3ENT00eGXDNUEj002DNT015G8ENQEj5GX0UGY00UAjU7:CLYAbU79FNUI
jUGZCLX00TVZ0TV70dEV00e5Qd66@HLiAS3T=BHiRD7;APe>;U9?ETmFL002FVl2FVh01eY]FTmFDEi`
GTdmJAQR00800004344<H@aQ340234400`PP224<@@0334400`Q1344<@@023444244334400`Q12248
8@0424400`PQ1208@@0224400`a1364@HP023642344224401@Q0324<8@a136400PaS0PaR0PaQ0Q1Q
0a1R111S00<@HQ1S46<00Q1S0Q2300@@Ha2358<DP`8DX`DDY0047<@LiAc47<@26:@87<D37>H011c5
6:DHYABU0QBT00TDQ12446<<@a1S6<DQ1bDV8@H00b3V00DTiBDU;DLYB2D6008Q1P058>HLiR3V8>HT
i@029@D012D69BHU9bTW0RTX00hY9bTX:BPU1bCV8<HU1RdW;DLaJC6:<FP]B2e70be800@Y:2T8:@LY
1`8Y1P06;BP]BBe9:DT]BBe:0Re900L]JS5Z<HXaRbe9:BPU20029@L02BD68>HPiR3W9@L]AbeY<FP]
B002;DX01ReY:FTY9bCU;DT]JP8eZ`0@<FT]9bd69<DTibTX;DPaJ35W<FPaJBeY<FP]B2TW9BP29@L2
9BP00bTX9BLU1`029@L28>H01bD79BLYAbeX;HT]J2U7008U:0@Q1`039BLU9RTU008Y9@LU1@039>DP
iB3U008Pi@038>@PiAcU00DLi@0>8>DPi23T8>@LiB3U8>@U12458>DLiAc57<@LX`<HX`097:<L`ac2
9:4e@dH9GZYNceZA009J/@=J/P9N/P9Rd@=Vd@03I]=Ve6Kc00IVl`9Vd`EVl`9VdPAVl`=VlP9Vl`04
I_AVlfKcI_<4I]800fKAI]9Vd@05I]800fKAI]9Vd@02I]42I_44I_801FKCI]AVe6KCI_<026Kb0fKB
1FKC16KB00=VdFKBI]400fKB0fKA00=VlVKaI_800VKA0VKB00=VdFKBI_<00VKc0VKb00=Rd6KAI]40
1fKA0V;A1F;B1V;A0f:a00=RdF:aH]400V;A0V;@0f;A00ANdF:aH[5R/@AR/005H[5N/EjbG[5R/004
HZl01F:^GZmR[V:_H[000Uja0V:a00=N/Ej`G[001Uj_0Uj^0ej_00EN/5j_G[1NTEj`009NS`03GXiN
SeZ@009JT003FXmJSUZ>00AJSP08GXiJSUj?FXmJKeY^FVeJKP9JK@03FViJKEY]009JK@MJKP05FVeJ
KUY^FViJK@02FTd01UY<FT]FBeY[FVaJJ`9FB`03ETaFCEI=00=FC@03ETiBCEI<009BB`03DRaBC59<
009B;0A>C003CRa>;Dh]009>;@a>;0=>:`9>2`05CR]B:dh;CPY>2`07CPX9BPX2BPT014X8BPU:2DX:
14WY00=:2TGZANT00TGY00=9jDGXANP00dGX0TGY1TGX00I5jDG9ALU5bDGZ@LX3@LT2ALT3@LT1@L/0
00048<deBd7YBRh2DR`3DRd00dh]DReB;@05DRd2DRh00di>DRiB;P02DRh00e8]DTiFCP02ETh2DTh3
DTl3DTh015I?ETiFCeI>0UI?00IJCeY`ERmF;EH=EP`3EP/2EPX01UX9ENYIjEWYFNYEjP=Ej@03DNYA
jE7Y009Ej@09FNQEj5GYDNUEjE7ZDLYAje7:00A=bP04BJY5R4FXCJP2BJP03dVWBJQ9bDWXAJTmAc3S
=@HiJ47;APe>;U9?ETmFK`02FVl3FVh01UY@ES1JCV:>@J/TY0840005344<H@a13448@@0734400`Q1
344<@@02344010a2368@H`aR0`a100H8@@PQ22448@PQ2443248010PQ244<@@aR0`aQ1Pa100@88@`Q
320@H@@<HP06244880a0464@HQ221A230a1S1A2300<@Q1B35:<00QBS00PDY1BS58<DPaRT7>DQ:2D6
0Qc400DHaAc57<DU1R46008PiP<Pi@<LiP0>7<HLiQS55:@@PaBT6:DDYAB458<LiB468@DU1P8U1`8T
iP049@DU1RD78@L27>H00b3V7>HPiP028>H01R469@LPiQS59@HYB08Y:08U:0068@LTib358<HY1bdW
0Re800`]JBeX;DP]B2U7;DL]JC5Y;DT]:2T7;@L2;BP01Re8;DTYBBU9:DX]BP8]JP07<FXaJBe9;DPY
9bD89@H00R3V00@PiBCV:BP]B@@aJ@0@;FXaJc6;<HXaAbdV;DTe[3G<=J`aJBdX:@H]1c59;DT2<FT0
1c5X<FTaJBeY;DPY9bTX00<U:0@U9`049@LY9bTX:BP29@L012TX:DP]J2eX0RU800HU:2498@PQ2247
7@L28@L00bD59BHU9@049@D01BD69@DU9RD59>D00R3U00<TiB3U8>D00R3U1AcU0b3T1R3U00DLiQc6
6:@HXaB2008HX`086:8DH1B08<8a8dGZGZaNd09J/@EJ/P06G[=R/V;BH]9VdfKc0VKC0VKc00=Vm6Kc
I_@00VKc00=VdfKcI_<02fKc0fKb1fKc16KB00AVdFKBI]9VlP=VdP08I]5VdVKBI]9VlVKBI_9ZlP9V
l`05I]9VdfKDI]=Vl`07I_801FKcI]9VdfKCI]@01FKC00UVlfKBI]9VdFKBI]5VdVKAH]400fKA0fKb
1fKB16Kc00=VlVKAI]400VKA00ARdF;BI]9VdP9Vl`9VdPARdP9Rd@9RdP03H]5R/V:b00=Rd@03H[5R
dF;A009Rd0IRd@03H[5R/6:a009Rd006H[1R/EjaG[9N/F:`0f:_00AN/5j_G[1N/0AN/@9R/@=N/@=N
/004GZmNSUj^GZh2G[02GZl015j`GZmN[eZ@0eZ?00=JSUZ?FXl00eZ?0eZ>0eZ?00QJSUZ?FXmJT5Y_
FXmJKUZ>0eY^00AJKEY^FViJK@]JKP9JK@9JC@05FTaFC5Y[EVeJK002ET`6ETd00e9>DTeFC003DT/0
159<DRa>;58/1Di<0Th]00=>;4h]CR`03Dh/14h[0U8[14h[00=>2dX;CPX00Th:00=:2dX:CPX00Th:
00M:2TX;BPY62TX:BPU>2@02BPT00dH:ANY5j`02BNX014W[AN]5jTGZ0TGY1DGX1DGY0dGX0TGY0TG9
00A5jTG9@LY1b@=1bP91b@51b051b`0000LLcS5;ANYBCUI<DPaB;002DRd00dh]DReB;@06DRd6DRh2
DTh3ETh3DTh2ETh3ETd03EI>ETeFCUI>ETmF;UH_FRmF;eX_EPiF3EH<00=J2P=J2@9Ij@EEjP03DNYE
jEGY00MEj@03DNYAbU7:009AjP04DLU9ZDF:BJT2ELP04UWXELUAYdf6CJI=aeH9BLXmAS33<@@iRD7:
APe>;EI?EVmJK`EJKP0:FVmJCeY?HXm5cBBU000400`Q364234401@PQ22088@PP24400`a100<8@@a1
34400`a100@8@@aR468<H@<<@@888@03244<@@a2008<@P06248<@Pa1340880a00PaQ00<<@0a13440
0Pa100l8@@PQ100<811Q364@H@aR34488@PP340@HA2358<01A2300<@Ha2358<00QB300<DQ12448@0
0QBT00/HY1BS5:<DXaB2468DPaRT9@LU:23V008La0057<DLiB3U8>DLiP028>H00bCU9@DU1@047>H0
1ac57<@HYAB448@HYAc6008La@048>DQ1RD69@H29@L012467>HPiR3V0QcV00<LaQcV8>H0123V00DQ
1b3V7>HLiR47008Y9`0>9BLQ1bD78@LPiQc59>HY1RdV;BLaJ358<FP]B08Y9P0<;DH]Ic68<FX]BBdX
;BLY1bdY<FT]BBU90RTY00P]BS5Z=JXaJBe8:BPU9bD70RD600/TiBCV8<DTiC58=HTiZCV:=HXaJS6:
008aR`08<FTeQbe7<FTe[3F[;DT]B08Y1`04;BPaBC5Z=HX2<FT01S69=HTaRBe7:@LPiP<Pi@099@DY
9BU5:DHYAbU8;FTYB2TX00HYB08U:0088@TQ21d88@LM22478@HQ1@@U1@0;8@DTiRD69BDU1RD59>DP
iB3V8>DPiP038>D00acU8>DPi@027>D28>@27>@27<@04acU8>DQ1B479@PLaAB3588HXQRS584DH1R0
9<8XhTGZGXaN[eja009N/P08F[9N/UjbG[9N/f:bH]9VdPQVl`03I_AVlfKc00AVl`9VdPQVl`03I]9V
lVKb00=VlPIVl`AVlPEVl@03I_9VlfKB00AVdP05I_5VlVKbI_9Vl`02I]<00fKcI_9VlP06I_<00fKB
I]=Vl`06I]<2I_<00fKBI]5Rd@06I]400fKaI_9VlP05I_88I]82I]43I]8016;BI]9VdVKA1VKB00=R
dFKAH]401F;B00=RdF;@H]000f;@00=R/6;@H]4016;A1f;@00MR/6:aG[5R/F:`HZmN[`03HZl00f:`
G[1N/@03H[02H[400ejaH[5N/@03H[001Ej_GZiN[ej_G[000Uja00=N/5j?GZh00Uj^35j>0eZ?0eZ>
0UZ?0UZ>00AJSeZ>FVmJK`=JKP9JK@]JKP9JK@06ETeFC5I<FV]FKEI<2EI=0UI<00MF:eI;ET]F:e8[
DT]FB`03DT`01E9;CTa>;4h/DR/03dh/00=B:dh[DR/00U8[1Dh[0Th;0dh:00=:2dh:CPX00dX:00A:
2dX:BPY>2P9:2@03APU:2DGZ0095j`99j`=5j`05ANY5jDGYANU5j005ANT0147ZANY5b4GX0TGY0TGX
00I5b4GYANU5jDGZALT2@LX3@LT1ALP1@JX000066<daBd7[DTiJKE8/0UH]00=B;Dh]DRd01U8]258^
00=BCe9>DTh0159>0UI>15I=00QFC5I=ETeFCUY>ERiJ;UX_0UX^00AJ35X;FPYJ2PEJ2@03FNYEjUGZ
00=EjP03DNYEjEGY00=Ej@=EjP03ENUEjUGZ00=EjPAEbP9Eb@0@ELQEjEG7DHI=Qe6WDLQ9bCe5<:4`
iCUY@L]63Dh]DTh2EVl4FVh035Y]FViJL6:AGVm5cB2T000400a1340<@@@88@032408@@Q100D8@@<<
@@04224<@@aQ36423684344234800`aR36<<H`02368010a0320<@0aQ0`aR0Pa11@a20Q1R00<@H`aS
34400`a100<@PQ2346800a1S00<@HQ1S48<011B300@DQ12358@HY0@DY0<DX`8HY0057>DLiQS57:@H
a0027>D00b3U9>DTiP029@H29@D01R457>HLiQc67<DLaP<La@8LaP047>HPiR479@D29@H00bD7:BPU
:0029BL00b468>HLiP026<D00acV8>HPiP028>H042468@LQ1b478>LQ1bD79BPYAbDX8@LLib478>HU
1RT50RdV00`aB35X<FP]J2TW;BH]AbeX<HT]JRTY:BP2;BP01be9<F/eRS5[<DX]:BTY008]B@05:DTY
9bDW:BLU9`02:BL2:@H03RdW=FPeRCf[?L]1c3V[>J`aRbeZ9BTYBBeX;FT3;DT01BTY:BPY1bT8;DT0
0cF:00/eRC69<HTaRReY;BPTiB2U7:@PiBD600<Y9P8]A`03:DPYBBU800@YB003:DLYB2DX008U:005
8BTQ1b478@LM1`028@L00b458@HQ1P028@H02B459@HU1BD69BHY1RCU8>DPiP028@H28@D00b3U7>DP
i@038>D0323T7>@LhaRS5:<HXaS47>DM1R4W8@LLiP8HX`0>7<<LXabR680P`BCR:@A1jeZ<G[1N/Ejb
G[5N/P9N/`03G[9Ndf:b009RdP9Vl`9Vm09Vl`04I_AVlfKcI_<4I_@00fKcI]=Vl`09I_<6I_85I_<4
I_801FKaI]9VdVKcI_801VKc1VKb00AVlfKCI]9VdP9VlPAVl`AVdP03I]=ZlfKc009Vd`04I]9VlfKc
I_83I]4016KBI_9VlVKA0fKb00=VdFKbI_8016Kb00=VlfKBI]8016KB00=VdFKBI]400VKB0V;B0fKB
00=VdFKBI]800VKB00=RdFKAH]401V;B0V;A2F;@00=RdF:aH[401F;@1F:`1F:_0f:`0V:_00=R/6:a
H[400f:a0V:`0V:_00AN[Uj_GZmN/0=N/@06G[1NSUj?GXmN[ej^2Uj>0eZ?0eZ>1EZ?00=JSUY_FVl0
0UY_00AJKUY/FVeJK@9JKP03FVmJKUY^00EJKP03EVmFKUI^009FKP=FC09FC@=FCPAFC@9FC003ET]F
C5I;009F:`9BB`=BC006DT]>C4h/DRaB:e9<3Dh/0e8[00A>:dh/CRa>;0Q>:`9:2`05CPY:2Th:BPY6
2`05BPX00dX9BPY:2@02BPX014W[BNY9jTX;0TG[00=5jTWZBNX01TGY00=62TX;BPX00TGY0dGX14GY
00E5bD7:@LY1bT7900=1bP55b@51Z`0000DHc2d[?JU>;UH/00=B;004ERaB;58/CRd2DRd01U8/DReB
;E8]DRaB;P=BCP04DRiBCU9>DRh5DTh2ETh2ETd00eH]ETeFC002ET`01EI>FTeFCUY>ERh00UX/00=J
2eX:FPT01UX90UWZ0eGZ15GY00AEj5GYENUEj@9EjP9Ej@9EjP03FNYJ2EhY009N2@0DFNUIbEG9ELUA
b5G6CJI9QdV8BJM=ZD54;80/aCUY@L]63U8/DTeFK`9JKP0:EViJKUY]GVaJKUY_H[5RKdG<::@21000
0``P3408@@04224324000`Q13448@@02244334401PPP344<@A1Q468<H@@<@@03348<@@a200<<HP8<
H@03320<@0a100<<@@03368<@Pa200@<HP03468<HPaR008<HP04348<@@aQ4642368010a1348@HQ1R
0Q231QB300<DY1RT5:@00aBT00@HY1RS6:<HX`8HY0085:@@PaB26:@HiAcU8>DTi@<U1P<U1@068@HL
iQc57>DLaAcV0b4600@U9bD78@HQ1P8U1`8U1P0<:@LY9be8:DPU9b467<HHXac58>HPiB3V0QcU00<P
iRD79BL00R4700XPibD8:DP]J2UZ:BPQ1ac58<DTi@<Y1P0<;DPaB35X<FT]B2dV;DHYAbeX:FTYBBTX
0RdX00<aJCF:=HX00S5Y00PaBRT88>HU1bTX:BHU1RTW0Re8018]BC59<FTeJCV:@L]5kDG/@Na1c3g<
=HX]BB3W8<HTiRU8:DL29@L3:@P01Be8<FTiZCF9=HX00SF900LaRBeX;BPTiR359>HU1`02:BH00bT5
:@HYA`02;FL2;DP00bU8:BPYA`02:DL00be69BHU20029BP022488@LQ1R468@LQ9b468@D38@H28>H3
8>D00b459>DPi@028>H01R467@HQ1B458>DLi@<Pi@097>DPi1cT7<<DPQ1Q588HXacT008Li@8Pi@0=
7>@La1c47<<P`QR07:4ThbdVAPaRcV;AG[000Uja1Ejb00AR/V;BH]9Ve0=Vm003I_=VlVKc00=Vl`=V
m003I_EVm6Kc00YVl`03I_9VlFKB00=Vd@9VdPEVl`9VlP04I_5VdVKbI_<3I_84I_<3I_800fKaI_9V
lP02I_<00fKBI_9VlP03I_82I_<03FKBI]5VdV[bI]9ZlVKcJ_9ZdVKBI_9VlfKb00=Vl@IVlP=Vd@9V
lP03I_5VlVKb00=VdP04I_9VdVKBI]83I]400fKBH]9Rd`02I]8016KAI]9VdFKA0fKB00ARdFKAH]5R
d@9RdP04H]=RdV;AI]03H]42H]02H[000f;?H]5Vd002H[000f:aH]1Rd002H]03H[0>HZl2H[03G[42
H[000ej_GXmN[P03GZl01Ej`GY1NT5j_GXh00Uj?00AN[ej^GZiN[PQNSP04FXiNSUj>GXh2FXh3FXl2
FXh00eY^FVmJK`02FVl00eY^FVeJK@02FVd9FVh00eI_EViFKP02EVh00eI]ETaFC002ETd00eI>ETeF
CP03ETd015I^ETeFCEI<15I;1U9;00=>;58[DR/00e8[1dh/00AB:dh/CRa>;0=B:`05CR]>2dh;CP]>
;003CR/2CP/3CR/2BP/014h:BPY>2TX:0Th:0TX:0Th:0TX:00=:2DWYBNT014WZ00E62dX:BPY:2DWY
00Y5j@A5j0=5j@03ALQ5bD7:0091b@05@LY5bT7:ALY5b@01@J/000075<dY:cfZBRiB;EH/DR`00UH]
1E8]0eH]0U8]1e9>00=B;U9>DTh0159>00=BCeI>ETh015I=00AFCUI?ETmFC`9FCP04FRaJ:eXZFPX3
FPT2FPX00eH:FPYEjP02FNX2ENX3ENT015GXFNQEjEGY1EGZ0UG[00AF2UX9GPUN:@9J2@0SFNYEbU7:
DLUAadfXBHQ9Qdf7CJU5IS2Q:<DiJT7<APmBCEI>EVmJKUY_FW1JKeY^GVmJKeY@GY1NKTW/;<D<00@0
320<@00422400`Q12408@@033443244334400`PQ344<HP02364534401Pa2344<@Pa1368@PP8@H@03
340<@@Q1008<@@06348<HPaR3688@PaS1`aR0Pa20PaQ00H<HPa1320<@A1Q488348<00aB358@DQ005
5:@25:D00aRU6:@HY0026:@01QBT6:@DY1B3588La08Li@038>DU1QcV00<PiP8Ti@8Pi@8La@047>HP
iQd67@H28@L49@L00b478@HTi`029@L02RDW:DPU9ad76<DHY2358>DU1RDV0bD612DX00`U1bTX;FXe
Zc6[:DTU1bCW8>DTiBdX<DP2<FX01S5Y<DP]B2TW:BHYA`8YB08YB@05:BT]:34X=FXaRP03<FX022e:
;BTaBC5Y<FXeJC5Y<DT2<FT04c5Z=HXeRcV[?La1c3g;@J]1bd7<>J/eRBT78<LPY2TW:DT]J2e9008Y
:00J;BT]BBe:<HXiZSF[=H/eRSF9<FT]B2T79>LY1be8;FX]B2TV8>DU1Re7;FP]IbeX;DT]B0@YB003
:BLY1RD7008U:0038@PQ1b47008M1`037BLQ9b4600@M1P<LiP038>HPiBCU008PiP@Q1P<LiP@Li@<L
i0046<@DPQ1R5:<27<@37>D03R3U7>DLi23T8<<LXARQ8<<Y1DH<HZeN/5jAF[83G[801UZbG[9N/V:a
H]9Rd`9Ve003I_EVm6Kd009Vl`05I_AZm6KcI_AZm@02I_D016KEI_AVm6Kb0fKc16Kd0VKc00AVlVKA
J_9Vl`9VdPMVl`=VlP9Vl`05I_9VlfKcI_=VlP02I_<4I_800fKcI_9Vl`02I_<8I_82I]800fKbJ_9Z
lP02J_800f[BI]9VlP0BI_88I]83I]400fKBH]9Rd`02H]83I]401VKBH]9RdV;BH]5Vd@9Rd@ERdPIR
d@05I]1R/6K@H]1Vd003H[400f:`H]1Rd002H]02H[0015j`H[1R/6:_2f:`00AR/EjaG[1N/0=N[`03
G[1N[ej_009N[`9NS`=N[`05GY1NSej`H[1N/002GZl6GXh2FXh3GXh2FXh3FXl015Z>FXmJSeZ>15Y^
00=JKEY^FVd02UY^00=FKeI^EVh015I^00=FCEI>ETh00UI=00AFCUI<ETaFC@=BCP04DTeFCE9<CT`4
DT`4CT`5DR/7CR`0158[CRa>;4h/0U8[00E>:dh/CPa:34h;00A>:`9>2`U:2`Q:2P07DPU9jDWYBPY=
jDWZBPX00dX;0TX:14GZ14WY14GY00M5j4GYANU5jDGXANU5b@04ANX0147;ALY1bTG90D7;00001AB/
;B`iZTX^ETd00UH/158]00=B;U8]ERd015H]00EFCU9>DTiBCUI>00=B;PABCP=FC`03DTmF;eI>00=F
C@IFCP05FTeJ:eXZFRYJ2P03FPT2FPX00eH:FPYJ2P02FNT02UWZENYEjEWXFNMIj5WWFNQIjEWZ1EGZ
00QF2UX:GRUN:5h9GPQJ2EWY0UG9011EbUG8CLU=R4VXCJQ9ZDEW<<@/aSUZ@La63e9=ETiFKP9JKP9J
K`0;FTiJCeY?FTmNL5i=BN`/i0`010080003220222400`@Q2448@@0434400`Q1344<@@0334400``Q
244<@@0834400``P340<H@02464010aQ34488@Q11@a10Pa20`aR0Q1R01@<@PaR364<H@a2368<H@aR
344<811P364@HA1R488@PaB35:DDY12311BT0QBU00PHYART6:@HY1BT58@DY1RT0QRS00<La2469@H0
0R3500@LiQS56:DLa@8PiP067>@La1RS7<DLiB3U0b460RD60bD700<Q1b468>H00R3V00dU1RDV9BHP
iQS57<DPiBD5:BH]B2e7:BLYB002:BP03RTY;DXaJcF/>J`ic3F/<FTY1bd8<DTaJ35Y=HT2=HX01C5Y
;BLY1RD6:@H00bTW0RTX00@]:2dY<DTeJ@8eRP8eJP06=F/iRcV;?J/iRcV[0SF;01@aRSF:=H/eRcV[
@Na1kCg<?J/m[47<@L/mZcEY9>HPYRC5;DL]JBeX0Re801H]BBe8;DTaJSF;>J/eZcF;=HXeRC5Y;DT]
:2TX;BPaJ369<FLY9RCV:BL]A`<]J004;DPYB2U8:BP29@L29@H01RDV9BLU9b4X8@PPiP<Q1P038BHQ
1R4600<Q1`087>HHaQS67>HPiRCU8>HU1P8Q1P048@DPiQcV7>H27>D48>D011cU7>@La1RT0Qc40Qc5
0acU0R3U00/Ti23T8<<LXQRR9<8]9D7[FXaN/5ja00=N/P0:G[5J/UjbFY1R/6;AI]=Ve6KEI_D4I_@0
0f[cJ_AVl`02I_@3I_D00fKdI_=ZlP03I_<5I_@01FKCI]9Vd6[aI_800VKc00=VlVKcI_<016Kc00=V
lVKaI_801FKc00AVlVKaJ_9VdPYVlP03I_=VlVKb00EVlP9Vl@AVd@03J]5VdFKb00AVl@=VlP9Vl@03
I_9VlFKA00=Vl@9VlP03I]9VdFKB009VdP=Vl`03I]9VdFK@009Vd@04I]9RdV;BH]82I]45I]8016KA
I]1RdF;A1F;B0f;A0f;@00IVd6:`I]1Rd6K@H]42H[46H]000f:`H[5R/003H[05H[43H[000f:_H[1R
[`03GZl02F:^GZiNSej?GZiN[ej^HZiN[P02GZl00ej`GY1JS`02GXl4GXh015j^GZmN[ej_0ej^0Uj>
0Uj=0Uj>00=JSUY^FXh00eZ>0eZ=0UZ>00MJSEY^FViJKUY]FViJK@04FVh00eY]FViFKP02EVh00eY]
ETeFC@02ETd015I>ETeJCEI<0UI=00=FC5I=DTd0159=00=FC59<DT`0159<0di<0U9;1e8[00=>;58[
CR`00Th/00=B:dh[CP/00Th[0dh/00=>:dh;CP/00Th[0Th;00E:2dh;CP]:2dh;00=>2P03BPY>2TX:
00I:2P0:BNY5jDX9BPY:2DWZBPY:2dX:AP/3BPX3ANX00dWZBNU9j@02BNT6ANT2ANP4ANT01TGZANU5
jTGZALY5b@55b`0000DDZbT/>HY:;eI>009B;003DReB;U8^009B;P03DReF;EH]00=F;@03DTiBCe9>
00=BCP03DRiBCU9>009BCPIFC`=FCP03ETeFCUI>00=FC`03FTiJCEY;009J:P04FR]J2UX:FPT2FPX3
EPX01eGZFNUIjEGYENQIj5WW00=Ij09Ij@=EjP9IjP9J2P07GPUN25hZGRQN2Eh8GPT00eWY011EbU79
DLU=bDW:@HPe1RcV=DTmZdH>CRiBKeI_FVmJKP9JK`0;FTmJD5Y?FTmNKV9]BNd/i@`0000400022202
22422444344010Q1344<@@Q10`a100H8@@a124488@a134833680111R344@@@a00PaQ0a1R00<<HPQ1
34401`a100<<@PaR36800PaR0Pa200X<HPa2348<HQ1R368<@P`P464<HP8@HP03488@Pa2S008@Y003
48<DXaBT008DY08DY@036:DHY1RT00@HY0095:@HY1RS7<@LiB3U7:DLaARU008DY0066<DHaQS57<@L
Y1RS0Qc500LLiQd69@HU9bD69@LY1`049@L01ac67<DLaR3V8@LQ1R3V008LiP0;8>DU1RTW:DP]B35Y
=HXaJBe9<FTeR`02>Ld013g]?L`e[35Z0S5900/aBSEZ=H/iZcV/>HXeRS5Y<DP]B2TW008U1P06:BLU
1bT79@LY235:0SEZ00/iJSV;>J/m[47]@LdmZcV;>H`i[CW=00<eR`04>HXiZSV[>J`2?J`02cg<APi6
33g;>HXY:23W:BP]BBeZ;FT01C5Y00`aJS6;=JXeZcF;<HXaJS5Y;DT]:2dY:BP2;DP012e7;DP]Abe8
12eX00<YJBU9:DP00RD700<Q1b468@H00RDW00DUB2U99BPU1R3V00HQ1P058@LU9acW5:HHaP027>H0
123U8>HPiR470RD600LU1B3V7>HLiR3U8>HLiP028>D29BH00acU7<@La0027>H04Qc57>HLiAcU8>DQ
1B3U7>DPi1R26:8P`RdUAPaN[f;dG]=N/`9J/`=N/P05H[5RdFKBI]=Ve002I_D2I_@2Ia@3J_@2I_@3
I_D2I_@5I_<4I_@016KCI]9ZdV[a0fKc00=VlVKBI]8016Kc16Kb16Kc00AZlV[aJ]9VdPAVlP=Vl`=V
lP03I_=VlVKb00=VlP=Vl`9Vl@06I]5VlF[bJ_9ZdVKb0fKa0fKb0VKa0VKb00EVlFKbI_9VlVKa009V
lP04I]9VdFKBI]83I_<2I]85I]43H]82I]45I]8016KAI]1RdF;A1F;B1V;A1F;@00=RdF:aH[400f;@
00=RdF;@H]000V;A00=R/F:`H[000V:`16:a0f:`00=R[f:`HZl00f:_00AR[V:_GZmN/09N[P9R[P03
GZiN[ej_00=N/@03GY1NSej>009NSP03HZiN[Uj_009N[`03GZiNSUj>00=NSP06GXeNSUZ=FViJSUZ?
1UZ>0UZ=00=JKEY^FVh00eY^00=JKEY^FVh00eY^00IJKEI^EViFKUY]ETd2FTd01EI=ETiFCEY=ET`0
15I=1U9=1e9<14i<00=BBe8[DR/00U8[00=BBe8[CR`014h/00=>Bdh[CR/01Th/00=>2dh[CR/014X;
0Th;1Th:14X;00I:2TX;BPY:2dX:AP/2APX5BPX014X;BPY62TH:0TGZ0TG[00A5jTWYBNU9j@I5j@95
j0=5j@05ALU5jDGZANY5bP02ALT1AL/000055:/Y2cV:BRiFC@03DR`0158]DRiB;U8^0U8]0eH]00=B
;E9>DTh00U9>1EI>00AFCeI>ETiFCP=FC`AFCP9JC@0:ETiFCeY?FTmJCUY=FTYN:EXZFR/2FPX015X9
FPYJ2UH:0UX:00=J2EWYFNT00UWX0UWW00EIj5WWFNQIj5WY009IjP06FPUJ2UWZFPYJ2Eh90UhZ00AN
:EhZGRUN2@9J2@0AENYEje7:CLYEjUH<AJXmB347=DQ1ZdH>CPiBCeI_FVmJKP03FW02FU001UY?GViR
SDh^;@H<00<4008880888@05244<H@aQ364<@@022447344010Q122448@PQ1Pa100<@@11Q36400Q1R
00D@PPaR368<@@Q1008<@@03224<@@a1008<@@04464@HQ1R4684348236801Q1R368<@@a0360<H@8<
HP03468@PQBS008@X`0348<DXaBS00@DY08HY@8HY08HX`8DQ08DP`096:@HaAc558@@Ha2346<<HQ23
00<DY0036:@La1c5008Ha@8LiP038@HU1RD7008U1`06:BLU9bDW8@LLaQS50b3V00lHaAc68>HU1BT6
9@LY9beX<FTaJ358<DTaJCF9=HX00cVZ00<eRcF:=F/00SV;0SV<00Xi[3f[?L/i[3F;<FXaJBe9;DLY
1P8U1P039>HU1c5Y008eRP0:=FXiRcf[?J`mc47<?L`m[3f;>H/4=H/04CF:>HXeRSF:>H/eJSUZ?La:
;Th]@L/iRcEZ<DXaBC5Y<FX00c5Y00@aJS5Y<FTeRP<eZ`8eR`0:=FXaJRe9;DTY9bT7;BL]B2e7<DP5
<FP01C5Y;FP]J2e8:BL00RD700PPiRD69BHYAbeX:DPYAbD60R3V00`PiB3V8>DQ1BD58@DU9QcW6:HH
aQc67>H28>D01BCV8@HU1RCV9>D00R3U00XPiR458>HLiAc58>DU1RD58>DLi@@La@036<DLiAcU00<P
i@0:7>DPi1bS688LXRT4ANaRd6<DH]<3G[800ejaG]9Rd@02H]4016KAI]9VlfKe0fKd0VKc00=Zlf[d
J_<016[d00=Vm6[cJ_<00VKc00AZlVKbI_9Vl`AVm003I_=ZlVKb00=Vl`9VlP03J]9ZlV[b00=VlP04
I]9VlVKaI_84I_<2J_800f[BI_9Vl@02I_83I_<5I_801FKAI_9VlVKbI_<016Kb0VKa00AZlF[bJ]9V
lP=Vl@9VdP03I_9VlFKb00IVlP03I_5VdFKA00AVd@EVdPEVd@05H]9VdVKAI]5Rd@05I]84I]400f;A
H]9RdP02H]83H]42H]800f;AH]1Rd006H]0016K@H[1Rd6;A0f;@00=RdF;@H[0016:`0f:a00ER/6:_
HZmR[f:`00=R[`04HZiR[F:]HZh5GXh01Ej^GZmN[ej`G[400Uj`00=NSej>GXh00Uj>00=N[Uj_GZh0
35j>15Z>0UZ=1EY]0eY/00=JKEY/FVd00eY^00MJKEY/FVeJKEI^FVeFC@03FTd015I>ETeJCEI<1eI=
0e9=1e9<14i<00=BBe8[DR/0158[0dh/0Ti<00EBBdh[CR]>;4h<00=>;003CR]>2dhZ009>:`9:2`03
BPa>2dh;00I>2P03CP]:2dh;009:2`9:2P03APY:2TH:00A:2P06BPU:2TX:BP]:2TH:0dGZ0TG[00A5
jTGYANU9j@I5j@A5j004@LQ5jDGZANX3ALT1ALP1AL/000065:/U2cF:ARiBCTh/0Th]00=B;U8_DRh0
0e8^00IB;EH^DRiBCe9>DRl2DTl00eH_ERiF;@02ETh:ETl01EI>ETeJCEI>ETl00UY?00IJCUY=FT]N
:EXZFR/2FPX015X9FPYJ2UH:0UX:0UX90UWY1eWX1eWZ00AN2Eh:GRaN;0=N:`0EFRYJ2UH;EP]Ak5G[
DN]B2eH]AJTi9S46>FU1bdH>CPiBCeI?FVmJKUY`009JK`9JL006FU1RKVJ^DU0]1`P00P@00PPP00@8
@0Q12488@@<<H@043448@@Q2244634400`Q1344<@@0634400a1Q440@H00236800a1R488@P`033680
1`a1224480@Q244<@@aQ008@HP0358<@HPaR008<@P05344@HQ1R468<H`0436800`Q1368@P`0448<0
0aB35:<DX`025:@00aRT5:@DY0046:@01aRS48<@Ha2346<@PaRU008Ha@055:@@Q11T48<DQ0035:@0
0aRT6<DHa@026:D021S67>HPiR479BPU1bDW:BL2:DP02BDX8>LPib3V6<DDY1RU8>HU1`02:BL012DW
;DPaJ36:0S5Y0SEY00LmZcV:>HXiRSVZ>H/iRP02>H/01cV/?L`m[3f[?La1c3g<00<iZ`09<HX]B2dW
;BL]B35Z<H/eRcV/008iR`0??Ja1c47]@Ni1kD7^@L`iJRdY;DTeS35[;DXeJSV[008ic00>=H/]BBd8
<FXmk4X]@L/i[3F<=F/aBRe9<DTeRP@eR`08=J`i[3W<>L`e[3F;=FTaJ`8aRP08<FXaBBT7:@L]B35X
<FTaR@<eR@<aR@03;FT]BBTY008U:008:BLU1RDW:DTaRBU7:BHU1P<PiP047>HPiR459@D29BH031d7
5:HDQAc77>HPiR3U9>HU1bD69>HPi@<PiP089@HLiR3U6:@DPac59>DPi@8Li@037>@La1S4008Ha@8L
i@8Pi@0<8@DTiB346:<LXRCS@LYJ[UkcF[=N/Ujc0Ujb0ekB00ARdFKAI]9Vl`AVm004I_=W56KdI_@5
J_@01FKdJ_=VlfKcJ_<00fKb0VKc0fKd0VKc00EVlVKcI_=VlfKb00AZlP9VlP=Vl`9VdP03I_9VlfKc
00=Vl`03I_9ZlV[b009VlP=Vl`EVlP=Vl`MVlP9Vl@9VlP04I]9VlFKaI]42I]82I_83I_<01FKbI_=V
lfKbI_402VKB0VKb0VKB0VKA00IRdVKAI]5VdFKBH]83I]86I]43H]8016KBI]5VdFKA0V;B00=RdF;@
H]4016;A0VKA00=Vd6:`H]001V;A00ER/F:`HZmR[f:`00=R/@MR/09R[`=R[P9NSP03HZiNSUj^009N
[`EN/003GZmNSUj>009NSP=N[P03GZmNSUj>00MNSPAJSPMJS`9JSP05FVeJK5Y/FVeJK004FVd2FVh2
FVd00eI^FVaFC@04FTd:ETd015I<DTaBCE9=1E9<00=BCDi=CTd00Ti<00=BC4h/DR/00e8/2Th/1Dh<
00E>2dh[CR]>:dX;00=:30=>:`07CP]>2Th:BP]>2Th;BP/00Th;0TX:00=62dH:BPX014X:00A:2DX:
BP]:2`=:2P05ANY5jdG/AN]62`03ANX3ANT01dWYANU9jDG9ANY5jDGX00A5j@A5b@55k00000LDZRD;
>JY:;U9>CRaB;@02DRh00e8_DRiB;P02DRh01U8]DRiB;U9?DTiBC`9FC`9F;P9F;@03ETiFCeI?00QF
C`03ETiFCEY=00EJCP06FTeJBehZGRUJ2Eh92EX90UWY00=J25WYFNP00UWX00MMj5WYFNUIjUX:FPUJ
2P02FNX01UX9GR]N;5h/GR]N;0=J;004EP]F35G[EPX2DN/02e8<AJTe133U>DM1ZdH=DRiBCeI_FVl0
15Y^00QNK5Y>GVmRKVJ^DW0]1`P00P0000@<80a03408@@8<@@05360<@@a122088@0934401@aQ344<
@@a134800Pa100D<HA1P440@H0aQ008@HP8@P`07488@HPaR344880PQ24400Pa100H<HA1R468@PQ1R
368334824680111S36<@Ha1S0Q1R0a1S0Q1R0a2300TDXaBT5:@DY1BS5:@@HaB26:@00Qc40QRT00HH
YAB446<DYAc67<D26<D051RU48@@HaB46<DLaABT6:DLaART48@DY1c67>HQ1R479@LU:2D7:BP2;FT0
2BDX9@LU1b366:DDYB3V9@L]J@02;DP022e9<FTeRSF:<FTeJ3EY=HT3>HT2>HX013V[?J/mc47/0T7]
0T7<00A1bd7<@L`mZ`8iZ`07=J/eRC56=FLaAcF;>J`00cg<0Sf/0T7<01M1cD7^BRm5k3V[;BTY22dY
;DXaBSV;@Ne6;d7]>J`]:BSV;BPiZdG[?L/iRc5Z008aBP03<DTeRSV[008i[08iS08i[00@?Ne1kCV/
=HXaB35Z=H/iZc6:<FX]:2TX;DTaJ3F9>JT2>HT2=HT2<HT02BeZ;DTY:BTX9BLY9RD58>HU1P03:BH0
12D68@DLiQc60QcV00LQ1BD59BHYAQd76<HDQ0027>L01acV8>DU1R469@HQ1R3V008LiP0C8>HU1AcV
7<HHQ1B46:@LaB3U:@@Q1AcU7<@HXaB258<DXac47>@00b3U00`LaAc48<<Y0T79FVaNdUZbG[9Ndejb
G[42G[82H]800fKAI_5Vl`02I_<3J_<00fKdJ_AVm009J_@2J_<01VKcJ_9VlVKbI_=VlP9Vl`06J_=Z
lVKbJ_9VlfKb16[b0VKb0fKc00EVdVKAI_5Vlf[c009Vl`9Zl`EZlPQVlP05J_=ZlV[bI]5Vl@04I_88
I_42I_82J_86I_<00fKbI_5VdP03I]801FKcI]9VdVKAI]800fKa0VKb1VKA00EVdV;CI]9VdFKB00MV
d@9VdP03H]5Vd6KA009Vd@9Rd@03I]5RdF;A00=Rd@=Vd@05H[1Rd6;@H]1Rd@02H]800f;AH[5V[`02
IZl016:`H[5R/F:a0f:`0V:a0V:`16:_0f:^0ej>00=R[Uj_G[000Uj_0Uj`00=N[ej>GXh01Ej>0Uj^
35j>15Z?0eY_0UY^00=JKEY/FV`01UY/00=JKEY^FVd00UY]0UY/00AJKEY^FVeFC@9JC@03ETaFCEI=
00EFC@03ET]FC5I<00EBC@=BC0=BC@03DTa>;58[00AB;004CRa>:e8[DR/9CR`014h<CP]>2dh[1Dh;
14h[0dh;0dh:0Th;00=:2dX:BP/01DX:00=5jTX9BPX01TX:00A:2dG[AN]5j`=5jP07ANU9jDGYBNU5
jDWXALP00TG90TGY0dGX0dG80DG90DG/00001aBY9@/eR4G/CRe>3Dh]009B;P03DRmB;U8^00=B;P9B
;`03DTmBCU9?00=FC`05ETiF;EI>ETiBC`09ETl2ETh00eY=FTiJCP03FTh01EY=FR]N:UhYGPT00Uh8
00=N2Eh8GPP00UX900EN2UX:FPYIjEX9009Ij@9Ij0=Mj003FNUIjUX:00AJ2P06FRYJ;EY=FTiNCUh^
0UX^01=J;EH]FR]F:UG[DN]F34h<AJTi9CD5=BI1ZTG]CPiBCUI>EVmJKP03FVl02ei]GTeNKV9]HXeB
Cbd6200000@032000Pa000<<@@a236801@aQ0`a100<8@@a134400Pa10PaR1@a20PaR00@@HA10460<
H@8@HP07488@Pa2348<@HPa232401@a1111R00T<@PaR368@Ha1R46<@Pa2448<00Q1S0QB300DDQ1B3
56<@HQ2300LDY00458<@HQB36:@47<@00ac57>HLi`027>H00acU7>HLiP027<H27>H57<D00b358>HL
iP027>H011d78@LQ1b470RDX01@YJRUY:FXU:2477<HPiRD7:@LY:36;<HXaJReZ<HXiZcF;<FTaB3EX
0SF:00@iRSV9=FTeRP8i[091k@03ARm63T7=0091c091c@91c00F@L/mk47:>DHiJ3V:@Le63d8>@Nhm
kSg>?J`iRcV<?H]1kTH>BRe1kCF;>H`2?Jd05Cg=@Pi:;dY@ARhmkCEZ;>HeBCV[@N`mc3F;>H/i[3V<
>H/mc47]@Nhmc@03?L`03Sf/>L`iZcV;=HXeBCEZ>H/iZcF;=FXaJBe9<FX2=HT5>HT033F9<HXaRS5Z
:DTY:2DX:BLPiAc58>DU1P8U9`038BHQ1R46008LiP067<HQ1RDV9BHYAad70ac600TLiacV8@HU1bDW
9BHU9bD68@L00R3V00<U1B3V8>H00QRU00HLaR3U8>DQ1B467>D27<@01A1R464DXac47>D00b3U00LL
aAS58><Y0T79GXaN/002G[801ekCG[9N/EjbG]9Rdf;B00AVl`9Zl`05Ja=Zlf[dJ_AVm004J_@00f[c
J_AZm002J_@3J_<01V[bI_9VlVKcJ_=Vl`9VlP04J_9VlV[bI_<3J_<2J_82I_82I_<01F[dJ_=ZlV[b
I_800fKc00=ZlfKcJ_<00fKc00=Zlf[bJ_801F[b00IVlf[cJ_=ZlV[cJ_84I_800f[bI_5Vl@02I_42
I_800fKaI_=VlP02I_87I_<2I_87I]82I]42I_400fKbI]9Vd@02I]401FKaI]9VdFKBH]<00fKB1fKA
00=VdV;BH]4016KA0V;A00=VdF;AH]400f;A0VKA00ERdF;@H]1RdF;@00ARd@=V/003IZmV/6:a00=R
/@03H[1R/F:a009R/@9N/003H[1R[f:_009N[`=N[P9N[`MN/003GZiNSUj>00=N[PUNSP03FXiNSUj>
009NSP03FXeJSeZ?00=JS`9JK`9JKP=JK@9JK004FVeJK5Y]FV`8FVd00eI^ETiFCP02ETd00eI<ETeF
C@05ETd3ET`00eI=ETaFC002ET`02E9;DTaBC59=CTeBCE9<CRaB:`06DR`00e9<DR]>;006CR`2CRd2
CR`2DR/2CP/00dh:CP]>:`05CR/2BP/00dh:CP]>2P03CP/014X;ARa62dX;0TX:00=>2dX:BPX00TX:
00A62dX:BPY:2@9:2P=5j`03APY5jTGZ00A5j@03ANY9jDGY0095jPA5j@03ANQ5jDG90095b@51b`00
00P@RBCZ=FM1bTh]CRa>;E8]1e8^0U8_00EBCeI>ETiFCU9>00AFCP03DTiBCeI?00MFC`=FCP9JC@AJ
CP04FTeJ:eXZGRX2GRT4GPP00eh:FPYN2P02FPX015WZFNUIjEWY0eWX0eWY00=IjUX:FPX00UX:00=J
:UX[GTd00ei=15X]019J;5X[EP]EjU7:ENYB34FY?BH`a33U@HU5kE8=DTeJKEI^FVh3FVl02eY^FTiN
CEi<HXeBCc4V324000P032000Pa000/<H@aR344@H@aQ368<H@aP34488@Q100@<@@8<H@8<HP<<@P08
368@HPaR348@@A10340@H@8@HP0<48<DPa23488@HPaR340@@0a0344<@0aQ0Q230Q1R00@@Ha1R468@
HP8DP`0:58@DPaB346<DPaBT6<DHXaB346<35:@011B3568DXaBT0QRT00<DPa236:@00Qc500hLiBD5
9BHY9R467>HLa2CT7>DLiR3V:@HY9RD50R3U00HPaBCU9@HY1RCU8>D27>H04Ad78@LQ1b479@PU:2TY
;FTaRbU99BPY:2dX;DP]Ac5Y<HX00S5Y01@aJc6:=HTaJRdX;BLaB3F:>HXiZSV8;@H]:3F;>J`mcD7<
@Ni1kCg=147=01M1cT7]BRi>CdX/?JPmRCf[@Ja1cD7>?Nm1kd8@AQ11kcV]>Ha1cTH>DTe63Sg=0091
c@0;@Ni1cD7]BRi6;TX^@NdmZcDW>HXi[002@Nd01D7<?L`mcCg=@Ld00T7]00XmcCg<?J]1bcfZ?J/i
ZcV:=HXeJ@8iRP07>J/mbcV[=HXeJS5Y<HT00SF90cV900PeZCVY=HXaJReY;DPY:2TW0RD700DQ1bD7
9@LU1RD7008U9P8U1P049@LQ1RD78@H29BH01RU78@HHaARU5:@LiP8Q1`069BHU9bTV9BLU9RD70bD6
00DQ1R3V7<HLiR3V008Pi@037>DLaAc400HLa00<7>DPiB3U8>@PiAS48><ThD79GZeR[f;B0ejb0Uja
00ARdV;CH]=VdP9Vl`06I_9Zlf[bJ_9Zlf/C0f[d00=Zlf[dJa<00V/C00=Zlf[dJ_@00f[c0f[b00=V
lVKcJ_<00f[b00=VlV[bJ_801F[b00=VlV[bI_<00VKb0V[b0fKb00IVlf[cI_=Vlf[cI_82I_<00f[c
J_9ZlP02J_82I_401F[bJ_=Zlf[CJ_<016[b00AVlV[bJ_9ZlP=Vl@03I_9ZlVKb00=VlP9ZlPIVl`9V
lP04I]9VlfKcI]82I_<2I]84I_45I]45I]8:I]42H]4016KAH]5VdFKA0V;A1VKA00=RdF;@H]0016;@
0V;A00AR/FK@I]1Vd09V[`03H[5RdF;A009R/@03H[1R/F:a00=R/@9R/003HZiR[f:_00AN[`03GZiN
[ej`00IN/0AN[`03GZiNSUj^009N[PINSP06FXiNSUj>GXiNSEZ=0UZ>15Z?00AJKeY^FXiJS@9JK@IJ
K004FVeJK5Y/FVd2FT`00eY/FV]FKP02ETh015I=ETaFBeI<1UI=00=FBeI<ET/015I<0UI;00QF:e8/
DTeBCDi=DRaBC58[1e8/00=B:dh/CR`024h/0dh[00=B:dh;CPX00ThZ0dh[00M:2dh[BP]:2dh:CP]>
2P03CP/2BP/00dX:BP]>2P02BPX00dX;BPY:2P04BPX2BPT01DGYANY62TGZAPT00TGZ1DGY1dGZ00=5
jDGXANT00dG90D7;00001Q298<TeIdG[DReFK@9B;@EB;P05DRmB;U8_DRmBC`02ETh2DTh5DTl2DTh9
ETl3ETh3FTl025Y>FTeJ:eX[FRYJ;5X;FPX3GPX2FP/01eh;FPYJ2UX;FPYIjEWZ00AIj@=IjP07FPYJ
2eX:FP]J:eX/FTh00Ui>00=N;UX^FPd00UH<011F;EH[EN]EjU6YDLY=jdFY>BH/a33T@JY5kDh=DRaF
C@9FK`03EW1JL5Y`009JL00>GViRKF[?EW0iAa0Q10040@a0344<HQ1R48<<@@8<@P8<HP03364<@@a1
00D<@@04364<HQ2348@43680111R368<@Pa10Pa000<@HA1R58<00Q2300@DPaBS58<@HP8@@@04320@
@@aQ468248<25:<00aBT58@DP`0358<02QB45:@DY1BT6<DLiQSU5:<DPa1S0aBT00D@HQR27<@LiAS4
008HY@036<DLaAcV008Li@078>DY9RTV8@HPiAc48>D00QcV00TPiRD6:BLY9RD58>DPiRD69BL00RD6
00@PiQcV7>LM1`@Q1`039@LU9bU8008aR`06;FX]BBe8<FTaJS5Y0c5Z018]BC5Z=HXaJRe9<DPeJCV:
>J/mc3f[>FTaBC5Z>H`i[Cg<?Lh3?Ld06Sf]@Le1cT7^APi:Ce:@EXi63CfZ>FXmS47<@Ni244H`BU9:
<T8A@O0mkdH@BRmBKTH`@Nh2@Nd0147^?Le1kDH=0TH>00E1kCf/=DTiRcV/008mc004@La1kDH>APl2
APh01D7]@Ni63D7<@J/00Sf;00DeRSEY=FTiRSV;008i[005?L/iZcV[=H/eRP04=HT3=JX01CF9<FX]
JRe9;DP00RD600DY9be8;HXaRBeY00<Y9`079BLY9bD69@LPiR3W9@L00bDW00LU1R3V5:@DQ1S68>HQ
:0029BL00bDV9BLU9P029@L012DW9@HQ1QcV0R3V00<Q1B3U7>D00Qc50Qc400<Li1cU7>D00Qc41AcU
00LHXac29@91bUj]I_5VlP03G[82G[4016;BH]=RdfKC0fKc00A[56[cJ_=Zl`IZm007JaAZlf[dJ_AV
m6[cI_<00V[c00MVlfKbI_=VlfKbI_=Zl`02J_82I_82I_<016KbJ_9Zlf[b0VKb0fKc1FKb00=Vlf[c
J_<01VKc0f[b00EZlf/CJa=ZlV[c009Vl`AVlP03J_9VlV[b00=ZlP05J_5VlFKaI_=VlP03I_<01FKb
I_=Vlf[cJ_800fKc00EVlVKcI_9VlfKb009VdP05I_=VdVKBI]9VlP06I_43I]43I]83I]400fKBI]5V
d@04I]42H]43I]43H]43I]45H]42I]42H]4016;@H]5R/F;A1F;@0V;A00IRdV:aG[5R/F:bH[42H[80
1EjaH[5N/6:_H[000V:_15j_15j`00EN[ej@G[1N/5j_00=N/004GZmN[Uj^GZh3GXh4GXl3FXl00eZ>
GXiJS@02FXh3FXl2FVl4FXh4FVh3FV`4FVd01EY<FVaJK5Y/EVh00UI>00AFCEI<EV]FC0IFC@04ET]F
CEI=ETd3ET`2ET/00eH[DTaBC@02DTd00e9<DRaB;007DR`00e8[CRa>;00;CR`2CR/2CP/3CR/2BP/0
0dh[BP]:2`02BP/4CP/2BP/01DX:BP]:2dh:CPT01dX:00M:2DX:BPY62TX:ANY62@03ANX5ANT7ANX3
ANT2ALT1AL/0000448XPbCEWAN/2DTd0158]DRiB;U8^0e8]158^00AFCeI>ETiBCPIBC`03ETmFCUI>
00EFCP=FC`9FCP9JC`=JCP03FTeJBeX/009J;00:FPaJ2eh;GR]N2eX<FP]N2eh<FP/2FPX2FPT5FNT0
15WZFNUIjUWZ0UX:00MJ2eX/GReNCEh^GReF3002CJ/04e7/EPaF:eG[DNY=bE7ZDPa5bSe8<>Ha1D6Z
ANa>3E8/ETaJKUY_00=JL00;FW5JD5i^HVeV[eI`>DH@80@0204<@@043683348236800`a2344<@@05
34433642368446801@aR344<@0`P3440111R00H@Pa225:8@PQ1R3442220010a1444@HQ2211BS00<D
PaB458@011B400HDY1S57>HQ1QSU6<@358<01aBS5:@HY1RR8><Ha1c4008Ha@057<DLiQcV7>DLiP02
8>D02BD58>DLiAS558@HYAc58>DU1@02:BH012DV9@HU1RD60RTW00@U1b3W8>HPiP8Q1P0<8@LU1bD7
9@HPiRTW:DP]B2eY<HTeRS6:0c5Z00DeJSF:=HXeRcV:008eJP04>H/eRSF:>H/2?J`013V<>H/eS3V/
1Cg=00@m[3V;@La5kP91kP0JBRm>L5J>BRi5k3f;>H`m[4G]@Pi63dH@AQ524DHAAQ1:<4iADVm:;dH?
@Pi5kD7]@Li5kP963P0<APe1cCV;>FXaBSEZ>H/mc47<@Ne63DX?0dH>00E:;TX]@N`mZcEZ008aB@03
=FTiRSVZ00<i[0<iZ`06>HXeRC5X<FTeRCVZ0SW;00<eZSF9<FT00Re900l]B2TX;DP]B368=JXeZC69
<FP]B2dW:BLY9RD79@H00R3V00HQ1bD79BLY9bDW9@L38>H01B469BLY9bDW9BH00RDW0RDV010U1R46
8>HPiR3U8@DU1B457>DHXaB36:<La2T48@DLi@8Li0037<@Li1c5008La0068><P`RT3@N]N[F;@0Uja
00ER/UjbG[5N/F;B009Rd`9Vd`9Vm003JaAZm6[c00UZm0=Zl`03J_9Zlf[c00QZl`9ZlP=Zl`9Vl`05
J_9Zlf[bJ_9Zl`05I_<00fKbH]5VlP03J_<4I_<00f[cI_=ZlP05J_4=J_8016[aJ_1ZlF[a0fKb0VKc
00MZlfKcJ_=Vlf[bI_=Zl`03I_<01F[bI_9VlFKBI]4016KB00=VlV[aI_401FKa00IVdFK@H]5VdFKb
I_42I]400fKBI_5VlP02I_83I]43H]47I]47H]401fKAH]5RdF;AH[1RdF;@00MRd@05H[1R/F:aH[9R
/@02H[83H[42H[03HZl00ej_HZmR/002G[02H[0016:_H[1N/5j`0Uj_00=N/5j_GZh00Uj^15j>00=N
Sej_GY000ej@0UZ?00INSUj=FXeJSEZ>FXl2FVl01EZ>FXeJSUZ>FVl015Y^0UY]25Y/00=JKEI=ETd0
0UI=00=FC5I[ET`01UI=00=FC5I=ETd015I=0UI;00=F:e9<DT`0159<00IB;59;ET]FBe8/DT`3DR/2
DT/2DR/9CR`00e8[CR]>:`06CP/00dh[CPY>2P05CPX00dh;BP]:2`04BPX00dX9BPY:2P07BPX01DX9
APU:2DH:APT00TGZ00=5bDGXANT014GY1DGZ1DGY0DWY0DG;00001a299>XeId7;CReBCE8]009B;`09
DTmFCU8]DReFCU8]DRmB;UI?009FCP03DTiBCe9?00ABC`03ETmFCUI?009FC`=FCP=FC`04ETiJCeY?
FTl4FTh2FT`015X/FPaJ35X<0UX[00AJ2UX;FPYN2`9J2`9J2P9J2@03FNUIjUWZ00=IjP03FNUIjUX9
009J2P0JFRaN;5h/GTeNCUh^FReEjeG;EP]J;EX[EP]EjUG[DN]F34W[@FPe1S46@HU5kDh=EReJC@9J
K`9JL009FW5JL5Y?GViRKF:=FW0iAQ@P00840003344<HPaR00L<HP04364<@@a13442244234400`aP
364<H@073680111R344<HPaR0a1R00<<HQ1S58800QB200<@PQ1R36<00PaR00D<HA1Q488@PaBS008D
P`0758@DY1BT5:@DQ1BT58@00QRT00DDY1S57>HLaABS00<DP`055:<HY1bS7<<Pi@037<D01acV7>DM
1QcU7>HLaQcU008Pi@087>DHaAS57<HPiRD5:BHY9`8]B0DY9`0<:BPU:2D89@LQ1bDW8BLU1RD79>LP
iRTW0bU800<YJBeY<HX00ReZ0S5Z00@eRSF;>H/iRP8iR`<iZ`0N>HXiZcV/=H`eJcV/?L`mcCg^@Nhm
kCg=?J`mRd6/?Le1cD7^APm:;dh^CTm:3D7=>F`m[DG]ANi63TH?0TH@00E:<DYACU5:LDX_00963`05
@Pi63TH>ANi63P02BPh01DX=APe1c3g<@Ld00T7]00A63TG]APi63@9:3P=:;P05APhmkCF<=F/iR`02
=FX00cV[?L`mc@04?L`033V[>HXeJBe8=FTeRSVZ>L/aZc6Z<HTaJ@8]B@0:;DP]BC5Y<HTeZCFZ>JXe
ZS5Y;DP3;DL3:BL00bD79BLYA`02:DP01BU79BLU9bD69@L00RDW12TW0RDW00<U9R468@H0123V00TQ
1RDV7>HHPaB268<Pa2T48@D00QcU1Ac400dPi2CS9<8Thd7;GZiRdEjaG[9R/UkBG[9NdP03H]<016KD
I_AVm6Kd0f[d0f/D0V[d00=[56[dJ_@016[c00YZlV[cJ_=ZlfKdIaAVm6/CJ_=[4`AZl`03J_9Zlf[c
00=Vl`9Zl`03J_9Zlf[c009Vl`03IaAZlfKc009VlP=Vl`=Vm004J_=Vlf[bJ_83J_42J_8016[cJ_9V
lfKc2F[b0f[a0VKb1fKc00=ZlV[cJ_8016Kc00=VlV[aJ_800VKB0fKc0VKb1VKa0VKb0VKB0VKb00AV
dFKBI_9Vl@=VlPAVd@=Rd@IVdAERd@ER/@=R/P03H[5R/6:`00=N/0=R[`04H[1N/5jaG[03H[02G[00
15j_G[1NT5j_0Uj^1Ej>0Uj?0ej@0eZ?00EJSUj>FXeJSEZ>00AJK`03FViNKEY]00EJKP=JK@03FViJ
KEY]00=JK005FVeJCUY=ETeFKP02EVd00eI[ETaFC@05ETd00eI<ETeFC@05ETd00eI;ETaBC004DT`0
0eI<ET]FB`02DT/0159<CTaBBe9;0e8[00=B;4h/CR`02Th/00=>:dh;CP/00Th[0Th;00=>:dh:CPX0
1Dh:00=>2dX<BR`00dX;0dX:00=>2TX:BPX01DX:00=:2DH:APX00TH:00I62dWZBNU9j4GYBNT3ANT4
ANX7ANT1AL/0000748TTbCE6?JY:;59=DRd00U8_00=BCeI>ETh00UI=00=F;59>ETh015I>00=BCU9?
DTl00e9?00=FCeI>ETl00UI?0eI>00=FCeI>ETh00UI>0UY?15Y>0UY<0eX[0UX;00MJ2Uh9GPUN2Eh:
FP]J2P05FPT00eWYFNYIjP02FNX2FNT015X9FPYJ2Uh;0Uh/00=NCEi>GTh00Uh^01ANCUh]FReJ;EX:
FPUEjU7[GTaF2TFZ>BLe1T6YANe>3EH]FViJKeY^1EY_00INKUi<HXiN/4685442100010a1368<HPaR
10a100<<H@aR36400`a100D880@P244<@@a000D<@@04244<@Q1R48<346800`aR468@HP023480111S
58<DPaB30a230Q1S00D<HQ1Q468@PQ23008DP`035:<DY1B3008DP`085:@DXaRT58@@Q1BT5:DDY08D
P`8DPP03584HXabS008Pi@0;7<@LaAc57<DPiB467>DLiQRU58@La@027>D01QcV8>DU1BD59@HY9P@Y
9`03;BL]AbTW008Y9`8U1`8U9`<U1P<TiP039@LY9bTW008YB007:FTYB2TX:BP]BC5Y=HX00SV;0Sf[
00Xi[3V[>LXiZSV[>H/aBBdY<DXi[08mc08mk@0:@N`mcCf/>H/iJcV<>H/mZcg<@Nd3APd02DG^?He1
cD7^@Pi63TX?AQ16<002BRl01Di?BU163cg^@Nh00dH?0dX>00E>3E8]CRi:3DH=00963P=63@03@La6
3DH>00=:;P06APi63D7^>Jdm[Cf/0Sf[00@m[3g<?L`mk0923@06?L`ibcF:<FTeRSV:0SF:0c6:00<a
J2eX;DP00ReY0S5Y00PaJ3W9>L/iZC69<FTaJ3571Be700HYAbU6;FD]IbeX:DL2:BL01RDV9BLY9bU7
;FLYA`<Y9`039BHY9B45008Q1P8PiP098@LU1RDV8>HLaB357<DLiBD4008Li@036<@La1c400@La007
7<<PXRT3@LYN[V;BG[800V:b00AN/V:bH[9R/P9Rd`03H]AVm6Kd009Vm003J_AZlf/C00MZm0AZl`07
J_9[4f[cJ_=Zm6KdJ_@01f[c00=ZlVKbJ_801F[c0f[b1FKc0f[c00EVm6[cI_=ZlfKd009Zl`AZlP=Z
l@9ZlP9Vl`AZl`9ZlP03I_5ZlV[b00=Zl@04I_5ZlV[bI_85I_<3J_801fKbI_=VlfKcI_9ZlF[B00=V
lP04I_=VlVKbI_85I_4016[aI_5VlFKa0VKA00MVlVKaI]5VdFKaI_9Vl@03I]4016K@H]5Rd6;A2VKA
0fK@1f;A00=R/F;AH]4016;A00ARd6;AH]5Rd09R/0AR/@03H[1R[f:`009N/0AR[`03G[1N/F:a00=R
/003HZmN[ej_009N/003GZmNSUj>00MNSP04GY1NSej?GXl2FXl01UZ>FXeJSEZ=FXiJKP=JK`03FViJ
KEY]00EJKP=JK@03FViJKEY]00=JK005FVeJCUY=FVaFK@03FV`015I]ETaFKUI^0eI=0eI<1EI=00=F
BeI<ET`0159<159;00=B:e9;CT`00U9;0e8[00=B;4h/CR`02Th/0Th[00=>;4h[CRX00Th[00=>2dh:
CPX014h:00A:2TX;BPa:30A:2`Y:2P05BPU:2TH:APY:2@02ANX014GYBNU9jDWY14GY0TGZ00=5jDGZ
ANX00TGY0TGX0DWX0DG:00001a298<PaAT7:DRa>;58]00=B;`03DRiBCU9>00=BCP03ETiB;EI>009F
CP03ETmBCe9?00=BC`IFC`9FCP=FC`=FCP=JC`=JCP03FTeJ:eX[00=J2`05FPYN2EhYGPUN2P02FPX4
FPT00eWYFNYIjP04FNX2FPT2FPX06UWZGRaNCUi>GTmNCUi?HViNCei=GTiN;EX/FRYEjUG[FT]J:dg[
>BLe1T6Z@Ne:3E8/ETd2FVl02eY`FW5JLEYaFW1NKei<IZmNT4FY76800PP00`a100<<@Pa134400Pa1
00@<H@aR364<H@/<@@05348<HQ1R468@P`08468848<24680111Q468@HQ2321B300@DXaB348<<P`8D
Y00:4:@DXaB3488DPaAR6:<La2458@H47<D0123U7>DLiAS50QB400<LaAcU8>D00b4600@U1RD7:BLY
9`8Y1`0>:BLY:2U7;DT]B2TX9@PU1bDW9BPU9bD69>HTi`<U1`04:@LY:2U8:DP4:DT052e9<FTaJSV;
>Ja1c3f[?J`ic3W;>L`ibcV[=FXaB35:>Ja1k3g]?N`2@N`01Sg<?L/eJSEZ=H/i[08iR`07@Ne63DG[
ANa1c47=@Lh00TH?0TX_0dH_0dX_00M63T8>@Ni23TH>ARm:;`02BRh03e8^EVmBKdh]CPe>;Di>CRe:
;TX>APi63dH_BRm:C`02ARl00dH>?Nhi[002?Ld2?J`023g<@Na1kD8>AU1:;d8>?L`2>J/2=JX00cF:
<HTaJ@02;FT3;FP022eY<FTaJC69=JXibSFZ=HT2<FT3<FP012eX;DP]Abe80Re700@]Ic69;HPYB0<Y
9`0<9BLY9bU7;FL]J2e7:BLU9RDW:DLU9b460RDW00HQ9b478@HU1B468>H29>D28@D37>D031cT7<@L
a1c47<DLXaRR7:8XhT7:GZaRd`9N/P03G]9Rdf;B009R/P9Rd`03H]AVm6Kd009Vm005J_AZlf[dJaAZ
m003Ja@3J_@2J_<016[dJ_=W56/C26[c00=Vm6[dJ_<00VKb1F[c00AVlf[bJ_=ZlPAVl`AZl`03I_AZ
lf[c00=Zm0=Zl`EZlP9Zl`04I_=ZlfKdI_<2J_<01VKcI_9VlVKaJ_9Zl@=ZlP03J_5ZlVKc00EVl`05
I_9Vlf[bJ_9VlP02I_<00fKbI_5VlP03I_85I_<2I_800fKaI]5Vl@02I_400fKbI]5Vd@05I]4016Kb
I_5VdFK@16KA00=RdFKAI]401FKA00=RdFKAH]400fKA26;A00AR/F;AH_9Vl@ERd@04H]1R/6:`H[44
H[0016;@G[5N/Eja0Uj`0V:`00AN/5jaG[1N/09N/@9N/003GZmN/5j@00MNS`03GZiNSej?00ANS`UJ
S`9JSP9JKP03FVeJKUY^00MJKPEJK@05ETeJKUY^FVeFK@02FV`00eI/EVeFK@03EVh2ETd8ET`01UI;
ETaFC5I<DTaB;09BC09BB`9B;005DTa>C4i<CTaBB`02DR/00e8/CRa>;@07CR`024X]BRa:;4h/BRa>
;4h[CRX2CR/00dh;CPY>:`02CR/2CPX2BP/2BP`01TX;CR]>:dh[CRY:2`9:2P05BP]62dH;AP]:2`02
BPX2AP/00dH:BPY62P02BPX5BNT2ANT5ANX3ANT1ANP1ANL1ALT0000746PPacE6ANUJJe9=DRd00U8_
00=BCe9>DTh0159>1EI>0UI?0e9?1eI?00=FCUI=ETh015I>00AJCeY>FTiJK`=JCP04FTaN:UXZFRX2
FR/00eXZGRUN:@05GRT6FPT01UWZFNUIjEWYFPUIj@9IjP03ELYN;5i?00=RK`9RKP04GTiNCEh]GT`2
FR/03eG[EPYF2UH:ALXiB3D4@JU1k4X=DRaFCEY_FW1FL@03FW402UY`GVmNC6J^ETm1Z1b2200<811Q
1`a10PaQ00P<H0a0340<80a0344<HPa20`a100<88@a134800Q1R00H@PQ23468<HA1Q468348801123
58<DPaB30a2300<DPa2358800Q1Q00<<HA1S48<00Q2321B300H<HQ1R5:8DXa2448<258<01Pa1444H
Xac57>DHa08HY@8La@<Li0076<@@Pa1R6<@LiB458>D00b4600<U1bDW8@L00RD70bTW00<U:2TX:BP0
0RTX00D]B2UY:BPQ1RD6008U2007:BPY1b3V7>HU1bU8:FX012eZ00DaJC5Z>H/m[3g;00<mc00S>J/m
bcg;?L`iZcEZ>F/mc4H<APe1k3g;@LXmZSg:?J/mc3g=@L`m[3g=@Na:34G[ANa1k4G^@Ni23d7_APm:
3U9>CTm:3P02APl01dX_CTi>;dH>@Ne>;E9>009FL@07EY5BKe9?CRm63U8^FXh00UZ`00EBCdh_BPm:
3diA009>L@04DW1:DDH_@Ph2@Nd01cg=?Ja63DX_APe1k4H^009:C`09ARlmkCg=?Ne23Sg=<HTeZ2eX
008]B@04;FT]J2eX;FP2<FP06SVZ?N/mbSF9<FPaB35Y=HTeR35W<DH]Ac5X;DL]Ic5X;FLYIbeW;FPY
AbTV9@HU9RU7;FP2<HP01cF8<FP]9bD7:BL]J2U800<U9`8U9P039BDQ1BD6008U1@8Q1@047>DPiAcU
7>@37<@021c37<@HXb33:>51bF:/H]82G[82G]800f;AH[9RdP02H]<4I_@4J_@4Ja@7J_@016[cJaA[
4f/C16[c00M[4f[cJ_=[56[dJaA[4`04J_<00fKcJ_=Zl`03J_<00fKcJ_9Zl`03J_@3J_<5J_@2J_<4
J_8016[cJ_9Zlf[c0fKc0f[c00IVlfKbJ_9ZlVKaJ_45J_800f[cI_=Vl`03I_<5I_82I_<6I_85I_<5
I_82I_42I_87I]42I_43I]400fKBI]5Vd@09I]401F;AI]9RdF;AH]800V;A0V;@0f;A1V;@0f;A00AR
d6:aH[1R/0=Rd09R/006H[5N/5j`G[1N/F:a1Ej`0eja00AN/6:_H[1N[`=NS`05GZmNSej?GZmN[P05
GXl3GXh00eZ>GXmJS`04FXl01EZ>FXeJSEZ=GVd00UY]1eY^00QJKEY^FViJKUY]FViJKeY^1EY/0UY[
00=FKEI^EVh00UI=0UI<00=FBeI[ET/01EI;1EI<00AFBe9;DT]B;09BC003CTeB;59<00=B:`05DRaB
C4i=CTe>;@02CR`00e8/CRa>;005CR`00dh[CRY>:P02CRX2CPX014h;CR]>2dh:14h;00A:34X;BP]:
2P9:2`03BPY>2TX;00=:2`04AP]:2dX:BPX2BP/014H;BPU62DX81DWY00=9j4GYANT024GY0DGX0DWV
0DFX00001a1X7<LeATGZFXaFSU8^009B;`03DTmBCU9>00]BCPYFC`03ETiJCEI>00=FCP03ETmFCUY>
00IJCPEJ:`03GR]N:Uh:00EN:@03FRYJ2EX9009J2@9IjP05FNUJ2EWYFPUIj@03FNX015h]GW1NKf9`
0V9_00IRKUi>GTiNCEi;FR/3EP/03E7ZEPU5bSTX=@I1RT7/BPeB;5Y=FVmFL5Ia00AJL@09GW1NCF:^
EVlmZQRT2008811Q00L<@@033488H@aQ008<@003320<@0aR00<<HP8<@P<<HPD@HP03368@HQ1R00<@
HP<@P`8@H`8@P`06488DPaBS588@HA1R1A230QB30QB411B300<DQ1BS5:@00aB300DDHa1R588DXaBT
008Ha00=6:@DXaRT7<@Li1cU8@DLiART68<La1cV8@D0124600<Q1b4W8@L00RD700<U9bTW9BL00RDX
0RD800D]B36:;H/Y:BD700<U:003:BPY9bDW008U1`0::BPYBBUZ<H/e[36;<FXeRcV<@Nh2BS004T8>
@Ne1c3g<@Ne63TH=@L`m[47/BRi6;TH=@N`mbcfZ?L]1k@9:;`04ANi1cD7=@Nd2ARh02TX_CU1>DE:B
DW963d7]BRmFKdi@0TX`015BD5JAEY1>D4G^@Le:;UI`G[5RlekCF[9FLE8`BRmB;eZ?009N[`09G[5J
/EZcEY5>LE9bDY9>LTiB009>D@03CS1:;dX?009:;`0A@Pe1k47]@Ne23T7]@Rm6<3h?>N`ikCh>?Ndi
bc69;FTaRP02=J/02SVZ=JXeRSF9>JXmjcg;=HTaAc4V0S5700HaIS57=FLiRCW;>L`2>L/01cFY<HTe
R369<FP]J2U800<YA`04;FLYAbDW8>H27>H012DX;FP]J2eY0ReX0bU700/Q1R3V9@HU1B468>HQ1QcV
7>DLa1c3008La00:8<@La1RS8<<Y0d79GZaRdUjbG[<2G]<00ekBH]=Rd`02H]<5I_@3J_@016/DJ_A[
56/D0V[d00=[56[dJ_@00V[d0f[c0V/C0f/D00I[4f[cJ_=W56[cJa@2Ja<9J_<00f/CJ_=Zl`03J_<0
0f[dJ_=Zl`06J_@00f[cI_=ZlP02J_8016[cJ_9Zlf[d0VKd00EVlf[cJ_=Vlf[c00EZlP9Vl`03J_=Z
lV[b009Zl`IVl`=VlP=Vl`EVlP=Vl`03I_9VlfKb00AVlP03I_=VlVKb009VlPAVd@04I_5VdFKAI]84
I_83I]43I]86I]46H]400f;@H]5Rd@03H]4016K@H[5R/F;A0f;@1F;A16;@16:`00=N/5jaG[000ej`
00=R/5jaG[400Uja00EN/5j_G[1N/5j_00=NS`=N[`04GZiNSej?GY02GXl4GXh00eZ>FXmJS`03FXl0
15Z>FXmJKUZ>0UY^00=JKEY^FVh00UY^00AJKeY^FViJK@=JKP9FKP04EVmFKUY]FVd3FV`2FV/00eI]
EViFKP02ETd2FT`00eI;EV]FB`04ET/6ET`01eI;DT]BBe9;DTeBC59=009B;006DR]B;58/DTaB;4i=
0Th]00E>;4h]CRe>;Dh/009>;@=>;09>:`=>:PI>2P03BP]>2dh;009>2`9>2P03BPY:2dX:009:2P=:
2`962`08BP]62dX:BP]9jdX:BNY62P=9j@03CNU9jTWY0095j0=5j@95jP95j@04ANY5jDGXBNH1BLT0
000936LLYS4T?HMBC59^DRiB;E8^009BCP9FC`MBCP03DTeBCUI>009FCPMFC`9FCP03ETeFCUI>00AF
CPMJCP=J;0=N:`9N2PEN:@EJ2@03FNUJ2EX9009Ij@9J2@05FPYIjUX;GReNL004HVl05V9^HVmNKUi=
GT]J:UX:DN]EjeX:FRQ5bSD8<>HmJD7<CPaF:eY=FVmFL5Ia15Y`00UNL5i>HXmNSdG[9>D880@03400
20a100H8@@a1244<@0`P3647368248<00a1R464@H@0246401PaQ344<@@a1368@HP<@H`8@HP@@PP05
588@PQ22468@PP0248<0111R48<DPaB31AB41QB300<DXaBT5:@00aBT0QRT0QRS0QS300TLa2D5:BDU
9QcU7<@LiB3U9@D00b4600LU1BD68@HQ1bD79BPY9`029BL39BP2:BP00c5Y;HXYB@029@P00bTX;FT]
J@03:BL2:BP02BU9=J/icCg]>J`eRcF<?Je1k`02BS006DiaCU563T7=@Ne:;e9?CU1:;dH=BPi:;dH>
@N`mc47<@Na63DX^BRm:3d7^ANm:3dX>00963P0?CTmBL4iaBU11kTH>CU1>CdH>@Ni:;U9`DY5>CdG^
008m[@0@ANiBL5Z`F[5JTDX_@Nhm[3V[@La:34i>DVmFT59`BTl2CU003TY@@Pm1kSg^?Ldmc3g;?J/m
ZSV[>JXeRSF9<FT3;BL01Re8<FTaRC68<HT]J08]B00B;DT]B359<FTaRCF9=FP]9bT6:BL]AbdU9@@T
i2C49<<Xi2SS0bST00@]9C5W<HLaJ08]J006<FL]IbTW8@LLiQRT0QBT00XDPa1R588DP`PP120<@QBT
7>DQ1P8U9`04:BLYAbD78@L29BL052D78>HPiR3V8>DLiAc46:<La1RS8>@La1S28<8Y0d79FX]RlEjb
G]<2H]<00ekBH]=Rd`02H]<01FKcI_AVm6KdI_D016[d1V/D0f[d00=Vm6[cJ_<00V[b0V[c16/C00IZ
lf/CJ_=ZlV[cJa<5J_<00fKcJ_=Zl`04J_<00f[bJ_=Zl`04J_<5J_@01F[cI_=ZlV[cJ_800f[c00EZ
m6KdI_AZm6[b009Vl`IZlP9Vl`04J_=ZlV[bJ_82J_<3I_<3I_800fKaI_9VlP0AI_800fKcI_9VlP03
I_87I]4016KaI_9VlVKb0fKA00=VdVKAI]401fKA0V;A0VK@0f;@16;A00AVd6;AH[5R/@=Rd003H[5R
/6:`00IRd008HZmR/6:`H[1N/5jaG[1NS`9N/004H[1N/EjaG[42G[0015j_GZiN[Uj_0Uj?0Uj>0ej^
0Uj?00=NT5j?GXl00Uj>00=NSEj>GXh00UZ>00=JSeZ>FXh00UZ>00AJKUZ?FVmJKPAJK@07FViJKeY_
FVeJK5Y]FVh01EI^0UY]0eY/0UY[00EFKEI^EViJKEY/00YFB`03DT]FC5I<009BC0ABB`06ET]FC59=
DTaB;58[0U8/0U9<0Ti=00=>;Dh/CRd014h]14h/0Th[2Dh:0TX;0Th;00=:2dh:CPX00dX:00=:2dX:
BP/00TX;00=:2TX;BP/00TX;00=9jdX:ANX00dGZ14WZ00=9jDWXANP01DGY00I5jTGYANU5jDGXBNH1
ALT0000:34LLYC4S?HM:34i>CReB;E8^DTl7DTh3DTl00e9=DTiFCP02ETh00eI?DTiFC`04ETl9ETh2
FTl2ETl01eI@ETmFCeH]FRaJ:eh[009N:P03GRUJ:UhY00=N:@]J2@AJ2P04FRaN;Ui?HVl3HW02HVl0
4Ei_GW1NKUX/FR]J2eH;GTYR:4FY;<H/aCE9@La>3EI=ETh00UI`00mFLEYaFW5JLEiaGW1NCf:`G[1:
3BC5224400a034400Pa20PaR00H<@Pa12248@@Q2244234403@aQ368<HPaS368<@Pa3368@HPaR468<
@A1Q00<@HP03464<@@aQ008<HP8<H`<@H`@@P`8DP`06588DPaB348<DPa231AB300<DQ1B358@01aB3
1QBT1ART00DLa1cU8@DQ1QcV00<Li@058>DU1RDV9BLU9P028>H01RDW:DTY:B479BLYB08U:00::DT]
JS6:;DTYBBe9:DT]BRe9;DP4<FT02Be9;FTaJSF;=J`iZcF/>JdmcP03@Nh02TH?BRm:<4H=?J/eRCf[
APe6;dH>0T7^00E1kD7<?J/iRSF900<iZP06>J/mcCg=>J`iRcV:0SF900/iZCVZ>JXaRc5Z=HTaRC5X
;DL]B35Y008iZ@03<DH]9bdX008]9`07<DLeR3W;=HTaB2T7:>H00RT600/Y9Be6<DHaAbe7;FP]B2U8
:BLQ1b3V008La@8Ha@8DY0086<DHYARU68@@Ha1R348@@P8@HP035:@HY123008@HP0548<@HPaR468D
P`036:@258<00a1R344<@@032204320234000`a1468DP`0248<35:@01A223688@@Q124000P@P1@@0
00@480Q0364@P`<DX`055:@HY1S57@LU9`028@H01b3V7>HPiB3U8>@Li1S400<La0087<<P`bSR@LUN
[5kbG[9Nd`9Rd`03G]=Rdf;C00=Rd`05H_AVm6KdI_EW5006Ja@2J_@00f/DJ_AZm002I_@00fKcJ_=Z
lP02J_801F[cJa=[4f[cJa<016[c00=ZlV[cJ_<00f[c0fKc36[c00=Zm6[cJ_@00f[d00EVlf[cJ_=Z
lfKd00=Zm003I_AZm6Kd00QZlP05I_9Vm6KdJ_=ZlP02J_<01F[dI_=VlfKcI_@00VKc0fKb00AVlfKb
I_9VlP=Vl`03I_9VlfKb009VlP=Vl`=VlP03I_=VlVKb00AVlP04I_=VlVKbI_82I]8016KaI_9VlVKb
0fKA00=VdVKAI]401VKA0f;A0VK@0V;@16;A0VKA0f;A0f;@00=RdF:aH]401F;@00=RdF:_H[000V:`
00AN/5jaH]5Nd@9N/006H[1N/EjaG[5N/5j_0ej^00=N[ej?GXl00Uj?0ej>0Uj?0Uj@00IJSej?GXmN
SUj?GXh2FXh01EZ?FXiJSUZ=FXh00UY^00=JL5Y^FVd00UY]0UY^00AJKeY^FViJK@MFKP9JKP9JK@03
FVaJJeY[009FK@05EViFC5I<ETaFC@06ET`00eI;ETaFC002ET`2DT`4DT/2ET/3DT`01E8[DT]BBe9<
CT`00Ti=00=>;Dh/CRd014h]14h/0Th[00I>:Th:CPY>:dh:BPX3CPX00dX;CP]:2`05CPX3BPX3BP/3
BPX014X;AP]62dW[0dGZ00=5jdGZANX00TG[00M9jTWYBPU62TGYANY5j@04ANX2ANT1ANP1BNL1ALX0
000634LLQC43?HQ:;E9_0U8/00=FCE9>DTh01U9>00EBCe9@DTmBCE9>00=FCPMFC`IFCP03FTmFCeY?
009JC`03ETmJCeY@009JC`05FReJ:eXYGRUN:008GRT:FPT015X:FNYJ2Uh;0Uh/015RCF9^HY1VT6I`
HW1RD5i@GTmJ;UX]FR]J2eX<EP]N:45W008/a@06=DU1c4X>DReFCUI`1UYa00YNL5i?I[1JSdW]8:@8
00@0468<@P8<HP0646<<HPaR344<@PQ20PQ10Pa11@aR00@8@@PR348@HP8<HP04344<HA1R46823682
46800`aS46<<H`0236<0111S48<DPa231aB30QB40aB300D@PaB35:@DY1BS008DP`05588@Pa23488D
PP0258<00aRT5:@DY0025:@00aRT5:@DY0025:@011RT8>DPiAc40ac500/U1bTW:BL]Abe8;DLU9bTW
:DP]B2TX008U2007:DTYJRE99BP]BC59;DT00Re8010Y:BT7:@L]9c58;BLY9bdW;DPY1b3V9@HY:2U7
:BL]:0D]9`06<DL]Abd4:>@Ta2ST0bT500<TiBCV9>D00RCU00<Pa2CT9>@00RCT010La1RT58<HY1bT
588@HAB18<<HXQB26:@DHQ1P5:8@HP888004444@H11P340522000`a0444<@00322000``P22088008
100300000`@00000000A00021007000020@000000000200@H1RR8:<27:8011B2464880P01`0000<4
000000000`000P@01@@P00<4000000000P0000X480PP2208811R6<DLiB468>HLiP8Pi@037>DLi1c4
008Li0087<@HXQb2:>91bEj/H_9NdP9RdP03H[=Rdf;C009Rd`06H]9Rdf;CH]9VlfKd0VLD1F/D0V[d
00Y[56[dJ_AZm6[cI_=VdVKcI_9ZlPE[4a1Zl`03Ja=Zlf[c00=ZlP03J_=[4f[c00AZl`=Zm09Zl`MZ
m003J_=ZlV[b00MZlP04J_AVm6[cJ_83J_<2I_<02F[cI_AZlfKcJ_=Vlf[bI_=ZlP02I_83I_<00fKb
I_=VlP02I_82I_<8I_800fKcI_9Vl`02I_<2I_800fKaI]5Vd@06I_42I]42I]05I]400f;AI]5Vd@02
I]001F;AI]5VdFKAH]401FKA1V;A1V;@00=RdF:_H[000f:`00MN/6;@H]1R/5j`H[1R/@03G[400ej_
GZiN[P03GZh00ej_GXmNS`07GXh4GXl015Z?GXmJSUj>0eZ>0UZ=00AJKEY^FVmJKP9NK@9NSP03GVeJ
KEY]00AJKP04EViJKEY^FVd4FVh00eY]FVaJJ`02FV`01EI/ETaFC5I<FV`01UI=00AFC5I;ETaFC@AF
C0=FB`9BB`04ET]B;58/DR`2DR/3DT/0159<CTa>CE8/0Th]0U8]00=>;Dh/CR`014h[00A>:Th:CPY>
:`E>2P03BP]>2TX:00A>2PQ:2P03BPU:2TX:00=62`9:2P06AP]5jTH:ANY62dG[0TGZ0TGY00=5j4GY
ANX014GZ0TGY0DGX0DGW0DG:00002@a568@]0Sf7BReBKe9<DRaFC@08DTh00e9?DU1BC`03DTh2DTl7
ETl7ETh2ETl00eY_FTmJD003FTl015Y>FRaJ;5XY0UhY00EN:UhYGRYN:EhZ00AN:@03FRUJ2EX900IJ
2@9J2P9N2P04GR]N;69=IVh2IY000fJAHW5RL002GTl045X^FReF;5H<DNaB2eX9BHTdibc6<BTm[4G]
CPeFCUI_0eYa00]JTEY`FW1NLEi_H[1NT4G<8:@80@@0008@HP08368@HQ1R46<@HPa13488@P8<HP8<
@@04364<HPaR368234801Pa3348@HPaR46<<H`H<HP06468<Ha1S36<@Ha230QB300TDY1B358<DPaBT
6:DDY1B458<00QBT00<HY1BT5:@00aBT00<HYABT58<01A230Q1R00<DPaS46<D00QBT00<HYAS66:D0
0QB400@DY1RT7<DHY08HX`0@7<DU9b3V7<DQ1bDX8>HHY23V9BPQ:1cV6:DDQ1BU7>L26>L011cW6<DH
YART0aRU00PDPa1R468DPaB45:@@Pa1R0Pa20`a100@8@@a1344<@@8@HP04324800@0200210000`P0
220<8@03100400031002000310030005100:000510001@P0100400@0200010@00`000P@000D800@0
100000@000800084008000L40004200400000007100300004P@0000000001008010P7:<eISVY>HPm
ZSg:>JX]AbCU6:@800D00004120400@P120210000`@P2208800322000`Q12404800212002@@00000
00001008811Q6:<Li0027>H00b3V8>DPi@038>D02B458>DLiAB2788ThD79GXaRlP03H]801V;CH[=R
df;CI]=Vl`9Vm09Vl`9Vm003IaE[5F/D00I[50=Zm005J_=VlfKcJ_AZl`0=Ja<8J_<016LDJ_A[56/C
16[c00=[4f[cJ_<016[c16[d16[c0V[d0V[c00=ZlV[cJ_8016[b00=Zlf[bJ_<00V[c00=ZlVKcI_<0
0VKc0V[c00EVm6KcJ_=Vlf[c00AZlP03I_9VlfKc00=Vl`05I_9VlfKcI_=VlP03J_83I_42I_85I_<2
I_801FKaI]9VdVKBI]400fKa00EVdFKBI]5VdFK@009Vd@9Rd@03H_9VlFKA00eVd@MRd@ERd005H]5R
cf;?H]1Rd@04H]000f:`G[1R/@04G[4015j`GZmN[ej^0ej_0Uj?0Uj>00EN[Uj?GXmNSej>009NS`MJ
S`0:FXiJSeZ>GXiNKEi^FVmJKUj=FVh4GVd00eY]FViJKP04FVd5FVh2EVh2FVd00eY/EVeFJ`04ET`6
ETd00eI<ET]FC006ET`01EI;ETaFBeI;DT/01E8/00=B:e9;DT/00Ti<00A>CDh]CRe>;09>;@9B;003
DR]>:dh[009>2`03CPY>2dh:00E>:`A:2`=>2P]:2PA62`05BP]62dGZANY62P02AP/00dG[ANY5jP03
ANT00dGZAN]5jP06ANX1ANP1AL/0000:34DHQ2cR?HM:;59^ET]F:eH/DTd4DTh01U8]DTiBCU9?DU1B
C`=BCP9BC`03ETmFCUI?00AFC`9FCP03ETeFCUI>009FCP=FC`03FTmFCUY>009JCP04FTaJ:eXZFRT2
GRT5GRX4GRT2GRP00eX8FNUIj@04FPT03eX:FPUN2Eh9GPYN:f9;IVeVSfJ@J[5VTF9`GU1N;`02FRd0
3eX<EPaF2e8;FPY9bcTX<@La:3f/ANe>;EI>EVmJL002FW403EY`FXmJT5Y`GVmNSeZAALdTaPP2100@
HPa1008<HP03468<Ha1R008<@P06248<HPaR368<@@aQ0PaR00/8@Pa1348<@`a2468<Ha1S36<<HQ1R
00@<HP03468@Pa23008@P`0348@DQ1B4008DQ08DP`0:6:@HaART6:@DY1BU6<DLiQcU7<D36<D25:@0
0aB346<<HP023683468011B26:<LaART0QB31A2300DDPQB3468<811Q00<DPP8@HP8<@@05364@HA1Q
24440002000010@0120000@09P0010@000@40@P1100400@88007320880PP344<@PP022400Q130P`Q
00D@@QAS568@HQB3008HP`0?6:@LYAbU8<DTaAbT68<HHQR37:<HXaB3468DPaRT00@LY0037<@LaAc4
00LLa@037<@LYAbU008HY@0348<DPaRU00@HY00658<@HQ1R568@HQAR0QAS01LHPaRT5:<@HQ1146<H
Q1R38<@a9CUW?JU5jdX<BPe1k3fZ;BLPaAR3568@@@`P00840003120880PP00L88004224880PQ2202
1202220020Q1220880PP464DXQS47>@27>D00b3U9@DU1@049@D022D48>DDPR2R:>11bEZ<H_43H]40
1F:bH]=Rdf;CH]800VKB0fKc0VKd00=W5FLDIa@02F[d00E[56[dJ_AZm6/D00=Zl`A[4`03J_=[4f/C
00A[4`IZl`05J_AVm6KdJaE[4`04J_<00f/CJ_=Zl`03J_800f[cJ_AZm002J_@2Ja<016[cI]9Zm6[d
0V[c2F[b00EVdF[cJ_9ZlVKc009Zl`=Vl`03I_AZlfKc009Vl`EZlPIVlP=Vl`9VlP9Vl@03J_5ZdFKa
009Vl@MVlP04I_5VlVKbI_85I_400fKBI]5Vd@03I]400f;AH_9RlP0?I]47H]46H]03H/l015j_G[1N
/6:`15j`15ja00EN/5j_GZmN[ej`009N[`05GZiNSUj>GZiNSP03GXl015j>GXmNSeZ?0Uj?00EJSeY_
FXiNSej>009JSP06GVmNKUi^GViNKEj<1EY]00AJK5Y]FViJKP9JK0AJK@AFKP9JK003FV]FK5I;009F
B`9FJ`03ETaJK5I=00=FC@05ETaFBeI;ET]FC003ETd00eI<ET]FB`02ET/0159;DTaFBe9<0U8/1E8[
0Th/00=>C58[CR`00U8/0U8[0Th[00EB:dh;CPY>:dhZ00U>:`A>2Pe:2P06AP]:2TGZAPU5jTX:0TH:
0TGZ0TGY00I62DGYANY5jTH:ANX2ANT3ANX1ANP1AN/0000:46DDHRcR?HM:359>FV]F:eH/DTd3DTh0
159?DTiB;U9>0e9?0U9>00=FCU9>DTl02EI?0eI>15I?00=FKeI?ETh00UY?0UY=00=J:eXZFRX00UhY
1EhZ00=N:Eh:GPX00UhY00AJ:EX9FNUIj@9J2@EJ2P0KGPUN2Uh/HTeVSfZbI[5Z/VJAIW5RKei`GTmJ
;UX=EPaEk5H;FP]F3SeZ=@PeBT7<APe>;U9>009FL005FW5FLEY`FXmJT002FW002EjAFY9:3Rd82284
0@a1220<@P0236800`aS388<H`0236<636801@a22488@PQ334<01@aS0Q1R00`@H`aS368@HQ2248<D
Q1BU6<HLiQS56:D35:@26:@26<@01QRT6:DLiR487>LHa@@DY00558@@Q11S46<<HP02344236854682
36801`a234488@@P2248@@@P00D401D000D400880003300800P000D80004320<@0a032023440211R
58<DHa1S56@HYAbU7<D28<D29<D2:<D00bS6:>HXi`02;BT00bT7:@H]1P02;@H01Bd7;@HY1BT59@D0
0RT700TXiRC6:>H]1c4X<DPeJCEZ=FT00SE800DeBCEZ>F/iJSUY008eB005=BLeB3UX>FTeJ002=FT2
<FP02c5Y<DP]9bdV<DPeJ3EY=FPiJCV:=H/00SV:13EY00DaBBdX;BLY1bdW00<aB004:@LY22dX<DP3
<BP01bdX;BH]9c58;DP]9bdX008]9`0E;@La9SEW?JY1jdH=APa63Cf[>HXaB2d7;>DTiB346:<@HP@0
12048@@P00`88084800J144880PP360@HABR8@HUAb4V8BDU9RTW:DLY9RTW:BHU9RD58>DLY22R;>11
b5j]IaAVl`9RdPERd`03I]9VdfKC009Vl`03I_AW56LE00AW50QZm0=[5004J_AZlf[cJ_<:Ja<3Ja@0
0f[cJ_AZm002J_@5I_@2J_@5J_<00f/CJ_=Zm004J_@016/CJaA[56/D0V[d0V[c00EZlV[cJ_9ZlV[a
00AZlP9Zl`9ZlP03I_=Zlf[c00=Zl`04I_AZlfKcI_<3J_<3J_86I_83I_<4I_801F[aJ_9VlVKbI_40
26Kb00=VlfKbI_800fKa00=VlVKaI]8016KA1V;A2VKA0f;A00=RdV;AH]4016;A1V;@0f;?00=Rd5j`
G[000ej`00AN/Ej`G[5N/09N/@03G[1N[ej`009N/09NT09NS`04GZiN[ej_GY05GXl025Z@GY1NT5ja
G[9N/Ej>GXd2FXh01UY^GVeNKEi]GXiNS@9JS@=JK@03FVaJKEY^00AJK@03FViJKEY]00AFKP05FVeJ
K5Y[EVaFB`04ET`2EVh3ETh00eI=ETaFB`02ET/5ETd2ET`2ET/0159;DTaBC59=0U9<0U8/00=B:dh/
CR`00Th/00=>C59<CR`0158/0Th[00=B:dh[CR/00dh[14X;14h[00A>2dh:CPY>2P9:2P962PE:2P05
APY:2TX:BPY62`08APX00dX:APY5jP04ANX014H:CPY9jDWZ0dGZ0DGY0DG/00002Pa4688/hCeUANY>
;E9;DR]B;58]159>0e9=159>00=FCUI=ETh01UI?15I>00=FCEI>FVh00eI?00QJCeI?FTmFCUY>FTeJ
C5X[0UXZ2EhY00EN:Uh9GRUN:5XY009J2@03FPQJ2EX900EJ2P07GPUN2Uh<HTeVSfJ@I[400VJ@019Z
TFJ@HW1NKeX_FRiF3EG/EP]NBeH^@J`e23E:@Le:3Dh]DTh2EW02FW402eY`FXiJKeY_FW1JTf:cDTl]
20a322400Pa100/<H@aR348<@A1R368@HPa0464<H@aR00@<@P0424<8@PQ334<436<00`aR468@HP03
46802Q2346<@PaB45:@Ha1S56:@@Pa1S0Q1R00<DPaBS58<00QB20a2300<<P`aR36800`a100<<@Pa1
220010@000H800@0100000@0000310070004100600001@@0120880Q122400PPP00@@HQB3468@HP8@
H`0458<HY1bU7:@268@00abU8<DPa@02:>D022cU:>DTaBC5;>Da1S4V;@H2;@D3<BH2<BL023E7=DPe
AcE7>FPiRCf:?H/2?HX013f[@La5c4W]0Th>0dG^00M5kDG/BNa9kDW/AN]1b`02?L/01cfZ>HTiJCf:
?JY1ZT6[0091b`04?J/mRcf/@L`2@Ld2ALd0246[>HXmRSf:>FTeJCV9?HX2>HT2=FT2=DP00cEY>HXi
RP02>HX2>J/00cV/?L`m[003?J/013g<?J/iRSV:0cEZ0SF:00HeJC5Y=FTaBCE9=FT2>FT01CEX=FTe
JCEY>HT00SV:00HeBBdX<DLiJ3f8AN`2CTh044X=@L`mRSV:?HTiRCV8=FHU9aB424888@@Q224880@P
2`PP010480Q0220880a0460DXR46:DLYIbU6:DLaIc5X;DHY9`8]A`0::BHTiBCU8:8/h46VH/iW=FKc
H]86H]<00fKBI]=Vd`02I_<00fKdIaAW5002Ia@3Ja@016[dJa=Zlf/C0V[c1F[d0V[c00=ZlV[cJ_<0
16[c16/C16/D36[d00E[56[dJ_=[4V[c009Zm005J_=Zm6[eJ_AZl`05Ja<00f[cJ_9ZlP03J_800f[a
J_9ZlP0;J_82J_<00f[bJ_=Zl`02J_<00f[bJ_5ZlP02J_82I_8016[bI_9VlVKb0VKc00IVlFKbI_9V
lV[aJ_83I_800fKaI_9VlP05I_800fKcI_9VlP02I_42I_8016KaI]5VlFKa0fKA0f;A3FKA0V;A16;B
00=RdF:aH]401F;@16:`16;@0Uj`00EN/Ej`G[1N/5ja00MN/09NT004GZmN[Uj_GXl2GY0015j?GY1N
T5j?15j@00AJT5j?GXiNS@=JS@ENS@9NK@08FVeJK5Y/FVaJKEY^FVeJK09JK@04FViJKEY]EVd2EVh0
1UI]FVaJJeY[EVaFB`9FC005ETeFKUI^EViFK`02ETh00eI=ETaFB`04ET`3ETd2ET`4ET/00e9;DTaB
C002DT`00e8/DR]>;002DR`01E8[CRaBC4h/DR/00e8/00=B:dh[DR/00U8[0Th[00E>;4h;BPa>;4X<
009:2`9>:`04CP]>2Th:CPX<BPX00dX9APY62P06APX00dH9BPU5jP08ANX00dWZANY5jP02ANX1@N`0
000;34@HPRc1>DA1bTX]CRaB;59<DReB;P03DTh00e9=ETiFCP02ETh2DTh015I>ETeFCU9>1EI?15I>
00=FKUI>ETh00eI?0UY?00QFCUY?FTiJCUY<FRaJ:eh[0Uh:00AN:EhZGRUN:P9N:`05GRYN:eh:GRYN
:@06FPT3FPX01eX;FPaN35X;FPeRCVJ@009VT@0DIY1VSfJ?IVmRTEi_GTmJ;UH=EN]J2eY<CPe1ZcD7
<@Pmc4H=CReBCP9FL09JL@0<FY5JT5Z@FVmJL5YbH]AFL2d8228000PP10aR00<<@11R36800Q1R00<@
H@aR34800`a20PQ200<<HPQ334<010aS00@<HQ1R468@H`8@HP8<HP<@H`05368@HPaR368<@P023442
3643344010PP120480000P@00P000P@00P0000<4000000001@0010@000D000@0200880PQ008@@P8<
8@07548HPaR3664HHQR36:@00QbU020LaAc69@LY9bT7:@H]9c4W<@Ha9cE7=DPaB34X<DPeBCEY=DTe
B3E9=FTiRcf[>HXiJCV:?H/mZcf/@La1bcf[13V:00HmZT6[@L]1[3f[?JX7?J/02T6[ALe5kTX>CPm>
;TX?BPi5kTW^0TW]00i>3TX=@Na1bcf[?L/iZSV9>HXmRSV:>FTiRCUY0SV900/eJCEZ?J]1c46/?J/m
RSeY?HXiRSE9008eB08aA`03=DLeJ35700<aB007<FPaJC5Y=FXeRCF:>H/00SF;0cV;00<iRSV9=FP0
0S5900<]:BdX;BP00S5900DaB2e8<DP]9bd7008a9`07<DL]1RT6;@L]:358<FT00c5800TeB3EX?HU1
bdX]CRe:;D7;?HX00Sf900PmZT7<=JTUJABT46<88@@Q0PPP0P@P1@PP1P@P0`Q000X<@0aQ484HXb46
:FL]IRe6:DHaI`8]I`03:DLY9RTU008Y1@06:>8]046VGZ]W=F;b0V;B0f;C0V;D0V;C00AVlfKdI_AW
50EZm0=[50EZm005I_EZm6KdJ_=Zm002J_<01F[bJ_=Zlf[cJ_800V[c16/C0f/D3F[d00QVm6[cJa=[
4V/DJ_AZmF[c0f[d00=Zlf/CJa<016/C00=[56[cJ_<01F[b0V[c3V[b0f[c16[b0VKb00AVlF[bJ_9Z
lP9Zl`03J_9VlVKb00=ZlP=VlP9ZlPIVlP03I_=VlVKb009Vl@IVlQ=Vd@9Rd@ERdP9Rd@IRd0=R/0ER
d006G[1N/EjaG[5N/5ja2Uj`00IN[Uj_GXmNT5j?GY05GXl3GY001Uj?GXiNSEZ=GXiJSP=JS@03FXiN
SUj>009NK@03FVeJK5Y/00=JKP=JK@03FViJKEY^009JKP9JK@=JK004EVaFJeI<ET`2EVd2EVh3ETh0
15I=ETaFJeI<1UI=0UI<15I;00=BBe9<DT`00U8/00=BC59;DT`00U8/0dh/00=BC58[DR`00U8/0U8[
0Th[00=B:dh[CR/01Dh/0TX<00=:2dh[CP/00Th;1dX;1TX:00=:2DX:BPX01dH:00=62DH:ANX00TGZ
00I5jdGZANY5jTH:BPX2BNT2ALT1@L`0000734@HHRS1=D=1bTi@DTd00U9<00AB;E8^DRiFCP9BC@04
ETiFCEI=ETd3ETh00eI=ETiFCP05ETl2ETh5EVh00eI>ETmFC`02ETl015Y?FTiJCUY=0UY<00AJ:UX:
FPUN2P=N:@9N:`06GRaN:eh:GR]N:UhY25X90UX:00]N35h]GReN;V9`IY5V/VJAIXmVSF9<009RK`0A
HY1NL5i?FRiF35X[GVaJKTW<>BHe:3f/ANe>;E9>EW1JL003FW42FY402EY_FW1JTf:bEVl]20P1000<
@002364334400`a2368@HP03368434801@PQ120<@@a234<00Q1S00L<Ha1S46<@HQAR468<@@032200
0`@02004000310000`00100400031003000310020004100020PP320880PP320880`P4442568011AS
68<DQ1R30QR40QRT00XHYAc58<HPiRD7:@LU1bT7<BLe9`<eB08eB@07<DTeRSV[>J`mc47<@L/00cfZ
00@mRCfZ?HXiRP8iR`<iJP09?H/mZcf/@La1[46[?J/iRSUY008iRP03?HTiZSfZ00@mZ`0;@J]1ZT6Z
>HTiJCV:?J/mZSV:?H/mZ`03?HX01cf[@J]5c4G/ANe5c46[008mZ`05@J]1bd7;?J/iRP02=FT01CEX
<DLaAc56;BL0134W00DaAbdW;BH]9S4W008aA`05<BHeAcE7>FLeA`02=DH00c4V;BD]1@02;@D012T6
;@HY1RT60RT700LY9be7<DPaB2e8<DP]B002;BL00bdV;BL]9P02:@L00bD7:@LY1`05:@H2:>H01RSU
:@DY1BSU:>HXi@@Y1P0D;BH]9c57=DLiJ3V9?JY1bT7;?HTiIcUV<DHaAcEX>JPYB1BT344400`88005
120880PP2204800324001`a0240@PABR6<@PiB45008U1003:DDYARTV008Y9@08:@D]12SR;>4mQUY[
IcARlP9RdPIRd`AVl`06I_AZm6[dJ_=Vm6[d0V/D26[d00=Vm6[dJ_<00V[c0V[b0f[c00=ZlV[cJa<0
1F/C0V[c1f[d00AZlf[dJ_AZm09Vm09Zl`03Ja9[56[d00EZm003J_=[4f/C009[4`03JaA[4f/C009Z
l`=ZlP9[4Q1ZlP9Zl`AZlP=Vl@08J_5ZlV[bJ_9ZlfKcJ_9VlPMZlP]VlP=Vl@9VlQIVd@=Rd@04H]9R
dF;BH]82H]400fK@H]1Rd004H]04H[02H]02H]43H]000f:`G[1N/006GZl2G[000ej_GZiNS`02GXl0
0ej@GZmNSP02GXh00ej?GXiNS`03GXl02Ej>GXeNSUj>FXiNSUZ=GXiNS`02GXh5FVd2FVh015Y]FVaJ
KEY/0eY]2EY/15I/00=FKEI^ETh00UI>00AFKUI]EV]FC0IFC@9FC0EFB`05DT]B;58/DRaBC002DT/0
1U8[DRa>;4h/DTa>;0EB:`=>:`05DR]>2e8ZDR]>:`03CR`2BP`00dX;CR]>2P02CP/00dX;BPY:2P05
BPX00dH:BPY:2P03CPT2BPX014H:BPY62TX91DH:00A62DGYAPU62P=5jP06APY:2DGXBNQ5b4GY0DG/
00002@`S564T`CU4ANaBTE9_DReBC002DTd3ETh00e9=DTiFC@02ETd3ETh00eI=ETiFCP07ETl2ETh0
0eI^ETiFCP02ETl3EVl025Y?FTiJCUY?FTeJ;EX/FRX2FPX00eX9FRYN:`04GR/01Eh/GP]N2UX:FP/0
0UX:1EX90UX:00EN35h/GReN;F9`009V/P9V/@9VT006HW1RT6JbHY5NL5i?0UY?00]RT6:aEPa1J3U8
@La5kDh^DTmFL5Y`009JT@03FY9JTEIa009JL007FVmN/UI`<BT<8PP056400Q1R00<<@A1234401@aR
00L@HQ12348<@P`R324<@P0234400a1346<DP`0346<01AAS568@@PPQ10000PP01`@00PP00PPP00<<
80a144400Q110Q1000HD@AAQ668HPQR368@27:@011R36:<La2CV0RD60bCV00XTibT8<BP]22T7;@La
:359<DPa:0@]:004;DPaBC5Y=HX2=H/063V:=HXeRcg=APi23Sg<?J/iRSF:>HTeJCF9>HXeRCF:>H/e
JS58;@LaBCEZ>FXiRP8iR`8iRP05=FTeB3E8=DLeI`02=FP00c5X=FPiRP02>HX01CUY=DLa9c4W=DP0
0SEX00<eJCEX<DP00RdX00XaB34X<BLeJCV:?J/iRSEZ=DXa:0@aA`8]9P03<DL]9bT500<Y1@0>;BH]
9bdW;DL]9bT5:@@Xi2T4:@D]9S4V;@DY1@@]1003;@DXiBT4008Xi0039>DY1BD5008Ti@049@DU1RD6
9@H39>D02BD6:@HY1BT4:@DTiB3U9>HU1`029@H49>H012CU8>DTaBC50bCU0RCV00HXiRT6:@H]9BdV
;@H2;BH0234V<DLiRCV8=FPaAcE7<DL2;@H01Bd5;BHLiQB320000P0000<88@PP22401PPP00<480PP
12000P@P00D880@Q12088@Q100<88008240<@1226<@PiBD49BDU9P8Y9@08:@@Ti2C39:4X`3eWGXeS
509RdP=Rd`9Re09Rd`05H_AVlfKdI_AZl`03J_@3I_D9J_@016KeI_AZm6[d0V/D00A[4f[cJ_=Zl`9[
4`03J_=[4f/C00=[4`03JaAZlf[d00EZm0=[509Zm09Vm09Zl`03Ja=[56/D009Zm0EZl`A[4`09J_9Z
lf[cJ_=ZlV[cJa5[4V[a00AZlP03I_=Zlf[c00UZlP03J_=ZlV[b00eZlP03I_9ZlV[b00AZlP=VlP9V
dP=VlP9Vl`9VlP03I_5VdFKA00=VlP07I]5VdVKBI]9VdF;BI]400fKB0fKA00=VdVKAH]400f;B1F;A
16;B00=RdF:aH[0016;@0f:a0f:`00=R/F;AH]400f;A00=Rd6:`H[000f:_15j_00=N/5j_GZl00Uj`
0ej@00AN[ej>GXiNSP=NS`=NSP04GXmNSUj>GXh3FXh015j>FXiJSeZ?0eY]00=JK5Y]FVd00UY^00=J
KEY^FV`00UY]00EJKUY/FVaJK5Y]009FK@AJK@9FK@03EVaFKEI=00=FCP9FKPUFC005DTaBBe9;DT]F
B`02DT/2DR`2DT`2CT`01E9;DTaBC4i<DT`00Th/00=BC58/DR`01Th[0U8[14h/00I:2dX<BP]:2dh[
BP/2BP`4BP/2BPX3BP/014X:DPY:2TX90TX:00=62TX:APX01TH:00A62DGZANY62P=62`03BPY:2DX9
0099j@5:2@55k00000`<8aAQ9<4eA47<DY5BKU8/ETaF:eH/ET`=ETd2ETh5ETl015I_ETiFCEI>1UI?
00=JCeY>FTh00eY>00=J;EXZGRT00UX900EJ2UhZGP]N2eX[00=N2`04GPaN;5X/GP/2FPT01EWYFPUJ
2Eh9GPX00Uh[0Uh/00URCF9?J[9V/VJAIW5VL69`HTl00V9`01ARTEi_GTmJCeY>I[1R/Eh[AFLmAT7;
APe>;U9?EW1JL5ZAFW1JTEY_0UY`015NKUY/G[5NTC5944<<01B1464@@Pa1348<@A1R46<@HPaR008@
HP07448<8@`Q324<@A12468011AR1AAS00`@HPPQ100800`Q448@HAAR444@HQAR56<2568268800aR3
7:<LY0037:@04b359>HU1RD6:@HY1bD69>HU1RT7;@H]9c4W<BP]9bd7;BLa9bdW00<]:08]9`0E<BPa
B34X;BP]1bdX<BP]1bdX;DT]B2U8<DTaJC59;DPaJSF:=HTaJ2e8008]9`@]9P03;BLY1RD6008]9`05
:@DXiBd6;BL]1`02;@H00bT6;@H]1P02:>D01Rd5;BH]1BST:@@]9@8Y9P04<BL]9RcT:<@29<@01234
9<DXi2ST0RCU00`TiR3U8<DPaB368<DXiBCV8<DLYB359<D29>D2:@D00bd49<DLa@027<@02Qc57>DP
iBCU:@HTiQc58<DPiB340Qc41B3400@LXaQQ688Xa08Xi0039<@PaAc4008LY08La0037>DLaAc5008L
a@047<@LaAc56<@27<D01B3T8>DLaAc57<H00R3V00HLaR3V8<DPaB3V9>D38>D28<D03BCU9>HTaBCU
:@D]9C4T<BD]12cT:>@a9SUX008iR@0;=DL]9Rd6:>HXiBS4:>DTaART4448000210001@PQ124480@P
220020@P0PPP00<48@PP22400`Q10PPP00D<@A1R5:@Li245008U1@8Y9@0;:B@Y11bR8:4TX3f8FXeR
lUkAH]5RdP03H]<00f:cH]=VdP02I_<00fKdI_=Vl`03J_@2I_@00fKeJaA[5002Ja@6J_@4I_@4J_<4
Ja<00f[cJ_9ZlP04Ja<01F[cJ_AZm6[dJa@00V[d0f/D00MZm6/DJaAZlf/DJa=[5002Ja<9J_<2J_83
J_<2J_800f/AJ_5Zl@02J_83J_<EJ_84J_400f[bJ_5ZlP05J_8016KcJ_=ZlVKa16Kb0fKc0VKb00=V
dF;@I_400fKb00=VlFKBI]800fKB00AVdFKBI]9VdP9VlP04I]5VdVKAI]83H]801F;AI]5VdFKAH]40
16;B26;A0V:a0f;@00=R/F;AH]400f;A00ARd6:`H[1R/0AR[`AN[`03G[1N[ej@00=NT003GXmNSUj^
009N[`03GZiNSUj>009NSP=N[PANSP04GXeNSUZ?FXl2GXh01Ei]FVeNK5i]GVh00UY^00=JKEY/FV`0
1EY/1UY]00=FKUY]EVd00UY/0eI=0eI^0UI<00=FJeI;ET/015I;00=BBeI;DT/00e9;00MB:e9;ET]B
Be9<DT]>C003DT/01Di<DT]BC58/CR`00U8/1E8[00=>:dh;CP/01dh[00E>2dh[CP]>;4X<00=>2`03
CPY>2DX:00=:2`03BPY>2TX:00=:2P04APY:2TH:ANX3APX00dH9ANU5j@04ANT014GZANU62TX90TWY
0DWX0DX80DG[00002@a3564T`S54>JY6D4h^DRaF;@02ER`00e9=ETaFC@08ETd3ET`015Y=ETiFCUI>
15I?00AFCUI=FTiJCPMJC`AJCP03FReJ:UX9009J2P0=FR]N2eh;GR]J35X;GPaJ2eX<GR]J:eX9FNX0
0UWY0Uh900=N25h9GPT00UhZ00AN;5h]HTiVL@9VT@05IW1RL5X>ENaJ3P03GTl08EY@GRiNCf9`HY5E
bcdU?DE1ZdG/CRiBCeI`FVmJTEYaFY5JL5YaGW1NKUj=G[1NL35944<<81B1464<@A11344<@P024680
212346<@PaAS568@@QAR56<456800aQS68<HPP0268<011AS58@HQ1B40QAT0QR40abT00<Pa2CU9>H0
0RCV0RC500LTiRCU9<DTaBSV;@HY1`02:@H4:@L29@L00bT79@LU1`02:@L39@L012dW;DP]9bD70RTX
00/Y22T78>HLaR3V9>HXibCV8<HTibT700@U1`<Pi`049@PYB2TV9>H28>D00b3V7>DLa@037<D0123V
9@LU1R3U1Ac50abU0Qc500DLYAc58<DLaAbT008HX`067<DU1R3V7<DHY1B30QAR01T@HQAR58<DPaAR
58<LaB3V6<DDQ1B368@HY1B3348<80P0324@HabU7>DLiQc56:@@HP0244401A1R6:<HY1S56:@00QB3
00<DQ1RT6:@00QRT0QB200DHXaB2568HPab2008DH@0::>@eABd67<DLYAbT58<@HAB26:<26:@25:@;
6:@00ac57>HLiP047<D28>H01acV8>DPiR3U8>HPaB36008Ta@0=:>D]9S4U<DDa9CDV>DLmRD6Y@JXm
RCUY<BL00Rd70RcU00@TaB3468<D@@<<80888@03220480@P00@480<88003120880PP00D88@88@@08
2248@A1R5:<Ha1cV8@DU1@8Y9@03;DDY9BT4008XhP04?HQFC5kBG]42H]82H]<2H[<00f:bI]9Vd`04
I_<00f[dI_AVm002I_@00fKeJ_AZm002J_@016KdJ_A[56Ke16Kd00AVlfKdI_=Vm0=Zm0=[4`=ZlP=Z
l`06J_9Zlf[dJaAZm6/D0V[d16/D00EZm6/DJaA[56[c009[5005Ja=Zlf[cJa=[5004J_<3J_83J_<0
1f[bJ_=[4F/BJa5[4V[b00EZl`EZlP=Zl`aZlPAZl@EZlPAZl`AZlP03J_=ZlVKc00AVl`9VlP03I_5V
lVKb009VlPEVdP04I]5VdVKAI]83I]47I]83I]400f;AH]9RdP02H]85H]400f;BH]5Rd@02H[43H]03
H[4016:`H[5Rd6;@16:`1V:_00=N[ej`GZl00Uj_0Uj`1Uj_0Uj^0Uj>0ej_15j>00INSEj>FXiJSeZ>
FVh3GVd2GVh2FVh025Y]FVaJK5Y/FVeJK5Y]FV`2FVd015Y^FTiJCUY]0UI^00=FKEY/FV`00UY=00AF
CEI^EViFKP9FC0AFJ`9FB`=BB`=BC09BB`9FB`03DT]BC59<00M>C09>;09B;006DR]B;58[DR]>:dh/
0Th[0Th/1Dh[24h;0Th:00A:2Th:CP]>2P=:2`962`03BPY62dH;00A62P03APU9jTWZ0099j@0;DNM9
idWYANU:2TH:BPY9j4gYBNQ9i`01AN/0000934<DHB32<B@mZDX_DReF;5H]009F;003DTeFC5I<009F
C0=FC@03ETaFCEI=00AFC0=FC@9FCP03ETmFCUI>00=JC@03FTiJCeY?00AJC`=JCP04FTeJ;EX[FRX2
FPX02EX;GP]N2eh;FPaJ2eh;FP]N:`02GRT015h9FNUIbEh91Eh801mN:5h9GRaN2eh<HU1RLFJAHW5R
CeX>ENeIkEX=GRiNCUh^FPeJ;Ui?GU5EbcS3=><mR4X<DReFCeY_GXmJT002FW402eZAFW5NL5i^GVaR
[f:>=DT@H``P56400Q1R00<@@Q1R46801QAR2aR30QR400HLY1c57<DLYART68@27:D01b359>HPa233
9<@TiB3400<LY0067:<LY1c48<@PaBC40R3500@LaB357<DLa@8LY0077<DPiB3U8<DLaAbT6:@00QbT
00DTiRT69>HLaARU00HHY0045:@HQ1R468@45:@01QB45:@DY11S348@H`8DQ00558<DXaRT5:<DPP03
46803aB35:@DY1RS6:@DPa1Q568HY1RS58<<@@`Q444DHP0246826:@01QAS444DPac56:@@H`8<@P8<
8@0@348@@A11444<8@a168<HY1RS58<<@Pa1468DPaAR324220007@`Q568HXaRT6:<DQ11R220400PP
464DXaRS5:<DP``Q224@HQB35:<HXaB3568DHaAR56<DQ1bT78800QA000P/i45T;@DLY1AS448DHQR2
0QRS00HDPa1R348<@Q1R58<26:@258<00aRT6:<DP`0258<011RS6:@@PQ1R0aB300<HY1c57<D00ac5
01THY1S47<DHYAbU9>D]9SEW>FLiISeW?HQ1ZDh<CPe5k3V:>FTeBC4X;@H]9RCV7<DLY00254401A10
320<8@PQ22001@@P0P@Q10PP1PPQ00d880PQ100880a0588Ha1d68@HQ1BDU:BDaA@02:B@01Bd4;@<m
Qej<H_801F;B00IR/ejbGY9R/VKCI]83I_<00f[cI_AVm003I_@01FKcI_AZlf[cJ_@00V/D00A[5FKe
I_AVm09Vl`=Vm0AZm09Zl`=ZlP=Zl`04J_9Zlf[cJ_<3Ja@016/CJ_=[56/D0f[d0V/D00=[4f[cJ_80
0V[b0V[c0f/C00AZlf[bJ_9Zl`EZlP03J_=ZlV[b00=Zl@9ZlP03J_=ZlV[b009ZlP9Zl@04J_9Zlf[c
J_<6J_800f[aJ_9ZlP03J_85J_42J_85J_<7J_82I_83I_<016KbI_5VlFKa0VKb1FKa0VKA00=VdVKA
I]400fKA16KB00=VdFKBI]400fKA1F;A00=R/F;AH[401F;A00=R/F;AH]001V;@1f:`0f:_15j_0Uj^
0ej_00=N/5j_GZl00ej_0ej^15j>00=JSUj>GXh00Uj>0ej=0eZ=00=NKEY]FVd00Ui^0UY^00EJKEY/
FVaJK5Y]00EJK004FVeJCUY^FVh2EVh00eI]FVaJC002FTd015I=EViFKUI<0UI[1eI;0UI<0e9<0U9;
00AFBe9;DT]BB`=B;0E>C09>;0AB;09B:`04CR]>;4h[CR/2CR`2CR/014hZCR]>:Th[1dh;1Th:0dX;
0TH;01=:2TH;BP]62dX:APY:2DH:BNY:2TGZBNQ>1TGWBPQ:2DH9APY5j@02BNP1ANP1BNL1ALX00007
34<DHAbR<B<mZDh^EVd015I>00=BCU9=DTd01E9=0eI>1eI=0UI>00AFCeI>ETiJC@9JCPAJC`9FC`07
FVmJCeY@FTmJ;UX/FR/015X:00]J2eX[FR]J35X;GPaJ3Eh]GRYIjUW:009Eb@04FNUR25h8GNT3GPT0
2Uh[GRaN2egZHVmRTFJaI]=RTUi@0UX?01AJ;ei@GTmN;UH=FRiNCUh^ELXh`cCS?FQ>34h=DTiJKej`
GY1NTEYa0UZA00UJL5i^GXeRd6:>>FTHP``P4440111R0QAR00LDHAQQ788HPQb38:@Pa@047:@00abU
7<DPa@027:@278@28<D00abU7:@HY00268@27:D27:@00abS78<LPP0278<37:@01QbS7<@LY1R3588H
X`<HY0<LY@8HY00358@DHa1R008DP`0658@DPQAR68<LY1R30QB300<DHaB358<00QB300P@HQ1S56<@
@Pa146<DPa2310a200@<@@PQ348<@P<<@@0348<DPPaR00<88003344@HQ1R008DPP0<468<@0PP568D
Pa1R10080112468<HQ1R0QB300<@HQ1246800QB300@DQ11S348<@@888@06344@@A12448<@AAS0QB4
00@DPa1S468DHP8@HP8<8@05448DHQAS58<DQ00258<02@a1324<@Q1R46<@PaB2568@@P0232401A1R
568@HQAS58<00Q1S11AS00`HHA0P520PPS3T7:<DHP`P324@HQAR588246802@a1224<@A1R46<@HQ1Q
344@HP0244834682464010aP364<HA1R0a2302@DPaRT7>HHaAB4468@HaB46:DTaBdV=DLiQcf5@HI5
Z4G9CPa:3DG]?J`iJCE8<DPaJ357;DLTiQbT668D@1A1420<8@PQ220312051244220722401@PP1008
81226<@00QcV00/Q1RD59BD]9BTU:@DThbS2@HMNRf;b00ARdP04H]=Re6;DH]<2I]<016KcI_AVlfKc
0fKd00EVmFKdI_=VlfKd009Zl`03J_AVm6Kd00]Vm09Zm009J_=Zm6[cJ_=ZlV[cJa=Zlf[b00=Zl`e[
5003J_=ZlV[c00=Zl`06Ja=Zlf/CKa=Zlf[b0V[c16[b00=Zlf[bJ_800f[b0V[c00=[4f/BJ_801F[b
0f[c2F[b00=Zlf[bJ_<00V[b0f[a0V[b0f[c0VKc00AZlV[cJ_=Zl`9ZlP03I_9VdVKa00=Vl`9VlP04
I_5VlVKbI_83I_44I]43I]800fKAI]9VdP07I]83I]45H]400f:aH]5Rd@05H]4016:bH]9RdF;A1V;@
1F:`00=R/F:_HZl00f:_00IN[ej^GZmN[ej`GZl2G[05GZl015j^GZmN[ej_0ej>0Uj?00IJSUj>GXiN
SUi^GXd3FXd01EY]GVeNKEi]FVd015Y^0UY]0eY^0UY]00=JK5Y]FVd00UY^0UI^00EFKEY/FTaJCEY]
009FCP03EViFKEI[00AFC004DTaFC5I<ET`3ETd0159=DTiBC59<0e9;00EBC58/CReB;4i=00A>C003
DTa>;58/00AB;003CR]>;4h/009>:`05CRa>:dh[CR]>:P03CR/2CP/00dh:CP]>2`02CP/2CPX00dX:
CPY>2P04BP/2AP/00dX:AP]62`03AP/2BPX01dWZANU5jTH9BPU:2TH900962P06AP]>2DWXCPQ62DGW
0DG:00001Pa3564LXBd2?HM:;@9FC@]FCP=BCP=FCP07FTeFCEI^ETeFCUY^ETh00UY>00=JCEY>FTh0
1EY>0eY_00EJL5Y?FTiJ;EX[00AJ2P9J2`03GP]N35h;009N300<GP]R;5G;AFQ1ADV7ELUN1egXGNUN
2Uh90Uh:01iN;5h<HR]VKVJ`La=_5FJbGRmJ3eW_GS5NDEi`GTmN;UY>HViVKUW9?@Ddi3eYAN]:3E8]
EVmJSUY_GY02FY402UZBFY5NKf:^IZiRS3f978<<81110aAQ00<@@AA156800QR200<LPQbS7:<00Qb3
00<LXb2T7:<01AbT00@HY1R368<HX`<HP`0358<DHQR3008LY08HQ0037:DHQ1R2008HP`056:<LY1c4
8<DTi@02:@@02bCU9<DTaAc57:@DHQQS68@DPa1R34800`PQ00@<@@a2344<@@<@HP0<444<@@PP1008
80aQ468<H@PP200880a10`aR00H<@@PP344@HPa2344234801`PQ100880aR468<@@PP00880003220<
@0aQ008@H@8<@007464@HQ1R34488@`Q44801A1R00H@@@`Q468DHa1R368234801@`Q200800`Q4440
0P`Q00<<@Q1246<00Q1S00P<@P`Q324@@@`Q320<8A120aAR0a1R00D<@@`P200800`Q00<880043208
00P0324234803`a122488@PQ32488@`P324@80`P300@81A0564<800220000``Q344<@@0434402PPQ
22088@a1588DPa1R348@HQB30QRT0QRS00XHXQcT7>@LaABT48@HYAcV9>DQ1P8PiP<PaP0K9>HY1RdV
=DHiICf3?F@mYdG:BNY5c3f;>HXeJC4W;BL]9RdU<DHa9R3U7:<D@AAQ424<8@P10084008880062244
8@@Q12488@@P1`PP0`PQ00H880@0220DPQS37>D28@H02RD59BDY9RTV9@DP`bC2?HMJJVKb0V;B0fKB
0V;C0fKC00EVe6KcI_=Vlf[c00=Vm0IVl`03J_=Vm6Kd00EVm006J_AZlf[cJ_=Zm6Kd16[d1F/C1F[c
00=[4f/DJa@00f/D00AZlf/DJa=[4`9Zl`EZlP9Zl`03Ja=ZlV[b00=ZlP03Ja=Zlf[b00EZlP03J_=Z
lV[b009ZlP03J_=[4V/A009Zl@=ZlP03J_5ZlV[b00YZlPEZl`EZlP=Zl`AZlP07I_9VdV[AJ]5VdFKB
I_800fKc1VKb0fKa16KA00=VdVKbI]800VKB00=VdFKBI]400fKA0VKB0VKA00=Vd6;AH]400V;B0f;A
00=Vd6;AH[400V:a00=RdF;BH]800V;A00=Vd6:`H[000V:`16;@0f:`1V:_0Uj_0Uj`1Uj_15j^0ej_
0Uj>00=NSej>GXh015j>00=NSEZ=FXd00eZ=0ej=15Y^00=JKeY^FVh00eY^00AJKEY/FVeJK@9JKP04
EViJKUI]FV`3FVd2ETh015I^EVeFK5I]2UI=1U9=00EFC58]DReB;EI=00=BC0=BB`03DTa>;4h/009B
;004DR]>:dh/CR`4CR/5CRX01Th[CP]>2dh:CP]>2P9>2`M>2P9:2`03BPY62TX:009:2`=62`E:2PM6
2P05BNU9j4X7ANM9i`01AN/0000:328DHAbR;@8iQdG[ERaBC5I>ETl2ERl2ETh3ERd2ETh0159>DTmB
Ce9>0UI?0eI>00=FCEY^FTl00UY?00=JCUY=FVh00eY>00=NCUi=FTh00UY>00IJKeY`FTmJCUX/FR/3
FPX3FP/045X:GR]N:eh/GP]MjEWYCL/m9cd3AFIAjEh7GPQN2UX:0Uh:00iR:Uh[GPaVCFZ@K_9c56Jb
HU1E[57=ENmND5iA0ei`00iRTFZaJ[5VBT4V<>@mJ4GZBPeB;EI_FVmJL5ZA0eZB00UJTEZ@GXiVcf:<
@J/LQ0P044400aAR00PDHAQR688LXb2S8<@LXQb30ab200DLPaR36:<LY1bS00<HP`@DP`@DHP0658<H
Y1R368<HQ1B40QB301HDPQB36:<HY23V;BDeJ3F8=HT]AbdV:@DPaB2T544LHQbS688@HPa110088@8<
@P03244880a2008<HP0322088@PP00840005244<@@a12208000222000``Q344<@@06344222023240
0`a2344<@P023442200010PP344<@@a10PaQ0`a00Pa100<<8@PP34800Pa200H<@@a2444<@@`Q4482
46800`a122080007200210000`P03248000210000`00200<8006200910000`001004000210000`P0
22488002100222404P@122088@PP324@8@`P200@@AQQ68<@@@`Q468@HaAR68<DH`8DP`<DQ0<HY08L
a@8LaP@LiP078@HU1RD68@HU1RDW8@L00RD700<Y9be9;DP00RD700@Y:2TW:BLY1`8]1@0<<B<mPdGW
BPUB:Th:AN`iJC4W<BH]1BT30RCU00HU1RCV9>DPa1b354824482324010P0220880@Q0PPQ00<48@@P
220020PP0PPQ00T800@0100@HQS38@HQ1B469@H00RDU0RTW00DTi2C3?HQJK6Kb009RdP9VdP03H]9R
df;C00AVd`04I_AVlfKcI_<5I_@9I_<3I_@026[dJ_=Zlf[dJ_=Vm6[dJ_D3J_@01V/DJa=[4f/CJ_=Z
lP9Zl`03JaA[4f/D00I[509[4`AZl`=ZlPEZl`05J_9Zlf[cIaA[4`03J_<2J_8016[cJa=Zlf[b0f[c
00A[4f/BJa5Zl@9ZlP04J_=ZlV[bJ_<:J_85J_<5J_83J_<6J_800f[aJ]9Zl`05I_<5I_800fKcI_9V
lP02I_800fKAI]9VdP07I]84I]42I]85I]43H]82H]400fK@H]5V/002I]400fKBH]5RdP02H]401FK@
H[5V/6J`H[001F;@0V:`1F:_00AR/5j`G[1NT09N/003H[1N[ej_009N[`AN[PAN[`03GXiNSej>00IN
SP9JS@=JSP=NSP05FXmJSUZ?FXmJSP02FVh4EVh3FVd01EY^FVeFKUY^FVd00UI]00QJKEY^ETiFCUI^
EVeFK5I]0UI^25I=00=BCE9>DTh0159=0e8]0U9<0U8/00=B:e9;DT/00Ti<0dh/00=B;58[CR/00dh/
0Th[0Th:24h[00=>2dh:CPX01dh:0TX;00=:2TH;APX00dX;14H;0TH:0TX:00Q62TX:APU62TX:APU:
2TH90TX90DX80DG[00001Pa2540LXRd3>FI5j`9B;004DReF;eH_ETl5ETh2ETd00e9>DTmFC`02ETl4
ETh02EI=ETiFCeI?FTmJCUY=ETiJC@03FTh015Y<FTiJCEY?0UY_00EJCUY<FR]J:UX:009J2@AJ2P04
GPYN:EhZGPX2GPP09dg;?BM114V6ENUN1eh8GPYJ2Uh:GRUR9ehZGP]RCFJ@J]9Z/F:AFRmEkU6]ENiN
D5ibHW1NCV9_HY5ZdfkBIT/m9SD6?FQ5jdh=DReFL@02FW403EZAFY9JTUZBFY5JT5Y]HZeVbceX78@<
811100<DHP07668HHAbQ7:<Pa1bS7:800Qb200@HPAbR7:<LX`8La0047:<HPaR368825682468010a1
444@HA1Q0Q111aAR01<DPQR36:@LiBe6=FLiZ3F8<DL]9BTU8>HHQ10P688Pa1bS444<8@0232022204
22400`Q122488@04224222000`@0200880052202200232001PPP100400PQ220400888@03320400@0
008800888003100880@P00D400<000840003000400@0008400L00005100000@00004000300021000
10P0100400@010P000<<00P000000P001`@00`P00P`00`P000@<8A12448@@P8<@P03468<HPa200<@
@P0;56<LXbS4:>@TaART58@HaARU6:@LY0028<D00ac68>HPi@039>D49>H00b479>LPi`029@L02BTW
9@HPiBCU9BHU9bDV9@HU9`02:BP2:BL3:@H072D5:<@T`bcPAL=JB6[XJbacD6K>AN`mAcE7;B@XhaRR
344@@QR38<@Xi2C556@DHa12344<8@P01@PP00<48@PP22000`PP0`@00`PP00L480@0200401B27<<Q
1P029@D03bDV:BD]AReY:BLU1BC3?HQNS6LCJa=VlVKcI]9RdP02H]<6I]<2I_<00fKdJ_AVl`0;I_<3
I_@01V[dJ_=Zlf[cI_=Zl`9Zm0EZl`03Ja=Zlf[b00=ZlP9[4`M[50=[4`03JaAZlf[c00=ZlPEZl`04
J_9Zlf[cJ_<2Ja<016[cJ_9ZlV[b0f[c0V[b0V[c00=[4f/BJa800V/B0f[b0f[c16[b0V[a3f[b00=Z
lf[bJ_8016[b0V[a00=ZlVKbI_801FKb0VKa00AVlVKcI_9VdPIVlPIVdPAVd@9VdPAVd@06I]9VdF;A
H]5VdF;A0fK@16KA00AVdVKAI[1Vd0=V/003H[1Rd6;@009Rd004H]5R/6:_HZl2HZh3GZl015j?GY1N
T5j@0Uj`15j_00AN[Uj_GZiN[PAN[`9N[PINSP03GXeNSUj>00=JSP=NSP9JSP9JS@=JK@AJKP08FVaJ
KEY/FVeJKUI^FViJK@9FK@03FVaJKEY]009FKP06EVeFK5I<ETaFKEY/1eI=00EBCE9>DTiBCE9<009B
C@03DReBC59<009BC09B;09B:`03DRYBBU9:009>:`=>;005DR]>;4h[CR]B:`04CP/7CR/3CRX6CPX0
1DX:CPY:2TX:AP/00TX:14X;0TH;00=62TX:BPX00TH:00Y5jDX8APU:2DH9APY62DX9APQ:2055jP00
00H<8aA1560XhcEVAP`2ET`01U8]ETmF;eH_ETmBCPAFCP9BCP03DTmFCeI?00=FC`9FCP03EViFCUI>
009FCP04FViFCUI?ETl3FTl2FTh025Y_ETmJKeY_FTiJC5X[FRX2FPX00eX9FPYJ2P02FPX08EXZGRUN
:eh[HRUVB57:@DU19DfXENUN9eh8FPYJ2eh;GRYR:Eh[FP]RCFJ`J]5V/F[CI[=VTeiAHY9V/fKDI[9R
T@02HW4046JBK_AZKD58=@HiATW[CPeB;EI`FW5JLUZAFY9JTeZB0UZA00MJKV:^ETheAaR4448DH`04
68<01QR27:<Pa2347:@LX`8LP`0368<LY234008Pa0037:@HXaR3008HPP05588DHQ1R468@@P034642
4682464356804A1Q344@HQ1R58@LaBDU;DL]AS57;BHY1B3V7>HHQ1bT8<D00RT600@PiAR3568@@P88
00<400<48003124400@000@40003000400@000D400<0008401d000031000000000800003100800@0
00H40009300<80`0400D821Q744@8100008H@@0956<LPaAS444HHQaS88@PYB2T008PX`0@88<PPRB2
988/`cD5>@DmB3TX;<D/aS3V>BPiBCDX;@L2:>L02BT7:BPY22T8;@PXibd7<DPaA`02;DP01bT79>HT
ibdY:@PY1c59008]JP8]B@03;BP]B35800H]B@04:BTU1b3V8>H27<D01b358@DQ9bDW9@LLaR3V008U
1`8PiP0N8@HU9bT69<@PXbd2@JABBVK9Mi5k/gNFGXi5R3E7;DL]1AR2320400`P7:8]12T57:@HQ1AS
34880@@00`PP00@88@PP1204808400<88003100800PP0088@009344<@Pa1348DPac38>DU92DU008Y
9P07<FPYAbTW9@HXi3U7ET`00VLC00=VlVKBI]<016;C00AVdfKDI]AVe09Vd`9Vl`03J_AZlf[d00AV
l`9Vm003I_=Vm6Kd00MVm09Vl`03I_AZlfKd00AZm0=Zl`9ZlPAZl`IZm0=[5004J_=W56[cJ_<4J_84
J_<016[bJ_=Zlf[c0V/C00=Zlf[bJ_<01V[c0V[d00=[56/CJa<00V/C0f[c00=Vlf[cJ_<02f[b00EZ
lf[bJ_9ZlV[c00EZlP03J_=VlfKb00=ZlP04J_=[4f[bI_42I_800fKcI_9VlP02I_8016[bI_5VlFKb
0VKB00IVdFKbI_9VlfKBI_89I]82I]42I]800fKbI]5Vd@04I]43I]05I]42I]82I]44I[0016K@H]1R
d6;@0f;A00IR/6:_HZiR[Uj_GZh2GZl00ej@GY5N/002G[000ej_G[1N/003G[09GZl00ej?GXiNSP02
GXh01EZ>FXmJSeZ?FXh01eZ?0UZ=0UY]00AJKUY_FViJKP=JK@9JKP9FKP05FVeFKEI]FVaFK@03EVh0
0eI]EVaFK@02EVh00eY/ETaFC@02ETd2ETh2DTl3DTh2DTd0159>DTeBC59<159;1E8[1dh/0Th[158[
00=>:dh/CR`01Dh[14h:0TX:1Dh:00=:2dX:AP/00dX:0dX;0TH;0TH:14X:00=:2DH:APX00dH:0TH9
0DGX0DG[000050@2424DH2C4>FI:35I<DTaBCEI>ETmF;UI?ETiFC5I=ETaFCEI>ETl3ETh2ETl3ETh2
ETd015Y]EViJKEY^15I?0UY?1EY_00EJCUY<FTaNBUXY00MJ2@9N:@0;GPUN2UhXGPMAbD5X@BA5Qe7X
GRIN2002FPX07eh;GRYN:Uh[GPaVKVZ`J]9^m6lEK_AZe6ZdJ]Ac5W<fK_=VTf9cHW9V/fkdJ[15RC45
=BE5jTh=ETiFD5Ya00EJTP08G[9JTEY^DPdmRBc578@DH`8HQ0<HP`04788P`b346:<568<01AR268<L
XabT6:<00QB20QR20QB200<DHQ1244400a110Q1Q0Q1R00D@@AAQ564@@0a1008<8@0758<HaBTV9>DT
i2CU8<D00Qc50Qc600XTiS57<FPeQbdW9@HLaA1R200000<401@000<40004000400@0100300061000
2@PP224<@@PQ10088@a134<<H`0334<02A1U48DDQ1RU6:@HQ1RU8<DTa@039>D01bT6;@L]1Rd7<BLe
:3U8008mJ@0<?DU1JTF;AH]1Rd5[?H]5[4G>@J`mRd6]0TG>00i1[DW^DU1JCeI@ES1B3eH_GU1RL6:A
J[9VTeiA0UH@00AJ<5i@FU5B<09:4005BS5>DDYBBS11k`03@Lh03d7^APi5kT7^?Ldm[CV]>JhicSg_
AQ16<48?@Nhmc@03>J/2?L`3>J`01cV[=HXaBBd79>LU1RT7008Y9`<U:00H9@PU1bT8:BPY:BDY:DTY
:2TV:>DPXabR;@11YDhYGZYgKVl_GV`mIS4V:BLLY1AQ0P`P00T@81R19>8Xi2d58>HLYAAU10800`00
0P@00P@P00H40000100880`P34023440111R588HXaRS0aB300HHXb3T8>DU92DU:BD2:BH2:BL01RTX
:>HiAeI;Ha=VlPARdP03H_=Vdf;C009Rd`9Ve003I]=VlfKc009VdP03J]9ZlVKc00=Vl`EVm09Vl`QV
m003J_=Zm6[d00EZl`=ZlP=Zl`03JaAZm6[d00EZm0=Zl`05JaA[4f[cJ_=ZlP04J_<5J_800fKcJ_9Z
l`06J_<00f/CJ_AZm003J_<2J_84J_<016/CJ_=[4f[c2F[b00=Zlf[bJ_<02F[b0f[c2F[b0fKb1FKa
1VKb0fKB0fKA1fKB16KA00=VlFKAI]0016K@0VK?00=Vd6KAI]400VKA16KB0VKA16K@16;@00=R/6:_
HZl016:^0Uj?00=N/5jaG[400Uj`00=N[ej`G[000Uj`00=N/Ej`GZl015j_0Uj@00=N[ej?GXh00ej>
15j?00=NSUj?GXl00UZ@0eZ?00IJSEY]FVeJKEY^FVl2FVh3FVd2FVh00eY]FViJK@03FV`02UI]FVeF
KUI^EVeFK5I]EViFCEY/15I=00EFCUI?ETmFD59?009BCP9BC@03ETeFC59;00AFB`03DT]B:e8[00=B
:`I>;003CR]B:Th[00E>:`9>;003CR]>:Th[009>2`]>2PQ:2P03AP]62TH:00962PA:2PI62P962@5:
2055j`0000H<A112564Pa3UWAP`2DTd2DTh02U8]ERiFCUI>ETaFCEI<ETeFCUI?0eI>0UI?00AFCUY=
FTiJC@9JK@9FKP05EVmFCeI?EU1FL002ETl6FVl01UY>GTeNBeX[FRYJ:@=J2@9J:@9N:@0;GPUJ2Uh9
GPQAbT5X@DI1Ie7YHTMJ:002FPX04eX;GR]N:eh]GPeVKVkAMcAkE7]FLaE^m6kDKaIc5fkeI[9VTfJd
009R]00;J]EV/TG=<@LeAdGZCPeFCUI`FW5JTP03GY803UjcG[9JTEH]?HTXa1aR68<LYAbT78@HPaQR
78<27:<26:<00aR358<DP`0358<5588258<25882568244401aA1444<8111568DPaB2008DHP8DH@<<
@@0358@HaB46008La00368@@HQR3008La@0:7>HU1be7;FPYAb476<@DY11R200210001`P0100400@0
1208@@PQ00<4000:224<@Pa124488@P0220<@@aR3482468031AR6:@HY1RT68@HYAbU6:DHQ1bU9>HU
1`<Pa@0::@H]1bT6:@H]:359<FXaBC5:;DT2;BT012e:=F/eS35Z0c5900/iJcf]@Li5kTX>CS1FLUZC
G[=N]5jC009NT@04H[=Ve6KEH[D2H[@056KEJ_M[5f[fI[ARTfJdJ]MZmfKFI[EZeFlgMgUcNG=HKcQc
>7MIMgT2MgX00g=JKcQZmP02I]H016KfH]IN]5jD0UkF00eJ]EJeEYABLe9CEW=FM5IcDU5BLUIbCU9>
D@02CU8024YBCW9>Le:CDYA>LTHa@Ph2@Nh03dH?AS1:DDH`ARm1kCV[=FTa:2d9;BTeRcV/>L`ec@02
=J`05c5[:DT]:BdX;F/YK2UZ9BTPiQc556<<@AAQ8:4Y0cg8CR]FKDG9>BDXiARU46800Pa000X@@1AQ
680ThbT5;@D]9bD76:D40@@00004220<H@aR3683468258800aB36<@PiP028>H022D78>HLaARU6:@U
1BDU9BH3:BH02BTW;DL]Abe89>DmJEY/HaARl`03H]802F;CH_=Rlf;CH]ARm6KdH]AVd`02I_<2I]80
0f[BI]9Vl`03I_<5I_@00fKcI_AVm005I_D016KcI_AZlf[c0V[d16[c0f[b16[c1V[d2f[c00=ZlVKc
J_800f[b2F[c00AW56[cJaAZm0=Zl`9ZlP9Zl`04I_AZm6[cJ_<2Ja<016[cJ_9Zlf[c1F[b0f[c1f[b
16Kc00=Zlf[bJ_802V[b1FKa1VKb00AVlfKBI]9Vd@QVdP03I_9VdFKB00IVd@9Vd003I/mVd6K@00EV
d@9VdP9RdPARd@9Vd0ARd004H[1N/6:`HZl3HZh2HZl016:aG[5N/Eja1Uj`00=N/Ej`G[000ej_1Ej@
0Uj?0Uj>15j?00ANSUZ>FXiJS`9JT09JS`04FXiJSeZ=FXh4FVl01UY^FVeJKEY^FVeJC@9JK@=JK09J
K@9FKP03EVeFK5I]009FKP07EVeFKUI^EViFC5I=ETh00eI?0UI>0UI=0UI<15I;00=BBe9<DT/00e8/
0U8[1Dh/0dh[1dh/00=>:dhZCPX00Th:00=B2Th:CPX01dh:2DX:00A:2dH:AP]62`962P9:2P9:2@03
APY62dH:00962P03BPY:2DX80055j`0000T88a12588Pa3E6@LY>;5I]DT`00U8/0UI>00AFCEI<ETaF
C09FC@04ETmFCUI>ETh2ETl00eI>FTeJCP02FTd00eI=EViFKP02ETh00eI?EU1FL004FVl015Y>FVmJ
KeY_0UY>00AJ;5X[FRYF2P9J2@=J20=J2@0:GPYIjF8YDLY5J4V8BJUEjUhWFPP3FPX07eh[GRaN;UX=
HTa^l7]COe5c<g<DK_=ZdfJcHW5ND69`IY5RLF:BHY=ZmV:BCNh]23E8AN]>3EI>ETmJL5ZA00=NTP0=
FY9JTEZ@CN`i:2AS668LPb358<@LY1b478<00QbS00<LXQR256400Q1100<@HQ1244800QAR00<DHA1Q
56400QAQ00<DHQAQ56400QAQ0Q110Q0Q00T@@AAR568DHQB2688HHQA144400Q230QB300DDY1RT6:@L
Y1RU008DQ00;6:@HYART58<HY1c56:@@Pa1S48<DP`04468348800a2358<@P`0248@02QB46<DLiQc5
5:@DYAS58>HU1bDW0RD70RT700D]9bdX;DPaBC5Z008aB@03<FTiRcf[008mb`06?JXiRSF9>HY1c4G/
0T7<00=1cDG]ANh00TG^0TX>0TH=00=:3TH>BPl00Th`00I:<4iAFW5NTF:bH]<2H]@01VKEJ_E_5Vlg
KaI[5P=ZmP07KaM_>7=HLeU_=flFJ_H00V[g0VlH01A_>6lGKcMgNG^KNgUgNG]jOiYkVW>KKcQ[5flG
KaQ_5f[fI]IReUkE0Uje0UZe00MFUEIcDWAFU5JEEWA>DP02DU801Dh`BS1:<4haDU400U9a0diB00AB
LDi@BRm:<096400<@Pm1kSg>?La1k47]>JXa:2d9;DTaJReZ0c6:00<]JBU8:BT00R3W00`Q21e:8F/M
BadZ5>PDYPaU12848A1S:BL2?LT01SV7<@@HP`P00004008<@004440HP2CS;BH2<DL042dV7<HDQ0`R
224@HaB35:<Ha1S56<@HY1BS6:@LaB3U0RD600XPiAc57<@LaART5:@DQ1RT8>DUAP8U9P0?:BHYAbe7
;DLaARTV:>HmJ5Z<HcERlf;BH]=RdVKC009Rl`=Rm09Vm004I_=VdVKcI_<3I]86I_<6I_@4I_D016Kd
I_=VlfKc1V[c1V[b0f[c16[d1F[c1fKc00=ZlVKbJ_801F[b0f[c0V[b00AVlf[cJa=[4`AZl`=ZlP9Z
l`9Zm004Ja=[56/CJa<2J_82J_<5J_801F[cJ_9ZlV[bJ_401F[b0fKc4F[b26Kb0VKc00IVdVKAI]5V
dFKBI_42I_8016KBI_5VlFKA0VKB0fKA1fK@16KA00ERdF;BH]9RdV;A00IVd006H]1RdF;@H]1R/5j`
0V:`1F:_00AR/6:aG[5N/@=N/003GZmN/5j`00=N/004GZmN/5j_G[04GY02GXl2GXh4GXl015j>FXiJ
SUZ?0UZ@15Z?00=JSUY^FVl00UY_00=JSUY]FV`00UY/0UY^0UY]0eY/00IFKEY]EViFKUI]EV`3ET`0
1EI]ETaFKEI<EV/00UI<00=FCEI>ETh00eI=0UI<0UI;00IBBeI;ET]FBe9<DT/3DR`3DR/5CR`2CR/6
CR`2CR/3CRX00dh:DPY>2P07CPX;BPX014H:AP]62dH:0dX:00A:2DX8ANU1j@=62P03BPY62DX70055
jP0000`890a2324LaC57@N]BCE9]DTaF;5I>ETl2ETh3ETd8ETl2ETh00eI?ETiJKP05ETh00eI?EU1F
L002ETl3FVl02EI?FVmJL5Y@FTiJC5XZFRUF2P06FPT2FNT02Uh9FNUIjE7:BJU9R4g9EPYJ9eX90eX:
0UX/00aJ;UW]HP]^d7<cOe5c4flEJ_AV/f9aHW02HY007F9aGU5RTV:CI[ERTdG>;@Ta:4G;BPeB;EI?
FW1JTEjBGY=JTeZBFY5JL5H=?DPXY1aR8:@LaAc47:D00QbT00@LXaRS688DPP8DH@05568DHaAR568D
H`05468456800aAQ444@@00244402Q12568DHQA2568HPQAR444DHQB20QB300@DXaBT5:@DY08HY0<H
Y@046:@DY1BT58<258@00aBT5:DDY0035:@01QRT6:DHaAcV8>LQ1`@LiP037>LQ22DX008U208YB@8U
:00;;FX]JBE9:BPU:2e9<F/eRS6;=H/aS002>J`2=H/01Sg=@Pi1kSV[>H]1c091k@0;ANe1c47<ANe6
3TH?APi5kTX_CU1BL003CU000e9@DU5FL003EU4015YaFY9N/ekD0Ujd0V:d00=ReF;fI]D00V:d00=V
eF[fJaP00Vli00=_=f/GJ_H00V[f00I[5flhKcQ_>G=IMeP3LcP01GMHNiYgNFmJIaL00V[g00=Vmf[f
H_H00UkE00EN]5ZdFYAFUEJD009FM003DWAFTe:E009FU003DW=BLU9a00=>LP9>D@0QCU1:DDiACU5>
<DXaBS16<4H@@Q123d7^@Li1cDH<@NdiRRdX8<LLabD98BTLiaSV7>HHaQRU5:@LiRU::H`]cc8@00<b
4@0;<M0][b5;6>THj1cW9DTa[3F9:>D@HP0300003@`P340<@1R18><]AS57<DPaAbT77:DDQ1S500<Q
1`058>LLiQS56:@DY00258<01QRT7>DLiART6:<DX`8DY00858@DPaBS7>@Q9b469BHY9P8YA`08;DP]
ART59<<iIeI/HaANe0=Rd`AVm09Rm003I_AVlfKc00IVl`05I_AVlfKcI_=Vm002I_<5I_@01FKeI_AV
mFKEI_@00fKc0fKd0V[d0V[c00=ZlV[cJ_<016[c16[d1V[c2fKc00=ZlV[cJ_<03V[c00=Vlf[cJ_<0
1V[c0V/C00=Zlf[bJ_<016[c0V[b00=Zlf[bJ_801F[b0VKb1FKc3V[b36Kb00EVdVKAI]5VlVKa00EV
lP03I_5VlVKB00=VdP9Vd@=Vd0MVd@=RdP03H]5Vd6K@00=Vd0=Rd@04H]1R/6:`G[02G[42H[001F:_
H[1R/6:`H[400Uja1Uj`00=N[ej`G[000Uj_00=NSej`G[000ej@0Uj?00=NSUZ>GXh00Uj>00=NSeZ>
FVl00UZ?0UZ@15Z?00=JSUZ?FXh00UY_00=JKUY]FVh00UY]15Y^0UY/00=JKEI]EVd00eI]00=FJeI<
ET`00eI^00AFCEI<ET]BC09FC09FC@9FC003ET]BC5I<00EFB`04DT]BC59;CR`5DR`2CR`014h]CRa>
;4h[1dh/1Dh[14h:1Dh;0TX;24X:0TX;14H;0dX:00=:2DX8APX01DH:0DX:0Dh70DW[000030@2328<
81bU<DM5je9=DVeBCEH/ETiFC`IFCPYFC`EJC`03ETiFCEI>009FC`9JC`=JK`07EW1JL5Y`FW1JCUY=
FRX00UX900AEjUH:FPUJ2@9J20=N1`0/GNQIjEG:CJU5ITfXENUN9eX8GPUN25hYFRYN:eX^FNeR2fj_
L_9k<G<DKaE^mF[eJ_A^m7<EK_AZ/f9cHU5VTV[EI[A=kbd9;BQ1bTg/DRaFCeY`FY5NTP=NT`08FVmJ
TEi^@FT/XaaR9<@Pa0<LY0048:@LXabS788266436882668256824680111Q468@HQ1R0QAR0QAQ00/D
@AAQ564DHAAR68<LY1cU:@DY1Qc4008HX`06588DXaBS5:@@PaB40aBT00HDPaAS58@DY1B458<358@0
11BT6:@HaAS40QRT00@HaART6:@La@<Q1`038@HU1bDW00DU1`<U9`079BPU22DX:DTY:BTX:BT00be9
00L]JS5Z<FXaJSF:>J/eS002=H/01CV;>J/mZcg<?L/00T7<00E1kD7<?L`mc47<0091k@04APi5kTH>
BPl2CPl00dh_CS1>;`02DS003eIAEW5JTUZBFY=NTejcG[EN]6;DI]AVeFKfJ_IVm`02J_L01VlGKcMZ
mF[eJ_I[5`9cF09c>09g>0=c>00;MeQkN6mIJaQZef[gJaQVmVKFH]EN]@02G[@00ejDFYAJU002FY@0
1UZEF[EF]EZeEYAFLP9FL@05DU5BLTiBCU1><002CU00159@CU5>DDha0TXa01Y6<48@AQ11kd7^@La1
jcg;=HXU1a1T34<<@PaS22440@00248HibV<>Pm2DDJd@[E2]T;G0T;H01A6fD[HD_Q6UcHB8FhI31T9
8@LLaP`S100000@0220<80PP440L`bdU0c5700HY1Qc46:<HY2DW8@H26:@00aBT5:<DP`0234401Q1R
588DXQBT6:@DX`<DP`08588HPQRS7<@M1b479@HY9P8YA`0:;DL]9RCS:<4iAEY/H_=Ne6;CI_@2I]<2
I_<5I_@5I_<00fKdI_=Vl`07I_<016KdI_=VlfKc0VKd00AVmFKfI_AVlP9Vl`03I_AVlfKd009Vm003
J_AZlf[b00QZl`9Zm0IZl`04J_9Zlf[cJ_<2J_800fKcI_9VlP03J_84J_<00f[dJ_=Zl`03J_<01F[b
J_=Zlf[cJ_801V[c00=ZlV[aJ_8016[c0V[b1F[c00=ZlV/CJ_<026[b00EZlf[bJ_=ZlVKb00IZlP03
J_=Vlf[c00IZlP9Vl@AVlP9Vl@=VlP05I]9VdFKAI_9Vl@05I_800fKaI]9VdP03I]8<I]43I]800f;A
I]1Vd003I]0036KAI]1RdF;@H[1R[f:`H[5N/F:aH[1R[`AR/09N/@EN/0=R[`06GZmR[Uj?GXmN[ej`
0Uj@00ANSej>GZmN[P9NSP04GXeNSUj?FXh6FXl015Z>GXiJSUZ=0UY]0UY^00AJKEY/FVeJK09JK@=J
KP04FVaJKEY]EVd3FV`2EV`2EVd2EVh2ETd00eI<ET]FB`07ET/01E9<ET]FBeI:DT/00UI;1E9;1U8/
0dh/00=>:dh/CR`00dh/1Th[00A>2dh:CRY>2PI>2`03BP]>2Th:00I:2PA:2`03AP]:2dH;009:2P06
BPU:24h7APM:24H90dX:0DX90Dh70DW[00002@PR324801R3;@HmbTi=DVeBCP02ETh3ETl4ETh01EI?
DTmBCeI_ETl00UI@0UI?00=FCUY?FTh015Y>00MJKEY^FViJKeY?FU1JC`02FVl02eI`FVmJL5Y`FVmJ
C5XZFPUEjEGZEPX00UX90UX800eN25h7GPMN25h9FNYAZ4UUBHMEb686GPMN2002GPT07ehZGR]J;UW]
HRa^[fkBLa=_5G<FL_Eg5GmgOgEkMg<fI[AN<F9AIY9^eF[CES8a:bd7ALY>35H/ETmJL5ZA00=NTP0<
GY=NTEjbGU11JRRT888TY2357:@La2350R2T00TLXab2664HHAb17:8LXab252000Q110a1R0Q1Q00@D
HA11564HH@8@@00>540D@A0Q568LY356<HTeR3W:<FLLa1RS588DP`8DY0035:DDY1BT008DY0056:@D
HQB358@DY00458@00aBU6:DHY@036:@00aBT6:DHY0026<D011cU7>HLiR460R4700<PiR3W8>L00b47
00<U1bD89@P00RDX0RTX0RTY00<]BBe:;FX00ReZ0S5Z00<eRSF;=H/00SF;0cV[00@mZd7<@L`mc08m
c@8mc006>H/mcD7]ANe5kTH?0dX?00M:;dh`CRmB<59AEW5FL`03FY<01ejDG[EN]F:dI]EZmFlh00=[
5`9_5`9ZmP05J_E[5V/hKcM_>002LcP04GLgMeQg=gLgLcQgFG]jLcQ[66lHKcQ[66KgI]IReF:eH[@0
0Ujd15ZD0UZd00IF]EZeEYAFLeIaEW02DU42CU42CS401DiADU5BDU9ACU800TXa00]6<4HA@Q11l47_
@Ne1bcg;=HTTi`P200H000085:Da[CibA]A764/HCaQ:m`9:n00<B_U:nT/JCaY?>TKi?[Pj<RV>5:H<
A0PS10000P@000@<81bS;BHaAP8aA`0X8>HHXa1Q6:<PiBD57:<HY1B3588@HPaR244<@A1R58<DY1BS
5:@DXaB3568@HAR258<La1cV8@HU1RTV:BP]:2TW9@DPXRSP>DAFBf;cH_@2I_@016KcI]=VdfKc1FKd
1FKc00=Vm6KcI_@01FKc26Kd0VKe00=Vm6KcI_@016Kd00AVlfKdI_AVm09Zl`03J_9Zlf[c00AZl`03
J_AZlfKd00AZl`]ZlP=Vl`=Zl`9Zm0=Zl`=ZlPQZl`9ZlP04J_5ZlV[bJ_82J_<01V/DJ_=Zlf[bJ_=Z
m09Zl`9Vl`03I_9ZlV[c00MZlP05J_=ZlVKcJ_9Zl`05J_82I_<00f[cJ_9ZlP04J_87I_43I_801FKa
I]9VdVKbI_401fKb16KB36KA0fKB00=RdFK@I]000fK@00ERdF;@H]5VdF;A009R/003H[5N/F:a00ER
/004G[1N/EjaG[44H[04HZl00f:^HZmN[`02GZl2GY0015j?GZmN/5j^0Uj>00ANSEj>GXmJSPAJS`07
GY1NSej>FXeJSeZ>GXh00Ui]0UY]00=JK5Y]FVd00UY]00=JKUY]FVd00UY]0UI]0UY/0eI/0UI]0UI^
0eI=0UI<1EI;00AFC59<DTaBC0EFB`EBB`03CRaB;58/00AB;09>;09B;0A>;0=>:`08DR]>2dh;CP]>
2ThZCP]>2PE>2`9>2P9:2`E:2P04BP]:2TX:APX2AP/02DX:BPU62TX9CPQB1TWWBPY62P02BPX00dH:
APU:2001AN/0000;224@8@`P568Y1D7:DTaFKE9=DReFCP03ETl01EI=ETiFCUI>ETl00e9?00EFCeI@
ETmFCeY=009JC`05FTiJCeY?FTmJCP02FVh01EY]FTiJCeY@FTl01UY_00MJKUY<FRYJ2EG8ENYF2P02
FPT04EX8FNQIj5h8GPMMj5h9FNYAZ4U5AFIAaf85GPMN25gYFPT00Uh901QN;5g/IT]^[fkBLa=_5FlF
KaEg57]DNe=[4fJcHW5J<69@IY9Z/fkcFU4eC2d6ALT2DR`015I>FW1JLEZA15jA00MR/eX^@H/XY2B3
8:@Ta@038<D032348<<LXaR2684LPB2R9<8LXQb1520800840009324@HP`P320<0110684LPAAQ008@
@00=420@@A128<@mQSg9AP/mjcEX8>DHY1B25:<01aBT00<DPaB258800QB31QB400@DY1RT6:@DY08D
Y@076:@Ha1S57>DLiR467@L00R4700LQ1R3W8>LQ1b468@LU1`029@P00bDX:BPY:002:BP02RdX;BT]
BRe:;FXaJS5Y<FXeRCF:0SF;00DiRcV:>JXiZcf[00=1c08mc@@mc005@La1kDG^APi63`04BPl03Th?
CRmBDEIaFW9JLeIcFY=NU5jeG[IN]FKEJaH2KcL02VlFKaM_5flFJ_EZeFJcJ_E_>7<g0Vlh00Ic>7Lg
MgUkV7MHLcP2JaP036/hKcM_5f/FJ_IVmVKFI]ER]F:cG[ANU0AJT`9J]09J]@06F[AJTeI@EW1BLE9A
1DiA0e9A00i>DDYABS5:<DHA@Q52447_@Ni1c3g<=HTPi`@11@0000H8@REZAW575TlgA_L2B_P3C_P0
34[hB_U:nE<jFgaOW5MKCcTnM2f_5:T40`<00006100800@0344HXbTV0SE600Xa9RCU588801B16<<U
123T6:<HP`8DQ00658<@H`a2468DPQB30QB20QB301<@HQ1Q584DHQB37>HPiBD6:@LU9be9:@LTaB2Q
:<0mHeI:Ia=Vm002I_<2I]<2I_<00fKdI_=Vm002I_@=I_<00fKdI_=Vm005I_@2I_D00fKdI_=Vm004
I_@01FKcI_AVm6KdJ_@00f[c0f[b16[c00=Vm6[cJ_<00V[c0f[b0f[a1F[b0fKc00=Zlf/CJ_<016[c
16[b1F[c16[b0f[a0V[b00AZlf[dJaAZl`=ZlP04J_=Vlf[cI_<8J_800f[aJ_9Zl@04J_82I_800f[b
J_5ZlP02J_82I_<5J_8:I_400fKbI_5Vl@05I_45I_800fKaI]5Vd@0=I]43I]800fKAI]1Vd005I]02
H]000f:aH[1R/@03H[45H[0015j`G[5N/Eja0V:`1f:_00AR[Uj_GZmNS`9NT09NS`04GZmN[Uj>GZd4
GXh2FXh4FXl00eZ>GXiJS`02FXh00ei]FVeJK@07FVd9FV`3FV/00eY/EVeFKP03ETd2ET`2ET/3EV/0
0eI<DTaBC003ET/2DT/:DR/6DR`5CR`3CR/3CP/6CPX4CP/00dh:BP]:2P08BPX2BPT2BPX2BPT2APT0
1DX9CPM5jDG[AP/00TH:00=:2TX9BNT00DG[00002PPQ348DHQR3;@E1bUI<EVeB;E9>1EI?00ABCUI>
ETmFC`ABC`03EU1FCeI?00AJC`=FCP03FTiJKEI^009JKP06FTmJD5Y@FTmFCeI`0eY_00MJKUY<FTaJ
:EG9ENYF2P04FPT2FNT2GNP025h8ENYAYd4SADAAYf86GPP3FPT2GPT02Eh/GNYV2Vk?L_=c4g<EKaIc
5P02LaD00g<DJaEV/P03HW4036JBJ[9^lUH?<@TXY4G:DRiB;EI_FW1JT@9NT@0:HY5NTEYaGW9ND4F;
<>HXaBd7:>H2:>D29<D2:<@04bS39:<XXRRQ;>4a0Rc2888@80P0320<@A10320@81A078<X`c3R008/
hP0=<@@`hb2356<HPc4V=HXeRCW:=HTQ1aRT58<01aBT00@DQ1B358<DPP8DP`0348@DQ1B400@DQ0<H
Y0086:DHaAS56<DLaAcU7>HM1P8M1`TQ1`039@PU:2TX008Y:0<Y:@8]BP03;DTaJC5Y00<aJP@eRP03
>HXiZcf[00=1c007ANe1kSg=?L`iZcg=@Ld00T7^00=5kTH?APl00TH?01E>3Th_CS1BDEZBFY=NU5ZD
GY=NU5jeG[IN]FKEJaI_=flfKaI_5f/GKaH00VJd00AV/f[fJcQcF09c>00=McQgFG^kOkYgNG<hI_IV
eflhLcM_5f[fI[@00fKF00=VeF:dH[@01Eje00INeEkDG]ENeEjdFY<2FW42DU400diADU5>LP03DW82
DU42CU4034XaAS52<T8AAQ123d7^?LdiZcV:8@P88PD000054:@YcD[DBeU;>002BaP00d[hA_Q6f002
B_P02d[iBaYC>UMLEgaKWEMlCe]2]bf_58L00`0001@400P0200<@ARS;BHeISE6<BDPaAAR200@H1S3
8@DU1Ac46:<DQ1B30QBS00DDPaBS6:<HPaR2008DPP0C58<DPQAQ584DHART7>DQ1BD69@LU:2TX:@LX
iRC2:>0mQUY[I_800VKc00=Vm6KcI_<00VKc00=Vm6KcI_@026Kd00=VlfKdI_@01fKd00IW56/FJaIV
mFKdI_D8I_@026KcI_AVm6KdJ_AZlf[bJ_<3J_83J_<016KcI_AVm6Kd16Kc1F[b00AZlf[bJ_=ZlP9V
l`03I_AZlf[c00IZl`=ZlPEZl`05J_9Zlf[cJ_9Zl@04J_800f[cI_=Zl`04J_801f[cI_=ZlfKcJ_9V
lV[b009Zl@QZlP03I_=ZlVKb00IZlP9Vl`04I_9Vlf[bJ_84I_84I_400fKAI_5Vl@05I_800fKaI]5V
l@05I_800fKaI]9Vd@0>I]401F;AI]9VdVKAH]400fKA00ERdFK@H]1Rd6:a009R/004H[5N/F:aG[42
H[401V:`H[5N/5kBG[5N/09R/003HZmR/Ej`00EN/0AN[`9NS`9NT09NS`05GZiN[ej>GXmJSP0;FXl0
0eZ=GVeJK@03FVd015Y/FVeJKEY]1EY/0eI]00=JKEY/FV`00UY/00=FKEI<ETd00eI=00ABCEI<ETaF
B`9FC003ETeBCE9=009BC09BB`IB;005DR]>;4h/CRaB:`05DR`8CR`2CR/2CP/2CPX014hZCR]>2dh;
0Th[0Th;0Th:14X;0TX:00=62TH;BPX01TX:0TH:0TX:00=::dX<BP`00TH;00=:2TH:ANT00DG/0000
1PQ2348@@QR3;@@mQ`9BC003DReBCUI?00EFC`9FCP04ETmBCeI?ETl2ETh3FTl2ETl00eI>ETeFKP02
ETd01UY]EViJKEY^ETiFC`=JK`9JL00<FVmJKUY^GVaJC5XZFNUIjUGZFNUJ2EWY15WZ00UMj68XGRUE
YT41AD=EYF7VGRP00UX90eh900UN2V7XHLI^[W<DMaEg=GLELcH00W<F019g=W=HKaIZdfJcIY9Z/fkd
K]5J3CD8;:91RDX>DRiFKeY`FY42GY403V:AGW5NLEYAGU55ZceX=BP]22d7;>H/iBd5;>D2;>@06c44
>DDiACeU@JM5bDFW<><HHaA1420DHAAP540@@22S<@A1QdFU?F@mIDFXCNU1RRRU58@HY@028<D011c4
6:@DXaBS0QB300DDQ1B35:@DY1B400<DP`0348<DPQ2300@DP`<DQ00558<HQ1RS6:<HY0026<D27<D2
7>H00b467@LQ1`088@L00b489BPU:@02:BP012T8:BTY:BTY0RdZ00<]BC59<FT0135Z00LaJCEY=HXi
RSf[?JXmb`02@L/3@L`01Sg=@La1cD7<?Ja1cPA63`07ANi>3Th>DS1FLUYaFY<00ejC02IN/ejdG[ER
]FKEJaIcEg<fKcI_=flhJaIV]F:DI[AZmV/GKcMc>7LhMcMgNW^kOkQgN7<hKaQ[66/iKcM_>6[gI[EV
eVKGI]IVeFKD0V:e0eje00URe6;EH]ENe6;DG]AN/eYbFW400UIA00=BLUIaDW800U9b0e9A0Tia00=>
DDXaAQ000TH@00M63d7^APhmc3W;9BT88P0300003PPP140Da2g]BaE?>4lHA_M6n4;GA]M6n4KHB_P2
B_T02U<jEe]KO5^MHkiOWEmlAYL]KPP20P0001L400P0220<@ARS;DHiICDT<BDTiAAR200<81B17<<U
1Ac46:<DPaB26:8DXQBS00@HX`036:8DPQB2008DP@06688HPac48>HY9RD60RD700/U22T7;BL]9BSQ
?HIJBV;aH_9VdVKc00=Vm0EVl`MVm003J_=Vm6Kd00=Vm09Zl`04J_AZlf[cI_<4I_@00fKcI_AVl`02
I_<00fKdI_=Vl`03I_<2J_@00f[cJ_9ZlP04J_85J_<01FKdI_=Vlf[cJ_@00V[C0V[c00=ZlV[cJ_80
0V[b0f[c0V[d1V[c0f[b0f[c0f[b00EZlf[bJ_9ZlFkb009ZlP04Ja9Zlf[cJ_<5J_83J_<3J_800f[a
J_9ZlP07J_82I_<00fKbJ_9VlP06J_83J_<00fKcI_9VlP02I_83J_8016KaJ]5VdFKA0VKa0fKb00AV
lFKAI_5VlPAVlA=Vd@=VdPAVd@=Vd005H[1Rd6;@H]1Rd@07H[400ekAH]1R/004H[02G[000f:aG[5N
/@03G[03GZl01Ej?GY1NT5j@GXl00ej>00INSej@GXmNSej@FXh7FXl00eZ=GVeNK@02FVd015Y/GVaN
K5i/0UY]15Y/00IFKEY]FVeJKEY=FVd2ETd015Y/FV]FKEI<15I=00AFC5I;ETaFC0EBC@03ETaBC59<
00ABC005DRaB:e8/DRa>;003DR/2DR`5CR`014h[CRa>:dh[158[00AB:U8:CRY>:`E>2`E>2P06CP]:
2dX;CP]:2TH;1DX:14H:00=:2TH:AP/014H;00=5jdGZBPT00DG/00002PQ234888A1R:>@mR4h/DTeB
C59?2EI?00AFD5I?ETiJC@9JCP05FTmFCeI@EU1FC`03EVh6EVl00eI`FVmJK`04FVl2GVh015Y/FTaJ
2UX:0UWZ00=IjEX9FNT015WY00YMif8XHRUEYTDSADAAQEg5GPQIj@9N2@9N:P09GR]R2F77KZmc57LD
NcEoEGLg009c=`0EMeMkNG]HK_EVTfZcK_Ac=W<CGTm1Jc2S>FQ63Th]EVmJL5ZAGY5NTV:A00=NT@08
EPe9ZceX>FTeBC4X<BLa1P8a1@0Q=BDeACeWAJQ9jUI<GXeVkUI/@HPXaB2T8<<HPAQQ564LXbST>DI9
jE8ZCLQ5Yf9ZJZYBCC4X:<DPaAAR220<8111008@HP<DP`8DY08DP`8@P`8DP`03588@Ha2300@DP`8D
Q00468<HY1RS6:<26:@26<D011c57>DLiQd71b4700<U1b4X9BP00RDX00<U:BTX:BT00RTX00@]:Be9
;BX]B@8aB@04<FTaJc5Z<H/3=HX2>HX2?J/013f/@Ja1c47;0T7<00LmcD7=@Ldm[D6]@Li63`03BPl0
24g^DRiBD5I@EW9JLEYbFY82GY<01UjcG[AR]F:eI_I_=`9gE`06LeQ_>6lhJaQZmfKF0fKE00Q[5flh
KcQg>7MIMgYkVGMi0W<h00Mc>G=HMeQ_>6/GJ]EVe@03I]H2I]D2H[D00f;EH]IRe@05H]D00ejcGY=J
LP02FW82FY<01eJCEW=BLU9bCU5BLDib009BLP04DU5>DTXaBQ03APl014H_?L`U20PR0`0000X<H0A0
5<DYkDKECcU?64[gA_M6f096n0=:n00>C_UC6ULkEeaKWF>mHkiOWE=LAW@PZ@@3000400880008440H
XbdV>FDiACDU;@HDHP840007360HXAcT7<@HXaRT5:<02ARS018DPQR2588DPQR27:@LiBD59@HU9bD7
9@PY9bdW;DHThCUVET/2H_<00fKcI_AVm002I_D2I_@3I_<7I_@016[cJ_AZm6[d0fKc16[c00=Zm6Kd
I_@00VKd00=VlfKdI_<00VKC00=Vm6[dJ_@00f[c0V[d00IZlf[bI_9ZlV[cJ_82J_<2J_@016KdJ_=V
m6Kc0V[c00=Zm6KcJ_@00V[c00=ZlV[cJ_801F[c0V[d26[c00=ZlV[cJ_<00f[c16[b00E^lFkbJ_9[
4f/B00=Zl`EZlPEZl`]ZlP=Vl`03I_9Vlf[b00AZlPAZl`04I_=VlVKbI_85J_8016[aJ]5ZdFKa26Kb
0VKa2FKA00=VlFKAI]401FKA00AVd6KAI]5Vd@AVdPEVd@9Vd004H]1RdF;AH]47H[400ekAH]1R/004
H[000f:aG[5N/@04G[401Ej`GZmN[ej_G[0015j@0Uj?00=NSUj?GXl015j?0UZ?0eZ@0UZ?0UZ=00=N
KEY]FVd00UY]00=NKEi/FVd01EY/00=JKEY^FVd00UY]00IJCEI^ETeJKEY[EVd3ET`2ETd00eI<ET]B
C003DT`2DTd00eI=DTeBC@02ET`00e9<DReB;@05DR`3DR/00e8/CRa>;006CR`2CR/5DR/00e8ZCRY>
:`05CR/5CPX4CP/00dX:BP]:2P04BPX014H:BPY::dh:0TX:0TH;00I:2Th:BNY5jDGZBPT1AN`0000<
248<H`a2448Xa3fYCRaFCE9<DTiFCe9>0UI?00=FCUI?ETl00UI?00=FD5I?FTl00eY=00EJCUI?EU1F
D5I_00=FKP03EVmFCUI_009FL004EViFKeY^FVl3FW0025Y_FViJKUi/FTaJ:eX:FNX2FNT045X9FPQJ
25WWFPQMj5g7GNQEb56VAD@m0TE3FLEIj5WY0Uh901mN:UhYGR]MjF78JY5c=G/dNeEk=6lfI]EV/f[D
J]EZ/VJBHW9VTFkdLcIg=FJbAH/``cUXAPmB;EI?FW1JT@03GY80<EiaHY1R/EH<AJXmIcE8=BPeB3E7
<BLa9S4U>DDiIDFXDR]NC69[J^]_2VkYBNTe9bSS;@8LXAb268<LYBd4@JM>2e8[ERURJFkWOfIFBcf9
;><T`aAR100880`P468DPQB300@DX`0358<<HQ2300<DP`04568@Ha1R468258<458@25:@46:@01ARU
7<DPiB3V8@H00R4700<Q1R478@L00R4700@U1bDW9BLU:0@Y:006;DP]BBe9;DTaBBe90S5900LaJC5Z
<FXaJSF:=H/iRP04>H/00cf[@Ja1c002@L/02T7<?Le1c47=@Li5kdX>BPm>;dX?0Th?00EBD5IAEW5F
LEYa00=JLP09GY=N/ejdH[AVeF[fJaM[=flg009c=`06KcQ_66/GJaMZmfKE0V:e00MVmg<hMeUgNGMj
MgUgF@04MeP01W^HMgQc=VkfJ_IVe@9VeP9Ve@9R]@04H]EReV;FH]H3H]D01EkDG[=JTeIbFW800UZB
00mFTUIbEW5BLTiACU1BL4iaDW9>LE9aCU5><4X?BPh00TH?019:<47]9@P<@`001008H121140DaBW=
@[E?65<ICaU:n4lIDcT3EcX03e<ID_UC6E<jEe]OWF>MFgaSWEmmGcTe/1280004000320001aB2:@He
A3DT>FHa1QR300840005340DPBCT9@@HX`026:@56:<011R26:<HXaRS0QRR014DPQAQ564HXac48>DT
iBTV9BHY9bTV:@DY92d3>FEJJf;c00EVm003I_EVm6Kd00=Vl`=Vm003I_EVm6Kc009Vl`AZl`=Vl`=Z
l`9Vl`=Vm003I_=Vm6Kc009Vd`=Zm0IZl`MZlP03J_=Zm6Kd00=Vl`MZl`03J_9Zlf[b009ZlPIZl`9Z
m0EZl`=ZlP=Zl`06J_9Zlf[cJ_=^lFkb0V[b00A[4V[cJ_=Vl`EZlPEZl`IZlP9Zl@9ZlP06J_=VlfKc
I_=VlVKc1F[b1F[c26[b0f[a00=VlF[bI_801VKb00=VlFKAI]401FKA0VKB0VKA00=Vd6KAI]4026KA
16KB26KA0V;A26:a00=RdF;@H[001F:`1Uja00=N/5j_GZl00Uj_00ANSej@GY1NT09NS`=NSP=NS`03
GXiNSej?00=JT005FXmJSUZ=FXeNK@03FVd2FV`00ei/FVaJK004FV`2FVd4FTd01UI^ETeJK5Y[EVaJ
J`9FB`07ETaFCEI<EVYFBeI<DV`00U9<0U9=00=BC59=ET`00U9<0U8]0e8/1U8[24h/0Th[1E8[0ThZ
00=>:dh:CP/00Th[00=B:Th:CPX014h:00E>:dh:CPY:2TX;00I:2P=62@03BPU:2TH:00=62P04ANU6
2DH9BPT1AN/0000724<8H`PP444Ta3V9CRd00UI]00ABCU9?DTmBCPIFC`03EU1FCeI>00=JCP04FTmF
CeI@EU06EVl3EW000eI^EVmFL004EW000eY`FViJK@02FT`01EX[FPYIjUWZFNT00eX90UWY00]Ij5WY
FNUEjE78@DDm0dE2FLEIj5X9009N2P0OGR]N:UX/GNYMbVZbNeMoUG]EMcEZmEicFQ1EkUX?GU1J<5X@
GRmZe7=HMeMZeD5/=>DmJDH>DRaFCeY`FY800ejB00INLF:AGY1NBdG;>DP2<BP09bd8;@L]9c4W<BHe
ACU5@HI9jEHZGVUVbFlZJZU9jC4W9<@P`Qb2668LXbS4<B@iITh<EVeNBV:9MbMg1eY<=BHP`abR564<
00P0344@HP02588021BS5:@DXaBS58<@Q1B358@358<3368346800aB358@DY@025:D02QS46<DHaAS5
7<DLaR3U8@HPiad71R4700<U1bDX9BP00RDX0RTX00@YBBe8;DTaB0<]B@<aB@06;DXaJS5Z<F/eRcV;
0cV/00<m[3g=@Ld00T7<0d7=00U1kD7=ANi63dX?BS1>;dh`CS400U9A0eIa00QJLEYbEU5JLEjCG[AR
]6;E0VKf00][5f/gKcM_=g<gKcQ[>6lhLcQ_>6lG009Zm`06LaQgF7^KNiYgNWMi17=I0WMi00=k^WMG
KaH00V[f00AZmfKfI]EVe@9R]@06I]IVmfKgI_MReV;E0ejd00EJU5ZBFY9JTEIb009BD@05CS1:44ha
BU9>L@02CW800diaDW5BD@02CS407DX@BPm644H`@Nd]:@a3000880R03848H13U:Li2]E<HEcUKFU<i
DcY;6D:gB]QC6E;iEaUG>ULkEe/00e]l00ESWFNnHga6MbD=0080000>100880P0564TiC4T=BDiAS46
68<<80@0120DH@8Ti0076:<HY1BT6:<HY1RS6:@00QbT00THXaRT6:<HXaBS588DHAAR6:<00Qc500dP
iBDU9BLY9bD69>@T`RSR>DEFBf;cH_ARm@04I_D4I_@00fKcI_AVm003I_@00fKcI_AVm002I_@016Kc
I]9Vlf[c0f[d0V[c00=VlfKdI_@00VKd00AVmFKdI_AVe09Vm003J_AZlf[c00AZl`03J_9Vlf[b00AZ
lP9Zl`05I_AVlfKdI_=Vm00?J_<4J_@5J_<3J_82J_<01V/CJ_=Zlf[cJ_9Zl@AZlP=Zl`9Vl`9ZlPEZ
l`03I_=ZlVKc009VdP9ZlP=Zl@AZlP9VlP03I_=VlVKb00=ZlP9Zl`05I_=Zlf[dJ_9Zl`08J_83I_47
I_84I]83I]44I]800fKAI]1Vd@09I]42I]800f;CH]9VdP05I]4016;BH]5RdF;A26:a00=NdF;@H[00
16:`00=R/EjaG[4015ja00=N/5j_GZl015j_0Uj?00=NSUj?GXl015j?00EN[ej>GXmNT5Z@00AJS`=J
S@=JK@03FVaJC5Y/009JK00:FVeJK5Y]FVeFKUI>FTiJCEY]ETd3EVh2EVd00eY/ETaFB`03ET`015I[
ET]FC59/0e9<159=0U9<0U8]00=BC58/DR`0158/0U8[2Th/00=>:e8[DR/01Dh[00I>2Th;CP]>2dh:
CP/2CPX01TX:BP]:2dh;DRY>2P9:2`M:2P04AP]>2Th:CRX5BP/2BPX1BPT1AP`0000:10888PP0440X
i3fYCReFKEI[ETh2ETl3ETh3ETl2ETh2ETl4FTl00eI?EVmFK`03EVl4EW0015Y`FVmJKUY_0eY`0UI`
00=JKeY^FTd00UY<00EJ:UX:FNYIjUWY00QJ2@09FPYEb4fXAFMAQEW5GPMN25h9009N:@0=GRYN;5g[
GN]Zdg]hOiAkE7LfI_IRUEjCHW<00V:C00iRLeh`HS1Z]G=HMgMV]4F<>@LmRDG]DRaJCUj@0Ujb00eN
TejBGW1NT5j>GVY5ZSDX9<HXj2cW;>H]1P02;@D09345=B@mI4FVCNQF:5iWHZYRJD66;<@HHQR1544D
HQbS:<8]0SE5@JQ1YTG5ETQZbf::AHHTXaA0784@@0`P200<@A1Q6:4DPP<DX`0558<@Pa2358@DY002
58<246800`a1368@HP0246823680112358<DPaRT0Qc400DLaAcV7>HPiQcV00@Pi`038@HQ1bD7008U
1`<U:08Y9`03:BPYB2e8008]B0P]B@06;DXaJSF;>H/i[3f]13g=1D7=0T7^00=63TX?CRl014h`00=B
D5I@EU400eYa0UZB00]NTf:cH[ARe6KEI_EVmV/FJaM_=f/G009Vm`0<JcQc=g]FMeQc=f/GKaQg=g]g
OkYo^g^J0WMI00Qg>GMJMeYcNWMjMgQg=VlG16[f00=VmVKEH[D00VKF0fKg00=VeV:dG[<00V;E00iR
mVKeI_EVmF;DFY9B<4G>@Ji1cTXaCU1:LTib0e9b01mBDDhaCS5>3dh`BU51kBT8328000PP384<P0b1
5>DYcTKFEcUSNU]IEaM2LcW`;HhU;36>@S9BeV=jHieOO002Fe/01enNHkm[_VNLC]TaS`P20080000:
220801B29>Da9CE5>DHXiARS320210002Q10660P`QRR6:<DPaB258<HXaRT0Qc400DPi1c46:@HY1BS
008DPP0A58<HY1S57<DTiBTU:DLY9RCT8<@P`RBP>DAF:f<DH_ARm@05I_D3I_@7I_<3I_@4I_<00f[c
J_AZm004J_<2I_@01fKcJ_=Vm6[cI_AVlf[d00AZl`03J_9Zlf[c009ZlP04I_=Zlf[cJ_87J_<00f/C
IaAZl`04J_<5J_@5J_<3J_@2J_<6J_86J_<01F[bJ_5ZlF/BJ_8016/B1V[c1V[b00AVdV[cJ_=ZlPQZ
l@03J_9ZlFKb009VlP03J_9Zlf[b009ZlP03I_=Zlf[c00mZlPAVl@=VdP03I_9VdVKa00AVl@9VlP03
I]5Vl6KA00MVd@05I]9VdFKBI]9Rd`02H]83I]42H]43H]84H]43H[42H[000f;@H[1R/003H[400f:`
H[5N/@05G[400ej`GZmN[`04GZl015j^GXiN[Uj>0ej?00=N[ej^GXh00Uj>00=NSeZ?FXl00eZ?0UZ=
00=NKEY]FVd00eY]1EY/00EJKEI^EVmFCUY^00=JK@EFKP04FVeJC5I;EV/9ET/00e9<DTeBC@02DTd3
ET`2DT`5DR`3DR/7CR`5DR/5CR/3CRX2CPX01Dh;CPYB2E89CPX00dX:0Th:00E:2dh:CPY>2TX:009>
2@03BPY62dX:009:2P=62`A:2P5:2@59k00000X88PPQ200@82S3?HM:2eI=FVaFCP9FC`=FCP=FC`9F
CP9FC`AJC`03ETmFKeI_009FK`IFL003FW1JKUY^009JK`06FW1FLEI`FW1JKeY^0UY=00EJ:UX:FNYI
jUWY00IJ2@08FPYJ2EXZGRUIjEG9FLQN1`9N209N2@0;GRUN:5h[FNYMjV[CLeQoMGMENeIgE`02McP0
4G/hNeQkF7<GJ[=VLVJeLcQgEfJcAH/i1ceYBPeFCEY>GY000UjA0UjB00UNLEZAGXmRJd6Z:<HPYBBV
:<H00RS50RST01</i3D4>D@mID66AJE9iU9;DRTiAQaS300@8111568LXbS3;><`hP02=B@0434R?HA:
:D6V;><D@QA0684@H@PP100<811Q584DXQRT0QBS00<DPaB45:@011BT00`DQ12348<@PaB36:<LXb3T
7:@HXaB258<26:@00b357>HLiP048>H38>L00b469@LU1`039@L01RDW:BPY9bTW:BPYB0<]B08]B@08
;DX]BBe9<DTaBS5Z=H/iZ`8i[003>JdmcCg>00@mcP07@LhmcD7=@Li1kTH?BPh00TX_00Q><4X`CU5>
D59@EU1FLEYa0UZB00IJTejCGY=NTf:cH[@2I]D02VKfJaM[=f/GJaQ[>6lhLcQc=gMG0W<g00A[5f[g
LcQgM`9kV@04MgUgF7LgMeP2MeX01GMjLgYcF7<gKcL00V[g00QZmV/GJaIZmVKfI]IVmVKg0V[g00AZ
mVKEI_IVm`9[5`0>JcM[>6/gJcM[5VKfG[=>446^>Ji244IACW9BT`9BLP=BD@9>;`0SCU55kBT73480
00Q0484@X@A04<DYcTKgFg]SNe;g@S4YBQc766DLQbC7;DY6<5;eGiaSW5mKFe]KOEmnIkmWWE/k@S<D
QP0200003`PP100DPbD6=DHiIcEW9>HHY0P0100800`P560LX@026:<01QRT7<@La1c47>DPi@8U1P0G
8>HLa1S46<<HXaBS58<HY1S57<DTiBTU;FLaAbe7;BLY1BSR?FIFBf<DH_AW5@06I_D016KdI_EVm6Kd
1F[c16Kd0fKc00EZm6KdJ_AZlf[b009Zl`03J_E[5F/E009Vm004I_=Zm6[dJ_@8J_<3I_<4J_<016/D
J_=Zm6[c0V/C00=W56[cJ_<00V[c00AZm6/DJaA[50=Zl`03K_=Zlf[c009Zl`9Zm0=Zl`aZlP9Zl@04
Ja9ZlV/BJ_42Ja82J_82J_<00f/CJ_=ZlP02J_800f/BJa=Zl`03J_<4J_801F[aJ_9ZlF[bJ_400V[b
00IZlf[bJ_=ZlfKcI_84J_800f[cJ_9ZlP0>J_83I_401VKbI]9VdVKBI_9Vl@=VlP06I]9VlVKbI_9V
lFKB1VKA00=VlFKbI]800VKB0V;C00AVdV;AH]5Rd@ERdP=Rd@03H]9RdF:a00IR/09R/@=R/0=R/@=N
/@03G[1R[f:_009N[`9N[P03GZmN[Uj_00IN[`ENS`AJS`04FViNKEi]GVd3FVd00eY^FVeJK@03FV`0
1EY]EViFKeI>EVl025I^00=FCEY<ET/00UI<1UI;00=BBeI;DT`01E9=0eI<0U9<158/0e8[0e8/258[
00=>:dh/CR/01Dh[0dh:158:0Th:00A:2Th:CPY>2P=:2`=:2P04CPU:2Th[CRX4BPX00dH;BP]:2`02
BPX1BPT1AN`0000<224<80P0320T`SE5BP]FCEY[ETaFCU9>0UI>00AFCEI>ETmFC`9FCP03FTmFCeY?
00=JC`03ETiFKeI_009FK`9FD003EW1FLEI`009JK`06FTiJKUY^FVmJL5Ya0eY`00IJKeY]FTaJ:UX:
FNX2FNT7FPT015XYFPUJ2EWY0UW715h801mN2EhXGRMN25WXGPYZdW=HNgEkEG]gNgUkMgmFOiMoMgmF
LaE^dfIbIYIc>7MGI]A=RcCV?DU9kUY]FTeNKP02GY02GY401Ui`FY5R/Ei[@HXTYP8TY@<Pa@0V8<@P
aBC4:<@/hc43=@<e8cUS@JM1QRcU428800`056<HQ1bT9<<X`bc2::<DHQ109<8/habR440@@ARS7:8@
H@P01008011Q588DXP<DX`0558<DY1BT5:DDY0026:@04ABT7:@TiC58=HTiZSg;>JXeRS58:@HTaAR4
68<PaBCU9@D00R3U00<LaR3V8>L00R3W1BD700<U9bTX:BP00bTW00<YAbe7;DL00be80Re900XaJC5Z
<HXeRcF:?JXiZcV/?Jdmc@DmcP03@Li1kT7^00=63`03BPi:;dh_00=><09>D003DU1BDEIa009JL@=J
LP08GY9NTf:CH[AVmV/GKeM_=`=c=`04McMg=WMFMeH2LcL017<GKaMc=gMg0W]h00AgF7MhNgQgN@Ag
NP04MeQgEW<gKcP2KaL016/GJaIZmV[f0VKF00IZmf/GJaM[5f/FJaL2JcL00flhLcMgM`02MgL02Wnh
MiUcN6;EBO4eSCE]ANm>;U9b0U9a0UIa01eFL58_CRiBD4X=:BL<@`@0340@PA2Q140<Q2g=BaIKNeLG
AW8aK1bV66DTYb2W=F/aBC5YAW5KFFNK009SN`0IGgaOWVNnKkiSODjF8>T00@00100801B39@HeJ3UY
=FP]9QbS200400P0220DHARR6:<00QbT00XPiBTV;BHU1RT69BHY1R3U7:@HX`<HXP0D588HY1S58>DT
i355<FHeR35X;DPY9bST>DIJK6<DIaAW5FKdI]=Ve0=Vm006I_=VmFKeI_EZlfKc0f[c1VKc16Kd00=Z
m6[cJ_<00f[c0fKd36[c00AVlfKbI_9VlP9ZlP9Zl`06J_9Zlf[dJ_=[4fLD16[c0f/D0f[d16[c00=Z
lV[cJ_<016[c36[b0V[a00A[4F/BJa9[4PAZlPAZl`9ZlP9Zl@03Ja9Zlf[c009Zlb9ZlP04J_5ZlV[b
J_83I_400fKbI]9VdP02I]400fKaI_9VlP05I_8016KaI_9VdVKB16KA00=VlFKAI]400VKA0fKB0V;A
00=VdF;AH]4016;A00ARdV;AH]5Rd@9Rd0AR/004H[5RdF:aH[42H[03H[4015jbG[5N/Ej`0V:_00=N
[ej>GXh01Ej^1Ej>1Uj?0eZ?00MJKUY]GVeNSUi]FViJS@04FVd2FV`2EVd9EVh01UY/ETeFCEY<ET]F
C0IFB`05EV]FK5I/DTeBC003DTd01E9<ETaFC5I<DT`00e8/3e8[00=>:dh;CR/01Th[00A>:Th:DPY>
2P=B2P9>2P04BP]>2Th:CPX3BP/4BPX00dH:AP]:2P02BPX00dH:BPY62`03AP/1APX1CPP1BN/00088
@@0:320@8233=DE:2e8]ET]F:eH]DTh4ETh2ETl4ETh3FTl00eY_ETmFK`02EVl00eI?EU1FD005EW00
45Y_FW1JKeY_EW1FLEY`FW5FLEI`FVeJCEX[FPYIjeX:0UX900=N2EX9FPX00UWZ00UJ2EXXGRUJ25G:
DJUEbEW8FPP00Uh8021N2EhXHRMN:68ZHR]ZdW]hOiQoVG]iMgUgF7]GMcIg=f[eJ[=Z/F9bI[Ec>7]i
KaIIk3S4?DQ5kUH]FTiNKej@0ejA00QNLEYaFY1NJd6::<HLHabT0QRT00HLa2358<DPaBC58<D28:<0
1BC3:><Y12C468<00PP000/@8AB46:@LY2349<@T`bBS788D@110008HHP0;568DPaRT6:<@HP`P220<
@A1R588DXP035:<06ABT5:DDYABU5:@HY1B37:@]9Sg:CTmFKejaG]9NdeI`BS11c3599<DLPb2T7<DT
iB4600<PiP<Pi`038@LU1bD7008U208U:0<Y:005:BLY:2TX;BP]B002;DT012eZ<FXaJS5Z0S6:00He
RSV:>J/i[3V]?Jd3?Lh01T7_@Ni1kd7_@Ni23`963`04BPi:;dh_CRl2CS0014i@CU5>DE9A0eIa00EF
LUZCFY9JLEYb009RT`08J_I_F7MHNgQgEgMhNgQgE`Ag=`06McIg=gLhMgUkVG^J0g]i0WMi0gMj00Ig
FWMiMgMc>6liJcP2JaL01F/FJ_IZmV[fKaL00V/G00Q_>6lgKcM_>7<hMeMgMgMf0WMh04IgVG^jNm]k
^G=jG[I5[bd[=DY>3TiaDW5BLUIbEY9FL59?EU1BD4X>;BP@I0@0360@PA2Q260@Y2g<B_EGNdkH?Nl]
:B2U88HHI22U<DTiRS4W@RmG>6^lIkeSNf=lHiiW_VnnIie>]b4;004000@022088B3V=DHiJC58:BLL
Y0`P200400a0468DPP8HX`0<6:@La2468@DPiB469BHPiQc46:<HPaRR0QBR018DPQRT6<DPiBT4<FHa
Ac5X<HT]IbDW9<@iAUI;HaAW=6LDI_D2I]<016KDI_=Vm6Kc0fKe0VKd00AZlf[dJ_AVm0=Vl`AVm003
I_EVm6Kd00EZl`EVm0EZl`03J_AZlf[d009Vm0IVl`9Zl`06J_9Zlf[cJ_=[4fLD16[c00=[4f/DJ_@0
0f[d00=Zlf[dJ_@00f[c00=Zm6[cJ_<00f[c3V[b00=[4V[bJ_800V[b00=[4f[cJ_<00V[c00=[4V/C
Ja800V[a00=[4V/CJ_<00V[c4F[b00MVlV[bJ_9ZlV[cJ_9Vl`07J_800fKbJ_9ZlP02J_82I_8016Ka
I_9VlFKb0VKB00=VdFKaI_401fKb0fKB1VKA2FKB00=RdF;BH]400V;A16;B0f;A00URd6:aH[1N/6:`
H]5R/F;AH[400V:`0V:a00=N/UjaG[400Uj`0V:_0Uj_0Uj?0ej_00INSej>GXiN[Uj_GXh2GXl01EZ?
GY1NT5j@FY000UZ?0UY^00IJSEZ>FViJSUZ=FXh2FVh2FVd00eI]EViFKP09EVh01EY/ETeFCEY]ET/0
0eI<1eI;0U9<159=0UI<00=BCE8]DRd0158/1e8[0Th/1e8[00A>:dh/CRa>;0=>:`05CP]>2Th;CPYB
2P02CP/01DX;BPa:2dh:BPX00dX;3dH;0DX:0Dh80DW[000224402P@0320HXc56ANYBCEY;ERYF;EI?
2UI>15Y?00AFCeI_EVmFK`EFC`MJK`=JL09JL@08EW1JKUY]GRYJ2UWZFPYN2@9N200CGPUJ2EWZFNYM
j5h7FPQIidVY?DQ9IeW7FNQN1eh8GPUN:F8WGRL00V8Y01YZdG]hOmUo^g^JNgUkF7]FNcEg=V[eGTmZ
/VkDLaIgF7nHKcIJ33ST>DQ5kUI=FTiNKej@0UjA0Uia00QJL5Y_GVa1ZRSV768HPQb30abT0ac400<H
PaAR56800QR30QAR00D@@P`Q424HQ1RT008LY08Pa0049<<PXabS5442568546824442468021AR588D
XaBS488DPQBT5:D25:H25:@02234=HY:;ek>I_9[=6/DJaD2IaD026;CG[1><3f/;@PLQAR39>D28>D2
8>H38>L00b479@PU1`029@P012DX9@PU22DX1BTX0Re900<aJBeZ<FX00c5Z00@eRS5Z=FXiR`8i[005
?JdmcSg>?Li1cP04@Nh2ANl014H?BPi:3dX_0Th_00E><4i@CU1BD59A009FD@05EW5FLUYbFW9NT`02
H[@02VKDJaI_F7MGLcMg=gMGMeIgEgLf0gLg00IkEGMGNgYkVWnjNk/3NiX00g^KMgYgN@04MeT017MF
LcM_>6/H0V/G0V[f00M[5V/EKaE[5V/gKaM_=`02LcL01GLgMiQofgojOmX017^j00Uo^WnIKeUJUCf=
<>LmZTH`CW800U9b01m>LEI`DRiFCdi@APdY1aAT220@H1214:4<HA2T;LaC5EnLC[Q64Cg>=F/TY@`0
564X`cE5;@DicELGKke[g@02Hg/04V=mIia__FMlC[LQ2`01000400P0444La3E5>FPaB2T87:@<8088
0003464DPQB200<HX`8La0047>@La1c47<@26:@00aR358<DPP0258801a1R5:@Ha23U9@@]9Be6008a
I`06<DHY9RSU>DI>2ekb0VKc00AVm6KcI]=Vd`9Vl`07J_=VmF[eI_EZlfKdJ_<00fKd00EZm6KdI_AV
m6Ke00=Vm0=Zl`=Vl`04J_=Zm6KdI_@9J_<4J_@2J_<3I_<2J_<016[bJ_=Zlf[c26/C0f/D00=Zm6[c
Ja<01V[c4V[b0f[c16/C00EZlf/CJ_=[4V/C009ZlP03Ja5[4f/C009[4`9ZlP03J_=ZlV[b009ZlP03
J_=[4f[b00aZlP05J_=ZlV[bJ_9Zl`03J_800f[cJ_9ZlP03J_86I_86I_400fKbI_5Vl@03I_4016Kb
I]5VdVKB1VKA0fKB0fKA16KB00=RdV;AH]400fKA00=RdVKAH]400VKA00=RdF;@H]001V;@0f:`00=R
/EjaH[400Uja00IN/6:_GZmN[ej`H[03G[02GZl3GZh02Ej_GZiNSUj>GXmNT5Z@GY1JT002FXl2FXh2
FXd3GXh015Z>FViJKeY_0UY^0eI^15I]00EJKEI^EViFKEY/00=JK@03FVaJJeY[009FJ`IFB`ABC005
DTeFCEI<ETaBC@02DRd0159<DRaB;58/3e8[0dh[0Th/14h[00]>2dh[CP]>2e8;DPY>2dX<CP]:2dX:
00A:2`A62`08BP]62dH;APY62dH:AP]62P962`5:2P5:2059j`0000`48@Q1100881B3;DI5jeJ?FVaF
BUI=DTl9ETh5FTl01UI?EVmFKeI_ETmJK`=JC`IJK`AJL09JL@08FY5NT5Y^GRYJ2UWZFPYN20AN2@0O
FPYIjUgXGPMJ25GX@HPhiT55FLIJ25h8FRUN:EhZGRUR:F89GNUV/7MHOkUog7]jNgUkF7]hOgMoEWLF
K_H00Vke00U_5WMHNgU_=eWZ?@DmB4G^ETd00UY_00ANTEjBGY9NT@9NLP05GY5RSD7<;@LPHP027880
0bC38<@LY0047:@011R3568HPaR30QbT0QRT00<HQ1bT7:@00QbT00LPa1c49<@LXaRS340<@@022200
1P@P220880PP344@H@8@HP0@568DPQBT5:@DXaBT6:DDYAC65:D@Hac3>HYBD6;cIa<2JaD00f/eJcI[
=P02JaD036KdH_EFL3f]:>PLHb2T7<DPaB3V8>LQ20@U20039@LU:2DW008Y:08Y:@03:DT]B2e8008]
B08]B@09<FTaJS5Z<F/aJS5[=HXeRcF:008iZ`03?J`mcCg>00<mcP05@Ni1kd7_@Nm1kP02APl2BPl0
14X_CRm>;dh`0Ti@0U9@00aBDE9aEW5JLUZBGY=Re6KfI_M[5f/gKcP3LcL017<hMeIg=gLg0WLG00Ag
=g]GNgUo^`9oo@06Ok]kVW^KNi]kVW]j1GMi00Ag=flhJaQZm`9ZmP9[5`=[5P9[5`08JcQ_>7<hLaMk
MgnjOoeoo0=og00;Ok]k^g^JOkYkVV/iDO0diSDX@Pm:D@03CW807TiACS1BCdh`ANdY1a1T100<H0bQ
4:4<HA2T=PiKEUnLC[QFM5IaBS0`i@`0400HPRC18<<aJTjdJiY[g@9SN`08HgaWW6oMIga>ebE=0080
00880008564LXcE4=DLa:BdY6:D<8@880003464DPQB2008DPP035:<HY1S400<Ha0047<@LY1RS6:<2
5:<04QBR588<@A236:@LiB45:BHY9be7<FP]ARTV:>@iATh;G_5Vl`AVm003I_EZm6[e009Zm004J_EZ
m6[cI_DFI_@016[cJ_AZm6[d0V[c0V[d00AZlf[dJ_AZm0AZl`04I_=Vm6[dJ_@4J_<4Ja<3Ja82Ja<2
Ja@01V[dJaA[56/CJ_=ZlP9Zl`03J_AZlf[c00aZlP9Zl`=ZlP04J_=[4f/CJa<4Ja@01V/CJa9[4f/B
Ja=[4PA[4`9Zl`05Ja=Zlf[bJ_9Zl`03Ja<00f[cI_=Zl`03J_<2J_802F[cJ_9ZlV[bI_=ZlV[cJ_9Z
l`03J_800f[cJ_9ZlP03J_86I_84I_400fKbI_5VlP02I_401VKAJ_9ZlVKbI]5VdPMVd@EVdP03I]5V
dVKB009VdP06H]9RdF;AG[1RdFKc0f;B0V;A1F;@00=RdF:`H[000V:`00=R[ej`G[4015ja00=N/5j_
GZl00Uj_00AN/5jaG[1N/0IN[`04GZiN[ej>GXl4FY0015Z?GY1JSUZ?0UZ>00IJSEj>FXeJSUY^FXl2
FVh4EVh5EVd2EVh00eY]FVaJK@02EVd2EV`2EV/7ET/015I<ET]FC5I<0eI=00AFC59=DReB;@9BC0IB
;0MB:`05CRaB:e8[DR]B;004CR`6CR/2CP/3CPX00dh[BP]:2`05BP/4AP/024X;CR]::dH;BP]:2TH;
BPX2AP/1APX1BPT1AN`0000<2248@@a1444HY2dV@N]FSeZ<ETYFCEI?15I>0UY?0UI>1UY?00AFCUI_
EVmFK`9FC`9JC`=JCPIJK`=JL005FW5JL5Y>FTeN:P03GPT3GPP2GPT02UX:FNYIbEh7GRQIidfX>BM5
IUW60Uh801AN:EhZGRYN:Uh[GPYIj69_LcIo]gnkNi]kNG]hNeMoEGmFNcIc5fkF0V[E00e^mW<fJ_AN
2CST?DQ5kEH/FTiJKejAG[5NTP03GY<02f:bHZm5kBcW768HPQbS8<<LaAbT68<00QRS11R30QRT1abT
123400<LXaR334401@@00PP000L<811P468@HQ1Q588Ha0025:@00aRT6:DHa@026<H02AR3:BE:Cf<A
Ic=[=6KdIaEVm@02IaD036KeIaE[5FLDI_9BD3V=9:DHPaB38>DPiP8Q1`039@PU:2TX00<Y:003:BLY
:2U9008YB@8]B@8]B0<]B@03<FTaJS6:008aR`8eR`<iZ`03?L/mc3g<00<m[@05@Ni1kd8?APm23`02
APl014X?BPi:3dX_14h_00Y><59@DU1BD5I@EW5JLEjBH[=Vm@=[5`9_=`Ac=`0;McIg=g<GLaM_67Lg
NeMkNGnjOmao^`05Ni/02g^JNgYgNWMiMiUgNGLhKcUVmfKfJ_H00f/G00a[5V/GJaM[5fKgJaM[67<h
MgUk^WoKOod2Om`4Omd037nlOkUoefmHFRle1S4X@Pm:D5:CDW9>DP9BD@0VDS1><4G];BT@I0@0360<
X@b1260<Y37]EeIGNe;jCU9JT4h_>BL@00`0788X`RC4:DU:/fMjJkaSNf=lHge[_7?mIiaK62U=0080
00840008440LXcU3<BH]:BdZ6:D@@@840003460@PABR008HX`086:@DY1S56:@DPaRT6<@LX`<HX`8D
X`0F588@HA1S6<DLiB459BHY9be7;FP]9BCT9<<iAE8ZIa9[=FLDJ_AVlf[cI_@7J_@3I_@4J_<00f[d
I_AVm005I_@00f[dJaAZm003I_@3J_@01F/DJa=Zlf[bJ_<01V[d16[c00AVlfKdJ_AZm0AZl`A[4`E[
4P03Ja=[56/C00AZl`03J_9Zlf[c009Zm0=Zl`IZlP06Ja9ZlV[bI]9VlV[c0V[b00=[4V[bJ_800V/C
0V/D0f/C0f/B00=[4F/BJa800f/C0V[c00=[4f[bJ_800f[b0f[c00=VlV[bJa800V[c0f[b00=ZlF[b
J_8026[b00=Zlf[bJ_800V[b1FKa00=VlVKaI_4016Ka0fKb00EVlFKAI]5VdFKB00]Vd@04I]9VdF;A
H]45I]83H]44H]800f;AH[5Rd@05H]000f;AH[1R/003H[02G[001UjaH[5N/F:aH[1R[`=N[`03G[1N
[ej`00=N[`9NS`9N[`9N[P03GXiJSeZ?00=JT09JSP04GXiJSUZ>FXh2FXd2GVd015Z=FXiJKUI^0eY^
00=FKUI]FVd00UI]00AFJeI]FVeFK@=JK09FK09FJ`aFB`05ETaFBeI<ETaBC@02DRd3DT`5DR`7DR/0
0dh/DR]>;006CR`3CRX3CR/2CPX01E8:DPUB:DhZBRX00dX;0TX<0dX;00A::dH;AP]:2`962`=62P05
BPY62TH;APY:2001BN/0000;2248@@a1444LY2dV?L]>D5I/ET]FCP02ETl2ETh3FTl00eI>ETmFC`02
ETh3FTl01UI?EW1FL5IaEVmJK`EJC`AJK`MJL009FTiJCEhZGPUJ2UhZHRYN:5h800=N2@03FNUN25h7
009N1`04ELU9J5FXGPL2GPP00ehYGRYN:P02GRX045h:FN]NCfkeOkMo^g^KNgUkF7LfMaIZeVJCHW=V
TfJd0V[E00UZmFJAGNPh`CTWANeB3EI>FW000UjA00mNTV:cGY=NTf:cGY11[2BW66<LPbC4:@DQ1aRU
56800QR30QAR00@HPaR46:@HY0HLY08PY0<Pa0047<@DP`a1200210000`@Q2248000232001a1Q468@
HQAR588HaART00<DY0086:DHaQRU:>@mbE[bIcA_EP9[=P9[5P03IaI[5VLF009W5@0:JaE[55jcANlX
aaQS68@U1BDW9BP3:BT01BTX:BTY:BTY:BP012U900<]BRe9;DT00Re900<aJC5Z<FX00c6;0SF;0SV/
00<mc47]?Ld00cg=00U1cT7=@Ni23dH@BS1:44X?APl00dX?00=:44X`CS000Th`00=><E8aDU400UIA
00IJLEYbG[=Re6/GKcP2JaL016/gLcMc=g<g0g<h00a_>6/GJ_MZmg<hMeIkNG^INk]kVW^KNiX2Ni/2
Mi/02g^KMi]k_7^kMiYc>6liI_QZmf/GJaP00f/G00iZmf/GIaQVmf;FLcQgVW^kOmeooGonOmeooGon
0goo00]ooGnjOkQcNEib?DTa:3g^CU1BLTib009>DP0MCS5B;dh`AN`a:11S100<H0bQ2648@@bT:Ne?
=UMlEaY:<TH?@LdiJR23668TY34W9<Di[E;eKk][W002Hg/04V=lJiacoF^mE_LY;001000800@0440P
`cUT=DH]:Be:7<H@@P840005464DXQc46<@DX`025:@26<@01ART6<@Ha1S46:@00QRS01DDXaBR5:8@
HQ236<@LiB459@DY9RdX:DLY9B3T9:<i95HYJc=[=FKdJ_@00V[c00=Vm6[dI_@01F[d0fKd00EZlfKc
J_=Zlf[d00MVm0AZm0=Vm004IaAVm6[dJa@3J_<3J_@00f[eJ_AZm@02J_@3J_<00fKdJ_=[5002J_@2
Ja@00f/CJaA[4`02Ja<2Ja83Ja<4Ja@00f/CJaA[4`04J_@2J_<00f[bJ_=Zl`03J_801F[cJa9[4f/C
J_<016/C00=Zlf/CJa<02F/C0f/B0V/C0V[c0V/C00=Zlf[bJ_<00V[c0V[b00=Zlf/CJa<00f/C0V[c
0V[b00IZlF[bJ_9VlVKcI_85J_8016[cJ_9VlfKc0VKb00=ZlVKaI_400fKa0f[b00=VlF[bI_800VKb
0fKa00=VdFKBI]4026KA00IVdVKAI]9ZlfKbH]45I]85H]43H]82H]44H]02H]401F:`H[5R/6:`G[00
0eja00ER/F:`H[1R/6:_009N[`9N/003GXmN[ej`009N[`9NS`ANSP03FXiJSeZ?00EJS`AJSP09FXeJ
KEi]GVeJSEZ>FViJKeZ>009JK`03FViFKUI^009FKP=FK@05FVaJJeY/FVaFK003EV/5ET`5ET/2ET`0
1EI=ETaFC5I<DTd00U8]0U9<1E8/00=>;58/DR`00U8/0e8[14h/00E:3Dh]CRe>;Dh/00I>:`05CPY>
:ThZDRY>:P02CR/3BP/00dX<APa:3002BP/00dH/AP]62`03AP/2BPX3BP/2BPX1CPP1BN/0000<2248
@@a0220@HRT5>JY>CeI/ET]FCUI?1UI>0eI?1EY?00=FCeI`EW000UI`0UY_00=JCeY_FVl00eY_1eY`
00QJKei_GTiJCEhZFNUIbUWY15h800aN1eh8GPQN1ehWGPMN1UW8ELQIaeh7GPP2GRP07ehYGRYN:5hZ
HRYN;5h_K_Eo]gnkNiYkNG]HMcMVe5XaEQ1J<5X_HW9VU6[gJ]EVT5VV><4i9TG]CPeFCUY`00ANT@0>
GY9NTf:dHY11S2BW66<PY2C4<DHYBAbU568HHP8DHP0366<HPaR300<LY0057:DLQ1R37:<LY0028:@0
222U8<@/iBD66:@<@@PP1003224020@0320<811P364@HQAR58826:@25:@02QB35:@DQ1B4;BE>C5kb
JeI_EfmH0V/g011[5VKfJ_I[5F/FJaEZm6/EH_AJL3DZ76DLY2T5:BLYB0@YB@03:BTY:2TX008Y:08Y
B@@]B@03<FTaJS5Z008aRP03<F/aJS5[008eR`04>J/mZd7<?L`2?Ld01T7=?Le1cT7=ANi6409:;`A:
3`04CRi:3dW_BQ02CS44DS402eIAEW9JLUjBH[=Re6KEI_IZmf/GKaL017<g0flh00Q_5f/GLaMg=g]F
NgQkVG^J0g^I0W^K0W]k00=gNW]iNiT00W^I00IgEfliJaU[66/GKaP3JaP2I_L01VLHH_MVmgMiNkao
o`9ooP03OmiooWoo00Aoo`0:OoeoV7nhLeUVe4F:<BPmcEI_CU03CU805DX`DU1>D4G/;@L@H`@0460<
PPR1264<Y2W>BaMKWE]KAU@e[bU;:BTTi`0278@01QR58@Pn<5]HKkaWV`=SN`05Ji]coEmkCY@Pb002
00002PP0320DH2CT>D<iAcEZ<F/PiQA20PP000XDPAcU8>@Ha1RT5:@HY1S56<@HY08Ha08La00<7:<H
XaRS588HXQB25:<HY1cU8>DY12T50RTW00PY9RT6:<@i8eHWIa5W56Kc0f[c00=Zm6[cJ_<01F[c1F[d
0V[c00AZm6KdI_AVm0]Zm003IaAZm6[d00=Zm09[509Zm09Zm@=Zm0=Zl`=[4`I[50e[4`03JaAZlf[d
00=Zm003J_=ZlV[c009Zl`=ZlP03Ja9[4f/C00i[4`07J_=[4f/CJa=Zlf[bJ_<01V/C1F[c1V/C0V[c
0f[b00EZlF[`J_1ZlV[c015ZlP05I_5ZlV[bJ_9VlP03J_83I_800f[bI_9Vl@02I]400fKBI]5Vd@0=
I]42I]800fKAH]5Vd@02I]400f;AH]9Rd@02H]42H]0016;AH]1Rd6:a0V:`0f:a0Uja00=NdEjaH[00
16:_0Uj_00EN/5j_GXmR[Uj`009N[`9JS`YNSPIJSP9JS@03GXaJKEZ=009JSP04FViJKEY^FXh4FVh0
1UI^FVeJKEY/FV]JJP9JJ`05FVaJJeI[EV]FC003ETd2ET`2ETd00eI<ETeFC@05ETd4ET`01E9<ERaF
;5H/DR`00U9<00AFBe9;DRaB;0EB:`=>;09>;@03DRe>;4h[00E>:`04CRYB:U8YDRX2CP/2CR/3BP/2
BP`3AP`2AP/3BP/2BPX00dH;BPY:2P02CPT1CPL1CN/0000;2248@@PP100<@2ST>HU:;UI/ETaFCP03
ETl3ETh015Y?ETmFCeI?1EY?00IFCeI`EW1FL5I_EW02FVl00eY`FVmJK`02FVl5FW03GW0015i_GViN
CUh/0Uh:00=N2Eh8GPP00UhX00]N9eh8GPQN1ehWGPMN1UWWFLQIaeWW009N2003GRQN:Eh[00=N:P05
FP]J3VkeOkQo^`02NiX00g]iMeM^mP02I[@07V[eK]AVLV9cI[EZe6J@GNLl`Se7ANi>3UI@FW1JTEja
GY5R/EjAGY9R/V9^BLdTaaAS68<Ta2TV9FTHa@@DHP0356<HPaR300PLY08PY0078:DTaBd69@HHY0a1
22000PPQ0P@Q0`PP00H<@0aR368@HQB258<35:@03AB45:<@HQR4=HUFKF<CIcE_EgMgMkQcMflg009[
5P0=KaE[5V/FJ_E[5F/fH[51S1b668<Y1BTW:DP012U900<Y:BTX;BP00bTX00<YBBe9;DT00Re900Ha
JC5Z<FXaRc6:<F/2<H/013F;>J`i[3f[0T7<00E1kD7^@LhmcT7>0091kP963`04BQ1:3dX?BRl2CS02
BQ000dhaDU5BDP02EU800e8aEU9JLP02FW<02ejCH[=Ve6KDJ_EZmV[gJaMc5g<gLcP00Vlh00Ac>6lh
LcMc=`9g=`05NeQkNG]iNiUoV@02Ok/2Ni/00g]jNg]gF@02MgT02gMhMgMgEfliI_QZmflgKaM_>6/i
KcT00f/i00=Rmf[gNi/00goo0gon17oo01IooWnlOkYoMg=IH[91RS4Y@NiFT59aCU5:DDXbBS5>DE9a
APd]:11T0008@08<XP0K164<Y2W=A_IGVemkB[Hj<BV=7@XDYaB746@DYbf]A]IGNf^mHgaOG6=mIie[
_FoNEe]2<Qb50080008<800<560P`cE4>FLeJ35Y8<HD@PP0440DPAS30QRS00@DXa226<@Li@<La003
7>@L`abS00@HX`8HXP08588HY1cT8>DY9BTV9BL]B08Y9P07:>@i8eHXHa5W56LEI_@00f[d2F[c00=Z
m6[cJ_<00f[c0VKd2V[d0V[e00=W5F[dJ_@00V/E0V/D1F[d0V[e00=Zm6[cJ_<00f[c00E[4f/DJaA[
56/E009[5003Ja=[56/D00E[50=[4`9[5004Ja=Zlf[cJ_<3Ja@2Ja<2J_<3J_82Ja84Ja<00f/DJa=[
4`03Ja<01F/DJa=_4flCJ_<00V/C00=Zlf/CJ_<026/C0V[c2F/C00=Zlf[bJ_800V[b00EZlF/AKc=[
4f[c00EZlP09I_=ZlV[bJ_9Zlf[bJ_=ZlVKb00MZlP9VlP=Vl`03I_9ZlVKb009VlP09I_5VdFKBI]5V
dVKAI]9VdFKB00EVd@07I]9VdFKAI]5VdVKbI]8016KA00=RdF;BH]401F;A00QRd6:aH[5R/F:`H[5R
/6:a15ja00MR/F:`HZmR[ej_G[1N[`02G[02HZl00ej`GZmN[`02GXl015j>GXmNSej?1Uj>1UZ>00=J
SEZ>FXd00UZ=00AJSUY^FVeJK@9JKP03FVmJKUY^009JKP9JK@03FVaJJeYZ009JJ`04FVaJJeI/EV/2
EVd?ETd4ET`00eH/DRaB;004DT`2DT/00e9<DR]B:`05DR/3CR`00e8/DR]B:`07CR/00dhZCPY>2`02
CP/014h[BP]:2dX;14X<00A:2dX:BPY:2P=:2`962`9:2P03CPU>2587005=jP000PQ10P@000L<@2ST
?HQ:;EI<FVeFCP04ETl3FTl3ETl6FTl2EU03EW02FW06FVl4FW02GW02GVl015i^GTiN;Eh[0Uh90UhX
00=R:5hWGRL00eh70Uh6019N1EW6FLIIaeWWFPQN1eh8GRQN2Uh[GRYN1eWYFPi_5WnHOiT2NiX05GnJ
NgQoN7mfOiAoEW<EIY9VLfJdK_A^dV87>><i9dG^DPiFL5Y`GY1N/002GY42GY002f:@IVi9kRcX66<H
PbBT:@DUJAc556800QB300HHHQAR68<HPaRS6:@27:@011bU8<DPXabS0R2T00LTY2S5:>DPaAR33488
8002224212401`@P220<80a0364<HQ11008DPP8DP`0>58@HY1BS468HQ3VZFZaS4f/fMgQoeW^fNiIg
EP9_=P0BKcE[5V/FJ_I[5VlfJ_55[2BV66<Y1BTW:DPUBBU9;DX]BBTY0bTX00PY:BTX:BP]B2e9;BT]
BC5Y0S5Z0c6:0SF;00LiRcV/>J`mZd7<@Le1k@02@Nh00d7>@Nm1k`03APl2BPl034h`CRm><4h`CS5B
DE9BEU9FLeIBEW=JT`9N]0=NT`0<H[=V/fKDJ_EZmf/GJaIVmVlGLcQ_5f/H0W<h00Mg=gLfMcIg=gLf
NeMkV@02Om/06WnjOk]o^gnKNgYkFWMIMeQgN7MgMeIg=fliI_MVeFlfKcM_>7<hMeMgF7<hKcU[66kf
Om`4Ool3Ooh03gomOmeog7^lNiak^g^HKcINTCeY=DU63e9_DW5>D@02BS401TX@CS5BLDX^<DT@H`80
000M388@XPQQ38<Yc4KeFiYSVemjDaLjE2F?8DdM32f>>Q5:]e]JGiaSW5mkGeeOWVONKmi[_E<k<Hl8
0@02000220000a108:8iA002=DH01S579<D@80P0320DP@8DPP03688DPQB200HHX`036<<HXaRS00<H
X`0@6:8DPAB16:<La1cU9>DU1BDW;FT]ART69<<e0eHXIa83JaD00fKeJ_AZm00?J_<3I_@9J_@2J_D5
JaD016/DJ_AZm6[d0f[c0f[d00=Zlf[dJ_<00V[c00=[4f/DJa@016/D0V/C16/D1F/C0V/D1F/C00E[
56[dJaA[56/C00=ZlPA[4P03J_=ZlV/C00I[4`06JaA[4f/CJa9[4f[c0V[b00AZlf[bJa9[4PE[4`03
J_=[4V/B009[4P9[4`9Zl`=[4`9Zl`=ZlPAZl@eZlP03J_5ZlV[b00QZlP9Vl`04I_9ZlVKaI_43I_80
0fKaI]5Vd@02I]400fKBI]5VdP05I]400fKBI]5Vd@03I]400fKBI]5Vd@02I]48H]4016;@H]5R/F:a
0f:`0V:a0eja00AN/6:`HZmR[`EN/003HZmR[Uj_00IN[`9NS`ANSP03GXeNSUj>009NSP9JS@03FXiJ
SEY]00=JS@9JK@03GVaNKEZ=009JK@9FKP9JK@=JK006FV]JJUY[FV]JBeY[15I[00AFC5Y/ETaFC0AF
C@03ETaFCEI=00=FC@03ETaBBe9<00ABC003ERaB;59<009BC0ABB`EB:`A>:`04CP]>:dh[CR`3CR/2
BP/01Dh[CPY>2Th:CP/00Th[1dX;00I:2TH:APY:2TXZBPX3AP/3BPX1CPT1DPL1CNX00088@@880007
464Xi46XCReFC5I/ETh035I?00AJKeY?FU1JD09FD0EFL09JL0EJK`AJL00JGVmNT5i_HVmNCUX]GReN
2eh:GPUN:EhXGRUN:5h8GPUN:5hWGPIN1EW6ELIEYUWVFPMN1`9N200EGPUN:UhYGRUN2Ei?K_EoEWnI
NiYkVgnlNiUkN7niOmEkEVkeIY9ZU6[C009c5@08IThm9c3V@Le>3U9?FVmJT0=NT@06GW1RT69^IVa5
bc470Qb300`Ta2dU9DPLaAAR68<DPaR2544HPQR36:@37:@01ab47:@PXb239:<Pa2BT008Ta0059>DD
H`a222088@0212422240:0PP340<@0a1220<@AB168<Ha1BT58@DY1RT58<HYCW;FZe[=7>HOmIonGoj
NkUkV7MgLcM_=V/fJaIZmVKeKcIc4U7/9:HLQ2T5:BPYB2U90RTY00@Y:2TY:BPY:@@YB@08:BT]BBe9
;DTaJC5Z<HXeR`8aR`8eR`<i[004?Le1cD7]@Nd2@Nh0147>@Lm1kd8?0TH?0TX?00I:<4h`CS5><E9B
DW82EW<01EYcFY=JU5ZdG[D00Ujd0UjD00YR/f:bJ]=ZmF/FJcQ_=flhJaM_5`9c>00;LeQgF7MGMeUg
EgLgL_IbmG]iNiUo^P04Ok/02g^KNg]kNg]jMeQgEgLfMcM_>FKgJaL00Vlg00Ec>7MiNiUkNG<h009_
>003J_EkVgoo00=oo`0COmiogG_MNmak_7^kMgYcNWNkLiY_=eX`>BPmS4H`DW1>LDiACS400TX@00E6
44YAAPd]BA1T0080000<288<XPQQ4:<YZdKCFgUSVf>LFg]C>dlK0T[j00i:nDlJEe]OO5]lFe]KG5]l
GmmW_VoOGga6^B4<0`0000h880P0440LXSDT>FDmQc4V:<D@80P0340DPAB20aR221RS00<Ha1RS6:<0
0aRS01<DPQB16:8La1cT8>DU1BDX:FT]ART69:@e8eY8H_1[4fKcJ_AVm@02I_@01VKcJ_AZlfKcJ_=V
m0AZm0=Zl`9Zm0=Vm09Zm09[50AZm0AZm@04J_I[5F[eJaD2J_@00f/CJaA[4`02J_<00f[dJ_=Zm002
J_@01V[cJa=[4f/CJ_=Zm0=[5004JaE[56/DJa@2JaD00f/DJa=[4`03Ja<2Ja@7Ja<2Ja@2Ja<00f[c
Ja9[4P02Ja82Ja<00f[cJa=[4`05Ja<01V/DJa=[4f/CJaA_50=Zl`a[4`03Ja9[4f/C009Zl`E[4`04
J_=ZlV[bJ_83J_46J_82I_<00fKbJ_9Zl`03J_800fKbJ_9VlP05J_82I_83I_<00f[bJ_5Vl@03I_<0
0fKaI_9VdP02I]42I]84I]400fKBI]5VdP05I]401FKBI]5VdFKAH]8026;A00ARd6:aH]5RdP9R/@03
H[1RdEja00AN/@03H[5R/6:`00=N/003G[5N/5j`009N/003GZmN[Uj_00=N[`9NS`MNSPAJS@9JSP03
FXeJKUZ>009JKP03FVeNK5i]009JK@AJKP03FVeJKUY^009JK004FV]JK5Y/FT`4ET`01EI[ETaFC5Y/
ET`02EI=0UI<0e9<00ABCE9<DRaB;0QBC003CTaB:e8[00=B:`03CRa>:dh/00A>;003CR]>2dh;00=>
:`9>2P04CP]>:dh[CR/7BP/2BR/00dH;BR]::`04BP/2BPX00dh9CPYB2001DNX00088@@09440<81AQ
9<@mR4X/FV]FBeI>00UFC`9JC`03ETiFCeY?009JD003FW1JKeY_009JK`AJL004GVmJKeY^FVl5FW02
GVl02Ui^GVeNCUi>GReN35h:GPQR:68W0UhX0eh900AN25X7GPEIa`9EYP04GNEN9UhWGPL2GRP025hY
GRYR:Eh:HTmZdgleOgP2OiX097^JNgQkV7nGOg5_5FJdIY=Z/fkBMcAc=VIb?BT/icf/CPeFCUY_FY1N
T5jAHY5NT69`HXiRJTFZ<@HLHQb3:<@eABU77<DDHP<DP`04568HPQR368@27:@01aR368@LY1bT8:@T
Xb34008TY0059<@TaAR3424<80022244220234001Pa1224@@AB1688La08DY00O58<HY1B47<LiZek<
Je=g^7oGOoUo^7^HMeMc=g<fKcE_=VlEJ_E[5V/eLa99bbS58:<TiBTW;DPYB2TY9BT00bTX1BU912e9
00HaJC5Z<HXaJS5[=F/2=H/01SV[>J`mcCg=@Le1k@91kP04@LhmcSf^@Nl2APl2BPl01dX_CS1><58a
DU5BDUIb009FL`0AFW9JTeZCG[AN]EjdG[ENU5jCHY=V/V[CJ_A_5VlgLcM_>002McL03gMGMeQgN7Mi
MgQgNG]iMcQc5WLFMcIkF7^IOk]o^P02Ok/02GnKNgYkNg]jNeUkF7MHMcMc>002KcP2LcL02WLgLeMg
MWMgLcM_=f/FI]EgFWon0Woo01AooW^lMi]k_7^KMiYgNWMiLgUcVVmGG[=5S3DYALe>D5ZbDW5>D4X`
0TX@00E244X`@N`Y:1B400800009264<P@QP5<<YZDKADeQKNUMJ009GF`0EEeaKO5mlFgaKFeMKDcYG
Fe]KFgaOOF>nJoiWWEmK>O8@I`0010088@PP008<800<7:8e0cU5?HH]12S4568<811R588DXQRR1ARS
00DDPaB258<HXaS300DHX`0B6:8DPQB2588L`ac59>DU1RDW;FP]ABT59<Di9Ei8I^i[4V[b0V[c0V[d
1F[c00AZm6[eJ_EZm@]Zm0=[50AZm09[5@07J_EZmV[fJ_EZm6[cJa@01F/C0f[c00=Zm6[cJ_<016/C
0V/D1V/E0f/D1F/C0f/D36/C0f/B1V/C00=[56/CJa<026/C00A_56/CJa=[50Y[4`03Ja9[4f/C00UZ
l`9ZlP04J_5ZlV[bJ_<?J_800fKbJ_9ZlP03J_801VKbJ_9VlV[bI_9Zl@9Vl@=Vl`9VlP03J_9VdVKB
009VdP9Vd@AVl@QVd@04I]9VlVKBI]42H]400f;BI]5Rd@02H]43H]0016;AH[5R/F;A0V:a00ANdEja
G[5N/@=R/@AN/@AN/0IN[`EN[PANSP9NS@9NK@03FXeNSEZ>009JSP9NK@=NK09JK@03FViJSUY_00EJ
KP05FVeJJeY/FVaJC@03ETd01UI<EV]FJeI;ETaJK0=FC@03ETaFKEI]00AFC@YFC0MBC0QB:`03CR]>
;4h/009>:`I>:P9>2P03CR]>2Th:00=>2PI:2PE62`A:2P03CPU:2E88005=j`0000/8@@aR344<81AR
:>@mZDh]FVaFC5I>00UFC`9JC`06ETiFKeY^FTmJD5Y`25Y_00=NKei^GVh00Ui_00EJL5i`FW1NL5j@
009NK`0;GViNKei>GRaJ2Uh:GRQR:68WGRQN1`04GPP01eXWGREIieFWFLIN1UhW00=N1`0;GRQR:UhY
GPUN2Uh<J[5o=7mgNgMkV@02NgT06g]gNgIk=7;eIY=Z]6[DK]=g=GLgGS4i:BcX?Ja>3EI=FVmJT5j@
G[5NTF:AGY5VdVZ]BN`a1P0266801bC4=DD]Aac468<DHaB4008DP`8HP`036:@LY1bT00<LY08Pa0<T
a006::@XaB3U68<<00P01PPP00D8@0a0344<@Q11008DPP035:<DY1BT008HY00:58@DYCF:DVe[<g>G
MkUgV7MfLeL2LcL2KcH03F/EKaE[5F/FKeIZcdFZ98<LQ2D69BPY:2DX00@U:@03:BTYBBU8008YB@8]
BP8]JP<aJP04<HXaJS5[=FX2=H/00cV;>J`i[@02?Ld3@Nh02D7>?Jdm[T7_APm:44X?BRm>;`02CS00
258aDU5FDUIbFW=JTeZdF[<2G[@3G[D02eYdGW=RTfJcJ_AZmG<fLcMg=WMGMeP00WMi0W]i00akNW^J
Ni]kVW^KNiYkFG]HNgUoVWnkOkX3Ok/01gnJNgYkNG]INgUgF7MF009g=`04KcQc>6lhLcL2McL03W<h
LcM_=flGI]IVmgMhOoeooW^jNk]kVgNJMgT2MgL03GNIKgY[FEkEBNhiS3f<CPmBTeZBDW5>D4ha009:
4005AQ163d8<:BPHY@0200001`@P380<P12R:JQ:lDmG009?>@9?6@0:CaYC>ULjCaY?6DljDcYG>U]K
Fg/2Hid02FNlEeY:URCZ008000@02244000220001abR=B@iACU5;@@Xa1bT00<DP`03588DXQBS008H
X`037:<Ha1RT00<HY0037<@HY1RS008HX`0E5:<DPQB2588DXQc37>@PiBDV9BLYAbU59@DTXcU5FTQ[
46lcKaA[4f[c009Zm0=Zl`9Zm0=Zm@9[5@UZm0=[50EZm003J_E[5F[e009ZmP05J_EZm6/DJaA[4`03
Ja@00f/CJaAZl`02J_<016/DJa=[4f[c0V/C0f/D0V/E1V/D0f/C00=_56/DJaD00V/D16/C00=Zlf/C
Ja<01F/C0f/B0V/C00=[56/CJa@016/D0V/C0V/D1V/C00=_4f/CJa<00V/C1F/D00A[4f/DJa=[4`AZ
l`=ZlP04Ja=Zlf[cJ_<2J_83J_<;J_8016[cJ_9Zlf[b0VKc0VKb0f[b00EZlF[bJ_9VlV[b009VlP=V
l`=VlP04I_=VdVKCI]82I]43I_83I]400fKaI]5Vd@03I]43I]83I]400f;BH]5Rd@04H]400f;@H]5R
/@03H[400f;AG]5N/@03G[42H[47G[400ej`GZmN[`02GZl015j^GZmN[Uj_0ej>0ej?0Uj>15j=00IN
SUZ?FXiJSUj=GVd3GV`015Y/FVeJKUY^0eY_00MFKUI_EVmFKUY/EVeJK@02ETd00eI^ETeFC003EV/2
ET`2ETd01EY]FVaFKEI<EVh00UI=2UI<00ABC58]DTeBCP9B;@9B;004DR]>;58[DT/3DR/0159;CR]>
;4h/0dh[14hZ14h[00=>2ThZCPX00Th;0dX;00=:2TX;BPX00TX:0dX;14X:00=>2DX9CPP00DW[0002
1242100020`Q9>HmZTh^FVaFBeI=ETh8ETl2FTl015I>EVmJKEY>15Y_00=JCUY_FVl00eY_00=NKei^
GVd00Ui]0eY_00QNL5j?GXeNKF9_GVmRC5h[0Uh900AN1f8VHRIN9`EN1`03FPMN9EWV009Ea`08FLII
iUWWFNMN9UhWHRQR:@9Mj007GP]Z[g/COgEo]WnHOiT00Wmg00=oUg]FLaH00Vke021^dfkBLa=c5f8b
>BX/j47=CPeFCEY^FXmNSejAGY1RTF:BJ]=Z[dg];<DH@AQQ8:<a8bdV8<@HPaB358@DPaAR0QR300<L
Y2358<D00QbT00<LXb338<<012C400LTaBT6788<00P0220<8004220234001`a1444@@AAQ588DXaBT
00<HY08DY@059BI22e[?JcA_N002JeP3KcL2KcH036/fJaEZm6lfJcIRSCTV768LY2CX9@PU1`8U20<U
:004:BPYB2U7:DP2;DT00beZ<FXaJP03<FX00c6:<H/eR`02=H/2=H`013V<>JdmcCg>0d7^00A1cSg>
?Li1k`9:3`9><09>;`06CS1BDE8`DU5FDUIb0UZC0ejd0Uje00aNUEYCFU9RTfJdI]EZmFlfLcIgMGMg
MgP3MgT017^JNi]kVgnl0WoM00=o^gnKOiX00WnJ00=o^gnjOkX00Wnk00Io^WnkOi]kNg]jMeP2MeL0
1WLgLcQ_>7<hLcMc>09_>09_=`0QJaEReEjeH]I_>7MhMiMcEgMFMgMgMWMFNiMgNF/hH_I><D6]@Ji>
4E9ADW9BLE9@CU1><4h@BPm:44X`ARdaJAbU00<00088@006384UYT/@DgQCFD/H0dlI00m;6DlIC_U?
6E<IEcUG>U]JGg]W_6>kHiU>]CF>44@00P0000d400PP324<80P07:8i@cEU=B@a12d58<@LX`036:@0
1ARS6:@HXaRS7:<00Qc400DLY1RT6:@La1RT00<HX`0E5:<DPQ1Q468HXac37>@PiBDV9BLY9bTT9@@T
`cDSFTQ[3g<cKa=[4f[c009Zm003J_=Zm6[d009Zm0=Zm@9[5@03JaAZm6[d00IZm003JaAZm6[d00AZ
m006J_=Zm6/DJaEZmF/E0V/D0f/C0f/D2f/C00AZlf/CJa=[509[5@04KaE[56/DJa@4Ja<2Ja@00f/E
JaA[5002Ja@:Ja<016/BKa9[4V/B16/C1F/D0f/C1F/B00A[4FlAKa9_4`9[4`09KaA[56/DJa=[56/C
JaA[4f/D00AZl`AZlPAZl`04J_9Zlf[cI_<2J_801f[aJ_9ZlF[AJ_5ZlV[a00QZlP9VlP03I_5ZlF[a
009Zl@03J_9VlVKb00MVlP07I_5VlVKBI]=VdVKAI_000VKA00=VlVKAI]400VKA00AVd6KAI]5Vd@9V
lPEVd@04H]9R/V;AH[44H]45H]03H[000ej`H[5R/@02H[400ej`G[5N/@04G[4015j`GZmN[ej_0Uj^
00=N[ej^GZh00ej>0ej?0Uj>15j=00INSUZ?FXiNSEj<FVd3GV`015Y/FVeJSUY^0eY_00AJKUI_EVmF
KP9FK@03ETaFCEI=009FC@03ETaFJeI[00=FJ`03ETaFCEI=009FC003ET]FC5I=00=FC003DT]FC5I<
009FC0ABC004DTeBCU8^DRd3DR`2DR/2DT/5DR/3CR/5CRX5CR/2CPX00dhZCR]>2`03BP`00dX;BPY:
2P02BPX00dX;BPY62`06BPX1CPP1BN/0000:12048@0000040Ac6<FU:;UY]ET`3ETh6ETl025I_ETmJ
KeI?EVmJKUI>FTl9FVl01Ei_GViNKEi^GVl00eY_00=JL5j@GXl00ei]00URBeh9GPQN2Eh8HPMR9f8X
GPL00eh800AN:5i8GRMIi`9Ea`08ELEAYTfWFNQN9UhWGRUN2@9Mj009HR]ZSg<EOeMoU7ngOgEoEW/g
009oN00?MeQ_5VkeK]A^/VkBK_ER<Ce:;>PmcE8]ETaJKUZ@00ANT@0<GY9R/V:@BNd/aQa1664TXc44
:BHPa1R20aB300H@@QAR68<La23U7<@37<D03B348:@Pa2359<DTa2C59@HPXa0P300800`P00@8808<
@007364@@A10564DPQBS5:@00aRT00PDYABT9@DibDj=Ha1[=F/f0f/g0V/f00e[5V/EJaE[56/cHaE5
kBRS88<PaBT89@PQ1`048@P00bD89BPU:002:DP2;DT022eZ<FXaJS5[<FX]Jc5[<H`2=H/00cV/>Jdi
[@02>Jd00cg=@Li1kP04@Nh00dG_AQ1:4002BS003Th`CRm><DiACU9BDE9BEU9FLeZCFYAN]5jeG[@2
G[D02UjEFW=NU6;DI]EVeV[fKcMc=gMg17Mi00UgNW^JNiakVgnlOmeooGoLOk/00W^K00EoVg^KOiUo
VWnK009o_009Omeo_7^LNi]kNgMiMeQg=flh009[609[>@0;KcU_>6lhKcM[5V:dFWANLf:eI_M[=`02
JcP2KeP02FmIJcMW5f;EEU99kTF]BQ5>DP02DW82CU402Ti?BS1:<4X?BQ1>DDY?=HXLa@@00`0000P4
00b19HM:l4mhDeUC64lH14lI00I>nE<IDaUG>ELjFeX2Hk`03U^KDaHmkbC742840000200<81103008
01b2=B@2=FL01SDV;>DPaAc46:@HX`<HY08HX`<La0<LY00H7<@Ha1RT6:@HXaBT5:<@H@a1564L`acT
8@DU9RDW:BHY92D4:><e8eHXIa1[4fKc0V[c00=Zm6[eJ_@016[d0V/E00=ZmF/EJaD00V/D1f[d00=Z
mF[dJa@016[d00I[4f/DJ_AZm6[eJaD2Ja@3Ja<3Ja@00f/CJaA[5004Ja@00f/CJ_=Zl`02J_<00f/C
J_A[5@02JaD5Ja@3Ja<4Ja@00f/EJaA[5007Ja<00f/DJa=[4`05Ja<00f/DJa=[5008Ja@4Ja<3Ja80
16lCJa=[4f/C1V/D00=[5F/DJa@016[c0f[b1f[c0VKc00AZlf[bJ_9Zl`eZlP=VlP9Vl@9Zl@03J_9V
lVKb00IVlP04I_=VlVKcI]82I]<00fKBI]5VdP03I]42I]8<I]400f;BH[9R/@02H[45H]43H]000f:`
H[5R/004H[000f:aG[1N/@04G[45G[02GXl3GZl00ej^GXiNSP02GXl00eZ@GXmNS`02GXh2GXd00ej>
FXmJSP03GXd025i]FVeJK5Y/FXeJSUY^EVl2FVl015I^EVmFKeI_15I^0UI=0UI<1EI[00=FC5I=ETd0
0eI<0eI=0eI<00IBC5I<ETaBC59>DRd2ET`01E9=DRi>Cdh_CRd00U8/0U8[00=BBdi<DT/0158[0dh/
00=>:Th[CRX01dh[0Th;00E>:Th[CR]:34X;009>2`9:2P04BP]62dH;APX3BP/4BPX1CPT1BN`00084
8@06220800P17:DaAdH=0UI]0eI>0eI?0UY?00=FCeI_ETl00UI?00AFKeI>FTiJCPUJK`9NK`04GVeN
KUi_GVl2GW002Uj?FVmNKUi]GVaNBV99FNMN25h90Uh800ER25hXGRQN25h7009N200KFPUN9eh8ELMA
aUG5BHI5R5GXGPEN1V8YGPUMj5gYGPQZSVkcLeIkEGMELcE_5F[dI[=V/VJc009V/P0>J[9Z/FZaK]AR
;d5:<@PmRe8<ETaJKUZ@G[5N/P9NT@0=GY9NLF:ABNhe21A1668TY2ST:BHPa1QR56800QB300@DHaB3
68<LX`HLY0038:@Ta23500<Ta@069>DPXaA0300800`P1@PP00H@@0aQ444@HAB258<25:<36:@02QS4
7<@Pi35XARaW3FLbJeI[=F/f0V/F00YW5V/FJcI_=V/cJc1FKcEZ888TX`8TiP8Pi`098@PU22D88>LQ
1bD8:BPYAbe8008]B@03;FXaJS5Z008aJP03<F/aRc6;008eR`<i[004>JdmcCg=@Nd3@Nh00d7_ANi:
3`02BQ001TXACS1><4h`CU5>DP9BDP05DU=FLeIcFY=JU002G[D015jdG[EN]Eje0V:e00MVeFKfJ_M[
5g<gMeMgN003MgT00g]iNgYkV`02Ni/4Ok/00g^JNgYkNP03NeP09WnJOi]o_7oLOoiooGnlNkakVg]j
MeUg=flGI_MVn6/HKcUc>7LhLcM_=flfJaIRU5icFW9JTejdH_EW5V/FIaIVmF:cEW9B<4h?CQ02EU40
1e9aDW9BLTiBCS5>;TX_009:3`06CRm>D4X^<FTLYP@0100000T481dUBZm;MEMhDcQG>ELjDcT00dlI
0U<I01UG>U]JHgYOFE]GA[@ikbDY7:@HQ0`Q100<80PP200880`P688]13EW>FLe9Rd59<DHY0036:<0
1ART6:<HXabT7<@00Qc50aRU01HLY1RT6:@HY1S46:@DXa1R224<81RR8>DU92DU9BLY9RdT:@@XhSDR
DPQVl@9Vl`9Zm0AZm@AZm004JaA[5F/EJaD2Ja@7J_@00f[eJ_AZm003Ja@01F[cJa=[56/CJa@00V/E
0V/D0f/C0f/D0V/C0V/D00=[4f/DJa<016[d00=[56[dJ_@00V/E0V/D2f/C0f/D1f/C00E[56/CJa=Z
lf[b009[4P03Ka=[56/D009[4`M[50A[4`03Ja9[4f/B00I[4`9[50=[5@9[50AZl`AZlP03J_=Zm6[d
00AZm09Zl`03J_9ZlF[b00eZlP=VlP03J_9VlF[b009ZlPYVlP03J_=ZlVKB009VdPEVd@9VdP04I]5V
l6K`I_08I]44H]42H[44H]44H]06H[02H]001V:aG[5N/EjAFY1NT0=N/003H[1NSej_009N/009GZmN
[Uj>GXiNSej_G[1NT5j?00QNSP03GXeNKEi]009NK@04FVeJSEZ=FVd3FVh2FVl025Y^EVmFCUI>EViF
CEI<EVd7EV`015I]ETaFC5I[0UI<0UI=00=FC5I=ET`01EI<00]BCUI>ETaFC58]DRiB;dh_CRi>;Dh/
00=BB`03CTaBBe8[00=B:`9B;003CR]B:Th[00M>:`04BP]>2dh;CPX3CR/014h:CP]>2TX;0TX:00I6
2dH:BPY::ThZBP/4BPX1BPT1BN`0000?12488@`P20080AAS<BI5jeI=EXiBCeI>ETmFKeI?00=JC`03
ETmFKeI_009FL004EVmJKUY^FVh2FVl2FTh3GVl01EY_FW1JL5i_GVh00Ui_15i`00YNT5i^GVeNKEi;
HVUN9eh8FPUN209N:004GRUN:5hXGPP2GPL01E79CLQ9Z4VXBJL00TfV0195Z5GYGPIN1V88GPUN2V8[
GPYVKV[CJ_EZdV:aHY5NL5X^ENd2EL/00eX^HY5Z/P02J[406g;cJVm9JC3W>FY=k58/FVeJT5jaG[9N
TUjAGY9NLF:BBNle:AQR688Ta2T4;DLTiAR3468DHP0258<268<00abS7:@LY0028:@011bT68<Pa2C4
0R3500DTaB359>DPa1AQ00880006320880PP220<80a00Q1P00T@@AA1588DPaBT5:<DPQRS6:@00QRU
00PDPb3T>JUFSV<bHa9[=6]E0f/f0VmG00M[=FMFG/lmZb3676<Pa0028>H28>L02Ad88>LPibCW9@LY
:2U9:DPYB@03;DT00beZ<FXaJP02<FX01C5[<H/eRcF;=J`00SV/00@m[Cg=?Le1k@=1kP04@Nm:3dh>
CS02BQ03CS001DiACU9BDU9BDU<00UIc00=JTeZeF[D00eje00]NeV;FH]IVeVKfJ_M[66lhMcQgEgMg
009kM`03NgUkNW^K00AkV`03OkYkVg^K009kNP06MeQkEg]HOiYoVgnk0Wnl00AogGnlOk]kV`9kVP0C
NgYg>6lGI]I[67<hMgYgF7MILcQcF7<gJaMZmVJdHY=NLUjCG[@00V:d00ENTeZBFW9JLUYa009JLP04
EY=JTeJDDW82CU802TXaBRm63dX?BPi>3TX_@N`aBQRU0P000P@00P0000DDXcH]AcE;EUMi009GF@0P
EeYC>DlIDaUC>TlICaQGFU/iC[A2DRV=7>PLYRCV8<H@H`a2344<HA1Q340<81R2;@@eIcEX=DL]1B35
58<DPP8LX`@HX`047<@LiB3V8>H27<D00ac46:@HY0026:@25:<01Q23344@@ARS7>DU1@8U9@07:BDY
92T4:>8a8U8YHa400VKd00=Zm6/EJ_D00f[e0V[d00=Zlf[dJa@01F/E00=[56[eJ_@00f[d0V[e00=Z
m6/DJa@00V/D0V/C00E[56/CJaA[56/E009[5003Ja=[56/D00M[5003Ja=[56/C009[5003JaE[56/D
009Zm09[5@03JaA[5F/D009[509_50E[5003KaA[4f/C009[4`04JaA[4f/DJa@2Ja<3Ja@00f/EJa=[
4`02Ka<00f/DJa=[4`0;Ja@016/CJa9[4f/B1V/C0f/D00A[5F/DJaA[4`AZl`AZlP03J_=Vm6[d00=Z
m0AZl`mZlPAVlP03I_5VlV[b00AZlP=VlP9Vl@05I_9ZlV[bJ_9Vd@02I]85I]43I]8<I]400fKBH]9R
d@02H[401F;AH]1RdF;AH]000V;A1f:`1Eja0Ujb1Ej`00IN/Ej`G[5NTEj`GZh2GXh01ej?GY1N/5j@
GXmNSUj?00ENSP03FXiJSEY^009NK@06FViJSUY^FXiJSEZ>15Y_00AJKUI_EVmFK`9FKP9FK@MFK004
EVeFC5I<EV/2ET`01EI=ETaFCEI=DTd00eI<00IBCE9>DTiBCU9=ET`2DTd01E9?CRm>;Th]CTd014i<
00=BBe8[DR/0158/00=B:dh[CR/024h[0TX;14h[0dh;0TX;00A:2Th:CR]>:PA>:`04BP]:2TX:BPT1
BN`00088800=320400@0544a1DG[FXaJ[eI_ETiJKUI_ETl00eY?00=FCeI_EVl00eI`00=JKeY^FTh0
0UY^1UY_0UY`00=NKei^GVl00Ui_00ENL5j@GY1NT5i^009NK@07GTaNBEhXGPQN2Eh8GRP00UhY00IR
:5hYGPQJ25WVBJL3@DH02TEVBHI9QTVXENQR9UgVHPQN2F8Z0V8[00UVKfZbI]=NL5H]EPeF;Ui=GTh0
0Uh^019VT6JaJ]5ZdFkBL_=^/4EY<>HiB4g/DRaFCEjAG[5NTEjBGY42HY404fJcBPla:222788T`bdU
<FPY1AbS56<@@QB258<HPaRT7:@LaB34008PY08LY00<8<DTa2SU9<DPaBSU:@HLa1AR300880`P0PPQ
00@880`P340@H0<@@@08568DPaRT6:@HPaAR444<@P888@0D344P`cV8CTeRkV/bKeA_EF]EJcE[EFLC
Ia5FKcf[9<HHI22T8<DPi@8PiP048>LLib3W8>L29@L012TW:BPY:2TX0Re90ReZ1C5Z00@aRSF;=H/i
R`<i[003?J`mcD7]00=1kP05APm:3dh_CRm><002DU43CS00259ADU9BDU9CEW9FLeZDF[D2G[D00ekE
H]IReP02H]H026KEJ_I[5f/HJcQc=gMGNgL2MgL00gMiNgYkN`02Ni/2Nk/01WnjNiYkNg]kNi]oV`=o
VP9o^`9o_00EOk]oVW]jNgYkVGnINgUg=flGJ_Q_>7LfMgQgFG<hLcUc>6lgJaIZmFKE00=Ve005H[AN
TeZCFY=NT`02FY<01ejBFY=JTeJBEW9BLU9B009><@03BQ1:3dH?00963`05BPi:;dH==H`HYP020000
;0P022000000120M9Si`Dc=GMUMhEeQKNUmjFeYG>DlHB_M:eTZdBW9242T[5:LDIac79>DU1aBT46<@
HQ1Q560DHA10788e93EW>FPeAc458<DHPaB27:827:<01aR26:8HXac37<DLa1bT00<HY0046:<DXaBS
5:<25:8021B3468DPQRS7<@PiBD4:BD2:B@01BD3:>8e8U8XIa800V/E00=[56/EJ_D00V[e1F[d0f/D
0f/E00A[56[eJ_E[5@E[509Zm09[50A[4`03JaA[4f/D009[5004Ja=[56/CJ_<4Ja@3Ja<3Ja@00f/C
JaA[5002Ja@00f[dJaA[5@02Ja@01F/CJaA[56/DJa<01F/D0VlC0flB00A[4f/DJaA[509[4`=[509_
50A_4`9[4`][5004Ja=_4VlBKa42J_86Ja<2Ja@4Ja<00f[cJ_9ZlP03J_83J_<2J_@5J_<3I_<<J_80
0f[aI_9VlP05I_83J_83I_83I_401F[aJ_1VlFK@I]400VKB0fKA00EVd6KAI]5VdVKc00=VdP9Vd@03
I_9VdFKA00AVd@05I]9RdV;AH]5Vd003H]0016;AH]1RdF;A1f:`0Uja00=NdF;@G[4015ja00=N[ej`
G[000Uj`00AN/EjAG[1N[P9NSP07GXmNT5j@GY1NSej>GXl01Ej>00AJSEj=GVeJK@=JKP04FVeJKUZ=
FXh2FVl015Y^EViJKUY^0eI^00=FKEI/EV`02EI/0UI[0UI;00IFC5I;ETaFC5I=ET/2ET`0159=DTiB
CU9=159<00=B;Th_CRh00U8/0Th/00=>C59<DT/00U8[0e8/0U8[2Dh[14X;0Th[00A:2dh;CP]>2`9:
2`04BPY:2DX:CRX3BP/01DhZBRY:2TX:BPT00DW/000222002@P0100401AR<@A5bEi[FXmBC`04ETl2
FTl015Y_EVmFL5I_0eI`00=JKeY?FW000eY`0eY_0eY`0UY_0Ui`00=NKei`GW000ej@0UY_00UNKUi]
GTYN:Eh9FNQN25hXGPP00UhY00EN2EX8FNQIaT54008i100J?BE1ADEUAFE9Z578HPIN1V87HPQN2Eh:
HR]VKf[CI]=V/Ui`HY5RTVJAHW5RD6IaJ[9Zd`9ZdP0:I[5^dVj`BHTa1SU8CNaB;5Y^FY02GY42GY80
35jAI[9V/U8`;@LDHQAQ9:<aAS69:>DHPP8@HP0758<DHQR368<LXb359<D00R2T00/LYAc58<DTa2C5
:>D]1RT6:@LHY1A10088000822088@PQ200880`P460@@08@@@06564HXaRS568@@@`P0`P00P@0018<
81b2<DHmbTi_G/mW4V<AIcAS4eJ`@N`aB22T668HQ1c58>D48>H00acW8@LQ1`029@L2:BL01BTX;BP]
BBe:;FX00c6;0S5Z00<aRS6;=H/00SF;00`eS3V/?JdmcCg>@Ni1kdH?ANm:3dH`BRl2CS03CU400dh`
DS1BD@02DU800eIBEW9FL`02FY@00ejdG[ENe@03H]H026KFJ]I[5V/GJaQ[>6lhMcP4MgP00g]gNgUk
V`02Ok`00g^lNk]kNP02NgX017^JOk]o^gnk17nl00moVg]kNgUkFG^JNiUoVW^JMcUc5flHLcQgEg=H
LcT00Vli00Q[>6lGJ_IZmVKfI]ER]F:d0ejd0eZc00=J]5ZcFY<00UJC00=BLU9BCU400Tha00=:<4X?
BPl00TX?00E:3TX_BRli[ARW0080008400<00006224HiS7<@Y9:ddlh0U<h019>mdJe@YDnUD9C?Q0e
S3E:;@P/j2SY9@TU1acV5:D<HQAR588258403A10664a0cEW=FPeAc469<DLY1R37:<L`ac400@HX`04
7<DLa1bS7:@36:@35:<05ABR5:<@Xa1S468HXaS47>DU1BTV:BDY92D39>8e8U8YHa5W5F/EKaE[5@04
J_D3J_@00f/EJaA[5@04JaD02F/DJaE[5F/EJaA[5F/DJaE[5002J_@3Ja@2J_<00f/CJaA[5004Ja@0
0f/EJcI[5@07Ja@00f/EJaA[5@06Ja@2JaD2Ja@016/CJaA[56/E1f/D00I[4flCKa=_4f/DJa<2Ja@2
Ja<3Ja@6Ka@00f/CKaA[500:Ja@01F/CKa=_4flcKa<02f/C00=[56lDJa<00V[c0f[b1F[c0V/D00AZ
lf[dJ_=Zm09Zl`03J_9Zlf[b00YZlP03I_9ZlVKc009Vl`=VlP03J_9VlV[b00=VlPAVl@03I_9VlFKb
009VlP=Vd@9Vd003I]5VdVKB009VlP03I]9VdFKA009VlPIVd@9RdP03H]5Rd6;@00=Rd003H]5Rd6:a
00ER/09N/0UN/@=N/09N/@03G[9JTEjA009N[`03GXiNSej?00ANS`9NT004GXmNSUZ?FXh2GXh00ei_
FViJKP03FVh00eY_FViJK`02FVl00eY^FVmFK`03EVl00eI^EVeFK006EV`00eI]EVaFK002EV`01EI[
ETaFC5I=ET`00eI=0eI<00AFCE9>DTeBC0=B;@04DTaB;E8]CTd2DR`0159<DTe>C4i<0Th/00MB:dh/
DRaB;4h/DR]>:`05CR`2CR/9BP/5CR/014X;CR]>:dh[14X;0TX:0DX90DX<0003220020@0200HHS43
@JMFBeI]DTl3ETl2FTl2FVl4EW05FVl7FW03FVl00eY`GW1NL003GW002eY`GW1NL5j@FY1NKUi]GT]N
:UX9FNP01eh800=J25WVAD@00SSS00Lh`Cd3@BA5ADVXDLQMi@02HPD03eh7HPMN2F8/IW1Zm6lFI]=V
TFZbJ]ARLEX_HU5VTP03J[8046JaI[1^dFj_CJX`iCUXDPaBCEY^FVmNSejAGY9NTF:@0V:`01QBD34X
640@@2BR=DDeZBT5568<8AB456<@@AAR688LXb358<@PY22U8<DLaB359<@39<D012T69@LLY1110PP0
00<<80@P22000PPP020<8110440@@1A0564HPQbR564@@A10544LHQQR464DHAAR420@@Ab3;BHiZ47Z
APXmbCW9<HTY9R3568@HY1c50R351R3V00<Q1RD69@H00RTV00<Y9bdW;DP00be900<]JS5Z<FX00S6:
00DaRcE[=F/eRcV<008mc@91cP08@Ni1kdH?BPm:44H`ARm:;`=:3`9><007DS1BDE9ADU9BDEIbEY<0
0UZC00AN]5jeH]EReP=VmP08J_I[5V/GJaQ[>6/iLcQg=`9gE`08MeIkUG^GOk]og7nkNi]kNP9kF@04
NgQkNGnIOmX3Ok/2Ok`01GnKNeUgFG]INiT00W^J00AkVg]jMcQg=`Ac>@04KcUc>6/iJaP2J_L01f[f
I]ER]6:eH[AN/ejC00AJT`0<F[=FTeJCDW=BLU9BCU5:<DhaCS1>;dX_0TX?00I>3TX`BPheS1RV1002
00000`@01200000300007P0Q4:DI9R5Y;L`ekT8_@PlmcS5/=H`iSCf<?H]1[46<=DXXibT86<HDQ0PQ
588DXaB2464@@1A0;>8eIP8eA`06;@DTaAR4688LXac31aRS0QbS00@HY1RS6:<HX`<DXP8DX`0>58<@
HARS6<@LiB3U9@DU12TS:@<XhCDQDPQRl@9Vm005JaAZm6/EJaIZmP02J_D3JaD016/DJaE[5F/E2f/D
00=Zm6/DJa@01V/D16/C0V/D00I[5F/DJaA[56/CJa@4JaD4Ja@00f/EJaA_5003Ja@4Ja<00flDJaA[
5005Ja@2Ja<4Ka@5Ja<2Ja@6Ka@4Ka<2Ja<2Ja@4Ja<2Ja@00f/CKa9_4`05Ka800flCJa=[4`02Ja<3
Ka800f[bJ_=Zl`06J_<5J_84J_<00f/CJ_9Vl@0?J_800fKcI_9VlP03J_83I_800f[bI_5Vl@04I]45
I_43I]42I]0016:_I]5VdVKa36KA0V;B00MRdF;@H]1Vd6:`H]1Rd@03H]000f:`H[5R/@03H[400eja
G[1N/@03G[44G[04G[42G[800ejaGZmN[`05GXh025j_GY1NT5j@GXmNSUZ?GY02GXl2GVl4FVl2FVh2
FVl2FVh01eI_FVmJKeY_EVmFKUI]00=JK003EVaJK5Y/00EJK09FK003ETaFCEI>009FC@03ETiFCEI;
009FC09BC@9FC003DTeB;E8]009BC003DRaBC59<009B;003CTeB;4h/009>;0=B:`=>;004DR]>;58[
CR/2CR`7CR/2BP/6CR/00dX;CP]>2`02CRX014h[BP]:2dX;0TX:0DX90DX<00000`PQ220<80023200
1QAQ<@=1Ye9;FXeBC`9FC`09EU1JD5Y_FVmJL5I`EW5FKeI`009JL0=JK`MJL0=JK`=JL0=NL007GY1N
L5i`GY1JTEY_GVh00Ui<00AJ2Uh9GPMN:0EN200MFPUIiTE4?@@h`SSR><4m0TE5BJQEaegUGPIR9V8W
HPQR:f8/IW5Ze6lgI]AVTVJcGW9F45G]GTmV/`02I[42I[801fZbK]9Z/4VZ;>DiJ4g/009FCP04FVmN
SejAGY42H[4066:?H]1:;cDX864LHBRS=DLiZRdU68<<8A2448<@HQAR688LY1c48<@T`b347:@La08P
a@8Ta@089>DPiB3V7<@@@0P0220<80@88003320@@1AP008D@006788XXS3Q>B@mAT680T6900dmIcE7
<@DPPAb1544<81116:<LXQc28>8Ph`027<@01QRU5:@HaAc57>DLaP8PiP058>DTiR3V9>HU1`029@H2
:@H012TV;BL]B2U90Re900@]JS5Z<FXaRP8aR`06=H/eS3F<>JdmkCg^0Sg>00A1cT7_AQ164096<005
ARm644H@BQ1:;`02CS0014haDU5BDU9B0UIb0UZD00AN]5jeG[ERe@9ReP03I_MVmV[g009[5`04JaQ[
6F/iKcT2LeP04W<gMeMoUWoKOk]k^g^JMgUkNG]IMcQg5g]iOiUo^WnkOmao^`=oV`09NgYoVgnKNi]k
^g^jNi]kNWMj00=gN@9cFP0=LeUc>FliKcU[66/GJ_MZmVKfI]IR]5jdFW<00UZC0UJD0UJC00MFLe9c
DW9BDTiABU9><@02CS002DX_CRm>;Th^BS163S5[6:H40002000212000`@00000000300008P@0248@
Y1cU:BLeJSE:>D/mK4F]ALe9cTW^BPlmJS479>LHaa1S220@HQB3588@HP`P560/hS55=DLe9bd68<HH
YAAR1ARS0QB21ARS01HHY1RS6:<DXaB35:<DXQBS46<DHARS6:@La1cU8>DQ1BD49@</hCTRDPQW4P9V
m004JaAW5F[eJaD2JaH8JaD3Ja@3JaD2Ja@4JaD016/DJaE[5F/E16/D00=[4f/DKa@00V/C1F/D00=[
4f/DJa@00f/E0f/D16/E0f/D16/C1V/D2flD00=[4f/DJa@01VlD1FlC0V/C0V/D00A_56/CJa=[4`=[
50=[4`05Ka=_4VlCKa=[4`02Ja@2Ja<2Ja800flBK_9[4`06Ja<3J_<016[bJ_=ZlV[b0V[c0V/C0V[c
1F[b00AZlf[bJ_9Vl`IZlP03J_=ZlV[b00=ZlP=VlP9Vl@9Zd@EVl@03I_9VlFKa009Vl@03I]5VlFKa
00mVd@04H]5RdV;BH]82H]42I]000f;@H]5Rd009H[400ej`G[5N/@05G[400ej`G[5N/@02G[42G[80
1EjaGZmN[ej^GZl00ej>0Uj?0Uj@00AJSeZ>FXmNT09NS`9JS`04FY1JL5Y`FVl2FVh3FW000eY^FW1J
K`02FVl00eI_EViFKP02EVd5FV`3EVd01EY/EVeFKEI]ETd00eI>0UI=00=FC59<DT`00U9=00=FCEI<
DTd00U8]0U9<00QBBe9<DTaBC58/CTeB;59<0U8/00=B:e9;CR`00dh/158[00=>:dh/CR/01Dh[0dX;
1Th[00A:2dh;CP]>2P9>:P06CR]:2dX;BP]:2TX90DX<00002`Q0340<80`P420D@342ALQJBeZ^DTl0
1EI?00AJKUY_EU1FL09FK`9FC`AJK`IJL0=JKP9JK`06FW1NL5i`GW1NT5j?0UY`00=JTEY`GVh00Ui<
00AN2eh9GRQN:@AN200PGPMJ25G6AFDm93d3><4hhD53BHIAYeG7GNIR1V8UHRMR:F8/GPeRCfKCKaMR
]5iAEPmJ45G^FPiV/FkdJ]9V/P=Z/P0;K]9ZSdF:<>DiB4g/DTeFCUZ@GY1N/@03H[4036J`J_1>CcE8
840PPRBS<DHeRRdU7:@@@`8@P`06568DPQR366<LPb330RC300<LY1c48<D012C400DTiBD67<@@@0PP
008<80<88004100<8110564266403RRR>DE>2fJ/K^i^cf[AIZmZd5i`BL```AaP5402320020P0320<
@11R488DY1S56:D27<D012357<DLaR3V0RCU0bCV00HQ1RD69@HU1RT6;BH2;BL01Be8;DTYBC5Y<FX0
0S6:0S6;014eRcF<>H`icCg=@NhmcSf/@Li5kdH?BS1>DU9cDU5:<4X@009><008BS1>DDiBDU9BLUIb
EW=JT`9JU003G[AN]Eje009Re@07I]EVmVKgJ_M[5f/HKaT00Vli00YcFG=iKcM[5G<gMeQoN7oINiQg
E`9c5`06LaIbmWLGMcMkN7nj0gnk17nl1Gnk0W^J00AkNW]iMgUgN@=cF@0=LcU_FFlhKcQ[>F/HJaMV
mfKfI]AN/ejCFW<00UZC0eJC0U9c00EBLU9BCU5>DTha00=><00:DRm>;Th^DU1:D3V<8<H800001004
12000`@00000000200008@@0348HY357>FXiBd6=AHe5[DW=BJaF3Dg^?FXa1bT78@P@H``P588DPaB2
56<<8AQQ:<8a93E7>DLa:2377<LDP`036:<011BS5:8DPARR0aRS00<LXaRS6:<00QRS0QB30QBR00HD
PQ1R444DPARS7<@27>D02AcV7>DPhbC0=@5>2F;aJaE[=@03Ja@00f/EJaI[5P07JaD4Ja@01V/EJaA[
56/DI_AZm0=[5@05KaA[5F[dJaE[5002JaD016/CJa9VlV[c0V/C0f/D1F/C00=[56/EJa@00f/D16/E
00=[56/CJa<00V/C26/D0V/C1VlD00A_4flDKcA_509[509_5004Ka=_56lDKa@5Ka<01F/dJa=[56lD
Ja<00VlD00A_4flDJaA[50=[4`05Ka=_4VlBKa9[4`02Ja@2Ja<2Ja8016lAJ_9ZlV/B1F/C0f[c1f[b
00=Zlf[bJ_<00V[c46[b0V[a00=VlFKbI_400fKa0V[a00AVlFKbI_9Vl@9VlP=Vl@AVd@9Vl@AVd@03
I_9VdFKA00IVd@06I]1VdF;AH]5R/F;A0VK@00ERd6;AH]5RdF:`00AR/@=R/003G[1N/Ej`009N/09R
/003G[1N[eja00EN/@03G[1N[ej_009N[P=NSP08GXmNSUj?GXmJSej>GXmJSPAJS`04FY1JTEZ@FVl2
FVh2FW000eY_FVeJK`03FVh3EVh2FVd5FV`2EVd00eY]FVaFK@04ET`2ETd3ET`2DT`3DTd015I=DTeB
;E8]0U9<00IBBeI<DTaB;59<DTd2DT`7DR/00dh/DR]B:`05DR/6CR/2BP/00dh[CRY:2`02CR/01DX;
BPa:34X;CPX00dh[00E:2dX[BP]::Th9005>300000/8@0PP32088110540`hD6WFT]JSE9?009FC`9F
L005EVmFCeY_EU1FL002EVl2ETl015Y?FW1JL5Y`0eY_0eY`0eY_25Y`0UZA00MJLEY`GVmNCEh]FR]N
2P02GRT0<Eh9GPQN25XYFRQIjEGXBLQ1ITEUAFI5QdV7BHIAYeG7GNIR1V8VHRQR:Ui=GPeNCf[CJaMZ
mF:CHW5RD6IbJ]=c5G<FLaA_5W<FJ]=ZTVZAITe1RC3U=BM9k58]ETmJTEja00=N/P0<H[5V/6[`DU0i
BB10644PPbSU=HT]9AbT0a1S00D@HQAR568HPabS00<T``038<@LaB3500<Pa@089<@]9BD67:@DHPPQ
324<8088800:100800PP440DHAR28:8e958/Lbh2NiH027^HMgUkVGMgLeMJCSdU764254002@`P200<
8111468DPaBT6:DHa@027<D01B3U7<DLaR3V8>D00R3V00<Q1RD79@L00RD700DY1bT6;BH]9be8008]
B@8]JP<aJP8aR`8eS006>H`i[Cg=?Li1[Cf<0TG^00a63dX@BS56<T8??JdiSCf]@Ni644iACU82DU80
0e9CEW=FM002FY@015jDG[EN]V;F0V;E01YVeVKfI_M[5f/hLcQg>7<iLeU_=f;DFU9Ac5ibLeQo]WnG
NgIc=g<GMcMkFG]jNeUkNG^J0Wnk0Wnl17nm0WoM00=og7nkOk/00W^K00EkVWMjMgUc>G=I009_FP03
Ke][>F/i009[>@9_FP0;JaIVeFKEH[ANU5ZCFYAFU5JCDY=BM003CW<2CU800diACS1BD@02DU002Di@
DU1BL4iA>J`Xa@P000040004120030PP200800PP324881AS9>DaAce:@H]5S095[@0ICJe=ZeG/CNhm
JSDW;BLQ21B4344DPQB36:<DP``Q564X`cE5>FLmJ2d69>LHYQB46:@00QRS0QBS1ARS00LL`aRS6:<H
XaBS58<DX`0258801QAR444@@1B26:<La08Li@097>HLiAc49<4a0DX9G/i[=6/e00A[5@9[5PQ[5@=[
50U[5@=Zm003JaE[56/D009[5004Ja=[56/EJaD6Ja@3Ja<01F/DJaE[56/DJaD00V/D0V/E0V/D0f/C
26/D0V/C26lD00=[56lDKa@00VlD00=[56lDKa@01flD00=_=6/EJaD00V/D1FlD0V/D00=[4f/DJa<0
0VlC0f/C0V/D16/C00A[4V/CJ_=Zl`E[4`9[50=Zl`EZlP9Zl`03Ja=Zlf/C00=ZlP03I_9ZlV[b00EZ
lP03J_=ZlV[b00=ZlP09J_5VlFKaI_5VdVKbI_5ZlF[b00EVlP=Vl@03I]5VdVKA009Vd@03I]9VdFKA
00IVd@03I]1VdFKA00=Vd@03I]1RdF;A00=Rd@03H[5RdF;A009Rd@03H]9R/F:a009R/@AR/004G[1N
/Ej`G[02H[03G[06G[400ej`GZmN[`03GZl3GXl00ej>GXmNS`04GXl2FXl00eZ@FY5JT@02FY4015Z@
FVmJKUY`0UY_00AJKEY^FViJKPIJK@03FVaFKEI]009FK@=FKP03EVeFC5I<00AFC004ETeFC5I=ETd4
DTd2DTh01e9=DReB;E9<ETaFBeI<00=BC003DTeBC58/009B;0=B:`A>;003DR]>;58[00A>;0I>:`05
BP]>:dhZCRY>:`02BP/00dH/BR]::`04CR/01DX[ARa::dhZCPT00Dh;00002`a0320<@0a0320D@33Q
@HAFBUJ=DTl00UI?0UI_1eI?0UY?00AJKeY`FW1JL09JK`aJL004GW1JL5i`GW42GY401ei`GTmNCEh]
FR]N2UhY009N2@06GPQN:5X9FPUJ25X70UG701MIj4g7BJQ5R4V7DJMEaUh5HRER9V8YHRYRCEh]IVmZ
dg=HNeMc=gLfMcMg5W<E009^m00?K]=Ze6[DJ[=VTVJAITa9ZS3U=BI5jdh]ETmJTEjb009R/P0IG[9R
/F:_IZmBCcE8844D@B23:>@iZSE57:@@HPaS46<@HQAQ568HPabS:><ThbC38<@00b3500LPYB359<@/
iB3U6:<DHP0232400``P2208800222002``P440DHAR18:8mIUi[Ok=of7ngNgL00W]h00]kVG=GK]0m
AaQR444HPA11324<@AAR008DP`8DQ0046:@LY1c57<@27<D0123V8>DPiR461BD700DY1bT6;BH]Abe8
008]B@03;DX]BBeZ008aJP08<HXeRcF<=H`iS3V]?J`mc@91c@95kP0ABPm6<4H@?LhY:B2V78HY23V:
@Ni:<4iADU5B<E9BEW=JM002FY@06EjDH[ENeV;FH[ERe6KEI]IVmV/GKcQkEgLhLcQ_5fJcDJd/j2RV
<@QNCWMFOiIkUgMi00=kN@=oV`03OkaogGoM00=og004Okao_GnmOk`3Ok/03GoLOk]o^g^JNgYgFGLh
LcQ_>G<iLeY_>F/i009[>007KcQ_F6lgI_EVeF:dG[@00UZD00=FUEJDDW@00e9d0U9b00A>LU9aDU5B
D@9BD09><009DW1>D3V;:<D800@0000880@P00D88008320@@A126:@TiSE8?FY1R`95[00<AHa9S4V;
DL]9cCeZ=BL]1AcV6:@<81AR0aB300P@@QAQ;><eISf7?DHa9BCV0QRU0QRT00DHXaBS5:8DPARR00HH
X`<DX`<DPP06464@@A1P6:8HXac40acU00TQ1B44:>8e0Th9G/e_<FlCJa@05F/E0V/D0f[d0V/E00=[
56/CJa@016/C0V/D2F/C16/D0Vld16lD2f/D0V/C2VlD0f/D00E_56lEKaA_56ld00A_5007KaE_=FlE
JaE_5F/EKaD01FlD00=_4f/CJa<00V/D00=_56/CJa@00V/C0flD46/C00=Zlf[bJ_800f[b0f[c1F[b
00EZlf[bI_9ZlV[c00QZlP=Zl@06I_5ZlVKbI_9VlF[a0VKb0VKa00AVlVKaI_5VlAQVd@9RdP=Rd@04
H]1RdF;BH]44H[43H[000f:aG[1N/@02H[42H[03HZl4G[02G[4015j`GZmN[ej^0Uj_0Uj@00ANSej>
GXiNSPANS`03FY1JSeZA009JL@9JT@06FW1JKeZ>FVmJL5Y_0UY]2EY/00=FKEI^EVh015I^00AFCEI<
ET]FJ`=FB`9FC0AFC@9BC@03DTiFCU9=009B;@05DTaBBe9;DT]FB`05DT`2DR`00e8[DT]B:`03DR/7
CR`DCR/3BR/00dh[BRY>2@01CN`0000;344@@11P364<81A0<>51QEI;EXeBCP02ETl00eI`ETmFC`04
ETl3FTl2FVl3FW000eY_FW1JL005FW000eY_FW1JL004FW03GW03GW401Ei`GTiJCUh/GPX00UhY1UX9
00eN1eh8GPQR:5gWENQEb578DJMIaf85HRIR9`02HRX03f9<GR]RCV[CNgMoUgniOiQo^gmfK_EVTV8_
GU1RL@02I[802fJAK]=Z[e7;<>He9TG/CRiBCeZAG[400ejb011NTF:_HZiBCcE898<LHR22;@DibSUV
8<@@H`Q2348@HP8DHP0768<LXb338<<Ta2347<D00R2U0b3500@Pa2356:@DHP8<8@0322088@PP0088
808<800G564DH1b1>HIRc7=bNmUgMgMEMcIg=GmhMeQZ/3TW424@@AR1444<8@`P56<@P`0258@011RT
68<La1S50Qc500HLiAcV8>DPiR468@L39@L29@P012TW;BLYAbU80Re900@]BRe9;DTaJ@8aJP8eR`05
=H`iS3V/?Ja1c@02@Nh03DG^BNi><4Xa@NlaBb2U86@TY235;DTicDH?009><@09DS5BDEIcEW=JM5ZD
GYAN]F:e009ReP0GH]ER]FKFI_I[67<hNeMgF6lGJ]IVLTU9;:LH0bAVBDQZdWnHOkYk^g^JNi]oV`02
Ok`00gnmOmeog@04Omd00gnlOkeo_004Ok`01WoMOmao^g^JNgUkF09g>09c>@9_>@9[6004KaQ_=flg
KcL2I_H026;EG[EJU5ZDF[EJU5JEEY@2DW@00e9cDW9BLP02DW801E9ACU5><DhaBS400Tib00<mcRS6
20000P@000<880@P220010PP01L<80a1368DYBD8=FU1RT6;AJa5SDF]BJa=Re7:BL`mJS46:>@LaAB3
320@@AB2008DP`0>344D@2C3<DDmQcU6=DDTiARU48<DQ1BT6:@DY08DX`03588HXaRS008HX`036:@H
XaBS008DX`046:8DPQRS5842564011RR6:<La1cU0R4500TU1BD49><e8Dh9I`i_<VlcJa@056/E0V/D
00A[5F[dJ_AZm09[5@M[50=[4`9_5003KcA_56lD009[4`03Ka=[4flD009_5003KaE_56lD00A_50Q[
511_5006JaE[56lDKcE_=6le0VlD00=[56lDKaD01flE16lD00=_4f/CJa<01V/D0VlD3F/C3V[c0V[b
0f[c00=[56lDJ_<02f[b0V[a00EZlV/CI_=VlVKa00=VlPMVl@03I]5VdVKA01=Vd@05H]5RdV;BH]9R
d@02H[400f;AH]9RdP02H]43H[401ejaH[5N/EjaG]5N/5ja009N/003GZmN/6:_009R/005G[5N/5ja
G[5N/002GZl01Uj^G[1N[ej@G[1N[`=NSPANS`9JT0EJT@03FW1JKeY_00=JK`9JK@04FVaJKEY/FVd5
FV`00eI]EViFKP02EVh015Y^FY1JSeY^0UI<0eI;0UI<1UI=00=FCU9=DTd00U8]00=BC59;DT/00U9;
159<00EBCE9<DTaBBdi<00AB:`E>;003DR]>:dh[00=>:`=>;0U>:`9>:P9::`06BRa::dX[CR]>:Th9
0Dh<00003@a1340@H11Q344D@2S2>DA>:eI^DTiFCeI_00UFC`9JC`03FVmJL5Y`00MJL09JK`04GVmJ
KeY`FW02GY001Ei_GW1NL5i`GY400eia00YNCei>GRaN2Eh8FPUN2EX9GPUJ2@9N2@0=GPQN1f8WGPMN
1EGVFNEEaeG8FLMR9F8VHRT00f8Z00IN2Eh:J]9kEWnDOgD2OkX037mfJ[=N<56]ENiRLFJ`I[5VTFkc
L_5Ab`8a1P04ANa:3U9?FY45GY403fJ`IZiBCcE99:<LHR1R;><iZCE58<@<@PQ2348@HP0256800aR2
78<LX`027:@27<@00abU8:DPY@038:D00abT68@@@P023242224422005110460D@1b1?HIJS6laKe=[
4fKBI_A[5FlEKcIRCSSV524DHQR1564232001a1R58<DY1BU6:@LY1c400<La@037>DPiB3U008PiP@U
1`048@PU22TW;BL3;DP5;DT0735Z<HXeRSF:=F/eRcV;?Ja1c47^APm63TX>CU1:DT7?;BTTaRc5::<T
XbT7>Ja63dh@CS1B<EIA0UIb00EFLeZDFYAN]F:e00=ReP0DH[EVeFKfJ_M_5WmFNeMg=f[FHU=5Bbc8
:<XH9SdYHY1o^7nINiUkVP=o^`9o_003OmaogGoM009og@9og0Io_00=Omao^gnkOkYkVW]hMcMc>7=I
LcU_>F/iJaP00Vlh00E_=flGJaMW5fKg009ReP0;G[EN]5ZeF[AFUEJDDWABLe9bEW5BL@02DW802U9A
CU9>DDhbBQ9>Ddic@Q4Xa``00P@000<480PP220010PP01H<80a1448DQBD8>FY1RT6;AJa5SDF]BJ]9
RU7;BL`mJS459<@HY0a2224<@@8DPP0<48<8810P8<<aACU6>D@e92CU6:@@@Q1R0QB30aBS0QRS00<H
`ac46<<00aRS0QBS0QBR0QB20QB100HHXQRS7<@LiBD59BD29@@022SQ=B5B1fL>Kc9[4V/DJaD5Ja@>
JaD2Ja@00f/EJ_AZm002JaD3Ja@2JaD3Ja@6Ja<4Ka@00flCJaA[4`02Ja<00f/DJa=_4`03Ka@00flC
Ja=[5006Ja@4Ja<00flCKaA_5009Ka@00f/EJaA[5002Kc@016lDJaA[56/D1VlD0VlE00=[5FlCKa<0
1FlC0V/C00E[56/CJaA[56lD00=_4`Y[4`aZl`07Ja=_4V/CJ_9Vlf[bJ_<026[b00=ZlF[bJ_800V[b
00=VlV[bJ_400V[a00=ZlVKaI_400fKb2FKa00AVdVKbI_5Vl@=Vd@03I]1VdFKA00aVd@ERd@=R/@03
H]5R/F:a00ER/@=N/@03GZmN/5j`009N/0=N[`03HZmN/5j`00=N/003GXmN[ej^009N[P=N[`04GXiN
SEj=GXh2GXl01Ej>FXmJSeZ@FW000eZA00=JT5Y_FVl00eY^00AJKEY^FVeJK@QJK003ETaFKEI]00=F
KP9FK@9FC0=FB`9FC004ETeFKUI^EVh2ETd00e9=DReB;@03DT`5DT/3DT`01E8/CRaBC59;CR`0158[
1Dh/1Th[0dh/0Th[0dhZ0dh[0Th:00=:2dX[CRX00TX/0dX[0DhY0Dh<00002`Q1320<H0aR220<822R
=DA9jU8^DTh00UI_25I?00AFKeI?ETmJC`]JL003FVmJL5Y`009JL003GY1NSej@009NT@ANL@03GW1N
Ceh/009N2@05FPUN2UX:FPUJ2P02GPT03Uh8HRUN25h7FNIEieWWELQIb5h8HRMN:F8YHRX2HRT03688
GNQZ/WMGOgEkEG]HMcMc5V[EHY=VLP9V/`9V/@04IY5ZdVk@DL/2<@H014G<CRmFL5ZA0UjA01MN/Ejb
H[5RSV[>ERhiJb24668LHBcT>HPeAB3534<88@a2344@HAAQ688HPabS008LY0@LY@<PY@078:@LY1bU
568<8@`P32400PPQ00<880P022000Q10018DHAb1>FIFKVK^I]1NSf[cLcEgEVlfJ]AN33BT744DHQRQ
564234400a1S5:DDY0026:D00abT7<DLa@037>H28>D28>H02b469@LU1b478@PU22TX:BLYB2eX:DT0
0RTX00@]B2e9;DT]JP<aJP06<F/eJcV;?Ja1cD8>0dH?00a:<4IB?LhiJcDX<@L`iRB2:>DeRdG_BPl2
DS0045IAEW9FLUYdFYAJUEjeH[EVmf;gH]MR]V;FI]IVmV/G0WLg00]g>6JdHW9=[cU<:<TTR44YJ]9o
VG]i009kVP05Ok]o_7nlOiao_@03Omd3Omh3Omd01GoNOmeogGnlOk/00W^K00QkNGMiMeUg=g=HLeYc
FG<i0Vli00=c>6lgKcL00V/G00]W5fKgH_MReUkEG[AJ]EZdEYEFM59d009BL`0>DW9FDEIbDW9BDE9B
CU9>DdXcBU=>LchA:<L<00840006124480@P120880P00P`P01`<@@a246@Pj3E[@H]1[46^AJi5[DV/
BJ]=c4g^@FTa1BC56:D<@`PQ348DPQRS48<880`P8<<a9@<iA@05:>@HY112448@P`0358<25:<011RS
6<@LiAS40aRS0QBS00@Ha1BS588DPP8DP@0?6:8HXacT8>DQ1B4U9B@U0bC1=@1B1fL>Jc9Zlf/D01E[
5@03JaA[5F/E00=[5@03JaA[5F/E00=[5@05JaA[5F/DJaE[4`08Ja@01F/EJaA[56/CJ_<00VlC0Vle
00=_56lCJa<026/D0V/C1VlD00=[56lDKa@00flD00Q_5F/EJcA_=6/dJaA_56/D0VlD00A[5F/CJa=[
4`9_5004KaE[5F/EKa<3Ka@3Ka<6Ja@016/CKa=_4flC0f/C0V/D2V/C2F[c00=[4f/DJa@00V[c3F[b
00=VlV[bJ_4016[b0VKa0fKb16Ka0fKb00EVlFKbI_9VlVKa009Vd@05I]9VdFKAI]5VdP03I]43I]85
I]42H]401V;BH]5VdVKBH]5R/0MR/@05G[5N/6:aG[1N[`07G[000ej_H[1N/005G[05GZl2GXl3GXh0
0ej?FXmJS`02FXl00eZ@FXmJT004FXl5FVl00eY^FVeJKP02FVh00eY]FViJK@02FVd2ETd3EVh00eI]
EViFK@03EVh2ET`00eI[ETaFC@09ETd2ET`3DT/2DT`00e9=DTaBC002DR`00e9<CTa>C003CR`2DR`3
CR`00dh]CRa>;002CR`3CR/3CR`2CR/3CRX3CR/2CP/00dX;BR]::`04BR`1BR/1CRX1BP`0000@244<
80a0364880P07:8eADG[DTiJKEI^FVmJCeI?EVl6ETl00eY>FTmJK`02FVl9FW000ei`FW1JK`02FVl0
1Uj?GXiNSej@GY5NL0ANL@04GW1NC5gXGPP2GPT00eh:GPQN2@04GPT01Uh8GPMMieWWFNQIj@9N2003
GRQN:F8Y009R:@05HRQR25gWJ[1c=P02NcH03WLFLaMc5VlFK_E^m6kCJ]=VTF9_IXiZ/6Z_DL`2<@H0
14G/CTmFKeY`0UjA00QN/UjAH[5RSF[=ERheBR240QQR00L/i3f8?HHU1Q24224<@@0244400aAQ688H
X`027:@012347<@LY1bT0R2U00TTYB2T8:@LYAc646<<@@P032400`PQ01H800PP340<@1AP788eADX<
GTQNBfkdOg=onGojOkMgFF8^><DL81A1784DH@8@@P0:58<DYABT5:DHYART6<DLaAcU7>H38>D0123V
8>DTiRD60bD700<Y1bTW:BH00RTW00DY:2U8:BPY:2e800@]B@04<DTaJSEZ>HT2?J/013g<@Ni23dH?
0TYA00hm[CUZ>DP/iRS5:<@Xi3f/ANm>3e8`DU1FL5Ib0UYc00MJTejDGYAN]F;FH]MReP02H[H04F;F
I]IZmV[fJ_EZeFJdIY9J<DF=>D`mC5G_KaEgF7]jNi/00WnK00=o_7nmOkd02goM00Qog7^lNgYgFGMH
MeUgF7MI0WMH00=cFG=JLeT00W<i00Ec>7LgLcMc=flG009[6006I_MRmV;FG]ENe5je0UZe00IFU5Ic
DW=BLe9bDU82DW83DU801dhbBSA>E4ic?Q4Xa``00084000D10448@@P120800@0200880`P324@@bCY
<BXmK46=ALm5[TF]AJa9[099c005@HT`iBC56<H@I002348031226:8DPPa0420P`cE5@HLmASUV:>@L
Y08@H`035:@DPaB3008DP`03588HXQRS00@HX`<DX`0E6:8DXaB2588@HAB16:8Ha1cT7>DU12DT9@@T
hbBP=@1>1f;]Ja9[4f/D011[5@03JaA[5F/E009[5@M[509[5@04JaI[5F/EKa@2JaD3Ka@00flEKaA_
5004Ka@3JaD2Ja<3Ka<4Ka@7Ja@5Ka@00f/DKaA_5005Ka@5Kc@01FlcKa=_4flCKa@00Vld00=[56lD
Ka@00VlD0VlE0V/E16lD0flC0f/D16lD0flC00E[4flDKaA_56/D00Y[4`04J_=ZlV[bJ_<3J_800f[c
J_9ZlP0CJ_800f[aJ_9ZlP05J_800fKbJ_9Vl@03I_400fKbI]9VdP05I_401FKbJ_9VdF[aI]401VKB
2FKA1F;A00EVdF;AH[5R/F:`00=R/@9R/09R[`03HZiR[ej`00=N[`AN/003HZmN/5j_00AN/0=N[`05
GZiN[ej?GXiNS`02GXh00ej?GY1JS`02FXl00ej?FXiNSP02GXh3FXh00eY^FVmJKP08FVh4FVd01UI^
FVeJKEY/FVeJKPAFKP03EVeJJeI<00AFC@9FC004ET]FC5I;ET`5ET/0159<ETaFC5I<0e9<00=B;59<
DT/00dh/0U8/00=B:dh/CR`00Th]0dh/14h[0Th/0Th[1DhZ00=::dh[CP/00dX;0dX/0TX[0Dh90DX<
00000`a1340<@00234001`P06:<a9DG[EVmJSeY^009JC`04ETmFKeI?FVl4FTl00eY>FVmJK`02FVl5
FW001Ei`FW1JL5Y`GW000ej@00EJKej?GXiNSej@00INL004GW5NC5gXGPP3GPT2GPP3GPT02F8ZGPQN
1egVFLMIj5X9FPQN2@04GRT0268YHRYR2EgZIW1^mGLeMcH2MaH2MaD01g<EK_=Z/V9aGTmRL6J>009Z
/008DL`/iC3U@L]>;e9>FW1NT@9R/@0?G[9R/VJ_J^iJ;SDY88@HHab3;>@iISfV8>H@I0PP008@H@8D
H@03688LY1bT008LY0037<@PY22T00@PY0047:@LaQR546<432403PPQ220800@P320<@1AQ688/i3f8
EJMR:7laOo/2Ool02gokOkEZ/DU8:48@@AR1568<@@`Q58<00QBU00@HYAS56<HLaP8LiP088>HPiB3U
8@DPiRCU9>HU1PDU1`03:@LY9bTW00DY:004;DP]BBe9;DT2<DT063EY>FTiRSV;?J`mcD7^@Pm63d8?
?JdeBS4X;>L]1cE9?J]1kTW_DQ1FDEIbEW5FLP9JLP9JL`06FY=N]5jeG]IReV:f0V:e00mReFKFI]IV
eVKEJ]EVe6KFHYARM5iDI[E_=gMINiX00W^K00AoVgnlOkao_@9og@03OmiogGoM00Eo_@9k_00;Ni]g
NWMILeUgFGMHLgUcFG=HLeU_FP03LcT4LcP016lhJcQW5fKf0V;F00ENeUkEG]EN]EZe009JU004EYAF
M5IcEW<2DW<02U9bDU=BDThbBS=>E4iB@O0Xa``00P@000@880@P12048088800;100800PP320DHR2S
<BLmRd6<AJe5[P02AJd06DG=ALa5Zd69<>DTaAS646@<@`a2488DXQ22240801bS=DI1Qd5W>DL]1AbU
58<DQ1BT008DP`0448<@PQB258836:<00aRT6:<HX`025:<04QBR5:<DPQ22460DPARS6<@Li23U9@@U
1BD49><T`CD1CPQRk`9W4`03JaEW5F/E00A[5@03JaI[5F/E00M[5@9_50U[5@04JaA[5F/EJaH2JaD0
0flDJaE[5@03Ka@016lEJaA[56/D0VlD00I_5F/EJaE[5FlDJa@3Ka<4Ka@2Ja@2JaD4Ka@00f/DKaA_
5002Ja@6Ka@01fldJcA_=6lEKaA_=Fld009_4`05J_=_56/eKcA_=@03Ka@016lEKaA_5F/E0flE0VlD
0f/C2FlD00=[4flDKa@00VlD00E[56/CJa=[4flC00I[4`9Zl`03J_9Zlf[b009ZlP9Zl`9ZlP=Zl`04
J_9Zlf[cJ_<DJ_82I_42I_8016KaI_9VlVKb1FKa00AVlV[BI]5Vd@UVdPIVd@ERd@03H]9RdF;A00MR
/@04H[1R[f:_HZh3H[02HZl01Ej_G[1N/5j`GZl00Uj`00=N/Ej`G[000Uj`0ej_00=N/5j_GXl00Uj?
0Uj>1Uj?00ANSUj?GXiJSP=NSP03GVmJKUY^009JKP=JK`9JKP9JK@07FViJKEI^FVeJKUY]FVh01EI^
00=FKEI<FT`02UI<0eI;0U9;00ABC5I;ETaFC0=BC09BB`9B;005CRa>;Dh/CRaB:`03DR`4CR`014h[
DR]B:dh[0dh/0dh[00E>:Th[BR]:;4X[009>:`9:2`A>:`5:2`5>2@5:300000<<@@`P34000Q1000/8
01AR<@E5bU9?EVeFCUY?FTiJCeI_00=JK`9JC`04FTiJKUY^FVh2FVl3FW000eY_FW1NL002FW000eia
GW1NT002FVl2GVl3GXh2GXl3GW001Ej@GW1NC5h8GPL00Uh800=N2Eh8GPT00Uh800YN2F88HPMR9egV
ELIIieWXGRQN209N:0=R:@08HRYR:eh<HU1ZmG/eNcMg5@=g5007La=ZdFI_GTmJ3Uh]IVd00VZ`00M=
c2c5;<=1ZE8^DTeJL002GY0046:aG[9R/VJ`K^mJCSUZ88<LHRBS;><e8cf49>H<@`P00Q1Q0QAQ00<H
PQRT7:@00abT122T0b2S00HTiQRU56<88P`R2282224322002P`P340DHAR29:91REWXJXaoKGoh0Woo
00aoo7odOgEQjCC6544HPQB23448011R5:@26<D011c67>HLiQcV0R3V0R450RD500HU1RDV:BLY9bDW
9@L2:@L00bT69BLU9`03:BP00bU8:BPY:002;BP01BdY;DPaBCEX=FT00cF:010iRSV;?La1c3g<?J/i
Jc4Y=BTiJcf]ANi:458_ERmFD09FD@03EW5JLEIb009FL@9JLP03FY=N]5jd009NU00:G[AR]6:dHY=N
Lf:DJ]Ec>7=ILcP2J_H016/GLcMkVW^J0W^K00AoW7nlOkao_@9og@07OmiogGoMOkeoW7^KNg/017^K
00EkNWMjMeUgF7MG00AcF006LeU_>F/hLcQcF7Lh0W<h00M_>6lgJaIVmV:eG[ENeP02G]D00ekDG]EJ
]@03FY@00eZCEYAFT`02EW<02e9BDU5><TXCCU=>DSg_<@L<00P0100010PP02`800@010088110588P
PS4U@LY5kDG=>F/mK46<AJe5cDW]BLa1RC3U:>DLaQB4348@HQ225:8@PPPP300LXS4T>DDmASDV;>DL
a1B258<DY1B3464@HQ220QB20QRR0aBS0aBR0aB200H@PQ1Q584HXac47>@28>D022458>@Pi2CR<@9:
2V;`Ia<2Ja@00f/EJcE[5@0<JaD00flDJaA_500>JaD00f/DKa=_5005Ka@3Ja@3Ka@3JaD00f/DKaA_
4`05Ka<00flDJaA[5002JaD7Ka@00flCJcA_5005Ka@02FldKcE_=6lEJaAZlflCKaA_4`02Ja@00f/e
KcE_=@06Ka@00flEKaA_5@05Ka@00flCKaA_5004Ka@00f/CKa=_5004Ja<2Ka<8Ja<01F/BJa=[4f/C
Ja800V[b00AVdV[bJ_=[4P9ZlP=Zl`04J_9[4f[cJ_<;J_800f[cJ_9ZlP05J_800fKaJ_5ZlP02I_88
I_400f[aI]5Vd@02I]400fKBI]5VdP07I]800f;BH]5Rd@02I]42H]400f:aH]5Rd@02H]800f;AH[5R
/@02H[0016:_H[1R/F:`0V:_00AR[V:`H[1R/09R[`03GZmN/5j`00AN[`03G[1N[ej`009N/0AN[`03
GZiNSUj>00ANSPANS`03GVmNSUj>00ENS@03GVeJKEY^00IJKP03FVeJKUY^009JKP06EViJKEY]FTaJ
CEI=0eI^0UI]00=FC5Y<ET/01EI<00AFBeI<ET]FC0QFB`03ETaBC59<00=BB`9B;005CRa>;Dh/CRaB
:`06CR`01Dh[DR]B:e8[CP/00Th/14h[00=>:Th:CR/00dX[0Th[1TX;0Dh:0DX<00000`Q122488002
32002P@0320/i47:CU1FKUI?FU1JCeI?0eI`0UY_00=JCeY^FVh015Y_0UY`0UY_0UY`0Uia00=JTEj@
GY000eY_0ej@00ANSei`GY1NT09NL004GY1NKeh/GPX4GPP4GPT3GPP01eX8FLMAYTg7FNQRAf98009R
:P=R:@08HRYN2Ug[HU5^e7]ENeMk=0=g500ALaA^dfZbIY5RD69?IY1V/FJ@DL``ibRQ@JQB;EI=FW1N
T002G[4045jbGY9RSf[aGY4mS21S768LPbcS>D<mQ2CV34<801100Q1Q00<@@AR26:<00abT00@LYB35
8:@PY@8PY0068:<Ta2357:DDI0P20PPR0`PQ0PPP00`<@A1R568HPRS2DNU^k7<ANdmoeGojOo`2OoX0
2goaMa@mBQaQ688DPa11300DHQBT7<D00acV00<Q1Qd67@H00R4612D60RDW00<Y9bDW9BL00bD70RDW
1RTX00d]:2e9;DT]BC59<FPaJSEZ=H/iRcF;>H/i[002?J`02cf[?J`m[D6]ANm:<E8`CQ1=kU8?DRl0
0U8`00=BDEIADU800U9B00=FDUIbEW<00UZC0UjD00YN]F:dHYANLV9cI[AZmVlGLgYcF@9_>@04LcMg
Eg^JNgX3Ni/017nlOkeo_GoM17oN0Wnm00Yo_7nLNi]oW7nkNi]kNWMjMeUgF0=cF09cF@0=KeU_>Fli
LcUcFFlhKcU[>F/hJaM[5V[fI]D00f;F00UNeV;EG]INeUjeF[EJU5ZCFY@00UJD0UIc00QFDThbCS=:
<U9b@Q0a1Q000P@00`PP0P@000`800a15:<PiBd4>HM>;Uj^H_=FD58?AH`2?D/05T6]ALe5cD6:<@HX
iAc546<88A1S48<HXaB2320<01bS<B@iASeX<@HXiAc40QB20QB300<@HA1R46400QB200<DXQBS5:<0
11BS00DDPQB358<DPa22008DH@0=6:8Ha1c47>DPiB459@DQ1BCS<BA62ekaIc@01F/e00=_=F/EJaD0
1f/E00=[56/EJaD01V/E0f/F0f/E00I[5V/EJaE[5F/DKa<6Ka@016/EKaA_5FlD0V/E00E[5V/EJaE[
5F/D00=_4`04KaA_4flDKa@2JaD00f/DJaE[5@06Ka@00f/DJcE_=004Ka@2Kc@00fleKcA_5@02KcD0
0flDKcA_=@02JcD00f/fKcE[5@02KaD7Ka@00fleJaA[500>Ka@8Ja<01FlDJa=[4f/CJa801V/C00AZ
lf[bJa=Zl`9ZlPAZl`04JaAZlf[cJ_83J_<7J_800f[cJ_9ZlP08J_82I_83I_43I_800fKAI_5Vl@02
I_42I]42I]800fKcI]9VdP05I]83H]82H]400fKAH]5Rd@02I]400f;AH[9R/@02H[44H[02H[4016:`
G[1R/6:`0V:a0V:`1Ej`00EN[ej`G[1N/5ja009N/0IN[`=NSPENS`ANK`ENSP03GVmJKUY^00QJKPIF
KP9JK@9JC@04ETeFKUI]EVd2ETd5ET`00eI=ETaFC002ET`00eI;ETaFB`05ET/00e9;DRaBC002DT/0
1E9<DRaB;59<CT`024h/00=>:dh/DR/00U8[00=>:dh/CR`00Th/0Th[00=>2dh:CPX00TX[00A:;4X[
CR]:2`9:3004BP]>:dh[CPX1CP`0000;224880@0100800@0200Xi3fYDU1JT002FW02ETl00eI`FVmJ
K`03FVl2FVh5FVl5FW02GW03GY000ej?GY1NT003GY04GW001Ui_GW1NKei_GReN2PEN200AGPUN25h8
HRMR1eh7FPQIaD53@FEEafIWHTMR:687HRQR:@03HRX0268<HU5^dg/dOiEoLgLCM_@2LaD047<FL_EZ
dfJAITmVL6kBJ[5EkCD7<<91Z4X<EReJL5j@0Uja011N/UjBHW1VdEYa?H/PHQQ1788/`cU4@JDY1Q13
220@H08@H@03568HPQRS00<LY0047<DPaB2U8:D28:@01RBT8:@PY1bT56<<@P@88@<8800K344@HQR3
788eA6JWOjmoTG]`Ng5kM7nfOmMonWodMeE1Raa1788HPQA1320HPQRT7<@LaAcV008PiP047>LQ1R47
8@L29@L00bD69BHU9`03:BL01BDX9BLU1bDV9BL01RTX0RdX00T]:Be9;BTaBC5X<FTeJSF;>H/00SV<
00<i[3f[?J`00Sf[00A1c4G_BPm5k`95kP04BNi=kU7]DPh2DS000e8aDU5BD@02DU82EU804eIcFW9N
TejDG[ENU5YBHY=V]6KEJ_I_=gLgNeMgF7<hLcMgEgMi009kNP9kV`05Okao_GnmOkeogP02Oml017oN
OkekW7^L0Wnl00Eo_GnlNi]kNWMi009gF09c>003MeQcFG<i00=_>@04LcQcFG<hKcP2JaP01F/GJaIZ
mFKeI_H00f;f00YW5V;gG]IJ]EjeFYAJ]5ZDFYEFU09FL`09DU=B<dhcCU9FTDH_;>D@00@000880084
0088800I464DXR46<DHaA47WG/icUgNILgQRmUYcEO4mSSU<@Ha5[45Y=BLXa1bU468800Q148<00QB2
00`<80`07:<aAD68@HTeB2cU7<@DHQ1Q58<25882468258800aRS58<DP`0658<246<02122584@H1B1
5:<H`ac48>D2:BH01bD58><eADH;Ha9[=Flf00A[=@03KcA[56/E00U[5@E_5@9[5@04JaI[5F/EJaH6
JaD00f[cKa=_4`06Ka@3KaD00f/EKaE[5@02JaD00f[dJaA_4`04Ka<3Ka@00flEKaA_5008Ka@02F/d
KcA_56lDJaA_56leKcA_=@07Kc@01F/eJcI[=VlfJaH00VlE6flD00I[4flCKa=_4F[aJ_<2Ja<00f/B
Ka9_4P05Ja<<J_<2J_83J_<HJ_82I_85I_400f[AI_5VlP02I]800fKaI]9VdP04I]801FKCH]=RdV;B
H]400fKA0VK@0f;A00ARd6;AH[5R/@9R/003H[5R/6:`009R/0ER/@IN/@AN/0QN[`UNSPANKP9NSPAN
K`=JKP03FVeJKUY^00AJKP03EViFKEI^009FKP08FViJKEY]ETeFC5I]EVaFK@9FC@03FTeJC5Y;009J
C004FTeFCEI=ETd4ET/4ET`3ET/2DT/015I;DRaB;58/0e9;0dh/00A>Bdh[CRa>;09>:`=B:`9>:`=>
;003CR]>2dh:009>2P9>:`04BR]>:dh;CR/2CR`014h;CPY>2U890Dg/000010Q1224400000PP000L<
82ST?JQ>CeZ>FVmFD002FW000eI`FVmJK`02FVl00eY`FVmJKP04FVl8FW09GY000ei`GY1NT003GY00
15i`GVmNCEWX0eh800=N:5h8GPT00Uh801YR268WHRQN:EFV@@4hhDfWHPIR9f87HPIR:5hZGR]RBV99
HRaN<6kCMcAoMGmcMaAbmFke0f[D00eVTV9@HTmRCVZaJ[1F3C3V<<95Z4X=DRiFL002GY4045jaG[=R
/f:AI]=FLCU[968L@R1R<>8iA46U<BH@I0Q10Q1Q00DDHAB268<HPabS008LY08LY@0:7<DPa22U8:@T
Y22T9<DLY1AS324322400``Q2248800220002@PP440LPCf5K`aolWo`Ok1oT`02Ne<02gnfOoaomWMi
>F/H@Ab2688@@@`P68800ac500DLiR3V7>HLib4600<Q1`8U1`059BHU9bTW:BLU9`029BP39BL01BTW
:BPY:2TY:BP00RdX0be900@]:359=FTeRP8eJP04=H/iS3V<>H`3?J`2@Ld0247^ANi5kTG>@Le9cU7^
DPh2DRl0358`DU5BDU9ADU9B<DhaDS5FDUYcGYAJU09FL`0=EU9JLUjDH[EVeVlFL_AkEG=HLcMc=W<g
MeT00W]j00=gNWMkNi`00W^M00=gO7NMOol00goN00YogGnmOmeogGoNOkek_G]jMeUgF0Ac>004LcU_
>FliKcT2LcP016liLcQ_>6lh0V/h00I[5f[fI]EVeV;EH_D2H_H01f;gG]INeUZeG[EJU5ZE009FU0=F
L`0:DU=>=59cEY523bd6400800@020021000;Pa0488H`acT8>DY1C55=JM>SfLfMkYong_mKeUNUDV`
?Fe5[DF/@FTe9bcU7<DDHPP0344@PaBR568<80P07:8aACf8?FPeAbd58<@DHA11468DPQB3588DPaB2
0aB30a1R00<@PaB348<00a230Q22010@HAB16:<Ha1c47>DU9R468>DL`bdTAP]S4V]EKcI[5@=[=P9[
=@9[5@05JaI[=V/EJaEVm003JaD3KaD4JaD016/FJaE[5V/F0f/E0flE2FlD1f/E0VlE00U_56/CKaA_
=6lDKa=_56lEKcD00VlE1FlD00A_5FlDKaE_5@9_=0=_=@9_5003KcA_=Fld00=_=@=_=003JcE[=Vlf
009_=P03KaE_56lC00=_=@9_=0=_50=_=004Kc=_56lDKcD;Ka@016/CKa=_4flB1F/C0VlB00A[4f[c
Ja=[4`EZl`E[4`05Ja9Zlf[cJ_=ZlP03J_<00f[bJ_=ZlP0>J_8016KbJ_9ZlVKa0V[b0fKb1FKa1fKb
1FKB00ARdf;BH]9RdPERd@05I]1RdF;AH]5Rd003H]401V:`H[5R/F:aH]1R/@=R/0=R/@QN/@9N/0=N
[`9R[`03G[1N[ej_00ENSP06GXmNSUj>GXiNKUi]0Ui^00=NSUi^GVl00ei_0UY_00EJSeY]FViJKEY_
00EJKP03FVeFKEI^009FK`9FKP9FK@0:EVaFKEI=ETeJCEY<FT]JC5Y;FTd3ETd015I<ET]FBeI;0e9=
0UI<00AFBeI<ET]FB`ABC0=BB`03CTa>;4h/00A>;0M>:`9>;004CRe>;4h;CP/2CPX3CR/00dh:CP]>
:`02CR`2CP/1CPX1DPT1DN/000043448@@PQ100220002QAP;>=1bDi>FVaJCEY`FW5JL5I?1UY_00=J
KUY_FVl015Y_00=JL5Y_FW001UY`00=JKej@FVl02Ej@00ENKei^GTaJ2Eh800AN:00@GPQN:5hXGPUJ
268XGRYAYSS0;611@eW5HPMR9f87HRL2HRX07V8YITMR2Uh_J]9g<g]DOc9g4fZbGRiIkEX>GReN;UX=
GPeRCf9=J/mEk3D7;:4mJ4X_DTiFL5ZAG[9R/P9R/`0DI[=Ve5ZC?H`THR1R888`hSU4@JDa9QB4344@
HAAQ584DPQRS788LX`8LY0057:DLY1bT9<<PY0028:D0122T9<DLXaAR0``Q10PQ01P800PP320@@1b1
?HAVagoBOnmolgnfNiQkMWnfOoMoeV[E<@XH@Ab2668@@0`P68837<D37>H021cW8@HQ1R468@LU1bD6
9BH3:BL01bDW9BPU1b469BHU9bTW00<Y:08]:08aB003=FPeBCDW008a1`06=BPe9cDW>BLiB3U70SU8
00LmB3eY?FY1Rd6[AJ]1R`02?F/03dV;DLaAbe6[DL]EkEX^FRmF3EG<DJaE[5W=FNiJ3P03FPl02EX_
FS1J3eXaFU5NLVJCL[5fl002La<027<EMcMkNG^JNgYgNW=JLe/2Mid00g^nOmmoo`07Ool01GoNNkik
O7]IMeT00W<h0flh00=_>FlhKcP00Vlh0V/h00][>FlhKcQ_>6lgJaMZmV:eG[AReFKe009Rm@08H_IN
eUkFG[EJ]EZDEYEFU09FL`0;EW9FLE9CDSAFLeYaAPha1Q002000000220007Pa0484HXAS37><Pi2D3
:@@]ATH^F[=_EWofNmYkVf/iGWIASTV]AJa1RSDW;>DLY1R3200DHaB38<@DH@8<80097:8aA3f7>DHe
9RST9<@D@1AQ00DDPP03688DPQAR00H@HP<@H`<@HP03588DXQS4008La00:8>DPiR3V8<@PXRd2APYS
4F]DJcD9JaD00f/FJaE[5@05JaD016lEKaA_5FlE1F/E00Q_5F/EJaE[5FldJaA[5F/D16lD0flC0VlD
00=[5FlEKaD01FlE00=_=FldKa@01FlD0VlE16lD0V/D0VlD00E_5FlDJaA_=6le00=_=003KcE_=6ld
00A_=@9_=004Kc=_=6leJcD2KcD01VldKa=_4V[bJa=_50E_=0=_5004Ka=_56lDKaD4Ka@3Ka<5Ka@2
Ka<00flBJa=[4`03Ja<2Ka85Ja<4J_<016[bJ_=[4f/C0f/B00=[4f[cJ_8016[b0V/C0V[c4V[b0fKb
1FKa1VKb0VKA00=VdVKAI]801FKB00EVdF;AH]5VdF;A00=Vd004H]1RdF;AH]42H]000f:`H]5R/@07
H[000f:aG[5N/@06G[42G[02GZl3HZl5GZl3GXh00ej?GXiNSP03GXh4GVh015j?GXiNKUi_0eZ?00EJ
KEi]GVeJSUY_00=JKP04FVeJK5Y/EVh2ETh01EI=EVeJK5Y/EV`015I<00EFBeY:FTYJBUI;00AFC003
ET]BBe9;00=BC@03ETeFC5I;009FB`05DRaBC59<ET]BC003DT/7CR`7CR/2CR`014h]CRa>2dh;0Th:
0dh[00=>:Th;CR/00dh/00=>2dh:DPP00E7[00004PaQ3448@@@P200401AQ;<=5b59>GXeJCEY_EW1F
D5I`EVmFL0AJL003FVmJL5Y_00AJK`]JL0ENT0ENT@05HXmNKUi=GTaN:@02GPP2GRT2GRP02eh9FP]J
:ei:ENYAYcRP<80lh5W4GPL00V8X019R:F8ZHRYR:FI7GNMR;fkBNc=kE7lbK_AVTF8_GPeIk5X<GRd3
HTl02f9=JZaJ33eY<>@iJDX`DW1FL5ZAG[<016:c01AVe5ZB@H/XPQa1864`hSU5@JHa9QRU220<@11Q
564DPQRS788P`ac41R2T00TPYB358<DPaAR3568@@@PP32000P`Q0PPQ01D800`P444HPAb1=B=JBW=A
OoAomgokOoMoegoCOeAg5Dg=96DD@Ab268<00P`P00DHPQc57<DLaAc6008LiP097>LQ1b468>HQ1R47
8@HU1RDV008Y9`039BLU:2DX00<U9`04:BLY:2TW:BL2;BP0334Y>DTmJ3U7=>D`iCT7>BPi1cCV>>Di
1P8hi@04>@I1B4UYCHT3BFT034eYBDU=JE6/ENiEcE6[CFQ=JEW<FNeIc09MZ`03HLaV3FH_009V;`0?
JU1^L6i`LY5fTG[CO_Eo5G[bNaEoEGmFOeMo^gnm00AogPmoo`03Nkig6WLh009c>005KcQ_>F/hJcU_
>@03LcP01F/hJaMVmfLHJcP00Vlh00M_=f/GJ_IVeFKFI]EVm@03H]H01EkEF[IJ]EZeEYD015JD03IF
TeIcEU=B=59CFW163S4740040000100<81AP5:8L`aS37<<Q1BTU;DHeRDH>FY5Vm7MgNkQkVGnmKaUJ
45G?ALe1Rc4X:>HLYAB3444@HAB37:<DHA10320LXS4T>HLiASDV;@DXa1R2568458<02AB26:8DPQR1
444<@@aR468<HP0446801Q22468@HQB15:8Ha08Li0088>DQ1BD47:<PXBd2APYNl@9[=@U[5@03JaI[
5F/E00E[5@E_5@03KaA[5FlE00E[5@9[=@03JaE_5FlD00=_5003Ka=_56lD009_5009KaE_56lDKaA[
5FleKaA_=F/e009_=@9_=0E_5003KcE[56/E00E_50=[5@06Ka=_=6ldKcAc=6le0Vld16le0Vld00=_
<fldKc@016le00I_56lCJa=[56lDKaD3KcD01FlEKcE_=6ldKc<016lD00=[56lDKa@01FlD00=[56lD
Ka@026/C00A_4VlCJa=_4`A[4`AZl`=ZlP03J_=[4V/C009Zl`=ZlP05J_=[4f/CJa=Zl`0=J_83I_82
J_83I_8016KBI_9VlVKa0VKb0fKc0VKb00=VdFKBI]800fKc16KB00=RdFKBH]400f;A00=VdF;AI]00
0V;@00ARdF:aH[5Rd09R/@9R/004G[1R/6:`H[03H[400ejaG[9N/P07G[42G[08GZl01Uj^GXiNSUj_
GY1JS`9NS`9NSP08GVeNSUj>GXmNSUi^GXiJK`9JS`04GXmNKUi]FVl7FVh01EI^ETeFCEY]EVh00eI]
00=FCEI<DT`00UI<00AJC5Y;ET]FB`AFC003ET]FC59=00=BC@9BC0AFB`04DT]BC58/DR`2DT`2CT`;
CR`0158/CRa>;4h]0Th/00=>:dh;CP/00ThZ00=>:dhZCRX00dh[0TX<00=>2dh:DPP00E7[00003`aQ
344<8@PP200400`P8:91YU9?FVeJCEY^FTiFC`03EW02FW000eY_FW1JK`03FVl3GVl00eY_FW1JL004
FW09GY02GY402V:AHY1RT6:@GVmNCEh[GRQN25hX0UhY00aN:68WGPUN2eh:GRUEjU6X>>8dPCd2FL@2
HRL04V8XHRUR:V8[HTYV9UgWHTi^lWmCOgAo<W;cK]=ZTFI`IW5VL09VT00>IVmRKf9]IVYJ:d69<>Di
JdiBEW5FDEjAGY9R/P9R/`05I[9VdUjA@JXTPP0264403bc3=B=1YCE57:@800`P340@HAB268<LPR33
7<@LY0028<@28:@02Qc48<DTaBCU8<DHPaAR344800`P0`PP0PP001`<811Q684LPRc2BLYRK7=FOm=o
mWo^Ohic4FZaGNhi:A`S548LXQR3444<81R26:@La1c57<HLiP8PiP058@HTiR3V8>HQ1`029@H012DV
:BLY9bTW0RU800<U9bTW:BL012TW01/]1bcV;:Di1TEXDHYERDU8BBQ=B4dWEDMMIf67HFMMJ5f9HLYV
36X_IRiR3fH_JW5ZLVYcJY@00VIc00AZLVZCJ[=^/`9^T`0<LY9jTGj@OZmn/7kAO]9o57mGOiYo_7oM
7Goo00=oggLJMcL00W<h00=c>FliJcT00V/i00U_>7<hLcM[>6/GI_IVmf/HKcP00Vlg0V/F00EZmFKF
I]ERe5kE009N]@=J]@03E[EJ]EJD009FU00YEY=FU5IcEU=BE59AGY1:3SU942040000200<81B05:0L
`ARR7<<Q1Be6=HQ1jdX^F[9Vm6mhMiUkVW^lOiYVeEXbBLe1Rc4X9:HHQ112464@@0025640311Q4408
01B0:@@iISU6=DLaARST7:<HPP@DP`06588HXQR1684@@0a10`aR0a1R01D@HA21488@HQ1Q584HXQc3
7><U1BDU9@<LXBBQ<@962Uk@JcA[=F/EKaD03V/E2VlE0flD1F/E00=_56/EKa@016lD00A_5FlDKaA_
509_=003KaA_=6ld00=_=@=_=0M_5003JaA[5FlE009_5007KaE[5F/EKcE_4flDKc<00flD0Vld16le
00=_=6lDKc<00Vld00=_=FldKc@00Vld16lD00=_5FleKcD00VlE0Vle00=_=6lcKa<02VlD0Vld0VlD
0V/D1V/C00=[4V/CJa<016/C00U[56[cJ_=Zlf/CJ_9VdF[bJ_<016[b0V/B00A[4f[cJa=[4`9Zl`9Z
lP03J_5ZlV[b00eZlP=Vd@9Zl`04J_9ZlF[bJ_84I_<2I_82I]82I_<3I]85I]402F;AI]5VdFKAH]5V
d6;AH]1R/@02H[03H]02H[08H[4015jbG[5N/Ej`0eja00=R/EjaH[0015j_00=N[Uj_GZl01Uj_0Uj@
0Uj?00=NKUj>GXd00Uj>00ANSej>GViNS@9NSP03FXmNKei^009JKP03FVeJKUY]00AJKP04EViJKEY]
FVd5EVh2ET`015I;ETaFC5I;0UI<00IFBeI/ET]FBeI<ER`2ET`00eI;DTaFB`06ET/00eH[DR]B;003
DR`00dh/DR]>;004CR`3DR/7CR`00dh[CRY>:P04CRX2CPX5CR/00dh;CPYB2001DN/0008<@088800;
200400P08:8mQdi?EViJCeY^FTiFC`03EW000eY`FVmJK`05FW02GW02GVl7FW08GY000ejAGW5RT@02
HY4016:@HY5NCUh[0Uh900EN:5hYGRQN:F8800=N2@0[GPQIjEG9AFHi14V6HNER9f8XHRYR:F8ZHR]R
C6I:HPYRCVkcNeEoUGmCM_5^lfkBJ[9Z/FkBJ[9VLF9`HVmRSVJ;GRa1RRRS<BU:<E8_EU5JTEjBG[80
0V:c01EVTF[AH[51ZbBS768H@BBR<>91Q3DU68<<00`P464DHAB268<LXR348<D00Qc500<La1bT7<@0
123500PLY1R3468<80P0320880`P0`PP01d<80a0560HPRRQ?DEEjFJ_Ja9kUgnAL_5RKEi_FL`hiRR3
668LXaR2564<81R26:<La1c58>DQ1R3V008TiP059@HU1b478@LQ9`039BH2:BL00bTX9BLY9`03:BL0
5bTX9BLUBBd798<da5EWJLM^:Vh[KP]]jfg/KPab378=LTifKgZ@OY1n/7jaN[400WkA0Wka00=o4WlC
O_@00Wkc00inlWlcOcEoE7mEOaAnm7mFOiUoV7nJOk]ogGon8Woo00Ak>GLgMcUc>0Ec>@=c>008KcQ_
=f/GJcQ_>GLgLaI_=`9[5`06J_IVeV;EH]AN]5je0UZe00=F]EZeE[D00eJe0eJD02EFLe9CDU=FLUjA
CS0i:10Q100000`P460HX1S26:4HXQc38@DYACF8?L]BTEkDJcMcNG>ILgYk^goKOi]NM4g^?H`]2AbU
56<@@@02344041AQ588@PPPP100DPRT6>FLiJ3EX<BHXa1b368<HPQR30aB300HDXQRR6:4@H@a13686
46805A2248<@PQ1Q584HXQRS7<<U9BE69>@LPB20=B95jEj^JcE[=V/FKaE_5002KaD2KcD00f/eJaE_
5@03KaD01VleJaE[=FleKcI_5@=_5PA_5@=_50A_5@9[5@06JcE_=6leKcE_5FlD0flE16lD00=_=6le
KcD00Vld00=_=FldJa@01FlD0Vle0Vlf00=_=FlDKaD00VlE00=[5F/eKcD00Vld00A_=FldKaA_=0M_
=@07Kc=_=6ldKcE_=6leKc@01fle0VlE0fle00A_=6lcKa=_4`=_500;Ka=_56lCKa=_56ldKaA[=6ld
KcE_5@03Ka@9Ja<00f/DJa=[4`03J_<3Ja<00f[bJ_=Zl`03J_83Ja82J_<00f/DJa=Zl`02J_800f[a
J_9[4P06J_800f[cJ_9VlP04J_8016[cJ_9ZlV[c0V[b00=ZlF[bJ_801FKc0fKb00=VlfKBI]8016KB
00=VdFKBI]400VKA00=RdV;AH]400V;A00AR/F:`H[1R/@=Rd09R/0]R/@03H[1N/F:`00=N/@9R/004
G[1N[ej_GZh8GZl2FY001Uj@FXmNSUj>GXeNSP=NS`05GXiNSEj>GXiNK`04FVh01EY]FViJKEY^FVd0
1UY^1EI^0UI<00AJK5I]EVeFK@9FC09FK09FB`AFC003ET]FC5I;00MFB`04ER]B;58/CR`2DR`3DR/3
DR`00e8[DT]B:`02CR`2CRd4CR`3CR/3CRX2CPX5CR/00dh;CPYB2@01DN/0000=240880PP220800@0
200LPcf7CTmJKeY`FVh00UY>00AJKeY`FW1JL0IJK`9JL004GW5NL5i_GW09FW05GY02GY400f:AHY1R
T002HY0015i>GPYN2Eh915h80f8800UN25hWHRUMj5W8DHMIafHUHRL01F8Y00YRC68/HP]RCV[AMcEo
EGlbM_5bl@9^d@0WJ[1Z[F9>GRmN;Uh]GT]RJUi;@HTXPc47APmB;UIAGY5N/F:aG[9RTV9_I[1R/46[
:>DLHQaQ9:8`hT63=BDHP`P0420@HAAR588HXabR008Pa0048<DLaAc57:D27:@02B347:@LY1bU68<D
HQ11200<8005220220006Q10668/X456FNQNBV:^G[1NKUi=HVmND68_@DTXXQR27:<HPa11320HPARS
7<@LaBCU8>D39>H01BD69@LQ1bD78BL01BD60RD700<U1RDV9BL00RTX00dYB2U9;@H/XTE8KPQjbg[?
N]5f/GkAO]9n/003O[401Wk@O_1nkWk_Oa1o4@9o<003Oa1o<Wme009oV004OgQoMgmgOiL2OkX2Ok/0
17oLOoeoogoo0Won97oo00AfmW;dMcQg>@=cF@04MeQc>7<hLcP3LcL03VlgKcQ_F7MFKaI[=f/GJaIV
mFKEH]ER]EjeG[@2F[@3F[D4E[D00eJDEWAFL`02DU<01EIbH[5><3DX42400P0002h<@11P7<4H`QRQ
584DXQcU:B<]93F9BRiJ/f/gKeQcF7=INk]onWnlI]MAl46<;@XPYQAS448<@Pa1564HXQB132088123
:BPeRCV9=FL]1BC4688LPQB1688DX`8DP`045:<HXaRR564546800`aQ464<HP034680411Q564DPQRS
7<<Y923U6:<DH1b0=B55j5j]JaA_=f/F0flD0VlE00A_=F/eJaE[5@=_5@9[5@04JcE[5F/EKaD3KaH0
16lEKcE_=FlE16lD0VlE00I[5F/DJaA_=FldKcD4KaD6Ka@00fldKcE_=@02Kc@00fleKcA[5002Ka@0
1FlCKcA_=6leKaD00fle00=_56lEKa@00VlE00=[5FlEKcD00fld00=_4flDKcD01Vle00=_<fldKc@0
16ld36le00E_=6lCKa=_4VlC009Zl`03Ka=_56lC00A_50=[50E_50M[4`9[50Y[4`04Ka=[4flCJa<2
J_8016[aJ_9Zlf/D0V/C0f[a0V/B00=ZlV[aJ_800f[b00=Zlf[bI_800VKb00EZlV[cJ_9Zlf[b009Z
l`=ZlP03J_5VlVKb00AVlP9Vd@EVdP03I]5VdVKA00QVd@03H]5R/F:a009R/0ARd0=R/0UR/@9R/09R
[`05H[1NT6:`H[1N/006GZl00ej^GZmN[`02GZl2FY000ej@GXmNSP03GXh3GXl00ej>GXaNK@03GVd2
FVh01EY]FVaJK5Y/FVh00UY]00=JKUY]FV`00UY/00UJKEI]EViFKUI]FVaJKEY/EVd00eI/0UI[0UI;
00=FC5I=ET`00UI<2eI;00EB;59<DTaBC58/00AB:`9B;0=B:`9>:`E>;004BPa>:dh[CR/3CRX2CPX0
1Dh[CPY>2dh[BP/00Th:0E890Dg/00001@Q022088@`P34000PP000@HHSE6BRiFC`9JL006FTiJKeY_
FW1FL5Y`0UY_0UY`00EJKeY`FW5JL5ZA00=NL0QJL0ANT0=NT@08GY9NTF:AHY1RSei_HTeN2P9N2@03
GPQN2Eh8009N2@03HRYR:F8Y009R:@07GPMMj5gXGPQR9V8WHPP00V8Y015V:6HYHRaR;5gZGP]VSfkc
McEg4WKaM_1blVkBJ]5ZSeh<009Ij`0DHTiRCFJ<GTa1RRbR=BM:3eI@EW5NTUjbH[5N/V:bHY1VdEjb
?L/Ti@8HHP069:<e8dFU>FDLX`P00P`P00<DHAB26:<00QbS0QbT1AbU11bT00DHXaAR344800`P00@8
800:100800P0440HHBc1AHM^R69ZIXh2GVh03f:>IXiZdfZAAFX/XaR27:<HPaAQ320HPARS7<DLiP02
8>D00b3V9>HTiP029@L38@L00b4W9BLU9`059@L00bDV9BLU:0029BP042DY<@Lh`eF7MXajcWk?O]5n
lGl@O_5nlWkBO_9nlgkb0Wka00Yo<gk`O_1nl7k?O^io=7mgOiUoV09oN@04OgQoVGnkOk/2Ok`017oM
OoiooWon9Woo00AfeG;dLcQc>0=cF@9cF09c>003LcMc>6lh009_>@0ALeUc=flgJcQW66KgI]IVeF;E
G]EN]EjdF[AJU5ZdF]EJ]@03E[D2EY@2EW@2EW<01EIbGY5><CDY54800P0000<881207<400QRQ01H@
@1B27>@Y0bCS:BHmkEIaH_E[=f/iLeYkVWolOmeRee7@?F`]2RC768@DP`8<@P0<568HXQB244488@PR
9@LaJCF8=FL]9RC511R20aB300DDXaBT588DPQ2200@@HP06364@HPaR468<HQ1R0a1Q010HXabT;BDP
iARS440PP3DPBPMVkf/DKcM[5VlEKcA_=@9_5@09JaE[5V/FJaI[5FleJaE_=F/E00=[=@09JaE_5VlF
KaI_=F/fKcE_=Vle00=_5@08KcE_=VleKcE_=6leKcA[5@A_5@04KaA_5FlEKcD2Kc@2Ka@00fldKcE_
=@03KcD3Kc@6KcD2Kc@00flDJaA_5002KaD2KcD00g<dKcA_=009KcD5Kc@?KcD2Kc@;Ka@016/DKcA[
=6ld1FlD00A_4f/CJa=[509[4`9[50][4`03JaA_56/C00=ZlP9Zl`04JaA[4f/CKa@2J_800f/BJ_9Z
lP07J_83I_84I_<01FKbI_=Zm6[dJ_<00f[b16Kb1FKA0fKB00=VdFKBI]4026KA00=RdF:aH]400VK@
16;@0V:`00ER/F:bH[9N/V:b00ER/@04H[1N/6:`H[02H]42G[03GZl3G[03GZl00ej`GZmN[`03FY00
1UZ?FXiJSUj>FXiNSP=NS`05GXiJKEi]FViNKP03FVh3FVd00eY^FVeJK@02FVd3FV`01eY]EVeFKUI^
EVeJK5I]009FKP9FK@9FK09FJ`04ET]FC5I<ET`5DT`01eI<DTaBC5I<ETeFBeI<009FB`04DT]BC59<
DT`4DR/3DR`2DR/2CR/6CR`2BR`00dh/CR]>:`02BP/2CR/2CP/2CR/2CP/1CPX1CP`0008<@00@2248
8110220801A1=BA:3EY^FY1JD5Y>FViJKeY`EW05FW000eY_FW1JL002FW03GW05FW07GY003ejAGW5N
TUjBGY5RTF:@HXmRKf9<GRYN2Eh8GPMN2@03GPX00eh9GPQN2002GPP02F8WHPMN1V87HRMR1f88HRQR
:@02IRP01f8ZHPYMjEh:IVe^dW<D009g4P0[Na5^lVkcK]=V/FI_HRiN;F9?IXmZ[V9^AHX/PSDWBPiF
CeY`GY5N/V:aH[9R/FJ?J]5N/D7;:<@HHQQ198<i8dFU?HLT`a103208011Q588HPQR37:<011bT0QbU
0abT00LLYAbT7:<DHP`P200<80042203200061AP684XXDF7JZQ^cfJ`I[5V/6J^J^ic<fZ?AHT/Xab2
7:<HXaAQ320HPARS7<DLiP<PiP039>HU1RD700DU1`079BPU1bD89@PQ22DX9@L00RDW0RD700dY1bTX
<>Dh`V6TMVUjd7Z^O/mnd7k?N[1j/@02O[02O]000gkbO_5nl@02O_02O_401Gl@Oa9o=7mFOgL00Wmh
0WnI00=oVWnkOk`00WoM00=ogWonOol09Woo00AfmW;eLaQc>0=cF@07MeUcF7<hLcQc=flhKcT00V/i
00I[>6lhLcQ_>6/HI_L2I_H2H]H3G]D015kDG[AN]5Zd0UZe15JD02EFM5IcEU=BDEIaBQ4a2AA21000
00`P460HXARR6:4DH1RS7>@U12CS9@E1kUJAH_E[=flhLcUgNGolOoiRedf^>F`]2BC67:DHQ0024480
31AR588DPQAR324@I2CW=FPeIcV7<BHTa@<HPP05588DPaB2588DP`0358800a22468@HP034680111Q
344<@@a20Pa10Q1Q00/DPaRT8>HQ1ac5464PP3D0BPEZkFle009_=P03KaE_=6lD00=_5@=_=P=_5@A_
=@03JcE_5FlE009_5@03KcE[=Vlf009_=PU_=@=_=0a_50E_=0=_<`=_=@=_=09_<`05Ka=[56/DKaA_
5@03Kc@;KcD00fldKcE_=@09KcD:Kc@00fleKcA_<`04Kc@2Ka@3Ka<00fldJaA_5003Ka@2Ka<016lB
Ka=_4f/D0V/C00E_4f/CJa=[4f/B00Q[4`9Zl`9ZlPAZl`04Ja=Zlf[cJ_<DJ_801fKcI]AZm6[cI_=Z
lf[b00AVl@eVd@03I]1VdFKA00=Vd@=Rd@9Vd0ARd09R/0=R/@=R/P06H[5R/6:`H[1R[ej`0V:`0Uja
0Uj`00=R[f:`G[0015j`00=NT5j_G[000Uj_00ANT5Z@GY1NS`INSP9NS`03GVmJKUY^00EJK`AJKP9J
K@MJK0=JK@04FVaFKEI^EVh2EVd015Y/EVaFK5I[15I;00=FC59=DTh0159=00ABCU9=DTiFC@AFB`04
DT]FBeI;ET/4DR/014h/DRaB:e8Z0U8[00=>:dh/CR`024h/0TX<0dh[1Th;0Dh=00003@a0220480PP
340880@0444e94W[FViFTEI@009JC`=FL0YJL0=NL0IJL0QNT09NT@07GY9RTF:AIY1RL69=GR/00Uh9
00=N25h:GPX00Uh:00aN2Eh8GPUN2F88HRIR9egVFLMMb5gWHPL2HRT2IRP09F8YIRUR268:IVe^lWLD
Nc=g4g;cK_A^dfkeK_AV/FI_HTmRD6:@J/mVSdF;;:8a1dG^DRiJKej@G[9R/F:bH[5RSfK@FXi1bRRS
008H@P06888e0d6V@JL/i1AQ0P`P00LDHAAR58<HPabS7:@La0027<D00ac47:DLY0047:@00aRS5688
8@02320040PP320880P0220<811P680HPBB1AJQV[6lCJ_=VdfJc0VZa00e_5FZAAHXXXab28:8LXaAQ
320DPARS7<DLiP028>H39>H89@L01BD88@LQ22488BP00bDW00`Y1bT6;BP`a3cSGHEfJWJ^NXij[gZa
N[03N[400gj`O]5nd003O_401Wk`O_5nlGlBOa1o4P9o=003OeIoMgmh009oV@06OiYo_7nmOmeogWon
:7oo00Ak>7;fMeYgF@9cFP03LcYcFG=H00=c>003KcU[>6/i009[600:KaQ[66/HI_MRefKgI_IRmV;F
G]H4G]D4F[D015ZdFYAJU5JD0UId00IBDe9BEW56<Bd942821000<0P0560HXAc37<8LXaRS7>@Ti2CS
=HU:CV;eKeUkVG=HMg]kVWolOmiRUTf]?F`a:RS67:DDPa1R448DPaRS58<DHPa156<XiSEX>FPmZ2dV
9<DHPQB1588DPaBS5:8DPP@@P`8@HP04464@HQ1R468234400a11348@@@0346403aB26:@LaB486:D<
@220<@1:1VK]KcA_=FlFKaE_=@02KaD2KaH00f/FKcI_=P03KaD01FlfKcE[5F/EJcD016lE00=_=F/f
JcH01F/f0V/e1Vle00A_=6leKaE_=@A_5@03KaA[5FlD009_50=_=@=_=003KcE_=6le00A_=@=_=0=_
=@03KaE_=Fld009_=@03KcA_=Fle00Q_=@=_=0E_=@=_=006KcE_=6ldKcAc=7Ld16ld0Vle00=_=6lc
Kc@00Vld0flD00E_4flcJcA[56/E009_5@05KaA_4flCKa=_4P02Ka<016/DJa=[4flC0f/C00A[4V/C
Ja=[50I[4`9Zl`03J_9Zlf[b00MZla5ZlP06J_=ZlVKcI]9Vlf[c0VKc00=ZlVKaI_400VKa2FKA00=V
dVKAI]401fKA1F;A1F;@16:a0f:b00ER/F:`H[1R/5j`009R/09N/@05G[1N/Ej`HZmR/008G[001Ej^
GXmNT5Z@GY001ej>0Uj?00=NKeY_FVl015Y_00UJL5Y^FVmJKUi^FVeJKUY/FVd01EY/0UY]00=JK5Y[
EVd00UI^0UI]00AJK5I]ETaFC0AFB`03ETaBCE9=00=BC@03DTaBCE9=009BCP03DTaFBeI<009FC003
ET]BBe8[00AB:`9>;004DR]BBTi;CR/=CR`3CR/2CR`3BP`1BP/1BPd0000?240880PQ220<@0PP100@
@343ALYJKEjaEU5JD5Y?00=FL0aJL003GW1JL5Y`009JL0UNT003GXmNT5j@00=NT@04HVmNKf9=GR/2
GPT00eh8GPUN2@02GPX2GPP035h9HPQR1f86GNMIaDe4CFMIb687HRUV:@9V:00cHRUV9f87HPUVK6kA
McAk<g<CK_A^dfZbIY5VKf9_HVeN;Ei@HVm^cfJ>BL//`bcV@NiB;EY>GY1RdV:aH[9R/FJ?I/mNSDG:
::<L@QaR:88dhTW7@JL/ha10320@@AAQ568DHaR3008LY08La0038<@La1bT00@LY0087:<HXaAR348<
8@`P220<80<8800J320@H1R0584TXT68IZi[5FKCI[=V]6JcJ]A^mFZcBH/XXaQQ8:8LXQA1320DPARS
7>DLiP<PiP8TiP0:8@HU1bD79@HU1bT69@LU1RD78@L28@P00b4X9BLU9`02:BL2:@L01C35?>=MQG99
NZl00WZ>0gZ@00=j/7jaOZl00Wk@1Gka00Ao4Wl@O`io409o<@07Oc9oEGmfOgQoVGnKOk`00Wnm00=o
gGonOol09goo00MoFGLhMeYgFGLiLcU_>@02LcT3LcP2KcP02F/hJaQ[66/GJ_MVeV:eH]IVm`02I_H0
0f;FG]ENe@03G]D01UjeF[EJ]EZeF[AJU09FU00fEY=FM5IdFYAJTdYB<DX@8P@0000<011P7:4Phb33
7:8HXQRS8<@Y0d7[E[5[F7NkOmYkVWNLOmeoo7^LGWE=[D6<<BXXaART68<@HQAR58<LXaB3448<811R
8>DaAcEW>HL]9bC578<HPQRS0QBS00<DXQ1R46800a1R1AB200DDPa1R464@HA1R008@H@0A564@HAAR
58<HY1BU58@@HBBP<@19iVK;Kc9[4flEKaI_5@04KaH00f/FKcE_=@02KaD00fleKcI_=@02JaD00f/e
KaE_5@02KaD00flDJaE_=@02KcH2JcH016/eJcA[56/d0Vle00A[=6leKcE_=09_50E_5@05KaA[5FlD
KaA_=003KcD3Kc@00fleKcA_=@04KcD6Kc@>KcD9Kc@00flDKcA_=003Kc@026leKcA_=6lcKcA_4flD
Kc@2KcD01FldKc=_<flcKc@00flD00A_=6lcJcA_=09_=@03KaE_56lD009_4`=_4P04Ka=[4f/CKa<3
Ja<3Ja8016/CKa=_4flC0V/B0V/C0f[c00=ZlV/BJa8016/C00=Zlf/BJ_800f[a3F[b00=ZlF[bJ_80
1F[b1FKa00=VdFKaI_8016KA00=VdVKAI]400fKA0fK@16;A0V;@00=RdF;@H]000V;A0f;@0f;A0f:a
0f:`00AN/6:`HZmR/0=N/@06G[1R[ej_HZiNSej@0Uj`0Uj_00EN[Uj>GXmNSej@00UNSP9NK`IJK`03
FViJKEY^009NK@03FVeJKUY/00QJK003FT]JJeI]009FK@=FK003EVeFC5I<00EFB`04ETaBC59<DTd4
DT`3DTd2DT`0159;ET]FBeH[1E8[0Th/0U8[00=>:dh/CR`024h/00A>:dh;CP]:2`=>:`9>;09>305:
305>2`5>3@0000l8@0PP224880Q0224801A1<@=5bUj=F[9FDEY@ETl01EI`1EY`0UYa25Y`15j@00=J
TEj@GY000ej@0ejA0UjB00ANT5i`GTeN:`9N2@03GPQN2Eh900=N2P0=GPUN2V88GPQN1eWWEHA98TU6
ELUN268ZHRT00VHY00aR:FHXHNIR2VI=K]5c=GLdKaA^e6ZbHW02FRd07eh^GTeN;EX^GVi^d6ZaDL`/
a2SV@NiB;UY=H[1N/F:aH]=R/VJ`K_5R[dh<<>DH@QQ1::8e0TgW@HH/`a10008<@@04564DHQAS68<2
7:@011c47<DLaAc51QbT00DHPa1S348880PQ00<8800;320800P0320DH1B28:8mR6:>JaEVd`02I[<2
J[<02fkeK[99ZbRT564T`R2S544<01AQ6:@00RD600DPiR3W8>LPibCW00<Pi`039@HU1bTX00<U1`<Q
1`<U9`<Y9`0C;@L`a3bRFFIb:gZ_NZijKWJ?NXmjT7Z`O[5n[gk@O_5nlWkaO_800WlB0Wka00]o3gka
O_1nl7lAOcEoEWmhOgUo^gnl009o_@03OmeooWoo02Moo`04NeUg>7MJMcT2LcT2KcT01W=ILeQcF7<i
KcU_>0=[60EZm`9W5`03I_MReUjf009N]@03G]ENeUkE00=J]@03F[AJU5JD009FT`9FU00cF[AJddic
=F/D@P@0000<01106:8Q1B3S8<<LXQAQ6:8ThcW:E[=W67>KOkUkVW^LOomo_7=KES=9[Sf<<BPXaAbU
6:@DHQ1R58<HPQB3348881118>DeAcEW=FP]:2C67:@LXaRS008DX`035:8DPQ1R00<<@@08568DPQRS
6<@H`aBS588@HPL@H@8DPP8DP`07564PXC4PANIVbflbKcD00V/F1FlF00A[5V/EJaE_=@9_5@03KcI_
=F/f009[=P03KcE_5FlE009_5@03JaE_=F/f00A[=@03JaA[=F/e00E[=@03KcE[5FlE009_5@03KaI_
5FlE00=[5@04KaE_=6leKaD3KcD00fldKcE_=@02JcD00f/EKcE_=P02KcD016lEKcE_=F/e2Fle00=_
=6leKcD01Vle00=_=6leKcD02Vle0fld00=_56ldKcD00fld0flc00M_=6lDKaA_56ldKc=[=002Kc@2
KcD2Kc@2Ka@3Ka<00f/CKa=[4`02Ja<00f/DJa=[4P02Ja8016/CKaA[56lD1f/C0f/B16/C00=[56/C
Ja<00V/C00=Zlf[bJ_800V[b0f[c16[b00=ZlF[bJ_4016[b0VKb16Ka16Kb00=VlfKBI]800fKB0VKA
00AVdVKAI]5Vd@9Vd0QRd@9Rd09Rd@9Rd0=Rd@03H[5R/6:`00=R/09N/@04H[1N/EjaG[43G[0016:`
HZiNSej_0ej`00=N[ej>GXh00ej?1Ej>0Uj?00AJSUj>GXmNK`=JK`04GVmJKeY_FVh4FVd2FVh4FVd0
0eY/FVeJK003FV`00eY[EVeFK@05EVd7ET`00eI^DTaBC006DT`2DTd3DT`00e9;ER]B:`03DR/00e8/
DR]>;002CR`00dh[CRa>;005CR`00dX/BRe>;002CR`2CP/00dh/CR]>;002CR`2BPd00dh<BPa>2`01
CPd0000334088@PQ0088800:12040111;@=5bEi[FY1FDEY@FVl7FW02FVl01EY`FW5JLEY`GY000UY_
0eY`1Uj@1ejA00UNTUjAHY5NTEj@HViN:eh9FNP00eh800=N2Eh:GPT00Uh900UR25h8GPMR:5FTAB59
IeW:HRT00V8Z0V8Y0VHW00eR268:ITa^/GLeNc9blfkCK[9Z/69>GTmRL002HTh08Uh^GTiZ/6ZbEL``
iBcU@NeB3EY=GXiNT6:aH]=V/fJaK_5V[U8<=@DP@AQ0;:8i8TgVAJHa0QR2444@@QAQ444DHQR30QbT
00@PiQcV8<DLa0@LY0057:<HY1B346<<@@0522002``P200800`P580HPR22@HQR[F/EI]@00VJc0VZb
00m^mFjbBJ//aAaR9:8LXaAQ300@@1RT9@HPiRCV8>H00R3W00DTib3W8>LPibCV00@U1P069@LU1RD7
9BHU9bTW0RTV00hY1bT6:BL/Y3B1CDM^2gJ>NXifKGI^NVijSgj^0Wj_0gkb17lB00=o4Gk`O_000Wk`
0Wka00Yo4WlCOcEoNGnKOk]o_GoMOmiooRQoo`04NeQg>7LiMcT2LcP016liLcUcFGMI0W=I00=c>Flh
JcP01F/H00E[>6lhJaM[5fKf009ReP05G[EN]UkEG]INe@04F[D3EY@025JCEW=FLUJBG]9:DCEZ66@2
000220001A1Q7>@U123T7:<00QB100DT`RdUBPiJ]F/i009kVP0KOmak_GMkGYE=/4F^@H/a:2S57:DH
Xa1R348DHQRS56<@H`PQ320PiCEW=FPiRBe9:>LLY1R2008HX`0>5:8HXaB1464<@0PP340DHAB26<<H
XaS46:@DPP<@H@04344<@110440246402QB1688DPAR18:0e8DGXHZUc<W=g1Flf0VlF00E_=VleKcE_
=6le00=_5@04KcE_=VlfKcH3KcD00flEJaE[5@05JaD00f/DJaE[5@03JaD2KcD3KaD4KaH00flEKcA[
=@02KcD00fldKaE_5@08KcD3KcH01FleKaE_5FlEKcD00Vlf0fle00=_=6leKc@03Vle0Vld00A_=FlD
JaA_5@A_=@=_=09_=@9_=003Kc=_=6lc00Y_<`03KaA_=6ld009_=0I_509_4`04Ka9_4flDJa<4Ja87
Ja<01F[cJa=[4f/BJ_800V/B0f/C0VlD0f[c0V[b00=ZlF[bJ_800f[c0V[b00IZlF[bJ_5ZlF[`J_43
J_85I_400f[aJ_9ZlP09I]85I]42I]02I]401F;AH]9RdF;@H]400f;@0V;A1V;@1F:`00=R/EjaG[40
0eja0Uj`0V:`00=R[f:^GZl015j_00=N[Uj>GXh01ej>00=NSej>GXh00ej?0ei_00ANSUY^FViJKP=J
K@AJKP=JK@04FVaJC5Y/FVd3FV`00eI]ETaFK@04EVd00eI/EVeFC005ETd00eI<DTaFB`06ET/5DT/0
25H[DR]B:e8/DR]B;59;DT`2CR`3DR/3CR`00dh[CRa>:`07CR`014h[CRa>;4h]0dh/0Dh<0Dh;0Dh=
00022443224200001a0P;>=1b5i/FXmFDEY@009JK`MJL09JK`9JL@=JL003FVmJL5Y`00INT09NT@03
GY9NTEjA00=NT@09G[9RTF:AGY5NT69^GR]IjEh:009N2@03GPQN2Uh900=R20=N2006GRUIY4D1CFME
jV8Y0V8Z01=R:f8ZHRUV9VHZHPYVCFZaMcAk<W;cK_=^dVjbJ[5Z/VkCJ[5VK`02HTh086J?IY5AbcC3
:<A1kDh=ETeNKejAH[5R/VJcI[5Zd6J>DN`a1B1R740XPCTRCLE9acDS7:<@@A1R564D@AAR68<27:@0
0bCV8>HLa@037:@01bC48:@Pa1RT58<@H`a200D88@<8800:320@@1AP784mQej<IaAVeFKDI[82J[80
36kdK]9=[336768PXabS668<81106<@Q1P8PiP8Pi`068>PPib3W8>HPib3V0R460bD701XU1BD69BHU
9RT6:@DY1RT7:@HY9c35>:95:6WZLTabSW9]MVefKgZ?NZin/7k?Oa=nlWlB0Wka0WlB00Eo4GkaO_1n
lGk`009nl@05Oa9o4gleOgQoVP02Ok`017nmOmeogWon9goo00AoNWLhMeUg>@9c>00:KcUc>G<iLcUc
FW=ILgUc>6liJcT2JaT3JcT00f/hJaQ[5`02I_L00f;gH_INeP02G]H00eZeF[IJ]@02F[D02eJeF[EF
U5JCDW=BDU9AFY5:DCE:68@00P0000@800PP340@PP8Li00E7<<La2339:4]0cV9EU5[5WniOoioo7NL
H]I=[T6=AJe1RcDW:<DHYAB3008<@@0=468HPQB258<88@a27>HaB3V:=FTaBBSV7:@00QB300DDY1B3
588DHA1Q008<8003464@PQRS008Ha003588DPa22008@HP03368@@A10008<800<460<@0a0584HXQc3
9<8a0DGWGZU_<W=F0Vlf00Q_=f/gJaM_=f/FJcI_=FlE0Vle00=_5FleKcD00Vle1F/f00A_=F/EJaE_
=@E_5@9_=@E_5@03KcE_5FlE00=_=P04KaI_5FldJcD2KcD00fldKcE_=@08KcD5KcH2KcD4KcH2KcD0
0fldKcE_=00BKcD00flfKcE_=@04KcD2Kc@2KcD2Kc@016lcKcA_=6le0Vld00I_<flCKc=_<flCKc<2
Ka<5Kc@00f/DKaA[4`04Ka@3Ka<016/CJa9[4f/B1V/C00=[56[cJ_<00V/C00=Zlf/BJa800V/C00IZ
lf[bJ_=[4f[cJ_83J_<01V[bJa=ZlV[cJ_AZl`9ZlP03J_5ZlV[a00=Zl@9ZlPIVl@03J_5ZlV[B00AV
dP03I_=VdVKB009VdPMVd@9Rd@=RdP9Rd@03H]1RdF;A00=Rd@03H]1RdF;@009Rd0AR/0AR/@=N/@03
G[1R/F:`00=R/09N/004GZmN/5j`G[02GZl015j>GXmNSej?0ej>00=NSej>GXh015j?0Ui_00ENSUY_
FVmJSUZ=00MJKP9JK@9JK09JK@03FVaFKEI]00MFK@03EVaFKEI<009FC0=FC@9FC0EFB`03ETaFBeI;
009BB`=B:`9BB`03CRaB;58/00IB;09B:a9>;003CPa>2e8:005>3@0000h8@@PQ22488@Q12484010P
;>=1YeY/GXmFDEY@0UY_1UY`00=JKeY`FW001EY`00=JKeY`GW000Ui`0ej@0ejA00=NTUjAGY4015jA
00IRT6:AHY5RSf:<GRX2GPX01Eh9GPYN:EhYHPP00f870Uh80UX800EEXd40BFIEbF8X009R:P0:HR]R
:V8YIRMR:EgZHRaZT6kbMa42L_409FkAK[5Z/FZ`J[5VKf9>GRiJ3Ei>IXmEbCC2;<91k5H]ETaNSeja
H[5R/VJbI[1ZdFJ>DN/e9Qa1740XPCT0CLA9aSDS688@@A1Q008DH@07568HPabS7:@Pa1c57<@00abT
0R2T00@Pa1bT58@DH`8<@P@88@<8800:200<@1AP7811IEi[JaAZm6KCJ[82J[403G;cJ[1Ac2c6768P
Xb2T68<@81107<DQ1QcU008PiP047>HLaac77>L78>H01RCU9@DU1BTV:BLY9P<Y1@0B:BDY9c3U><A9
B6W9LRYbC79/LVefKgJ?NXij[gk=Oa5o4gka17lB0WlA1GlB00Io4gldOeIoMgnIOi/2Ok`017nmOmeo
gWon9Woo00AkF7LHMcUg>09c>0=_>@05LcQgFWMjLgYcF002KcT3JcT3JcP00f/HJaMVm`03I_L016;f
G]EN]Eje0eZe00=F]EJDEY@00UJC02ABLdiCDS1FT4YA=FXDI0@1100880PQ220<HA225:8Pi2D59>@X
hc56>HYJLG=FOoEoo7ojJcMJDTV;AJe5cDF[=BLXaAR4568234403aAR688DPQB2320@@Qc5<DLeJC5Y
;BTTaAR358<@HP0258<011B2564@H@a00Q1Q00HDPQBS6:<HXaB3488246800`a1340<800232003@a0
460@H1AP580LXR3T:>8]04GWGZY_<W=E009_=P07KcM[=f/GJaM[5V/fKcD00VlE0Vle0VlE0V/E00Q[
=VleJaE_=FlfKcE[5Fle0flE0Vle00A_5FldKcA_50=_5@04KcE_=6leKcD2KcH016lFKaE_56ld1Fle
00=_=6lDKc@016le00=[=FleKcH016lf00=_=FlfKcH016lf00=[=FldKcD00Vld1Vle0fld2Fle00=_
=6leKcH016le00=_=6leKc@00fld00E_<fldKcE_=Fld00E_4`04Kc=_4flCKa<4Kc@2Ka@00f/CKa=_
5002Ka@2Ka<01FlBJa=[4V/BJ_801F/C00A_4f/CJ_=Zl`=[4`9[4P=[4`03J_=ZlV[b009ZlPEZl`05
J_9Zlf[dJaAZlP02J_400f[bJ_5Zl@03J_42J_85I_42J]400f[aI_9VdP02I]800fKcI]9VdP02I]80
0fKAI]1Vd@04I]42H]43H]801F;AH[5Rd6:aH]400f:a00=R/6:aH[001V:`1F:a0eja00=R/F:`H[00
0V:`0Uj`1Uj_00ANSUj?GXmNS`INSP=NS`05FViNKUi]GXeJSP02FXl015Z=FViJKUZ>15Y^0UY]00=J
K5Y[FV`00UY/0eI]0eY/00EFK5Y/FVaJK5I/00=FB`=FC003ET]FC5I;00AFB`03ETaFBeI;00EFB`9B
B`06DTaB;59<DT]B;59;0e8/0e8[1Dh/00=>2dh/CR/00Th/00=>34X<CR`00dh[00A>;4h<DP]B:P5B
300000<880PQ24800PQ200T8@`@Q420/hd6XFVaNSeIAFU000UY_1eY`00=JKeY`FW000eY`0ej@0ei`
15j@0UjA00=NTUjAGY400UjA00QNT5jAHY5RT6:AHY1VSF9:0eh[00=N2UhXGRX00Uh900=N25h9GPT0
0eX900MAYD41BFEEbEh7HRQR:P02HR/01f9:ITUR:eh;HRaZSfkA009bl@0ZK]5^dVjaJY1ZSfI_HTiJ
3Uh`GU1NCfJ?IRThhS3SAL]F;5I<GXmN/F:bH]=R/fJaJ_5Z[eX=>DPL@A@P:84i0Dg6AJHe0QR2444@
HQAQ568HPaRS0abT00<LaAbT7:@00QbU11bT00<HPa1R34800PPQ0PPR00`88@@Q124880P0340DP2C2
?FAJBf/DJ_D2I[805FZbJ[5^m6kBDNd/aaaR9<<LXaR2320@@1BT7>DLaAcV7<HHYAS67<LLi`028>H0
1QcV8>HPiQcV8>HTi@DU1@8Ti@09:>DY1RD7;<D`Y4DXIHMfBW8Z009bC008LVmfT7Z?NZin[Gl?O_1n
lP9o4`05Oa9o4glBOa9o4002Oa8017lCOa9o4gld0WmF00=oN7nIOi/00Wnl00=ogGoNOoh09Woo00If
mG;GMaQg>7=IMeP2KcT01VlHLcQgFWMjLg]cF@9_>@E[>@0:KcU[>F/GIaMVmf;gH_INeUkEG[D4F[D2
E[D03UJDDYABTdicCS9>;eJAAS8eC1AT100000P0100222406a1Q468HXbD5;@DaIcV8CTmRlgMhOo]g
^f;eFU9AcdE[BLe9kDW;=BLXaAAS548@@QAR564HXP0258802`PP324LaRdV=FTaB2e99<DHPa124440
0aB300@DHQ1R468@H@8@HP0348<@HQ22008@PP04468<@@PP100222003`a0440DH121588HXQc37>DT
`S40ANMNbflcLeE_=P02KcL2JcL3JcH01fleKcI_=FleKaE_5VlE009[5P05JcI_=VleKcE[=P02JcD0
0f/EKaE_5@02KaD2KcD2Kc@016lDKaE_5FlE0fle00Q_5FlFKaI_5VlEKcE_=6/E0Vle00I_=6leKcE_
56ldJcD3KcD016/eKcE_=Vle0flf00=_=FlfKcH00VlF00=[5VlfKcH00Vle00=_=6leKcD02Vle00=_
=VleKcD01Fle0flf0fle16ld00=_=FldKcD016le00=_=6lDKa@00flc00=_=6lDKa@00Vld00E_=G<e
KaE_56/E00A_50=_4`03Ja=[4V[b00M[4`9Zl`A[4`9[4P03Ja=Zlf[c00AZl`03Ja9Zlf[c00AZl`=Z
m003J_=ZlV[b00QZlP=VlP=Vl@9VlP9VdPAVd`=Vl`9Vd@03I]1VdFKA009Rd@ERdP9Rd@QR/@IR/0IR
/@=N/@9N/0=N/@9N/004GZmN/5j`G[02GZl015j?GY1NT5j?1Ej>00=JSUj?GY000Uj@00=NKei^GXd0
0UY^00=JSUZ=FXh00eY^0UY]00=JKUY]FVd00eY/1EI]00AFK5Y/FVeJK@9JK0AFJ`03ET]FC5I;009F
B`MFC003ET]FC5I;00AFB`06DT]B;4h/DTa>C59<1E8/158[0Th/00E>:dh/CRa>;4h[00A>;003BRe>
;4h/009>;003CPaB2e8Z005B30000PPP00d88@Q22488@P@0300Xhd6WFVaNSeIAFU1JK`0=FW0:GY0:
GY4046:AHY1RTF:@IZiRBf8ZHR]N2Uh9HPQN2F8ZGPUR:Uh90Uh803YJ25XZEJI58TeVFNQR9V8WHRUR
:f9;HRYVBF8[HReR;6Z?K]1blFkAK_5^/FZ`JXiZSFI^HTmN<5haGU1RTFJ>HRPhhS3S@HUF:eI;GY1N
/F;BH]=VdfJaI]5R[ei=>DPTHQ@P984e0TW5AJHe0ab2440@@@8DH@03688HXabT00DLY00;7:DLY1bU
7:@Ti1bS68<DHPa220088@0222800`PQ12448@0222005Q1P684T`SDRER][4flDJ]9Z/VJAJ[5c56kB
DPh/iaaQ8:<PXQb1300@@AB40Qc500DLaQS658DDQ1RU008LaP8HaP047>HPiR3V8>H58>D00ac58<DT
i@029>D01bD6;<@`PccVHFMf:7I;009bC008LVifSgZ>NXanZgk=O^ao4@Ao4`0BOc5o4Gl>O_1o4WlC
Oc=o4WlcOcAoE7mFOgQoVWnkOkao_GoM0WoN9Goo00MfmG;FLaQg=gMHMeMcF003LcP01WMJMgUcNW=I
KcU_>0A[>@=[6006IaMVmf;FH]INeUkE0UZe011FUEJDEYAFU5JCDW=FLe9bDU9>DdiBDS1FT48a;B/@
@`80000I22440000000400PP584HXb3U<DDmZ4i>H_1VlFKbF[5F;dF<?Fa1JdF/BLa9bcDX9:D00Q12
014@HQ12564HXQR2584<80`R7<D]9CEX=FTaJBCU7:DDHaAR008DP`@@HP03464<HPaR008<HP05344<
H@aQ344<8003220234001A10460DPABR7<<00R3T00HThRcPANMRk6lcKcD4KcL00f/gJcI_=P02KcH2
KaH4KcH016/fJaI_=Vle0VlE0Vle00A[=F/EKaE_5@=_=@04KcA_56lDKa@2KaD3KcD2KaD01FlFKaE_
5FlEKcD01Fld0Vle0VlD00E_=FldKcE_=6le009_5@9_=@04KcI_=FleKcD2KcH016lFJaI_5Vlf16le
00=_=6leKcD01Vle0flf0Vle00=_=6leKcD01Vlf0fle0Vld00=_<fldKc@016le00A_=6lcKaA_=0A_
<`05KaA_=6ldKcA_5@07Ka@016/CKa=_4flB0V/B00=ZlV/CJa<01F/C0f[c00=[4f[cJ_800V/B1V[c
00=ZlV/BJ_801F[c0f[d00=Zlf[bJ_800V[b00AZlf[bJ_=Zl`AVl`04I_9VlFKbI_44I]82I]<2I]@2
I]<2I]85I]401FKBH]9RdV;BI]8016;A1F:a00ARdF:`I/mR/09R[`03IZmV/6:a00=R/@9R/0MN/@MN
/09NT004GXmNT5j@GXl6GXh02Ej?GY1NT5Y`GXmNKUi/FVeNK@02FXd2FVd4FV`3FVd3FV`00eI]FVeF
K@02EVd3EV`00eI[ET]FB`09ET/7ET`00eI;ETeFC@02ET`0159=ETaBBe8/0e9;00EB:e8/DRaB;5H[
00EB:`9>;09>:`9>;003CR]>;4h/00M>;09>2`5B2P5>300000d88@PP2244@PPQ124400P08:<mQeI;
FXeFD00>FW0:GY09GY44HY401f:aI[5VSV9;HRYR2V89009R20EN2@0;GPQN:EX9FRYEaTTSCHIIj6I6
HRMR:@03HR/2HRX06V8/IRaVKfZaK_5^lVkAK[5ZT6Z`JXiVKV9>HU1N;ei?GW1NKUWY>@<``T68EP]J
C5Z?G[83H[<04f:bI_9R/Ui>>BHTHQQ1888a8d6V@JLe91bS420<8110568HPQRS00<LY0<LY@0;7:@L
YAc47<@Ta22S7:<DHQ1R200400021283124222005Q10684TXS43ERa[57<eK_AZdf[BJ[5^m6kBEPh/
iaA18:8TXab1300@@ABT0QS500<LaQS66:D00QRU00<LaR3V7>H0123V00TQ1R3V8>HPiR3U9>HPaAc5
8<D00RCV01<TaBc4;8<haF5WMRMjJWY9LVabKWJ?NVijSWj^O/io3glbO_9o=002Oc<2Oa82Oa03Oa80
27lCOc=o<glcOeEoMgnIOi/2Ok`00gnmOmeogP0UOol00g]GMaQc>P02MeX00gMiMeYcF@02MeX017Mk
LgYcNg=H0Vli0f/I0VLH00AVmf;gH_IRm`9NeP04G]EJ]EZeEYD2EY@2EW<0459cDU9BDE9ACU9>DdiB
CS5BLShB9@/<@`@110088@@Q0PPQ01D880@0220<@1B37<@Y12e6?LY6;TX=BLa1Rd5[@Fa5[DF/CPe9
bSDV78@00Q120Pa2010DPQRR6:8HPA11324LY34U=FPiRC5Y9>DLaART56<DPP8@H`04448@HPaR4644
36801PaQ344<H@aQ344<@088@08<@00>460@HAB25:<Pi2D48>@LXRSPANMRc6lcKcE[5PE_=P03KcE[
=Vle009_5P9_=P04KcM[=f/gJaH3KaH2KaD016leJcI[5FlE16le0Vld0VlD36lE00=_=F/eKc@00Vle
16lE00A[5FleJcE_=09_=@03KaA_=Flf00E_=@9_=P03KaI_5Flf009_=@03KcA_=Fle009_=@06KcIc
=FleKcE_=Vle0flf16le0Vlf00A_=FlfKcI_=PE_=@=_=0E_=@03KcA_<fld009_=09_<`E_=004KcE_
56lDKa<5Ka@2Ka<016lBJa=[4V[b26/C1V[c00E[4V[cJ_=Zlf/B00YZl`05J_AZlf[cJ_9Zl`03J_86
J_<2I_<6I_82I]84I]<00fKDI]=VdP02I]84I]44H]8016KBH]5RdFKB0V;A00QR/F:bH[9R/V;AI]5V
d6:`0fJ_00EV/6:`H[1R/6:a00=R/0MN/@IN/003GY1N/Ej@009NT003GXmNSUj>00ENSP9NS`03GY1N
Kei^00=NK0=NK@9JK@04FVaJKEY]FVh2FVd3FV`00eY]EVeFK@02EVd4EV`015I;ETaFC5Y/1eI;00=F
C5I;ETd01EI<00=FCEI<ET`00e9=00=FC59;DT/00U9;00EB:e8/DRaB;5H[009B:`03ER]B:dh/015>
;05>:`5>2`5>3@000`PQ0P@Q00L40@00200LXcU5ET]NS005FW000eY_FW1JL004FW06GY0015Y_GY1N
T5j@3UjA0V:A00UR/F:`IXeRBeh9GPQR2687HRL01F880Uh800UJ2EXZFLE9@U65FLMR9F8VHRT00V8[
00QRBf8YHRUR:F8ZIViZ/Fka0V[A01AZ/FZ@IVmVKFI_HViRCUh]GRaJ;F9]ENTm9C33@HQF2UI;FViN
/V:b0V:c01=R/VKcI_ANKS3U864L@B23=BE1YTG9>D@PX``P200@@1AR688HX`027:@00ac47:@LY003
7:@022347:@T`b2S7:8HPQ1R220322421242220060P0440@@22R>FINK6ldKcEZm6[BJ[1Z/FkcLa=F
3RcW768TXb2R784<00a15:DHa@8LiP8HaP037<HLiQcV00<PiP038@HU1R3V008Pi`0C9@LPibCV9>HP
iBCV9>LPiRCV:>H/a2bT><IQIgI9NX]jR7I[MV`00WI^00MjKWZ>OZin[7k>Oa1o4`02Oa82O_44O^l0
2WlAOa=o4WkaOa5o=7mEOgQoVWnk0Wnl00=ogGoNOoh097oo00Mo^gnKMg]gFgMJNgYkV`04NiX02W^K
MgYgF6lhKcU[6F/HIaQVmf;g0f;F00ANeUjeG[EN]@9J]@04FYAFU59cDW83DU82DU42CS40259ACQ1>
DT8B9@`@A0@110022240<`PP224880@0000400P0320@@22R=DDiJ3V:?FY1RdF;@H]5S4F/CPi9jcDV
8:@@HQ12348@@aB26:8HPQR1440@@AbS<B@iISV7=DH]1B357:@DPQAR34888@a1348<HQ1Q368@HP03
36800`a1320<@@0336400`a1340@H00246402aB26:<Q1BT39><PXBT1ANMNZVlcKcD00V/E00=_=F/e
KcD00fle0flE0Vle0Vlf00A[=flfKaI_5P=_5@04KcE[=VleKcD2KaD2KcD3Kc@3Ka@00flEKaA_5002
Ka@6KaD00fleKcA_=@03KaD7KcD2Kc@4KcD3Kc@2LcD3KcD00fldKcE_=002Kc@00fleKcA_=@03KcD0
0flfKcE_=@02KcD00fldKcE_=@0<KcD00fldKc=_=004KcD00fldJa=_<`03Kc@01FlcKa=_4flcKa<0
2VlD0flC00=_4V/CJa800V[b1F/C00=[4V/CJ_<016[c0V[b0V/C0f/B0V/C00AZlf[bJ_9Zl`=ZlP9Z
l`=ZlP03J_5ZlV[b00IZlP9VdP03I_9VlFKb00=Vl@03I]9VdFKB00=VdP9Vd`=VdPAVd@04H]5RdV;B
H]83I]801fKAI]1RdF;AH]9VdV;B009Rd@9R/0=V[`AR/004H[5R/6:`H[07G[44G[000ej_G[1NT003
GY02GXl3GXh00ej?GXiNS@03GXd025j>GViNKEi/FVeNK5j>FVh2GVd2FVd00eY^FVeJKP05FV`00eY]
EVeFK@02EVd4EV`015Y[FVaFC5I<1eI;00=FC5I;ET`015I<00=FJeI<ET/00UI<0U9=00AFC59;DT]B
B`9B:`04DTaBBe8/ER/6DR/3CR`00dh[CRa>;00;CR`1CP/1CPd000888@88@@09224480@0200HPcE4
ET]N[Ej@00]JL0YNT0ENT@03FY5NTEjB00=NT@9NTP9NT@9RT@0:H[1VSF9;HRYN2F88HPMR9f8XHPL3
HPP2GPP03EX9GRUIa4e1DFAEaV84HRIR:F8ZHR]RBfHZ009R:@08HRYVKFJ?J]9V/FJ?IVmN;09J300Q
FRaN;5i>HRaN2eX<FRaIjSdU<<8mAE89ET]NSUj@G[9R/f;CH[9RdV;dFThe1b1R768PPc4UALQ5jCUU
8:@@8@`P008DH@05588HY1bT7<DLa0028<D57:@01RC38:<LXaR3468<8@<88@0=12488@@0220800`P
440HPSUVFVa_=6[dI]<00VJa00EVdVkcLa9J;S48008TX`068:8LPP`0348DaQd60QcV0QcW1AcV00@M
1Qd78@HQ1P<Pi`059>LTiR469@LQ1`029@P032T7:>H`iS3V><IIIgI9OZ]jRGI[MVafC@9fCP05NVij
SGj/OZinc@02O_401WlBO_5nkgk]O^mnc@9nc`9nd@0<O/mnl7lcOe=oMGmgOiYo^gnlOmeogWon97oo
00Mo_7nLMgagFg]JNgUkNP02MgX3MgT01GMjMeQc>6/iJaP00VLH00=Vmf;FH]H00V;F15je00MJ]EZd
EYAFU59cDW9>DP04DU80259ADS5B<DX@BS524RT;34<200000`PQ1248800322002@`P100800P0444L
PS45>DM1R`02@J`3AJ`01d6/ANe>3CUX:<DDPa12008<@P04568HXQRR684244002abS=B@iISUW=BHX
i2357:@HPaB346800P`R00<@H`aR46800PaR00H<Ha1R464@@@`P464248804PaR344<@0aP364@HABR
6:<Q1BCT9><ThRSQANQN[6ldKeI[=@9_=P05JcI_=VleKcE[=@02KaD3KcD2KcH01F/gKcI_=VlfKaH0
0VlE00E_=F/fJcI[=Vle009_5@05KcE_=6ldKcA_=@02KaD5Ka@4KaD3KcD00fldKcE_=@0<KcD00flf
KcE_=@02LcD00g<dKcE_=005KcD3Kc@6KcD00flfLcA_=@09KcD00flfKcE_=@05KcD016ldKc=_=6ld
1Fle00A_=6leKcA_=0=_<`03KcA_56lD00U_50E_4`9[4`9_4`E[4`03JaA_56/D009[4`04Ja9ZlV[b
J_82Ja<016/BJa=[4f/C0V[c00=ZlV[cJ_<00V[b0V[c1f[b00=ZlF[bJ_800V[b00=VlfKBI]800VKc
0fKb1VKB00EVdfKBI]9VdFKB00AVd@03H]5RdV;B00ARdP=Rd@ARdP03H[9R/F:`009R/@9R/003H[5R
/6:a009R/@9R/003G[5N/5ja00EN/@MN/0=NT003GXmNT5j?00=NS`ENSP9NS`05GXiNKEZ=GXeNK@02
FVh2GVd015Y^FVmJKUY^15Y]00=JK5Y]EVd00eI]00=FK5I]ET`00UI]00=FKUI=ETd00UI<00=FJeI<
ET`00UI<1EI=0UI<00=FBeI<ET/00UI<0U9=00=FC59<DT`00U9;00IBC4i<DTaB;58[ER/3DR/<CR`0
14X]CRa>;4h/0Th<0Dh;0Dh/0Dh^000222403@a0244<8@a1200<01QR=BA>:UZ=GXiJKUY_00=JL09J
K`=JL0MNT003GXmNT5j@00QNT@04GY9NTEjAGY43GY83HY401ej@IXeRBf8ZHRUR2687009R9`9R1`9R
209N2008GPUN:5W3CD1=HUFUGNAR9P9R:@9R:P05HRUV:F8YIRYVJ`02HVd0;UY=FR]Eje69CHU=RUG:
GR]N;5h[GNYJ35X]FN/m9C30?D=N9ej:GXaNSf:bH]=VdfJaI]5RleH^?DPTPaQR9:<a94G8BPXmIBBS
444<81AP464DPQRS7:@PiB341abT00HT`b348:@HPa1S3242224212406`@P100880@0320DHAR1>DAJ
;6/CJ_=VdVJ`HY1V/W<DLa1J;CDZ988TXb2S788@80a36<HQ1`037>L27>H011cU7>HPiQcV0b3V0R46
00HPiRCV9>HTiB469@H39@L2:@L2<>H03CS4FDEb1gZ<MX]bJg9<LTebC7I=LTefC7j;009n[00:OZen
[Wj^O^mo3Wl<O^]nZgj]OZ`2OZl037j]O^io<GlaOe=oMGnHOiYo^goMOmiooRAoo`08OkaoNgMJMcUg
FG=HJaMVmP9ZmP04JcQcFGMIMeP2KcP2JaL2I_L01VKFH]IReV;FG[IN]@9J]@07F[AJU5IcEY=BLeIc
DW<00U9B0e9A0U8a00E><DiB@Q4]:a1300800003120880PP00<880@<8005568LYBd7?FY1R`02@J`2
AJ`03TF<AJ]5c4G<>DPXiAR4468<@Pa1568HPQRS564242003AbS<@@iACUV<BDXi2357:@DQ1B346<<
@Pa3008<H`8<HP03468<HQ1R008<H@07340<HA22488<H@a134000PaP00<@HAB25:800Qc400lP`bT2
;@91jEj]Kc=cEVlfKcE[=V/eJaE_=FldKcD00VlE00=_=FlfKcH00Vlf00=[=VlfKcH016le0flf00A[
=VleKaE_5@A_=@04KcA_=FleKc@2Ka@00flEKaA_5@02KaD4KcD00fldKaA_=007KcD017<eKcI_=Vlf
0Vle00A_=6lDKaA_50E_=0=_=@03Kc=_=6ld00A_=19_=@9_=09_=@04KcA_<flcKc<7Kc@7Kc<:Ka@2
Ka<2Ka@00flCJa=[4`02Ka<00f/BJa=[4`05Ja<2Ja800flAJ_5[4P03Ja801V/AJa9[4f/CJ_=[50=Z
l`YZlP9Zl@AZlP9Vl`=Vd`IVl`AVdP03I]5VdVKA009Vd@03I]1VdFKA009Vd@03I]9RdVKB00ERd@=R
dP9R/P03H[5R/6:`009Rd@MR/@9R/09R/@05G[5R/5jaH[5N/002GZl01Ej?GZmN/5j_G[0045j?00AN
SUj=GXeNS@=NKP9JKP9JK`EJKP03FVeJK5Y]009FK@9JK003EVaFC5I^00=FKP9FC@04FVeFKEI/ET`6
ETd00eI;ETaFB`05ET/00e9;DTeFC002ET`4DT`00di<DT]B:`03ER/00e8[DT]>;00@CR`00dh;CRa>
:`01CPh0000312488@Q100<<@@8@8007568e94H:EXiNSeY^FVl00eY`00=JKeY`FW000UYa0UZA00=N
TEj@GY400Uj@00=NSej@GY0025jA00=NTUjAGY8015jB0V:A0V:a00AV[f9/HTYR:P9N2@0AHPQR:F88
HPMR25h9HPQN25h9GRQM`ddPDF=IY5gTHRMR:@03HRX00f8YIRUR:@02HTX0<V9=GTiNCEX/FPaEjTf9
FL]N;69]HTeR;5h:FP]NCUh=@FLdhCe3HRMNRUj=HY1R/V;CI]9VdFKaI]9NCSe986<DHRBS<BA5adh[
>FDTXa11340@HA1R568HPaRS7:@La1bT8:@47:@02R2T8<<Pa1bS68@@HPP022088@@Q0`PQ00X<80P0
320DHAQQ>B9J:fKaJ_=V/@9V/P0<I[=^m7<AFRde:R229<<LY1bS420<8QBU0QcV00HLiacV7>HLiQS5
7>H58>H38>L48>H00bCV9>LU1`029@P02BT7;>L`iSBSFDEb1gI[LV]bC003LR`01G8[KP]b:gY/NXd0
0Wj=00En[Gk?O/inkgk;009n[09n[@0=OXen[Gk@Oa1o4GlbOeAoM7mgOiUoVgnlOmd01goN00AoggoN
OmmogaYoo`0AOi]fn7LIKcQ[>6KEFS9El57_GY9VmVlhLeU[>6/iJcQ[6003I_L3H]H01ekFF[IJ]UZf
F[EJ]5ZD00EFL`04EW9BDU9ADU82DU401U8aDU5BLTHb=F`DI0800003224880PP0088800:200880`P
340@@AAS7<D]1cUZ@H/3@J`00dF<AJa1R`02?H/06C4X9<DLY1B3468@@QAQ684DXa1R320@81b2;><i
ASf7=DL/i2356:@DQ1B346<8@@aR008<H`<<HP8@HP8<HP8<H@04368<H@a0220234003PaP464@PABR
5:<La1c38:4a8SfXFZi[=6leJcD2JcH01FlfKcE_=FlEKcD00Vlf0fle0Vlf00=[=VlfKcH026lf00=_
=FlEKaD01fle00=_=6leKcD00Vle0flE00=_=FlfKcD00fle00=_=6leKcD016le1Flf0Vle00=c<g<D
La@00W<C0Vld00=_=FldKcD00Vle00=_=6leKcD00fle00=_=6leKcD046le1Fld0flc0Vld0Vle1Fld
1Flc2FlD00=_4flDKa@00flD00E_4f/CJa=[4f/B00A[4`03Ka=[4f/C00Y[4P=[4`03JaA[4f[c00aZ
lP03J_5ZlV[b009ZlP03I_=VdVKC00UVl`MVdPMVd@9VdP9Rd@09H]9RdF;AH]5RdV;AH]9R/V:a009R
/09R/@=R/0=R/@03H[1R/F:`00ER/@9N/@04G[1R/5j`G[04GZl00ej?GY1NS`02GXl00ej@GXmNT002
GY04GXl2GXh3GXd01Ej>GViNKUY^FXl00UY_1UY^0UY]0UI]00=FK5I]EV`00UI]0UI^00=FKeI>ETh0
0UI^0UI]00=FC5I=ETd00eI=0UI<1EI;00=FC5I;ET`015I<0e9<00=>C59;DT/00U9;0e8[54h/0DX>
0002224224402`a1464DH@`0568a14X;EXiNSUY]FVl00eY`00=NL5iaGW400eYb00ANLEjAGY5NT@9N
T003GXmNT5j@00INT0ANT@ENTP9RT@9RT004HXmRKF9;HRX2GPT6HPP3GPP0268WGL=9@De2DHAQi5h7
HRT3HRX026HYHRUV:F8YHTYRKEi>FRd2FR`01eWZDJUIjf9_JXeRKEh[009J2P0<GViN;D5X=>8i8EGV
ERUNKUjAH[9RdVKB0VK@01aVdV9`?DPTHQQQ888a0dG7BPXmI222440<811Q468DHQR36:<LXac37:@P
Y1bT8:@Pa1bT8:<P``8Pa00468<@HPP022022243220220001`a0584HH3T0FR][4F[b009V/@0=IY=V
/flDLa1JCBd9868T`bCU7:<<80`Q5:D021cV1B3V0R3W0b3V00DLiR3V9>HPibD700<U2007:>PXaS22
DBEaagI;LTX00VhZ00I^2Vh9LPYb2W8[MT`2NV`00gY]NXin[`02OZd01Gj[OZan[7j]OZ`00Wk_00An
kWl=Oa1o<`9oD`06OgIoMgnIOk]o_GoM2GoN00=oggooOol067oo00aoFWKILcU_5fKFFS59JcD:>DY9
ZejBI_D2JcP00f/iJaQ[6003I_L01f;gH]IReUkFG[INeUZf009J]@04FYAFLeIcEW82EY<00eIbEU5B
D@02DU82DU401e9@EW5:<SV<56@4000000D8800<200880`P320@@AR48<Da1cUZ?H]1Rd6<0TF<00Q5
[46[?H/iJc59:>DLY1R30Q1100@DHAbR6:@DH`8<800:668/hcUW?HPiJ2cU8<DHQ1AS588346801PaQ
368<HPa2468<HP8@HP05368<HA1Q488@H002320334000a1P484DP@0258801aB17:4/h479GZm[=6le
00=[=@=_=@04KaE_=F/EJaD2KaD2KcD5KcH2KcD5KcH4KaD01VldJcE_=6/EKaA_5@9_50=_=0E_5@05
KaA[5FlDKaE_=003KcD00fldKcE_=@02KcD3KcH01VleLcE_=6/CKa=c4`M_=0=_=@=_=006KcE_=6ld
KcA_=Fld0fle00=_=6leKcD00Vld0fle00A_=6leKcA_<`9c<`03KcA_<flc009_<`9_=09_=@03KcA_
<fld00A_=003Kc=_4flc00E_50=_4`03JaA_56lD009_509_4`05Ka9[4f/CKa=_4P09Ja<2J_82J_44
Ja8016[bJ_=Zlf/D0V/C00=Zlf[bJ_801F[b0f[a00IZlV[aJ_5ZlF[bJ_42I_84I]8016KcI]9VlVKb
0VKc0VKB00ARdFKAI]9VdP9Vd@03H]5VdFK@00AVd@04I]9RdF;AH]82I]4016K@H]5RdF;A0V:a0f:`
0V:_0f:`00=R/F:`H[000V:`0V:a0Uja0Uj`00EN/Ej_GZmN[ej`009N[`03GZiNSUj>00ANS`03GY1N
Sej@009NT09NS`03GXiJSUj=00ANS@05GViNSUi^GVmJS`08FVh2FVd7FV`00eI]EViFK`02ETh01UI^
ETeFC5I<EV]FC0AFC@9FC0UFB`07ETeFC59<ERaF:e9;DT`01E9;0U8[1dh/00=>:dh/CR`01dh/0Th[
0Dh;0Dh=000322403@Q1344<@QAS420D@C44BN]FKej=FVeJKeY`009JL@03FW1JLEYa009JLP03FY9N
TEjA009NT@=NT0ANT@ANT004FY5NTEjAGY45GY84HY4016:?HViRC68Z0Uh900EN25h9GPUN2F8800=N
2@0:GPQR9f74DF=5AE66GNER9ehYGRX3HRX2HRT0<VHYITYNCEh/FRaJ:eH<DL]9RDV[FRaRJehZGPYE
jEGZFRaJ3D57<<4i0U7WERYJKejbH[9RdfKCI[9VdFKcHVlmB2AR640PHS43ALM:2T65784@@0`P444@
HQAR58<HXabS7<<37:@27:D03QbT7:<PY23U8<@HXaAR200<8@PQ124480PP120210005P`P584PXCSP
ERY[<VlCI]5VTFI`I[=c57LaHVla2R229<<La1R2320<8ABT1acV1b3V0QcW00HLiQRU48<HQ1c58>H2
9@L03bT79@LXibBU<89=9VV7KNY^2FhZKPY]jVh:KNY^2`02LR`2MTd047I]NVijSWj>OZinZgj]OZin
cWl>Oc1nkWk]O^io4Wld0WmC00IoMGmhOiYo^WnlOkd4Omh2Omd00goNOmeo_P0KOol03WmIM]Qc>7<h
HYAA[S3898LXYSDYDNiR/f/FJaL3JaP2I_L2H_L00f;FG]IN]P02G[H015ZfF[EJ]EJC0eIc00EJU5JD
EY=FLe9C00ABDP05DU5BD4Ha<F/DH`0210000`PQ2208800522006A10444DHac5;@HiJCUZ@H]1S4F<
@Ha5[46/AJdmRc4X:>DLY1R2300<81AQ8<<HY11R008<800:688`i3UW>HPeJ2ST8<DDH`a158844680
1@aR464<@Q1R36800Q1S0PaR0PaQ00L@H@a0340880a0320@H@02484246402110680]0D79GZi_=6mE
KcH2JcH01f/EKcE_=FleJaE_=F/E00=_5@9_=P04JcI_=VlfKcH3KcD3KcH00fleKaE_5@02KaD026/E
JcE_=F/fJaE_5FleKaD3Kc@00flEKaI_5P03KaD7KcD00fldKcE_=@04KcD00flfKcE_=P02KcD7Kc@5
KcD00fldKcE_=@07KcD00fldKcE_=002KcD00flDKcE_=@04KcD016lcLc=c<g<c1Flc1Fld00A_<fld
KcA_=09_=@9_=003Kc=_56lD00=_4`9_5003Ja=[56/D00=_50A_4`9[4`04Ja9[4f/CJa<2J_<00f/C
Ia=[4`02Ja<01V[cJ_9Zlf[cJa=[4P9[4`EZl`9[4`03J_=[4f[b00EZlP03J_5ZlV[b00EZlP9VlP=V
dP04I_9VlFKBI]85I_<01VKBI]5VdFKAI]9RdP=Vd@9Rd@ERdP9Vd@04H[5RdF;AH]44H[43H[000f:_
H[1R/@06H[42G[43G[03G[44GZl2GZh025j>GXmNSej?GY1JT5j@FY03GY0015j?FXiJSeZ=15j=0Uj>
00=NKEj>FXl025Y^0UY]0eY/15I]0UI^00=FKeI>ETh00UI^0UI<00=FJeI<ET`00UI<00=FCEI<ETd0
1UI<00AFBeI<ETaFC09BC005ERaFBe9;DTa>C003DT`2CT`8CR`00dh[CRa>;002CR`00dX]BRa>;002
CR`2CR/1CP/1CPd000@88@0@324<8PP2200@@2d4AL]FKej>FViNKeY`FY5JLEY`FW42FW8015ZBFW9N
TUjA0Uj@00=NSej@GY001EjA15j@0ejA1EjB0V:A0V:a00ART69_HTaN:P9N2@05HPQN2F8ZGPUR2002
GPT2GPP025gXFLE9A44VCHIMiF97HRT4HRX4HRT02V9;GRYF2EhYFP]5JSDWAFYJ;5hX0UGY02AEbEGX
GR]Ik4EX<:0i0e7XFTaNL5jbH[9N/f:cH[9Vdf[dGThmAbAQ520PHCD3BLM>:d65884@80`0440@HAAR
688HPabS7<<47:@02QbU68@LY22T8<DPa1R3468800PP0PPQ0`PP00X400P0320DH22Q<<1>2F/AKa9Z
lP9ZdP0=J]Ac=GMBHW0iBbBR:<8PXabR420<8AB47<D00QcV00@PiQcV7>HLiPLPiP038>LLiaS6008<
@P0@6:@La2359>HU1RT59BLXiRS5<89=1FEWJLU]j6h:KNX2KN/036h;LP]b2g8/LRefCG9=LTifKWY^
NXanR@9n[@0>O^aoCGmaO`mncGk`Oa=o=7lbOg9oMWmiOiUo^P9o_006OkeogGoMOmeo_Gnl0gnm6goo
00ioF7[hLaM^mUiCAFdXR1`U:8HXYTW=GY5W5VlG0V/G0V[g0VKg00ARmf;FG]MNeP9N]P03F[EFUEJD
00EFL`04DWAFM5IdEW<2DU<02U8bDS5B<5I@BU4eJQR3100000PQ1@PP0P`P00P@@11R58<LaBd6>FTm
RSf;0d6<00i1[4F]BLe5ZcDV;>DLY1b2300<81AP7<8DPQ1S0Q1100`LPc44>FLiJ3E7:>@LYA1S344D
PAB2468246401a1R464@@A1R368<@PaR00@<@@<<@004220<80`P460246402aBR588@@1AP;@11aej]
KcA_=FlfJcH00Vlf2Fle1flf00Q_=FlEKcE_=VleJaE_5Flf0VlE0fle0Vlf00=_=FlEKcD00fld00=_
=FlEKaD02Vle00=_=6leKc@01Vle00=_=VleKcD00fle26ld00=_=FldKcD026le0fld0Vle00=_56le
KcD00fle00=_=6lcKc<026lc00=c<fldKc@00fld00=_<fldKc@00fld00A_<flCKaA_50=_4`06KaA_
4f/dKa=[56/C0VlC0f/C0f/B00=[4f/BJa<00f[c1F/C16[c0f/C1f[c16/C00AZlf[bJ_9ZlP9Zl@=Z
lP04I_=ZlV[bJ_82I_4026KAI]9VlVKaH[5VdVKbI_42I_801fKBI]5VdFKBI]5VdV;C009VdP03I]5R
dFKA00ARdP03H]5Vd6KA00=Rd@=R/@9Rd0ER/0AR/@08G[5R/F:aH[5N/Ej@H[1R/@AN/@04G[1N[ej_
GZl2GZh2GXh2GXl6GY0015j?GXiJSUj>15j=0Uj>00AJSEj=FXiNK`IJKP04FVeJK5Y]FVd2FV`00eY]
EViFKP08EVh2ET`3EV/2ET/2ET`6ETd00eI<ET]FB`02ET`01E9;DTaF;5H[ET/01U9;0Ti<00=>;58[
CR`014h/00=>:dh/CR`01Th/00A>;Dh/CRa>2P5>3@0010PQ00`880@010040110:@@mbeJ@GZmJSeY_
FW02FW400eY`FY5JT@02FW800ejBGY5NT@05GY05GY45GY02GY44GY83HY42H[4026:@HXmNC68ZGPYN
:Uh:GRX2GPT00f88GPUN2@02GPT01egXFLE193CTAFIR1FI8009R:@=R:P0;HR]R:V8[HRYR:eh[HVeR
K5h/EN]Ij`02GR`0:5h[GRaJ;5XZGRUR;5h<BHT``ST3CNUFC5YaGY5N/UkCG]ARdekCI_ARKT5Y:88H
@BAQ=@A5b4X;@JHT`a10420DHA1Q564DHQR27:<LY1c511bT00LLYAbT8:@LXb3468<@HP0222022240
8P@Q220880PP320@@1AP680/`4X:Ia1[4V/CJ_9^lflENgMgE69a=D/XXbRR9:8PXQ0P324HPac47<DP
iB3V7>HPiR3U0b3V00<PiBCU9>D00R3V00DHiQB37<DU1R3V008La0099>DU1RDU9BLXiRS5<898iF55
009]j0A]jP9^300>LP]b;G8]MRabCG8]LRajC7YZOXUn[Gj^OZenZ`9nk00:O^mnl7kcOaAoDgmeOgMo
VGnJOkX3Ok`3Omd01GnmOkao_GnLOmh06goo011oF7JDK_MZeEhaAH`/bBAV82<XaT7=GY9VmFlgKaMZ
m`9ZmP9Vm`03H]INeUkF009NeP06F[IFUEJEEYAFLU9c0eIc00MBLe9dDYEFM5IcDU=B<P02DS401eI`
CU51RQb3100000@000H88009320@@11R58<LYC45>HU1RSf;0091S00?@He1S4F]BLe9bcTV;>@LXabR
664@@AB27<8HXaAS008@@@0778<a13UW>FLe9bcU7:D00Q1S00X@PQB3464<@11Q468@HA113208@@<<
@P8<@@05444@H0aQ364<@@02320030Q0360@PQBR6:<HXQRQ9>0mYUZ;KcA_EPA[=P9_=P03JcE[=Vle
00A_=@Y_=P03JcI[5F/E009_=P04KcE_=VleKcD4KcH5KcD4KaD9KcD00fldKcEc=006KcD3KcH3KcD8
Kc@00fleKcA_=@08KcD00fldKcE_=@06KcD00g<eKcE_=002Kc@2Kc<2Kc@00flcKcA_=007Kc@00flc
KcA_=003Kc@016lcKa=_56lD0flC00A_=6lDJcA[4`E[50Q[4`=Zl`03JaA[4f/C00E[4`03JaA[4f[c
00UZl`A[4`03J_=ZlV[b00=ZlP06I_9ZlVKcI_=ZlfKc0V[b16Kb0VKc00=VlVKaI]800fKB0VKc0VKB
0f;B00=RdF;BH]801F;B00AVd6KAI]5Rd@=R/@03H]9RdF:a009Rd0=R/09R/@03G[9R/Ejb009R/P04
G[9N/EjaH[05G[400f:`HZmR[`02GZl00ej^GZmNS`02GXl6GY001Ej?FXiJSeZ>GXl00Uj=00ENSUZ>
FXiJSUZ=00QJKP03FVeJK5Y]009JK@03FVaJKEI^009FKP=FK`AFKP9FC005EV]FC5I<ETaFB`02ET`6
ETd00eI<ET]FB`02ET`2DT`00eH/ER]FB`03DT/2DR/01E9;CTa>;4h/DR/01Dh/00=>:dh/CR`024h/
0Dh;0E890Dh<000322402`@Q12080000100@@2ST?J]FKej_GXl00UY_00AJL5YaFW1NT0=JL0ENT003
GXmNT5j@009NT@05GY9NTEjAGY1NT@03GY04GY42GY83HY401V:aGY1RSf9^HTaR:P=N2@03GPYR25h8
00=R2009HPUN2V8XFLE5ASSUADEMi698009R:@ER:P0<IRYV:fI<HTaRKVJ?I[5VSf9^IViVSfI^0Uh]
00eJ;Eh;HRaR34V9=>8dhDWXETaJL5jAH[5RdP03H]<03fKdIXm1RRB3744PHCCSALU:2d6W9<<DH10P
564@H@0256401AR27:<LY1RT6:<01AbT00LPY1bS8<@HXa1S34888@0222003@@P220880PP200@H1B0
7:4``4WXI^i_4F[a009ZlP0<LcA_=6lBGRhe:BB1::8X`R2Q420<81RS0Qc50R3U00<LiR3U8>D00b3V
0bCU00/PiAcV7>DLiAcT9@DLi11R588TiBDV008Y9`07:>DTY322B>AQIW8:KRT00Vh:0VgY00E^2Vh<
LRab;78]009f;00ELRab;G8/NTYnR7j=NXmjSWj>OZanZgk=O_5o4WlcOe=oM7mgOgQoVGnJ009o^`03
Okao_GoM009og@=o_@03Omioogoo01Uoo`0>O_EbLVZfJ]EVU5X?>B/XQbc6>DUF;ejBI_E_5P=ZmP04
I_IVeV;FH]H2G]H025kEG]IJ]UJEEWAFLeIbDW82EW801eIcDW=BLdicDW9BDe9B009><P08CS5JD4h`
AJXLPP@0000800H88008320@@111568LY2cT>FPmR@8mR`=1S00=AJe9[4FY>@@/`aR17:4DHA11588H
XQRT56<00Q1100lLPS43>DHiASD6;>DLYA1S348@HQ22464<811Q46800Q1Q0Pa100<<8@a134400Pa1
00@@@11P360<H@<<@@0<464@HQB25:8H`Qc39><Xh3fUFXU_<fmG0f/f0Vlf00=[=V/eKcD016le00=_
=VleKcH00Vlf00=_=flfKcH00Vlf00=_=F/eJaD00V/E00E[=F/EKcE_=6le00A_=PM_=@9_5@03KcE_
=6ld00A_=@Q_=003KaE_=Fle00=_=P=_=@a_=0M_=@A_=003KcE_=6ld009_=005KcEc=7<cKcA_4`02
Kc<4Kc@3Kc<00fldLc=_<`09Kc<00fldKa=_4`02Ka<01FlDKa=_<f/cJa<00V/D00=[5F/DJa<00Vlc
16/C0V/B00AZlV[cJ_=Zl`I[4`03J_=ZlV[b00AZl`03JaA[4f[b00=Zl`E[4`04J_9ZlF[aJ_82I_80
16[bI_=ZlVKb0V[b26Kb00=VlFKBI_<00fKc0VKB00QVdF;BI]5RdFKAH]5VdF;A0VKB00=RdV;AI]00
0VK@0V;A1F:a0V;@16:`00IR/EjaG[5N/V:bG[82G[400f:aH[1R/004G[400f:`GZmN[P03GZh01Ej_
GXmNSUj>GXl00Uj@00ENTEj@GXmNSej>009JS`04FXiNSEj=GXh3FXh015Z=FViNKEi_0UY^0UY]00=N
KEY]FV`00eY]00IJK5Y]FVaJKEY^EVl2FVh2ETd00eI^EVeFK002EV/3ET`3ET/00eI<ETeFC@03ETd0
0eI<ET]FB`03ET`00e9<ERaF:`02ET/00e9;DR]B:`02DR/3CR`00e8[CRa>;003CR`3CR/7CR`2CR/1
DPT1CP`000<88@0?244<@@Q1224401119<DiRTi?FVeJKUY_FW1NLEYa00EJL0INT005GY5NT5j@GY5N
TP0;GY43GY82HY401f:bHY9RTF9_HTeR:Uh800=N2@03GRQN:F88009R200:HPUN2F99GNI9QScU@BAI
aF99HRT5HRX01FHZIRUVBfI/JXh00V[A01EZ/6J`J[1Z[fI^HTeN;Eh^FReJ2egZGN]9ZCCR<>59jEI]
FU1RSfKAH]800fKC00mVlf:>@HXTQ1@P764``T68BP]1Z2C4540@81AQ46400QAQ00LHPQRT6:@HY1bS
7:@LP`027:@01Qc57:DPaB346:@@H`888@88800=120880PP220800a0560PXBRP@JMNS6;;GZh00Uj@
00iN/F;BHXiEbcT7840XPRS28:4D@10Q6:@PiB3V0R3U11cV0R3V00<PiBCU8>D00R3V01<LiQcU7>DL
i1B2344DPRD59BHY9RDV9>DTY3B2B>=UQW9;LTY^:`02KPX01fgZKN]^378/LR]b;7I;009f;004LRa^
;7I<NV/2NXh037I^NVinSGj<OZencglCOc=oDgmDOgMoV09oV@04OkYo^gnlOkd3Omd01GoNOkeo_GoN
Oml06Woo00ejT6i@J[Ig>6lhIYAN<UGaDLiJ<5YbH[AVe002J_D00f[fI_IVeP03H]H2G]D02E[EF]IF
UUJEEWAFLeIaEW9FL`02DW<3CW<00e9cDU9>DP02CS801dhaFTm>3T699:@8000000L8800;320@@10P
548LY2ST=FTmRCeZ?H/mS002@H`09DF<BLa5R3T5;:@D@AAQ568@@AAR688HYAAS548@81QR<><iASU7
=@H`iAbU32488A1R58<@HA11464@PQB258<@HQ11348<@@a2008<HP03344@@110008<H@06444@@11Q
468DPQRS0QcT00HPhbT0@LENR6/cKeH2JcH016/eJcI[=Vlf1Fle1Vlf00I[=flfKcI_=VlFJaD2JcD2
JcH2KcH4KcD2JaH3JcH00f/eKcE_=@02KcD2KaD00fleKcA_=@04KcD3Kc@6KcD4KcH01VlgKcI_=Vlf
KcE_=0U_=@03KcA_=Fle00M_=@=_=003KcE_=6le009_=09c<`03Mc=c=6lc009_<`=c=0I_=0=_<`E_
=003Kc=_=6ld00A_5006Ka=_<f/cJc=[56/E0f/D00=_4fleKc@00f/D00E[4f/DJa=[4f[c00M[4`9Z
l`07J_9Zlf[cJ_AZlfLDJa<016[c0V/C00=VlfKbI_8016[b0VKb00AZlVKbI_9VlP9ZlP05I_9VlfKb
I_9Vl@03I_83I]800fKcJ_=Vl`02I_<00fKbI_=Vl`02I]4016;BH]5VdVKB0V;B00ERdFK@I]1Vd6;A
00ER/@04G[5NdEkAH[42H[02H[42G[43G[83G[4016:`HZmR/6:`0eja0Uj`0ej_0ej?00=NSUj?GXl0
0ej@0ej?0UZ@00EJSeZ=GXmJSUZ?00=JSP03FXmJSUi_009JKP9JK@03GViJKUY]00=JKP09FVeJKUY]
ETiJKUI_ETmFCUI=009FKP04EVeFK5I]ET`3ETd2ET`00eI;ETaFC@04ETd00eI<ET]FC002ET/3DT/4
ET/0159;DRa>;4h/0di<1Th/0dh[0Th/00=:;Dh/CR`00dh/0Dh[0E8Y0E8<00003`Q132488@PQ344<
@Pa1200<8234>FU>;UY/FViJK`05FW02GY02FVl00ei_GW1NT005GY0:GY44G[42GY45HY805F:@HTaR
2EgXGNUN25hXHRMR25h8HPQMj688GPUR:6H4DF@li443FLEVB@02HRX2HTX01V99HRUR:687IT]VS0=Z
[P9VS@04IXaVJf9;GP`2FP`07EX=FPaIbV7ZCHP``S3RALUFKEY_GVeV[fJaI]9V/V:bI]9JC46[98@D
81aQ;<95Z58<ALTXi11032000Q1Q00@DHAA0688HX`<HY0036:<HPab3008LX`8Pa0048:@LY11R2202
100522002`@0220D@1bP::0mITh;ERQB:E8:DR`00UI?00eRSEWZ?DL/XBAQ9<8PXAA0324DPac48@HP
i@027>H011S57>HLib3W0R3V01lPiB3V8>DTiB3U9>DPiAc4468DY2C5:@DY9RTU:@DXi2S4=854`F5U
LV]fJfhYKPU]j6g9KN]^378;LRYb:`02MRX04WH[MRafC7I<NV]jKGI^LTmfCgZ?OXanRgj[O_1o4GmB
Og=oMP9oV09o^@03OkYo_7nm00Iog@03Omioggoo01Uoo`0:O[9bDG:fK_MgFG<hJ]EV]6ZeI[D2H[D0
0f;EI_EVe@02I]D2H]D3G]D2F[D01UZfEYEFU5IcEW9FL@9FLP04DW9>DdicDU83CU802TiACU9:<Tha
FTi>3SeX8:D<0@001`PP00X<8@`P320@@AbT;@DiJCf9?FXmR`=1S00NAHa9c4F8=@HTY1A1440DHQ1Q
544HPQBT56@@8@`P668/i3DV>DPe9c4678@<80PP588Ha1RS568@HQ221A1R00<<@PaR36800PaR0Pa0
00L@@0aQ444<@1AQ584HPP027<@01acT9@@]8D75FVQ[<VmF009[=@03KcA_=Fle00I_=@Y_=P04KaI_
5F/EKcD4JcH016/eKcE_=Fle0VlE00=[5VleKcD00Vle00=_=6leKaD00VlE00=_56ldKcD016le0Vld
00=_<fleKc@016le16lf0Vlg0flf36le0fld00=_=FldKcD00Vle1Fld00A_=FldKcA_=0Ac<`9_<`E_
=004Kc=_=6ldKc@5Kc<00fldKc=_<`03Kc<6Ka<016/CKc=_=6lD16/C0f/D0f/C00=[56lCJa@02F/C
0V[c00=Zm6/DJ_@00V[c00=[4f[cJ_<01V[c00=Vlf[bJ_801f[b00=VlV[bI_800fKb00=ZlVKaI_80
0VKb16KB2FKA1VKB00=VdFK@I]000fK@00=R/F:`H[400f;A26:a00AN/UjaG[5N[`=R/003HZmN[f:_
009R/09N/@03G[1R/6:`009NS`03GZiNSUj>009NSP03GXmJSUj?00=NS`08GY1JT5Z?GXiJSUj?FXmN
SP9JS@04FXmJSUY^FVh3FVd:FVh01EI>ETmFCeI>FVd00UI^00=FKEI/ET`015I=0UI<00=FBeI<ETd0
15I=00=FC5I;ET/00eI;159;00=BC5I;DT`00U9<00EFBe9<DTaBC59;009B:`A>;09>:`E>;005CR]>
;4h/CR]B:P01CPd00004224<80a1348234402@PP2008022T>FMFCF:/G[1JK`03FW0015i`FW1JL5Y`
0UY_00=NSei`GY0015j@00=RTF:@GY401ejA15ja00AN/UjAHY9RTP=R/P09HY9RT69;GPQMj5gYGPQN
:68700AN200:GPUN268WINA98cS3@@9MYEi9GRX2HRX02F9;HTYR:F88HPUVC6Z>JZiZ[`02JXh096Z=
IVaVJfI<HRaN;Eh/FPeJ35gYIRU=R332;<95bU9>FTiRKVJ_I[9VdVJcH[=Vdej=?J`TYAQ1768`i4FY
DPa9bBC4440800<@@@03564HPQRS00DHY0047:@LXabS8:@37:@0111R220400@P10PP0P@001P881A0
8:4`hCe6ALY1ZD68DPYNT6KcJcIZlf9^EL/i9RR2788PXA10204@HQc48@H27>H00acU8>HPiP037>H2
8>H00b3U9>HTiP029@H48>D03BD6:@DY9RT5:@@/i2C3<854XEeULVebJfh:009]j@06KNY^378;LRab
:W8/0WH[00Ef;7H]MTefCGI<00=fC`0;MVmjSgj<OX]nZWk_Oa5o<GmdOgIoU`02OiP2OkX2Ok`3Omd0
0gnmOmeog@02OmhJOol017keLW1b]G;f0flH00A^mf[gI]IVe@9ReP9Ve@=R]@04G[IN]EkEG]D2F[D0
1EJeEYAFLeIcEW800e9b00=>LdiBCU<01DiB00Y><TXbBS5JL5H`?FTHQ@P0100800H88008224<80a1
444LY2cT=DLmJ@8mR`0P?Ha1S46<AHa9ZdFY=BHPY1AR444@HA11544HPaRU58@@@@`P668Xa34V=DLi
B3D77:@<80PP468HY1S45:<@PPL@HP0=46<@Pa1R368<@110460@HA11464DHAB16:800QbR00PH`ac3
:@0maEJ:Jc9_EF/e1fle16lf0Vle1Vlf0flF00A[5V/EJcE[=@9[=P04KcI_=F/eJaD3KaH00flEKcI_
=@02KcD01VldKaA_5FlEKaA_=0E_=@=_=003KcE_=6le00A_=@I_=P03JcI_=Vle00Q_=@03KcI_=Fle
00=_=003KcE_=6le009_=@=_=0=_=@E_=004Kc=c<g<cKc<;Kc@3Kc<3Kc@01flcKcA_56lDKa=_<flb
00E_4`9_50U[4`=[5003J_=[4f[c00E[4`04JaA[4f[cJ_@2Ja@2J_<2Ja<6J_<2I_<3J_82J_<01V[b
I_5ZlV[bI_9ZlPAVlP9ZlP=VlPIVdPEVd@03I]9VdFKB00=VdP03I]=VdVKA009Vd09V/003H[1R/F:a
009Rd@YR/@03H[9R/F:a00=R/004G[1N[ej`GZl2H[03G[4016:`GY1NSf:_0Uj>00AN[Uj>GZiN[`9N
S`07GY1JT5j@GY1JT5Z?FXh00eZ?00ANSUZ=FXeJSPAJKP9JK@UJKP9JK`04EVmFCeI_EVd2EVh00eI]
ETaFC005ETd00eI<ET]FC006ETd4ET/00e9;DTaBB`07DT`4DR`3DR/5CR`00dh[CRa>;003CR`01Dh[
CRa>;4h[CP/00Dh=000010PQ320@@0a00``P00P800`0788mIeI=HZ]NSeY_1eY`00AJKei_GXiNS`IN
T003HY1NTEjA00MNT@9N/@9N/P03GY5R/F:a00=R/@06HY5RSf9ZGNMMb5gX0Uh800mR1eh7GPMN1f87
HRUN268WGLA10cB3?@=IaEhXHRP00V8Y00UR:V8YHRUV:FHZITaVKFZ^K[000VZ?0VZ>0VI]00mRC68/
GRaJ;Eh<HPQZAdV7<<8/XT6ZDRmFCUi^H[000VJa00eV/fKDJ_AR[T6/:<HL@AaR;>@mIdh;BNTTa002
200344401QAQ688HXaRT6:<HY0<LY00:7:<LY1bT7:@PaAR3568880`Q224322008`@P100800`P440T
`SDR@HM5bdF[ETiVlW>IOoIof7^ILeMRSTF[;<DTXQbQ44480AAS6:@Q1QcU7<@PiAcV8>HLiQcW7>H0
0R3V00<Q1BD69@H00RD600@U1bD69>HU1P<Y1`8Y1@0:;@@Xa320A:5IIFi;KRU]j6gYKNX2KP/2LR/0
0g8ZLR]b:`02MR`02GH]MRaf;7I<MTifCgI_NVijS@02OX/03WjXO^]o3Wl`Oc5oDgmeOgIoUgniOkYo
^gnlOkd5Omd2OmhJOol027lgLW5VU6[DJ]IZmV[gJ_H4I]H00f;FH]ER]@02GY@3G[D3F[D01eZdEYAF
TeJCEW9FDE9A009>D@03CU9>LTiB00E>DP9><@05DU5JD58`?FXPaP0210000``02208800522002P`Q
344@@AR3;<<e9CeY?FXmRcf<0T6<0195[4F[AJTe9bC556<DHQ11440@@AR36:HDQA1S320HHRC4=DL2
>DP01SDW8:@@80PP468DPP@@PP<@H@D@HP8@PP03464@@11P008@H@03440DPAB200<HX@08484HXRSP
>F=JRV/BKcE[=@Q_=@09KcI_=FleKcE_5FleKcI_=Flf00=_5P03JaI[5F/F009[5@09JcE[=V/fKcI_
=F/eKcE_5FlF009_=@03KaE_56/E00=_5004KcE_56lDKc@5KcD4Kc@00flcKcA_=006KcD4KcH00f/e
KcE_=@06KcD2KcH2KcD4Kc@017<dKcE_=6lc16ld0Vle1Fld00=_<g<cKc<00flc00I_=6lcKcA_<fld
Lc82Ka<4Kc<3Kc@01FlcKcA_4flBKc<00Vlb00=_4FlBKa<00VlC0flD36/C00=[56/CJa@016/C00=Z
lf/CJa@00V/D00AZm6/CJaA[4`IZl`03J_9Zlf[c00=ZlP03J_=ZlV[b009ZlP9Vl@07J_9VlVKbI_9Z
lV[aJ_8016Kb0fKB2fKA00=VlVKBH]400VKA00EVd6J`I[1V/6:`009R/@03H]5R/Eja00IR/@03H[1R
/F:a00=R/@9R/003GZmN/6:_009N/09R[`05H[1N/5j@GY1NS`02HZh7GXh00ej?GY1JT002GY000ej?
FXiNSP02GXh015Z>GXiJSEj<0eY^00YNKUY^FVaJKEY/FVeNKEY_FViFKPEJKP04EVmFCUI^EV`3EVd4
ET`01UI]ETeFCEI<ET]FC0=FC@9FC003ETeFBeI;00=FB`04DTaBBe9;DT/4DT`4DR`2DT/2DR/5CR`0
0dh[CRa>;003CR`5CR/1CRd00004224<8110364234402A11324<81QQ?FEBCV:;FVeJK`02FW0025i`
GY1NTEjAFY5NL5i_GXh5GY000ejAGY1NT@06GY43GY84G[42GY402V:aHY5R/F:aHY1RSfI[HPMMj5g9
0Uh800=N1f87HPL0168800UR:5g5CFE19TeVGNMRBV8XHRT00V8Z00UR:F8ZHRaR:fI<IVaZ[FZ^JZl0
0fZ>011VKVI_HViRCUi=FReIjUg8IRIAYcT4;<=1ZTh_ETiNK`9R/@0>I[9V/fKDJaEVd47<::DD8AQR
9<@mJ58]BNTXa088008@@@06464DHAR26:<LY1c42AbT00DHY1AR320<8@PQ008880<4800L100<8110
9<8i@Th9BPaB36:aMiQongomOomooGnjKaAEk3U9;><LXP`P204@HaRT7>HLaAc48<D77>H01B3V8@HU
1RT79@L00RDX00<Y:2DW:@L00bT700XY1Rd4:<<dPT2QFFE^Bfh9KNQ]j@9^2`04KPa^2W8;LP/2LR`3
MRd3MR/05GH]MTmfL7Y_NVinS7j[OZQnc7l?Oa1o<GlbOeEoMgnGOkYoVGnjOk]o_004Omd3OmhJOol0
1WmILW9VU6[DJ_IZm`=VeP9ReP03I]IReUkF00=N]@9JU@03F[AJ]EZe009F]@05EYEFU59cDW=BDP05
CU43CU82BU802dhbCU9><U8aEU1:<3f;8<H80@@032000PPP00D480PP220880PQ008<@@08444HPRcS
=DHmRCUZ?F/mS0=1S@0HBLe9bSU8:<DDPaR2468<@A11588DYAB4348<81AR9<@aASEW=DL`iB2T5448
00a11Q1R0Q1Q00D@HQ2258<DPa23008@HP03364@HA1Q008@H@04364@PQB25:826<<01a1P6:4T`3UT
DTY[4Vld00=[=@A_=@9_=P07JcI[5FlEKcE_5FleJcH00Vlf0flF00I[5V/EJaI[5F/FJcD3JcH01Fle
JcE_=F/EKaH00Vle0VlE00Q_=FldKcA_=6leKaE_56ld2Fle00=_=6leKcD016le00=_=VleKcH00Vlf
00=c=VlfKcD01Vle0flf16le0Vld00=_=FmELc@00Vld00=_=FldKcD01Vle1fld00M_=FldKc=_<fle
Lc=_4`02Ka@2Kc@01FlcKcE_=6ldKa@00fld0flc16lB0VlC00=[4flCJa<00f/C00=[56/CJa<00f/C
0V[c0f/D0f/C00=[56lDJa<00V[c0V/C0V/D00EZlf[bJ_9ZlV/D00=ZlP9Zl`QZlP=Vl@04I_9ZlV[b
J_82I_44I_85I]800fKAI]9Vd@03I]42I_801VKBH]9RdV;AI]9RdPAVd@04I]1RdF;AH]82H[42H]83
H[4016;AH[5N/V:b0V:a0V:`00ER/F:`G[1N/5ja009N/007H[1N/Ej`G[5NTEj@HZh01ej?00ENSUj?
FXmJT5Z?00=NS`03GXiJSEZ=00EJSP9JKP04GViJKUY^GVh2FVh015Y]EViFKeI_0eI^00IJKUY]EViF
KUI]EV`3EVd3ET`2EVh01EI=EViFKEI[ET`00eI=0UI<00EFCEI;ET]FBeI<009BC@9BC006DT]BC59<
DTeB;Dh]158/0e8[3Dh/0Th[0Dh/0Dh]00005PPQ320@@11P588DPa12220801@P>B=>;6:;FVeJKeY`
GW1NKej>FVmNTEZA0Uj@00ANSej@GY1NT09NT@9NT0MNT@=NTP9N/@9NT@=R/09RT007HXmV[fJ^IVYR
25gXGLT00Uh800=N1f87HPL00V870V8800=N2687HNL00Ug800=R269;HRT00f8Y00mV:F8ZHRaR;6I=
IV]^RfZ<JZiVSFZ>JVeVKFI=HR`00Uh[00]J2eWZGLIV1EG7>@D/`SfYCRmJKEj@009R/@9V/P0>H[=[
56K?ALdTYA0Q568Ta3f9ETe9jBS43488008@@@08464DHAR2688P`aRS7:@HY08LY@<LY0047<@LXabS
56423202224222006`@P220400P0540X`dFUFTQF:U8ZI]1om7ojOomooWooOmUgN6:@AL`e9BBR3208
0A1S6<@LiP057<D27>D37>H28>H012D69@LU1bD70RDW0RTW0bT700TY1Rd4::<`PD20EFI^C6hZKNT0
0Vh:00Y^2Fh:KPY^2g8;LRab;G8^MRef;0=f:P09MR]fCGI`MW1jKgj=OZ]nb7k]009nkP0<Oa1o4Wlf
OgIo]gniOkQo^GnjOkaogGoN0Won0WoN00=kgWooOol067oo00EoF7ZbJ]E^mV[f009VeP07I[IVeVKE
H]IVeF;FG]H00eje0UZe00YJ]5JDEYABUE9dCWABM59cDU9>DP9>D@03CS5>DDiA009>D@9>DP9><P09
BS9B<Dh@EU1:3d6<8:D<0@@000D8800=100880PQ224<@Q11788/hcU6?HTiJSf;?F`00Sf=00E1STG<
BN/eB2S5008HP`0;568<@A11588HY1AS444@@1AQ9<<a9@02=DH01S3T8:@DH@P0220<@@8<@004344<
HQ1R4682488346801PaQ464<H@aP364<H08@H@0>468@PQB15:8HXaRR684HXBSP?JEJJVlaKcA[=09_
=@Q_=P05KcE_5FlEKcE[=P04KcH3KaD3JaH016/EJcI[=Vlf0Vle00=_=6lEKaD00flE1Vle0VlD00=_
=6leKc@00Vld4fle00=_=6leKcD02fle0fld00A_=FldKcA_=0]_=@03KcA_=Fle00=_=@04KcA_<g<b
Ka<3Ka@:Kc@016lcKc9_<VlC0flB0VlC0Vlc1FlC00=[4f/DJa<00V/C00=_4f/CJa<00f/D0f/C0V[c
0f[b1f[c3V[b0V[a0V[b00=VlV[bI_801VKb0fKa1FKB1VKA00=VdVKAH]400VKA00IRdVKBI]5VdF;A
I]06H]401V;BH]5RdF:aH]5R/@9R/P04H[5R/6:`H[02H[42G[4015j`HZmR/6:`0eja0Uj@0V:>0V:?
00ANT5j`G[1NS`MNSP03FXiJSEZ=00EJS@05FXiNKEi]GVeJKP03GVh015Y^FVeJKUY^15I^00=JKUY]
EVd00eY/0UY[00AFK5Y[FVaFC0=FC@04EVeFK5I[ET`3ETd3ET`2ET/3ET`2DT`2DT/3DT`2DRd2DR`5
DR/00dh/DR]>;002CR`00dh[CRa>;003CR`01Dh[CRa>:dh[CP/00Dh=00001`PQ320@@110460<HA1Q
00840005420e8dX<GXaNS`02FW02GW0015i_FW1JTEZA0Uj@00=NSej@GY4035jA0ejB0Uja00=NTF:a
H[000V:`00YR/F:`HXmV[f:=HVYR:Eh9GNUN2@=N209R2003HPMN25h8009N20AR200;GRYR:F8YHRUR
:f8YHRYR:f8/IReVB`02KX/016j^JXmZSfI]0VI=02IRBf8[GR]J2eh9GLMV9U7Y=@DXXCV9CRmFKEj@
H[5R/VKAI[9Vdf/EI[19kRS5548DHbSU>FU>34WX9<@<@PPQ448@HQ1Q568DPQR30QbS00@LY1RT6:DL
Y@8LY08HY0076:<HPQAQ320800PP22400PPP00d480PP2204010P:<==j6[8GZ]FC6KaOmEoo@03Ool0
37onMiYZm57/>DHPXP`P204@HaS47>HLaPDLa@@LiP8PiP038@HU1bD7008U1`03:@PY1bD700<Y1`09
:@D/i2RT;40lP55WJTa^:Vh:009^2`0:KPY]jfgZKP]b2g8]LRab;GH]MR`3MRX027H/MTifL7IaNY1n
SGj/O/T4O^d037k_OcEoMgnhOkMo]WoIOmYog7onOmiooQioo`06OeQj]6kfJ_IVmVKF0f:e00MVeFKf
H]EReUkFG[IN]@04F[D01EJeEYABUE:CDW@00Tic00A>LTiBCU9>DPE>D@9>DP0<BS9><DXbCS5>3eH_
BPlmRb2U100000P01PPP00/8@@PQ448@@1R2;><eASUY>FXmJce/00<mS@0<@H]5bcEY:>DHPaB2468<
@A116:8Ha1B30Q1100XDHBC4=BHiASE6=BDPa1R23208808<@@05320<@0a1468@P`024880111Q368<
HPa110a000L<H0aQ464@PQB15:4HXP027>@01Qc36:8a0D6UGVU_<@=_=@Q_=P03JcI_=Vlf009_=P03
JcI_=Vlf00=_=PA_5PA[5P08JcI[=F/eKcA_=FlEJaE_=@=_=PA_=@9_5@03KcA_=Fle00a_=@03KcI_
=Fle00=_=@9_=003KcE_=6le011_=@=_=0]_=@03KcA_=Fle00A_=@06KcAc<fldKcA_5Fld0Vle0fld
00=_<fldKc@00Vld0flc1flC00=[4flCKa<00flC0V/C00=[56/CJa@00f/C0f/D0f/C00AZlf[bJ_9Z
lPUZl`UZlP=Zl`9ZlP03J_5VlF[b00]VlP05I_5VlVKBI_=VdP09I]43H]44H]800f;AH]1Rd@02H]40
16:aH]5RdV;B1F;A0V:b00ER/F;@H[5R/6;A00=N/@04G[1R/6:`H[03G[400ej@HXmRSP02HXh01V:?
GY1N/Ej`GXmNSP=NS`=NSP05FXiNSUZ>GXiJKP05GVd2GXh00eZ>FVeNKP02FVh00eY]FViJKP03FVh2
EVh2EVd3FV`2FV/01UI/FV]FC5I<FVeJK0=FK@03EV]FC5I=00AFC@=FC004ET]FC58]DRd2DT`3DT/0
0e9<DRe>C@02DR`0258[DRaB;58/DR]>;58[DR`2CR`00dh[CRa>;005CR`2CR/1CP/1CPd00003224<
811000<<@008440<80P0420e8TX;GXaN/0=JL006FVmJL5iaGW5NL5i^0Uj?00=NT5jAGY400ejA00=N
T5jAGY401EjA0ejB0Uja0UjA1F:`00IRSf:>HXeVJf8ZGPX2GPT2GPP00egYGNQMj003HPL00eh8HPMR
1`02HPP00f8YGRUR:002HRT02fHZHRUR:V8ZHRaR;FI:KZY^RVZ<IV`00VI^029VKF9=HT]N:eh/GR]N
2Eg7HPMEjCTU:80eAdX_ETaNKf:`I[5VdFKBI]=Zm6[BBNd/iQQ256<TaCUXCP]9j2ST44<88@8<@P04
464@HQB268827:<26:@27:@02AbS7:@LY1bT7:<HPQAQ32080002224010PP120480PP0P@000T802cR
CPQ^if:ZFTiR[gmfOo/00goo00]ooG]iK]=N:Se5::8@@0P0468HY1c5008LaPDLa@@LiP8PiP038@HU
1RD700DU1`0::@LY1BT5;>DXa31Q>81=Ifi=KT/2KPX016h/KPYYjVgZ0Vh;178<0W8;00Yf:g8ZMRab
CGI`MW9jTGj=OZanb09njP03O/]nkGk_009oMP08Oe9o2gk8O`QoCWmeOkYooQmoo`0:OcEfTVJdJ_EV
eV:eGYARU6:dI]D2I_H01F;EG[EN]EjeG]D00eZe00MF]EJDEY=FTe9cCW=>LP02CU42CS401Th`CS5>
D4iADU1>D@E><@08DRmF;TX>@J/PY@@0000800H8800<224<8@a1540HHBc3=DHiJ3UZ?F/mK3f<0Sf=
00a1[4G;=FTXi1QR564@HPa1464HXQRS588232002aAQ9<@e9CUV>DHeARSU68<<80a034400`a000T<
@@aQ364@H@aR364<@0`P34401@a000<<H11Q46400QB100hLhb457>@L`abR:>11YEI9Kc5_=G=FKcE_
=V/f0Vlf0fle00=[=F/FJcH01flf00=[=VleKcH00flF00Q[5V/EJaI[5V/eJaE_=Fld0Vle0Vlf00=[
=VlfKcH01Fle0Vld00=_=FlEKcD00fle0Vld36le16ld4Fle0fld2Vle16ld1Fle26ld00=_<fldKc<0
0Vlc0Vld0Vlc0Vld1VlC00=[4flCKa800flB00=_4f/CJa<026/C00A_4f/CJa=Zl`9ZlP03J_5[4V/B
009[4`=Zl`]ZlP=Zl`9ZlP05J_5VlFKaI_9ZlP06I_82I_4016KbI_5VdVKA0VKB1VKA00=Vd6KAI]40
0fKA00=RdF;BH]800V;A00AVd6;AH[5Rd@ARdP=Rd@9Rd005H]5R/V:aH/mR[`03H[000ej`H[5R/@02
G[001V:`H[5N/Ej`H[1RS`9RSP07HXeRSUj@G[5N/5j?GXh00Uj?00AN[ej>GXeNS@=NSP04FXeJKUY^
FVh4FXd01ej=FXeNKEi]FViJKEY/00=JK@04FViFKUI^EVh2EVd5FV`00eI/FV]FB`03ET/2EV/8ET`0
1EI;ER]FBeI;ET`00U8]00EBC58/DRaB;58[009B;004CTeB;58/DR/3DR`00e8[CRaB:`04DR/00e8/
CRa>;004CR`2CR/1CP/1CPd0000412488@aQ468236403Q1P464@@AA0<@59jEj<G[1JLEZAFW5JL5i_
FVl2FW0015j?GY1NT5j@0ejA00ANTUZAFY5NT0INT@=NTP=N/P9N/@=R/@9R/004HZmRSVJ=HT/2GPX0
0eh9GNUN2003GPP3HPL015h8HPMR1f870V8800mR:F8XHRUR:FHZHRUR:V8[HRaN36I;JX]ZS6Z=IVd0
0VI^02IRCf9^HTeNCUh/FR]N2UW8GNMAbCe5:60eAdX_FVeNKf:`I[5VdFJaI[9R/FJ_CNd/iQA1448T
aCUXCP]9j2d544<80@`R224@HA1R0QB20QbS0QbT00<HY1bT7:<00QbT00DLa2337:<DPPa100888@<4
8@03120400000084000E:<9B:Vl9HZiB;UY?JaMkVGoMOoik^gLgKaIVT698@DD/XQ11320@HQRT008H
a@<La@039<DLaAc600DLiP8PiP038@HQ1bD700<U208U1`8U1P8Xi@07<:8lXDf8JVi^BfX9JPX00fWZ
00I]jfh;KP]^2g8<LPd3LP`02g8[LRYb;79>LW5fLWZaOZenZgjZO//00Wk/00enjGlbOeEndWIAKJaY
JFg;MTinSGl`OoeooP0NOol01WlFLW9VU6[DI[ARU@9NU005H[EVeF;FH]ER]@03G[D01ekFF]IJeUZe
E[EFU5Ic009BL`03CW=>DTiA00=:<@9><@03CS1:<4ha009><@9><09><@07DS1F;dh_@HXPY@P00000
1@PP00h480PQ224<8@`P564HHBc3<BHiJCV;?F/mRcf<0T6<01Q1[47;=FTXaAQR564@HPa1464HXQS4
588@@@PP440Pa34T>FHiIcDW9<DDH`P0320434401PQ1344<@@aQ368<@@8<808880D<@00@360@HAB1
5:8H`acU7<@DHA1Q9<4mYEI9Ja9_EVlfKcD8KcH2JcH2KcD6KcH2JcH01FlFKaE_5VlFJaD00V/F00A[
=FldKcE_=0A_=@04KcI[=V/fJaH3JcD:KcD2Kc@;KcD016ldKcE_=6ld5Vle00=_=W<fKcD01Vle00=_
=6leKcD01fle00A_=6lDKaA_509_=005Kc=_=6ldKcA_<`04Kc@2KcD00f/dJaA_5002Ka<6Ja<00flC
Ja=[4`09Ja<00flCJa=[4`02Ja@026/CJa9ZlV/BJa=_4f/CJ_83Ja<00f[cJ_9ZlP06J_83J_<2J_84
I_800f[bI_9VlP02I_8016KcI_9VdVKa1FKb0VKB36KA00=RdF;BH]400f;A00=R/F;AH]400V;A0f;B
0f;A0V:a1V:`00=N/6:aG]400UkA00AR/F:`G[1N/09NS`ARSP09GXmN/Ej`G[1N[ej`GY1NSej>009N
S@04GXiNSEZ=FXd3FXl015Z=FXmJSeZ?0UY^15Y]00=JK5Y]FVd00UY]1EI^0UI]00AJK5I]EVeFK@AF
C0=FJ`QFC0AFB`03ETaB;E8]009BC0=B;003DTaB;4i=00IB;004DR]>;4h/CR`3DR/00e8/CRa>;006
CR`1CP/1CPd000<88@0<244<@@a1340<@P`Q420/hT77GX]N[UY`0UYa00IJKei]FTiJKeY`GXl4GY02
GY400ejBGY5NT@08GY44G[4016:aG[5R/F:a1F:`00ERSV:<GTaN:eh9009Mj@AN20=R1`04GPQR2688
HPP5HRT2IRT00fHXHRYR:`02HR`0:fI<IT]ZK6Z<IViVCF8]GPeN;Eh/GTeN:eX;GP]Mb5h8DNTm92QP
>DM:;eY]FViR/6:aI]1V/FJbH[1V[E8=;>H@81128:@eAdg[BNPXi@`R10888`Q2008<H@03488DPQbS
008LX`8HP`0<6:@LXabT7:@LXb33688DPPa2224400@P0P@Q01/480PP100400P09:9B:fl;GY19[Dg>
EU=_FWMiLgU_=VLFJ_EV/697@D@/XA0P320@HQRS6<D01Ac50Qc600<LiQc67>H0123V00DTiRD79@LU
1bD800@U1`0;9>LXiRSU<84hH4UXJTeZ:fWYJPUZ2`02JN/00fh;KPa^2`02LP`07W8=LReb37H;LR]f
:WH[LTefKgIaNY1n[7j[OZUnZWk;Obeo2Gl=O/e^<E3X=6H/0d36D@EQbgZ_OgEooQioo`06O_E^Lf9d
I[AR]6:D0ejD00AN]5jeG[AN]0=N]@9J]@9FU004EY=FLe9cDW82CU800dYBCS5:<@06BS44CS402Th`
CQ1><4h?DRm>;ceX8:@80@001PPP0PPQ00T<8@`P440LPRcS<DHiJCV;>FX013f;01PmRT7;=FXXaAAR
564@HPa1468HXaRT588DHA11564/i34T>FHmR3DV9<D@@PP0320234432446344422001@`P340<@0a0
36000Q1Q010DPQBS6>DLa0a0220T`CV5ETY_4VmFKcE_5FleKcI_=@9_5@A_=@03JcI_=Vlf00A_=PE_
=@A_5@9[5@03JcE_=6ld009_=0=_=@9_=P9[5P9[5@E_=@9_=0A_=@9_=09_5@03KcE_=Vlf00I_=@03
KcA_=Fld00=_=0A_=@04LcEc=7<dLc@PKcD2Kc@2Ka@00flCKc=_=005Kc<2Kc@3KcD00fldKaA_5002
Ka@00f/DKaA_5003Ka@00flCJa=[4`06Ja<2Ka@00flCKa9[4`02Ja<3Ja82J_86J_<00f/BJ_9ZlP0<
J_83I_83J_83I_82I]800fKaI_9VlP02I_4@I]45H]400fKAH]5Rd002H[001F:aH]5RdF;AH[400f:`
0V:_16:`00=N/6:_GZl00Uj_0f:_00=N[f:^HZh016:>00=NSUZ`G[000Uj@00AJT5j@GXmNSPINS@04
FXeNSUj>GXh2FXl015Y_FViJKUY]25Y/00AJKEY^FViJKP9FKP04EVeJK5I]EVd3EVh015I=ETaFBeI[
2EI;00=JBeI:ET/00eI<1E9<00=FBe9;DR`01e8/258[24h/0E8[0Dh<00000`PQ2208800224423440
20PQ100802C3@JQNReZ=EW02FW4025Z@GXmJT5ZAGY1JL5ZAGY02GY42GY800eZBGY9NT@03GY4015ZA
GY9NTUjA0Uja1Ejb0V:a1F:`00ERSV9/GTaN:eW8009Mj0QN20=N2@03HRYR:F8Y009R:@=V:@05IRYR
:f8/HR]VC002IV/05VY]IVeRCEh/FP]EbEGZFP]N:eX/FN]MjF8YFPa1IbQP>DQ>D5Y]FViNT6:a0VJa
011VdV[BJ^mF;BcV644HPb2T<DM=k4WY:>H88`@1228<@P8<HP0458<DPQc47:<37:@00aRT7:@LY002
7:<011c3688DHPa10P@000D88@@Q124480PP0084000K200TXU8/K`eR/DF]AJaFDF]INiUkNGMILeMg
Eg<eJXa5IbR1320801116:<LiR3U8<@TiAcV008La@038>HLiR3V00DPiP039>DQ1R4600<Q1`0:9>LP
ibCV9>HTiBSU:84/84E8IR`2IPX5JP/2KP/03Fh<LPab;G8^MRef;78[MRYf:g8]MTmfL7Z?009nR`0:
OXYnRGj/O`eoB7k>MW9DiR`T8002<8@01CS5B>EUkGj=Om/07Woo00Ene6YCGWAV]6:d009RU0=NU004
G[AN]EjeG[@2G[D2F[D015ZDEYAFTeIc0U9c00ABDTiBBU9:D@Q:<@0?CS5:<4X`BS1:<Dh@BNm:3dX>
?FPPY0@0000400@P0088800;12048@PQ224<8@a1444HPbcT=DHeJP02>H/2?H/2?H`04Cf;@L`eRbC5
544@@@aR344@HQBS6:@DPQ1Q564HPBC2=BD00Sf800<e9bC556800P`P0Pa10`Q100T<@@aQ364<HPa1
120880Q134000P`P00<<@0aP36000Pa000d<H11Q5:<DaAS4564<@23R>HIBBf/BKcE[5@02KaD2KcH5
KaD00fleKcI_=P04KcH01VleKaE_=F/EKcI_=@A_5@9[5@05JcI_=FleKcE_=003KcD01FlfKaI_=W<f
KcH01Vle0fld0fle0Vld0fle0Vlf16le00A_=VleKcE_=@A_=0E_=@Ac=0U_=@03KcI_=Fle019_=@09
KaE_56lDKcAg<g<CKcA_=Fld00A_<`03KcA_=F/e009_=@=_=003KcE_56lD00I_50=[50A[4`9_5003
KcA_4flB00A[4`=ZlPUZl`=ZlP03I_=ZlV[b00IZlPAVlPAZlPMVlP05I]9VlFKbI]5VdP09I]400fKB
I]5Rd@04H]401fKAH]5RdF;AH]1R/F:`00ER/@=R/09R[`AR/003G[1R[f:`00IR/09N/0ANS`03GZmN
/5j_009NT003FY5NT5j?00INSP03GXeNSUj>009NSP03FXmJKeY_009JK`9JKPAJK@04FVaJKEY]EVh2
FVh015Y]EViFKUI^0eI]0eI^00MFCEI<ET]FJeI;FT]JBP02ET/4ET`00eY<ET]FC004ET`4DT`3DT/0
1E9<DRaB;58/DRd00U8/1E8[00=B;58[DR/024h/0E8[0Dh<000010PQ32088@Q10PPQ00T<@@PQ100<
822S@JQJK5Z=EW000UYa00YJT5j>FXmJKeY`FW5JTEj@FY5NL@9NT@9JTP05GY9NTEjAGY1JT@02GY82
GY43G[401EjAG[5N/Ej@GY401F:`00URSV:=GVaN2UW8GNQMieh7GNP015h800=N1eh8GPT00Uh900=R
:V8YHRT00V8Y0fHY00eV:V8:HRYV:VI:IVYVK6Y]IVeVCEh;GPYN;002GT`03eh[FPaIjeW9FNYJ;D5X
:80e9TX^GXeJKejAH[9V/P02I[403f[AK/eF3BcV648DHbC5=DM=k4W[;@L@I0PQ220<HP0246801aB2
688P`abS7:@LYAc5008LY00768<LXb347:<HPQB234400`PQ00@48@@P120880<40008789B;7<?I_=F
<5H_JaIon`=ooP0=OmaonG^IK_55RBR1300800`P6:<LiB3U7<@011c500<LiAcV8>H01B3V00HPiB3V
8@HPib478>L29>H04bD69>HTiBSU:84`H4E8HPaZ:VX[JRYZ2fX:JP]^2VgZKNU^2g8;009b;@0LMRaf
:g8[LRYb:g8/LTifKGZ>NXanS7iZOV]nJWjWOb9n[fgAA8DT0RaT=<@diSBT=:EA1WY^Og@NOol01GjB
IUANM6JDHY@00V:d00=RTejCGY@015jd0ekE00=J]EZDEY@00UIc0U9c00A>DTiACU5:D@A:<@A:<09:
<@0=BS1:44X@BPm5kdG^ANdiIbBT200000@012000`PP00X48@PQ22488@a1444HPRcS=BHiJP8iR`8m
J`0J?F`mS46[AL`eRb36444<80aR344@HARS7<DDPa11420D@1bR<B@mR3eX>BLXaAR3200<808<@@05
244<@0Q1344<H@02368010a1244<@@a110a000@@H0a0340<808<@0095:<HaAS47<@HXRT3>HIBBf/A
009_=@9_5@9_=@03KaE_=Flf009_=@03KcI[=Vle009_=@05KcI_=FlEKaE_=@04KaD00fleKaE_5@04
JaD016leKcA_=6ld0fle16lF00A_5FleKcE_=@=_5004KcE_56/EJaD2Kc@2KcD2Kc@:KcD3Kc@00flc
KcA_=002Kc@IKcD01FldKcE_=FleKc@00fle00=_=6leKa@00VlD1Vld16lc00U_56lEKcE_=6leKcA_
56ldKcD00VlD16/D0f/C00=[56/CJa<01f/C00=_4V/CJa<00V/C00=ZlV/BJ_800V[c0f[b16[c0f[b
00=Vlf[bJ_801V[a0f[b00=VlV[bJ_800V[b00=VlVKBI]800fKb0VKB0fKA00=VdVKAI]400VKA00=V
d6KAI]400VKA0f;A0fKA00ARdFK@I]1Vd0ARd003H[5RdF:a009R/@9Rd003H[1R[f:_00=R/006HZmN
[f:_H[1N/5ja0V:a00AR/5j`GZmN/0ENS`07G[1NSej@GY1NTEj@GXl00ej>0ej=0ej>0Uj=00=JKUY_
FVl00UY_0UY^0eY]0UY/0eY]0UY^00AJKEI^EViFKP9FK@06ETaFKEI]EVeJKEI<1eI;00AFC5I;ETaF
C09F:`AFC0EBC09FB`04ETYBBe8/DT`4DR`0158[CR]B:e8[0U8/00=B:dh[CR`01Dh/0Th[0E8Z0Dh<
000534402P`Q344<@@P0320HXcV7DTeJ[eZA0UYa00IJL5Z?FY1JTEY`FW42FY4015jBGY5NTUib0UZB
00ENTejAGY9NTEZA009NTPENT@9N/@03G[9R/F:a00AR/@07HY1RSVJ=GVeN;5gYGPP00UgX00MN25h7
GPMN1eh8GPMN2003GPT00f8ZHRUR:P03HRX0168[HRUR:V8:0VHZ00AVC6I[IVaVK0AVK@0WIViRKV9^
GRaJ2eW[FLYEjeH^@HTXPBcTAPiNSeY_GY9Re6KBI[9V/F[@J/iB3C48648<@b35=DM5bdG9;BL@I0PQ
444<@A1Q468DPQRS008LX`<LY@8HY@0;7:@LXabS7:<HXaR2468<@@Q122448@02120210002P00100L
XU8/K`i[55jBGY1gVGom0goo00aooWoJOm]ZlDW;:88<80P0320DXaSV7<D27<@37<D27>D57>H28>H3
8>L05b3X8>LPib3W8@HPiRCU:>DXPCB0ADMMjfXYJR]Z2VX;JPYZ2fh:KNU^2Fh/LR`00W8]01ab;78[
LPab2g8<LRabCGI]MVijK7Z<OVanKGi/OZYo0Wi_IBdlA315:8D`iS47=>D`QDC7LRioUAioo`09O[5V
M5YDGWANLf:DGYARTejd009NU09N]003G[ENeU[E00=J]@03EYAFTeIc009BL`03CW=>DTiA009:<@A:
<0=6<003AS5:<DH`00=64009@Nm5kT7=?FTTY0`Q000400@Q0084800322088@PQ00<88@08348HPbC3
<@HiJCV;>F/iK08mJ`0:?Fa1JdG<<H`LaP`02208@Pa146426:<031B2440@810P8<<a93UW?FLe9RSU
68<800<<@@8<@0<<@@8@HP05368<@PaR368<H@0234401A10464<@0a032000Pa000l@PQBT5<@Li23T
;B8eQE9;Ja=_=VleKaE_56lELaD00VlE00A[=VleKcI[5@9[=P=_=P9_=@03KaE[5FlE00A_5@=_=P04
KcE[5F/EJaD5KcD00flEKaI_5P02KaH01FlEKcE_=FleLcD00VlD00E_=FldKcE_=Fld00=_=@9_=003
KaA_=Fle00M_=@A_=09_=@=_=1a_=@03KcA_=Fle009_=@9c=@9_=@=_=003Kc=_=6ld00=_=09_5005
KaE[5FldKcE_=002Ka@00f/DJa=[5004Ja@016/CJaA[4f/D1F/C0f/D0V/C00Q_4f/CJa=[4f/BJ_=[
4f[c1F[b1F[c0VKc0V[c1f[b0fKb00EZlV[cJ_9ZlFKA009VdPEVlP=Vd@03I]9VdFKA00MVd@03H]5R
dV;B00IRd@ERd0=R/@04H[1R/F:aH[42H[001F:_H[1R/6:`HZl00Uj_00=N/6:aH[400eja0ej`00=N
Sf:_GXl015j@0UZ@00=J/EZ@FY000Uj?1Uj>0ej=15Y^00=JKeZ>FXh00UY^0eY]1EY^00=JKEI^EVh0
15I^1EI]0eI<0UI[0UI<0eI=1EI<0U9=1E9<00=F:eI;ET/00U9<00=BCE8/DR`00e8/00I>;4h[CRa>
:dh/CR/7CR`2CR/1DRX1CP`0000?364<@@a1344<8@PQ32488@@0200HPcUWDTeNd5Z@00EJL003FY5N
T5j@009JT@04GY9NTEibGW83GY<2GY8015jaFY5NTUjB1UjA0Uja0f:a0V:b00QN/V:aHXiV[69/GRaN
2Eh80UgY00=N25h7GPL00eh700IN2688HPQR268XHRT2HRX01F8[HRYR:f8YHRX00V8Y00=V:VI<IT/0
0VI/0VY]0VI/02MVKFJ=HVeN;5X;FNYMbUh[GTi5bbR1;>A5k5Y]FTiR/V;DI]9V/V[BJ[1^keX^=DTH
@a138:Da9TG9BNP]1A13220@H@a0444@HAB268800QbS00<LQ1R46:D00QRU00<HY1bS7:800QRS00<H
PQ1134400PPQ00<48@@P120010@000PX`dh:LbeVl5Y_FTe[57^H0Wok00mkVVmIKeQ_=f[AAHP/`Q11
300<81BS6<DLaAcV7>@00QRT00PLaAcU7>DPiB3V7>HLaR360b3V00@Pib3X8>PPj08Pi`0;8@HPiRCU
9>DTPC1P@@EEZF78INUV2@02JPX016h:KPU]j78Y0g8[01eb;7H[LR]b;78;KNYb378]MTafK7iYNVan
K7i]OVanbgkRNVmM2cb6:2<XI333;>Hhi3BV?:QfLGnf01ioo`03O[1RDeie009NM09NL`9NT`05HY=N
TejCGYAN]002G[D01UZeF[AFU5JDEY=FL`9BL`05CW=>LTYACS5:<003BRl00dH`AQ164002AQ43AQ02
APl03D7_BPm5kCf98:@80000200480PP120880@Q00<88@07348@@QR39<<]1CUY>H/00SU[0Se[00hm
K3eZAL/eS23730488@aS348@@1R16:<DHP`P0Q1000/P`bdT>FHiASDU:>DHP`a0444<@0a1008<@08<
@@04340@HA1Q36833643344734002a1Q588DXaS39@8Y03V5DT][<fmFKcD00VlE0VlD0VlE00=[5Fle
KcD01Flf16le6VlE16le00=_=6leKcD016le0Vld0W<C0Vld1Vle0fld2Fle0Vld5fle0fld1Vle16ld
0Vlc00A_=6leKcE_=0E_5006JaA_56lDKaA[4flC0flD2f/C00M[56/CJa=[4flCKa9[4P02Ja<00f/B
J_=Zl`04J_<2J_85J_<00f[bJ_=Zl`02J_<2J_8016[cJ_9ZlV[b16Kb0VKa0fKA00IZlVKcI_9VdVKa
I_8>I]4016KBH]9VdVKB0fKA0V;A26;@16:a00=R/6:_H[000f:`0V:_00=R/6:aG[401Eja00AN/6:^
GXmNT0ANS`03GY1NSej`009NT0ANS`9NSPINS@03FXeJKUY^009JSP9JKP9JK@03FViJKEY^00=JKP04
FVeJK5I]FVd4EVh01EI]EVaFK5I/EVd00UI<00AFKEI[EV]FC0=FC@AFC0AFC@=FC09F:`03ET]BBe9;
009BC003CTeB;58/00=B;003CRa>:e8[00AB:`E>;09>:`5>:P5B:P5>3@0000<<H@a134800P`Q00d8
@@`Q100400P06:<iIdi=F]5JSeY_FW1JT@03FY02GY02FY42GY400eYbGY9NT`02GY<2GY8015jAFY5N
TUjB1EjA0Uja00=N/V:aH[400V:a00MR/UjbH[9R[fJ/HVaN;003GPT00egYGPQN1`04GPL2GPP2HPP2
HRP00f8YHRYR:`06HRX00f8[ITaVB`02IVd00fZ=JVeZSP02IV`08F9<GRaN2eX;FNYIjEhZGTe5bRbR
<>E5c5X]FTmNTF:bI]9V/FKAJ]1^l5i_=DXH@a138:@a1DFXDPTe9QAT324DH@0346401AB2688HPabS
7:@011bU00<LaAbS7:<00QRS00<DPPa122000`PQ020880@P10040000100LXTFXIZaNS5H/FTeJKf/E
MeM_F6KgI]EN/UZADN`i12bR444800`P688HY1S57>HLiAc40Qc500@LiAcV7>HLiP<LaP8PiP8Ti`07
9@PPj23X8>LQ1RD68>H00RCU00TPPRaP@BIAZVGYINQV2VX:JPT00Vh:015^:g8ZLR]bBg8/LRYf:W8[
LRab2g7[LRebCGI<NVanRWi/009nKP0?OVenZWl3OVmU/4CY;4@P0BR4:<H`YB@0B<IjT7ok01ioo`07
O]9RE5YDGW=JDUibGW<00UjC0V:C00ENTejdG[AJU5ZC009J]@03EYAFTeIc00=BL`09CW=>LTiBBS5:
<4X@AS16;dH`009640964@03AQ163d7_00=1k`07APm5kSUY78@4000022000`@P0P@Q0`PQ00T<@P`R
58<Ta345=FTiRcUZ>F/00ce[00dmJT7;=F`Paa13224<H`a2340HPR35568<@002440021c4<DHiIcUW
=DHXiAR3320234000`a1364<H@0236400`a1464<HP03344236433445340030`P460@HABR6:8PhRSP
>HEBK6LCKeI[=@=_5@04KaA_5FlEJaD2KcD00flfJcI[=P02KcH2KcD00flfKcE_5@0AKaD3KcD00flF
KaE_5@02KaH9KcD4Kc@2La<00flCKaA_=@0AKcD2Kc@GKcD4Kc@00fleKcA_=@06KcD01W<dKcA_=6ld
KaE[5@9_=0Q_5004Ka=_56lDKa<3Ja<00f/DJa=[4`05Ja<00f/DJa=[4`06Ja<016/BJa=[4f/C46[c
0f[b1fKb1FKa0VKb00=VdVKaI_803fKA0VKB00MRdFKBI]5VdF;AH]1Rd@02H[45H]04H[45H[03HZl0
0f:`G[5N/@06G[42G[000ej@GXmNS`04GXl00eZ@GY1JT004GXl2GXh015j=GXiNKEi]0Uj=00ANSUZ?
FXmJSPAJKP03FVeJKUY]009JKP9FKP04EVeJK5I]EVd5EVh2EVd00eI/EVeFC002ET`2EV/2ET`9ETd4
ET`2ER/015I;DTaBBe9<0Ti<00A>;58/DRaB;0=>;0EB:`=>;0EB:`5B2P5>3@0000<<@A1134400P`Q
00<88@a032400PP000PDHSE5CTaNd5j_GViNKeY_0eZ?0UY_00AJL5j@GY1NT09JT@07FY9NTUjBGY5N
TUjAFY400ejA0Uja0ejA0Uja00iNTF:AHY5RTF:bG[9R/V:_IZeRK5h[GPUN25h90Uh815h70f870f88
00UR:68YHRUR:V99HRYR:F8ZHRT00V8Z00=RBfI/IVd00VI]03AZKFY/IXYRBf8/GRaN2eX:FLUIb5h8
ER]5Z33R;>A5cEY@FRmNT6:aI[5V/6J_J/m^kei_=DXH@QAS88<a1D66CNHeAQR5448DHQ1R464@HQB2
688HPab37:@HYAc66:@DHARS7:<HX`8HY005588@@@P022088@05220210006A10>B=9jEY;FTaNT5jA
I_A[=F/GI]INTUY>AL/eAbc2784@@0P0320HPQBS6:@LaAc400LLa@<LaP098>HPiBCV9>HU1bCX9>LT
iR3V00<Ti@078>DTPSB1ADMMbVH9IPX00fX900=^2Vh[KR/00g9;00Ab:g8ZLRYb:`9b3004LRab;GI=
MT`2NV`2NVh047Y]OVanRWl5O[1^<Ud[A>LhYSB3=6@/0Sb3HLUo<Gom7Woo00=n/EhcES800UYA00AN
LEibGY=NT`9N/`03G[AN/ejC00=JT`=FL`08DW=BLU9cDW=>LdibBU9:<@A64004AS16448@@Q03@Nl0
2d7^@Nm1kT7>@Ne1cCf87:D80@0022001@@P02H880PQ224<@@PQ548Pa2dV=FPiRSV9>FXiJce[?H]1
RT6[<F/TaaAS324@Ha1R464HPQbS568@HPa0440LY2dV=DLiIcE6:>DHP`PP10a01@aQ00<<@Pa13440
1`a10Pa000@<80a0220@@08@H008580PhBSP=F=BK6LCKeI_=@I_5@05JaE_=FleKcE[=P02KcH2KcD3
KcH00fleKaE_5@03KaD00fleKaE_5@06KaD6KcD2KaH00flEKaI_5P06KcD3Kc@00flcKcA_=004Kc@=
KcD016ldKcE_=Fle0VlD0Vld1Vle00=_=6leKcD02Fle00=_=6leKc@00Vle00M_=6lcKcA_<flCKcA_
=@03Kc@2KcD2KaD2Kc@2Ka@016/EKcA_=6lC0VlD00E[4flDKaA_56/C00A_4`=[4P9[4`06J_=[4f/C
Ja=_56lC0V/C0f[c0V/C00I_4f/CKa9[4V[bJa<3J_<8J_85J_<016[bI_9VlVKb0VKa0fKb0fKa4fKA
00=Vd6KAI]400fKA00ARdFKBI]5Vd09Rd003H]5R/F:a00ERd007H[1R/F:aH[5R/6:_H[000f:_00AR
/6:_H[1R[`EN/@04G[1NT5j_G[06GXl00ej>GXmNS`05GY02GXh015j=GXiNKUi^0Uj=00ENS5Z=FXeJ
SeY_00=JKP03FVeJKUY/009JK@9FKP05EVeJK5Y/FVaFK@04EVh2ET`00eI;EV]FJ`06ET/015I<ETeF
CEI=0UI<0UI=15I<0UI;00AF:eI;ETaFB`9BB`03CTaBBe8/009B;09>;09B:`04CR]B:e8[DR/3CR`2
DR/014h[DR]>2e890E8<00001@a0440@@0a132400Pa100`<80P0100@HCDTCTaNcej`GViNKeY`FVl2
FY001UZAFW1JL5Y`GY1JT@=JTP05GY9NTEjAGY5NT004GY43G[401UjAG[9NTEjaGY5R/@9RT@08H[9N
/f:bHY1V[V9]GTaN:PIN20=N1`9N2004GPUR2F89HRP2HRT3HRX3HRT2HRX01V8[IT]VK6I]IXiVK@9V
K00AHTaR;5h]GReJ35h:GNQN9e8:AJPe0bcTBNiJD5H_GY1R/@02I[003fKAJ_9^l5Y>=DXPI1QS768a
1466BNLeAaR5448<@@0346801AAR58<HPaRT7:@00QRU00<HQ1RT6:@00aRT00<DPaB234400`PP00<4
8@PP22000PPP01L800@0420/X4FXFTYRSf:aI]=Zm6lFKcM_5V:bERi5c3E9<BHTXa0P200<81R2008H
Y08La@036<DLaAc6008La@078<DLaAc57<DLaQcV8>H00RCV0RCW00dPibCV8>HTiR3U9>DLaRB2>:55
AV7ZINUZ2P02JPT2JPX016h:KRa^C6i<178[00Ib;78]LRab;W9>MTd2MVd04gY]NVijKWi]OV]nRGk9
O/mfLGZAKPmQAe2T@25<PfVZOZeongon01ioo`04OY5N<eHbGW42GW801EYcFYANU5jDG[@00Uje00UJ
TeZDFY=JM5IcDU=BLU9BCU800dic00=>DTXbAQ400dH@00A63d8@@Q123`=1k`03?NlmcSg>008mc@07
@Ne1cCf87:D80@0022000`@P00D880@P12488@`P008<8@08568LY2dV<FLiZcEY>FXiJ`8mS00A@H`m
Rc5;9<L@H`a146<@@A1Q588HPaB3468@@@a06:@Y1P02<DH02CE6:@HHY0PP340<@@a0440<H@063684
34400`aQ344<@@02344010a0220<80`P0Q100Q1P00DL`BCQ=FI>CFLB009_=@03KcI_5FlE009_5@03
JaE[5V/F009[=P09JcM_=VlfKaE_5VlEKcI_=F/E00E_5@03KcE_5Fle00=_5@03JaE_5FlE009_5@9_
=@9_5@06KaI[5VlEKaE_5VlE0Vld16le00=_=6lDKcD00fle0Vld2Vle0fld00E_=FldKcE_=6le009_
5@03KcA_=Fle00=_=@03LcA_=Vle00U_=@=_=003KcE_=6ld00=_=003KcEc=6le00Q_=@=_=09_5003
JaE[56/D00I_50=[4`9_4`E[4`07KcA[=6/BJa=[5F/DKa<00V/C0f[c00AZlV/CKaA[4`9ZlPEZl`AZ
lPEZl`03J_9Zlf[b009Zl`04I_9VdVKBI_42I_83I_<00fKbI]9Vd@02I]400fKBI]5Vd@05I]43I]83
I]4016KBI]5VdFKA0V;A0fKA00=RdV;AH]400f;A0V:a1F;@16:a1F:`1F:_15ja1Ej`1Uj@00=NSeZ?
GY001EZ@00=NSej>GXh00ej>0ej=0UZ=00AJSeY^GVeJK@9JKP04FVmJKUY^EVd3EVh3FVd3EVh015I]
EViFKUI=0UI<0eI;0eI[00AFBeI<ETeBC@=FC09FC@04ETiBCE9=DT`4ET`0159<DR]>;59<0Ti<00=>
CDh]DRd014h/00A>:e8[DR]B;0A>;0=>:`5B:`5B2@5>300000@@H110440<@08<@@0>324<80`P320H
PSDSCTaJ[EZ=FViNKeY_FW1JT@INT004GY5JTEZAFY44GY400ej@G[1NT002GY03GY401EjaG[9N/Eja
GY400f:A00QR/F:bH[9RTF:>GVeRBehX2Uh800ER25h9HPUR2F8X009R:@=R:P08IRUR:F8YHRUR:V9;
IT]VK09VS003JXaVK6I<009RC@9N;@0MFRaJ2UWXHRIJ2DFW=></i4G<GU1JCej@HY1V/6JaI]9ZlVlA
GThiJb24548HHS44@HM9j3U76:D<@P023442468258<00aRT7:@LY0026:@00aR468DDY@026:@011RS
58<DHPa11`PP0PP001X40110>B5>2VK=J/mNT6:aI]=[5FlfJaAR/UYaFU59kSf:<><@@@`0320DPQBT
6<@HaAc50aS500PLYAc57<DLaQc56:DLaAc60R3U0RCV0RD60bCV00XPiBCU9>DXXSRPBFIMbFGXINMU
j09Z2@9Z2P9^2P05KRY^:fh/LR]b;002LRd01g8/LTibCWI<MT]fK7Y[009jK@0BOVanRgj:OZ]nc7k/
O^inl7ZDKO9YSVhAOXmo:GoIOoeogWon77oo00AnSehcFS5RL@9NLP04FY=JLeYcFW<2FY@00eZeF[AJ
U002FY@01eIcDW=BLU9BCU9:DTha009:<@03BQ5644H@00964003APm23d8?00=1kP03?NhmcSg=00<m
c@07@Ne1c3eW8:@80@@022001P@P01D880a0340@@QAR8<@]9SV7>JTiRCf:?H`iJceZ?H`iRcE[9<HD
Ha1134400Q1100THPARS58<@HPa1444LY2CU<BD00SE600PY1QRT444@@A1Q340<HA1Q0PaR00@<HA1R
488<H@8<@003244<@@a100@<@@05340880a0340<H@0234002@PP580ThSV8DVeW4FleKcA_=@05KaD2
JaH00f/fJaI[5P02KcH2KaH00flEKcE_=@02KcD5KaD00flDKaE_5@07KaD01fleKaE_56lEKaI_5Fld
00E_=@9_=09_=@03KcA_56le00U_=@9_=0M_<`=_=003Kc=_=6ld009_=0=_=@9_=0Y_=@I_=0=_<`9_
=0Y_=@9_=003KcE_=6lD00M_509_4`=[4`=_4`E[4`05Ka=[4VlBJ_5Zl`0:Ja<5J_<2Ja<01F[cJ_9Z
lf[cJ_801F[c16[b00IZlfKcI_=VlV[aI_42I_82I_<2I_85I]400fKbI_5Vl@02I]45I]83I]42I]84
I]400fK@I]5Rd@02H]400f;BI]9RdP02H]42H]03H[05H[42H[06HZl00f:`G[5N/@02G[45G[03GY02
GY401Uj@GXmNSej?GY1NS`=NT004GXmNSUj>GXh3GXd4FXd01UZ>FXeJKEY]FViJSP9JK`03EViFKEY]
00=JK@03FTeJKEY]009JK@03FVaFKEI^009FC@03ETaFJeI[00EFJ`03ETaFBeI=00=FC09FC@0:ETiB
CE9=ETaB;E8/ERaFCE9<DT/4DT`014i<DRaB;58/0Th/00EB:e9;DR]B:e8/00=>;0EB:`5B2@5>3000
00<@H11044000`a10Q110Q1000XLXcDSCR]FSUI/FVeJKUY_GY1JT@ANT003FY5NTEZA00IJT@03GY5J
T5j`00=NT09NT@08G[5N/UjbG[9N/EjAGY9RTP=R/P06HY9RTF:?HXmNC5gW2Eh815h900AR:V8XHRUR
:@=R:P07HRUV:F8YIRYR:f9;IT/00VI/01EZSFY/ITYVC68/FPYJ2eX[FP]J2UWYGRMF2DVW<<4/a46:
FTeJCUi`HY400fJa015VdVlBGW0mS21U328LPc45@JM9j3UX7:H<@@`Q468@HA1R008DP`0368<HY1RT
00DHY@<HY00458<DHPa23442224522006@P0100DH464J/acE6KAFW1FCejBI]A_5VKDGY9JTVKdI[1>
3CCU54880@`Q58<DY1RT00HHa@<La@037>DLaAc500<PiP059>HU1RD69@HTi@039>H022CU:@D/XSc1
BDEIQfG8HNP2INX2JPX01fX9JPY^2Vh:KRY^2fhZ009b;00:LReb;78]LTifC7I;MVajJgY/NV/3OX`0
3gj[OZankGmBOc=nlWjcO[9ndgldOi=o^GnkOmeogP0LOol01gjbGSAF<UiaGW9JLeYd009JL`06EW9F
LeZDF[EJ]5Ze0UZD00=FLe9cDW800TiB00E:DTXaBS5:<4X@00=640=24003@Nlmkcg>00@mcP0;?Ldm
c3g^@Ni1c3UW9:@8000010048@05120222004``P444DHQRS8>D]1BdU<BHiJ3f:>FXiBCV;>FXeJbC5
68@@@Pa1008@@@0=584HXaB346<8810Q7:@Y1S57=DHaAbD66:@00a1Q0Q1R00<@H@aR36800PaR00T<
H@a1344<H@QQ344<H@a136400Pa10`a00`aQ00/<@0P0340ThcEWDVeW4FmEJcA[=F/E009_509_5@03
JaE[=V/f00E_=P03JaI_=F/f009[=@03KcE_5FlE00=_5@9_50M_5@07JaE_5FlEKaE_=VlFKaD026le
16ld36le0Vld0W<c0flc0fld00=_<fldKcD01Fle00=_=6leKcD00Vle00=_=VleKcD016le00Ac=7<c
La=c4`E_=0e_=@E_=003KcE_5FlE00=_509_4`9[4`U[509[4`03Ka=[4f/D00A[4`03JaA[4f/C00=[
4`AZl`03Ja=Zlf[b00EZlPEZl`EZlP9Vl`04I_9VlFKaI_42I_83I_<01VKbI]9ZlV[BI_5VlP9Vl@9V
d@IVdP=Vd@9VdPIVd@03H]5RdV;B009RdP9Rd@9R/@04H[1Vd6:`H]44H[44H[000f:_H[1R[`04H[00
25jaG[1N/5j`G[5NTEjaG[02GY02GY400ej@GXmNT002GY05GXl2GY0015j?GXiJSUZ=1EZ?0UZ>00=J
SEZ>FVl00UY_00EJKUY]FVeJKEI=00=JC@05FVeJK5Y/FVaFK@03ETd015I<EV]FJeI[1EI<00=FBeI<
ET`015I=00=BCU9=DTd00U9=0e8]00=FC59;DT`00U9<0Ti<0Ti=0Th]0Th/0e8[00EB;4h/CRa>;58/
009B:`03CR]B:e8:005B30000Q1P018@@0a1344<@A1Q568<80@0540a0TX:FXeNSEY]GViJKej@FY02
GY0015Y_GY1JTEjA15ZA15jA00=NT5j`GY000Uj@00QN/EjAG[5N/UjAG[9N/EjA0ejB00]R/V:BHY5R
T6:_HY1NC5WWGNMN25h700IN20=N2@ER:@=R:P9R:@06IRUV:V8[IR]VBVI;0VI[01IVBVI9HRUN2EW8
FNUN2UX:FNYEjEGWFPU9acCR::<mREY<FTeNL6:BI[9V/@9Vd@0BK_9RL46;88D@8ab3<@A1QdWW?HPL
Y@a2220<@A1Q468DHQB30QR30QRT1ARU00HHY1bT58<DPa1R3482224222006P@P220880P0100DH465
LbacE6:aFPe=cEiAH]=VeEjBFTmNT6kbL^iF3CD644880@PQ58<36:@011S46<DHYABT0ac400DLaAcU
7>DLaB35008PiP049>HU1RT59@H29>D29>H29>D02RbR>8198eF6ILMUjFG[INYUjFGZ0VWY00IZ2FX:
KPY^2VhZKR/4LR/0278/LTafC7I/NV]jJWiXOXX2OX/2OZ/03Wj/O^io3gl@O/mn[Gk_Oe=oU7nGOkYo
_7oMOmhKOol01WkHFSAF<F:@GY9JLP9FDP9FD@05EW9JTeZCEW9FL`02FW<00eJCDW=BLP02CU800dYA
BS5:4004AQ001TH?@Q11l47_?Nlmc`DmcP0;@Ni1kD7^@LdmZceW8:@80@0022048@06120222022000
2@`P464DHQR37:@Xa34V=DPiR@02>H/05SEY;>DHY1AS344<8110584DPQAR448<8A0P7:<Y1RdW=DLe
ART67:@@@AAQ0a1R00<<HPaQ36400PaR00D<@@PQ344<H@a100@<H@05368<H@a1240<@00236402`aR
344400a09><eQdh[I`m_EF/dJa@01FlD0Vld0fle0Vlf0Vle0Vlf0V/e0fle00=[5FleKaD00flD00A_
5FleKaE_5@E[5@04KaE_5VlFKcD2Kc@2KcD2KaD4Ka@00g<cKcA_=002Kc@6KcD01VlEKaA_56lcKcAc
<`Q_<`A_=0=_=@03KcA_=Fle009_=@03KcI_=Fle009_=@03KcA_=Fle00Q_=003KcE_=6le00U_=@05
KcA_<flcKc=_=002KcD2KaD2Kc@3Ka<2Ja<;Ja@6Ja<00flCJa=Zl`02J_<2Ja<3J_<00f[bJ_=ZlP0@
J_83I]83I_400fKbJ_9VlP02I_82I_401F[AI]5VdFKbI_400VKA00=VdVKAI]8016KB1FKA00=V/FKA
I]400fK@0V;A0V;B00ERdF:aH[5R/F;A00AVd004IZmR/6:aH[42H[03HZl00f:`HZmN[`02HZh01V:_
H[1N/5j@G[1N/@9NT@9NT09N/0=NT0=NS`=NSP9NS`9NT004GXmNSUZ>FXd5FXl025Z=FVeJSEY^FVmJ
KUY]FVh2FVd2FV`4FTd01EY<ETaFC5I<EVd00UI=00AFC5I[EV]FJ`9FC003EVeFC5I<009FB`03ER]F
C5I<00AFC@06ETiBCE9=ETiB;E9<0U9;0U9<0Ti<0Th/0dh]00=>C4h/DR/01dh/00EB;4h[CP]>2e8Z
005B3000018@HA11344<@@a2344@H@a1200400`P:@=5jEj=HZiNKEj?GY02FY03FVl025j@FY5NTEjA
FY5NTEZAGY42GY85GY4015jaG[9NTEjb15jA00eN/EjBGY9N/ejbGY9RTV:AI[1RT5i=GPQR1`08GPP2
GPT00eh:HRYR:P02HRX00f8YHRYR:P04HRX01F8/HR]V:fI:IT`00VI;01EVBVI9ITYR:Uh8GPYN:eh:
FNYEjEGXFPUAj3T3988mJF9/GViNLEjbI[800fKB00aZdF:B@H`TQA12668/iCf8ANTmRAc532022200
1a1Q468@HQB368<HXaRT008HQ0@HY@087<DHXaB358<@H`a2224880@48@0E100800P05411Yf/=LeIJ
CdUY@FU=beiaFY=B44V8DNYV/7;aFP``iA0R00880004568DY1RT6:@46<D01QS47<DLaAc57>DLiP8L
a@047<HLiR3V8@H29@H042CU9>HTiRCV9>DTiRR2=81595F7ILQV2V7[INYUj6GY0VWY00AZ2FX:JPY^
2P9^;09^:`03KPY^:g8[009bC006MT]jBgY[OVUjJgY/0gj<00=nZgj]O//00gj]00MnkGlbOe5oMGnI
Okao_@02OmhJOol037lJFQAJ<UiaFW5FD58`DS5BDEIAEW9FL@=FLP9JLP04FY=BTdicCU82BS800dH`
AQ564003AO000dH@@O11k`02?Nl00cg??LhmcP03?Lh2@Nh023g=@LdmZcf87:D80@@02207120010PP
100000@00`PP0P@001/<81AS9<HaB3V[?JXiJBd568@@@Pa1324@@AR1588DHa12444@81bS:BL]9c4W
=DLY1QbT58<01A1R0PaR00D<H@aR344<@@aQ00<<@@04368@HPaQ344224400`Q0344<H@03368020@0
320ThcV5DR][46mEKc@2Ka@3KaD016leJcE_=F/E0VlE00A_5VlfKcE_=PE_=@=_=P9_5@05KaA_5FlD
KaE_=@0;JcD5KcD00f/EKaE_5002Ka@3Kc@2KcD00flfKcE_=@04KcD00gLdKaA_=007Kc@00flcKcA_
=00<KcD00flfKcE_=@0<KcD00fldKcE_=@0:KcD016ldKc=_<flc0VlD1Fle00E_=6lCKa=[56/C009[
50=[5@03JaA[5F/D00=[50I[4`06Ja9Zlf[cJaA[4f/D0V/C0f[c00A[4f[cJ_=Zl`IZlP03I_9ZlV[b
00EZlP9ZdP04I_9VlFKaI_45I_82I_400fKAI]9VdP03I_800fKAI]9VdP05I]83I]400fKBI_=Vl`02
I]82H]400fK@I]5Vd@03H]43H[44H]400fK@IZmR/002H[4016:`H[5R/F:`0Uj`1F:_00EN/Ej`G[1N
/5ja009NT@9NT0EN[`05GY1NSej?GXiJS`02GY001ej?GY1NT5j?GXiJKUZ=00=JS`03FVmJSUY]009J
K@9JKP9FKP07FViJKEY]FVaJKEY/FVd00UY=00=JC5I<ET`00UI]00AFCEI^EVeFJ`9FC0AFC@04ETaF
BeI<ET/2ER/015I<ETeFCEI<0U9=0e8]00=BC59;DT/00U9<00=>C4h/CR`044h/0Th;0E8:0Dh=0000
0`aQ344<@@0334402`aQ444880P0340Y0dG8FTeR[5i/GXh00Uj?0Ui_0UY_15j@00=JTEjAGY400UjA
00=NTUjAGY4015jA1Ujb00=N/EjbG[800Ujb00UR/UjbHY5RTF:`HY1NCEhZHRL025h80Uh900=N2V8[
HR/00V8Z00AR:F8ZHRUR:PER:`0XIR]VBVI<ITaVJfIZITYVBfI:IT]RC5h[FPUIjEGZFNQN:Uh8>B@T
PSf8HV]NKUiaH[5VdV[CI]9Z/FkaHY8mS2B4748H@C3U>FQ5bCUX8<D232001`a0444@HA1R588HPQRS
008HY00468@DQ1AT58@268@01AbS6:@DPa1S34800PPP10@Q0PP001<40110?HMVkVLEES0e:BcVBHYF
;Dh>AHa5JE7[I[9ble7<<>HD@P0220001AB258<HXaRT6:D00QS50QS400<HY1c56<D00ac500DHaAc5
7>HPiQcV008Pi@HTi@0;988dH43TEHMUafH;HLYUjFGWILMUj002JNT5JPX02Fh:KRY^:VhZLRYb:g9<
MT]fBP02NTT05WY[OVYjJgj<OZin[7j]OXanZgjYO/Yo3Gl_Oe5oE7nHOi]o_7nmOmeogWon67oo00Mn
n5HEEQ9NCeI?ERiB;`02DS000e9@EU5FL003EW4025YaEW5FTTicCU9:<DXAAQ42AQ001T8@@O15l47`
@Q11l091k`DmcP91kP0:?Li1cT7=@Le1c3UX7<D80@@02207120300001Pa17<@LiAB220000084000I
324PY358>HTaJ2C5568@@Q1R324@HAR16:<@Ha12544@81bS:@HeJ357>DLY1Qc458<00Q1R00<<H@aR
36400PaQ0PaR0PaQ10a100<<@0a1344010Q100h<H@aR368<H`aR220<82CS>HA>2V/@KeA_=6lD16lE
00A[5F/eJaE[5@A_5@I_=@04JcE[=V/EJaD5KaD4JaD3JcD2KcD00fldJcA_=006KcD4KaD016lDKc=_
=6ld0Vle00=_=VleKcH00flf1Fle1Vld00=c<fldKc@016ld1Fle00E_=6leKcE_=Vld01M_=@A_=0=_
<`Q_509_4`9_509[50I[5@03JaA[4f/C00A[4`07Ka=_4VlBJ_9Zlf/CKa<016/C1F[c2f[b00AZlf[b
J_9Zl@9Zd@9Vl@9ZlPQVl@05I_9VlfKcI_=VlP02I_42I]43I]84I]45I]82I]43I]0016KAH]5Rd6K@
0V;A0f:a00ARdFJ_IZmR[`=R/09R/@03H[1R[f:_00AR[`03H[1N/5j`00=N/0=NT004GXmN[Uj_GZh2
GXh3GXl00ej>GXmNS`05GXl2GXh00ej=FViJK`02FVl01EZ>FXeJKEY]FVh00UY_0UY^1UY/0UY<00=J
BeY[FV/01EI]00=FK5I]EVh015I=00=FC5I;ET/015I;00=BBeI<ET`015H/0U9<1U9;00=>;58[DR/0
1E8[2Dh/0dh;0Dh=00001@Q1224<@@a136400PaR00T<H@a0200<81bR@JMJCEj<FVd00Uj?0ei_0UY_
15j@15jA0ejB1EjA00=N/UjaG[800Ujb00=NTEjaG[401Ejb0V:a00ART6:bGTmN:`=N2003GPUN25h8
00=N209N2@03GPYR:f8[00AR:P03HRUR:V8Z009R:`04HRaR:f9;HT/2IT`05FI/IV]VK6I[IVeVBf8[
GPYJ2EWZENYJ25h9FPPmIRB3>FQJC5Y^FW1R/@02I]803VJcI[5_4V:b?H/TPbAQ864/iCE6@JTiZBC5
420232001A10444@HAAR58800QRS0QR30aB400THQ1R36:<HPaB2468<@@@022000PPQ0P@Q01P880@0
100<83E5GZiNdU8`AHY1JE8=H[5NTUiaHY9ZdgMGL_=Ik3CV424<00P068826:<26:@011RU5:DHYAS4
0aS500TLaAc67<HLaQS67<HLiR3V9>D00R3U0RCU00/U1BT59>DPPbaQ><==Ieg6IRYQjVG800=Uj003
INUUjVX:00AZ2P04JP]^:fh[KR/2LP/00g8ZLR]f:@02NRT01GY;NTajJgZ>NZl00Wj]0Wj<00enZWk[
O`eo3Wm@OgAoMgnIOiYo^gnmOmiooP0HOol02GkhEOAAdEH=EPaB;U8_CRmB<002DU003EI@FU1FLEIa
EW9FLEIbCW=:<TXAAQ124D8@00=1l0924091l0A1k`91kP0=@NdmkT7^@Ni1cT7=ANe1cCV:7<H80@00
10001P@P1000024La47W>NXPiR2T7:DLYQb5404@@R35=FLaJ235568@@Q1R444@HAB168<DHa12440@
81R29>HaAcE7<BH]1QbT44400Pa100D@H@aQ344<@@aQ00@<HP03364<@0a000<8@088@@0?22088@Q1
364<HPaS38@@P``P340ThcV5DT]W46mE009_=@A_5@05JaE[=F/eJcE[5@02KaD2KaH5KcD2JcD4JaD2
KaD5JaD2JcD4KcD00f/eKcA_=@05KcD4KaD00flDKa=_=005KcD5KcH9KcD4Kc@016leKcA_=6ld1Fle
00E_=6leKcE_=Vld00]_=@04LcEc=7<dLc@2Kc@8KcD2Kc@3Kc<3Ka@2KaD00flDKa=_4`05Ka@6JaD2
Ja@6Ja<2Ka<01VlBK_9Zlf/CKaA[509Zl`9[4`03J_9Zlf[c00=Zl`9ZlP03J_5Zlf[b009ZlP03J_=Z
lV[c009ZlPAVl@AZlP9VlP03I_5VlVKb009Vl@9VlP9Vl`04I_9VlFKAI]45I]800fKAI]9Vd@04I]80
0f;BI]5Vd@02I]001FKAH]5VdF;AI]000f:a0f;A00=R/FJ_HZl00f:`0V:a00=R/6:_HZl00f:_00=R
/5j`GY000Uj@00=N/5j@GY000ej@0Uj_00=N[Uj_GXl00ej?00=NSUj?GXl01Ej?0Uj>00=NSEj>GVl0
0UY_00EJSUZ=FXeJKEY^009JK`9JKPMJK006ETaJJeY/FV]JKEY/0eI]00AFK5I]ETaFC@9FCP9FC@9F
C0=FB`05ETaFBeI;ET]FC002ER/00eH/DTeBC004DT/2DR/00dh/DR]B:`03DR/00e9;DR]>;00:CR`1
CP/1CPd0000A24488@a0340<H@aR468@HA1P220<81R1?FEJCF:=FVeNSP04GVl3FVl01ei_GW1NT5jA
GY1JTEjA009NTPENT@03GY1N/Eja009N/@03G[9NTEjA009NT@=R/@07G[5R/6:aH[5NTUi?GP/00Uh8
00=N1eh8GPP01Eh800=R268ZHRX00f8Z00AR:F8XHRMR:09R:P09HRaR:f8ZHR]RBfI<IVeVK6IZ009V
BP=R:P0UGPUJ2EG9ENUN1eh8ENPmIRB2=BIJ:UY/FViRT6J`I[9V/fJaKa5Vd4F[::8THB1Q<<@eAT79
?L/PaA0P300800a0440@@AAR58800QRS0QR300@HQ1B458@HQ08HP`05688DPQ1R3404000322021203
10005``P>D=R[6LCFY5F;Uj@JaIoVGniOmYoUWnfOiUgEV8=>@HD@@`0200HPQRS7<@00QRS00<DY1BU
6:D00QRT00<Ha1S57<D011S500@HaQc57<DLa@<Pi@0@9>DTi2ST9<DTPbb2?<==AFGVIRUQbF78HLMQ
j6GWINP2INT3JPT00fX;JR]^:`02KR/03Vh:LPUb:GHZMRMf:WXZNTYjBgY<NVejSGj;OXd2OX`03GjY
O^Yo2gl;OdmoM7meOgMoNGnKOkao_GoN01Qoo`04O_MEldf`EPd2ERd01E8^CPe>3Th>DRl00UI?00YF
L5IaEW5BLE9bCU9:<DX@APm23`A1k`924091l0A1k`91kP07ANa1cD7]@Ni5kT7=BNd00T7=00DPa`P2
000400@P008880<480840080000?8>A:9SW6<DL]1SE9?Hde:QQU42<LY3E5>HTTiQAR008<808@@00?
684DPQB3444<810P688La2ST<BDeART57:@@@@a0008<H@8<@@03364@H@aR008@HP05368<H@aP3408
@00222004@PQ22088@PQ244<H@aR4:@@Q11S220<@2CS=FABCFLAKc@00fle0flE16/E0flE00=_5VlE
JaD00fle0f/d00=_=6/EKa@00flD00=_5FlDJa@00V/D00=[5FleJcD00Vle00=[5F/eKc@00Vld1Fle
00I_5F/EKaE[4flcKc@;KcD3Kc@00fleLcAc=002Kc@2Kc<00fldKc=_=003Kc@4KcD2Kc@3KcD2Kc@0
0fleKcA_=@08KcD3Kc@017<cKcA_=6ld0Vle00=_=6leKcD00fld0flc0VlD00E_=6lEKaE_56lC00A_
5003Ka=_56lD009[5@E[50I[4`04Ka=_4V[bJ_82J_<7Ja<5J_<2J_800f[aJ_9ZlP08J_800fKaJ_9Z
lP04J_82I_87I_400fKbI_=VdP09I]402FKBI]5VdVKBH]5VdV;BH]5V/003I]0016KAI]1RdFK@0f:a
0f;A00AR/F:_HZmR[`9R/09R/@03H[1R[f:_00AR[`9N[`03GXmN[ej`00ANT005GXmNSUj?GXiN[`02
GXl6GXh3GXl01Uj>GXeNSEj=GXiNK`9JK`07FXiJSEY]FVeJKUY_FVh00eY]15Y/00=JKEY/FV`00eY/
0UY;0UI;00EFJeI;ET]FBeI=009FCP9FC@9FC003EV]FBeI;00EFB`06ETaF:eI<ETaBC58/0U9;00EF
:e8[DR]>;59;00MB:`Q>;09B:`5B2`5>3@000108@@PQ340<@0a246<@HQ1Q444880`P7:4iI5Y=HXeJ
KPEJK`=JL005GW1NLEj@FY5NT002GY43GY83GY401UjBG[9N/UjaG[9N/@=N/P03G[5NTV:A00ER/@04
HY5NTEi?GPX2GPP00f87GPQN2005GPP00f88HRYR:P04HRX00f8XHRMR:@05HRX0268[HRaVC6I<IVaV
JfI;HTX2HRX00ehZGRUJ:P02FNT075WWENQEj3e6968e15H:FTaJKej@H[5V/VJcI]9ZlFJ_BN`/`b10
764`i3eWANXmbb35320800`P0Pa000D@@AAR588HXabS008HP`@DQ0075:@HXaB36:<@HPa132000PPQ
00l880@P22040000100@@3TQIZ][<ejbGY1VdgNJOod00goo00UooGoJMgMN3CCU768<00P068800Qc4
00LLaARS6:@DYARU6:@LY0027<D011S56:DDYABU0QS511c500dLiB3U8>DTiBST9>DTPbQR?<AAA6WU
HPQMb002HLP00f79HNQQj@04INT04fX:JP]Z:fX[KR]^2fh:LNUb2GHZMRMf:GHZNRYjBgI<MVejKWZ=
009jSP03OXin[Gk>009nk00;Oc5oEGmDOeIoN7miOi]o_7oMOmiooP0FOol00gjbEM9=[`03ERd02e8=
CPi>3eH_DS1F;eI@EW5FLU9bDW400TiA00=:<DX@APl01D7_0T8@0T7`0d7_00A23dH?APm63P=1kP09
@Nm1cDG^ANhm[1c6104000P000848006220480@P120400@P0P0000lDXc67>LP]9bdV<FTe[3E:7:D@
8QR2=BDeAbCU44400PP00Q10014HPARS58<@HP`P420HPQc4;>@a1CE6:@HLY111344<HPaQ00<<@@04
364<HPaR3682364020a0320<@0PP24088@Q11242224030a0364<HPb348<880a07:<eIdX]I_5[4`9_
4`A_5@A[5@=_5@05KcI[5V/EKcE[=P06JcD2Ka@00f[cKaA_5@02Ka@2Ja@016/EKcE[=F/e0flf36le
00=_=6leKcD01Vle00=_=VleKcD00Vle0Vld00I_=FldLcAc=G<cKc<3Kc@=KcD016ldLcEc=7<d1Fle
00A_=6leKcEg=09c5004KcE_<fldKc@8KcD00fldKc=_=002Kc@6Ka@01F/CKaA_56lDKa<00VlD0V/D
00A[5F/DJaE[5@A[5005Ja=_4VlCKa9[4`03J_<6Ja<00f[cJ_9Zl`02J_@2J_<5J_800fKbJ_9ZlP05
J_82I_4016KbJ_9VlFKa0fKb0VKa0VKA00=VlFKbI_400fKB00AVdFKBI]9VdPEVd@03I]9VdFKA00=V
dP03H]9RdFKA009Vd@=Vd003H]5R/F:a009R/@9Rd@9R/@9R/003HZmR/6:`009R/@=R/004G[1R/6:`
H[04G[05GY04GXl2GY001UZ@GXmJSUj>GXmNSP9NS`03FXmNSej>00=NS@06GXiJKUY^FVmJSUY]0UY^
0eY_00=JKUY]FV`015Y/0eY]0eY/0UY<00AFC5I;EVaJJ`9FB`03ETeFCUI>009FC@9FC0MFB`9FC09F
;09B;@08DTaBBe9;ET]F:e9;CTaBB`IB:`U>;09>:`5B2`5>3@0000D8@@PP34088@PR008<@P0;344@
@0P0320PXSUTFTeR[5Y^FW1NT@04GY0015i`GW5NLEia15j@0ejA00=NTUjAGY800UjB00ANTEjbG[9N
/PAN/@06GY5RTF:AH[5R/6:a0VJa00ARTF:BGTmN2P9R2003HRMN1eh7009N1`=N209R20=R:@9R:P04
HRUV9V8XHRT3HRX01f8YHRYR:fH[IT]VJfI:009RB`07HTYR:UhYGRQN:EX9FNT00eGX00m1IbRS<>=A
jEY;GViNT6JbI[=Ve6KCJ_9RSTG;:<<00Qa100h/a3U6BNU1bbC5320400a0440<@11R568DPQR20aR3
0QR40QB400PDY1RT6:@HXa1R344<80PQ0PPP00l480PP10040000440e05j:IbmNd5I;I_9o^GomOoh0
0Woo00]ooWnjLcE=bSCT544<00P0588La1S3008HX`056:@HYARU6:@HX`026:@36:D26<D04ART7<@H
Y1RU7:@L`ac48>DTiBd49>DTY32S?<==@f73HNP0167800MQbF7YINQUjFGXINUZ2P03JR/3KPT2LNL0
1789LPYf:WHY0WHZ0WI<00EfKWY_NVmjKWZ?009n[`0=O/]nkGl`Oc=oDgmEOeIoN7miOi]o_7oMOoh0
5Woo011nTEFaDNmJ;58<CNa9kDG<@Ha1cDH?DTmFLEZBDW9FL@9BD006BU1>DDX_APm5kd7_0d7^0T7_
0T7`0T7_00A5kT7^ANi5kP91kP91cP0:@Ni1cDG]ANhaBB36104000P012032202120050@0220400@Q
468HY23V9@HTiBSV;BL]1QbT300@82SS<BHXiA10100232005110684La1B2564<@110680Ti2d5<@Da
9BCV6:@@@11R368<@Pa1364634400`a0220880032203224212001@PP364@HA1Q58400Pa000HP`cEX
BRiRd6/CKa82Ka<00flDKaE[5@05JaD5KcD00flEKcE_=@03KcD2KcH00fleKaE_5004Ka@2Ja@2JaD0
1F/eKcE_=V/fJcD05Vle00I_=VleKcE_=FldKcD2Kc@2KcD3Kc@9KcD00fldKcE_=@08KcD00fldKcE_
=@04KcD017<eKaA_=Fle0fld1fle00=_=6lcKc<00fld1flD00=_4flDKa@00flC0V/C00=[56/EJaD0
0V/E0V/D0V/C00=_4VlCKa<01F/C1F[c0V[b00AZlf[dJ_=ZlPEZl`MZlP9Zl@EZlP=Zl@QVl@03I]9V
dFKB00AVdPUVd@9VdP06H]9RdFJaI[5V/6K?0VK@00=RdF:aH[401f:a00=R/6:_H[001F:`00AN/F:`
H[1R/0AN/0INT09NSP09GXmN[ej?GY1JT5j@FXiNSUZ>00ANT003GXmNSUj=009NS@08GVeJKUY^GXiJ
KUZ=FXiJKP=JK`04FViJKEY]FV`3GV`6FV`2FT`015I<FV]JK5Y[0UI;00EFC5I=ETeFCEI<00IFB`EF
C09F;09B;@03DRaB:e8[00=FB`04DTaFBU9:DRX4DR/7CR`2CR/00e8[DP]B:`01CPd000888@042408
8@PQ224222002@a0220881c3>D=JC5j<FXmJL002FY03GY000ei`GW5NL@0:GY42GY85G[82G[42GY40
1F:aHY9RTF:aH[000fJa00ARTFJbHViN:`=R2004HPMN1eh7GPL2GPP2HPP4HRT2HRX016H[IRUV:F8Y
0f8Z00UR:F8ZHRYV:f9;HTaR:V8[GRX00ehY029J:EX9FNYEjUGYFPYAj4F8<<@e0dgYETaJKej@I[5V
/VKDI]=^lf:aAL/Xa1a1644TPcDUANU1bbcU300400P0440<@@8DHP03688HXaR3008HP`0458@HQ1B4
58@25:@011B45:<@P`a20PPQ0PPP00<480PP22000P0000T@833PDTUW<5Z=CPUNdW_jOod00goo00]o
g7nJIXi5J332548@8@`Q588HaAc4008HX`0358@DY1BT008HY08LY0037<DLaQS500<Ha@@HY00;7<<L
a2359>DY12CU8:@`a3B2CDAQa003HNP3HLP01V79HNQUj6GYIPYZ2@9Z:`06KR]^2Vh:KPY]jG7X0g89
01Yf:WHYMRUfBWI<MVifKgI`NVmjSgZ@O[1n[7k_Oa1o<GlAOc=o=7mFOgMoVWnkOkeogGon5Goo00an
U5WBEO1J:eH<BN`mJS47;<D]1cV/BPl2EW401e9bEU5F<59ACU9>DDX`00963`07@Ni1cSg>?Li1kT7_
@O000T7_00E5kd7^@NhmcCf[0091c@91cP8mc@08APi1kSEY9<H80P00100480<880<4800<220800@0
340@H@a0320@HQR47:@PiAB30P`001/PXcDV:>H@@@P0324<8110684Ha1B2464@@1AQ684T`bcU<BHa
AR476:@<80a1348<HPa236400Pa100X<H@a1344<@@a02208@@a1320<8@<88@0C100480`P360@HAAQ
5848811P9@@aJ4i>I_1_<g<dKcA_56/EKcD00f/f0f/e0f/f00=_=FlfKaD01VlE00Q_5VlEKaE_56lE
KaA_=6lD0V/D16/e1F/f2fle0Vld16le0flf00E_=FlfKcE_=Fld00M_=@03KcA_=Fle01A_=@9_509_
=0E_=@05Kc=_=6ldKcA_5@05KcD3Kc<3Kc@3Ka@2KaD00fleKaA_5002Ja@00flDKa=_4`02Ja<2Ja@3
JaD2Ja@00f[dJ_=[4P02Ka<5Ja<2J_<3J_82J_<3J_@6J_<7J_82J_45J_82J_4016[bI_5ZlV[b1FKa
00=VlVKAI]8016KB00=VdFKBI]401FKA0fKB00ERdV;AI[5V/FJ`00=Vd005H]5R/F:aH[5Rd@06H[47
H[0015jaH[1R/6:`0ej`1Uj@00=NSej@GXl00ej?0UZ@1EZ?0eZ@00ANT5j?GXeNS@INK@03FXeJSUZ>
00=JK`9JKP9JK@03GVaJJeY[00MJK004FTaJK5Y/EVd2ET`00eI[ETaFC@02ETd3ET/00eI:ET]FB`04
ET/2ET`015H]DReB;E8]0e8/00AB:e9;DT]BB`IB:`M>;006DR]>;4h/DR]B2e8:0Dh=000010PQ2208
80@P0PPP00/480PP220800@0564e8dh/GXaN/5Z?009NS`=NT09NL0QNT09NT@9NTP03GY5N/UjA009N
T@05G[5NT5j@GY1NT@02HY42H[402F:`H[5V/FJAI[5RTF9^HRYR:@03HPL00f86GPIR1P02HPL00eh8
HPQR:@02HRT00f8XHRYV:P02HRT00fHZHRUR:@03HRT01F8XHPQN2Eh:GPT00UX900=N2EX9FPT00UX9
0UX:00]F2UG[FP]EjDV8<<<e14WXETaJKf:A009V/@0BI[9VdflCI_=9k2c5644D@BB3<@E5b3g:;@D<
80@0200@@1110QAQ00<HPQR368<00QR300<HQ1R358@011B400<DPa1S34400PPP00<88@PP12000PPP
0P@000T<82bQBNIR[UY:CLUNTGNkOoh00goo019ooFlEGRTdhbB1668@8A1158<DYART58@HY1B458<H
Y1RU6:@27:@37<D26:D04QRT6:<@HQB46:@LXabT8<DPiBCT9>DPXbbS=8==AF75HNQMi`9Qa`0=GLQQ
b678HNMUj6GYIPYZ2FX:KRY^2Vh9KNX00VgX00Eaj789LPUb2G8Z009f:@04MTYfBgI]MVh2MVl01WI`
NY1n[gj]O/enk`9nkP07O_1o4WldOgEoNGnJOk`00WoM00=ooWooOol04Woo00eneUWBCJiF2dW/@HTa
1BS4:<HTaS4X@La:;`02DW403EIADS1><DXaCS1:;dX?APm5kT7^?Le1cT7^00=1k`91kP=1k@91c@0=
@Ne1cCg=?Ldmc4G]@NdiRRC6228000@012000`PP0`@001X480@0100400PP34040000200HPbCU688@
81007:<]1b35444<8P`Q444DH1R16<<DPQ100QAP00THPB2S<@De9bdW9@LHY@`Q340010a10PaQ00<<
@@a034001@a000D<@@`Q22488@Q10088808<@00=460@HA1Q220<@2D3<FQ>CVKaKa=c=6ldKa@00V/E
00A[=FleKcE_=@9[=@=[=P03KcE[5FlE00Q_5@03JaE_56lD00=_50A[=09[5@04JcE_=F/fJcD2JaD0
16leKcA_=6ld4Vle00=_5FldKcD01Vle0fld0fle0Vld1Fle16ld0Vle00I[=FleKcE_56[bKa<2Kc<5
KcD2Kc<016lCKaA_=6ld16le00E_4flcKc=c<flD009_=005KaA_4flDKaE_=@02Ka@00f/DKaA_4`02
Ka<2Ja<6Ja@2J_@00f[cJa9[4P04Ja800f[cJ_9ZlP04J_82J_<2J_@3J_<016[bJ_=Zlf[c1f[b0V[a
1F[b0f[a0VKa0V[a16Ka00AVlVKaI]5Vd@=VdP03I]5VdVKA00IVd@9VdP04H]9V/FJaI[42I[02I]00
16;AH[5R/F:`1f:a16:`0f:_16:`0ej@00=NSej@GY001Ej@00=NSej_GZh00Uj@00=JT5j@FY0015Z?
0UZ@00=NT5Z>GXd01Ei]0Ui/00INSEZ=FXeJKEY^FVl2FVh2FVd00ei/FV]JJ`08FV`2FV/01EI]ETaF
C5I[ET`00UI=00EFC5I;ET]FBeI:00MFB`04ETaFCEI>DRd2DT`2DR`;DR/3CR`00dh[CRaB:`03CR`2
CR/1DRX1DR`00005244880PP10048002224020@Q12000000220a8dh;GX/3GXh01Uj?GY1NT5j@GW1N
T@UNT003GY5NTUZB009JT@ANT@9NT004GY5N/EjAGY45H[401V:AH[1RT69^HR]N20AR1`06GPMN1Uh7
HPMN26880f8Y00=R:68ZHRT00V8Y00=V:V8YHRX00f8Y00QV268XGPYN2EX:FPUN2Uh90UX901MJ:UX:
EPYF2UH;DN]=jUGWBHP`Y33TBNUFKEY`HY5VdFJbI[=Zdf/DJaE:3BS4008D@P089:<]146W@L/XiAAQ
320<@@8@@@05564HHAbR8:@HX`0268<01QR46:@DY1B458DDQ08DP`06468<@@P022088@PP0P@P0`@0
01H<02BQ@F=>;4WZ?FQF;V/FOkYooG_lOoegVUi_BL//X1QQ444<8@P0568DY0@DQ08HY0046:DHY1RT
6:@27:D05ac66:DHYA23464@HQ1S468DPQbT7<DPiBCU8>DLXbbT=:A99Eg6HNUQj678GLP00Ug900EQ
b67WHNUUjFH9009Z2`09JPYYjVWYKNQ]jFgXKNUb2G8:00=b:P03MTYfC7I]009fKP9fT005LVmjT7Z@
OZen[`04O_002GlAOc=oE7mhOiYoVgnlOmeooP0DOol03WjeEK99SUH;ANdmJ334:<DTYR2U:<DiRd8@
CU43DU4014haBS5:<4H@1DH?0d7_0T8?0T7^00=1kD7^@Nd00T7^00a1kCg=?Ldm[Cg<@Ne1kSf[:@P8
8`@0200912004PP0100<81B37<@@HP@0564Pa1RS564@01bS:BPLY@a120088@8@@@0=584HXaB1440D
@110684T`c4U<BL]9b486:@00``P00<<@0aQ36400PaR00@<@@a0340<@0H<@@D8@@03344<@11P00<@
H@07460Phc67CTiRlFldKcD016/E1V/e0f/f0V/F1flE00=[5F/FJcD00V/e0fle0f/e0f/E0f/e00A[
5V/eKcE_=@=_=0=_=@04KcA_=FldKc@>KcD00flfKcE_=@04KcD00fldKcE_=@02KcD2Kc@00fleKcA_
=@02KcD00flEKcE_=@05KcD00f/EKcA_=003Kc<00fldKcE_=@02KcD01FlcKaA_56lDKc@01Fle00E_
=6/CJ_5_4flD00=_=0I_5005JaA_56lDKaA[4`02Ja@00f/EJaA[5002Ja@2JaD01F[dJa=[4f/CJa80
0V/C00A[56/CJ_9ZlP=Zl`03J_9Zlf[c00=Zm003J_=Zm6[c00=Zl`QZlP05I_5VlVKbI_9Vl`03J_<0
1V[bI_=Zlf[BJ]5Vl@9Vd@04I_5VlVKbI_82I]83I]400fKBI]5VdP05I]82H]800f;AH[5V/@02I[42
I]400f:aH[1R/@07H[400f:`H[5R/003H[03HZl3G[42GY02G[000ej_GY1NT005GY03GZl2GY001eZ@
GY1JT5Z@FXmJSUZ?009JT09JS`03FXiNSUi]00=NK@9NK09NS@03GVeJKUY^00=JKP9JK@03GVaJJeY/
00QJK09JJ`04EVeFC5I<EV/6ET`2ET/00eI<ET]F:`04ET/015I<DTeB;E8]0U9<0U9;00=B:e8/DR`0
0Th/00=BC58[DR`00U8/14h/00E>:dh/CRa>;4h]00=>;05B:P5>30000`PP00<480@Q12400P@000X8
80@P100<@3DTCP]RRUj;GXeNSQ1NT0INT@09GY1NTEj@GY1R/5jaGY5R/F:`00AR/@06HY1RSf:?HVeR
:V8W0V8700MN1egWGNMMieh7HPMN2002HPP0168XHRUR:68X0V8Y0VHY168Y00YV:6H7HRQR:UhZFPUI
jEX9GRYN:@9N:P0XGRUJ:EXYFPUEjUH9FNI9Qc35;>=9jEZ=FW5NT6JaI[9V/fKCJ_ARldh=;>@PHQQR
9:<a9D6W@N/]1AAR320<@A11464DHAQQ7:8P`abS68<758@01AB368@@HQ1120001@PP0PP000X4010P
784e0CUW>DLiB4F;GW1[509[=P0@H_=VdEG[<>@TH1R1564<80P0464HYABT58@@HaB46:@26:D01QRT
7:<LY1bT7:DHY@8HYP0456<DPAB368@244400aRT7<DLi@029>@04BBT::<dPdT4GLIQjFH8HLQMbEg:
GLUQb67WHNQUj6H9INX00fWY00E]j6gYKNQ]jG88009b2P=b:`0<MTYfBgI]MVifSGJ@MY5fT7Z@OZmn
[Wk@17k`00UnlGlBOa1o<glfOeUoNWnkOoh057oo00en]EWCBJmF;4H>?HT/aBBU9:HPI2S6>H]:D@05
CU400dXaAS164004APl00dG^@Nm1kP0:@Nh00d7]@Ldm[@02?Jd01cg=@LdmbbD834@400PP00P48088
800T200@@B3U9@DDHP`R568HHAR3440@82CU=DTLaA12100<@A11440DHARS588DH10P320LPRS4<@@a
9S58:@PHY0`P200881100`aQ0Pa100<<@0a134400`a11@a00`Q10Pa10Q1Q00T@HQB2464P`SEUCTaV
lFleJaD016lD0Vld1Vle00=_=VlFKaH02FlE00=[5FleJcH00fle0f/e0V/E00I[56/EJaE[5F/fJcD5
Kc@EKcD00flfKcE_=@05KcD3Kc@00fleKcA_=004KcD00fldKaE_5@08KcD016ldKc=_=6ld16lc00=_
=6lCKa@00VlD00=_=6leKcD00fle00=_=6lDKa@026lD00=_4flDKa@00V/D0f/C00=[56lDJa@00V/D
00A_56/DJaE[5@9[50=[4`=Zl`=ZlP=Zl`03J_9Zlf[d00=Zm09Zl`03J_9Zlf[b00UZlP03J_5ZlVKb
009Vl`IVdPEVd@03I_5VdFKA00AVd@06I]1VdFKAI]5VdVKb0fKB16;B00=RdFKAI]400VJa0f:a00=R
/6:aH]4016:a2F:`00AR[ejaG[5N/@9N/004H[1N/5j_GZl5GY000ej?GZiN[`03GY02GXl2GY0015Z>
GXeNSUj?0eZ?00=JSUj>GXd00ei]1Ui/15Y]0UY/0UY[2EY/0UY;0UI;0eI[0UI;00AJBeY:ET]FB`EF
C0=FB`EFC004ER]FBe8[ER/2DR/00e8/DT]B;004DR`01U8]CRe>;4h[DRY>:`E>;05>:`5B:@5>3000
0`PP01048@Q124888@@03408@@@0320]14X;HZYRRUj=GXmNL0INT003GY5NT5j@00ENT003GY5NT5jA
00INT@07GY1NTEjAG[5NTF:aH[000f:a00YRTF:@H[1RSf9^HT]R:F88HPMN1`=Mi`0:GNQR1eh8HPQR
:688HRUR:688HRP6HRT03FI:IRUV1fHYGR]N2U7:BJYAbeG[ENYIjUX9009N:@AJ2@0RGPI9QbbU;<A5
jUY^FU1NLF:aI[9V/fKDI_ENm58^=@HTPab39:@a1Cg8?L/aAQ1110088@a0464DHAQQ8:8P`abS68<2
58<658@01AR3568@@@P032001@PP0PP001D@81QP;>8eACU6?HU5REH;FTiJCeH^FW1F3D5Z:88D@22R
688D@@`P56800QB30aBT0QRT00HHYART7:<LXac47<D26:D02aR568<HXb3V7<HDHQ116:DLaR3V9>D0
0RC400PTPc23C@AMYUgYHNQMb5g90Ug:0V7Y0VH900EV2VGXJNUYj6WY00A]j@03KPQb2W8;009b:`0>
LT]fBgI<MVifKgJ?MY1fTGZaO[1n[gj^O_9nd0Enl@07O`mo4WlDOcMo>GnKOoh057oo00ineUFcBK1B
3DH>?J/`iRRU98@XaS48?Le6DDiA0TiB00E:LdYBBU96<4H@00963`923`03ANi1kT7^00A1kP05@Le1
kD8?@Pi1kP02@Ld2?Jd3>J`01Sg<>JXLi`PS000400848@D4800D100880`P220<@1B27:<DHQ1158<H
PaAQ300DHRd6;BPLY@`P200<@@8@@@0>564HXaR2564@80`0684PXc44;@D]9bT76:@<80880003460<
@0a100@<@@03368<H@a1008<@@033408@0Q0008<@0032448@0Q0008<@003464@HQ22008DPP058:8e
HdX/H_5[=@02Ja@5Ka@2KaD2KcD2KaD3KaH9KaD00fleJaE[=@06JcD6JaD01V/FJcI_=FldKaA_=1=_
=@A_=PM_=@=_=0M_=@03KcA_5Fle00Q_=@03KcA_<flc00E_<`A_=003KaA_=6le00A_=@E_=09_5003
KcEc=Fle00=_5003JaE[56/D00=[4`03JaA[5F/E009[5004Ja=[56lDKa@2Ka<4Ja<8J_<00f[bJ_=Z
l`03J_@4J_<:J_800f[aJ_9VlP03I_<016KBI]=VdfKC1FKB00=VlVKaI]400fKA00=VdVKAI]800fKA
16KB1F;B00ARdF;BI]5V/@=R/@04H]5Rd6;AH]42H[400f:bH[5R/@04H[001f;@H[1R/6:aH[1N/Ej`
00=N/@9N/003GZmN/5j@00ANT09NS`=NT0=NS`9NT003GXmNSEj>00AJS`04FXiJKUj=GXd4GVd3GV`0
1Ui]FVeJKEY/FVeJK0EJK@03FVaJKEY/00MJK@07FV]FK5I[EV]FBeY;FTX00UI;0UI<00=FCEI<ETd0
0eI;1UI<00=FBeH[DR/00e8[1e8/0Th]00=>;58[DRX00U8[00IB;4h/CRa>:e8[DRT1DR`000<8800A
244<@@aS344880a0244400P09:=5jF:9GXQRSEj>GW1JL006GY000ej?GY1NT007GY06GY4015j@GY5N
TEja1F:`0V:a00mRT6:`HXmRKF9;GRUR2687GPMMieW8GLMMj687GPP00f8800AR:F8XHRUV:09V9`9R
:@09HRYR:F8YIRQV1f8XHRYIjDV900<mJ003@HU=ZEGY009J2@0=FNUIjUGYENMN1DV7<<D/`dG9DReF
CUjAH[800V:c01QVe6KeH_I>;S45864LHQaS<@A1Yd7[=DD@HP@0224<@111564HHAbR8:<LXaR25882
58<258@258<26:<011B2444<80`P1@PP00X<80@0420HH2c3>DE5bEH:GTQJ;09F;@0@GW1NLUX`AJdX
PaQ07:4HPQAR344@HQ2358<DPQBS6:@26:D00aRT6:<L``027:<26:@05QB46:@HXac39@HPaQ12424H
YAc68>LTiBC59:@XPcARB@=IQEgXIPMQiegX0UgY0f7Y00AR2VH:IPQYj09Yj@9]j@A^2@=b:P06LR]f
BgI;MVafKWJ?0WZ?00Aj/7j_OZmn[P=nd00;O_1nlGkaO_5nkWkaO_1o5WkhOgUog@0DOol01gjgEK=5
Sdg]ANi1bcU9008a2004=BTm[4H>CU02CS4014iBCWA:DTXa0dH@0dH?0dG^0T7^00E1cT7=@La1k3g]
0091k@0=@Le1c3f]?J`i[3V<>H/mZcF97>L88P0010000P@Q1@@P00D400PP340<80PP008<@@0<320D
HARS688@@1118:@a9C4W7:@<80PP0Pa101<@@AAR6:<HXQAP440<01A08:8`hc44;@HY1aRT320800PP
440<@0033642344236401A11364<@@a022000`a000<8@@a024000Pa000T@HA1R488DPQB18:4eHDX:
I_000Vld00=_4flDKa@01FlD00A_5FldKcE_=@E_5@=_=@05KaE_=FlEKaE_=@06JaD00fleJaE[5002
JaD2JcD016/EJcE[=Fle0fld0VlD00M_=6leKaE[5FlELcE_=@02Kc@8KcD4KcH5KcD00fldKcE_=002
Kc@00fleKcA_=003Kc@01VleKcA_=FldKcE_=0E_=@03KcA_<flc00]_<`05KcA_=FleKcE_=003Ka@0
0flCKaA_5006Ka@00flCKaA_5002Ja@3Ja<00f/DJaE[5@02Ja@016/CJaA[4f/C0VlB26/C00=[4V[b
J_8016[b0f[c46[b0fKb0VKc0fKC0VKB16Kb00=VlFKAI]400VKA00=VdVKAI]400fKA00AVdVKAI]9V
dP=RdP06I]5RdF;AH]5Vd6KA0V:a0V;A0f;@00=RdF:aH[800V:a16:`0V;@1f:`0ej`00EN[ej`GZmN
[ej`009NS`9NSP=NS`03GXiNSej?009NT003GXmNSEj>00AJS`03FViJSUj=00ENK@ANK003FTaJKEY/
009JK09JK@9JKP09FVeJC5Y/FVaFKEI<FVaJKEY/009JC003FV]FJeI[009FB`9JBP9FB`08ETaFBeI<
ETaFBeI<ET]F:`=BC09F;003ET]F:eHZ009F:`QB:`06DRa>;Dh]CRa>:e8Z0U8[0dh[00=B:e8ZDRT0
0E8/00001@Q0220<80a124400`a100/8@0Q120080222@LUNRV:ZHXiNKUi`009JL0iNT0YNT@9N/@MR
/@04H[1RSf9]HR/2GPT2GPP3GNP2GPP2GPT5HRX2HRT0168XHRUR:V8[0V8Z00mV:VH9HRUN:eh9ELY=
RDEXAHQAZUX9FRUN:EWYFNX00UGZ00YEj5h7BJPdiBR1@HUFCUY_GY5N/P9R/`0?I]ARmElGCRla1b12
524HHS45AJQ1bSUV568800PQ008@@@8DH@04784LPQR3440658<268<00aR2568@@@02320040PP2248
80@0200<80@0300DH2S3?FINBfK=J^mZdFKB0V[B00i^m6kBENd`aQQ0784HPQAR3248@A2358<DPQBS
0aRT00<La1S57<@00QbT1ART01<LiAcV6:@@8A116:DHYQc68<DTaBBS:88`HDT3EHEQj6HWHPMMj003
GNX4HP/01FH9INYYjVWZJNT00Vh916h:00Ub2g8ZLR]b:gI;MVafKWJ?NY000WZ`1Gj_0Wk@0gka00Qn
l7kbO_9ne7kgOeUo_7oN4goo00MnfEFc@Fi9kDH>@Ne1[@02?H`0146]@Nm>;diA0TXa00A:DTYdAS96
<@=640963`07ANm63TH>APi1kd7^@Lh01Cg=00i1kT7]@LdmcCf]?J`iS3f/>FTeJ1cV328000@00`@Q
00<480@Q12400`@0028<80aP468DPaBS6:@HXaR458<DHQAS9<DiJ3eY;>HD@@a1368<@@a0564HXaRR
464@@0`P544PXcD3<@@a1S4W6:<<80888004460<H@aQ3643344010aR468@HA1Q0`a00`a10Pa000H8
@0a0344<H@aR488256401RC2>F9>2VK`KeEcE@9_509[5@03KcE_56lE009_5@9_=@E_5@03KaI_=Vlf
009_5@05KcE_5FlDKaE[5@03JaH4JaD00fldJcE[5@05JcD3Jc@016/eKcE_5FlD0Vle00=[5FlEKcD0
1fle00A_=VleKcE_=@=_=PU_=@9_=0]_=@06KcA_=FleKcE_=6le0Vld00=_<fldKc@00fld0flc00=_
=6lcKc@016le0Vld1VlD00=[4flDKa@01FlD0V/D00A[4f/DJaA[5@I[50=[4`03Ka9Zlf/C009[4`06
Ka=[4f/CJa=[4V[c1V[b0V[c46[b0VKb0fKc00=VdfKBI]<016KB0VKb0VKA1VKB00=VdFKBI]8016KB
1F;B00ARdF;BH]5Rd@AR/@=Rd003H]5R/F:b009R/@04H[1R[f:`H[02H]43H[02H[400ejaG[1N/006
G[02GZl9GXl2GY000ej?GXeNS`02FY02FXl2FXh015Z=FViNSUi_0ei^00INSUi]FVeJKEY^GXh2FVd0
0eI^FViJK@04FVd015Y/EViFCEI=0UY]0UY=1eI<00MFCEI;ETaFBeI<ET]FC002ET/2ET`0159<ETaF
C5I<0UH[00=F:UH[ER/0258[00=B;4h/CR`00Th/00A>:e8[DR]B:`9>;003CP]B2U8Z005>300000<8
8@PP34000PQ100h<@@aP3448@@a1320<022S@JQNJf:[GXeNKUi`1ej@55jA00=R/EjbH[400f:a0V:`
00IV[fJ?HVeR:f8ZGPT7GPP00eh9HR]R:`04HR/0168ZHRUR:68Y1F8Z00IV:V8ZHR]R:f9<GNX2FLX0
1ehZIVYRBUhYFPYIjUX9009Ij@0KHPMEZ3CT:60iB5I@FVmNL5jAH[9VdVKCI_ES5eIA>DXPHaPQ86<a
1DFXALTmIQQR20488@a1008@@004564HPAR268825682688011B3588DPQB20QB100@@HA10320<8088
8004224880PP200210006AAQ9<<mI6:8K`mgE7<eKaAc4gmeOiIgDUh]<>LL@1b278<D@@a1244@PaB3
588DXaBT008HY0047<@Ha1RT7:@66:@071bT6<DDQ11R6:<LYAbV7<HPaBC5::<PH31PB>9IQF7XIPIQ
iV7XGNUMjV7ZHN]QjVH:IP]V2VG[0VWZ00=YjFh9KPT00fh:00m^2G8:LRYb:W8[LT]fK7I^MXmjT7j_
O]1ncgk@OZl01Gj^00=ncGk`O_000Wkb00Eo5WkgOcQoVgoM01=oo`04OcaImDE_CLd3ANh01TG>ANi6
3dX@CPm:409:<004BS5:DTXbBQ42AQ07APl01D8?@Ni1cD7<?Ld00Sf]0Sg=00=1c47=@L`00Sf/0Sf;
00LiRCV89>H<8P@020048@041202124210006@`P464HXbD69BHU1RSV8<HLaQbU9<La:D6/>FTe9QQR
444<HPaQ440DHARS6:8DHAAP008DH@0;7:</hc44=BH]9QbT444880a0460<H00436401a1Q364@HA1P
580@H110008<@08<@@05240<@0Q0340<@@0446402AAR9<8eHDh9I^i_E6ldKaA_5@03JaD00flEJaE_
5@02KaD00f/EKaE_5@04KaD2JaD00flEJaE_5003Ka@016lEJaE[5F/F0V/E00=_5FlDKa@00f/D00A_
=6/dJcA[=0=_=@04JcE_=FlEKc@3KcD00flEKcE_=@06KcD00flfKcE_=@0<KcD4Kc@:KcD00fldKcE_
=@03KcD2Kc@016lcKcA_=Fle16ld00=_<fldKc@00Vld0Vle16ld00=_56ldKc@01FlD00=_4flDKa@0
1FlC1F/D00Q[5F/DJaA[4f/BJa=[4V[b1f/C00IZlf/BJ_9ZlV[cJ_82K_8@J_801F[cJ_9ZlF[bI_80
0fKc1fKB0VKb0VKA1VKB00=VdFKBI]801VKB0f;A00AVdF:aH]5Rd@=Rd006H[1Rd6;@H]1R/F:`0f:a
00UR/6:_H[1N/5j_G[1N[ej`H[000V:a00AN/Ej`H[1R[`AR/004G[1NSej?GXh8GXl2GY000ej?GXeN
S`03GY001Ej?GXiJSEZ=GXh00UY^0Ui^00=NKEi_GVh01UY^00AFKUY^FViJKPAJK@03EViFCEY=00AJ
C@QFC@03ET]FC5I;00EFB`EFC004ERaFC5I;ET/:DR/5CR`3DR/2CR`014h[DRYB2U8:0E8<00004`Q1
22488@PQ244<@@aQ3448@@a1468<81bT?JUJK5j[GXiNKei`00INT11NT@=N/@9NT@03H[5N/Ujb009N
/P=R/@06I[1VT6I^HTaR:Uh91eh800=N2Uh;GP/00V8[0f8Z0V8Y168Z0f8[01YR:V8[JViVCF8[ITaV
KVI]HTYR:Uh[GRYJ2UX9ENUEj5gVCHHli2aQ=BQ>DEI_FW1NTF:b0VKB011RmFLhEW4iBR1S724PPc45
@HM>2d66688800PQ324@@@8@@007584HXaRS68<DHQB2688011B200@DHA1Q464@@08<800622088@PQ
224880`P0P@001@@@AbR?FENJVlbLeAgEg<fMcEgEWnHNiIJCbcX868LPR2S564<@@aR0Q230QB300@D
XaRT6<DHa08Ha@046:DHY1RU6:@26:D56:@011bT7:DLYAc50RC400/XXR10=618hE5UHLMUiV76GLQM
bUgZ009QjP05IPYUjVGYINUUj`02JNX00fX9KPY^2@03KPX00fh9LPYb:P02LR/0379=LTifKgJ@NXmn
/7kAO]1ndGj`OZin[`9n[P04OZencGk@O]82O_801WlEOaMoF7nIOkeogQ9oo`04OeeMmDU^CL/3ANh0
14H?BPm63dH@14X?00=>3dX`BS000TX@00=644H?APl014H?0T8?00I1kT7=@Le1cCf]?J`4?L`02Cf/
?Jdm[3f/>H/mZcfX;@L<@P0210001`@Q12048@@P12440@PQ00880008100@@1R28>DU1RdV:>D]1P8]
1`08;BTiS3V:=FTa1AAR2008@@8<@00A584H`aR2568DHA11544LXbcT<@@a9RT67:@DHPPP320<H002
36433682364246402aAP460@H0a0344@H@aQ344<@0Q034400PaQ0Q1Q00X@@1118<<e@DX9I^i_EF/D
KaA_5@9_=@9[5@03JaI[5F/E009[5@I_5@A[5@A_50=[5@E_5@A_5004JaA[=F/eJcD3KcD00f/eKcE_
=@04Kc@00flDKcE_=@0BKcD00flfKcE_=@02Kc@00fleKcA_=@09KcD00fldKcE_=@05KcD3Kc@00fle
KcA_=004Kc@00flcKaA_5003KcD4Kc@3Ka@3Kc@00flDKa=_4`06Ka<7Ja@2Ja<00f/BJa=[4P03Ja<0
16lCJa=[4f/C0V[c00=ZlV/BJ_800V[b0Vkb00=ZlV[aJ_802f[b0fKc0f[b16Kc1fKB0VKb00=VdFKB
I]401FKB00=VdFKBI]801VKB00ARdFKAI]5V/@9R/@=Rd@ERd004H[5R/6:aH[03H[47H[000f:aG[5N
/@02H[000f:_H[1N/002G[001Ej_GXmNSUj>GXl00Uj@1Ej?0ej@00ENSej@GY1NT5j?009NSP03FXiJ
SEi]00AJKP03GVeJKUi]00IJKP03EViJKUY^009JKP9JK@03ETeFKUI=00EJC@QFC@9FC0MFB`MFC0=B
C0EB;003DR]>;4h/009>;0AB:`9>;006CRe>;4h/DR]B2e8:0E8<00000`Q122488@02224424402Pa1
220<81AS=FMBC5j<GXmNKei`1ej@1EjA0Uj@3EjA00=R/EjbG[800ejb0V:a00ER/6:@HViRC68Z00=N
2@EN2005GPYN2eh;HR]R:P09HRT2HRX3HR/036H[IRaVC6I<IT]RBUhYGNUIbEW:DLYAb@9Ej00:FLI9
IScT:60e:4iAEVmJKejAH[82I[403V;CHaMJDCU:968H81aR;>A1Z4h;AJHLPP`Q3482444244001aR1
6:<U1BT67:<D@1R1008DPP8DH@05464@@110340<800222003P@P2248@@a1320000@0464HPSUUGVY[
4G<dJ_<2J_D01VlfMgQgE5H_:<TPHP8PX`04688<@@a148<358<00aB26:@Ha@026<D00aS46<DHY@03
6:D26:@021R46:@LXabT7<<HXabT7<D28<@02BBR940dH4T2DFEMaVGUHJIQb002GLT4HNX4INX016WY
JPUZ2Vh:1Fh900eb:W8;LR]bCG9>LVmfKgZ?OZincgk]O]1n[`03OZh017j]OZanbWk@0gkA00Qnlglf
OgQoVGnkOiak_7oN47oo00Mo?5gdBFaAbTW/ANe5kP02BNh01DX?APm:3dX?APl014X?24H?0d7^147=
00Lmc3V[?L/mbcg<?Ldmc003?J`01cf<?JXmZ2CV448000@000<480848@888@88800U100801AP6:<P
a2CT;@HaB357<DPeBCEY>FTeB3D6544400PP320@@1AQ6:<LXQAQ444<81A17:8/i34T;BDTiQRT568<
8@`P34001Pa10PaQ00H@HAAP440@H0aQ464236400`a03608@0033442340232001b33=D95jFK>KeE_
=6/D009_=003KaA[56/E00E[5@=_5@=[5@=_5@04JaE_56lDKa<2Ja@2Ka@5JaD01F/DKaA_56lDKc@0
0f/e0fle00=_=6leKcD016ld00A_56/CKcE_=P9_=@05KcA_=FleKcE_=00:KcD00flfKcE_=@02Kc@4
KcD3Kc@5KcD00fldKcE_=@05KcD2Kc@016lcKcA_=6/C0Vld00=_<fldKa<01flD00A_=6lDKa=_4`9_
5003Kc=_56lC00Q_4`9[4`03JaA[4f/D009[5004Ja=[4V/BJa<2J_800f/CKa=_4`02Ja<3J_<2J_80
0f/BJ_9ZlP02J_82J_400f[bJ_5Zl@04J_83J_42J_83I_801F[bI_9VlVKcI_800fKc0fKA0fKB00=V
lVKBI]400fKA16KB00=VdFKBI]400fKB00AVdF;AH]5Rd@=V/@=R/@AR/0=Rd09R/003H[5R/6:`009R
/@AR/0=R[`03H[1N/Ej`009R[`06HZiNSej?G[1NT5j?15j>00ANSej@GXmNS`9NSP03GXmNT5jA00=N
T0=NS`9NSP03FXiJSEY]00=JKPEJK@AJKP03FVeFKUY^00EJK@05FVaFKUI=FTeJK003FTd00eI<EViF
KP05ETd2ET`8ET/00eI<DTaBC006DT`2DR`0159;DRaB;58[1Dh/0U8[0dh/0Th]00A>;4h[CR]B:@5B
30000PQ100<<@@PQ22000PPQ00<48@@P10000P@000@<@S56CT]JS0eNT003GY5NTUZA00=NT09NT@03
GY9NTEjA00=NT@05G[5NTEjAH[5N/P03G[<2G[801V:aH[1RT69_HTeN:`9N2@9N2005GPUN25h8GPQN
2P03GP/01V8[HRYR:V8YHRYR:@=R:P03HRUR:V8[00=R:`0HIRYVBfI;IT]VBV8XGNQEZ568CHQAbEGZ
FNQEb5W7DHM11BaP=BQ>DEIaFW1NTF:a0VJa00eRdUkDFTlmBBRS620HHRd4ALU:2d6W9:<@8@024480
3a11560D@1R19@DmYSVY9>DHHQR2588DPA1Q344@@@0244002@`P200800`P220400@Q224880021000
5a1Q564iAEi[Ja9_4f[bKaE[5V/GMeUc=Th@:<TLHR2R7:8HPPPP244@PaB35:<00QB300<HY1C56<D0
0aS50aRU00<HY1bT68800abT010La1bT7:@La235:>@Ta2B1940hP4T3DFIQYfWVHJIMZ0=Mb@04HNYQ
jf7ZHNX4INX3JPX6KPT2LR/01G8]LTibL79`MXl00Wj_00Anc7k@O[1nS`9n[`09OZin[Gk<O/mndGk@
O]9nlWmG009oV@04OiYoNWnmNkd@Ool01WlKGMA9KEG:CLa9k@95kP04BNi:3dX?BPl8APl02D8?@Nm1
kdH?@Pm1kcg^@Lhm[003@Ld00d7]?Ldmc@02?L`3?J`02SW=?J`i[3V<>HTmZ23V448000P00P@P00D4
8@@P224<@@PQ0088808<800@564LXbSU:@D]9bdX;DPaB3EX=DLiJ3E8<@DD@@@0224244004AAQ688L
`aAQ300<81QR7:<X`bd4;BHU1aRT568<8@`P340010a100P8@@a1344<HA1R464@@11Q10aQ0PaP0PaQ
00l<@@PP340<@0PP320LXcESBPYVcVldKeE[56ldKcD00VlE2f/E16lE00=[5F/DJa@016lD00=[5FlE
KaD00f/E00E[56lDKaA_=F/E00=[=@=_=@03KcA_=Fle00E_=@03KcA_=Fle00I_=@03KcA_=Vle00A_
=@E_=P03KcE_=6le00E_=@=_=0E_=@03KcA_=Fle00E_=@Q_=003Kc=_=6lD00M_5003KcA_56lD009_
509_4`9_509_4`06KaA_4flCKa=[4flD1f/D1F/C0V[b00I[4flCJa=Zlf[bJ_<3Ja<00f[cJ_9ZlP04
J_8016[cJ_9ZlV[a0f[b0f[a00=ZlVKbI_801fKb0fKc26KB0fKA2FKB00=RdVKBI]400f;A00EV/FKA
I]5RdV;A00IR/@03H]5R/6:`00=R/0MR/@9R/004HZmR/5jaG[42H[0016:_GXmNSej@0Uj?0ej>00IN
Sej>GY1NT5j?GXh2GXl01Ej_GY1NT5j?GY000ej?0Uj>00AJSUZ=FViJK@9JKP9JK@03FViJK5Y^00AJ
KP03FVeFKUY^00AJK@04FViFCEI^ETd3FVd2FTd00eY/EViFC@07ETd2ET`6ET/2ET`5DT`00e9=DTaB
;004DR`00e8[CRa>;004CR`00e8/CRa>;@04CRd2CR`1DRX1DPd00003240880PQ0088800322448@@Q
00888007344881AS=DIBBej/G[002Ej@0Ui`00INT5jAGY5NTEj?GY03GY400ejBGY5NT@02GY42G[42
GY400f:aG[9N/`02G[<02UjbH[5R/FKAI[5RT69^HR]N2Eh81Eh900]R25h:GPYN2f8/GP]R:f8ZHRQR
:F8W00AR:@06HRYR:f8[HR]R:FHY0VI:015V:VHXHPMMj5W8GNUN2EWYENUIj5GXELMARD4V;60mJ59@
009JL00DGY5N/FKAH[5Vlf;dGXlmJBRS640PPRd4@LU5jSf6::<@81A256<DHP8HP@067:4a14WU?JPX
iAQQ0QR200@DHA10324@@@8@@005200400a0468<@@02000410005a1Q560e@ei[Ka9_56kbK_=_5FlH
MgYc>5IC;>XLHRBR8:8HP@PP224@PaBR5:<00aBT00<HY1S46<D01ARU00DHY1bS6:8LXaRS00<La00>
8<@Ta234:>@Pa222740hP4T3CDIMYVG6GJMMZ09MZ@03HLUQjF7Z009UjP04INUUb6G9INT4JNT3KPT0
1Vh:KPUb2G8ZLTabCP9fL004NXmn[Gj]OZ`2OZh047Z>NVmnSWj=O/inZgk>O/mnd7kBOa=oEWnJOk]o
_7nm0WoN47oo00Mo6eWCBDa=ZdG<ANe5kP02BNh00dX>BPm:3`04BPl01dH?BPi63dH?@Pm1l48?0091
kP03?Ldm[Cg=00=1c@07ANe1kSg=>L`mbcV;>H`00cV/00TmZcV/>H/mRCVX9@L@@`@020000`@P00<8
80PQ22000`PP00L@@1AQ68<LY2dU<DL]9`02;BP02C58=FLeASUX=FLa11QR20488@0234004A1Q688H
XQAQ444DHAR27:8X`bd4;BHY9abU56888@PP34000Pa100<8@@PQ22400PPQ0Pa100D@@A10444<HA1Q
008<H@04340<H0Q0360234403@aP460<@1108<<iI4X:I^m[<g=EKa=_=6/D00=[5@9[5P=[5@M_5@06
KaA_5F/EKaA[56lE0flD0VlE0Vle00M_56[cKa=_56lEJaE_5@02JaD00fleKcA_=004Kc@3Ka@00fld
KcE_=@05KcD00fldKcE_=002Kc@00fleKaE_5@02KcD5KcH2KcD00fldKcE_=@02KcD4Kc@5KcD3Kc@5
KcD2Kc@7Kc<00flCKaA_5004Ka@3Kc@01flDKa=_56lDJa=_4flD00=_4`06KaA_4flCKa=_56lC0f/D
2F/C0f[b0V[c1V/C16[c16[b1F[a0V[b0V[a0V[b2VKb00=VlfKBI]800VKB0fKA16KB1FKA00=VdVKb
I]8016KA0f;A0VKA00=Vd6;AH]400V;A00IR/F;AH]9RdV;AH[43H[09H[4016:`HZmR[f:_0f:`0V:_
00ANSej_GZiN[PENSP03GZmNSej?00ENSP03GXmNSUj?00=NS`03GXiJSEZ>009JS@=NK@04GXiJKUY^
FV`3FVh015Y]FViJKEY^1eY]00=FCEY=FTd00UY=00AJK5Y<FT]FC0]FC@06ETaFCEI<ET]FC5I=0UI<
1U9<1E8/00AB:e9;DR]B:`M>;0=>;@9>;05B:`5>3@0000D8@0PP22448@PP00848@0:24488@a1464D
@AAS=BABBek>G[89GY02GW001Ej@GY5NTEiaGY0015jA00ANTUjAGY5NT@AN/@AN/P9N/`03G[9R/V:b
009R/@04H[1NKUh/GPX2GPT01Eh:GPUMjEgYHPP00Uh:0Uh;00=R:f8ZHRT00V8X00=R9f8XHRT00V8Z
0V8[00=R:V8:IRX00fHY0VHZ019R:F89GPUN2EWZFNUIjUGYDLUAadfX?@HXH3DVBRmB;UI?FY42H]<2
IaD09VLgH[=1ZbRS668LPbd4>HM22cf58:<@81A168<LXab2784LXR33<@DTiAR3540HHQAR564<80P0
420@@@`P200<81cT;HTPi0PP000210002000220<@1RQ=B5F:V/AKa82K_803FkeKaIcFFlFGW<]2b23
:<<PPQb13208@A2300DDY0036:@HYAS500HHY@8LY0067<<La1c47<DLa1c50R3500XTa2358:<L@3R0
B>5=AUV7HJIMY`9MZ004HJQQb67YHNT2HLP2ILP3INT016WYJPUYjVgZ0Vh:00a^:Vh:LPUb:g9=LVmf
KgZ?NZin[7j]O/`2OZd01Wj=OXinSgj`O]5ncP=nd006O_=o=7mgOiYo_7nm0WoN4Goo00QoOUgeADa5
ZdG>BNi5kdW^0dX?0TX@00E:3dH?BPm63dX?00963`03@Pm1kd7_0091kP03@LdmcT6]00=1c@05?Ldm
cSW=>J`iZ`02>H/013V<>H/iZcf[0SV/00@mZSVY8@L@@`8400848003124480PP0088@@888006440@
@AB37<D]9S580bdX00TaB3E8=DLiJ3E7<B@HH@P022000Pa000<@HART588011AR00LLXbST;@DaABD7
6:@@@P02220434401PQ122488@@P22088@8<@003344<H@aQ00<<H@8<H00>340<@@aQ360@HAAQ584T
hcETCP]Vcf/dKeE[50E[5@=[5P03JaE_5FlE00Q_5@E[5@9_50A_5@9_=@9_509[5@=_5@04KcE_=6lD
Ka@3Kc@3Ka@;KcD00fldKcE_=002KaD3KcD6KcH5KcD4Kc@5KcD00fldKcE_=@05KcD00fldKcE_=006
Kc<01flCKaA_56ldKcE_=6lc009_=0=_5003KcEc=Fle00M_4`=_5003Ka=_56/D00=[5003Ja=[56/C
00A[4`AZl`03J_9[4f/C00=[4`03JaAZlf[c009[4`03J_=Vlf[b00=ZlP=Zl@QZlP03I_=VlVKc00EV
lP03I_=VdVKB009VdP=Vd@AVdPAVd@03I]1VdFKA00EVd@ERd@03I]1VdFJa009Vd@ARd@9R/@AR/0QR
/@09H[1R[f:_HZmR/6:_H[1R[ej`009N[`=N[P9NSP03GXmN[ej`009NS`03GXiNSej>009NSP03GXmN
SUj?00=NS`03GXiJSUZ?009JSP04FXeNSUj>FXh2FVh03UY/FViJKUY^FVeNKUY]FViJKEY^FVeFCEY]
ETd5FTd00eI=FTeJC@03FT`9ETd015I<DTeBCEI=0eI<00=FCEI<DT`01U9<00=B;4h/CR`00Th/00=B
C58[DR/01Dh/158/14h/0Dh=00000`Q022088@0322002`Q1344<@@aP464<8111<>5>:EZ^G[400Uj@
00YJL5j@GY1NT5Y_GXiNKej@GW1NT0]NT@=N/@03GY5N/Ejb009N/P0<H[5N/V:bG[9R/UjbH[5NTF:?
GViN;5h:15h90UgY00UMj5h8GPQN2V8[HRYR:68WHRH00f8W00AR:F8ZHRYR:P9R:`06HRYR:FHYIRYV
:FHZ168Z00mN25X9FNYEjUG9DLUIie6X@BHTH2c1ANaJCEY_G[800VKd01URdVKcH_AJLSeZ::@HHQR3
:>@eID7Z@LLLXQ10540LPaR2788HPAb1664HHQAR544DH@0266405a10200400P0100800@0684iID87
>HDDP@@022488PPQ340@H1R1<@1F:F/>La800Vkb00i^m6keMeQgEUib<B/LPb2S8:8HP@PP348@PaBS
21BT0aRU00<LY1RT7:@00ac40Qc500lLa23U8<DPiB347<DPXb1P>818`De5GJMQYUfVGHH00Uf70V6W
00=QZ678HLP00fG80fGY00=YjFWZJNT00fh:00e^:788LRYbCGI^NVijS7j/O/Ync7k/O/en[002O/h0
3gj`O/mn[Wj/OZin[gk@O_5o<WmgOiYo_7nmOmeogP0BOol00ehFADe=[004BNh01DX?CPi:3dX?AQ00
14H?00A5kTH>APi63`=1kP06@Ne1kT7>@Jdm[47<0Sg<00<mcSV^>Jd00SV/13V;00TiZcV/?L`mbcVZ
8@L<@P0010001@@P0PPP00P800PP320@@1R38>Da9S5712dX00HaB357=DPeIc45664220004@a1444@
HQRT58<DHQAQ440DHAbS:>@a93E59@HLY11132400Pa100@<HPaQ344<@@<88@0312488@a000D<@08<
@@8<H@8<@009220<@11P560DPB33=DA62f;?009_=003Ja=[5F/E00a[5@=_5@03KaA_5F/E009[5@03
KaE[5FlD009_5004JaE_5FlEKaD3Ka@6KaD9Ka@5KcD016ldKaA_4flD0Vld0Vle16ld0fle0flf1fle
00=_=6lcKc@00Vld0fle00A_=6lcKcA_=0A_=@03KcA_<fld00A_<`03Lc=_<flc009_4`04KaA_=6ld
Kc@3Kc<6Ka@4Ka<016lbKa9_4flD0flC00I^lflDJaA_56/CJ_<6Ja<3J_<00f[bJ_=[4`05Ja<2J_<2
Ja<2J_<4J_87J_45J_800fKbI_=VlP05I_82I]800f[BI]5Vd@03I]42I]82I]44I]03I]42I]03H]40
1F:aH[1V/6KAI]000fJ`00=Vd6:`H]4016:a16:`26:a00=R/6:_HZh00V:^0f:_00=NSf:^GZh00ej^
0Uj>00ANSej_G[1N[P9NSP03GXmNSUj>00QNSP04FXiJSeZ>FXh2FXd00ej=FXeJK@02FV`015Y]FViJ
KUY]0UY/15Y]0eI=00=FC5I=FTd00UY=00=FCEY=ETd00UY<00=JBeY<ET`025I<00IBCEI=ETaFBeI<
ET/2ET`6DT`2DR`4CR`00e8/DR]B:`06CR`01e8[DRaB;4h/DR]>;4h[005>3@0000<8@@PP22000`PP
00/8@0Q1344<@110200@8Bc2BPYFSeZ@009JL09JL@9JT@07GY1NSej@GY1NTEj@GY400Uj@0ejA00AJ
TEjAGY5NT@ANTP9N/@=N/P03H[5N/V:b00=N/P9N/@04GXmNKei=GR/3GPT00egYGPUN2@03GPP00eh:
GPUR:P02HPP00f8WHRQR:002HRT4HRX01V8[HP]R2V8ZHR]R;09R:`07GP]R:eh:GRUIjUW:DLT00U78
01aIie6X@DHTH2c3AL]NBei]H[9RmEZAEU1><4X`@Lda1b2468<LPb35;BHeJ345788HHAR27:<LPP8H
H@8HPP0966<DHQQR7:<LPa@P300400P0008@@@0C320<01A0=FA6:3V45604011258@DP`a1460HPC3P
FRQ_3g<bK_400Vkb00e^m7LfMeIRTc5;66<HPabS684880a248<DX`035:D00aBT5:DDY@025:@011B4
6:@HYAc50abT0Qc40ac500dLiB3U8>HPiAc57:<PHCc0B>5=AEfWILEQYP03GHL00efXHJMQZ003HLP0
1f7:ILYUjVGZIN]YjVW[009YjP0AKPY^2fh9LRYb:g9]MVijSWj=O/anjWl^O_1nkWk>O_5nc`02OZd0
3Gj[OZan[Wk?O_9o4WleOgMoVWnkOkaogGoN019oo`08GSI9KTg<ANm5kTW^CPi:3P9:3`06BPi63dH@
AQ163d8?0T7^0dH?00I1kT7]@Ni1kT7=?Jd2?J`2?Ld01Sf]>Jhe[SF]=J`eR`@iR`08>H`m[3f[>JXQ
20a3000400848003124480@Q00848007220<8110564HPb3U;BD00RdW0RdX0Re800X]BC5Y=FXa:1R4
34888@a2344@HP8DP`0;468@@@`0420HPRC3;@@eABT67:@DHP0334401`aR468<@@Q1224880@Q0088
8@8<8008344<80a0240<@@aQ3448@@@<@00:460@@11P7<<a@dG[H/i[=6leJa@3JaD00f/FJaE[5@09
JaD2KaD00flDKaE[5@02JaD00flEKaA_5002Ka@3JaD2KaD00flDKaE_5@04KaD2KcD00f/EKaE_5@04
Ka@016ldJcE_=6ld0Vle00I_=6lDKaA[56lDKc@2KcD3Kc@016lEKcE[5Fle0flf0Vle00=_=6leKc@0
0Vle00A_=6lcKcA_=0A_=@04KcA_<flCKc@4KcD00fldKc=_=002Kc@00g<cLa=g4P04Ka<5Kc@016lc
KaA_4flD0flE00A_56lCKa=_4`9_=003KaA[4f/D00=_4`03K_=_4f/D009_50=_4`A[4`=Zl`03J_9[
4f/C00=Zl`03J_9Zlf/C009Zl`=[4`03J_=ZlV[a00=ZlPEZl@9Vl@=ZlP03I_9VlfKb00UVlP03I]5V
dVKA009Vd@=VdP=Vd@04I]9VdFKAH]44I]4016KBI]5V/6J`0f:a0VJ`00=Vd6;AH]401F:a00AR/5ja
H[5R/0IR/@05H[1R[f:^HZmR[P02GZl015j`HZmNSf:^0Uj^00AN[ej?GXmNS`9NT003G[1N[ej?009N
S`03GXiNSej?00=NS`=NSP03GXmJSUZ?00AJSP9JS@=JK003FVeJKUY^009JK@03FVaJKEI]00MFKP03
ETeJKEI<00AFC004FTaJBUI;ET`5ETd3ET`00e9=ETeFC002ET`01EI;ETaBC58/DT`00U9=0U8]00=B
C58/CTd00Th/0e8/24h/00=B;4h/CR`00Th[0E8[0Dh=00001`PQ220<@0PP320880a00088@@888006
100802S3BPUJ[ej@0UY_00IJL5YaFW5JTEj@GXl2GY03GW000ej?GY1NT002GY07GY400ejBG[5N/@03
G[84H[43H[801F:aH[1NKei<GRX00Uh900=MjEh8GPP015h800=N2F88HPP01F880f8Y0V8X00AR:F8[
HP]R;0AN2`0LGR]N;5h/GPUN:5WYFLUEbEG7CLMAYDf7@BDXPBc5AJYNBEiZH[5N/dG^;>HTY346;>@T
Y1b47:D37:@011AS444HHQb20QbR00DLXaR2688HHAQR008D@@048:@TiB2S524210005P`Q7:@]1B34
544DH2S1<B@/hP`P220HaBD75:@<@@a0684/h587K`ec<Fk`0Vka00I^lg;bMc=R/S4[88@278<01aR2
44888A1S5:@HaABU00HDY08HY08HY@8LY@0C7:@La1RT7<DLa2357<DLaQc58>DLaAb3764l`4SQCDEM
QFW5HJH00Uf70Uf600QQQf6WHJMQaf78HLYUjVG;0VG[00=YjfWZJNT00VgZ0Vh:00]b2W8[LTefK7Z<
OXan[7k:O/eo47k^00=nc@06O^inbWk;O/encWk`0WlC00Mo=7mFOgQoVWnlOkeog@0AOol03GoOGSI9
KTV/ALe9kDG]CNe5kD7=APi:3TH>00A63`04ANi1kT7_@Nl2@Nh02d7]@Le1c47<?H`eRSf[>LdmcCV]
>Jh00SF]00<e[3F;>H/00cV;00HiS3V;>HXeRB4834@2100512005PPP12488@`Q444DHAR37<@Xi2d6
;BL]:34X;DPaAc59;DTaBbT968@<@PQ20PPQ01D@HQAS58<@Ha11200@81R19<<Xi354:@HLY1QR3208
80a1364@H@a022400P@000@480PP220<@0<88@062208@0a1368<@@Q11@a000H<@@`P7:<eA4H;H/h2
Jc@016/DJaE[5V/F2f/E1flE00=[5V/EJa@016lD00=_=FlEKaD01FlE00=_56lEKc@016le00=_5FlD
KaD026ld00A_<fldKa=_509_=09_=@=_=0A_5@03KcI_=Flf009_=@08Ka=_4W<bKcA_=FlCKc=_=0E_
=@05KcA_<flCKcAc=@03KcD016ldKc=_=6ld0flD16lC0flc0Vld00=_56lCKa@00VlD0VlE00=_=FlE
Ka@016lD00U[56/CJaA_4f/CKa=_4VlCJa<016lC00=_4V[bJa<00f/C00E_4V[bJ_9Zlf[b009Zl`UZ
lPeZl@AZlPAVlPIVl@QVd@EVdPMVd@04H]5Vd6J_IZl2H[4016;AI]5V/6:`26:a00MN/F:aH[1R/Eja
H[5N/@02G[000f:^GZmN[`05GZl3HZh2GZh00ej_G[1NT005GY000ej?GXiNS`06GXl3GXd00ej>FXiJ
S`03FXh2FXd01EY]FVaJK5Y/FVh00UY]0eY/00IJKEI]EVeFKEI^FVd2ETd00eI^ETeJK003FV/2ET/2
FTX2ET/2ET`3ETd2ET`015I;ETaFC5H[1EI<00IBC5I;DTaBCE8]DTd2DT`014i=DRa>;58[0e8/00=>
;4h]CR`01Dh/00=B;58[DPX00U8Z0E8<00001`PQ220<80PP320<@0aP0088@@888008000<02C3@LQF
KUj>FVmJL09JL@=JT@9NT0ANL0ENT0ANT@03GY9NTEjB00IN/PIR/@05H[9R/F:`GVmNC004GPT6GPP0
1Uh:HPQR2688HRUR:09R20=R:@06HPQR:F8YHRYR:eh[0eh;00EN;5h[GRaN;5hZ00=N200HFPUIae6W
DJE=QT55:88XPd68HTURBV:`DU4e:Q`1300@01A0544D@QbT7<DHY1120Q1100@DHAb27:8PX`8P``0C
7<<LPQA0544LPRcS<BDX`ab3100001R3>JU1bCV7<@D/hbS37:800QR100hLa2f8=HLLa0`Q344DHBc0
CPQZkFlAK_1^lFkb0W;b00]g<UjB=D/PHQb278<HPQ12224@HaB3008DY00558@DPaB358@DY0026:@4
6:D011bU7:@La1c40ac500dPaAc67<HLaQc578@H@3RPA>9=Aef5HJEMQP02GHL00ef6GHMQQ`02HJL2
HLP00f7:IL]Ub`02IN/2JNX00fgYKPY]jP03KP/01g8[LTefK7Y]NXej[Wj/009ncP9n[`06OZanbWk^
O^ao3gk^0WlA0glC00MoEGmgOgQoVgnlOmeooP0@Ool017noGQE5KTF[0TW^00Q:3TW]ALe1[4G^CPi9
kTG^0TH?00=23d7^@Ld0147^0T7=0T7<0Sf/00Hmc3W<?L`i[CV^=Jd2=H`3=H/023V;=F/iRcF:=FXa
JB4824<210004@PP120480PP224480@Q224<80P0344HPQc4:>D]1RdW;BP00S4X00P]B35:;DTY:Qc8
58D88PQ20PPQ00l@HQB36:@DPaAR420D@Ab2:><a1C55:BLLY1A132000Pa100<<H@aP24000PPQ10PP
00H<@@PQ2248@@Q02443340434402PaQ464<@@PP688e@dH;H/i[<f/d0V/D2f/E00=_5F/EKaD01FlE
00=[5F/FJaD00f/E0flD0flE00=_56lEKaD00VlE00=_=FldKcD016le00=_5FleKa@00fld0Vle1Fld
00=_=FlDKcD02Fle00=_=VleKcD016le0Vld00=_=FldKc@01Vle16ld0fle0Vld00=_<fldKc@00fle
00A_<flCKa=_4`=_<`9_=004KaA_4flDKa@6KaD3Ka@4Ja@00flCJa=_4`02Ka<00f/CKa=_4`02Ka<0
0fkbKa=[4`04Ja<016[cJa=[4flD0V[b00=Zlf[bJ_<016[c00=ZlV[cJ_801F[b00=ZlF[bJ_400f[a
16[b1FKa0fKb0fKa00=VlVKBI]401FKA1FKB1FKA1F;A00=Rd6;AH]400f;A00AR/F:`H[1R/@9R/0IR
/@=N/@=N/0MN[`03G[1N[ej_00=N[P9N/0INT0UNS`ANSP04FXiJSeZ>FXl2FXh01EZ=FVeJSEY]FV`0
0eY]0eY/00=JKEI]EVd00UI]00=JKEI=ETd00UI^00=FKEY[FVd00UY/1EI;0UI<0eI=0UI<00=FBeI<
ET`01EI<0e9;00]BC58]DTiBCE8/DTa>C59<CRaB:dh/009B;003CRa>;Dh/00I>;004DR]B:U8ZERT1
DR`000888005100880`P340<H00224402PQ0340401119<@mYdi>GXeNSeY`0UYa00=JTEjAFW400UYa
0ei`1Uj?0Uj@0UjA00ENTUjAGY9N/UjB00AN/@9R/@0:HY1R/F:aH[5V/F:`IZmRKUh[GPP4GPT00eh8
GNQMj002GPP2HPP00eh8HPQR:@04HPP2HRT2HPP3HRP01EhZGPYN2Uh:GP/00Uh[01UN2Uh9GPQR:68W
FNQEadfWDJIAYdE5;:4XXd68HTURJV:=DU4Xb0`0100<0A0P544LX`028<D0:QbU58<@@0`P440DHAb2
9<<Xhbd2;></hS32::8/XSDU=FLmISCU54<802d5DXmRkdY=@L/eARB242080233?JDmidGV6:<<8A11
564X`4X9J^i_4@9^l@9bl@05Ma9gDfJc=D/L@@028:801AR2444<@Q2358<00QB400<DY1RT5:@00QBT
00PHYART6:@HYART7:@LYART0Qc41Ac50ac600TPYAQ0>:14hdT6FDEMHeV5GHD00ef600=QQV6WHJL0
0V7800=QbVG:ILX00VG:00=YbVgYKNP00VgZ01A^36g[KNU^2W9<MVafKGZ<NXenZgj^OZen[WZ>OZen
j7l>Obmo<7l_0Wl@00Yo4GlBOa9o=7mFOgMoNWmlOkeogQ1oo`0<OkiN=DE^AH]9kTG]APm5kTG>@Le5
kTh>0TH>0d7^0d7=00DmcT7^@Ni1cCg=00=1c08mc004>L`mc3V/>Hd2=H`01c6;=H/eRSF:=H/eJcV;
008iRP05<FTPj0a30004000612003P@Q220880P0340HPQc4:>D]1bdW;BP]:Be9<DX2<DT00c5;:@/H
YP0434802Q1S56<HY1B3464D@AQQ7:8T`bd50RdV00PLXa0P340<@@a2344<H0a00PPQ10PP10PQ0`PP
00@8@0a0344<@@<<H@08464<@@P0564a8DH:H/e[4P9[4`03JaA[5F/E00A[5@9[509[5@03KaA[56/E
00A_5@Q[5@05JaA_56lDKaA_5@03Ka@00flEKaA_5002Ka@00flEKaA_5@02KcD016lEKcE_=6ld16le
1Vld3fle00A_=VleJaE_50A_=0I_=@03KcA_<fld00I_=0=_<`=_=003Kc=_4flC00A_4`04KcA_56lD
Ka<2Ka@5KaD2Ka@3Ka<3Ja@2Ja<016lCJa=_4f/C0VlC0VlB00=_4f/CJa<00V/C0f[c0V/C00AZlf[b
J_9ZlPIZl`=ZlP9Zl`05J_9ZlF[aJ_5ZlP05J_4016KaJ_5ZlF[a0VKa00]ZlV[aI]5VdFKbI_5VdFKa
I_9VdFKB00MVd@=VdP06I]5VdVKAI]5RdF;B0V;A00=R/F;AH]400fKA00ERdF:aH[1R/6:_00=R/0IR
/@=N/@03G[1N[ej`00MN[`03GXmNT5j_009N[PAN[`03GY1NSej?00=NS`ANSPANS`9NSP06GVeNSUZ>
FXmJSUZ?0UZ>00AJSEY]FXeJS@9JK@04EVeJKEY]FVd8FV`015I=EViFKUI]0UY/0UY<00=JBUI;ETX0
0UI;0UI<0eI=0UI<00EFBeI<ETaF:eI<009F;0EBB`07DTaB;58/DTaBBe9<DT/01E8[2Dh/00A>:e8Z
DRUF9`5F:`000PPP0PPQ00l880Q0344<H@a1340<H0PP448PXcV7DVmRd5jaFW000UYa0UZA00AJLUYa
FW5JL0=NT003GXmNT5j@00=NT0=NT@ENTP=N/@=N/P9R/P0:H[5RTFJaH[1V[f9^GTaN2Eh:FPT3GPP0
0egXHPQN2@04GPP3HPP3HRT015hYGRQR268Y0V8X00=R25h:GPX00eh/00MN:eh:FPUIjUG9DLUAb003
CLP04E6WDLQ5IS32;:95R699HVYRSDh`<<PD01PQ66<PXb2T9<@00RC500<PaAc468<00QR200@LXbC3
;@<a908eA00Q=B@/`S3T?DM9beI?DRe5RBS5768iRelEHa=O4e9`@JX`hQ00200L`cVV>LPaIQRS220@
@AAQ:<1:2F[]Lc9^lFkb009blP0<Nc=kE6KC>BXPHBRR8:<HPQ1Q348DPaRT1ABT00<DYARU6:D011RU
00<LY1c47<D021c500`PiAc678<L@3B0@<A4j54UFDAMIEf5GHH2GFH01V66HJMQZ66XHLUQbP9UbP03
ILUYbVWZ009]jP9^2`0PKPa^3G8<LRabCGI<MVejK7Z=OXaj[gj>NVefKgj]O^Mo<7mBOeAo<WlcOa9o
4glBOa=o=GmFOgMoNWmkOkeooQ5oo`05IYM9KTF/ANi9kP02ANh2ALd014G^APi63dH?0d7^0T7=00@m
cCg>?LhmcP<mc@07@Ldmc3g<?L`ic3g<>J`00SF<00HaRc6<<H/aRc6:=F/2=FX01cV:=FTaB23W46<0
00@000L48008220<8110440DPQc4:>H]1`8]:00=<BP]BC59<DPeJCE::@PHY@a3348<@@a246<00QB3
00L@Pa1Q564DHAR28<<Ti@02:@H00b34420<@003344010a022088@Q10`PQ00<8@@PQ22400PPQ0`PP
0108@@Q0224<@@aQ464<HA1Q344<01QQ=D=62f;=Ja9_=09[50E[5@=[509[5@03KaA_5F/E00M[5@03
JaI[5F/F00A[5@05KaA_5FlEKaE_5002KaD00f/EKaA_5@02KaD01VleKaA_=FlEKaI_=P=_=@9_=0=_
=@03KcA_=Fle011_=@04KcI_=FleKcD3Kc@2Ka@6KcD3Kc@3KcD2Kc@2Lc<01VldKaA_<fldKc=_4`9_
50=_4`9_509_4`=_50E_5@04KaA_4flCKa<3Ja@7Ja<016[cKa9_4flC0f/C0V[c16/C0f[b0V[c00=[
56[cJ_<00V[c00IZlV[cJ_9ZlV[cJ_82J_42J_800f[aJ_9ZlP02J_8016KbJ_9ZlV[a0fKb00EZlVKB
I]9VdVKA00EVdP04I]5VdVKAI]02I]44I]84I]4016;AH]9RdV:b0f;A00AVdVKAH]5R/@IR/0MR/@AN
/@UN/09NT006G[1N[ej_GZmN/5j_0ej@00ANSej@GXmN[`QNS`=NSP9JSP=JS`9JSPEJK@AJKP03FVeF
KEI]009JK@=JK006EViFCUI>ETeFKUY/0eY=15I;0eI<00=FCE9=ETh00UI=15I<00=F:e8/ER`01E9;
0e8/00A>;59;DTaBB`9B:`=B;0Y>;003DR]B:EHW005F2P000PPP01088@a13448@0Q1344<@0aP464<
@0`Q7:<iQUJ?H]5N/@9JL0=NT004FY5JLEYaGW03GY000ej?GY1NT00;GY43G[43G[800f:bG[9R/@02
HY4016:`IZmRSV9<0eh:0Uh800=N1eh8GPP01Eh800=R268YHRT01f8Y0f8800=N2Eh:GR/00Uh[00AN
:Uh9FNUAZ0==Z0==b00@DLM=Z4V7=<4XP45VHRURJUi/BS0a2BbT::<]1S44;@D2;>@3:<@0:BC4:<<X
`bS3<@<eA3f7@JLmQd67@FPmJDG;IZi_4Vk^CP`a1BS4@NiW>6LfEXiFJdh]?HL/`1A0788Xhb3T6:<@
@@PP440HPBcPBPQZkG<cKa800Vkb00e^lg;bNe=V/SU;860TXAbR688@H@a1468HX`045:@35:D56:D0
0abS7<<La0067<D03Ac47<DPi1c4688H82aP?<A0b5U7GFAMQF5U00=MIP05HHIUYVFWIJQUb003ILT0
0fW8JNU^2P02KPX2KP`00fh=LRib;@02LTd04GI=MVefK7Z<OXYjSGY^NTejT7k>OdUoCgmdOiIoMWmD
Oa<00Wka00Mo4gleOeEoMWmiOk]og@0BOol00fZGBHe9c002ANh0147^ALdmZdG<0TG]00I1kD7^@Ni1
kT7]@Ld2@L`00cg=?Jdmc@05?Ld2?L`01cW<>J`iS3F;=H`aRc6<008aR`8aRP03=FXeJCEX008aA`04
8>H@HP@010031205220232002A10584La2SV;@L]22dX<BL]:002<DL03C4W;@HXiART348<@A1Q348@
HaBT6:<DPa1R008DH@087:8Ti2dV;@L]1RC3660@@08<@@03240<@0PP00D880052408@@Q124488@03
22004@Q0220880Q1340@H0a0468<@@`P664e8dX:I^e_<fldJa@01F/E1F/D00=_56lEKaD01f/E00=_
56/EJaH00f/F0V/E1VlD00=_5F/EKaD01FlE00=_56lEKaH016le1Fld2Fle0Vld1Fle0Vld00A_56ld
KcA_=15_=@03KcA_<flc00=_=0A_<`03Ka=_56lD00=_4`9_<`A_4`04KaA_=6leKcD2KaD016lDKa=_
4flC2F/C00AZlf[bKa9_4`M[4`04J_=[4f/CJ_<2J_83Ja<6J_<02F[bJ_=Zlf[cJ_5ZlV[cJ_9Zl@02
J_800f[cJ_9ZlP02J]801F[aI_9VlfKcJ_800fKB0VKA00=ZdVKBI]800VKB1FKA0VKB16KA00IVd6;A
H]5RdVKBH]82H[82H]42H[47H[03H[400f:`H[5R/@02H[48G[401ej`G[5N/Ej?GY1R/Ej`00=R[P03
GZmNT5j@00ANT003GZmNSej>00INS`03GViNSEj=00=NS@03FXiNSeZ?009JSP03FXeJKEY]009JK09J
K@AJKP9JK@AJK003EViFCUI>00=FC@AJC@04ETeJCEY=FT`2FV`00eI=DTeBC@08ET`015I=ET]FBe9;
0eI;00EBBe8[DR]B:e9;00=B:`9B;0Y>;004DR]B:U8YDRP1EP/00003340<80a100D8@@<<H@073448
01b2=FI>L5j`FY000UY`00ANT5Y`FW1JL@9JT@03GW1NT5j@009NT0aNT@9N/@03G[9N/Ejb009N/P03
GY9N/f:b009R/P08I[5V/6:@GTiN;5WZFPUN209N1`MN2004GRQR:F8YHRT3HPP3HRT01V88HPUN2Eh9
GPYN;@9NC@03GRaN2eX900=Ij@0EENUIjUWYDLQ=Z4F7AFHd`BR0>B=N:EiZGXe>D3f;>DPmRTG]AN/e
J345008`h`8/h`0P<><e0cDT>DHmQdG8BN]:2TW[BL]5ZDW[GVeZlFldI/aF;C45=@AJKF]GH]=JCE8;
DReBCDG[=DHX`Ab1568<8084000B320HPBS0BNQ[3g<bLa=^lflDK_AblWLcI[4mJb10784LXQRQ0Pa1
00L@PaB358<DQ1BT58@DY0025:D26:@36:D00aRS7<@La@067<D03Ac47>DLi1c57:<@82a0@>E=BFF7
JNEYifF600=QQ`04IJMUafFWILP3IJT01fG8JNQYjVgZKPY^2g9^009fK`09MTmfCWI]NVefK79^MVij
SWj<009jK@0:OV]jSgkaOb]oLGmcOgAoDWlBO_02O/l01glBOa=o=WmFOgQoW7nm019oo`0;GSA9STF/
ALi5kT7>@Le5cDG/@Ndm[002@Ld01T7^@Ne1cD7=?Je1c08mc@05?LhmcCV]?L`mc@03?L`00cV/>H/i
R`02=H/2<H/2<HX4<FX01C5X<DLeJ23W58<00P@000<48@@P12001PPP00L<8110584LY2T6;BPY2002
;BP06RdY<BP]:2dW<@Ha1AbT448<@A1Q344@HaB45:@@Pa1R444D@1bR:>@aAbd6;@DP`aQQ34023442
34000`Q02208800222000`Q02448@@0224400`PQ2208800522400`Q0440@@002464020`P684a0TGZ
I/acE6ldKcD4JaD00f/DJaE_5002Ja@00flDKaE_5@03JaD00flEKaA_5@03KaD5JaH4JaD2KaD00flD
KcE[5@03JaD016leJaE_=Fle0VlE00=[56lEKcD00fle1Fld2Fle00=_=6leKcD00Vle00Ic=G<dKcA_
4flDKc@BKcD016ldKc=_<fld0Vle00A_=6lcKc=_<`=_=09_5004Kc=_56lDKc<3Ka<00flDKcA_=@02
KaD2JaD2Ka@00flCJa=[4`04Ja<016/DJa=[4f[c0V/C00=[56/CJa<01V/C00AZlf/CKcA[509Zl`03
Ja=[56/C00=Zm003J_=[4f[c00=Zl`03J_9Zlf[c00EZlP06J]9VdV[BJ_9ZlFKb0VKc16KB0fKA16KB
1FKA0VKB16KA00EVd6;AH]5RdVKB00ARd@05H]9RdF:aH[5Rd@05H[03H[400f:`H[5R/@02H[49G[40
1V:`GY1NT5j`G[5N/0=R[P03GZmNT5j@00ENT003GXmNSUj?00ANS`03GXiNKUj=00ANS@07GXiJSUZ?
FXiJSeZ=GVd00UY]00=JK5Y]FVd00UY]00=JKUY>FTh00eY]0UI]00=FKUI>ETh015I=0eY=00AFCEI<
FTeJC09FC003ETeFCUI>00EFC0=BC@04ETaFBe9;DT/3ET/3DR/2DT/00e8[DRaB;00<CR`2DR/1DRX1
DRP1DP/000043408@@PQ1202220030a0344<@@a03608@@PP564eADX^GZmJKPAJL004FVmJL5j@GY02
GW02GY000ej?GY1NT@0<GY44G[400ejAG[9R/`02H[802FJbI[5V/FJaGTmN2egYFNUN1`03GNL2GNP4
GPP00f88HRUR:@08HPP01F89GPQN25h9GPX00UW;021Ijeh<GPUN25h7GRQN25WYFLQAZ4VYBJQ5ICBP
:60i0eH8GX]N[eZ`DRi9jdh]DTi>;46Z=BL`hcD2<@<e93UW0Sf701e1ZDX;DRaBCE8/BNa9bdFXCNQ>
2VJ^I^mZbe8/=BH`hEY9Ia=RdeH]ERaN[VK<EVi:33UW;@@HP`P00080000G100DH2BPALQZkW<bKa9^
m6lDL_=g<g]DJ[11RRAP684LXQR134488A1S588DP`0358@35:@26:@258<36:@011RU7<DLaAc40Qc5
11c400XLaAR2640THTF:KTijdG[>KPUUR09QR00UIJQUb6X8KPUYjVW:JLUYbVWZKPY^:fhZKPY^:g9<
MVefSWI]LTafC7I/MT]bBg8/LVejJgj=NTajBgY/O/inbgl:OdioLGnBOc400Wk>00Unl7lBOa9o57le
OeQoNWnKOoh047oo00Eo65Wb@Fa1[47=0091cP04@Le1c4G/@L`3@Ld00d7^@Ne1c002?Jd013f/?L`m
[3V]0SV/00Dm[3g<?L`mc3V[008eR`8iRP8eR`03<HXaJS5Z008aJP07<FTaJ35Y=FPeR2D858<00P@0
00<48@@P12000P@P10PP01D<@110460LXbd6:BPY22dY;BP]:BdX;BT]2346<@@LQ112324@@0a04680
0QB300`@HPPQ200D@1b2;><a9Rd6;@DP`aA0420244000`a02208@003220010Q0340<@0a00PQ100D8
8@PP22488@@Q00848004224<@0a04402460020P0684e8dG9IZ]_<VldKcD3JaD2Ja@01F/EKaA[56lD
JaD00flD0V/E00A[56lDKaA_50a[5@05KaE_56lDKaA[5@04KcD2Ka@016ldKcE_=FlE16le2Fld0fle
0Vld00=_<fldKc@01Fld00=_56ldKc<01fle00=_=6leKcD00VlE16le00E_=6lDKa=_4flD00A_=0=_
<`9_5008Ka=_56ldKc=_=6lDKc=_4P9_4`E_50=_5@05KaA_4flCKa=[4`02Ka@2Ja<00flCJa=[4`06
Ja<7J_<2Ja<3J_<016/CJ_=Zm6[d0f[c0V/C1V[b00=ZlF[bJ]400f[B00AZlV[BJ]9VlPAVdP03I_9V
dFKA009Zd@04I]5VdVKBI]82I]42I]000fKAI]9VdP03I]42I]02I]402F;BI]9VdFK@H]5VdF;AI]1V
d@02H[400f:`HZmR/004H[05H[400f:`H[5N/@02G[03G[401Ej`GY1NT5j@H[000ej`0f:^0ej?0ej@
0ej?0ej>0ej?00=NKUi]GV`00Uj=00ANK5j=GXeNS@9JKP03FXmJSEY/009JK@EJK003FViJCUY>009J
K@03FVaFKEI<00=FKP9FC003ET]FCEY=009JC@9FC005ET]JBUI;ET]FC@02ETh3ETd2ET`0159=ETiB
;E9<0e9;0UI;00=F:UH[ER/00UH[0U8[0U8/0dh/0e8[1dh/00=B:e8ZDRT00E8<0002244322400``Q
344<HP02344020aQ344881A1=DE:;Uj?GY05FW02FW4015ZAGW1NL5i`0Uj@3EjA0UjB00AN/EjbG[5N
T@9N/P9R/P06I[9V/FJaH[9NCEh90UWY15gW15gX0eh8168815h90V8Z0Uh900]N25gYDJY9JDf9FLYJ
2UhZHPQN25X9009Eb00JDJQ=Z4VYAJQ5IC2P:64i15XYH/mRdEkBCRi5kDH>CRm5k3V:<@He13D3=@@e
ACV8>HM5b`9:3@0KBNa:34W[ALY1RDF7AJM5bTh<EVeNReH/>DD`h4GYIc9Vl6:^GXeR[VK_H/mFSe9>
ALTa11A100<0000D540TX4G8J^ec<VkbK_A^mG;cMc=oMFkAAJ/TH1QQ6:<HX@a1224@H`8DX`0358<D
Q1BT008DY0056:DHa1RT6:@HY@036<D011RT6<DHaAc50QbU018LaAc47<@La1c568<PHCe[McMo^Gnj
M[=]kFF9GFQMR5fYGJP2HLT01F7:GJUIR5F9FJT00V7:0VG900=YbFgYKNL00VgX011YjFVWJJM]b6W8
KLM]ig87MRYf:g8[LRefKGZ=OZmncP9nk`06O_1nlgkcOa9o4glb0WmE00AoN7mHOiYo_11oo`0EOY5=
:cU/@H`m[46/?Le1cD7]ANe1c3V<>Jdm[3g<@Le1[3f/>J`m[3W=00Di[@<i[004>H/eRSF;=H/3=HX0
136:<FXaJS5[0S5Z00PeJSEY=HTaJBDY58@800@010@Q00<480PP22000PPP010<@A11564LXbSU:BPY
2BdY;BP]2BdX;BT]2346<@DLQ08<8@03440<@11R008DP`0;46<88@`P564LPRSS<BDa9bd68<@D@@02
32001A103408@0PP22400PPP00<8@0a136400PaQ00<<@@Q124400`Q10`PQ0Pa000X@@11P340<01QQ
=B95b6:ZKc9_=0I[5@9[5006JaE_5FleKaE_56/D4f/E0VlD00A_5FleKcE[=@9_=@04KcA_57<dKcH8
KcD6Kc@6KcD3Kc@5KcD5Kc@6KcD00fldKcE_=@05KcD016lfKcE_5FlE2FlD0VlC00A_56ldKc=_=0E_
4`A_5005KaE_56lDKaA[5003Ka<2Ka@2Ja@2Ka<8Ja<01F[cJ_9ZlV[bJ_<016/C0V[c00=ZlV[cJ_<0
16[c00=Zm6[cJ_<00V[b00=ZlF[bJ_800f[b0f[B16[b16KB00EVlfKBI]5VdFKa009Vd@AVdPAVd@9V
dPAVd@05I]1VdF;AH]9Vd@07H]42H[42H[000f:_H[1R/004H[03H[42H[0015jaG[1N/5ja0Uj`0ej@
1Ej`0ej^00=N[ej@GY000ej?00=NT5j?GXl00ej>0Uj?00=N/6:`GXd00Uj=00ANK5i^GVeNK@9JK@04
FViJSUZ=FV`7FVd01UY^FTiJCUY]FViJK@IFKP03EVeJK5I=009JC@MFC004ETeFCU9>DTd3ETd01UI<
DTeB;E8]DTaBC@9BB`9FB`=F:P05ER]FBe9;DR]B;004CR`01E8[CRaB:e8[CR/014h/00A>2dh[CRYB
:@5B;00000@<@@Q124488P888@0<3248@@PQ324<@A1R220<834UBRiNSUjA1EY`0UYa00EJTEi`GW1N
L5j@00eNT@ANTP0@GY5R/EjAH[5N/V:cH[9V/V:@I[1R/69=GNQIb5W9GNP2GNL5GNP4GPP3HPP2GPT0
0ehZHRYN:P02HRX0:Eh9GNUMjE6Y?DU1B5W9GPYR:Uh8GPMIjEG7CHMAYe6XBJU9Z4V6=<8XPSf8GX][
4VKbFY15kCeZ>DXiJCE7<DLe9SD4=B<e0cE5=FI1Z46Y?HP00SUW00DmJ3f7?HM1QceW008iAP0N>FM1
b4hZCRY1QC30@HIR[W<]GXaJC5Y=BN]5bE9<HXiN[DWZ;>@<8@00100@82BQALUZcG<aKa9_5Fkd0W<D
00]kM6kbAJ/XH1QQ7:8HP@a1228@HaS3008DX`0358<DY1BT00<DY08HY0066<@LaAc57<DHa1RT0abU
00<LaARU7<@00Qc400/HaB2U:>INLWonOo]k=FhaGFU=:DU90099J0A9I`06ADI19T4VADM9IdV90Tf9
00IAJ5EWFFIIIeUVEFL2DDL015E7GFMQQFV50VV301MYYFW7JNY^CFi^KY1b/G;CL]9fdgJcN]9nlWlA
O`mnl7k^O`io<GmfOkYog7on00ioo`04FDXm2CU[@J`2?J`01D7<@Ne1kT7=?J`00cV<00Lm[3f[?J/m
[3V/>Ldmc@04>Jd2>J`00cV[>J`eR`03=HX00cEZ<FXaJ@02<FT2<FX022eZ<FTaJC5X<DPaJRDY58@2
100312431203220234401aB27:<TiBdX:@P]234X008]2@0I;BTa:347<@DHPa12320@@0`P368@PaBS
46<<@Pa1564LPRcS;@Da9Rd67:@D@@`P20000`a000<880@022000PQ000<<@0a136400Pa100<8@0a0
244010Q100h880Q0340<@11P340@81R1=@55b6J[Kc9_<f/D16/E0V/D0f/E0f/D00=_56/EJaD01f/E
00=_=F/EJa@00V/D16/E0flD00M_5F/EKcE[=FleKcA_<`02Ka@2KaD00flfLcE_=@04KcD016ldKaA_
=6ld1Fle0Vld00=_=FldKc@01Fle00=_=6lcKc<00flc1fld00E_=FldKcA_=Fld009_=@9_=P04KaI_
5FlDKa<5Ka@01VldKaA_4f[bKaA_=09_<`E_4`E_50M_4`08KaA[4f/DJaA_4f/BJa=[4P9[4`05J_=[
4f/CKa=[4P02J_4016[bJ_=Zlf[c0f/C00=Zlf[bJ_800V[b0f[c00=Vlf[bJ_<00f[b0V[a0V[b00AV
lF[aJ]5ZdPAZlP03I_=VdVKB00=VdPAVd@AVdPEVd@9VdP=Vd@04I]9Vd6J`H]43I]400f;AH]1Rd002
H]400f:aH]5Rd@02H[400f:`H[5R/002H[02HZl7H[06G[0016:`G[1N[ej_0f:^00AN[f:^GXmRS`AN
S`9NT003GXmNSUj>00ANSP06GXeNSUj=GXeNK5i]0Ui/0ei]00=JSEZ<FV`00UY]00=NKEY^FVh025Y^
0UY]0eI^00EFCEI<ET]FC5Y/00]FC@EFC003ETeFC59<009BC005ER]FBeI:ETYJBP04ERX015I;ER]B
:e8[0dh/00=B:dh/DR/00U8[1Dh/00=>:dh;DRX00Dh<0006244322402@PP320880@0320]1DH=FXiN
/@05FW03FW43GW02GY0:GY42GY805UjCGY9NTUjAG[9R/EjAH[5N/V:bH[=R/F:@IY1RSV9[GNMIj5gX
GNMN1egW15gX15h800MR268WHRMR9f88GPUN2P03GRX02f8ZGPYN2UgYFLYEZUWZGPUN;5h:GPT00Uh8
01AMaeW8EJMAZ4V8BJQ9QcdT>DM>36;?IaARdUI>@J/`iRRV:<De9S4V0S450SDU00He9SUX?JPeAS4U
;>D2<@D06S44=B@iACU6>DDe9CU7?HPmYd7Y@HH``3D4ALU>2d7:>FLe9CCT=>8mIU9<FXiJdDX:;>D2
20005A0P8811Z6[=Me5c=6kcKaA_5GMFNgIc54W;:60LHAb26848@0PR46<HX`025:<75:@36:@00aS5
6<@HY0036:@011bU7>HLiQc50Qc4018LaARU<DYRdgNkLc=VCTe[A@M0iD3VABI11CcT><<lhcd4?><2
><<2?@D01CT5?@Dm1D45ABH00d4500<li4DVADL00TDV01=9AdeWDFIAIeEWEHUEZUW;HPaR;FH<JReZ
:fW[JP]Z3Fh]KTm^K`03LVl01W9`M[5nlglfOiMog09og@Yoo`05GSDhaST9=FXmR`02?J/01d7<@Ne1
kCg<?J/i[3F<008i[08mZ`03?J`icCW=008i[@<e[@<e[08eR`8eJP<aJP04<FTaJS5Y;FX4;DT01be8
;BLaB2D846<000@000@48@<48009220<80a0344DHQbS:>D]:2T7008]:08a:00O;BTa:C4X;@HHP``Q
220@@0a1348@HaB346<<@Pa1564LPBC3;@Da1Bd76:D@@P`P200<80Q03408@0a032000`Q00Pa100<8
@@a124400Pa01PQ10`a00Q1000PLPSDRALMRZF/bKc=[4f/D1f/E0f/D26/E00=[5V/EJaH00V/E1F/D
0V/E0VlD00A[5FleJcI[=@=_=@03KcA_56lE009_5@03KcI_=Fle00A_=@04KaE_56ldKc@5KcD2Kc@0
0fleKcA_=@04KcD4Kc@00flcKcA_<`04Kc@00fmELcE_=@04KcD02FldKcE_=FlEKaI_5FleKaE_4`04
Ka@00flEKcA_5004Ka@2Kc<5Ka<3Ka@00flCKaA_4`04Ka<016lDKa=_56/C0V/D1F/C0V[c0V/C00M_
=6lBKa9[4V/AJa9Zl`02Ja<3J_<3J_82J_<3I_<2J_83J_43J_800f[aI_5ZdP02J]801F[cJ]9ZdV[a
I_801VKB00AVdFKBI_5VlP9Vl`9VdPAVd@9VdP=Vd@08I]9ZlVKAI]5RdFKAH]5Rd0=Rd@IR/@03H]1R
/F:`00]R/003HZmN/5j`00EN/09N[`=R[P03GZiNSV:>009RS`=NS`9JT00=GXmNSUZ`GXmN[ej>GViN
SUj?GXiNKUi/GVd00ei/00QNKEi/FVeJKEY/FVeJKUY]2EY^00AJKEY^FVeFC@9FKP9FC@=FC006ETeF
CUI>ETiFCEI<3EI=0UI<0UI;00AJBUHZFRYJ:P=F:P9F:`9B:`E>;003CR]B:e8[00E>;09>:`5>2P5:
3@0010Q10PPQ0PQ100<88@PP20000P@000D<@BT5ANaNSEj`009JL003FVmJL5Y_00=JL@=NL003GVmN
Sej@00ENT@0=GY9NTEjAGY5NTUjbGY=NTUjAGY1N/F:aGY401F:a0V:@00ARSFIZHPIN1`AMi`9Mj09M
i`AN2006HRMR1eh7HPIR1f8815hY0Uh900MN2Uh9GPUN25h9GRYN:`02GPX2GPT05Eh8FLQAZ4fWCJI=
Z45WAHQAjf;@Ia9NdUZ@DRhmRC2T72<XQ2cT<@Da1002<@D0>SD5=BDeASE5;@@PXaQR688TXbRS;><a
0c4T<@</`bS4<BDiISfW?HH/hRBR;><]12C568<@@@`P768/`SE3BNQBK5Z=ANX/iAA1540TP4FWJ/]g
LGMdLcA_4flfLeMkV7<eCLX/H1a0688HP@a1224<HQB20QBR00<DPaBS5:@01QBT0QRT00@HXaRT6:@H
Y08LY@0?7<DLa1c47<@L`aRT58D]1d7[CTm1bbcU:8@da3C3008`a005<>@`hbc3;:8/``02<>@0133S
;>@`hbcT0S3T00<e1CCU=>D00SCU0ST50SST0cCT00Di13d5>@Di1CTW00<mJ@0I?DU1BDF9CHY9JDE9
AFU=JDUXCFQAJ5V9FJQIbUW[FPeN;UiaGU5RTf[FLcUkNWnjOoh00Woo00Mo_fllDQDe;SD:<@LeJP02
>H/01Sf[?Ja1k47<?L`m[0@i[003?J`mZcV/008i[003>Jde[CF]008eS08eR`03=HXaJS5Z00PaJ@8]
B@08<DPaAbe8;DPa9cEW9@L@H`840003124480@P00@480888005340@HA1R6:<Xi002;BH01BdX;@P]
22d7;BP00Rd801LTiQR320080110364<HQ1R58<@HPa2344D@Ab18<<XiBd5;BLLYAAS344<80a000<8
@003340880Q000<8@088@@042408@@a03446244434001``P688e8TFWHVQ[4Vlc009[4`=[5@9[509[
5@9[50U[5@03JaI[5F/F009[5@A[5005Ja=[56/DJa=_5002Kc@6KcD016lEKaA_5Fle16lE00=_=Fld
KcD00VlD0fld00A_=FldKcE_=@=_=003Kc=_=6ld009_=@E_=0I_<`Q_=003Kc=_4flD009_5@03KcE_
56lD00=_4`9_5003KaE_56lD009_509_=09_<`I_4`9_50M_4`9_5004JaA_56/DKa@3Ja<016/BJa=[
4f[c0f/C00Q[4VlBJa1_46[aJ_=[4f[b0f[c0f[b0V[c0fKc0VKb0f[a0f[b00]ZlFKaI]5VdF[AJ_=Z
df[bJ_5VlFKA00EVdP03I]5VdVKA00EVdPAVd@9VdPMVd@ERd@03I]1R/6:a009R/@IR/003H[5R/6:`
00QR/003HZmN/5j_00EN/09N[`=R[P=NSP03HXeRSej?009NS`9NT006GXmN[eZ`FXmNT5j>0ei^0Ui]
1ei/1UY/00=JKEY^FVh01UY^00=JK5Y]FVd01EI=0eI<00IFCEI>ETiFCUI=ET/5ET`2ETd00eI<ETeF
C@03ETd015I<ET]FBeI;1eHZ158[14h/14h[1Dh/0Th[0DhZ0Dh<0003244234800`Q23448@@022240
20`P200880a1:@A1bUY]GZl2FW000eZ@FY5JL003FW43GW02GXl4GY02GY4015jBGY5NTEjA1EjB00=N
TEjaG[401Ejb00QR/F:`HXmRSVI[HRMN1eWX0UgX00=MiegXGNP00UgW0Uh800QN2Eh8GPQR1f8VHPIR
1f880ehY00IN:5h9GPUN2Uh9GPX3GRX3GPT05EWYFNYIbE79CJQAae6WCJQ9ZE7ZHZiRdUZAEY5FKe8]
ALX/HB0R744XXP02:<@01bd5<@D`iC45;@DXi22S008HP`0C8<@PXab28:8/hS54;@8X`R22;<8eA3V7
?JL]9Q1S444DHQ1232000PP001l@@Ab39:<a8dX9G/eJd4GY=@8TP210@HIZbgM`MgAVlVKCI_E_Eg=F
K_=AbRaP840LPQR146488@aR488DX`0258<:5:@36:@01QRU7<DHaAc56:@LY08La00<6:DDHaB38<<T
iB2S88@PY1b48:@PaBC522CU00<XiBCU:>D012CU00LXiRd7;@H]1RcU:>@Xa002:>D022C49<<PXbC3
:>DXa2SU;@H2;>D01S47<BLa:34X;@P]1`8a1`0?;>H/iBcU<@Le:3DW=BPa1RcU;>Ha1S47=DTiB3e8
0091J@06?FTeBSU/>F`a2c490SEZ00XiRSV<>H/iRcf/?J/i[3g=>L`ic@<i[003?J/i[3V/008i[0<e
[004=H`eRc6;<F/3<FX2<FT04S5X<FTaJC5Y;DT]JBe8<DP]B2TX;BPa9CUV9@HDH`P010048@84800>
124480@P12088@PP344@HA1R6:<Xi2d5<BL]:08Y208]200H:@PY2B3V58<880P0440<@@aR46<DPQ1R
444<@1A0784P`bCU;BL]1abU56<<8@a10Pa01@Q00PQ10`PQ00L8@0Q1340<@@a024488@0324402`a0
220<@0Q1220HPSDSAJIRJ6/AKc@00V/C0f/E0f/D36/E00=[5V/EJaD00V/E0f/D00=[=6ldKaD00VlD
00=_=6/dKc@00Vle0f/f16le16lE0Vle0flD0Vld0fle00=_=6leKcD00Vle0Vld0fle0fld0fle1fld
00=_=FldKcD00Vle0Vld0VlC00E_56leKcE_=Fld00E_509_5@I_5005Kc=_56lCKaA[4`02Ka@2Ka<0
1FlDKa=_4flCKa@00flC00E_56lCJaA[4f/D009[4`A[509[4`07J_9Zlf/CJa=[4V/CKa800V[b0f[c
00=ZlV[cJ_800V[b0V[c16Kc00=VlV[bJ_800f[c00Q[4f[aI_5VdFKbI_5VlVKB0VKb00AVlf[cJ_9V
lPAVdP9Vd@=VdP=Vd@04I]1VdFKAH]83I]800fKAI_9VdP02I]400f;AI]5Vd@02H]400fK@H[1R/@03
H[43H]03H[43H[03H[4016:`H[5R/5ja1Uj`00ANT5j`G[1N/09N[`9NS`=NSP04GXmNT5j@GXl3FY00
1Ej>F[1JSeZ?GVl015j?00=NKei]GVd00ei]00AJKEY/FVeJK@YJKP03FVeJKUY^00=JK@05FViJKEY=
ETeFKP03ET`00eI=ETiJC@02FTd01EI;ETaFC5I<ETd015I<15I=00=BCEI>ETd00UI;00=F:e8[ERX0
15H[0U8[00=B;58[CR`00dh/0Th[14h/00I>;DX]CRa>;4h[CRX1CR`00088@@03344<@Pa100<<@@88
8@09340@@@a0444Xi46XFVaNSEY^009JK`EJL09NL09NT004GXmNT5j@GY0<GY400ejaG[9N/P04G[80
25jaH[1R[fJ_H[1VK5h7FNL3GNP5GNL2GPP00eh9GPQN2002HPL00f8VHPIR9`03GPT2GPP01688GPUR
:Uh:0UhZ0UhX00MN25h9ELU=ZDfXDLUAb003DJL04EG9GT]NBUH]DRi>3EY_FXm9jS33848XQ2c3:<DX
a2RS;<<00RcT00DTiBC57:@HPabS008PX`0C78<HPBS3<D@i@bcS9:<TXS4S?JQ5bCV:56@400001008
00`P56400QAR01/<00P0;>5BAfL>H/a5ac3R8411I6IYMbaZcVJ>HTeRCfJ`La9blEG:;60PH1b2684@
@@PQ46800Q2200<DXaB358<00QBS1ABT0aRT00LDY1RU6<DLiAS57<DHa@037<@01Ac56:@HYAc56:D0
0QRT00HDPaRT7<DLaB359<D68<D39>D2:@D012CU:>HTiBSV0RT60RSV0bT500<XiBCU9>D00RSU0RT6
00DY1bdW;BL]9c4X008aB0@]:08a:00;=BLa9c4V<BHa9c47;@L/iRd6<BL]1P04:>H01Rd7<BLa:34X
<DPeB@8iJPDeJP8iR`04>J`mcCg=>J`3>J/00cf/>J`i[005>J`3=H/013EZ<FTaJC5Y0S5X00<eJ358
<DP00S5800`]JC57;BL]:2TX;BL]134T8>DDH`@0200312000`@Q1204800222402@PP344@@AAR6:8X
hbT4;BH]1`02:@P03Rd8;@T]:S5;:@LHQ0`Q200@@0a1368@PaB2444244002AA0688Pa2T5<BLU1abT
544<8002340010Q1340<@0Q10PQ000H88@PP22488@PP24043404244030PP340<@11Q468<@ARS=B=5
YV:8Kc9_<`9[4`04JaA[5F/EJaD3Ja@4JaD7KaD01F/FJaE[5F/EKa@016/D00=_=6lDKa@00VlD00A_
=6lDKcE[5@9[5P07KcE_=6ldKcA_5FleKcH00Vle00=_=6lEKa@00VlD00=_4flDKc@00Vle00A_=6le
KcA[50M_=0U_=@U_=005Kc=_4flCKa=_5003Kc@01FlDKcA_=6ldKa@00fld00=_56lCKa@00flc0flD
1FlC00A[4flCKa=_4PI_4`9[4`04KaA_4flDJa@2JaD026/DJa=[4f/AJ_5ZlV[cJa84J_82J_<:J_80
0f[cJ_9ZlP03J_801VKCI_=VlV[aI_5ZlP=VlP03I_5VdVKB00=VdP03I_5VlVKb009VdPYVd@07H]5V
dVKBI]9RdFK@H]401VKA00ERdF;@I]1R/F:`00=R/@=R/0AR/@03H[1R[f:`00ER/@09G[1R[f:_HZmN
/Ej`GY1N/5ja009N/005H[1N/5j@GY1NS`02GXh015j?GY1NT5j?0ej@00ANSUj?GXmJS`ENS`03FViN
KUi^00=NKP=JK@UJKP03FVeJKUY^00EJKP06FVeJK5Y=FTeFC5Y[0UI]00AFKUI>FTeJC@9FB`03ETaF
CEI<00EFC0=FC@04ET]FCEI>ET`5ET/2ER/5DR`00e8[CRa>;006CR`4CRd2CR`1CR/1DRT1DP`00088
@@888@04324<@@a13442220234002PP0468TXd67FTaJK5Y>FViJKeZA0UYa0eY`0ej@00=NSej@GY00
3EjA00=N/EjbG[8015jb00QR/F:`HZmV/6:`HVaN25WX0UgX00=Ij5gXGNL00egW00EMj5h8GPUN2Eh8
00AR1`05GPMN2Eh9GPUN2004GPT2GPX01Eh[HRYN2Uh9FNT015G901YEae6WCHI9IUG8HX]JBTW/BLaB
3EY^G[5JKDW]=BTi9d68?FTi9bbR<></i2SU9>DXiBC50QbT0ab301@DHAbS:BHaARSU8:@TXbcS?JPm
Yc5856@400P0348DHQAQ688HPaA10P0000/4034QFZiVjeY/>DDXP3TSENQZQF9W009Mi@0>IRQ^JW;=
L/m=ZC2P760LPQR146488@a1488@P`@DP`035:<DY1B400DDY0066:@HYABU6<HHaAc60QS500<LaAc4
7<@00ac500HLaQcV7<HHaART6:D57<D00ac67<DLi@048>D49>D49@H49>H29@H00bD59@HU1P029@H0
1BD79BLY:2TX:DT022e900@aJS5Y=FTeJ0<eB003=DTa:2dX008aB@0;<FTaBC59=FXeRSF;=HXiRcEZ
=H/iRP02>H/00cF:=FXaJP02<DX01cE[>H`i[3V/>L`e[3F[008iR`8i[003>LdmcCV]008i[08e[08e
R`04<FXaJC5Y<FT2<DP03cE7<DL]9RdV;BL]B357<BP]:2TX;BLa1C4U:@HDP`021003120212452200
10a1564HXbCT0RT501hY1bT8;BTa:2dX:@P]BbT758@400P0320<@0aR488DPQ1R464@@1A06:8Pa2T6
;BLU1ac4540<@@PP34042442240224422242244434042443344246801`a16:<a8TFWHXQ_<F/B009[
4`03JaA[5F/E009[5@03JaA[5F/E00A[5@M_5@9[5PA[5@A[50E_5005KcE[5F/FJaI_5@03Kc@00fle
KaE_=P02KcH2KcD01G<eLaAc4g<CKa<00fld26le0fld1Fle1fld00=_=FldKcD00Vld0VlD0flC00A_
56ldKcA_=0A_5003KcEc=Fle009_=@9_=003Ka9_4flC00=_509_4`04KaA_4flCKa@2Ka<00flBKa=_
4`02Ka<00f/CKa=[4`03Ja<4Ja@01F/EJcE_=FlCJ_800f[c16[b0V[c1F[b00=Zlf[bJ_801F[b00YZ
lFKaI]5VdVKCI_9Vl6KaI_9Vl`AVlPAVdP03I_5VlVKB009VdP9Vd@03I]9VdFKA00=Vd@03I]9VdFKB
009VdP9RdPARd@=Vd@04H]5Rd6;@I]02H[000f;AH[5Rd@02I]000fJ_I[1R/002H[400f:`HZmR/002
H[44G[43HZl9G[04GY02GXl2GY000ej?GY1NT004GXl00eZ@GY1NT004GXl2GVl3FVh00ei]FVeJKP07
FVh00eY_FViJKP02FVh00eY]FViJKP03EVh01EI=FTeJCEY<FV/00UI]00=FKUI>ETh00UY=1EI<00AF
CEI<ETeFC0EFC@04ETaJCEI;ET`2ET/2DT/6DR`;CR`00dh]CRa>;002CR/1DRT1DP`000H88@8<@@0:
224<8110444800`P7:<mAEHZGX`2FVh015j?GY1JTEZA0UY`0ei`00=NT5j?GY000Uj@2ejA0Uj@019N
/EjbG[9N/UjaG[9R/F:`HXmR[fJ`HXeR:Uh9FNUMj5WXGNP5GNL01Eh8GPUN25h8GPL016870Uh800AN
2Eh8GPQN209N2@AN2P05GPUN25h8GPUN2002HRP05UW7DJM=QTeUFNMRJeGX>DHmRTh=FVeNT6:aFTmF
;UX]HXeFCcf9;:8/`RST0RSU00HaAS4W7:DDHQA16682440051AR58<HXaRS68<HPR34<BHa9AbT4488
01AQ588DHAAP684Pa1QR200200006``0AJAZb5Z<@JLXP331BJMIaEh5HP=V9FYWKVIfbfj;BJT`X21P
664HPA1R2248@11Q488DPP0458<45:<01AB45:@DY1RT6:D00aS500@DYARU6:@DX`8HY08La08La@8H
a@XLa@037>DPiB3U008Pi@<Pa@8Ti@038>DTiRCV00@TiP039>DU1RD5008U1@<U1P09:@LY9bTX:BP]
B2e9;DP]BBe800D]B@06;BP]9c57<DPeAc580S5900<aBS5Z=FT013EZ00<eRSV:>HX00cV:00/iZcV:
=FXeJC5:<DTaBSE[=H`iRcV:008eZ`05=H/iRSV:>H/iZ`03>J`01CW<>Jde[CF/=HX00S5Z00HaJC5X
<DPaB35Y<DL3<BL00c57;DP]:003;BP01c57<DHeIRT758<880@0008880<480@88005320@@1AQ6:8T
h`02:@D02RT6:@L]9c4W;@LY1bTX:>HDQ0@00PP0014<80a2488HXa1Q444<81106:<Pi2CV:@H]9abT
544<@0`P008<@0033448@@Q100P8@@@<@088@00>2248@@PQ324<@@aR3488@1B2<@95YV:7Ka1_<P9[
4`=[509[5@03JaA[5F/E00E[5@E_5@03JaE[5V/E009[5@I[50I_5004JaE[5V/FKcD3Kc@00fleKaE_
=@02KcH3KcD01g<cLa=c4g<CKaA_4fld00I_=@9_=0=_<`=_=0I_5005Kc=_56lCKa=_<`05Kc@2Ka<0
0flBKa=_5003Kc@016lCKaA_56lC0flD0VlC00=_<flCKa<00flC00E_<flCJa=[56[c00A_4`A_4P03
Ka=[4f/C00A[4`=[509[4`9Zl`=ZlP9Zl`03J_9ZlF[b00mZlP0;Ja5Zl6K@I]5ZlVKcI_9VlFKAI_9V
l`06I_83I_4016KBI]5VdFKb0fKB0VKA0VK@0fKA1F;B0V;A0V;@0f;A00MVd6;AH]5Vcf:_H[1R/@03
H]04H[02H[4016:`HZmR/6:`15ja00AN/6:_GZmNS`ENT005GXmN[ej_G[1NT002GXl00ej@GXmNS`03
GXl2GY0015j?GXiJSUZ>0eZ?00ANSUj?GVmJKP=NKP04FViNKEY]FVd3FVh00eY]FViJKP06FVh3FVd0
1EY^EViFKUI^ETd00UY=00AJC5I;ETaFC0EFC@9FC09FB`03ETaFCEI<00QFC0AFB`9BB`9B:`03DRaF
:e8/009B;0i>;09>:`5B:@5B300000<88@PP32400`Q20Pa10P`Q00`@@111320401R2>DEFBUj<GXiN
Kej?GY02FW42FW03GW0015j@GXmNT5j@2EjA00=NT5jAGY400UjA0Uja1Ejb00MN/F:aHZmR[f:=HRUN
2002GNP00eWYGNQMi`04GNL00eh8GPUN2002GPP015hXHPMR1f8715h815h90Uh:0Uh;029N2Uh9GRYR
:UhZGPQIjEW8EJQAQe65HRMRRdg9=<8iJDi?EVmJKf;BI_ARe6/DJ_5RdTG<=@HXXR349<D/i3EW;DLL
Y@8<8006544@@@`P220<@AAR0QB200<DPaRS6:<00QR200/@@@`P684U1AbR560DHAbS7<@LaAA20080
000:941JJ5k?ANTX`BR1@B=QhfI4IVH2JVT03G:8M/Y^J4VX;80PP1QP684@HPPQ320@HA2200DDP`8D
Q0HDY0@DY@055:@HY1RS7<@Ha0026:@011c47<DLaAS60Qc60Qc500<La1c57<@00Qc40Qc500DLiB3U
8>DTi23U008Pa@8La@037<HPiR3V00DPiP039>HU1RD6008U1@8U1P059@LY1bDW:BLY:002;BP2;DT0
1be8;DT]BBTX:@PU22T7008XiP04;BLaAc59<DP2<DT00c5Z<FTeJP02=FX3=HX01CUZ>HXiRcV;=H/0
0cEY0S5:0SEZ00<eS3V[>HX00SF;00HeRSV[>H/iZcV;=J`3>J`01CF]<H`eS36;<F/00ReZ00HaJS59
<DT]BBe8<DP2<BP00bdX;DP]B002;BP02bTX;DPaAc568@LDP`@0000400PP12401PPP00L<@111564H
PRCT:BHU1P03:@L06BdW;>H]1bT79>HHQ111320<@0a1368@HQbS468@H@`P440HPR34:@HU1RD77<@H
PQ11008<@@8<H@8<@@P8@@@<@003240880PP00888@8<800;464<@0PP588]0d6WHXQ_46lcKa=[4`06
Ja@3JaD00f/DJaE[5@02JaD016lEKaI[5Fle0f/F00A[5F/FJaE[509[4`A[50=_5003KaE[5F/f009[
=P9[=@03KcA_=Fle00=_=@9_=P04KcE_=6lDKa@2Kc@5KcD01F/dJaA[=6ldKcD00Vld0fle0Vld00=_
=FldKa@00flD00E_=6lcKa=_<fld009_=@06KcA_56lCKa=_4VlC0VlD00A_4fldKcA_=@=_5003JaA_
4flD009_50E_4`9_5005KcA_=F/DJaA_=002Ka<00flBKa=_4P02Ka<016/DJa=[4flC0V/C0f/D0V/C
0f[c0f/C00=Zlf[bJ_400V[b0f[c00=ZlV[cJ_800V[b00=Vlf[bJ_800V[b00EZlf/BJa9ZlVKa00AZ
lP9VlP04I_=VlVKbI_82I_<3I_8016KBI]5VdFKB1VKA0VK@0fKA16;A00=RdV;AH]8026;A0V;@00AR
/6:aH[5Rd@=Rd003H[5R/6:`00=R/09R/@AN/@05G[1N[ej`H[1N/004GY02GXl00ej^GZmNT002GXl0
0ej@GXmNT003GXl2GY0015j?GXiJSUZ>15Z?0ej?0Ui^00=JKeY^FVd035Y^00=FKUY]ETd00eY]0eI^
15I=00=FC5I=ETd00eI=15I<00AFBeI<ETeFC@QFC0EFB`06DT]B;4h/DR]B;58[0e8/44h/0E8:0E8<
00022202224224401@a132488@`Q34400Q1100X<81bS?FENJUj/FViJKei_FW1NL0=JL0=NL09NS`EN
T11NT@9R/@0:GY5R/6:_HXiVRf98GPMMj5W9GNP2GNL01EgVGNMMiegWGPL00eh800=N9ehXHPP01Uh8
00IN:5h8GPQMjEh9GPX3GP/08Eh9GNUMj5WYFLUAbE6XDJUAQe64HTINK4FY;80iB59aDTmFCV:aH]=V
e6:bJ_5R/4h>;>DTXRC49:@/hcUU=FLLa00232001A1R464<@@`P32401@a100P88@PP344@@AQQ6:4H
`QRQ0P`P010@@1RR8>DPXQ00000@046SFZmBBbcS968m0VH4M`]bb`9ZJ@0>JTIbYfYWBJHd`2B1660H
PA23224<811Q48<DPPLDP`0358@DY1BT00<DY0046:@DY1BU58@26:@00abT6:@HY0026:@00abT6:@H
Y@026:D87<@02b347<DLiAcU9>@La1bT68<DPaR36:@00Qc500<PiR3U8>H00R3V0RCV00HU1RD59@DU
1RD79@H2:@L4:BL2;BP3;DL02RT79>PLaQBU7<DTiRT7;BL]Ac570S5800<aJCEZ=FX01CF:00DiJSV:
=H/eRcF:008eJ@8aJ@8eJP07=HXeRcF;=FXeJcF;=HX00SFZ00@eRcV;=H`eS08e[007=JdeS3F<<H/a
RS5Z;FX012e91Re800T]AbTW:BPY:2dW;BH]9B3V58<00P0000D880@P120880@P00@88008340@H1AQ
688Pi2U69@HXiP8Y1`0=;@L/iRd6;BH]1ARS568<80a1348<HQ1R6:800Q1R010<@110584P`bT6:BHY
1R3568<DHQ12348<@@aQ344<@0<8@@032408@@Q10088@@8<@0033448@0PP00D8800:320@H11Q340H
PRd3@JMRR6l@Le<4Ja<016/DJa=Zm6/D0f/E0VlE0V/E0flE0V/E0V/F00=[5F/FJaH00V/E0V/C00A_
4f/CJaA[50=_509_5@03KcE_=Vlf00A_=@03KcA_56lD00E_=004KaA_=6ldKc@3KcD:Kc@01V/EKaA_
5FldKcE_=0A_5005KcA_<flCKc=_=002KcD00fldKa=_<P04Ka8016[aKa9_<flc0Vld0VlD00=_5FlD
Ka@00VlD1VlC0flD00=[56lDKa<00VlC0flB0VlC00A[56/CJa=_4`=[4`03Ka=[4f/C009[4`03J_9Z
lf/C00=Zl`07J_9ZlF[bJ_9Zlf[bJ_<00V[b1V[c0f[b00=VlV[bJ_801F[b2fKb0VKB0VKA00AVd6KA
I_1Vl@AVd@=Vd0AVd@9Rd@IRdP05H]5R/6:`H/mRd003H[0016;AH]1Rd6;@0V:`0V:_00AR/6:_H[1R
/0=N/@9R/0AR[`04GXmN/5j`GY02GXl00ej^GZmNT003GXl00ej>GXmNT005GXl01Uj>GXmJSUZ?GXiJ
SP9NK`9NS`05GXiNKUi_FViJK@0>FVh7FVd00eY/ETeFC@05ETd2ET`5ET/9ET`2ER/6ET/2DR`00e8[
DRaB:`03DR`01e8[CRa>;4h/DR]>;58/00M>;003CR]>2e8:005B300000P8@0PP22488@Q1248<@@`Q
10a200T<@0`P688mIUi[GZiJKeY`GVl00Ui`15Y`00=NT5i`GW001Ej@1ejA00=NT5jAGY401ejA00aR
/F:bH[5R/F:_HXiVRf99GRMIj5gXFNL3GNH4GNL2GPP2GPL015hXGPQN25h80Uh900AN25h9GPUN209R
2003GPUN2Uh[009N2P9N2@0AGPQIj5WXDLUAb4fXCHMAQF97GXe1Qba0=DI:<4h^EU1NT@02H[<04VKC
J]9Ve58@:<HPPR2T9:</hcUV>FPTiAA1344@HQ1Q344<@08<@@0<368<HA1R468<HPa2244DPaR36:8D
XQB10PP0020000`P6:<P`b23540PH3E3BTe:2bd596518fHTM`]bc6Z:JTQZ9FiWITQ=acSP984LPQR2
46888@a1464@PQB21aB300@DQ1BT6:@DY0dHY08La08HY0036:DLY1c400LLa0067<DLiAcU8>@La1R4
0QR30aRT00<LaAcV7>H01B3V00DTiRD69@DU1bD600<U1`03:@LY9bTW008Y:007;BP]B2e8;BLPaAc5
6<H00Qc600DLaBD7:BL]B357008aB003<FTeRSF;008eR`06=FTeJSEZ>FXiRSF;0SF:00<eRCEY<FT0
0S5Z0SF:0S5[00@eJS5Z=HXeRP8aRP@eR`03=H`e[3F]008eS08aR`8aJP@]BP03;DT]:BdY008]B@03
:DT]B2TW00<Y9`07:BH]9B4658<800@022000PPQ1PPP00X<8110444HPR3T9@HTiBST:@HY1`<]1`06
<BHa9ARS444800PP0Pa200@@HAB1468@HP8<@00;684PhbCU:@DY1R3468<DHQ12468<@P0534462442
34401`Q1220880PP120880Q1008<@00:460@H@a06:<XhT6WGVU[4FlcJa<2Ja@00f/CJaA[4`02J_@0
0f/DJaE[5@04JaD3KaD2JaD4JaH01VlEJaE[5F/DJa=_4PA[5003KcE_56lE00A_5@03KcE[=Vle00=_
=@04KcA_=FleKcD5Kc@5KcD2Kc@7Ka@2KaD00fleKcA_=@02KcD016ldKaA_5Fle0flD16ld0VlC0VlB
0VlC00I_4VlCKc=c<g<dKc@2Ka@016leKaA_=6lD2FlC00I_56/DKaA_4flDKa<2Ka800f/BJa=[4`03
Ja@2Ja<00f[cJa=[4`05Ja<00f[cJa=ZlP02J_<4J_83J_<2Ja800f[bJa=Zl`03J_<00f[bI_9ZlP06
J_801F[aJ_9VlVKbI_<01fKb00AVlfKbI]9Vl@AVd@AVl@EVd@9Rd@03I]5RdF;A00=RdP04H]5RdV;B
H]47H[03H[42H]02H[03HZl3H[03G[402F:`HZiR[V:^H[1R[ej`GZmNT003GXl4GY000ej_GXiNS`07
GXl3FXl2GXh6GVl00eY_GVmJKP04FVh00eZ?FViJKP07FVh3EVh01EY]ETeFCEY]FV`00UI]00=FKUI=
ETd00UI=0UI<1EI;0eI<00=FBeI<ET`00eI<0e9;0eI;0U9;0U8/00=B:e8/DR`00e8/00AB:dh/CRaB
;0M>;0=>;@03CRa>2e8:005B30000PPP00X400PQ344@Ha1R224<@PQ334<<@P840004544e95I;HZd2
FW02GVl3GW000eY`GW1NT002GW0015i_GY1NT5j@2EjA0Uj@00=NTEj@GY4015jA00aR/EjAHY1RT6:?
HXeVRf99GPMMieWWFNH2GND00egVGLMMi`02GNL2GPL3GPP01687GPQN25h90Uh80eh700YR1eh8GPUN
:69;HRYN25g9GNUR209R:00>FNQIb5W8DJQAQFI6GXe1QbQ0=DE:;dh_EW5NTP=R/`0AI]AV]58@;@PL
HQR388</`cUU=FHTa10P440@HQ1Q220<@00234400`a2468@H@0258802AAS568HPabT7:<@PQ1Q3208
000210005Pa0684P`cU4?HHmQd7:?HP/i2B2@DAV97;8L/YZZfYYIREZ9FHXBHDdX21Q0QR200D@HPPQ
320@HA2200@DPPDDP`035:@HY1RT00<HY0045:<HXaRT6:<26:@01QBT6:@HY1RT7<DLa0<HY0037:@L
a1c400LLa08Li08La00;58<DHQbS9@HLY1AR6:@LaQcV8>HPi@038>H29>H012D59@HU1RD60bD700<Y
1bTW:BP00RTX00`Y:BTX:@DPaABS7<DPaAS57<DTiRTW;DP2<DL01358<FTaJC5Y13EY0SUY0SV:00<i
RCF:=HT00c5Y00<aJ35Y<FT00c5Z0SEY0c5Y00@aJSF;=H/eR`8eS08aS08eR`03<H/aJReZ008]J`06
;FX]BRe9;BPY:2TY0bTX0bTW00DY1be7<DHU1aB3008800<8800312048@PP00<8800:320<@111688P
i2D5:@@Xi2d5;@L3;@H01c4U<@<LX``P200<@@aR008@H@03584@HA1Q008@@@08684P`bCT9>@TiAbS
688DHPT<@@88@@@<@@88@088808400041208@@a0340246002Pa06:8]0d6WGVU[46lCJa=[56[d0V[c
0f/C00=[56/EJaD00V/E0flE00=_56lEJaD00V/E0V/F00Q_5VlEKaA[56lDJa9_4V/C1F/D0f/E0VlE
0Vle00=_=6leKc@00flD1Fld00A_=FldKaA_509_=@03KcA_56lD00=_509_=003KaA_4flC009_5008
Ka=_56ldKcE_=6lDKaE_=@9_509_4`03KcA_56lc009_4`9_4PA_4`=_<`9_4`A_50m_4`03Ja=_4Vlc
00=_4`=[4`03Ja9[4f/C009_4PAZl`AZlP04J_=ZlV[bJ_45J_85Ja83I_<01V[bI_9VlVKbJ_9Zl@=Z
lP04J_5ZlVKcJ_83I_82I_43I_82I_43I]43I]001FKAI_5VlFK`I]000fKA00=RdFKAI]400fKA00MR
dFKAI]5VdF;AI]5Rd@05H[000f;@H[1R/005H[03HZl01V:^HXmRSf:`GY5N/@9R/0=R[`06HZiR[f:_
HZiNSej>0Uj?15j@00=NSej>GXl01Uj?00YNSUj?GXiJSUj>FXiNKeY^FVeJKP=NKPEJKP04GVeJKUY]
FVd7FVh2FVd01UI^FVeFCEI=FVaJJ`9FK003EVeFCEI=009FC@9FC0MFB`04ETaFBeI<ET`2DT`6DT/6
DR/5DR`0158[CRa>;58/0Th/0dh[0Th/0dh]0Th/0E8:0E8<0002220222401`Q1344<H@a12448@PPR
00<40007444a94h[FXeJKeZAGY000Ui`0eY`00=NL5j@GY0015j@1EjA00=NT5jAGY402UjA0Uja00QN
/V:aGY5RT6:>IXaRBUhX0egW00=MiUWWGLH015gW00=Mj5h8GPP015h800AN2Eh:GNUN2@9N2008GPMN
25h9GPUN:F8YGPQMj@9Mb@9Mj00FGPQRBV8YELU=QU64HTIJKD6X:60iADX^EU1FLUZBH[=N/UjcHY9V
]4W`;@P266801Ab2:<<eA3V8:>D00P`P00<<HPaQ34400Pa10Pa201l@HQ236:<HY1B3568HPb3U6:<D
PQ1Q440<80PP100000PP;DMFSUJ??JLiA3UT<@<XPT55JTIfkFk=JXeZJ`02IRL02eh:AFH`P1A0664H
PQAR324<811Q46800aB20QB300<DY1BS5:<00QRT00<LYART6:D02QRT0QB300HHaAc47<@HY1bT7<@2
7:@37<D47<@27>D031cT7<@DPab38<DLaART544HPaS57>DLiP<PiP038@HPiR4600<U1P8U1`<U2004
9@LU:2TX:BP2:BT01BT79>HLaAc59<D00Qc500<TiRTW;DP00S570c580c5Y00HeJCEZ>FXiJSV;=H/3
=HX6<FT00c5Z<FTaJ@03<FT01C58<FTaJS6:<H/00cF<00HeSCF/=H`eRc6;<FX3;F/01BeZ;DX]B2TX
:BT012TX0RTW00TU1bT7;@HaARD7568000@022400`PP00D48@PP220880PQ008<8008444HPR3T:BH]
9BcT;@DY1P<]1P07<BHe9AbS448<811Q36400Q1R00<HXQ1Q46800Q1100/HPQbS9>@]1BCU7:<HPQ11
200<80PQ00`<@@88@@0422088@PQ124222400`Q0340@H00234001ARR<BE1bEj:Ja400V/C0f[d0V[c
00=[4f/DJaD00f/E16lE00=_56/EJaD00f/E00=[5VlFKaD00VlD0VlC00A_<f/DJa=[4`E[50=_5004
KcA_=FleKcD3Ka@01FlEKaA_=6ldKcD026ld00=_5FleKc@016ld00=_56lCKa<016lC00E_56ldKcA_
=FlE00=_5003Ka=_56lD00=_50=_4`09KcA_56lCKa=_56lcKaA_4fld00I_5003Ka=_56lC00M_4`05
KaA_=FleKcE_4`02Kc@00flCJa=[4`03Ja<016[cKa9_4VlB1f[c0f[b0V[a0V[b0V[c0V[b1f/C16Kc
1f[b0V[c26Kb00=VdVKaI]400fKA00MVd6KAI]5VdFKbI_5Vd002I]401F;AH]9RdV;BI]400f;A00AV
dFKBI]9Rd@=R/@03H]5RdV;B00=Rd@UR/004HZiNSf:_H[02GY02H[05HZh2HZl00ej?GXiNS`05GXl2
GXh7GXl2GXh025j?FXmJSUZ?FY1JKUY]FVh3GVh00eY^FVeNK@02GVd015Y]FViJK5Y]1EY^00AJKeY^
ETiJK@EFKP9FK@03EVaFKEI=00EFC@QFC005ET]FC5I<ETaBC004DT/00e9<DRaB;002DR`3DR/6DR`5
CR`3CR/2CR`4CRd1CR`1DR/1DP`00004240<80`P220222401Pa0344<@@a1324<@@880005448]1DX;
GVeNS`02GY02GW0015Y_FW1JL5i`1Ej@00=NSej@GY001UjA00=NT5jAGY401UjA0Uja0Ujb0V:a00IR
T6:>IXaRBUhXGNP2GNL2GLL00egVGNMMi`03GNL00eh7GPQN2003GPP01eh9GPYMjUgZGPUN25gW009N
2006FNUN25gXFLMIb5FY0UFX029EYeG7DLQAb56WCFEAPV8TGX]5b2bP>B=:35Y`FY9NTV:bH[5RTUjB
HY=9kc48648D@AR2:<@iICVZ:>H<80PP364<@0@<@@0H348@HQ1R588DPaAR68<LXac46:<DPQ1R444<
80PP200400@Q8@M::DY;?JDT`BS10RRQ01I5Z6YXL/iZS6I/HRUR25h8FN]1AS1P520HHQR2468<8@`P
464@HQB258<DPP<DP`8HX`036:@HYARU00<HY@HHY0<HX`0958<DQ1S56<@DXabT7<@Pi1bT00@La@@L
a0047<DLiAcT7<@27:@26:@01A12444HY1c57>D00R3U0b3V0R461BD70bD80RD700TY9bT8:BTU:BTX
9@LPaQc59>D00R3500`Y1bdW;DPaAc4W<DLaB357<DPaJ35Y=FP2=FT2=FX013F:>HXeRSF:135Y00<a
BC5Y<FT00S5X135800DaJC5Z<HXaRcF;008eS00>=J`i[3F/=H/aRc6:;F/]JS5[;FX]BBe8:BLY20<Y
:08Y9`8U1`07:>HXi2e58@H@H@@0200010PP0`@P0PPP0P`P02<@HAR28>@U1RdU:>@]1BT5;@D]1RdV
;@H]1ART548<811P340@@A1R584@HA1R340@@AR28<<TiC4U;@HTi1R2320800`P00P<@@8<@P032488
@@Q1008<@@@88@88@@0<340<811P460@HARS<BA1bEjZJc9_<f/C0V/D00EZm6[cJ_=Zlf/D009[5@03
JaI[5FlE00A_50E[5@9_5@06KaA_=6/CKaA_4flD16/D00A[=6/DJaA_50=_4`M_5005KaE_=FleKcE_
5002Kc@01FlcKa=_=6ldKc<00VlD00A_5FldKc=_<`9_=0M_4`04Kc=_=6leKcD2Kc@2Ka@3Kc<3Ka@2
Kc@00flCKcA_=002Ka@2Ka<016lDKa=_=6ld1VlD2VlC00I_56lCKa=_4f/CKa<7Ja<2Ka<016lBJ_=Z
lf[c16/C00E_4V[bJ_5Zd6[a00YZlPMVlPMZlPAVl@05I_9VlfKBI]9Vl`02I]800fKaI]5Vd@0:I]43
H]86H]401f:aH]5RdF;BH[9RdFK@00IR/@03H[1R[f:`009R/09R/@04H[1R[f:_HZl3H[02HY0016:_
HZiR[V:^0V:>35j>1ej?0ej>00ENSej>GXmNT5Y^009NK@03GViNKEY]00MJK@03FVaJKEY^00AJKP03
FVmJCUY>00=JK@=FKP9FK@03FV]JK5Y]00AFKPEFC@AFC003ET]FC5I<009FC09FB`05DT]BC58]DTeB
;@02DR`5DR/7DR`2CR`3CR/4CR`2CRd1CR`1DRX1CP`0000;240880`P320<@@`P344<HQ1S468<@@02
44002@`P448XiD7:GVeR[UY_FViJK`04FW000ei`GY1NT003GY000ej?GY1NT005GY400ej@GY5NT@06
GY42G[45G[802f:aHXmVSF9;GPUMj5gWGLMMaUgWGNH015gW0eh70Uh800=N2Eh8GPT00Uh900AN2Uh9
GNUN209N2@04FNUIbEG9DLT2DJT014f8CHMAQe660U6V0Tf601mAY696HZ]9j2bP=@A5c5H^EW5JLUjb
I[9R/V:cG[=F;c47668@8AAR:>@eISV[9>H<@@PP344<@0aR468<HP02348246824642468031AR58<D
PaAR468@@@a0200<80@0004<H`8Q1P0D460<81QP660XXDW[JZYZ[6I[GPUEYUG7GPQIjdV9<60P@1AQ
688@HP8<@@03464DHQB200HDP`036:<HY1RU00@HY@<HY0<DY08DX`8HY0055:DDaAS46<@La@027<@5
7<D57<@03AcU7>@La1bT68<HY1R458<LY23U8@HLiB3U00LPiP8Q1P8U1`<U208U1`8Y1`05:BPU:BTX
9@PU1`049>D01bT7:BL]B357<BLaAbe8008aB007<FPaJC5Y<FTeJCEZ>HX00cF:0c5Y00TaBC5Y;DT]
BBeZ<FT]BC58<DT00c580S5Z00/aRcF;=H`eS3F/>JdeS3F;=H`aRRe[008]JP8]BP04;DPY:2T8:@P2
:BP02BT79@LTibCV:>HTaBdV7>HDP`02200222000`@P2204800312002@PQ320<@1AQ688LXb3U9>DY
1@03:@H072d7;BLY1RCV6:D@@a12464@@A12468DPQ1R464<8110688LXbSU<@D]9RCU688<@0P03448
8@`Q1`a10`Q10Pa100@8@@PQ12488@<8@@0:344<@0aP360@@1R2;@=1Z5j9Ja42Kc@2Ja@4J_<016[d
JaE[5F/F0V/E00=[56/EJaD01F/E0flE00E_=VleKcI[5FlD00Q[50M_5003KaE_56lE00=_50=_=0=_
50A_=09_5004KaE_56ldKc<2Kc@2Kc<3Ka<00flBKa=_5002Kc@2KcD00fldKaA_5003Ka@3Kc@4Ka@3
Ka<01flcKa=_56lDKcA_<fld009_4`A_50E_4`E[4`E_4`M[4`9_4`03Ja=Zlf[c00I[4`04Ja9ZlF[a
J_44J_8016[cJ_9ZlV[a0V[b00=VlfKbI_801FKb1F[b0V[B00=ZlFKaI_800fKc16KB0fKA0fKB0VKA
00=Vd6KAI]400VKA16;B00=VdV;AH]800f;A16;B00=VdVK@H[001V:a16:`0V:a00=R/6:_HZl00V:`
00=N/F:`H[000V:@00=RSej?HXh00f:>3Ej>1Ej?00INKF:=HXeNSej=GVh2GVl3GVd3FVd00eY/FVeJ
K@03FVd00eY/FVeJKP02FVh00eI^FViJKP02FTh00eY]FViJK@02ETh01UI^EVeFKEY[FVeJK0=FKPIF
C@AFC004ET]FC5I<ET`4ET/4DT`2DR`5DR/7DR`4CR`014h[DR]B:e8/14h/0Dh[0Dh=00002`Q02208
80`P340<@@PQ344<HQ2246800Q1Q00h<81119<A1ZEi=HX]JK5i]FViNKej@GVmJL5i`1Ej@0Uj?00=N
T5jAGY000Uj@1ejA00ENT5jAGY5NTEja009N/P0>G[5N/UjbHY9RT6:?HTaN:eWYGNQMieg7GNMMiPMM
i`03GPMN25h900AN209N2@9Mj@9N2003FNUIbEG9009=Z@99R@0DCHQEZ5FXELQIieG7CHM=QEh6HX]=
j2bP;<=9c5Y=ETmJL5jBH[5RT@9RdP0;GThi9aQ1420DHRST=FDiZbdX4448800246401A1R48<@Pa1R
44400`a10P`P0Pa100P<8@a1468@HQ11440800`P0PPQ100001P400`P440XXEX/L^m^kfJ/FPUAZ5G6
HTQ^cfH/><8TH1QQ688@H`PQ320@HA1R588458<01QBS58<HY1RT6:DLY@8HY@046:@HXaRT6:@35:@2
5:<36:@01AS56<@Ha1RT7:@00QbU0Qc521c400/Pa1c37<<HXaR36:@LY1c49@DQ1R45008Pi@LPiP03
9@HQ1RD700<U1`<U1P03:@LY9bDX008U1`039@HU1BD5008Y1@079@HY9RTW;BHa9S57;DL00c580S5X
00<aJCEX=FT013F:00@eJC5Y<FPaB@H]B@DaB003<FTaJS5Z00<eR`8eS0<eR`03<HXaJS5Y008]B@06
:DTY:2D89@LQ1bD60RD70bD600HTiRCU:@HQ1QAS200322000`@P2204800322002@PQ220<8111688L
Xac59>DXiP03:@H2:@L062d8:>LLaQ1T344@HA11368@HQB2468@H@a0440HHQbS:>@a1BSU7:<HH@`P
200<80888003324<@@a100@<@@D8@@<88@032408@@Q10088@@@<@006564]0d6XGVUZl7<d0f/D00=Z
m6[cJ_800V[c00=[56/EJaH00V/E00A[56/EJaE[5@=_5003JaE_56lE00A[5@03JaA_56/C009[4`E[
5003KaA_=6lD00A_5003KaE_56lE00=_5003Ja=_4flD00A_5004KcA_56lDKa<3Ka@00flCKc=_<`03
Kc<3Ka<01FlBKa=_4flCKa@00Vld00A_56lCKa=_4`9_50A_=0A_4`03Ka9_4flC009_4`A_<`04La9_
4VlCKa@7Ka<00f/CKa=_4`07Ka<5Ja<01FlBKa=_4flCJa<00V[c16/C00AZlf[bJ_5^l@9Zl@MZlP04
J_5ZlV[aJ_87I_84J_801VKbJ]9ZlV[aI_5ZlP9VlP04I_=VdVKBI]88I]43I]03I]45I]801FKAH]5R
dF;AI]400V;A00ARdVKBI]5Vd09R/0ER/@MR/0AR[`ER/09NS`ERSPUNSP=NS@03GXiNSej>009NSP9N
K@9NSP=NKP9NK@EJK@9JK09JK@03FViJKEY/009JK09JK@03EViJKUY^009JCP=JK@08EVmFCUI=ETaF
KEY[FVaFC0=FC@04EVeFC5I;ET`2ETd2ET`3ET/00eI<ET]FB`03ET/01E9;DRaBBeI;DT/00U8[00=F
:e8[DR/00U8[00=B;4h/DR`00U8/0Th/00M>:dh/CRa>;4h;CR]B:`02CR/3CR`1DR/1CP`00005340<
80a1368<H@0234400`PQ344<@@023640211Q444<@Qb3@JQNKF:;FV`2GVh01Ei_FVmNL5Y`GW0025j@
3ejA00=N/EjBGY800ejb00INTUjAHXiRCEh/FPX3GNP01EgWGNQIj5gXFLP00egX00AMieh8FPUMj@9I
jP=N2@03GPQN2Eh9009N200VFPYEbDfZAFQ1J4EW@DI5AdV8ELQJ2UWYDLU5R4V7ENQRJeX9<<4/aDW<
GTeFCeiaGY9RTV:bI]ARm5Y?>DPLHQ0P440Ta3EW>Ld]B@8<8003444@HA22008DY00446<<@@`Q2203
320010PP344<@Pa20a1R00H@@0`P3208@@a1124200005P@0000@81A0:<=F;G<`Me=_46J_HVmV[fl@
MeEbcdEV:64HHQAR46<88@P00Q1R00L@PaB358<DPaRS6:@HY@026:@011c56:DHYARU0aRT0aBT00@D
Q1BT5:@HY08HY@8HY0036<@LaAbT008HY08LY0<La00=7<DLa1c48<DLaB347<@L`ac47:@LYAbT7<@0
1B3U0QcV1R3V00<Q1b469@L00RD700HU1RCV9@HU9bTW9BL39@H00bT6:@DY1P029@D01BT5:BH]9Re7
<DL00be800TaB35Y<DP]BC5Y=FPeJC6:<FX00S5Y00<]BC5Y<DP00Re80be900DYBBe8;BP]:2e8008a
B@8aJP03<F/eRcF;00@eR`03<FXaJC5Y008]B@04:DTY:BDX8@P28@L29@L39@H01bD79>HTiBT67<D@
HPP000888005224480@P1208800212401PPQ2208811Q688Pa0<TiP0O:>HTiRSV:>HXibd7;BLLY@a3
200<@0a1348@HQB2468@H@`P440HHAbS8<@a1BSU7:<D@@`P100<80PP32400Pa100@<@Pa1344<@@88
@@032488@@PQ00@88@D8@@0>240<@0a0320DH2cR@JMNJF/AKc=ZlV[dJaAZm0=Zl`03J_A[56/E00=[
5@05JaA[5F/EJaE_5@02Ka@01f/EJaA[56/DJaE[56/E009[5006Ja=[56/DJaA[4flD0V/E00=_56ld
Ka@00VlD0V/D1flD00=[4flDKa@01flD00I_4flDKaA_56lcKc@2Ka@00g<cKaA_4`02Ka<8Ka@00fld
KaA_5003Ka@01VlEKaA_56lDKa=_4PI_4`04KaA_4fldLa82Ka<3Ka@5Ka<01F/CKa=_4flCKa@01FlC
1F/C16lC00=[4f[cJ_@016[c0f[b00=^lF[bJ_8026[b00=[4f/BJ_8026Kb1V[b0fKa0fKb16KB26KA
00=Vd6KAI]400VKA0VKB00ERdVKBI]9V/V:b009RdP04H]5RdV;AH]82H]400f;@H]5R/@02H[05H[40
0f:`H[5R/002H[04HZl00f:`G[5N/@04G[02GXl3HXh00f:^GXiNSP03GXh015Z>GXiNSUj>1ej?00AN
SUi^GXiNK`9JKP03GVeJSUZ=00EJK@09FVaJKEY]FViJKeY^FVaJKEY/009JK@9FKP08EVmJKUY>FTeF
CEY]EVmFCP=FKP03EVeFKUI=00=FCP9FC@9FC004ETiBCU9=ETd2ET`00eI;ETaFB`03ET/5DT/8DR/0
1Dh/DRaB;58[DR`00Th/00=>:dh/CR`00dh/00=B:dh[CR/00dh/0E8[0Dh<000334401@aR468<HPa1
22000P@0010880a1464<@P`R88=1QeY=HZ]JK5j>GVmNKUY_GW1JL0=NL004GY1NSej@GY0BGY4015jB
HY9RTF:a0V:A00INTF:?HTeN;5h:GNT3GNP00eg8FLQMb006GNP2GNT01egZGP]N2Eh9GPQMieh8009M
j006GPQJ2EG9AHQ1AcdV0SdU018m1D56DLQEjEG9CLU9Z4V7CLURK6IY=>@`idF;FRaJKejAHY82H[<0
1F:dI_EF;STX76800Q0P00LPa3E8>Lh]210Q320<@0024642364234401@`P324<80PP32000Pa100H@
@A1R468@HQ1Q4403220010Q022440@@10P@00Q1001DX`e8/Mg1o]WnELcA_5G<dNgIo^7LAAHP/XaAR
688@HP`Q320@HQ1S58800QB300LHPaRS6:@HYART7<@La@027:D011RT5:@HY1RT1aBT0QBU00<DY1RT
6:@00QRT00@LY1RT7:@HY0<La0037<DLa1c400<La08P``037<@LaAc5008La@LPi@LPiP8Q1P8U1P07
9@DTiBD69BHU9BD69@D00RCU00@U1BTU9BHU1P8U1@04:@D]9Re7;DL3;DP2<DT2;DT02C59<DPeJ3EY
<FP]9be7<DPaB@02<DP01359;DP]B2dW0RTX0RdW0Re800/aBC5:<DXaBS5Z=FTeRSEY;BP]1c4X008a
B0<]:007:BPY22D89@LPiRCV9@L00bD600LTibD69@HY1QRT46<80002220512003`PP22488@`Q344@
HQR28>@U1RCV9>DXiRCV:>LY2002;@L05S4V7:D<8`PQ200880a1468DPa1R464<8110664LXbC4<@DX
iQbT668<80P00P`P00<<@0a134400`a100L<8@Q224888PPQ124880021203124222403@Q12408@0PP
100@@2S1@HIJJF/AKc=ZlV[c009[4`03J_=Zm6[d00=[50=[5@9_50=_5@=_5005Ka=[4f/CJaA_5002
JaD00f/DJa=[5002Ja@016/CKaA_5F/E0VlD0VlC00=_56lCKa<02flD0flC16lD00E_5FlDKcA_<fld
009_509_4`=_4P9_4`Q_5008Ka=_<flDKcA_5FleKaE_50Y_4`04KaA_4flCKa<3Ka@5Ka<00f/CKa=_
4`07Ka<5Ja<3Ka<2Ja<4J_<00f/CJ_=ZlP0=J_800fKbJ_9ZlP02I_8016[bI_9VlVKb26[b0f[a00AZ
dFKaI_9Vl@]Vd@03I]1VdFKB00AVd@9VdP9Vd`05I]9RdV;BI]9RdP02H]44H]02H[000f:_H[1V/005
H[42H[05HZl2H[04G[400ej`H[1R/002GXl3HZh2GXh01Uj?GXiNSej>GViNSP9NS`03GY1NKei_00AN
SP04GXmNKei]FXh3FXd00eZ>GVeJK@02FVd3GV`00eY^FVmJKP05FV`015Y]FViFKUY^0UY]0UI=1UI^
1UI>00=FCEI;ET`00U9=0UI<1EI;0U9;0eI;0UI:0U8[00=B:U8[DR/01e8[0dh[00=>;4h[CR`014h[
0U8[0Th[00=>:Th[DRX00E8<00000`Q1344<@@0434400`P0224<8@02344030aQ36888B23?HM>CF:/
FVeJKeZ@GVmJK`9JL0=NL003GY1NSej@00=NT0=NT@03GY1NTEjA00YNT@ART@06H[5RTV:bI[1RKUh/
0Uh900AIj5gXFNQMa`9Mb09Mj004FNUMj5WYGNP2GNT4GPT04Eh8GPMN25gXGPQN2EX9ELU9R456AFM9
RD5W?BE5Qe78DNT00U7901a=b4F8BLYRS69Y>@</aCeZEPaJL5YaHY9R/ejdG[=ReEi`>DXPHQA0544P
XbdV=J`]:1R3320<@@8@H@8<H@8<@P07344<@Pa2324<@A1146400Q1R00HDHQ1Q468<@@`P22042240
60@1204400`P340TXUH/Me1onWoHOiMoN7nFOkMonVk`@HTTPQR3688@@P`Q200@@@8DP`0458@HQ1R3
6:@26:D57<D00aRU6<DHY0026:@65:@01ABU6<HHaART5:@00aRT0ac500@La1c57<@La0@La@038<DP
a23T00<La0037>@LiAc5008La@<Pi@/PiP058@HU1RD79@HU1`029@H28>D012CU9@DY9RD60R3U00<T
iBD6:BH00RU700@YB2e8;BP]:08]B005;DTaBC58<DP]B002;DT6<DT02358<BP]9bTX:BL]9be7:DP3
;DP00bdX;BTaB@03=DT01C4X;@Ha1Bd5:@H00bT700@Y22D89@PU1P8TiPDU1`069>HTiBT56:@@HPP0
0PPP0`@P00H48@@P12488@PP320234401QB26:<LiR359>DXiP<Xi`0:;@La:3DV8:D@A0PQ22088@Q0
3682468244402A10564LXbC4;>DY1QbT668<8@0232001@a0344<@@a136800Pa100@<8@Q134488@84
8@<48003124480@P00888@<8@@0:120400`P;>8mQUY:Ja5_=6[cJa<3Ja@01F[dJaA[4f/EJa@00f/E
0flD00=_=VleKaD00V/D00=_56/DJa<00VlD0V/E00=[56/CJa@00V/D00=[4flDKa@01VlD0VlC36lD
0VlC16lD0Vle00=_=6lcKa@00VlD0VlC00E_4VlCKa=_<flC00M_500:Ja=_4flCKaA_4fldKaE_56lC
Ka@8Ka<2Ka@3Ka<3Ka@5Ka<2Ja@3Ka@00flCJa=[4`09Ja<00flCJa=[4`06J_<8J_83J_<4J_800f[a
J_9ZlP0>J_800f[BJ]5ZlP02I_802FKaI]5VdFKBI]5VlFKAI_1Zl@04I]43I]83I]46I]800f;BH]5R
dP04H]42H]02H[000f:_H[1R/005H[42H[05HZl2H[05G[42G[02GZl4GZh035j>GXmNSej?GXiJKUY]
GVmNT5j`FXiNS`=NSP9JS`03FVmJKUZ?00AJSP03FVaJKEY]009JK@9JK0=JKPEJK09JK@AFKP04EVmF
CUI>ETd7EVh015I=ETiFCUI>0UI=0U9=15I<0UI;00AF:e9<DTaFC09FB`03DT]BBU8[00]B:`03CR]>
;4h[00E>;003CR]>;4h[009>;004CR]B:U8ZDPX1DP`0000324488@a100@<@@888@@<@@0:348<8AAR
>DIFCUj<FVeJKeZ@GVl2FVl01UY`GW1NL5i`GY1NS`MNT003GXmNT5jA00=NT@03HY1NT5j@00ENT@=R
T@07H[5RTF:@HY1RKUh/GPT00UWX0eW700AIj5g7GLMMi`=Mj09N209Mj006GPQN2Eh8GPQN1egW0UgX
00EN25WYFLQEbE7900=AZ@0QDLUEb5h8GRYEjU79DLM=Z4g:HV]N:3e5<>I1RUG/FTmJLEiaHY5N/fKD
I]ERTcf<96@@81QP8:<]1S6:=DTLQ111008@H@04344@H0a1344234800`a1348<@@0244400a1Q468@
H@0246401Q1R344<8@PQ124880@88@88000F460XhdWYMdig]WNGLeIgMg^hOkMgUVk_?FLXXab35648
00@0200<8112588258<011B27:@LY1c40ac500<LiAc57:D00aRT00DDY1RT5:@DQ1BS00<DY0055:DD
Y1BT6:@Ha0036:@37<@011c57<@La1c40ac500<PaAc57<@00Qc400LHXQc37<@LaAc67<DLaP028>H0
0b3U8>HPi@028>H00acV8>HPiP088>H00b3U8>HLiP028>D01BCU9@DQ1B3U8>H00RCU00<U1BDW:BL0
0RTW00DY:2dX;BP]:2e800<aB08]B@03<FTaJ35Y008aJ@03<DT]B357008]9`<Y9`03;BH]Abe7008]
B00>;@LY1bdX<DTeJSV:?J]5k4W/@L/eJBT69<@PY08Ta08TiP038>HTiRD700DU1P059>DY1Ac44688
0002220512003@@Q224800`P340<@AB26:@LaB359>DXiRCV00<Xi`05;>He9QbT44<88@033440511Q
568@HA11320@@1AQ7:<Ta345;@DPa1QR324880`P340<@@aQ36823443244010a022088@@Q1P@P00<8
80PQ24400`Q100T000`P;@8mQUYZJa9_56[cJa<00V[d0V[c0V/C0f/D00I[5F/DKa=_56/DJaD4Ja@0
0f/CJaA[4`03Ja@4Ka@3Ka<8Ka@2Ka<00flDKa=_5009Ka@2Ka<5Ka@2KcD016lcKaA_56lC0Vlc00=_
4flBKa<00VlC16lD0VlC0VlD16lC00I_<flDKa=_4VlCKc82Ka85Ka<2Ka@3Ka<2Ka@00f/CKa=_4`03
Ka<01V/DKaA_56lCKaA_<`=[4`03Ka9_4flC00=[4`03Ja9_4flC009[4`=Zl`03Ja9ZlV[b00QZlP03
J_=ZlV[b00=ZlPAZl@05I_5ZlV[bJ_9Vl@03J_801FKbJ_9VlFKaJ]800VKA00AZdF[bI_9VlPIVd@04
I]1R[V[?I]03I]43I]83I]400fKBI]5Vd@03I]400fKBI]5Rd@04H]400f;@H[1R/003H[06H[42H[05
HZl2H[000f:aG[5N/@02GY400ej@GZmN[P04GZh7GXh4GXl5GXh2FXh015Y^FXeJSUZ>0eZ=00AJKEY/
FVaJK@9JC0AJK@EJK003FVeJK5Y]00=JK@04EVmFCUI>ETd4EVh01EI]EV]FC5I<ETd00UI>0eI=1UI<
00=F:e8[DT`00e9<00=B;58[DR/00e8Z1E8[00EB:U8[DR]>:e8[009>:`03CRa>:dh/00Q>;003DRY>
:U8Y005B300000<8@@PQ344010a110Q200/8@@PP10040A12=DIFKej=FVmJL5Z@009JK`9JL0=NL003
GY1NSej@00QNT0ANT@06GY1NTEj@GY1NTEjB0ejA00ARTF:aH[5RT@9RT003GW1N;5h900=Ij09Ii`9I
j003GNQIb5W9009Ij@9N2@=N2003GPUN25h800AMi`=Mj003FNUIbEW9009R:P0RGRYN:EhYGRYEje79
CLM=Z4g9FPYR:4W9=BI1REG/FTmJD5iaHY5R/VKDI]ENLSf<86<@81A08:<]1CF:>FPLXa1134423403
44423442324234400`aR468@HP03468010aS34888@PQ0`@Q00<880PQ22400PP001XDPBSS>FEBKVLc
JcE_EF/DKcA_E6/cCTde9B2S440@80`0200<0110568DPQAR468DHQR30QRT00LLY1c47>HLiQc57<@L
Y0026:D01AS56:DDY1BT5:<00QBT0QB40aBT00@Ha1S56:@LY0<La08La@057<@LaAc58>DLa@057<@0
11bS7<<La1c60Qc511cV00@PiR458>DLi@8LiPHPiP047>HPiR3V8>H37>H00b3V8>DPi@028>D01B3V
8>DPiBD69BL00bTW00<Y:2dX;BT00RdX0S5800HaBBe9;DTaBC5X;FT3;DT012e8<DP]:2dW0RTW0RTV
01HYAbe7;BPY9bT6;@LaB3g;CReJT5kBG[5Vlf;BG[9B3Cf[;>@TPR2S7:@TiP<PiP<TiP069@HTiBT5
;BDLa1AR0P`P00@88@@P12088084800:12488@P0320<@11Q588HY1c58>H29>D29>H02BCW:>LXiC45
7:@@@`P0324<@@02464021B2468@HP`P440DHAbS9>@2;>D01R3468888@PP3408808<@@88@@033448
@@Q10088@@888@04124880PP2204120030PP2448@@aP240400a0;@8mQUI;I_5[4`9Zl`9Zm003J_=Z
m6/D00I[5004Ja=[56/DJaD;Ja@00f/EKcE_5@02Ka@00flCJa=[4`03Ja@00f/CKaA_5002Ka@00fld
KaA_500@Ka@026ldKcEc=FleKaA_4flDKc@5Ka<5Ka@01FlCKaA_56lDKa<00Vlc00=_56lCKa<02FlC
00=_=6lCKa<00flC00=_56/CJa<01F/C00A[56lDJa=[4`9_5004KcA[4f/CJ_<5Ja<016lBKa=[4f/C
0f[c0V/C00=Zlf[bJ_801f[b00=Zlf[bJ_800V[b0V[c00=ZlV[aJ_400f[b0fKb00AZlVKbI_=VlPEV
dP04I_9VdVKBI_83I]43I]82I]401FK@I]5VdFKAI]000fKB00AZlVKAI]5VdPEVd@03H]9VdF;A00=R
d@03H[5R/6:`00AR/0IR/@MR/003G[5R/5ja009N/@9NT@03GY1N[ej^009N[`03GZiNSUj>00ENSP04
GXmNSUj?GXl5GXh015Z>FXmJSeZ?15Z>0eZ=00=JKEY/FVd01UY]1UY/0eY]0UY^00=FKeI>ETh00UI>
0eI^00=FKEI[ET`00UI<0UI=0UI<00=FBeI<ET`00eI<0UH[00=F;59<DT`00U8]00ABC58/DR]B:PAB
:`9B;0EB:`06CR]>;4h/CRa>:dh/0dh[0dh/00E:;Dh/CR]>:U8Y005B300000T8@0PQ344@HPaQ3448
@@PR22400P@Q00/400P000000112<BI>CeZ>FXmJKeZ?009JKP03FVmJL5i`009NL003GY1NSej@009N
T0=NS`=NT0ANT@03GY1NTEj@00ENT@9RT@9R/@ART@04GReN25gWFNP3FNL00eWXGNQMj003GNP7GPP;
GPL2GPP08eWYFLQIb5W8ELUAbTg9BJI1ADF7CLMVIdWY>DI1J5G[EReJCUi`HY5RTV:bI]ENLCf<98@D
81A0784/i3V8>FLLP``Q22001`a00P`P00<<@A1146800Q1R00PDHQ1R468<H`a2224480@Q0P@P02P8
80P0100000P0588ThbT3<FLiZT7[BPe>;DX<BP]1bCE59:8D@0`0200<81AQ9<<a0bd4:@DTa2C38:@D
H`a1448HPac37<@LaAc48>@HY08HY@8HY08DY0035:<DPaB300@DQ0035:@HY1RT008HY0037:@La1c4
008La@8La0<La@<La0066:<L`ac37<<La1c61Ac50QcU00LLaAcU8>DLiAcV8>DU1@028>D01acV8>HP
iRD78>HPiAc600<La@047>DPiB3U8>D39>D01RD69BLY9bT7:BHY9`8Y:004;BT]BC58<FT2;DP0135Y
<DPaB2e80Re90Re80RdX00<]9bTW:BH00bTV00X]9BdV9<@X`cUYCPaRcf/cLeIcM`=cN008KcI[55j@
ANdeB223888LY0<PiP098>DPiR3V8>HTiBT5;BDLa1AR008<8003224880PP00@88009224880`P320@
HAB26:@LaB3V008Ti@8TiP09:>HXibcW<@DLY112100<80a1008@H@0A588@HQ1R344@@1AQ7:<Pa2ST
9>@P`aR2348880a022088@022445224722051202240236001`PP440XhSf6ER]VlF/C00EZl`03J_A[
56/D00E[50=[4`U[5004Ja=[56/DJa@2JaD2Ka@01flCJa=_4f/CKa=_56/C00U_50E_4`=_50=_=0Q_
5004Ka=_56ldKa@2Ka<00flDKa=_500>Ka<4Ka@2Ka<2Ka800flCKc=_4`02Ka<00flcKa=_4`03Ka<4
Ka@2Ja<3J_<4Ja<00f/DJa=[4P05Ja800f[bJa9[4`03Ja<2J_<=J_801V[cJ_9VdVKAJ]5Zl@=ZlP=V
lPEVl`EVdP04I_=VdVKAJ]02I]44I]84I]42I]0016KAI]9VdFK@0fKA1FK@00ARdF:aH]5Vd@9Rd@9R
/@9Rd@03H[5R/6:`00ER/@04H[1R[f:`H[04H[402UjaG[1N/5j`G[5NTEjaGY1NSf:^0Uj_0Uj^1Uj>
0Uj=00=NSUi^GXh00Uj>15i]00=NSEj>FXd01EZ=00=NSEi]FVd045Y/0eY^0eY>00EFCUI=ETeFCEY/
00UFB`9FC003ETeFC5H/009F;0=FC006DTeBCU8]DTaBBeI:158[0U8/0e8[00EB:U8[DR]>:e8[00I>
:`E>;003CP]>:U89005>300000L8@0PP2248@@a124448@02224212402PPQ32040000300a1DX=FVeJ
SeZ@0UY_00AJKUY_FW1JL09JL@MNT003GXmNT5jA00MNT@=NT0=NT@0<HY5R/F:aH[5RTF:BGY5R/Ei=
GPQMieWX0eWW00=Ij5gWFNP01EgX0Uh80eh90eh80eh70eh800=R1eh7GPP00Uh801=N1eW8DJM=Ye6X
CLU=YdE4@DE=af98CPY1Z469DNaF;UY>GW1RT@02H[8016KdH[91[2RU0Q@P00PHH2S3<DH]1QR32008
8@aQ1`a000<<@@aQ46401Q1R00<<H`a222400`@Q00<480PP20000`@000`DPBD37>@DPQR38<<PXQbR
9<8X`R21420330003a0P::8iIT7:ANY>;TX=@L/iR3DW;>HHPa12424LY0037<D27<@46:@00aBT58@D
P`0558<011B45:@HY1RT11bT00<LYAc57<D011c500<HaAc47<D00Qc500<La1S57<D011c500@LiAcV
7>DLa@8Li0067<@LaAc57>HPiRD6123V00DQ1RD68>HPiQc6008La@039>DPiB3500<Pi@@PiP099@HU
1bDV:BLU9bDX:BTYBBU800<]B@04<DTaB2e7;DP2;DT00be8;DT]B@02;DP2:BP3:BH02RdV9>DXiCTV
DP]RlF/dLiQk^GoH0W^i00akVGNILgQ_EejaANha:2AR8:@LiR3V8@H28>H02B3U8>HPiBD5:@DLY1B3
3208000922001``P440@HAAR6:@LaB3V008Ti@0;9>HTaRS6:<L]1cDU8<D@@P@0320<H@0246402AB2
468@HQ1Q444DPQRT8<DXi@029>D01aB3348<@Pa024488@Q100@88@0422088@PP224522000`PQ2204
800212002@Q0340<H0aP220<82d2?HIFB`02Ja84J_<00f[dJaA[5006Ja@01FlDJaA[56/EJa@00f/E
16/D00=[4f/DJa@01F/D00=[4f/DJa<00VlC0V/D0V/E00=_5FlDKa@00flD1VlC1flD0VlC0flD0flC
0flD00=_=6lDKa@00VlD3flC00I_56lCKa=_56lCKa82Ka<01VldKa=_<flcKa=_4PA_4`=_50A[4`9Z
l`05J_A[56/CJa=[5003Ja<4Ja82J_8016/BJa=[4f/C1V[c0f[b00=Zlf[bJ_<036[b0fKb0fKc1FKB
00=ZlVKBI_<00VKB0fKA0fKB1fKA0VKB1FKA1FK@0V:a0f;A00=R/F;AH]400V;A00=R/F:`H[001V:a
00=R/6:_HZl00V:`0V:a00=N/Ej`G[000Uj`00INT5jAGY1N/5j_G[02GZl015j>GXmNSej?0ej>0Uj=
1ej>0Ui]0Uj=0ei]0Uj=00=JSEi]FVd04eY/00EJKEY=FTeJCEY>00AJC@03FTaFC5I;00IFB`9FC0=F
C@EFC003DTeB;U8]009BB`9BBP=B:`9B;0UB:`E>:`08CRa>:dh/CRa>:dh;CPY>:@5>300000<8@0PQ
22400`Q10`PQ0PQ100X88@`P200400P0;@A:35Y]FXiJK`9JCP9JKP05FVmJL5YaFW5JT@04GY000ei_
GXmNS`03GY05GY401Ej@GXmNT6:?GY000UjA0V:A011RT6:aH[5RTUjAHY5NC5h7GNMIieWVFNMMiUWW
GNIIi`AMj0=N2003GPUN25h8009N20EN1`9N20=Mj00VGPMN:5h7FLQEbE78ELMAb4fWBFE5IDfWGRQB
:TWYAL]=kE8]FTiNL6:@HY5V/VKdJ]99c2bS520D@1QP9<8]9BCT688400PQ340<@@H<@003440<HA1Q
00D@HP05588@P`a220088@021242120222021000211P7<8H`a22220800`P220220005@`P300800P0
564a94GZFVaR[6K_I_1VlF:`GXi:;Sf;;@LHHaA2448DQ0036:@36:<35:<558<0111S58<DPaB40QRT
0abT0QRT0aRU00HLaARU6:DHYAbT6<D37<D26<D00aRU7:DLa@057<D00ac47><La0027<D27>H28>H2
7<H57>H27<H011c59>@PiB350Qc500@PaAcV7<HLiP8PiP078>DU1BD69@HU1bDW:BP00RTW0RTX0Re8
00<]Abe8;DP00Re800L]BBe8;DP]B2TX:@PY1P02:BH02bT5:>Da247;GZe[EG>HNkQoeW^FMiH00WMg
00]gN7MiLiU_EejcANhXY22T7<DTiB46008PiP088>DPiR3U9>DY1AbT58<<00880004100880@P1204
22001``P440@H1B16:<LaBCU00<Ta@8TaP0<9>LY1SE67:@<@@@0320<@11P464DPQ1R0a1Q00XDPQbS
:>D/iRT69>DHPa12324<@0@88@0312488@PQ00888@0322088@PP00L880041248@@Q0240236001`PP
440XhCf5ETYZl6lB00=ZlP03J_=Zm6[d00=Zm004J_=[4f/CJa<3Ka@00f/EJaA[5006Ja@01f/CJaA[
56/DJa=Zlf/D00=[4`=_4`=[509[5@04JaA_56lDKa@2Ka<00flBKa=_4`02Ka<3Ka@7Ka<00flDKa=_
4`03Ka<3Ka@3Ka<00flDKa=_4`09Ka<00flBKa=_<`07Ka<016ldKaA_56lc0flC00=_4VlCKa<00VlC
00I_56lCKa9[4VlBKa<2Ja<00f[cJaA[5002Ka<00f/CJa9[4P05Ja82J_400f/BJa=[4`05J_<;J_82
J_400fKAI]9VlP02I_42J_82I_8016[bJ_=VlfKC0VKB00=VdFKBI]800VKB00=VlfKBI]800fKA0fKB
1VKA00AVdVKAI]5Vd@UVd006H[5R/6:`H[1Rd6K@0V;A00=R/F;AH[401F:`0f:a1F:_0f:`0Uj`00=N
[ej`H[000Uj`00=NT5j?GXl00Uj?00ANSUj_GXmNS`9NSPENS@ENSP9NK@03GVaNKEi]00ANK@9JK@03
FVaJJeY/00]JK0IJB`03FTaJCEY<009JC0AJC@03ET]FC5I;00QFB`9FC09FC@09ETaBBe9;DRaBC58]
ETaFBe9;00=B:`9BB`AB:`03CR]B:e8[00=B:`03CR]>2dh[00M>:`9>305>2`5B:@5B;00010Q100L<
@@Q1244<@@aQ2488@@0222402@PP100<82d3BNYNS5Z>FViJCP04FVl01UY`FW5JLEYaFW1JT@9NT09N
L0ENT0ENT@=NT0ANT@09HY5R/F:aH[5RTV:AH[5RCEgW00AIa`=Ii`=Ij003GNQN25h800=N2@03GPQM
j5gX00=N209N1`03GNMMj5gX009Mj@04FLUIj5WXFNP2FPP045h9FNUAbDfYCFE=QTVWCLQ>:dh;BPa5
kDh>ETmNL5j@0V:a00iVdfJ`BNd/Y1PP540LPBC2<BHU111010088@a10PaQ1Pa100<<HA1R46801Q1R
00@@@@`Q22448@@48007220800P0440HXABS48800PQ100D88@PP220<@0PP008<000@88<iRE9^G_1R
cfKaJa=_EFleJcEW56;cEVm1cC48768244800abT6:@HY0026:@00aR36:<DP`0858<25:@46:@26:D0
11RT7:@LYAS50QRU00<HY1RU6:@01AS52Ac50ac40ac50QcV11c600<LiR3V7>H011cV00DPiAcV7<DL
aAc4008La@067<HLiQc57<DLiRCU0bD60bD700LY1bTW:BP]:2e8;DLYB003;DP00be9;DP]B002;DP0
32U9:BPY9RD69>@XiCEYCTeS4g>INkQk]`9gM@9gMP0<MgMgUgNGMiUcVFmGFW0iBB2458<PiB3V11cV
00DPiR3U:@DLa1AS008800T88007320@@1AP564HXac59>D00RC50bC6014TibCV;BHHXa11220<80a1
440@@AB2468<@@`P444@@1RS008Xi@049>HPa1R334822202224010PP22488@PQ0PPP00<88@PP2240
10PQ0`PP00h88@@Q2448@@a0360<H@PP440XhCf6ERYVl6lc0V/C00=[56/EJ_@016[d1F/D0VlD00=[
5F/DJa@00f/D0V/E00=[56/CJa@00V/D00I[4f/DJaA[56/CJa@3Ka<00f[dJaA[5@02JaD6Ka@5Ka<4
Ka@2Ka<3Ka@00f/CKaA_4`02Ka<8Ka@6Ka<00flDKa=_4`05Ka<00flDKa=_5003Ka@016lCKc=[=6lC
0flD0VlC0VlB00I[4V/CKaA[56/CJa82J_83Ja<00f/EKcE_500:Ja<3Ja85Ja<00f[cI_=ZlP02J_80
0f[cJ_9ZlP07J_82J_<016[bI_5VlFKa16[b00=VlVKBI]800VKB00=VdFKBI]800fKC00=VdVKcI_80
1VKB16KA00=VdVKAI]400VKA1fK@0VKA00=RdV;AH[400V:a1F:`00=RdF:`H[000f:`0f:a0Uja1V:`
0ej`00AN/F:`G[5N/0=NT09NS`03GXiNSej?00=NS`ENSPENS`9NK`MNK@=JK@05FVaJKEY/FVeJK003
FVd5FV`00eY[FT]JB`03FT/3FT`00eY;FTaJC@03FTd2ETd6ET`00eI;ETaFC004ETd0159=DTaBC58/
0e9<0e8[00=>:e8[DR/0158[00=>:dh/CR/01U8[1Th[00I>;4h;CPa>34h;CPX1CP`00004244<@@a1
3442244234400`aQ3448@@0222401`a1100@@BSSAJMNJej^00=JK`03FW1JKei_009JL0ENT09NL003
GW5NT5j@00INT0QNT@MRT@03HY1RC5h800EIa`9Ii`=Ij004GNQN25h8GPT3GPP3GNP3GPP2GNL025h8
GLQIbDV8AFMAYeW8FNP2GPL2FNL03U79BHQ9I4f4BHE9Z4WZCNY>34h=CRiF;eY`H[02H[4036KAIXe>
3C34420D@1b1:><]9BT46648808<@003344<@0a100D<@@03348@HQ1R00D@HP05364@H0`P22448@04
120220000`@0320DH002488234407a1S348@HQ1Q448801A0=FEBSf/_Ia9[=6ldJcE_=FmFKcI_=F/e
KcAN/D7=;>LDHaA268<LXaRS5:<HXaRT00DDP`8DPP0458<DQ1B458@35:@26:@01aRU6:@HY1RT7:@L
aARU00<HY0<La0036<DLaAc400DLa00658<HYAc57<@HY1B30Qc400HLaAcU7<DLaAS56:D57<D26<D0
21c57>HLiQc57:@DHQbT7<@27<D27>D27<D0123U9>DU1BCU0R3U00LTiRD6:BHY9bdX:DP]A`02;DP0
1BdX;DP]B2e8:DP012TW00TY9RT69>@Xi47]H_A_MWNJNkL00WMf0gMg00igN7MgMiIgUg^hLiQVldG]
8:H@@AB28>DLiAc60QcV00DPiR3U9@DPiQAS008800T88006320@@110560HXac40R3500<TaBC69>H0
0RCV00DY1RSU7:@@@@PP008<8005340@@AAQ58<@HP0232002110788PXbcU:>HPa1QR324222032248
22022246220030PQ244<@@a1360<H@PP320T`Sf5ERYVkP9[4P03Ja=Zlf[d00QZm09[50A_5003JaA_
56/E00=[5@9_50E[4`A[50=_4`9_5003JaE_5FlE009_50]_4`04KaA_4flDKa<5Ka@2Ka<5Ka@2Kc@3
Ka@5Ka<4Ka@5Ka<00flcKcA_=002Ka@2Ka<3Ka@2Ja@2Ka<01flBKa=_4V[bJ_=[4f[c009Zl@03Ka9_
4flD009[5003Ja=[56/C00M[4`07J_9[4V/BJa9Zlf[bJ_<00f/C0V[c2V[b0f[a16[b2VKa00AVlV[b
I]9VdP=Vd`03I]9VlfKB00=VdP03I]5VdVKB00IVd@YVd09Vd@06H]5V/F:aH[5R/6:a16:`00=Rd6:`
H[001f:`00=R/F:`H[000V:`00MR[f:`G[5N/5jaH[5R/002G[401Uj`GY1NT5j@GXmNSPQNS`9NSPEN
S`03GVmJKUY^009JKP9JK`04FViJSEZ=FXd2FVd015Y^FVeJKEY]2UY/2UY;00=JC5Y/ETd015I=00=F
C5I=ETd015I=00IFC5I=ETeFCE9=ET`3DT`2DR`2DR/00e9:DR]B:`0>DR/6CR/2DR/2CR/1CP/1CPX1
CP`000<8@@888@03244<@@a1008<@@888@8<@@0710088233ALQNJej]EVh00UY_00=JL5Y_GVl00eY`
0ej@00ANSej@GW1NL@UNT0INT@9RT@03H[5RT6:@00ART004HTaN:5WXFLP2FLL3FNL4FNP6GPP01UgX
GPQR1eh8HPMN209Mj00IFNUIb4fX@DI1ADf6ELQIj5hWGPMIj5G7CLQ5IdeUCHE9QTF6AJQ5bTW/CPa>
;E8`FW0016:a00aZd5H^=>H@81@P540P`bD5:@@HH@`P3443340734400a12468@HP03468236801@aQ
32088@@Q22000`@P00H880P01008811P588646802aAQ2204022RAP]S4F/bKeI[=FleJaD016le00Q_
=V/eIcIFL3V/88D@@QAS0QRS0QRT00HDY1B358<@HaB3588458<258@55:@00aRU6:@HY0056:@27<D0
2Ac47:@LaAcV7<DLa1RS7<@Li0027<@37:@01ART68@DY1RT7<@00ac501<LYARU6:DHaAc56<DHYAB3
58@HYAS57<HLiQbT68<HHQbS7:@La@047>H01Ac67<DPaB3U8<D00R3U00<U1BD6:BH00RTW00@YB2U7
;DP]9`@]:003:BPY9bDW008U9`0;:BHY1RCU<BI:3VLeLiQk^GNGMgIgM`04MgP037MgMgIgUg^hNk]_
EUZA;@PDHQB27<@La@<LiP078>HTiBT69@LDQ0`P20002@PP0P`P00H@@1A16:<La1c58<D29<D022CU
9>HTiRC59>@HXa11200232004@a0464HPQRS464@@0`P540LPR2S<>@/iB3368<<8@P022001PPQ0PPP
00<88@PP22400PPQ0`PP0`@Q0PQ10Pa100/<H@QQ220<82C2>HIFBfK`Ja9ZlV[c00IZm0Q[5@04JaA_
56lDKa@4JaD2KcD016ldJa=[4f/C0V[d0f/D00=_4flDKa@00VlD0VlE0VlD16lC0flD1FlC3flD0Vle
00AZlfldLcE_=0E_4`=_50M_4`A_5005KcA_4flCKa=_5002Ja@4Ka<00flBKa=_4`03Ka<00flBJa=_
4`02Ja<3Ja@00f/CJaA[4`03Ja<3J_82Ja8016/CJ_9ZlV[b0f[c00=ZlV[cJ_8016[b0V[a0f[b0f[a
0V[b00AVlVKaI_5Vl@=VlPEVl@9VlP07I]9VlfKcI]=Vlf[cI_<016KB00IVdFKBI]9VdVKAI]83I]40
0f;AI]5Vd002I]401FK@I[1V/6KAI]000fKA00=V/F;AH[400f:a0f:`00AR/F:_HZmR[`AR/004H[5R
/6:aH[43H[000f:_H[1N/@03G[44G[03GY000ej?GXiNS`06GXl00ej>GViNKP04GXl3FVl2FVh015Y_
FW1JL5Y_0eZ=00AJSUY^FViJK@ANK@03FXeJK5Y/00IJK0IJB`03FTYJC5I;009FC0=FC@03ETaFCEI=
00=FC@03ETaFCEI=00AFC@03DTeB;E8]009BC09B;19B:`03CR]>;4h[00U>:`5>2P5B30000PQ10PPQ
0P@P00<88@Q134000`PQ0Pa100L880@07:=1QUYZGZaJK002GVd3FVl4FW03GVl3GW02GY000ej?GY1N
T006GY04GY400ejBHY5R/@02H[04HXl00f9/HRUN1`03FLL5FNL2FNP00eh8GPMN2003GPP4HPL3GPP0
:egXFNUIb578AFI1A56WENQIieh7GPIIieW7CLU=R4eUCHE=YTF5>@@iJDX=FV]BC58`FU1NKej@GY5V
dF[`GTli:1Q0420D@1R2;BHXi1Q0320<@110008<@08<80D<@@03348@HQ1R00@@HP03364@H0`P00<8
80<480888004320@81AP588346802`a2464@HA1Q100883EVEXeW<VmEJcD00V/E00=[=6leKc@00fle
00U_EV/eIa=>D34Y548@@QRT6:<00aB300@DPQB346<DP`8DPP<DP`0458@DY1B458<45:@36:@57:@0
11RU6:@HY1RT1Ac400@L`aS37<@La08LY0046:@DPabU6:@27:@00ac47<DLY@036:D36<D01ABT58<D
Y1RT6:D00QRT0QR300<HXaRT6:@011RU014HY1B46:@HY1c48<DPiBD5:@DY1RTV:DHYAbdW:BL]9RdW
008Y:003;BPYB2dW00<U9P08:BDTiBT6=DMBC6LeLiUgV0=gM`03MgQgMgMg00AgM`08NkUofWNHGY4i
JaaR58<La08La@8LiP078>HTiBdV9@LDQ0PP20002@PP00D<@110444DHQRS008La@<Pa@089<DTiRCU
9<@Xi1RS4408008<800A340@HAB2568DHA10420D@1b29<<e12cT8<<HHP`Q20088002224010Q12248
8@PQ10PP0PPQ10PP014400PP2448@0Q1344<80a136488110:>8mQEI;Ia5[4fKb00AZl`=Zm0I[5@=[
50=_4`M[5003Ka=[4f/D00=[509[4`E_4`=_50E_4`=_50E_4`I_5003Ka=_56lD00=_4`03KaA_4flD
00A_5003Kc=_56lC00A_4`03KaA_4flC00M_4`05KaA_<flCKaA_=003Ka<016/CKa=_4flC0flB00=_
4FlBKa<00flC0flB00I_4f/CJaA[56[cJa86Ja<016[cJ_5ZlV[a0V/B0f[b00=[4V[bJ_801V[b00=Z
lF[bJ_8016[b00AZlF[BJ]9VlP9Vl@04J_5ZdVKBI]83I_4016KAI_5VlVKb0VKc00=VdfKBI]800VKB
1FKA0fKB2VKA00=VcfJ_I[001FK@00=VdFJaH[400f:a00AR/6:aH[1R/0=R[`UR/0=R[`05H[1N/5j`
G[1NT003GXl4GY000ej?GXiNS`03GXh3GXl3GVh4GVl3FVl2FVh025i_FY1JKeY_FVeJK5Y]FXd2FVd2
FV`3FVd>FV`2FT/015Y:FT]FC5I;0UI<00MFCEI<ETeJCEI=EReFC@04ET`015H[ET]FC5I<0U8]00=B
C59;DT/0358[00=>;58[DR/0158[1dh[00=>2e8[DR/00U8[0E8:0E8<0002224010Q02448@@a10P`Q
00@<80PQ224<8@8<@@08340401R2>FAFJek=GZiNKP9JK`EJL003FVmNKej?009NK`08GXmNT5j@GY1N
SeZ@FY5NT@ENT0ANT@9NTP04GY5RT6:@HY02HXl016:>HVaN:Eh715W715WW0UWX00=N25h7GPP015h8
0f8715h802YIjEW8ELQEae77DLQJ2Eh8GPMN9ehXFNQEbE6WDHI=QTfVAHD/`bSV@L]JJeI/DRmFD5i_
GW1NTFKBJ]1NCcU8764D81Q08:<aAcDU784<80PP440234000``P344<@@0334401P`P348@HQ1R46<D
H`8@HP04368@H0`P220212000`@Q1204800222001@`P420DPABS46800PaR00X@HQ1Q464<@0006:A2
36;]KeA_E@9[=@04JcI_=VlfKcD2KcH2LeH027=GJaEFT3UZ76<<8QAS688358<00a2248<DP`0658<4
5:@26<D01QBU5:@HY1bU6:@LX`8LY08La0<La@@La0037>DLiQc4008La0037<DLY1bT008HY0076:DH
Y1bT7:@La1c56:D01AS500@HYABT5:DDY@@HY0<HX`8HY0@HY@8DY0<HY00;8<DPiBCU:@DY9BTV:DHY
9RTU:BH]9`04:BL03Be9:BPU1bD79@HU9B3U9@HeJ4i<JeIcV7NG009gM`04MgQgV7NHMgP4MgL027Mh
NmYcN5jA>FXD@A127<D27>D27>H28>D01RTV8@LDQ0PP200400P8800;340@@111568HXac57<HPiR36
9>HTaP029>H01BSU<BDLXa1130000Q1000H<@11Q588DPQ1R444256402ab3:<<e92d58<@DH@a1220<
@@Q134400`Q10PPQ0PPP00<8@0Q124000`Q100<880PQ22400`Q100/<@Pa1364<HPQ0340XhSV5DRYV
kf/C00AZl`AZm003J_E[5F/E009[5@a[50=[4`9[5003JaE[56/D00A[4`06Ka=_56lCKa=_56/D1FlC
1FlD00A_4flDKaA_=0A_5003Ka=_<flC009_4`03Ja=_4flD00I_50=_4`=_5003Ka=_56lC00M_4`9_
5003Kc=_4flC00=_4`04Ka9_4flCKa83Ka<4Ka800f/CKa=_4`03Ka8016lCJa=[56/D26/C00=Zlf[b
J_801F[b0V[c0V[b0f[c2V[b00AZlF[BJ_9VlP9Vl@04J_5ZdVKBI]82I_83I]42I_801FKcI]=VdfKB
I]400VKB1FKA00=VdVKAI]4016KA00=Vd6KAI]400VKA00=VlVKaI]401FJ`00=VdFJaI[4016:a0f:`
00=R/F:`H[0036:`00=R[f:`G[000Uj_00=NSf:_G[000Uj_00UNSej@GY1NSej>GXmNSUj?GXh00Uj?
00=NT5i_GVl00Ui_00=NSUi_GVl00eY_0eY^0UY_00=JKUY]FVd00eY]0eY^00=JKEY^FVd01UY]1EY/
00=JBeY/FT/00eY<00=JBeI<ETd01eI=00AF;EI>ETaFC@IFC09B;@05DTaBBe9;DT]B:`05DR`4DR/6
CR`014h[CRa>:dh/1Dh[00=>;4h[CR/00Th;0Dh:0Dh<00001PPQ220<@0a0344<80<<@@0=224800@P
224<@@Q0100DPSE4DT]N[6:^FVh00UY_0UY`00ANT5Y`FW1JK`9NKP9NSPENS`04GY1NTEjAGY43GY00
0ej?GY1NT@07GY401f:@HXmV[f:=HV]R:5gW009MaP03FLMMieWX00=Ii`04GNQMieh7GPL5GPP00f87
GPQN2002GPP02Uh9GPQN25WXENUEaTf5ELMJ2EhX0Uh800AIb5G8ELMAYP9=QP0;BFE5I3CT98DiAUHX
ET]B;UI?FTiNK`02H[4016J`ERhiB1a10Q@P00L/a3EW@HLLX``P220@H00334001`a1368@@@a0344<
811100@@HP05448@HPaR460<800322002P@Q120480PP200<010P560HXa220Q1R00d@@A1Q464880@0
:BA>SfL`Ke=_EF/eKcI[=P02KcL3KcH02FlEKcE_EVleG[51bb24208<8@0258801AB3588@HQ224680
1AB300<DXaBT5:<011BT00PDYARU6:DHYART7<@HY1c40QbT0Qc400HLY1c47<@La1c57:@26:D27:@0
1Ac47:@LXabS6:<00QRT0abT11RT00<DYABT5:D00aBU0QBT0QRT0QR30aRS00THY1RU5:DDYARU5:@H
PaRS7:<00QbT00DLaBCT9>@U12D5008Y9@06:@@U1BD59@HY1BT60RT70RD700/TibD5:@@Y1BT6=FMJ
S6]EMkUk^7Mh00=gV0=kU`9gMP09MgMgVG^jLiQNT3E7420@@Ac5008Li@8LiP079>DPiBD58>HDQ0a1
32000PPP00<480PP220010PP0a1000<DHARS7<D00R3V0R360RC600HXiRd5=DDLa1AR200244001@a1
464HXQc358800aAQ00PLPb2S;>@Y1BCT688@@@PP0Pa100<8@@PQ22400`PQ0PPP00<<@0Q022000PQ0
00@<@@PQ22488@88@003224<@Pa1008@HP08340@@2SQ?H=F:VK^Ka9ZlP9Zl`=Zm0=Zm@9[5@Y[50M[
4`04JaA[4f/DKa<5Ja<5Ka<00f/CKa=_4`03Ka<3Ka@2Ka<4Ka@2Kc@00flDKa=_4`02Ka<2Ka8016[a
Ka=_4flC1FlD0flC1flD26lC1FlB00=_4flBJa803flB00=_4f/CJa<02f/C1F[b0f[c0f[b0V[c16[b
0V[a16[b0f[a0f[b00AZlFKAI]9VdP9VlPEVl@04I]9VlfKBI]42I]8;I]43I]04I]4016;AI]1Vd6K@
0fJ`00=Vd6JaI[400fJa00ER/F:`H[1R/6J`00AR/09R[`MR/0ER[`9N[`AR[P9N[P=NT0MNSP9NS`9N
K`05GXiNSEj>GXiNK`02FVl6FVh2FVd00ei]FViJKP07FVh015Y]FViJKUY]0UY^00AJK5Y<FT]JC0=J
B`=JC003FT]JC5Y=00=FCA5FC09BB`9B:`=B;003DReB;58[009B:`E>;004DRa>;4h[CP`3CP/5CR/4
CP/1DPX1DP`00005120880a0344@HP05344224402PQ2244400PP588eA4i;FXaJSEY^0eY_0UY`00=J
LEY_FVl00Ui^0Uj>1Ej?00=NT5jAGY400ej@00ANTEj@GY1NT0INT@9RT@05HY1R/6:?IX]R9`02GNL0
15g6GLMIj5WX0UgW00=MaegWGNL00Uh72Uh800]N:Eh8GPUIjEX:DLM5@dfVDNUEjEWY009Eb@0>ELM9
QTUVCHM9QTUUAF@di2AT<>9B2EI<DReFCP9JCP0<GY1N/F:`ETliJAaR300D82BS>FLmQR350PP00Q10
00D<@0a1368<HPaQ008<@@8@@@0=368@HQ1R468@@Q1R368@H@a1220400PP12400P@P014880@0100<
81AP8>@HPPaR468@@A1Q244400PP9BEFlFLa009_E@9_=P=_=`03KcI_=flf009_5@0;KcE_5F[cCPdP
Y0P1324DHaAR588DHP0346801123588DPQB211BS1ABT00PDYABT6:DHaAS46<DLaAc40abT0Qc400TL
aAc47:@LY1RT7:@HY1bS7:@011bS00DLY1RT7:@LY23400<LY0066:@DY1BT4:@DY12T0aBT00<HY1B3
68<00aR300LHY1bT7:@LYABU6:DDP`02688268<00aRT7<@Pa0049>D29>@39@D39>D01BCV9@HQ1RCV
8>D00RCU00LTa3EWDTe[EGNhNmMcN003MiP017^GNiQkV7^H0WNG00Uk^7NJLgQN/cDX620DHQc57>D0
0acV0R3U00DU1B3V6:@<@@`P00T88007340<8111568HXac57>H00R3V014TiRC59<HTabT6<BHLa1A1
300@@0aQ344DHARR6:<DHQ1R008DH@0868<LXbCT8>DPa1R2448<@P8<@@@88@8<8@8<@0<88088@004
2448@0PQ224222003PQ0344<@A1Q488<@110;>0mQ5HZI^m_4f[bJ_<4J_@3J_D4JaD5Ja@00f/EJaA[
5002Ja@5Ja<016/DJa=[4flC1V/C0f/D16/C0flC3flD0VlC00=_4VlCKa<00VlC1FlD00A[4f/DJaA[
50A_5005Ka=_56lDKaA_4`05Ka@:Ka<00flBKa=_4`03Ja<00flCKa9_4P02Ka800f/BKa9_4`0@Ja<2
J_<5J_85J_<>J_8016[aI]5VdVKB0VKb0fKa0VKb00EVdVKCI]9VdFKB00aVd@03I]1VdFKA00AVd@03
H]5VdF;A009Vd09V/003IZmV/6J`009V/@9R/@05I[1R[f:`I[1R/003I[001f:`HZmR/6:`H[5R/6:a
009R/005HZmR/6:_H[1R[`03GZl00f:^GXiNSP02GZl00ej@GY5NT007GXh3GXl00ei_GXiNS@02GXh0
1Ei_FVmJKei_FXl015Y^0UY]00=NKUY^FVh00UY^0UY_0eY^00=JKEY^FVh00eY^15Y<0eY;0eY<00=J
BeY<FT`00eY=0eI<00=FCEI<ETd02UI<0U9<258/00=B:dh/CR`00dh/00A>:e8[DRa>;09>30=>2`E>
:`9>2`03CPY>2e8:005B300000@880`P340<@0<<@@03348<@@a100@<@P06120880a0=DA>BeZ<0UY]
0UY^00=NKUY`FW000UY`00=NKei^GVh00Uj>1Uj?25j@00=NSej@GY4015jA0f:A00IV/FJ_IXYR9egW
GLL3FLL015WXFLMIaeg70UgW0Uh725h800YN2Eh8GPQN25gXFNUJ:dV7@@55I@9=b@91R00RBHM=YU6W
DJI=QTV7BHI5I3ST948XX4G7DTi>;EH/ETaJCEY_H]9VdEj??FTPHP`0540PXcUV?FDTi@`1200D@110
340734400a11468@HP0246802112468@HA1Q344880@022021202220050P0100<01AP8<@DPQ1Q344@
H@aQ368000PP:DEB/6]BKeE_EVleKcH3KcL017<fKcM_=Vlf0VlE00M_=FKADRdXX``Q54<DH`035680
0a1Q468@HP07588011BR5:<HXaRT0QRS0aRT00<DY1RT6:@00QRT0aRS1AbT00@LXaRS6:<HP`8DPP07
68<HXaRS6:@HXaRT7:@00Qc40abT00<DPQ1R58<00QB300@@PaB268<DPP8DH@0<584HPQB1568HPaR4
7:@PiART58<HY1R20QAR00@HPabT7<@Pa0DLa0038<@PaB3500PPa@0=7<DLY1bT768/`DGZHa1g]W_I
MiQgN7NINiT00g^i0W^H00YgUWngMiY_EeI@<BPD@1B27<DLi0<Li@068>DTi2TU8@HHX``P0PP020PP
00H<@0`P464DHQR37<@27<D021c67<DTaBC59<HTaBSV7:@232001a10444<@AAQ684DPQAQ008@@00:
564LPb2S:>@Y1B33664@@PaR36473442340922001`@P220880PP340DPQ1Q008@@007:<0mPdh9I^mZ
lFKbJ_<016[d16[e0f/E0V/D0f/C00=[56/EJa@00V/D26/C00=_4f/CJa<00V/C00A_56/CJaA[509_
50=[4`03Ka9_4flC00e_50E_4`9_4P9_4`9_5008JaA_56lDKa=_56/DKaA_4`9[4`03KaA_4flD009[
4`06Ka=_56lDKaA_4flD0VlC00=_4V/BKa800flB00=_4flBKa800VlC0f/C0VlC1flB00=[4f/BJa<0
1V/C00=Zlf[bJ_<00V[c1F[b00=ZlF[bJ_800V[c0V[b00=Zlf[bJ_800V[b00=ZlF[bJ_8016[b0V[a
00=VlF[AI]400VKB00=VdFKBI_400VKa0VKb0fKB46KA1fK@00=Rd6K@I]000VJ`0VJ_0fJ`00IR/FJ`
H[1R[f:`HZl2H[02I[02HZl4H[001ejaH[1R/6:_H[1R[f:`009N[`03GZiN[f:^009NSP05GXmNT5j@
GY1NS`04GXh00ej=GXiNSP02GXh2GVl01Uj>GXeNKUi]FViNK`9NS`03GVmJKUY^009JKP03GViJKUY^
00AJKP=JK`9JKP04FVeJKUY_FVl2FVh00eY/FTaJB`0:FT/00eY<FTeFC002ET`00eI;ETaFB`0:ET`3
DT`3DR`00e9;DR]B;002DR`5DR/014i;DTYB:e8[0Th[1Th;0dh[0Th;00=>:Th:DPX00E8<000010a0
320<80PP0Pa100@@HQ2346<<HP8<@@88@@07224480a1<BABBeZ<FXd00eY^00=JKeY`FW000eY`0eY_
1Ej@00ANSej@GY5NT@MNT004GXmNT5jAGY02GY402F:@HY5RTFJaHXmVRf8YGPQIb@03FLP015WYFNQI
aeWW0UgW0Uh725h802mN2Eh8GNQMj5h8FNUB2dV6@>19QTg9DNUEjEG9FLQEaeGXFLM=QTV7BFI5I3d5
964XPD6WCTm>;E8]EReJCUY_H[5VdEj`?HXTPa0Q520PXcE6?HDTiP`Q200D@0a000D<@@04348<@@a1
464746801A1Q34488@P022000P@P0PPP00P800@0220HXB3U6:<@H@a10PaR00/<H`00000U0di^Jbi_
M6mFKcEc=VmG009cE`9c=`0<KcM_=VlfKcIc=VJaALXTHA0Q444HHQAR0QAQ00@@HA1R468DH@@DPP04
684HPQR2688568<00aB36:@HY0036:@00aRS68<HP`026:@37:@031bS6:<HPaR3464DHAR2588DHQAQ
588HP`8HY0036<@HXaRT008HP`08588@@A1168<HY1B2688PX`8LX`037:8HXabS008HP`037:@LYAc5
008La0047:@HXabS7:<27:@57<@011S47<@La1c40R34018LXac48<DPaAc57<@LaB357<@LPaA1520L
@3UVEZa_LgNiLiT2MiP017NINkYk^g^k0W^I0W^i00QgVf;E@LhPYA127:DLiBCT0R3U00TLiB3U9>@]
9B3U6:<@@0`P200020PP0P`P00@@@AAR6:<La0<LiP048>DTaBC59<D28<D02QbU548@@A1Q344@@AAQ
6:8DXaAR0Q1000XHHAbS8<@/iBSU8<@HHQ12368<@P@<@@03348<@@a1008<@0T880848003220<@0a0
008@H@0;440@82S0>F=B:V;_J_9Vlf[cJ_AZl`03J_@2J_D6JaD:Ja@00f/CJaA[5004Ja<016/DJa=[
4f/C1F/D1flC3flD1FlC26lD0f/D00A_4f/CJa=[50A[4`05Ka=_56lDKaA_4`03Ka@9Ka<6Ja<3Ka<0
16lBKa=_4flC26/C0f[c0V[b0f[c00=ZlV[cJ_800V[b1f[c00=VlV[bJ_801V[b0VKb0V[a0VKa00=V
lVKBI]800VKB00AVdFKaI_5VlPAVdP]Vd@03I]9VdFKA009Vd@EVd09Vd@04H]5VdF;AI[04I[43H[4:
H[0016:_H[1R/F:a15ja0f:`00IN/5j@GY1N[ej`GZh2GXh5GXl01Ej>GXmNSej?GXh00Uj?1Ej>00IN
K5i]GVeJKUj>GVl5FVh3FVl5FVh2FVl00eI_FViJKP06FVh2FV`01EY;ETaJC5Y<FT/00UY<15Y;00=J
C5I<ET`00eI<00=FCEI<ET`025I<1E9<00=B;59<DT`0158/00EB:dh/CRaBBe8[009>:`03DR]>:dh[
00M>2`08CRa>:dh/CRa>2dhZCPYB2P5B300000H<@0`P100400a13644468030aQ34488@@P2204811R
;@=::UY]GXeJKP=JK`MJL0ENL09NS`04GY1NTEjAGY43GY02GXl2GVl2GXl00f:?HY1RT@03HY001V:`
HXiVS69:GPQMb@=Ib@04FNUIb5W7GNH3GNL2GPL2GRL3GPL05F87HRMN2687GPQR1eh7GPQF2Tf5@@15
IDg9ENUN:FI7HPMMieW7EJIAQP02BHH06TET>@@THRBQ@JQBCeI=DRaB;E8/ETiJKFK@GZm5bbRS420@
01b2<DDmYBd744880110340834400a1Q468@HP04468246401@a1224880PP120010PP00L800PP7<8U
9ac3464@HP0236802@a2000001BR@NU[:W=cLgI_=@02MeH01GMfLeMc=g<gLcH00Vlf00UcEg<fGY0m
J1Q0420@@1QQ44001QAQ00<DPAB2584011R10aR200<HHQR268800aRS00<HPaB36:<00aRS00PHPaRT
7:@DPaR27:<HPA1011AQ00<DH11144400Q1100T@HAAR588DHQ1R588HPQb266800QR200<LPQbS7880
0R2R00<T`bC28<<00b2S00PLa2348<@La1bS6:8LXb330R2S00<La2347<@00R3400TLa1S47<@La1bS
6:<LXac47:<00QRS00<HPaR256800QAR00TDHA10300@02cQANUW3FnGMkX00W^h00=kV7^INiX00W^J
01Eofg^iMkY_>58b;BTHI1B47<HPiBCT8>DTiB3U9>DPiBT58@DHXa1032000PPP00<88@PP220010PP
0P`P00@<@AAR6:<Pi@8U1P038>DPaBC400<Ta@0F:>DLaAB4568@H@a1464DHARR6:@DPaA1560HHAb2
8:<Xi2CT8:<LPQAR368234400`a0344<@@02348010a1340<@0PQ1`PP10@P00@880`P440@H@8<8004
:<0mPeHZH^l2Ja@3J_<01F[dJ_=Zm6[dJ_D026/E0V/D0flC00A[56lDJaA[4`9[5004Ja=_4V[aJa<2
Ka<016/CKa=_56lD0V/D00=_56lCKa<00VlC00=_4VlCKa<01VlC00=_56lCKa<01FlC00A_56lCKa=_
4`I_5007JaE_56lCKa=_56lCKa@00flC00I[4flCKa=_4f/CKa<2Ja<4Ka<00flDKa=[4`03Ka<4Ja<0
0f/DJa=[4`02Ja<3Ka<3Ja<2J_<5Ja<6J_<6J_82J_<2J_82J_<2J_@3J_<;J_82J_400fKaJ_5Vd@06
I_400f[AI]5Vd@02I]400fKBI]5Vd@09I]44I]800fKAI/mVd003I]02I]401F;AI[5R/FJ`H[400fJa
0f:a0f:`00=Rd6:`H[0016:`00=R[f:`H[000V:a00=N/F:`H[000f:`0UjA00AN/Ej`G[1N[PQNSPIN
S`07GXiNSEj>GXeNKEi/GVd00Uj>00=NSEi]GVh015Y^0eY_3UY^1UY/00]JKEY<FT]JK5Y<FT]JJUY:
FT]JC5I;00IFC09FB`QFC0IBC0EB;003DR]>;58/009B:`03CR]B:e8[00=B:`E>2`9>3007CR]>;4h[
CP]>:Th:DRX00E8<0002340222000`a1368@H@0334801@aQ344<8@P034000Pa100HY0dGYEVeNS5Y]
FVl3FW000eY_FW1JL003FW000eiaGW1NL002GW02GXl7GY02GXl2GVl00f:?GXmRS`06HY0016J?IX]R
BUh80eW800EEb5WYFNQMiegV00=Mi`9N1`03GRMN25h8009N1`03HPMR9eh700=R1`0HGPMN9eWXELE5
@TEWDNYJ2V98GPQIieW7EJMAQdf7BHI=YdEU>@@TPR1P?HQ>CUI=0U8/00m>;E8^ERaRd5j`BN``a10P
400LXS4U@JH]9a1310000Pa000@<H@a2344<@P@<@@04468@Ha1S46<2348244801Q1R34888@PQ2204
80D88006100HXRDW7<<DHA1R0PaR00d<@`PR100<HCVWI`]_LfmeLgMgMWNFLeIcE`02LcL2KcL026mF
LgQ[55I@=BLH810P544366400aAQ560DH@0268400aQQ564HPP026843788278<011R3688LPab30QbS
00LHXabS7:@LY1bS68<HX`026:@02abT68<DHAA0788PXQb1880/hS44<BD00S4400Le1344::8TPBBR
:<<a9P02>FL3>HT01SUX<BH/i2S3::8PPP8LP@<PXP078:<TXbBS884PPRBR88800R210Qb200HPXabS
78<PXb2T7:@37:<01b337:<HXQbS8:<LXaR2008HH@0O544DHAQQ668D@0`0840eA4i<JgIcV7NjNkUk
UW^GOkQofWojOkUgVV/eFW<iSAb558@HaB3V9@DTi23U8<D00b3U00DTiBD67:<@@0PP00<88@042208
8@PQ224222002``P340@HAAR6:@U1RD79@HPiB359<@00RC500dXiC4U8<DDQ1B3468<@A11564HXQS4
56<@@@02664021b37:<Ta2ST8:<LPaAR368234400`a0344<@@02244234400``P22488@0522051200
2P@0220<@110200<82C0>H=B:fKa0V/D00AVm6[dJ_AZm0=Zl`03J_A[5F/F00E[5@04KaE_56lDKa@2
Ka<00f/DJaE[5@03Ja@2Ja<2Ka@3Ja<00flCKaA_5002Ja@00flDKa=_4`06Ka<01VlDKcA_56lDKa=_
50I_4`=_50A_4`=_5003JaA[5F/C009_4`03KaA_4flD00A[4`=_4`I[4`03KaA_4f/C00E_4`9[4`=[
5003Ja=[56/C00M[4`03Ja9Zlf[c00=[4`04J_=ZlV[cJ_<4Ja<016[cJ_9ZlV[b0V[c0f[b0f[c0V[d
0V[c3V[b00AVlFKbI_9VlPAVl@05J]5VdFKAI_9Vd@03I]8016KAI]9VdFKB0VKA00=Vd6KAI]000fKA
00MVdVKAI]1Vd6;@I]5Vd004I]400f;AI[5V/@04I[44H[45H[03H[43H[03H[44H[02H[401UjAG[5N
/5j_GZiN[`9NS`03GXiNSej?00INS`9NSP03GXmNSUj>00=NS@06GVeJKEZ>GXeNKEi^15Y^0eY_3UY^
1UY/0UY<00AJJeI]ETaJC0=JB`03FTaFBeI<00EFB`04ETaFBeI;ET/6ET`00e9=DReB;@02DT`9DR`7
DR/7CP/4CP`014h;CRY>2U8:0E8/00000`aQ444@HP0246801@aR364<@@PQ24400Pa100`<@0PP344<
@@P0:<=5jEI]HZaJKUY@FW02FVl00eY^FVmNT002FVl015Y`GW5NL5j?0Ui`00=NKej>GY0015j@00=N
TEj@GXl00ej?015RSej?GXmNSf:?GY1RT6:AHY1RSfJ;HTUIieW6ELIIaeW8009Ij003FLMMaUgW009M
i`=N1`9N20=N1`0aHPMN1f87GPMR1eh7GPIIieW3CD=5R5GZHTQN:5h7FNQIadV8AFM9ITV5BJI5ICTT
:84TP3UVBPaF;58[DRa>3DW]CReR[f:?BN`/a1A1520TXSE5?JHaAa13100<80a136400`a10`a20Q1R
00DDQ11S468@@Pa2008@@P05468<HP`Q224880031202220210004AB19@HLXQ1Q468@Ha1R46<<@`PQ
220Y0di:I^acM7NGMiP00W=h00YcF7=GKeQ_F6mGKgM_EV[a@J`PI08@8003668@@0`P00<@808D@0D@
@004564D@1A0564254400aAQ668DH@045642688011B2568DHQAQ0QB201HDHQR2788PHBcR>DDmR4G:
APaB358=EPeF;5i<DPe1R333<>A1R4h=EVmNSPAJKP06DPi5kCEY;>DXXR1P12B000<PP2B098001RB0
12200R210R2R0RC200DTP2R0;<0/hBc0008TP00M:80TH220::8/`RcR::4PH1a0300PH3V7F/i_M6mg
LiUgVGnhOmQo^G>HLiM[EUI_?JdPbAR55:@PiP029>D00bT58>DLa@037<D00bT69@HHX`0232022240
0`@Q22088004220020`P340@HAAQ6:@PiRD68>H28>D28<D01bC5:>D/i1bT68@DPaAQ008@@@0@564L
XaRT56<@@AAP564HPb2T9>@TiAbS788DHPaR3443340010a12248@@Q110PQ0`PP00@480PP220880<4
800;200880`P340800`P:>0iHdX;H]1[5002I_<2J_@01F[cJ_9Zlf[cJ_@00f/E0V/D0f/E00=[56lD
Ka<00VlC00A[56/EJaE[509_50M[4`03Ka=_56lD009[5004KaA_4flCKa<2Ka83Ka<6Ka@7Ka<016lD
Ka=_4flB0flC0flD00=_=6lCKa<01FlC0f/C16lC00=[4f[bJa800V/C00=_56lCJa<00flC0VlB1V/C
00A[56/CJa=_4`=[4`0:Ka=_4VlAJ_5Zlf/CKa9[4f[cJ_82J_<3Ja<2J_<5J_800f/BJ_9ZlP02J_84
J_<5J_8016[aI_5VlFKa1F[b00YVlVKaI]5ZlVKbI_5VdFK`I_5Zd@9Vd@9Vl@=VdPEVd@04I]1VcfK?
I/l2I]02I]42I]02H]04I]02I[000f:aI[5V/@03I]400fJaH[5R/@02H[45H[03H[42H[0016:_H[1R
/Ej`0Uja00AN/5jaGY5R/@=N/003GZmN[Uj_009NS`03GXiNSej?00=NS`03GXiNSej>009NSP03GXmN
SUj>00=NS@ENK@03FVeJKUY^00]JKP03FVeJKUY^009JKP9JK@=JK003FV]JBeY;00=JB`05FV]FKEI<
FTaJB`02FTX2ETX00eI;ETYFBP05ETX4ET/4ET`2DRd00e9=ERaB;002DR`00e8[DRaB;003DR`9DR/7
CP/3CP`014h[CRY>2dh:0Dh=00002PaQ468<HQ1R46<<H`a22248@@Q20PQ100X88@PP340400PP8:=1
bEI_HZiJK`9JD09JL004FViJKeY_FVl2FW000eiaGY1NT003GY000ej?GY1NT002GY02GY401Ej@GXmN
T5j@GY401Ej@00UNTEj@HY1RT6:=IX]RBEh7FLH00eW700AIj5WWFNMIi`9Mi`9N1`EN209N1`04HPMN
2687HPL2GPL03Eh6GPMIa4UT@FMAbEh8GRQN25gWFLMEb5FX009=QP0;BHM5ICT3;:8TXCU7BPaJC58[
DTa>;@02BPh0458/ETi5bbcU544D822R<BDmYcEX46<400P0324<@@Q10Pa10`a200<<HQ1R46<00Q1R
0Q1200L@@a12468<@PQ210088003120222021000111Q8>@HXaB20a1R0Q1S00H8@@@0340eIDi>Ia42
LiP01G>ILgUcNFmiKeP00VmG00i[EFLdCTl/iQ0R420D@A0P300<8110420<010P0aA000@@@1AQ440<
808@80H@@003444DHAb2008LP@8HH@03784LPQb1008LP@0Q788PPAaP::4iADGZFVaRd6/DJcE[5VKE
I]9ZlVlEIVm9JCeYCLaV/6LDH_9RdVKCI_AVlfKdH[5FD4g]?FTe1CD4008i9003=@@e1CD4008e1003
>DHmIceW00<mI`8iI`0N>FPiB3UY@HY5ZT68>DHm9Cd3?B=5IDF4AFDm8cd3@DI9bUH<DRe>2dW:?B<T
H100300PPSVYDXmO4f<D0f]F019[=FLeG]5>Ccf/9>LHQQB57>HQ1RD59>DTi2357<DHY1R47<D28>D0
21R2200800@022448@PQ124422401``P344@@A11588HY1c4008LY00E7<DTiRCV9<DXiBSS7:@DHaAR
564@HA12568HPQRS58<@@A10564HPb34008Ti@047:<HPQ123483344010Q122488@PQ0PQ100<88@PP
22001@PP1@@P0`PP00X8@0@0320Xh3USAP]Rl6/DI]9Vl`9Zm0AZl`I[50=[5@A_509[509[5@A_509[
50E[4`E[5003Ka=_=6lC00=_4`08Ja=_56lCKaA_4flDKa=_50=_4`9_509_4`03KaA_4flC00=_4`03
KaA[4flD009_5003Ka=_56lC00A_4`=[4`9_4`03KcA_4flC00=[4`9[50=[4`03JaA_4flC009_4`E[
4`04JaA[4f/CKa<3Ja<00f[cJa=_4`05Ja<00f[cJ_9ZlP03J_<3J_83J_<00f[bJ_=ZlP05J_82J_<8
J_801FKaJ_9ZlV[bI_400fKb0VKA00UZdVKbI_9VlVKaI_9ZlF[AI_401FKB16KA00=Vd6KAI]000VK@
16KA16;A16KA00=V/6:`H[400V:a00ARdF;BI[9V/PAR/@ER/003G[5R/F:a009R/@03H[1R/Eja009N
/005G[5N/5j`G[5R/@02GY02G[02GZl3GXl00ej@GXmNS`02GXl00ej>FXiNSP02GXh00ej?GXiNSP04
GXh4GVd00eY]FViJKP06FVh3FVl4FVh00eY]FViJK@03FVh2FVd02UY/FT]JBUY/FV]JKEY/EVeFC5I=
1eI;00=FC5I:ETX00eI:15I;15I<00ABCE8]DReF;0MB;0aB:`I>2`9>309>;09>:`5>2`5:3@000Q1Q
00D<@Pa1344<H`a10088@@<88@03200<00`P008800067:8mZ5I_HZiJCeYA0eY`0ei^00=NKei`GY00
15i`00ANT5j?GXiNS`9NL005GY1NTEjAGY1NS`02GY07GY4026:@HXmRSVJ=IX]RBEhWFLH2FLL2FNH2
FNL2GNP01EgWGPMN1eh8GPL01eh80V870f8600IN1eW5BFA1AdW9FNL2GPL085g7GNMMj5FWDHI=QTV7
AFDm92c2980e9TX<ETaFBeI<DTeB34W/CN]9k46Z;>@HHA00540]146X>FTHQ0@0200234400`Q1344<
@@03344236800a1S368<@P0444801AAS348<@PPQ22000`@P0P@000H800@0440DPQR25644468030aR
244800P068<iIdi>Ha9_MFmfKeM[=P9_E`0DJeIW4f;_CTleAaQ1548XXbcS:<<PPBB1;<8XXB10940/
P3CQ=@4/h@8/`P06;<4/`RcS;@Da1BcU0RSU00La9SE7=DLa9c4V<BLeA`02>FP00cEX>FTiJ002?HT0
53DU=@DmIeY:Ja9cMW^iOmYo^VlhI]MVeG=HMi]_5UX>BH]J;Uj>G[42FVl04EI?H]=cN7^kNkY[5ejC
FPiEZeWZHTaRKV9]GTeNC69<IVd00VZ^0VJ_00EVSVJ^IXmRSV:?009RL00YI[5V/6Z>GRaAbU6XFNQR
:FHWHPQMaf7WIT]Z[g<CLeAgE6J/DPX`XA0P200<8AbS:BDaRD8<CTaJSEJ=FZm>CT7/;DPLaQb47:@P
iRCU8>HLi@028>D02Qc57<@HPaB37:@La1c558<<80P00P@01`PQ00H880`Q200800a1468258807aAR
68<LY1c5:>D]1C458:@DHaAR564@H@a1564HXQRS588DHQ11568HXb34:>D/iRC4788DHPa1320<8@PP
00D88@X880840003120880PP00888@08120000PP:<0iHDX:H_5[509Vl`=Zm0AZl`03Ja=_4flC009_
4`9_5003KaE_56lD00=_509[50M_50Q_4`03Ja=[56/D009_=0=_4`03KaA[4flC00Q_4`9_50M_4`I_
50E_4`05KaA_4flCKa=[4`05Ka<6Ja<4Ka@00flCKa9_4`02Ja<3Ka<3Ja<00flCJa=[4`02Ja<3J_<4
Ja<00f[cJ_9Zl`02J_<6J_801F[cJ_9Zlf[cJ_800f[a3V[b16Ka00IVlVKaI]5ZlVKbJ_82I]401F[B
J_5ZlF[AI]800fKA00=VlVKAI]402fKA1F;A0f:a00=V/6J_H]400V:a00=RdF:bH[4016:b00AR/F:_
HZmR[`AR/0=R/@AR/00:HZmN/5j_G[1R/F:`GXmN/6:`G[02GZl01Uj^GZmNSej@GY5NS`=NSPANS@MN
SP03GXeNSUi]00=NK@03FVeJKUY^00AJKP03FVmJKUY^00EJKP08FVeJK5Y]FTiJKUj>GXmNK@9JB`9J
K006FVeJK5I]ETaFCEY=15I<00=FCEY<ET/00eY:0UI:0eI;0UI:00QFBeI<ETaB;EI=DRaB:e8/0UH/
0U8/158[1E8Z1U8[00=>:dh;CP/00Th;0dh<14h;0Dh=00001A1Q440<@@PQ344010Q10`PQ0P`P00P@
@0`P200LPSUWDW1N[eY`0UYa0UY`0ei^00=NKei`GY000Uj@15i`00=NKei`GY4025j@1EjA00YRT6:A
HY1RT6:?HXiV[F9[GRMMi`9Ia`05FNIMiUW6FLMIb002FNT00eh8GPMN2003GPP0<Uh9GPQN25hXGRUN
25h7HPIR1Eh6GRQEadf6AHQAbEX7FPQIj5W7DJMAb5FWCHI9QTUVAFDmABc1860a1TX=FTaJJej=GZmJ
C5GZDLY5ZSeX::@HHQ00540XiD6W>HPHY0P032073446348244801a1S448@H@a232488@PP00<48006
220480PP200880aQ0a1Q111R01L<@@`P200<8Ab3=FQ:Ce[?HaAW=6/eIaA[=F<CF]9:;C56664802B2
<@DmQe8]009F;@0BCPa5R3dV?@=5QE7YGRYF2dg:CJY=bUG[GTaNK5X/FTeRTEjA0Uj@00ANKeY>GVmV
/P9V/`0PI[5V/VJbJ_=ZdV:aFRe=ZUG[I]1k^7oiOoYooGoKKcQRef[eMgQg_7=iI_ENT5X]FVmJL5Y>
BJY9cEkCLiUoo@9of`0:LeUZ/ei@IW1c5GMGMgMgN7]gMeH2McD2MeH017<eMcEgEW=G0W<e02Uc5G<f
LcIc=VlCIXiRBV8XHTMVIfjYJXUZJFYZK/mgEWnhOoUo^7MeHT`m9Q@Q100<81B38<@Q1BT4;BH]ARe7
:DLY9RD57<DLY2359>HPiRCU008Pi@<Li@087<DLYART7:@LaART58<@HP888003320880PP008880<8
8@06220800@02008811R0QB301/@@A0P444HXac4<BHe92C466<DHQAQ444<8AAQ7:8La1R3568DHAAR
6:<PY2C4:>@Xa1b1444010PP1@PQ3@PP00h88@Q12448@@@P000802S1>F9>:f;aJa=Zm6Kc0f[d16[c
00=[4flCKa<00VlC1VlD00A_4flDKaA[4`M_50M_4`06KaA[56/eJa=[56le0flC0V/C0flC00=_56lC
Ka<00flC0VlD0VlC0VlD16lC1flD0flC00A[56/CKa=_4`I[4`A_50A[4`=[50=[4`05KaA_4flCKa=[
4`02Ja@4Ja<00flCJ_=Zl`04Ja<6J_<4J_86J_<016/CJ_9ZlV[a0V/B0V[b00=Zlf[bJ_801f[b1VKa
00AVlVKBI_9ZlP9Zd@05I]5ZdF[aJ_9Zl@02I]400fKaI_9Vd@03I]400fK@I]5Vd@06I]401VKBI]5R
dF;AH]9Rd@9R/@03I[1R/6;A009R/@9Rd@9R/@9R/P9R/@=R[`AR/0=R/@AR/007HZmR/5j`G[1NTF:`
HZl00f:`0Uj`00=N[Uj_GXl00ej@1Uj>00=NSEj>GXl00Uj?0ej>00=NSEj>GVd00Ui]0Uj>00=NKeY^
FVh01EY^00=JKeY^FVh00eY^00=JKEY/FVh00eY]00IJKUY]FVeJKEI]FV`3EVd015Y/ETeJCEY=0UI<
0UI=00=FC5Y;FTX00eY:00AFBUI;ET]FB`9FBP03FT]FC5I<009F;0=B;003ERaFC58/009BC005DT]B
:dh[DR]BB`02DR/2DRX5DR/014h[CP]>2dh;1Dh<00=>2dh/BP`00Dh^00000`a032040002100010Q1
344<@@a10PPQ00@880`P320@@0880005668iAU9`H[1NT002FW42FW001Ui^GVeNKUi_GW1JL09NT0=N
L09NT0=NT@03GXmNT5j@00ENT09NT@9NT00<HY1RTF:AHY1R/6:>IXaRJUhWGNIMieWW0UWV00=IaUW7
FLP00UWY00=N25h7GPP00eh800=N2Eh8GPP00eh8015N1f86HPEN1Uh8ELMAQUFWFNQVAUh7FNMEb4fV
BHM5ITEU0099I@0KAFE1AC31860e9TX=FTaJBf:^I]1RSUXZENY9bce8::@D@@`0544XiCfW=FLLX`P0
300880`Q00L<@@<<@P06368<@Pa2348<@A1Q0Pa100<880PQ12400P@P0`PP00@800PP340<@08@H@03
368@HQ1R008@HP0`464<80P0324DPbdW?JY6;E9_EXmJ[di?@N`aR2TU7:<800@0::15bF[[Le5kUGMD
La9VKEG:GJMZJ7L?Mbm^cfI]HRYZKWLCNeAgEGMfLeI_=FlEKcIcF7MhMeMcEgMH0WMi021kVWnjOkYk
^W^ILcIND5GZFRaVlgofOoYooGonOoegVf;gH]AkMWoHOkQcEV[aGTeJCf:cGW5F<E8bH]Io^Gon0Woo
00YooWnHKaI_5G=GOiUoUgmgNgMkE`=kEP9oEP03NeIkEgMG00=gEP05LcEc=7<CL_9ZS@02IVT00fI7
HTMVJ@02JZ/03Fk_Mc=oMGndOkEoeGMeJZe1Ib1R200@8AbT008La@046:<DPaRR7<<26:<01ac48>DP
iBCU9@HTiRCU008Pi@047>DPiAcU8>D47<D011RT58<@HPa00P`P10PP0PPQ00<48@PP22000PP001D<
@A1R588DHQ11440@81107:<Y1CU49>@DHaAR440<@@`Q564LXR347:<00aAR00<LPb2T:<@00RC300DL
HA10220<80PP0088@00524488@PQ12488@0=22003@Q0344<HPQ100088231>F=>:V;`JaA[4f[c00=Z
m005J_9Zlf[cJ_=[4`06Ka<3Ka@00flcKa=_4P03Ka<6Ka@7Ka<00flDJaE[5@03Ja@00f/CKa=_4`02
Ka@DKa<016lDJa=_56lD16lC00=_4VlCKa<00VlC00=[4flCJa<01V/C0VlC0f/C00=[56lDJa<00V/C
00I_4flDKa=_4flBKa<2Ka@2Ja<3Ka<00flBJa=[4`03Ja<6J_<6J_85J_<2J_83J_400f[bJa9ZlP0:
J_802VKaI]5VdFKaI]5Vd6KAI_9ZlV[A16KA00=Zd6[aJ_400VKa16KA1FK@1VKA00YVd6;AI]5R/F;B
H]5VdFK@H/mRd0=Vd008H]5V/6:aH[5R/V:aI[1R[`eR/09R[`0;H[1N/6:`H[1R[f:`HZmN[ej^GXiN
[P02GZl3GXl00ej]GXiNSP04GXh4GXl00ej>GXeNK003GXd3GVd00ei/GVeJK@03FVh00ei]FVeJK@02
FVh2FVd2FVh01EY]FVaJC5Y<FTd00eY]00AJK5Y<FVaJJ`9JK005FVeJK5Y/ETaFC@03FTd00eI=ETaJ
B`03FTX2ETX3ET/00eI:ERYFB`03ET`015H/DRaB;5H/0UH[00=B:e9;DR`00U8[00=>:e8[CR/00U8[
0U8Z1E8[00=>2e8[CR/00e8;14h<0Dh/0Dh[0Dh]000232000`PP244<@@023442244222403@PP320<
8110300801QQ>DE>Cej=FVmJD5Ya009JL003GVmNKUi_009NL09JL004FY5NL5i`GW43GY02GY42GY00
1Ej?GY1NT5j@GXl01Uj@00QNTF:AHY5RTF:?HXeNJehW15W700AIiegVGLMIb09Ij@IN2003GPUN25h8
00=N:00:GPMR1V86GPIIieG5BFA=QeG7HRH2GPL07UWWELMAae6WCJM9QTUUAHE1IcD4740a1TG/FRaJ
K6:>H]1RSUi<FRYB3CeX:<@D@Q00448]1SV6>JPLX`880004220<8@Q12442368234800`a1348<@P03
368246<01a23468@@@a122088@@Q00@48004220400PP22023440111Q368<HPaR111R030@@P`P320@
@ART9@H]IbeY;DPY9R33588@@@P0320<02cRHXakTWojOmUo^GMfJ_9J2FH5M`ioU7nAMc=blVj`K]9g
=GmeOiMoMgMgMgQgNG^IMiUkN7MiNiUoVG]iNgX2OiT02GnHOmUo^7=GHY9=ZDG;IaIonP03Ool04Gon
MkaW6FlGMgIofW^HMgM_=6[bI]=_=gMhJaMVn6/hOkT017oo00MooW<gLaEkEW]hNgIcEP04KaD027<D
McEg=GLeLcE_=VlEKa@2K_<08G<BK_5^cg;>KZYZRVZ9GRMN:6J/J/ec<G]BNe=oDWmcOiEgMfZ_AHXX
P`P0424LY1c47<DHa1c47<DHY1cU9@HU1@029@H38>H38>D01AcU8>DPiB3U7>D00Qc500@LYART58<<
@@D88005224880PP1244800210001``P540La1S458<DPQR2008D@00?300@@B34=DDU1QB4568@HA12
324DHAbQ7:<HPaR2008DH@0778<P`bc3:<<PXQQQ54400P`P00<88@Q124400PPQ0`@Q00<88@PP2200
0`PP00<88@PP22000PPP00<88@Q134400Pa100T8HP@P220L`CUTBR]Rkf/CJa@00VKd00AZm6[cJ_9Z
lP9Zl`03Ka=[4flC009_4`E_5003KcA_4flB00=_4`Q_509_4`=_50A[5005JcE[5F/DJa=_4`06Ka@0
1VlCKaA_56lDKa=_50=_4`=_50=_4`05KaA[4f/CJa=_5004Ka<016lBKa=_4flD26/C1VlC0f/C00I_
4flDKaA_4flDKc@2Ka<3Ja<3Ka<8Ja<6J_<00f/CJ_9ZlP03J_83J_<7J_800f[cJ_9Zl`05J_800fKb
J_9Zl`04J_<03F[bI_=Zlf[BI]5VdVKAJ]9VdFKBI]5VdVKA009Vl@03I_9VlFKA00IVd@=Vd003I]5V
dVKB00=Vd@9Rd@03H[5R/V;A009Rd@03I/mRdFKA00=Rd@04H[1R/F:aH[42H[000f:_H[1R/00;H[02
HZl00f:`G[1N/003G[02GZl3GZh00ej_GXmNS`02GXl7GXh00eZ?FXiNSP03GXh015i]GViNKEY]0ei]
00MNK5Y]FVeJKUi^FViJK@02FVh015Y]FViJKEY]0eY^0UY]00=JK5Y]FV`00eY/00=JCEI=FT`00eY<
00=FC5I=ETd00UI=00=JCEI<ET`00UI<0UI;0UI<0UI;0UH[1EI;0UH[00=B;5H[ER/00eH[0U8[00=B
;58[CR`00Th/00I>:e8[DR]B:dh[CR`2CR/01Dh;CR]B:dh[DR/00U8;0Th;00A:34h<CRa>2`5>3@00
00@880`P320<@0<<H@0434488@P0220232002Pa0440<80`0540i94h]GVaJKUY@0eY`15i_0Ui`00QN
T5ZAGW1NL5iaGY1NSej@0UjA0Uj@1Uj?0Uj@00ANSej@HY1NT@9RT005HY5RT6:>GV]N9`04FLL02EWW
GNIIaeW7FLQMj5h8HPMN2002HPL3GPP01F87GPMN1eh7HPL00V8600MR9UgVFJ950D4UCJIMi002GPH0
8UX7HRIR9egVDJI=QTf5CJI9YcTT740/iD7;EReF:ei]GXiR[ei^GVeJCDFZ;>DH@Q0Q548XiCV6>JPP
a0P0100880`Q0`Q11@a100L<@Q1Q348<HPa2368<@P0234403``P220880@P220480PP120880P02208
@@a1348@H@053680111Q468@HPa10`PP10Q100<880PQ24400P`P01X<00`P;@9NRgnaOmMomGnGMeER
[UX8HREbkGnbOnMoTG;bK[5^dg[bOe=kEGmENeIgEWMG0g=G00AgEg=FMeIgE`9c=`0:McMkEWmfOkAc
=F:?AFM9c6]HOod2Ool04WonOomkgG=KMeQgMG^iMgMcEfleK_=gEgnjOmYkVVliLcMofPAoo`08Omac
5VKCMc=gMW<eKaEVd`9Zd`04J_=_56lEKa@2J_<00f[dJ_=Zl`02J_<07f[AK_1bkW/=N`ibk6Z9GPIN
:VJ/L`ic<GL`Lc5g<G]DOgEgEfZb@FTXPP`0320HPQc37<@Li1cU8>DLiR3V008U1@038@HU1B3V008P
iPHPi@038>@PiB35008La@036:@DPa1100P8800=124480@0000@@1R29@@La1BS588DPAAP44000PP0
00DHPRdU9@HHY11R008<@@0?324DHAR17:8HPQB2544DHAb28:</`bC38:8HHA11008<80888@031248
80@Q00848@888@D880D88@03324<@@a1008<@@0C368880`P8<8iI4X[H/mVlFKBI_=Vm6[dJ_=ZlV[A
J_9[4flCJa<00flC0flD00E_4flDKaA_4flB00A_4`M_50=_4`9_5004JaA_56/DJa@2JaD00f/DKa=_
4`03Ka@5Ja<00flDKa=_4`04Ka<3Ka@7Ka<01VlDKa=_4flBKa=_4P9_4`A_50=[4`9_4`A_4P=_4`=_
4P03K_9_4VlB009_4`A[4`04Ka9_4flCKa<7Ja<016/BJ_9Zlf[c0f/C16[c2F[b00=ZlF[bJ_802f[b
0fKb0V[b00AVlf[bJ]9Zd@AVd@9VdPAVd@9Vl@=Vd@=VdPEVd@=VdP03H]5VdF;A00ARd@04H]9RdFK@
H]43I]800f;AHZmR/002H[000f:_IZmR[`02HZl7H[03HZl01V:`HZmR[f:_H[1R[`9N[`EN[P03HZiN
SUj>00YNSP03FXiNSUj>009NSP=NKP06FViJKEY]GXaNSEi/0Ui]0eY]00=JK5Y^FVh00UY^00AJK5Y[
FVeJKPAJK@EJK004FVeJCEY=FT`2FT/015Y=ETeFCEI=0UY=00=FBeI<ET`00eI=00AJK5I<ET]FB`9F
:`=FBP06ERYFBeI;ET]F:eHZ15H[0U8[158/00A>;4h[CR]B:`M>:`03CPYB:e8Z009B2P04CP]B2Th;
DPX2CPX1CPd00007224<80a0468DPaRT48<010a100`<8@PQ344<HA1Q320@83DTDReRRej>FVl3FW00
0ei`GVmNL002GW000eY`FW5JT@02GY02GW400ej@GY5NT@03GY05GXl3GY001Ej?GY1NT5j@HY000Ui_
00ERT6:>HXeRBEgX009Ib003FLMIieWW009Ia`06GLQMj5gWGPMN26870f8800=R1eh8HPL0168702]R
9V86HPIMXD30?<9195W4GNIN1Ui7HRMN25G7DJM=QTf5CJI9YSD3864XiT7]DRiF;5Y_GY1VdF:aGY5J
STh]<BHHHP`0324PY3E5<HTPa@`020088@0224422243324234401@a2464@HQ1R44800PaR00<<H@a1
32400PPP00<48@@P12000P@P00L880P02248@@a1368<H@07368246800`aQ34888@0322006`PQ344@
HQ23468<@P`Q320Xhei[Mi9o]gnFNgE[4VJ^FPQN:6K=Oo=ok7o_Oc=fdFZAM]5c4P02LcD5LcH00flf
KcMc=P04LcH02WLfMcEk<gmCLcENKdV7CNa[=gok1Goo00m[>g=JMgQofg]gLcMZmF:bI]A_F7MiI_MR
]flGOmL017oo00Uk^fKFJ_Ag=GMgLcE_5V[dJ]@00VlE00=_57<EKa@00Vkc02I^m6lDKaA_56/EJ_9g
47m>Obmg46k<IVQN9f99J/a_3W<aLc9gDg]COgAoMgMGHVm1J2AR300<81RS8>@L`acS7<@LiAcV8>HQ
1RD50R46123V1B3U00<Pi23U8<D00ac500@DP`a1200400<880888@031244800000800009320HXQc3
7<DDXaRS588DPAAP00840005440Ti23V58@<@@0222404P`Q564LXAb268<DPQA1668LPRBS;<<T`b2R
568<8@P022088@H48@<88@0412488@PQ220522403P`P340<@0a1364<HPPP320PXCUSBPYRcVKbI]<3
I_@016[dJ_=Zlf[c0VlC00A[4flCKa=_4`9_50=_5@03KaA_=6lc009_4`03KaA_4flD00=_50=_5@A_
4`03KaA_=6lD00E_5003Ka=_56lD00=_5003JaA_56lD009_50A_4`03KaA_4flD009_50E_4`9_5003
JaA_56lC009_4`03Ka9_4f/C00E_50A[4`9_4`9_4P04Ja9_4VlCJa<2Ja800flBK_9_4P06Ja<3Ka<8
Ja<3J_<3Ja<4J_<HJ_85I_83I_<00f[BI]5Vd@04I]83J]43I]401VKaI]5VdVKBH]=RdPUVd@=Rd@03
H]9RdF;A009Rd@04I]5RdFKBI]83H]42H[000f;AH[1V/003HZl7H[05HZl3H[0016:_G[1N[ej_15j^
00=NSV:>GXh00Uj>0ej?15j>0eZ>00=JSej?GXh00ei^00=JKUY]GVd00Uj=0Ui]1EY]15Y^00EJKEY/
FVeJKEY^00=JK@AJK0=JK@05FTeJBeY;FTaFC003ETd2FTd00eI;ETaFC@04ETd00eI<ET]FC002ET/2
ETX2ERX00eI;DT]FB`02ER/4DR/5DR`2DR/2CR/0158[DRa>;4h/0dh[0e8[0Th[0Th;00=B2dh;DPX0
0U8:0E8<00003@a1324@HA236:@DQ11S468<HPa1340<8@PQ008<@@07464@@0`0<@=>;6JZHXd00UY_
0UY`00]JKei_GVmNL5i?FTmJL5j@GXmNT5i`009NL@03FY5NT5j@00aNS`=RS`07HY1RSf9^HXmRSV99
GNP00UW800=IaeWWFNL00UW700IMiegXGNQMiegXGPP3HPP01687GPQN25h80V8700]R9Uh6GNIIa5VQ
?>0d`d4TFLAMiUh6009IiP0LDLM=YdV6BFE=Q4fTAFDi12B2;@M:3eH_DRaJL5jaI]9R/UjBG[5BCCE7
768@00`0788a935W7<@232052242324222400`a1348@H@0246401Q11368<@Q1Q468<@@8880848@05
120880@P2208000222401@a1364@H@aR46800Q1Q00@<HA1R464@H@@@HPD@H`0J48<DPaB258<<8@`P
:>=JK7MbNkQoUGMEKcAVd5XYELINJgnbOnEo/G/bL]5^/6jaL_=c=@9g=@03LcE_=W<d00E_=P03LcEc
=W<e009c=P09LcEoMFleHY59R58:I_=of7on009oo`0AOoiogFLIJaQgF7omOmQcF6KEFU5JLEjdFU95
SCT;FRmo/`03Ool02GomMgMVmflGLcMkNG]GLcM_5`02KaH027<fMeEkEWLeLaAg=G/eNeD2NeH08WMF
McEkDgmBNe9bkVYYIVQN9VJ9IZY^kG<@Ka1_<g]eOiMo^7=EIXlmB21R320<8AS48@@L`acS7<@LaAcU
8>DQ1B3U0QcV123V1B3U00PPi2347<@La23U7<DDP`a10PP000<400P032000P`P00<880@000000P00
00@@@1B26:<Ha0<La00K6:8DP@`P100@82338>DDP``Q220<@A11564LXQbS68<DPQ11568LPb2R;<<T
`b2R568<8@P00088800322448@@P00D48@T88@0?244<@0Q0460@HA1R368880P0680e@dX:H/iZlfKc
009Ve09Vm0=Zl`9_4`I_50=_5@03KcE_=6lC00M_4`04KaA_5FlEKaD3Ka<9Ka@00flCKaA_5002Ka@0
16/DJa=_4flC0VlD0flC00=_4VlCKa<026lC0flD0flC0VlB0VlC0f/C0flD00=[4flDKa<00VlC1FlB
0V/B00A_4V/BKa5_4@=[4P=[4`9_4`9_4PA[4`9ZlP9Zl`04J_9[4V/CKa85J_<2J_82J_<01F[bJ_=Z
lV[bJ_400f[b0V[a2F[b0fKa00=ZdFKAI]800fKb00=VlFKBI]800fKB00AZdVKAJ]5Zd@EVd@9VdP03
H]=VdVKA00=Vd@=Rd@03I]5RdF;A00URd@=R/@07H]5R/F:aH[5RdFK@IZl00f:_1f:`2F:_00=N/5j_
GZl015j^00=RSV:=HXd01Uj>0Uj^00ENSUZ>FXiNSUj?009NSP03GVeNKUi^00ANK@05FVeNKEi]FVeJ
K003FVd4FVh035Y]FVaJK5Y/FVeJKUY]FViJKEY/FVeJK09JK@03FTeJK5Y<009JB`09ET]FC5I<ETaJ
C5I;FTYFC5I;009FC@9FC0EFB`07ETYF:UHZERYFBe9;ET/00UH[158[0e8/1E8[00=>:e8[CR`00Th/
00=>:dh<CR/00U8[0dh[00AB:dh[DP]B2`9B2P5B2@5B300000<8@@`Q34400Pa21@a100@<@0PQ2248
8@888008340<02cRCP]RRUj=FViJK`AJL00;GW1NKf:?GVmNL5Y`GXmNT5i`GW5NL00BGY001f:aHXmR
KF:?GXeN:5W8009Eb006FLMIieWWFNQIiegW0UgX00IMieh8GPQMj688GPT4GPP2HPL02f8VHPIN1UW6
FLE5IT4VBHMIaUh7GPH00UgV00AEb56XBHM=Q`9=Q@0HBHHi922R9<DmcDh_DReFL5ZAG[5NTEZBF]9F
KSVZ::<D81@Q764]12T66:<800PP1@PQ0P`Q0`a100D<@PaQ368@HPa200@<HP04324880PP12421200
10PP100480@P0PPQ00<<@@aQ36800PaR00@<HA1Q464@HP8<HP04468<HPaR368336<246<248<04aB2
468<8@`Q9<9B;7=?OkMo]GmcMgAVceXYCJEIiWL@Oi1oU7/c009^d@09L_5c4WLeNeEc=VlfLeIgEWMG
009cE`9gF0=gE`0FLcMcF7^HNiQgN5jBAJY5ZF:aMiUoo7onOomooG=kG[INU7=HOoaof7]iI]@2CNh0
44h?EPi1B3d8DL]gEWokOoeoogolKcQR]V[fOgUo^W^H0W]i00EgNGMhNgQgMg=G00AgE`0PMeIgMgMG
LeIc=WMENgIkEFZ]ITUR:Ei:IZ]V[6J;IZi^lG<cLeEgUgMeKc=RKSe878<@@A1S6>HQ1B467>@La0<L
a@047>DPiAcV7>H47<H27>H00b3V8>DPi@027<@27:@01RCV7<@HPa11344<8@8<@@09444@HQ113204
00P0000<@11Q00<DPP0O58<DPQB26:<HPA1Q200@82338<DDP`a1324<@A11564LXRCU68<@HQ11568H
PR2S;<<Ta22S568@@P`Q34400PPQ1`@Q0`PQ00<8@@PQ224010PQ00h<@@aQ460@HA1R488<H@`P8:4i
@dhZH/m[56Kd0fKD00EVm6[cJ_=Zlf/D00E_5005KaE_56lEKaE[5@02KcD00fldKcE_5004Ka@01FlC
KaA_5FlEKa@00flC3FlD00=_=6lEKa@00VlC00=_56lCKa<00flC00=_56lCKa<01flC0flD00=_4flD
Ka@016lC0V/D16lD00A[56lDKcA_=0=_4`A[4`06Ja9[4f/CJa=_4V/B1F/C00A_4flBKa9_4PA[4`05
J_=ZlV[cKaA[5002Ja<01FlDJa=Zlf[cJ_801F[c00IZlV[cJ_9Vlf[bI_83J_8016[aJ_9ZlV[a16[b
00QVlV[bI_5VdFKbJ_9ZdFKb0VKc00EVlVKaI]9VdVKb00AVdP03I]5ZdFKA00AVd@AVdP9Rd@03H]9V
dFKA00YRd@03H[5RdF;@00=Rd@9R/@07H[1R/F:`H[1Rcf:aH[000V:a1f:`00AR[f:`H[1R/0ER[`03
G[1N[ej_00=N[P08GXmNSV:=HXeNSUj=GXmNSPANS`05FXmJSUZ>GXiJSP02GXh015i]FViJKUY^0Ui]
0eY]0ei]1EY]0eY^15Y]0eY/00UJKEY/FVeJKEY/FTaFC5Y/ET`00UY<0eI;00AFC5I;FTeJC0EFC@9F
C0=FB`=F:`03ERYFBeI;00=BB`=B:`EB;0=B:`03DT]B:dh[00A>;008CPa>;4h;CP]>:dh/CR]>;09>
:`05CPa>2dh;CPYB2@01DP`00003224<8@PQ00888@06220400@P22088@a00P`P00X88@@0100800`P
;>=9jEiZGXaJCP9JK`=JL006GW1NKV:<GViNL5Y`15i`00=NSej@GXl015j@35jA00MRT6:`HViRSV:=
HTUMa`03FLL4FNL2GNL00egXGNMMj002GPP3HPL2HPP00eh8HPMR1`03HPH06EgWFLMEZ5FXFJQMifHX
IRMR1f8WHRUMb568CHQ9QU6UCJLmA2B09:<iZdX>DReFD5ZB009NT@0=G]=NlfL@@L//i10P540LPRC2
:>@LXPP010001`PQ0Pa10Pa200<<H@aR34800Pa200@<HQ1R348<8@8880<480888009120880PQ224<
@@aQ464<HQ1Q008@H004464<HPa23484368246833680511R488DP@a13248021QBJQgBgnfOmEkU7]b
I/]RJEWVFPIN9f9ZIXd2JZl00fkAMcAkE@02MgL2MgP017]hMgQgN7=G0W=H0WMh02QcF7<gLeQgNG^I
NiQcEeibAJ/iJEI=I_=_F7^iMgUoV6liFWEF;f/DKeMgVF/EH[==kTg>EU5F;U7]DLiJ;f/DMiUomW_J
LgYVeUidI[Ac=P9gM`03LeIc=VlE009_5@=_5003K_AZlflC009c=00<Ka=ZdV[bJ_9Zl6Z^HTYMjEGZ
FRYRJVJ]0V9[00iRSFK?J_5Zkg<_I/e:2c4556<@@ART8@HU9QcU0aRT00HLY1c47<DLa1c57<@47<D2
8<D00ac57<HLa@037<@37:@00aRS68<DHP035682588021AR448<00P0340@HAR25642464030a1340@
HQB17<4DH@P0420LXB2T568<@@8<800B444DHAbS8>DHXaAR444DHQb38:<X`bC48<<HHQAR344<@0Q1
0`PQ1@@Q00<88@@Q124020PQ00d<@11P460@HA22584@H2d1>F9>:V;>Ja=Zl`02I]@01V[cJ]=Zdf[B
J_=[4`9_5005Ka=_<fldKcE_=002KaD5KcD2KaD4Ka@01flCKaE_5FlDKa=_56lC00A_509_4`03KaA_
4flC00M_50Q_4`9_5003Ka=_4VlC00E_4`=_5003Kc=_56lD00=_5004Ka=_56lDKa@3Ka<00flDKa=_
4`05Ka<5Ja<01FlCKa9_4FlBKa<016/C00A_4flBK_9_4P9_4`I[4`YZl`=ZlP04J_5ZlV/BJ_<5J_84
J_4<J_82I_85I_45J]4016KaJ]5VdF[@16KA0VKB26KA0VK@0VKA00ERdF;BH]5R/F;A00ARd0AR/004
HZmR[V:_H]44H[42H[05HZl3H[06HZl01F:^GZiR[Uj^GZl00Uj?00INSV:=GXiRSEj>HXh3GXl025j>
FXmJSUZ>GXiJSUj>GVh3GVd3GVl01ei]FVeJK5Y/GVaNKEY]00AJK003FVeJKUY]009JKP9JK@UJK0=J
J`9JK0=JB`04FTaJK5Y=FTd2ET`015I=ET]FC5I;0eI<0UI;0UH[00=F:UI;ET/015I;0U9;158/00=B
:e8ZDR/00e8[00A>:dh/CRa>;0=>:`=B:`9>:`08CRa>:dh[CR]>2e8:CPYB2@5Aj`0000D8@@PQ2248
8@@Q00@88@06324<@0a1344<8@PQ0P@000H<@2C4AJQNJUj<FTh2FVl3FW000ei`GVmNSP03GY03GW00
15j@GXmNT5j?15j@15jA0Uj@1EjA00]NT6:@HY1R/6:>HX]RB5g5GLIEaeW600AIi`9Ma`9Mj0AN209R
1`9R209R:@06HRMR1f87GPIN1egW0UW700=Ib67XHNP00Ug6025IaegXGLQAYdV7BHIAYTf5@D@TP2BS
?HY>;U8]EU1JTV:bG[5RlV=FF]4mc22U568@@AR28:8a0bSS420400PQ22000`PQ00@<8@a1344<@@8<
@P03344<HPaR008<@P03368@HPa200888@0322048@@P00D4800422088@a1364246801A1Q340@H@aQ
22401@PP0`a1018<HQ1R46<<Ha1R488@HPP0100H83d1JZIgLWNDNiIcDV[=GTL2FPL025GXFPIN9ehW
IXa^lG<dLc<2Ka@01flELcIcEg<eKaE_56lE009c=P0QLcE_=VlEJ_AVdV/CJa9Vde8^@J/iJ4W;FViR
dVKdKeQcF6[eFW9JL6KALcIZm5iaERmJ;eYaH]=Zm6KdH[=V/VKb009[=@0DIaIN]5Y@EPmF;Ui]GXiJ
K5i^FVeJCUi^HXmNKUI<FTaJCEY;FTaJ:`9F:`9B;00<DReF;4W[AJU1J4G:DP]NBeH;BNY=je7[0Th<
0UH[00M>;3E568<<@Q1R58<DY0026<@46:@47:@00aRT7<@La0027:@02Ac58<DPaB357<DLa1c57<@L
a@027:@04AbS6:@HY1bT6:<HPaRS8<DLXaAR448<811Q588HXQAQ44400Q1R00D@@@a1584PhQ1Q0088
000I788TaAQS348800a1444DHARR7<@HY1B3468DHQb38:<TXbC48:8HHQ11344<@0Q122400PPP00<4
8@PP22400`PQ0P@Q0`PQ00<880PQ22400PPQ0188@0a0460@HA22464@H2SQ>F962Ej]I_9VdVKCI]AZ
m6KDJ]<2J_<00f[dKaA_5003Kc@8KcD3KaD4Ka@01W<DKaE_5FlDKa=_=0E_509_4`04KaA_4flDKa<6
Ka@6Ka<016lDKa=_56lD26lC0VlD00=_<g<bKa800VlD00=_4flDKa@00flD2flC1V/C00A_4VlAKa9_
4PA[4`07Ka=^lVlCKa9_4flBJ_<01V/C00=Zlf[bJ_801F[c1F[b00=[4V[bJ_801f[b0V[a1F[b00EZ
lF[bJ_9ZlVKb00=ZlP=Vl@07I_9VlFKaJ]5ZlF[AJ_800VKB0VKA00=Vd6KAI]4016KA00=VdVKAI]40
1VKA00AVd6;AI]5Rd@9RdP9Rd@=Rd006H]5R/F:`H[1R/F;A0V;@0V:`0f:a0V:`1F:_0f:`1V:_0f:^
0Uj`00=NT5j?GXh00Uj>00QRSEj>HXmRSf:>GXmNSUZ?0UZ>00=NSUZ>GXh015i]0ei_0Ui^15i]0UY]
0eY/0UY]00=NKUY^EVh00UY^0UY]1UY/00=JJeI/EV`00eI]00=JK5I<FT`00UY<00QJCEI<ETaFC5I=
ET]FC5I;1EI<00AF:e8[ET]BB`9FB`03DR]FBeI;009BB`AB;09B:`A>:`=>;005CR]>;4h/CRa>2`02
DR/2CR/014h/CR]>;4h<0Th;0Dh:0E890EH;00000`Q122488@0222400`Q1344<@@0234400`a0344<
@@033442220021R3@HMNBUj;FTiJKeY^FVl2FW000ei`FW1NK`03FVl2GXl015j@GXmNKej@0ej?0Uj@
0UjA15j@0ejA00UNT5jAGY1NT5jAGY1RSF:;IVD00Ug400=EaEW6FNL00eWW0UW700=MaegWGPP00eh8
00IR1f88HPQR25h8HRL3HPL085h6GNIQiEW6EJIAQUFVEJMEYU6VCHIAYU65CHI9ITV5CHA9I44S960L
H3f9CRiBCUI@FY5Vdf;@H_1F/T7]:<D256<02QA2660PXS43=B<DH0P0224880PQ0P`P10a100H<@Pa1
364<@@aQ348236801@aQ348<8PPQ22001@@P00H48@@P220880a0344236401A1Q340880`P22000`@0
0PP00`@000D880a0468@HPaR008@@@0F320<00`0;:19iVJXK`aVbfJ[IVQN25GXDNM=idW5CLIEaeW7
HTQVRFJ:HV/2FR/01EH;ER]NK5i^FTd00eH<1EH[00eF;5Y<CPe1bcUX?HU5bdh<GZmVlF;cI_=Vd`02
J_<02f/CJaAR/EH<BLeF;FKAKeEcEFldKa@00VlC00M[4fKaEVm9kSUY=DPmR@02?HP4?JT01479@LXm
R3V90Sf900hmR3UX=DLeAcEW>FPeIc57=DLeASDU>BDiISf70T6X00/mQcU6=BHeAcUX>HLiQSEV;><H
HP`Q00<@@P03468DPaRS00DHX`03688HXabT008La0037:@LaAc5008La0078<DLaAc57<DLY1RT68<0
11RS02hLXabT7<@Pa1c38<<HPQAR320DHAB26:8@H@a1568DHA11348DPAc1564800`P8:<TiQR43484
00`Q320DHAR17<@HXaB3588DHQb28:<X`bS48:8HHA11320<@@888@@880@88@05124880@P12088003
1203220334002`aQ460<@230>F55jEj/I]5VdVKCI_@00f[d0f[c00A_56/CKaA_=09_50=_=0A_509_
5@9_5003KaE_56lD00=_5@04KaA_4flDKa<2Ka@01FlEKaA_4flCKa@016lC16lD0VlC0VlD0flC0flD
0flC00=_56lCKa<016lC00M_56lCLc1_4F[cJa=_4P02Ka<00flDKa=_4`04Ka<00flBKa=_4`03Ka<6
Ja<01FlCKa9_4FlAJ_800V/C0V[c00AZlVkbKa=_4`9[4`04J_=[4f/CJ_<2Ja<2J_<4J_82J_<5J_80
16[aJa9ZlF[a1f[b26[a0V[b00=VlVKaI_401FKa00=VlVKaI_400VKa00=ZdFKAI]400fKA00=Vd6KA
I]401VKA0VK@0fKA0VK@0fKA00ARdF;BH]5R/@ERd@UR/0=R/@9R/0]R[`9R[P06GZmR[V:^HZiN[ej`
0Uj@00ENSej>GXiRSEj>009NS`04HXiNSUj>FXl2FXh2FXd00ei]GVaNK002GV`01Ui]GXiJSei_GViN
K@AJK@=JK0=NK003FVeJKUI^009JKP9JK@03FVaJJeY[009JK004FT]JK5Y/EV`2ET`3ETd3ET/5ET`4
ET/4ET`2ER/00eI;DT]F:P02ERX015H[ET]BBeH[0U8/0U8[0U8Z00A>:e8[DR]B:`E>:`9>;004CPY>
2dh;CP/5CR/2CP/1CRX1ERP1DP/0000424488@PQ2442248434403`aQ368<@@a1324<@@PP100DHSU5
FTUNReY?FVmJKP09FW03GVl2GXl4GY07GY400ej@GY5NT@03GY43GY0025j_HXiRRfI7GJAMi5W6FNH3
FNL01eWVFLMIaegWGPQN2Eh800=N2@05HPQN2Eh9GPUR2002HPL025h8GPMMiUg4FJI=QU66CHH2BHL0
2TV6CHEEY5g4DHE=ITf6CFE9@d4S0R1P00DmR4h]EVmFLEjb009Rc`0>FXdmk2SV420<8A1R548D8232
?FDmI1RR224<8@888@07320<@@a1344<@PaR46<00`aR00L<H@aR368<HPaQ348<@@02224010@Q1204
80@P0P@Q00@480PP220<@08<@@08368@HPa1320@@1bT8>DTi08T`P06:>8X`Qb2300400P00PPP0PP0
00/@@1bR;>8/h3TR?FA1adWYBNY9bDVX0091QP0=AJM1QT5U?D=1ADEV@FE5QTFXAJTmASTV>DL00SUX
0SUY00<iJ34V<BD00S4U0S5502heACEV>FHe9C4U=BHiAcf8@LY:;EI^G]5N/Ej`G[5VdF;@H[5JKdG=
@Ja5cEY`G]=NdF;AG[1NdEj`EXi:3D7;>FTa9RcU:<@X`bd4<BD]9Bd5;@@X`bC2:<8Xh`8Xi00C:<8X
hbSS9>@Thb339>@Pi2CT:>@T`bSS;@@a9CE5<B@]0Rd4;@D00Rd400l]0bT3;@DPa1A1300800`P220<
80a1568HPabS6:@00QRS0QbT00<La1c57<D00ac511c400@LY1c57<@La@PLa0058<DPa2C49<DHP`02
32003AAR588@HP`P344DHQ1Q344DPQbQ420<01RT008]1P0C6:D<@`a1244<@1AQ7:8LaARS58<DHQB2
78<T`bcU:<@T`aaQ56400Pa100<8@@PQ22000`PP0`PQ00<880@P120020@P0`Q000T<@@aQ340<@230
>D5:2Uj]I_8016Kd00=VmF[eJ_@00V[c16lD16ld0flD00A_5FlDKaE_5@9_50=_5@05KaA_5FlEKaE_
5002Ka<7Ka@4Ka<9Ka@2Ka<016lDKaE_5FlD0VlC00E_56lCKa=_4flD009_4`04KaA_4g<AKa82Ka@0
0flcKcA_4`05Ka<00flBKa=_4P04Ka<8Ja<00flCJa9[4`03Ja<016[cJ_9ZlV[b1f/C26[c00=[4V[c
J_800f[c00AZlV/BJa9[4@9Zl@MZlP03J_5ZlV[b00=ZlP03J_5ZlV[b009VlPMVl@=VlP9Vl@AVd@=V
d0MVd@=Vd0=Rd@9Vd@03I]1VdFKA00=RdPARd@03H]1R/F:`00QR/003H]5R/F:a009R/@YR/0=R[`04
G[1N[Uj^GZh2GZl2GY001Ej_GXmNSej=GXh00Uj?0ej>00EJSeZ>FXiNSUZ=00=NS@9NK005GXiJSUZ?
FXmNK`02GVd2FVd2FV`2FVd3GV`4FVd015I^FViJKUY]0UY<0eY/00EJKEI]EVeFKUI=009FCP05ETeF
C5I;ETaFC@04ET`4ET/2ET`01UI;ETaFBeH/ER]BB`=F:`05ET]F:e9<ER]B;002ER/01eHZDR]B:dh[
DR]BBe8[009>:`E>;003CR]>2dh;009>:`A>;09>2`5B:P5B:05B2`0010PQ00@<@@a23448@@H88@09
320<@@P0100@HSU4GVUNReY?00=JK`04FViJKeY_FVl2FW02GW04GVl015j?GY1NT5j@25jA00=NT5jA
GY400UjA0Uj@00QN[f:^HZiRSF:;HTIMa5W50UW70UWW00QIiUgUELMIaegWGPQN2Eh80Uh900AN2V88
GPUR:P9N2@07HPQR1eh8HPMQiFH3FJD00df60259IT4TAD=AQEgUIP=IYEF7BHM=QDUTADDTH2B2?FMB
;5I^FY9R/6l=HX]9j2S3304400`P56<HHQQ09<<eAC54564010PQ00<<80a0340010a100@<@Pa1344<
H@8<HP8@H@05364<@@PQ22448@04120010@Q120880PP0``P00T<@A11564DHQbS<BE5jTh[BR/00UI]
00A>:cUV:<<D@@@8000<100HH3f2DVQJQdWU>D<`hC44=BHe9C4T0cE50S4U00Ha13DT=B@a0c3S;><2
:>802BS2:<4XhbSS8:<T`bC29:8PXP038:401R2R9<4ThRT3;@@]0`8/h`04<@DeASV8?JT2@LX06CfZ
@JXmZTG:@L/iJ34W;@LeBCEZ=H/mZcfZ?JTiR3UX<DH]92dU;@@]1Bd6;@DXiBC400<Xi006:<<T`b2S
888T`bCS1BC300LP`ac38<@Pi2CT9>DXi@02:>@032CT9><Xi2SS9<@LY1R37:<La1c36:<@@@<80084
00092008811268<HXaRT68<HQ1RT00<La@<Pa@048<@L`b348<@77<@00b348>DLa0027<@022CU8<DL
aB359>HLY0`Q200256808Q1R344<80P0320DPARS564<811Q:@HiIcDW9>LDQ11R348<@A106:8LaAR3
688DHAAR78<PXbcT9<@T`aQQ564@@@a10PPQ10PP00@48@PQ224880/4800<2208@0a0340880`P7:0e
@DH9FZeVlV/E0VKd0V[d00IVmF[cJ_=ZlflCKa@3Kc@016lDKcA_=6ld0flD0Vld3flD00=_4flDKa@0
0VlD0flC2VlD0VlC00E_56lEKaE_5Fld00=_4`03Ka9_4flC011_4`03Ka9_4flB00A_4P9_4`E[4`05
Ka=[4VlBJa=_4`02Ja<2J_<2J_84Ja<4J_<5J_800f[cJa=[4P02J_84J_<2Ja800f/AJa1Zl003J_44
J_82J_43J_83J_400f[bJ_5Zl@03J_44I_4016KbI_5VlFKa0fKA00EVdVKbI]5R[fK@00aVd@9VdP04
I]5Vd6J`I[05H]49H]03H[000f;@H[5R/003H[43H[06H[401EjaH[1R/6:`G[001Uj_00AN/5j_GXmN
S`9NSP03GXmNSV:>009NSP05FXmNSUj>GXiJS@05GXd2GXh015Z>GXiNSUi]1eY]0ei/15Y/00=JKEY^
FVd015Y=0eY]0UI=15I>00MFCEI;ET]JBeY<ET]FC@02ET`00eY<ETaFB`06ET/2ET`015H/ER]F:eH[
0e8/00AF:e8[ER]F:`9F:PMB:`E>;09>:`04DR]>:dh[CR`2CR/3CP/1CPX1DPT1CN`000@88@043248
@PQ12443224030@Q2248@@Q1220800@046<mIUiZHZaJK`9JL003GW1JKeY_009JK`=NK`03GW1NKei_
009NK`03GW1NT5j@009NT0MNT@08GY1NTEjAG[5R/F:bGY5N/09R[`05HZeRS69XHPIMi`02FNL2FLH0
1EgWGNIIieWXGNP00eh800MN2Uh9GRYN:5h:HRYR:`03GPX01Uh9HPMQaFX2EHE9AP99IP09@BA10d42
CHEIaVH5EJEAQdV6009=Q@0HAD</XB1R=BIBC5I^ETiN[FkZER/e0Q0P100001A1568HPQb1788TiAbR
320000@Q0PPQ00<<80a1340010a100@<@Pa1348<@P8<HP06464@HQ1Q344<8@PQ1@@P00<48@@P2200
0PPP02@<8110464DHAQQ688Pa3V:EY1[<6mbKbm_<6/?Ia5NSdG/=@HTPQ@P000801a0ALESCflYJ^Y9
j3C2;<DTaBCU9@HY1BD49>@28>D00bCU9@DTi@059>@012337:<Pa2340QRS00@LXaRS6:<LX`8HX`03
7<<La1cU008La08LY0047:<HXaR37:<28<@03QbS7:@LXaR36:<LY22T8:<LPbBT9>@Ta2338:<28:80
1B218:8TXR2S8<@00R350b3U00dLa1c57<@PaAbT68<LXbCU:@@Y9BdV;@D]1002;BL01bTW9@LPiRT6
;DPY9bD6008U1@0;8>DLa1B3468@80`P200<811022040004200050@0200<@AB36:@LY1c57:DLaAc6
8<HPaBC59>DXiBC5:>@Ti2CU9<D28<D29<D012359<DTaB350RCU014PaB348<@TaBCU:@D]1RSU7:D@
@Q1R56<@HQ11324@@AB200<HP`0?7:@TaCEY?HXeB2S66:@@HPaR324@@AB27<DHPaR200<HP`068:<T
a2CU8:<HHA1Q0Pa12@PQ0P@Q00<480@Q22001@@P1PPP00P480PP6:0a@d8:FXeVlV/D0VKd0V[d00EZ
mF[dJ_AZm6lC00=_=003Kc=_4flD00i_509_4`04KcA_56lEKaD7Ka@2Ka<3Ka@00fldKaA_5007Ka@0
1F/DKaE[5F/EKa@00VlC00=_4VlCKa<036lC00=_56lCKa<01VlC0flB16lC0f/C00=_4f/BKa401V/C
00EZlV[aJ_9[4V/C00AZl`=ZlP]Zl`05J_9Zlf/BJa=[4P02J_400f[bJ_5ZlP0<J_801F[aJ]5ZlF[a
J]4016Ka00=VlVKaI_400fKa00=VlVKBI]803fKA0VKB00ARdFK@I[1V/09Rd@03H]9RdF;A009R/@ER
d004H[5R/6:`H[02H]001V:aH[1R/6:`H[5R/0MR/@9N/@=R/0=N/0=N[`03G[1N[ej_009NS`08GXiN
Sej?GXmNSUj?GXiJS`=NSP03FXmJSUj>00=NS@=NSP9NK@EJK@=NK@9JK@EJK003FVeJK5Y]009JC@05
FVeJKUY]FVeJC@02FTh01EY^ETiFCUI>ETd00UI<00=JBeY<ET/01EI=00QFC5I=ETaFC5I;ETaFBeI<
0UH[0UH/00=F:e8/DR`00e8/00IB:eH[ERYF:e8[DR`8DR/2CR`4CR/3CR`3CR/2CP/1CPX1CP`00007
120880PQ100480@Q12000PPQ00<880a022400PPQ0P`P00L800@0448eAEI[HZaNS`03GVl015i^FViJ
KUY^15i_00ANKUj>GXiNS`9NL09NT003GXmNT5jA009NT@04GY1NTEjAGY02GY403EjaGY5NTEjAGY1R
Sf:^IXeRS6J:HRMN25gW009IaP07GLEIaUW6FLMIj5gXGPP00Uh700IN25h9GRYN:5h:GRX2GPX04Eh;
GPYR267VHLAUhE64@BE1944S@B@m0d43BFEAYUW5DJD00Tf60Tf500i5@RRQ624a1Dh[DViJSUY]FVXe
0AQQ100000P00QAQ00DHPAQQ664DHPa1008400<88@@<@@03324<@@a100D<@P8<HP04464<H@a13202
220212021243120090PP320<811068<LXQR26:<LY2T6BPaR[g=?Ni=gU7NFLgE_EFKBGVm5[3T68444
00`0=@1JRfkVJZUB23D466<<0@`Q58<DX`8HX`0758<@HQ1Q464DPQBS6:<011bS00@HXaB358<DHP8D
PP8HX`<DPP0858<DPQB3588@@@`P2208008880H400800003100<@11Q008DHP03588DHQ11008@@@0<
568DPQB2688DPaAR468@HaB458<@PQB20QRS00PDHQ1R544HPR3U:@D]AcEX0SV90SV:00diJSE:=DTe
BCV9=FT]9bCU8>DLa1RS448<0002200310001@P0320800`032000PP000h881116:@LaAc47<DLY1c5
9<DTiRT6:>HY1Rd60bd500@]1RSU:>DXiP<TiP05;@D/iBC48<@LY0027<@012349<@Ta2cT0SE600P]
1bC768DDHaR468<DPaR30QbT018La234:>@a9SV:AL`eB2S568<@HA12224@@AAR6:<HPQAR66<268<0
1abT9<@TiB34668@@@a100888@04220480@P12022202224212401@PP124480@P22000P@P10PP00d4
80PP220400PP8>4eHdG[FXiW4f/DI]AVm004J_@02F[eJ_A_4fldLc=_<flbKa9_4`02Ka@2Ka<00flD
Ka=_5007Ka@2Ka<2Ka@2KaD00f/EKaA_5002Ka<7Ka@016ldKaA_56lD0VlC00=_56lCKa@00flD00I[
5F/DJaA[4flCKa8:Ka<4Ka8:Ka<6Ka802FlCJa=[4flCJa9_4F/BJa=_4P02Kc<01V/CI_5ZlF/BKa5[
4P=Zl`AZlPUZl`IZlPEZl@UZlP03J_5ZlV[a00IZd@AVl@0:I_9VlFKaI_5VdFKaI]5VdVKbI_4<I]40
1VK@I]5VdFKBH]5Vd09V/007H[5RdF;BH]5R/F:`H[401F;@00=R/F:`H[000f:`16:_00ER/6:aH[5R
/F:`009R/@05H[1R/F:aG[5R[`03GY001Ej?G[1N[ej_GZh00Uj>00=NSej>GXh015j>00ANSej>GXiJ
SP=NSP03FXmJSUj>00=NS@9NK@=JK@9NK@04FVeJJeY/FVd2FXd00eY]FVaJK007FV`9FTd3ETh2ETd0
1EI;ETaJBeY;ET/01EI=00AFC5I=ETaFC0AFB`9F:`9F;006ER]B;5H/DTaFBe9;0U8[00AF:UH[DR]B
;0MB:`03CR]>;4h[00A>:`=>;003CR]B:dh;009>2`5>:`5>3@000PPP1`PQ00<880`P22400P`P0Q10
00L<80@0224]1DhZFXeNS`03GVl2FVh2FVl01Ei_GW1NL5i_GVh00ej@00=NL5j@GY000Uj@3UjA00UN
T6:?HXmV[F:;HVYN:5WYFLL01EW600AIaeWXFNUIj09N209N2@0FGRYN:EhZGRYN:eh:GP]N2V89HNMQ
iFH2EJDm14E5DHM9R4EVBHIAYe77DLH2DJH04DfVCHI=QDV4::4@8Bd5CRYFT59_DThmIAb3200000@0
20000QAQ0QQQ00@DPA1R220480<88@@<@@T<@P@<HP07344<80PP220480@Q22000`@P0PPP00L<80P0
320@HQRR688HP`0258<05bS5>FQBCF;=Ke9gUG^iMkQgV7=gJaANCTV/<<DL02R0?HA>1TgX?FHTY0P0
00000`@000@880a134488088000<220DHABS5:8DXaB2468DPaR358<DPQB30QRT00TDPaB2468@HAB2
5:<DP`a222000`@000<800@010001`0000<400a058800QB300TDHA11444@@A12568DPaR356800a1R
00l@Ha2348<DPaRS6:@HXaB3568@81AR7>DY9CF9?LX00TG/00i5kTX>ALe5cDg<DPeFCdG/=FXY9b3V
7<@HPaA21A1100@@@0a0440@@@<DHP0656<HPabU8>DTiRCU0bSV0Rd71RdW00<a9S4W;BP012d7018]
:2d68<DLXaR37:@HXaR3568DPb35:>@/hc4V<DPa:2dX:>L29<D04B359<DTaBST:>D]1S4W>FQ1ZT6[
>DP/aAbT688<@@P032001AAR0QR300LLY2349>DPa1QQ444<8@02224010PP120480@Q10PQ1`@Q10PP
00@88@Q12448@0<880077<0aHd7[FZm[4f/EI_@00fKD00AZm6KdJ_AZm09_509_4`03Kc=_=6ld009_
509_4`Q_5004KcA_56lCKa<2Ka@3KaD?Ka@2Ka<:Ka@2Ka<3Ka@7Ka<2Ka82Ka<01flDKa=_56lCKaA_
4flD00U_4`=[4`03Ka9[4flB00=[4`04Ja9[4f/CJa<7Ja8016[cJ_9ZlV[b0f[c00YZlV[cJa=Zlf/D
J_=VdV[cKa=Zl`AZlP03J_5ZlV[b00]ZlP03J_5ZdF[a009Zl@9Zd@AVl@03I_9VlFKB009VdP9Vd@9V
dPMVd@03I]1VdFKA00IVd@03I]9RdVKA009Vd@9R/@=Rd@=R/@05H]5Rd6;@H]1R/@09H[04H[42H[00
1F:aH[1NTF:`G[400f:_0ej@0Uj_0Uj^00=NSUj?GXh015j>00]NSej>GXmNSUZ>GXmJSeZ>FXmJSUY^
009NSP9NK@03FVeJK5Y]009NK@04FViJKEY/FVd2FXh00eY^FVeJK@02FVd2FV`2FVd015Y/FVeJKEY]
1EY=00EJCUY=ETiFCEI>00AFC@06FTaJCEI=EViFCEI>0UI=00AFC5I=ETeFC@=FB`9FC005ER]F;5H/
DRaB;@06DR`2ER/00e8[DRaB:`02DR`014h/CPa>:dh[0dh/0dh[1Dh/0dh;0Dh[0Dh/0DX>00082240
3P@P220<@0a1340<80a0588@@000100Y1DX:EVh2FVd02ei]FVeNKEY^GViJKei^GVmNL5i_GXh01ej@
3EjA0V:A00]RT6:`HZmV[FJ:IVQN:5W8EJIIaEW6009Ia`07FNIIaeWXGNQN25h9GPP00Uh900IN:UhY
GRUN:EhZHR/2HP/01F8:HNQQiVHTFLL00U6X01MEb5WYELQAYeW7HNQIae6VDJA9QDf6CJI9Q2bR428]
14i:DXe:2c4V5684000000840003340DHAAQ008HH@06564@@0`P100880Q10Pa100<<@Pa134400Pa1
1`a20`aR00<@Pa1Q32001@PP0`@P0`PP01h800`P464HXARR68<DP`a2224@@RcU@LUJSF/_LgAkegoH
OmUkUgMEK_5R:dF8<><e945V@DHdi224100400000`@02008800222000``P240<@00246400aAQ588D
PP0258800aB368<HY0026:@01ABT58<DQ1B458<00QB200<@HPa220000P@00PPP00D400P0220880P0
00<4000<320DHQRS6:<DPaRS7:@HPaAR468@HaR30QbT00@HPaB368@HY0<La@0J8<DPiB3T7<@DHa12
46<PaC55>HQ1jdH=BRi>;e8>EPiJ;Ui`I]=Vlf:`@L/]:2D67:@HP`<DHP0668<HXaRS6:<HY1R30aR4
00DLY235:>H]1S57008a9`05;@LY1RT6;@La9`04<DP00cDX<BLa9`03<BL2<DL063E7:>DTa1A1688L
a2SV;@HHPPa1568LY22S9:8a0c4T>DHeAcDW;@LY1RSV:>D]1`<a9`09=BHmIcf9@JXiJ2cU7:@HPPa1
008<80<DHP8@@@08568HPabS9<@XiB33664@@@888@<88006224880PP224880PQ10@Q00<88@@Q2240
1`PP00`8@0Q1240801B0<D55jeZ^Ia=[56KdI_D2I]@01f[cJ_AZm6[dJaA[5FlD00I_4`I_5004Ka=_
56lDKc@2Ka@2Ka<2Ka@016lEKaI_5FlE0Vle0VlD00=_5FlDKa@02FlD36lC0flD00=_4flDKa<00flC
0flB0VlC00=_56lCKa<00flC2VlD0f/C00=[4V/CJa<00V/C1f/B00=_4VlAKa400f/B00=[4f[cJ_<0
0f[c00=ZlV[cJ_<00V[c00EZm6[cJ_=ZlV[c015ZlP9Zl@=Zd@=Zl@IVl@03I_9VdVKB009Vl@03I]5V
lFKA00]Vd@9Vd0=Vd@9Rd@04I[5VdFKAI]03H]4016;BH]5RdF:a0f;@00MR/F:`H[1R/6:aH[1R/@02
H[0016J`H[5R/F:a0f:`00=N/F:`H[000V:`00AR[f:^HZiNS`=NT004GXmN[Uj^GZh:GXh2GZl01UZ?
FXiJSUj>FXiNS`9NK`9NK@05FVeNKEj=GVeJKP02FVd00ei^FVmJK`0:FVh3FVd00eY<FVeJK@04FTd0
0eI=ETaFC@0:ETd=ET`2ER`5DR`00e8[DT]FB`02ER/4DR/00e8/DR]>:`02CR/00e8[CR]>:`02CR/4
CR`014h[DR]>:e8[0Th[0Dh>000822403@@P2248@@Q1224<80a1364@H0@0200XiDH:009FK`04FTiN
KEi^GVh2FVh3FVl00ei_GXmNKP07GY03GY400ejBGY5NT@07GY43HY02I[001fJ=IX]VJEhXGNQIaeWV
00EIi`05FNQMj5h8GPUN2002GPT01EhZGRUN:F8YHRX0168900=R267VGPH00UX900MN:V8YHRYQjF89
HNQMj002FLP03EFVCHI=QTf6AHD/`a12:>9::4X/<DDHP`@0008000031008011000<DH@08568DHA0P
420<80`Q344<@P88@P06348<@@a1468@@Pa11Pa200H@HPaR368<H@a122442202120522000``P464L
X@026:807QB3448<8@`Q224HPbdV@L]J[fmCMkMk]gnhNiMgMVlBIZeN:UGZDLQ5AST488<<0@001000
00@0200880D<@08@H@03564DPAB200@DPP036:<HY1RT00<HY0095:@HY1B2588DHQ1R34888@P000P8
8007320@HQAR68<HXabT7<@00ac50abU00@LaRT68>HLa@8Pa@068<HTaBCU9>HTiBST0RT501dY9R3V
7:D<@ac5:@DaJ3fYAPa5k4G<ALe9kE8_H_AcMg>IH]=1cBCW7<HDHa0P444HPabS7<@PaB3U00@Pa@05
9<DXiRSV:@H]9P05<BL2<@L2<BL2<DP2=DP013DX<BPa:3DX0S4X01<]9cEY<BHPaAA2540LXRCV;@LP
aAR37:@e9cUX;>@/`c3T;><e9@02>FP2>FT013E9<DPeBCUZ0SE900TiB3UX?FQ5Zcf:;>DLY1113200
0P`Q0QAR00hDHAAR544D@AQR7:<TXbST9<<LPQ1122088@@Q0P@P1`PP1P@Q10PP0`PQ00T880a11004
01B0=D562Uj^I_800VKd00AVeFKDI_AZl`AZm005JaE_5FlDKa=_5002Ka<2Ka@00fldKaA_4`03Ka<8
Ka@4KaD2KcD00flEKaA_500:Ka@2Kc@2Ka@:Ka<3Ka@00flCKaA_4`08Ka<00flDKa=_4`04Ka<00flD
KcA_5002Ka<3Ka@00flCJa=[4`06Ja<7Ja82Ka801flAJa9[4V/BJa=_4V[b00IZl`03J_AZlf[c009Z
l`04J_9Zlf[cJ_<@J_83J_43I_42I_800fKaI_9VlP02I_45I_82I_400fKAI]9Vd@09I]43I]02I]44
H]400fKAI]1Rd@06H]43H]000f:aH[1Rd@02H[4016;@H]5R/6:`0f:a00=N/F:`H[400Uja1V:`0Uj`
0ej@00=N[ej^GZh00ej^00=N[ej?GXl01Ej>0Uj?00EJSeZ>FXmJSUZ?009NK`9JKPANK@05FVeJKUY]
FVeNKP06FVh00eI^FViJKP02FVh4FVd2FV`00eY<FTeJC@03ETd3ET`7ETd3ET`00eI=ETaFC008ET`0
0eH[ERaF;005DR`5DR/01EH[DR]B:e8[DR`00U8[00A>:e8/DR]B:`=>:`E>;0=>:`5>;05>:`5>3P00
20PQ0PQ10PPQ0PPP00X88@PP460<80`Q:>E1bUJ?FVmJKP=NKP05FVmNKUY_FVmNK`03GVh00ei_GXmN
T005GY02GY400ejBGY5NT@02GY400ej@GY5NT@02GY400f:@HY5RT002HXl01fJ>IVaVJEhWGPMIaUW5
009IiP9IaP05FNMMaegXGPQN2@02GPP2GPT2GRT2HRT03V88HPMR1f87HPIR1eh7GPQIj5h9HRQN25gX
GLP2FLL03EFWBHM=R4f7BHM9ITEV=@@HHBcR@L<eQQbS00<00005220<80`P440@H@02564011R2564@
@0`P0Pa11@a21@a11@a200<@H@aQ46800PaQ00<<@@PQ22400`PP0P@P1@PP00H<811Q7:4LXQRR6882
58<06Q1222440@PQ46<]Ad7ZEXiW46lbMiEkUW]dLe=_<fJ^HTUEjTF8<<@D8@@00004000010023204
34001111564DPAB10QB211RS00<HY1bT7:@00Qc400PLaAc4588DPQ1Q348<@@PQ0`PP00@400PP2208
808<8004464DPQc48>D2:@H012T59>HTiBCV0bCU00@TiRT6:@LY1P<TiP8Y1P0K;BHY1RT5:@D]9S57
;BHPiQB446<LaBTU=HLmZD7:?H/iJcf<CNeN/FldIaABTS5:6:D<@P`Q008@@@0468<LXb3U8<@28<D2
9<D01b359<DXiBd5;@H]9Rd7008]9`8a9P0;;@H/iS4W<BLe:3E8<DLaB3E8<DTeB@02<DT2<BP06CE8
;><DHP`Q644P`RT6;@HLY1R37:<iJ4h^DRde9bRT<:4i0cE6>FPeJ3UY=FTeB3EY008eB@8iB@07>DPm
B4G:?HXXaAA230000P`P00<DHQR26:<00QbS00<HHQA166800R2S00TTa233664@@P@022048@PP1200
1PPP00H480@Q12448@PQ1242220212000`PP22488@02224020Q1100001AP<B162Ek>H]82I_@2I_D0
1fKcJ_9Vlf[cJ_AZmF/E009_50=_4`=_509_=003Kc=_4flC009_4`I_509_5@03JaE_5FlE00E_509_
4`U_509_=09_509_4`03Kc=_56lC00E_4`03KaA_4flC00U_4`03Ka9_4flC00E_4`03KaA_=6lD009_
4`9_509_4`9_4PI[4`M[4P05Ka5ZlF[aJa9[4@02Ja<2J_83J_<016[bJ_=Zlf[c1F[b0V[c36[b00=Z
lf[bJ_800V[B00=ZdFKaI_400V[a00AVdFKBJ]9Vl@9VlP9Vl@MVlP03I_5VdVKA009Vd@03I_9VdFKA
009Vd@03I]9VdFK@00AVd006H]5R/F;AI]5RdFK@0V;@0f;A00AR/F:`H]1Rd0=R/09R/@=R/003HZmR
/6:`009R/@03H[1R[f:`009N/0AR/09N/003GZmN/5j`009NT003GZmN[Uj^009N[P]NSP9JSP03FXmJ
KUZ?009NK`9NKP=JK@9NK004FVeNK5Y/FV`2FVd4FVh00eI^FVeJK@05FVd3FV`2FT/015Y/ETeFCEI<
0eI[00=FC5I=ETd00UI=00=FC5I=ET`00UI<00AFCEI<ETaF:`AFC0IF:`9F;09B;@03DRaB:e8[00=B
:`9F:P03DR]B;4h/00MB:`9>:`A>;006CR]B:e8ZDR]>:dh;0Dh=00000`Q1344<@@02244020Q22448
@@Q13448@@PQ220210003P`P460DHP`R9<@mbEJ@FXmJKUi^FVmNKeY_FVh6FVl00ej@GXmNT003GY00
0ejAGY1NT@02GY8<GY42HY001V:?HVeVRei9GPQIa`=IaP06FNMMiUgWGLMMj5h80Uh90Uh800aN2EhY
GRUN:F8YHPQR1f86HRMR1eh6GPL2FNP2FLP015WXGNQIb5FW0U6600a=QTV7CHM9IdEV@DHi12BS:<<e
9234200200002`@1220880a0440@@AAQ664DHQAQ56800Q1R10a20`a10`a200L<@@a2348@@Pa2368@
HP02368334422245120010@Q224880PP0PP000D@@1RQ7:8HXaR2008DP`8<H`0L24800000100@Pb45
=JY:;Uk?Ke=cE7MeLgA_<f[_IZiN;4g/=@DD@P@0000400P0100800PP344334000a10564DP@025882
6<@26:<00abT7<DLa0028@H01QcU6:<DHAAR444<@@888@@880888@888007320DHARS7>DPiRD6;@H0
0bT600LY1bSW9>HTiRSV;@LY1P02:>H3:@L012D6:@HY1RdV0S5701XaJ2TV7>HDQ111468HXbdU>HQ1
bDG/@La1[4G=BPm>DDXa;DXDQ@`R200DHQR47:@Pa2C41BC500HXaBSU:>DY1RdV;BL2<BL2<DP5<BL0
134X=DPeBCE80SE900<aBS59<DT00S590S4W00PXa0`0320HHBSS:@HPa1bT0Q1000PTi48;DVeFCce8
;60di3E70SE80cEY01leJSEY=DTiBCUY>DTmB46Y>H/XaP`0100<8AR38<DPiB347<<Pa2CU8<DLY22T
9<@XiB34668@@PPP22448@0212062203120010@Q22488@PP0P@P0`@Q0PPQ0PQ100L800@0560a84X9
G/eRlP04I_@016KcJ_9Zm6[d0f[e00I[5FlDKa=_4flDKc@2Ka@016ldKcEc=6ld0VlC00=_56/DKa@0
1FlD00=[56lDKa@01VlD00=_4flDKa@026lD0Vld00A_56ldKcA_=0A_50=_4`03KcA_56lD00E_4`A_
5003Ka=_4VlC00I_4`9_=0=_4`9_509_4`03Ka9_4f/C009[4`03Ka9[4V/B009[4P03J_9[4V/C009[
4`E[4P05Ja=ZlVkbJ_9[4`02J_<9J_83J_<6J_801VKaJ_9ZlV[bJ_=[4`9ZlP04J]9VdFKaI_85I_40
0f[BI_5VlP03I_47I_800fKBI]5Vd@02I]86I]4016KBI]5VdFKA0VK@1F;A00=Rd6;AH]400f;A0V:a
0V;@0f:`00AR/F:bH[5R/09R[`AR/09R[`AR/003H[5R/5ja00AN/09NT0IN[`=NSPANS`9NSP9JSP03
FXmJSUZ?009JS`08FXiNKEi]GVeNSUZ>GXeJK@9JK004FVeJKUY]FVh2FVl015Y^FVeJKEI^1EY]0UY>
0eY/00=JJeY<FT`00UI=00AFC5I[ETaFC0eFC@03ETaF;5I<009FC0IF:`04ETaF;58]DRd5DR`00e8[
ER]F:P02DR/0158/CR]B:e8[0U8/0U8[0Th[1Dh/00=B:e8;DP/00Th;0DX=00000`aQ344<@@043440
4PQ1344<@@a022088@PP324<@A1Q444<8B2S@JQJSej_FVeNK@9NKPAJKPAJK`03GY1NSej@00=NT09N
T@9NTP04GY5NT5j@GY09GY42H[401f:`IXiVSEi;FPQEYUgV00=MaP03GNIMiegW009Mj0AN2003GRQN
:EhY009R:@03HRMR1V86009R1P0:HNIMiUWXELM9IEW7FNQN25g8FLP3EJL02e67BHM9IdEW@BHe1BRR
8:<HPQ1110000P0000<400PP22000Q1000@@@AAQ684DH@<DHP0546<@@Pa2328<8@03344634824440
10a1444<@Pa20Pa100<8@@PQ22401@PP00<480PP22000PPP00H80110684HPQRR588258<010aS2484
8P@Q10000188@RD6>HQ:35j]J`mcLGMcLe9_46k`HVe>2c4554840000200232002@a0344<@0`P3008
01AP6:8HPP0258802QBR6:8HXac48>H]AbTW8@HHXaR20Q1100@<HPa122488@<8800>320<@@`P1008
00a0564DPQbT7<@Pa23U:@DY1P8]9`04:@LXiRSV:>H5:@H01BT7:>LU1RT7;BL00S4V00H]9BcU9>DL
Y1R34442344051bS<FI62UZ>GY1B;dG<=DT]22CX6:H<8P00324DPabU9>DTaBST:>D3:<D01RSU:<DX
aC45<BHaA`@eB08e:0<eB08a:003=DPeBCE9008eB@0H=DXeBCE9=DTe:C4W;>DPXa10564PXc43:@@T
i1bS560<@1109<5>:6K@CN`d`bbS1CE900<iJCEY=FT00SE80SU900liAd69>FX`ia0Q200DHQR39<@T
i2C38<<Ta2CT9<@00R2T00LTaBcV7:@HHQ113208800=120322021203124222802PQ2244880P0560a
@DX8GZ]VlV/D0fKc0V[b00=Zlf[dJ_D00V[e00=[5FlDKa<016lC0flD0Vld0flC00=_56lCKa@036lD
16lC1FlD0VlC00E_56ldKcA_=6lD009_=003KaA_4flD00=_5004Ka=_=6lDKa@2Ja<2Ka<00flcKaA_
5002Ka@AKa<5Ka8016/BKa9_4FlA0V/B26/C00=[4V[aJa800VlA00AZlV[cJ_=Zl`9[4P03Ka5ZlF[a
019ZlP03I_9VlF[a009Zl@EVl@04I]5ZlF[AI_42I_87I_45I]42I]89I]45I]08H]42H[400f:`H/mR
/003H[03H[400f:_IZmR[`05H[000f:_G[1R[`03HZl2H[03G[4015j`GZmN/5j_0Uj`0Uj@00=N[ej^
GXh00Uj>00=NSej@GXl015j>00=JSUj>GXh00Uj>00ANSEi]GVaNK09NS@03GXiNKEY]00=JKP04FVeJ
KeY`FVl2FVd00eY/FVeJK@04FVh2FTh015Y<FV]JBeY;0UY<0UY=00=FC5I;ET`02UI=2EI<0eH[0eI<
0eH/0U8/00=B:e8/DR`00U8/00UF:eHZDR]B:e8/DR]>:dh;DR`00U8[00=B:Th;DR/00dh[0U8[0U8:
00=B2dh;CPX00Dh=000234401123368<@@`Q0`a10PaQ00H<80`Q224<8@a1444220001QR2?HMJKej>
FViJK@9JKP=JK`03FViJKeY_009JK`=NT003FY5NTEj@009NT@9NTP03GY5NT5j@00=NT09NT@=N/@9N
T@9R/@08HY5VT6J>GVaN:5W7GLIMa`=MaP9Mi`9Mj004GPUN25h8GPP2HPP3HRT0368WHPMR1V87HPIQ
iEgUELQ9IDTREJIIj09N1`0>GNMR267WFLMAYdV7BFM5J457>DH/XaQQ42040080000C1248@@a0364@
@0`P344@HAR2668DHQB27:<@Ha12324<@P`Q34400PQ100<<@PQ236<010a200<@@A0Q44400Pa200@<
HPa12448@@888005100880PP22088@0222001@`P340<811168400QR200DDPa1S34888@@Q0084@P80
8@0I00400000000@@RC3=FQ>CUZ>H/eVkVl`K`iVkEj=AP`a1AA14008010P8>@aARUW6:<00Q0P00<<
01AP58800aB200XHXQRS7:@LiBU7:FLUB1RT568@@@8@HP08368<@@PQ22088@PP320@H@8@HP033248
80a100<DPP0768<LXac47<DTiRT6:BL00RCV00<XiRd7;@L00Rd60RdW00<Y1bCV9>H00bCU00<TaB35
8<@00QbS010HXaB3448<01B2;DE62VL?Jc5Nd47<<<@/a1B4348400888@046:@PiRT5:@H4:>D2;>D0
1RS5;>Da1SDW>DPiJ@8iB@07>DPiBCE9=DTaBCE9<BT00SE90cU90SE901TiBCU:=DTeBCDX;>DTa22T
8<@XiBST9>@Pa1bS688DH110200mZ5kAHVi5RRRU<BTeB008=DT03CU9>DPi9ceY=DT/aQ@R200D@QbS
9<@PXR2S00<P``<PY0068<@TiQR3568<@@`Q0PPP30@P0`PP0`@P0P@Q01<88@@R1488@P@0220DH352
APMNZf/CI_AVlfKdI_=Zlf[bJ_=Zm002I_D00f[fKaE_5@02Ka@00flcKcA_<`02Kc@00flDKcA_500B
Ka@7Ka<3Ka@00flcKcA_5004Kc@00fleKaA_5004Ka@016lCKcA_4flD0Vld26lD2FlC0flD1VlC00=_
4VlCKa<00VlC00=[4f/BJa<00V/C00=_4f/CJa<00f/C0V[c1F/B16[c00=[4flBJa<00V[b00AZlf/C
Ja=Zl`9ZlP9Zl@YZlPMVl@03I_9VlFKa00=Vl@9VlP9Vl@03I_9VlFKA00IVd@=VdPYVd@03I]1VdFKA
00=Rd@9Vd@ARd@9R/@03H]5R/6:`009R/0AR/@9V/003HZmR/F:`009R/@03G[1R/6:`009R[`03HZiR
/6:`009R/@03G[5N/5j`009N/003GZmN/5j@009NT003GZmN[Uj^009NSP04GXmJT5j@GXl4GXh3GXd2
GXh00ej=GVeNS@03GXd00ej>GVeJKP03FVh3FVl2FVd00eY/FVeJK@05FVh01EY>FVaJK5Y/FT/00UY<
0eY=00=FBeI<ETd02EI=00AFC5I=ETaFC@AFC0=F;003EReFCE9=009FC0=F;003ER]B:e9<00AB;09F
:`03DR]B;4h[009>:`04CRaB;58[DPX2CP/3DR/00e8ZDP]B2`02DP/2DPX1CP`00007340<80`P2248
80@P22400Pa100H<HPa0320<80PP32023442200021AQ?FAFCEi/FXiNSUY^GVh3FVl00eY^FVmJK`02
FVl3GY0015ZAGY5NT5j@15jA1Uj@0ejA00mN/F:aGY5R/6:aHY5RT6:>GVaN:EgXGNIMaeg6GLL00egW
0UgX0eh80V87168800aR9f86HRIN1f86HPEN1EG8@DE58U65FNP2GPL2GNL02UW6EJI=QTV6BFI5R4VY
@HLi11000PP000L400P0224<@11P464@@00220000a1R664HH@0268800b3368<@HP02320322400`PP
22488@0222400`Q1324<8@0232401a11348@@@a1364<HPa100888003100880PP00D8808<8008444H
HAR368<@H`a2268<H`8<P`041484HPA20245000050PP6:<]9Cf7CPYRRG<8J^YZkEI>ALXa1AaR200<
83EUDVU2:S55668230002@`P464@HA1Q564DPQRS7:@Q1P02:DL0223V6:@@@@`P444@HQB334422200
1@P0220@@1R268<011AR0QB200<DHQ1Q58800QR300LHY1c59@HTiQc58<DTaP02;@D2:>D2;@H01BC5
7<DLa1c468<00QAR014HHQR27:<LXabT444<811Q9@=1b6;=MheNd46Z;:8HPQ1R00888@06328HPb3U
;BHeARdV12d60RcU00H/iS3V=BLeB3UX>DP3>FT2>DT4=DT3>DT2>DP00cE8>DPiB@02>DT2>DP02C46
:<@TY2349@DP`aRS564DH00258402AR2320XaEj`Me1F3BcY;@PeB009=DT02cU8=BPe9c4X;:@D00@0
300LPB2R8<800QbR00/P`bC38<@PY2BT9<@XiR2T568<8@P0008880@48003220480@P00D480@880<4
800522088@PQ22488P0210001aR1<D91aUj[Ja9ZlfKd009Vl`09J_=ZlV[cJ_=Zm6[eJaE_56lE009_
5003Lc=_=6lc00Q_5003Ka=_<fld00A_5003Ka=_56lC009_4`03KaA_4flC00Q_4`9_5004Ka=_56lD
Ka@2Kc@5Ka@3Kc@2Ka@3Kc<4Ka<01FlDKc=_56lCJa<026lC0V/C0VlD1VlC00=_4VlCJa<01F/C0f/B
16/C0f[c0V/B0f[a3f[b0f[a0V[b00=ZlF[bJ_801f[b00=VlF[aI_400fKb2FKa26KA0fKB00EVdFK@
I]1Vd6KA00MVd004I]5R/F:`I]02I]42H]42I]42I[400fJ`IZmR/002H[04H[42H[0016:_H[1R/Eja
0V:a00=R/6:_HZl00V:^0V:_0V:`00IN/F:`G[1N[ej^HZh2GXl01Ej@G[1N/5j_GZh00Uj>00ANSeZ@
GY1NS`ANSPQNS@03GXaNK5i/009NK@04FVeJKUY^FVh2FVl00eY^FVeJK@03FV/00eY]FViJKP02FVh0
0eY]FTaJK003FV`01EY<FTeJCEY=ET/00UI<1eI=2eI<00=FCEI>ETh00UI>00=FCEI<ER`00eH[00AF
:U9;ER]B:`9B;09F:`9B:`03CP]>:e8[00=B2`0=DPY>2dh;CP]B:dh[DR]>2e8;CP]B2e8:DPT00Dh<
00001@a0320880PP32000Pa100@8@Pa1344<@@88800<344<HPaS368<@@`P540m@eX/GV]JK5j>0Ui^
0eY_00=JKUY_FVl00UY_0ej@00=JTEjAGY001EjA0ej@00=NTEj@GY400ejA00EN/EjAGY5R/5ja009N
T@0=HXiNK5hYFNQIieg7FLMMj5g8GNQMiegXGNL00eh80V870V8800AN2688HRMR9`9R9P0>HPIR1F8U
ELQ5ITDSEJEEj5WWGPMIj5WWELI=Q@99I@08AFE5QdF7@FPT``P01008008<800A344<HA1Q468<@0P0
220@HAAQ664HPQR19>@HXaAS200<800422400`PP22488@0222400`Q1248<8@03344244400a1R344<
8@0222002@@0220880PP224880PQ2204000220001aB36:@DPaBT5<DDiaT7008I208IBP056BXI20bU
14800@0400004`P0420/`DgWJ/E_2f;<H^iNSDG/<>@H8111<HMFS5:?>JPLPQ10008<000C320<@0a1
444DHAR26:@Q1RE88@HHY1AS324<@A11468<HPa110000PPP00H<8A11688HPabU6:D26:@01ARS58<@
HQ1R58<00Q1R00PDPaRT6:DLYARU68@LYB3511c50QbT01LLa1bT68<DPQ1R568@@AAQ68<LXac47:@D
@A11588aAEJ>I^eBKc4V664DHA11008<@@03348La2dV008aA`03;BL]1Rd6008a9`8a1`07;>La1cDW
=DTiJCeY?FX013UZ00<iBSU9>DT00SU900HmJCU9>DPeB3DX=DP4>DT05CU8<@LXa1bS8<@LaAB2340<
80a0560DPQB1440XaVKBOkINLBd::>PeB002=FP4=DT4=DX02cDY=DPa:C2U300000@0664T`bS3:<@0
12C400XXa2BT9<@TaBC4568<8@@02248808480848@0322088@PP00H4808880@4800522088@PQ2244
8@0210001QB1<D91ieZ;I_9Zl`9Vm0EZl`9Zm09[5@=_5003Lc=_=6lD011_5006JaA_56lDKcAc=G<c
26lC26lD0Vld2FlD00=_<flDKa<02flC0V/C1FlC0f/D0VlD1FlC0V/C0f/D1F/C00=[56/CJa<00V[c
16/B0f[a00=[4VkbK_8036[b00=ZlF[bJ_800V[b00=ZlF[bJ_802V[b0fKb0fKa1VKb00AVdVKAI]5V
dPAVd@=VdP05I]5Vd6K@I]1Vd@02I]06I]42I]801VKAH]5RdF;BH]5Vd@9V/@9R/@03I[1R/6:`00AR
/004H[5R/6:aH[02H[43G[43H[000f:_H[1R/002H[001V:@GY1NT5j_GZiN[`9NS`04HZiN/5j_GZl2
GZh2GXh015j?F[1JT5j@35j>00ENSEi/GVaNKEY]00=NK@06FVeJKUY^FViJKEY^0UY/00=NK5Y]FVh0
0eY^00=JKEY=FV`00eY/00EJC5Y=FTiJKEY[009FC0QFC@03ETaFBeI<00MFC005DTeBCU9?DTmBCP02
DRd00e8/ER]F:`02ER/00e8[ER]B:`04ER/3DR/01Th[DR]B:e8;CP]B2`9>2`05DR]>:dh[CR]>;002
CP`00dh;DPYB2@01DP`00004224<80`Q344246801PaR244<@@a12248808<@@8<HP08348@HQ10540m
@U8ZIZUNS0ENKP=JKP06GVmJKei_GXmNSUj?0Uj@0UjA00ANT5jAGY1NT0ANT@03GY1NTEjA00=NT@0>
H[5RT6:@HY1RTF:?HXeNBehXFNMIiUW6GLIMi`9Mb0=Mi`03GPMN25h8009R1`04HRMR2688HPP2HRL2
HRH03V86HPAV95G8AFI58eFUFLMMiUh6GPMMiUW5DJH2BHD01DUUAFE5A3CS52000P0000/800PP2208
80a0464@HQ1Q440@@A1Q00<HH@08784T`aRT46<800PP224880<88@<880<88@03320<8@a100@@@@05
344<80PP3208000522003@P010040000124DY1c57>HM:1eZ7H/Q[BW>008UcP8Z4006;NhQS1U:5>P8
I001100001<803D0GTE_1f[]I/YZj5I=?HP/Xaa3>FMJ[5:_@LXT`aR3568@8002200232001a11688H
Xb3U8BPHa1B3008<@P0<324@HQAR348<80@0200880a1568LXaR30QbU00PPiRCV7<DLY1RT68<DPQ1R
0QAR00X<@11S68@<@P`R56<HPaR458<@HP8@@P8DHP8HPP0J568@@A11568LXbS4<BD]9bSU58<88111
:@@mbDH8<FLPY110540@H@a0220@@R35<BDa9PDa9`@a1`04=BLiAcUY>FT4?FX3>FX3>DT013U8?FPi
J3U80SDX01XiB3U9>DTmJCU9?FPa1bBT66<LXaRT468800a0588DPA1P440HHSg>MiYof5H_:>X]23U8
0SUX0SUY00@eJCE9=DXeBP8eB`0:=DXiJS4Z96@@00@0300LHBcS;<<4:<@022C4:<@TY22U8<@P`aQR
32442202224010@Q22488@PQ1@@P1@PP0P@P0`PP00X88@@Q0004011P;B95j5Y[H]1Vl`9Vm0MZl`04
JaA_56lCKa<2Ka@00fldKaA_5007Ka@00flEKaA_5005Ka@00f/DKaA_5002Ka@3Ka<00flDKa=_4`09
Ka<3Ka@00fldKaE_5@05Ka@01FlCKcA_<fldKa@00flC00=_4VlCKa<016lC0flB1FlC00=[56lDJa@0
0VlD00=_4flDKa<016lC00=_56/CJa@00V/D00A[4f/DJaA[50=[4`E[4P=_4@04Ka9^lVkbK_8@J_82
J_46J_82J_42I_43I_82I_400f[aI_5VlP02I_800fKcI_9VlP04I]88I]43I]000fKAI]1Vd009I]44
H]44I[400f:aI[1Rd@07H[06H[400ejaH[1R/006H[001F:?GXmNSej_HZh00V:_00=RSV:^GZh00Uj^
0Uj>00IRSEj>GXiN/5j_GXl4GXh7GXl01Ej>GXeNK5i/GVd00ej=00=NKEY]FVd00eY]0UY^00QJK5Y[
FVeJKEY=FVeJKUY]0UY=0UY]00EJK5Y<FTeJCUY=00=JB`EFC0=FC@04ET]FBUI;ET/6ET`01E9=DTiB
CeI?DRh00U8]0UH/0eH[0e8[00AF:UH[ERYF:PAB:`06DRYB:e8[CR]B2dh;0U8[14h[0Th/0U8:0E89
0E8<000010PQ324@HQ1S0Q1R00@<HPa1344<@P@<@@0:368<@@@Q344<81QP>B=>2VJYHX/2GVh3FVh0
1EY_FViNKei_FVl00Ui_00=NSUj?GY000UjA00INT5j?GY1NT6:AGY42GY801EjAGY1NTEjAG[400UjA
0V:a00URSf:@HY5VSfJ^HT]N:EWWFNH00Ug600MMaeW7GLQMb5gXGNMN1`02GPP01V88GPQR:F8ZGPUR
:P9R:@9R9`0EHPMR1FI5ENU5IdE3DHAEaUgVGPMMif86HPMIie6WCHI9QDET@B<TP@P0008000032008
80a0008@H@046:<TiQbT6682568041QR564H@Ab1:@@PiQ1T324<@@PQ340880PQ220<80PP0PPQ0PPP
00<<80`Q344011110Pa000<880`P20000PPP00<<80a132000PP000P4000026<HiR4X9HXM[2G>0RG_
0RX@00<^<C9B<U<00S9B00D^<RGa6F`@a`0300<0000C100PH58VJ`QZjf[9HZUNSE8^?HXPQ3e6EV]B
ScfZ=DL]1B357:<00P`0014800`P448DPQRS6<@LiQBT58<@@Pa2344@HaB3468<800000840005344D
HQbS7:@LY@028<D02BCV;BL]9bCU9<DPaAc56:@DHP0244400aAS448<@@02444446806112568HPaR3
568DHAbS9<@TaBSU<BHeB3V/<FXLaP`R420Pa2U59B@LiART320@@@8@H@04220DHbSU=BD5<BL00c47
<BLe9`02=@L013DW>DPiBCUZ0Sf:0ceZ0SUZ00LiJCeY?FTmJCeX?FTmJ002>DP00cU9>FTiJP02?FT0
53f:<DTTaAQR68<HY1AQ200<@0a1440800a0:@AW57ooNk]B3bSY;BT3>FP01cUY=FTeJCE9=DXaBS5;
008eB`0:=F/eBRRU=<A5R4W[?FH/XbBS9:@5:<@01bC48:DTa1bR664<8@PP00P88@<48008220480@P
22048@PP120880<480<8800912400000460]8TGXFX]VdFKc009Vm004J_AVlfKcI_<2J_<00f/CJaA_
5002Ka@2KaD00fleKcA_=003Kc@4Ka@016lEKaA_=6ld0VlD00E_5FlDJaA[56ld00=_5003Ka=_56lD
009_50A_4`07KaA_4flCKaA_4flDKa<00VlD0VlE16lD00A_=6lcKcA_<`9_509_4`03KaA_4flC00A_
4`E_4P=_4`04Ja=[56/CJa@2Ka@00flCKaA_5005Ka<01V/CJaA[56/DJa=[50I[4`A[4P03J_5_4Vkb
009^l@9^lP9ZlP03J_=[4f/C01=ZlP9Zl@03I_5VlVKb009VlP=Vl@9VlP=Vl`9VlPAVdPeVd@03I]1V
dFKA00AVd@03I]1VdFKA009Vd@9Rd@04H[5V/FJaI[42H[401V;AH]1Rd6;@H[1R[`9R/003H[5R/6:a
00IR/@03H[1R/F:`009R/@06H[1RSej?HZmN/6:^0V:?00=RSV:^GZh015j^0ej>0ej?15j>1ej?00=N
SUi/GVd01Ei]00=JSEY/FVd00eY]0eY^00MJK5Y]FVeJC5Y]FViJK@02FTd5FVd00eY>FTeJB`04FT`3
ET`3ETd015I;FTYFBeI;15I<00UFCEI<ETeBCE9>DRiB;E8/DRd00U9<00AF;5H[DR]B;09B:`04ER]B
:eH[ERX5DR/2CR/01Dh/CP]>2dh;DR/00dh[0dh/00=>2dh:DPX00E8<00000`PQ220<800222401@Q1
344<@@a136400Pa10PQ100`<@0a1220880P0420e0Th9IZQNJ5i]GVh3FVh00eY_GVmNS`04GVh01ej>
GVmNL5ZAGW5NT6:>009NK`9NT0=NT@04GY1NTEj@GY02GY4016:aHXmR[f:?0VJ@00EV[V9/HRQN1egV
009IaP06FLMMaeW7FLQMj5gW0Uh70eh800=R25h:HRX00f8Z0V8Y00YR9f85ITAIj4f7BDAAY576ELEE
aP9Ia@03FLAIaU660099Q@04AF@m0BRR300200002A1Q7:<La1c3588LXb347:8DH@0356802QA1664P
XS4U:DTDQ@a2444<80a01@PP0PPQ0PPP0P`P0Q1000/@@A1Q444<@@`P200880P0320<@111008@HP0:
44840@@136<Dib6::J`UcB7>9Lh28Ll01RG`:Q0^<CIB>W@n]08nU006=W@b<R6?4<P48`@10P@002DD
H4G2I^U_26JXHZ]JK58<AL`iBSE6BNU>CT7/>HPeJ3E69<<D@0P030080111564HPQc46<DDPaAR444<
@A1258@HXa1R3244000220002111588LXabT7:DPY2ST;@H2;BH03C4W;BHY1B357<DLYAc47:@DHQ1R
68<HQ1R300<DP`0C568DHaR37<DTaBS5;>@`iC45=BLeB3UY?HXi[3F;8>L@@``P6:400R3T00XHY11R
340<@11Q440801AS:>DeAP8eA`03=BPe9cDW008e9`0;<@La1S3V=@Hi9cU9?FTmRT69@FXmJ`02?FX0
1CUY>DTiB3U7>DP00SeY00@mJ3e8>DTiB@8mJ@09?HXmJT6Z>H/a1R2S78<LY1AQ00<8000;1008011R
CTeongooOma=cRcY<DXiJ@02>FP013UY>FPeJCE90SE:0c5;01HiJcTY?FYVRgn@OiE^cdF998@PHR23
9<@X`bS4:>@Xa2S59<DLXaAQ320800888@0322088@Q000888@L4800522048@PP12088003120010PP
120880@Q0P0000TDP351ANQJRfKaI_=Ve6KdJ_@00fKc0V[b00=[4V/CKa@00VlD0VlE1Fle00=_=6lD
Ka@00flD0fld00=_5FlDKaD036lD2flC1flD0flC0Vlc0VlD0VlC00=_56lCKa<00VlC00=_4V/BKa80
16lB00M[4VlBJa=_4V/CKa9[4`03Ka<00f/CKa=_4`04Ka<4Ja<00flCJa=[4`04Ja<00f/BJ_9ZlP03
J_400f[bK_9_4P02K_43J_83J_<3J_82J_4016[bJ_5ZlF[a2V[b0V[a16Kb2VKa00=VdVKAI]800VKB
56KA0fK@00=VdFJ`H]400V;A0fJa00=VdFK@H]000f;@26:`0V:a00=N/EjAH[400f:`0V:@00IR/6:^
HZmR[ej`HZh3HXh00f:^GZiN[P0>GXh6GVl00ej>GVaNK@07FVd4FV`01UY]FViJKUY/FVeJC09JC@04
FVeJCEY=FTd2FVd4FTd00eY<FT]JC002FT`00eY;FTaJC002ET`2ETd015I;FTYFBUH[1EI<00=FBeH[
ER`00U8]1E8/0UH[00=B:e8/DR/00UHZ00=F:eHZDR/01E8[0dh[0dh;00=B:dh[CR/014h[0Th;0E8:
0E8<00001PQ022088@PQ22088@88@@8<@@D8@@0:224<80P0200<02cQBNUVR5iXGVd3FVh2FVl2GVl3
GVh2GXh025i_GW1JTEiaGY1NKf:@HXl2GY03GY43GY02GY4015jaHY1RSf:_0V:`00IVSfJ=HVeRB5gW
FLH3FLL01Eg7FLQMb5gXGNL01Uh80UhZ0f8Z0f8800YR1VI5GNQEZ565EJEAYUG6CJI9Q@99I099I@99
QP95I@0:=BDXY1@Q66<e9SfW=JPY11B25642688031AR58<HPaR3544DHB2S=DD]BAB5200<808<@@88
8@03244880PP00888@<88003320<@A11008@H@03468<HPa100<8000>320@H1B26:<DPaAS348<HaT8
9LdYkRX@:O0Uk`8Uc`0O9NlUl2X@;S4b<SIB>Y@j]SZe?[HnU39C8F`DYPPS000400a0=F5JRVl4J/IR
R5Y[ERa9k4G;@JU5bDH;@L/00Sf[010iZS44768D@AAR444801AQ588La1RT58<@@@a1320<@P8DP`06
468<80@0320<01AR0QbS0QbT00@TY2cS;@H]1@8]1P8]9`06;BP]1bd7:>HTiBC50R3500<LaB358<H0
0R3500/TaBSU:>D/iS46<@La9cE9>DPiBCeZ008mRP0:?J`aJbDY46<@01b17<<La1BT348334404P`P
200@HRSU=BDe9SE7=DTeB3DW<@Le:3E8=DTe:3D7>DPmJ@=1RP91JP04?F/mJSUZ>FT2>DT3?FT01SeX
>DTiBCU8?FTmJP8mRP0D?JXiRcE7:<@PXb347:@@@@`P300@@1B27<Ec^7onOom[>D6<;@PaBPDiJ@04
=FTeBC5:<DX2<D/03S5[=DTe1E7[OoUolgojOoQR2C35868LPR34:<<2:>@01bd5:>DPa1bS668<8@PP
00<88@<880<48@D4800322048@@Q00P48009124400@0580]0D76FX]ZlVKc009Ve0=Vl`03J_AZlf[c
009[4`04JaA_56lDKaD4KcD00g<eKcE_=@02KaD3KcD2Kc@4KaD2Ka@00flCKaA_5005Ka@4Ka<00flD
KcA_5003Ka@3Ka<7Ka@2Ka<3Kc<016ldKaA_56/C16lD16/C0flC1F/C0VlC1FlD1FlC00A_56/CJ_=Z
l`9_4`=[4`04Ja9[4f/CJ_<6J_8016[cJ_9ZlV[b1F[c1F[b0f[a3V[b0fKb26Ka0VKA00=VlFKbI]80
16KA00=VdVKAI]400fKA0VKB26KA00=Vd6KAH]400fKA00=VdV;AH[400V;A0VJa00=V/6:aH[000f;@
2F:`0f:a0Uja0V:`0f:@00MR/F:_G[5N/5j_GXmRS`02HXh00f:^GZiN[P03GXl2GXh015j?GXiNSej?
0ej>00MNSei_FVmNKej?GXiNS`02GVl015j>GVmNKEi]0UY]00=JK5Y]FVd01UY]1EY^0eY/0eY]0UY=
15Y<00AJBeI<FTaJC0EFC0=FC@UFB`9F:`04DTaF;58/DR/3DR`01U8[ER]B;58/DR]F:`=F:P03ER]B
:e8[00=B:`9>:`04CRa>:dh;CP/4CR/4CR`1CP/1DPX1DP`00003244880PQ00T88@0>32488@PQ224<
@0`P200<033RCNUVR5iYGXeNK@ENKP03GVmNKUi^009NKP03GXiNSej@00=NT003GVmRSf:?009NT0=N
T@INT00:HY1RSf:^HXmRT6J?IXiRK68XGNL2GLH2FLL00eg7GNMMi`02GNL5GPP05f88GPYR:Uh9HRYN
2F88GPQR1f86IREMj5FWCFAEQE6VDJM=Z4V6AHI9QTfWCHL00dV7015=b4F9;<DPPbc5BL]JSDi^ANXa
9RBT988LPQbT7<@LY1R3008@8008888mIBe85:D800PP224880888@0324488@PQ00H88004324<@A1Q
464246803a1Q320<80PP320@@1RR6:<DHQB36:@LiR5Z:Nhb4002:Nl29Nl01bG>:NhYkbh@;Q4bDS9C
008fU@07>[Hj]Cjd>W<f3QdY4:H00P0000h802C1BPM^hg;TIXM=jTG9AJQ5bDh<CRa1jcf[0cfZ00le
ARS3:>@]9QbT420D@AAR588DPaAR444<@0`P34400Q1R00H<@0`P300@811066828<@01AbS7:@Ta2SS
;@D00Rd600/a9Rd7;@H]1bd6;@La1bd7;>LXiRSU008XiP03;@La1bd7008]1`04<BLeB3UX>FT2>DT0
0ceY?FXmJP02?FX053f<<F/]BQRT420DH1bS6:@DQ11S348<H@a1320401AR;>DiISU6>FL2>DP013DX
>BPiBCU80SU90Se900<mJD6:@HX00d6:0T6;00@mRcf:?FTmJ0@mJ@0K>DTi:CTX?FPmRT6:?HXmRcf:
>HPa9RcU:<@Pa1bT58<DPQc39@@aJVmDOoQ_Edgb<@Ta1cU[008iJP8mRP03>FTeBCEY00<eBP05<D/a
JcU:=<9RI`02OoH02WoeOn]ZJCTX988TPbC4:<<XhbcS0Rd500@Ta233688@@@@88003120880PP00P4
800322048@PQ00T480840009560a0474GXYZlF/CI_=Vdf[c009Vl`9Zm003J_=[4f/C009_4`06KaA_
=FleKaE_=6le0VlE1Fle00A_=6lcKaA_50=_5@A_509_=0I_50e_4`=_50A_4`=_<`05KcA[4flCKa=[
4`04Ka@00flCJa=[4`05Ja<00flBKa=_4`02Ka<01F/CKaA_56lDJa<01flC0V[c16lC0V/B0V/C0V[c
00=[4f[cJ_801V[c0V/C0V[c1f[b00=ZlF[bJ_802f[b0V[a0VKa00=VlVKaI_402fKa1fKA00EVd6KA
I]5VdFKB00AVd@03I]1VdFKA009Vd003I]5RdFKA009VdP=Rd@05I]5RdFJ`I[1V[`0BH[001EjaH[1R
/6:?H[000V:@00IR/5j`HZmNSf:>HXl3HXh2HZh00ej_GY1NT006GXl015j>GXmNSej@0UY_00ANSej>
GXeNK@=NKP03FViNSUY]00=NK003GVeNKUY^009NKP9JK@03FVaJKEY^009JKP03FVeJK5Y/009JK004
FVeJCEY=FT`7FT/015Y<FTeFCEY=0UI<0UI=00=FC5I;ET/00UI;00=FBUI;ET/01UI;0UH[0U8[00=B
;5H[DR`00e8/00=B:eHZDR/01U8[00IB:U8[CR]>;4h;CR/2DR/4CR/2CR`00e8[CR]B:P01DP`00003
240880PQ00L88@04320<@@a1324234402Pa0440<80`P:<==jF:9HZaNSeY^0UY_00=NKUj>GXh00ej?
0ei_1Ej@00ANSej@GY1NT0ANT@ENT0=RT008HXmRT6:AHY1V/69]HRQMi`9IY@03GLEIaeg700AMi`=N
1`04HPMR2688GPT3GPX035h9GPQN2687HPIR9UgZDJU594eUDJIEaPEEb00EELMAYdV7BHM9R4W;=BHP
XbSUCPeV[F;_GXiJCT6[?DPiAcE7=DHTiAAS008<0005788mQ3697<H<8@02344010a23448@@Q10PPQ
1@PP01P88@`P344@@A1Q588DPa1Q344880P0320<@1AP588DHQB27>DYZbW<9LdYkbG^9Lh29Ll01bW_
:NhUkbW`;S4bDSJE008f]@08=YDbUCIe>Y@nLbg_6BT8H`80000H4651YFkULbUZb57Y=B@e146:@Na:
;DX^ANa1bcfZ?HTiRCEY<FPaRBSU664<811S0QB200@DHA11440<80@<@@05320<0110564LX`028<@0
21c48<@Ta2ST;@D]1RdV<BH2<BL01C4X<BLa9c47;@L00c4700`a9c59=FXeJSDY<BTeB3UX>FTiJ3UY
?FT3?FX06Ce[?H/mRcf/=F/aJR35420DH1R26:<DPa1S368<H@a1220801RS<DM1Z46Y?HTmJSeY008i
B@03?FTmJSe[008mJP04@FY1RT6:AHX2AJ/01DF:AJa1RT5Z?FX00SeY00<iJCeY?FX00SeY00DmBCeY
?FXmRSf;0091Z`04?J/mZSV9=DL2;@H04BcW:>HXiRD69BTaJdh_HXiB3S5:<BTiJSEZ?J/m[3V:?H/0
0SUZ00<iJCE9<DT00S5:010aJcU8?BANB7ocOnUongocKZhmBBRS:<<Ta2S3:><Xi08/i08Pa00358<@
@PPP00<88003124880PP00L480@48@T4800;100001AP=@15aEZ:J_5[4fKcJ]=Zm002I_@2J_@00f/D
Ja=_5003Ka@016leKaE_5Fld0fle0VlE16le0flD0flE16lD16ld1FlD26lC00=_56lCKa<00flC00E_
56lCKaA_4flD00=_<`04KcA_4flCKa<5Ka@00flCJa=[4`05Ja<2Ka<9Ja<00flDKa=_4`02Ka<00flB
J_=Zl`05Ka<00f/BJa=Zl`02J_<01F/DJ_=[4f/CJ_<00V[b0f[c0f/C66[b3VKa2fKA0fKB00AVdFKB
I]9VdP9Vd@03I]1VdF;A009Rd@=RdP9Rd@9V/@04I[1R/FJ`H]4AH[002ejaH[5R/6:_H[1R/F:@GY1N
/F:`GXl00V:?00=RSV:^HZh00V:^00=N[ej@GY001Uj?00=NSUj?GXl00ej@00YNSej>GXeNSUj=GXiN
KUi_FViNK@=NK0ENK@9JK@=NK0=JK@=JK0=JK@03FTeJC5Y;00IJB`06FTaFCEI=ETeJCEI<0UI=00=F
C5I;ET`00UI<25I;0U9;0U8/00=B:e9;DT/00U9<0e8/00=B:e8/DR/01U8[1Dh[0Th;14h[0U8[0Th[
0Dh:0E8<00000`Q022088@022242124010PQ12488@a010a10Pa000P<80PP220PXdF7GTYN[EY_0UY^
00EJKei^GViNKUY^009NSP=NKP03GVmNSej@009NT004GXiNSej?GY02GY42GY02GXl2HXl2GY003f:@
HXmRSV:@HY5RT6:?IXiRB5gWEJEEXeg3FLIIa`05GNL2GPL01687HRMR25h90eh:02iN2Eh8GPQR2686
HRMIjTUY@@A5AE77GNIN1f97GPQMieG6EJEEYTf6BFI9QdVX>B@TPBRSAJURReY/HZiR[eY=BNa5jdX<
ALX]9aAS424<022S?J@mk2e858<@HP8<HP8<@@0324488@PQ00@880888@0:344@@A1Q464HPAB2464<
@@`P2002320246002@Q0464U9RVZ;L`YkbW>:NlYcP049Lh29Ll0:Rh@=U8jU3je=Y@fUC:F=WDfDd:D
=S4Y[ACW008000@0=B9JIfl7K^QNJCeV:60PHSD6>FM5jdi=CTi:3D7;@La1bcg;=HTXha0P200@Ha22
468DH@8@@005320880PQ320<8@02200011AP664LXabS0QbT00HPa2C4:>@]1Bd6;BH8<BL01c4X<BLe
:3UY=FTeBCE:008eB@09=DPiJ3UX>FTmJSf:?H]1Rcf;008mJ`05@Ja1cCV;<FTTa@0242001AB26:<@
Pa1R34800Pa100L400P07:<iR4GZAL]1ZP05?FT02D5Z?H]1Rcf:@FY1RdF[@HY5ZP02BL/00dV[AJ]1
RP02@HX01SeY>FTmJD6Z@J]1RP8mJP03?HY1[4F[00=5c00AAL]5c46[=FXa:2cW:>L]:BTY9BX]BcE;
>F`eBSDY>FXiJ@02=FX2=DT01cEY=DTeBCEY=FXeJCEZ008aB@0=?FPi0eGYOoEoj7o_OmAV:CTX964/
`RS4:<<00RS400HTa2S38:<PXaR34483220412000`PP1204800412021247120422002@a0200@H340
BNAJJV/AJa=Zl`02J]<00fKCJ]=Zm002J_@00f/DKaA_5002Ka@6Kc@3KaD00fleKaE_5004Ka@2KaD0
0f/EKaA_500:Ka@7Ka<2Ka8016lDKc=_4flC1FlD00=_4flDKc<02VlC00A_56lCJa=_4`=[4`9_4`03
Ka9[4f/B009[4`9_4`9_50=[4`=_4`9ZlP=_4P=_4`9[4P03J_9[4f/C00A[4`05Ka=[4flAJ_5Zd@02
J_83Ja<4J_83J_4>J_82J_<00fKbJ_5Zd@04I_400f[AI]5Zd@02J]47I]400fKaI]5Vd@05I]44I]82
H]44I]03I]400f;AH]9RdP04H]4016J`H[5V/F;A2V:`0f:_16:`0V:a00ER/6:^H[1R/6:a00=NT003
GXmRSV:>00=RSP9R[P9NS`03GY1NSej?00=NS`9NSP9NS`05GViNSUj?GXiNK@02GXd00ei/GVeNKP02
GVl00ei]GVaNK003GV`3GV/3GV`2GV/7FV`015Y]FTeJCEY<1eY;0UY<0UI=0UI<0UI=00=FC5I;ET`0
0UI<1EI;1E9;0U8/00=B:e8/DT/01E8/00=B:e8/DR/00e8[00=B:U8[CR/01Dh[0Th;0dh[00I>;58[
CR]>34h;DPX1CP`00003240880PQ00888@848@032248@@a1008<@@0@468<@@a1240<810P220481bS
@HINBeZ<ETmJKUi^FVl3GVh3GVl3GVh2GXl3GY000ej?GY1NT004GY400ej@GXmNT002HXl3GY0016:@
HXmRT5jA0V:@00YRSF99GNMIaUVTGNAIiUW7GLMMi`9Mj004GNMN1eh7HPL2HPP2GPT0<Uh[GPYN2Eh8
GPUR2F88HTUJ2dEXA@=9IE78GPMRB5h8FPQIaUF5DHIAQDf5CHM9IdF7>@<L@2BTAJYJ:eY:I/m_=6K@
ETaB;UY^BPX]9QR4424<0AbS>HA2;BeY7<DDY12446<23443224322001P`Q344<@@a1444@HP8DPP8@
H@03344880P000<<80082204812S9FLYZRg]:NlUc`8YcP8Yc`0::NlUcQf=7H`QSBW?<S4jLcZe>Y<2
=W@01SHb=U8bDRW_6D/8I080000G6851a6/:K`UZk5WX=:4T8APP::8eIdH;CW1BKdi>BRiFCdH=>LX]
0a0P1008@@0248801Q1R444@@@`P3248808<8004440@HAB17<@47:@00b349<DXi002;@D2<BH2<BL2
<DP2<BL0134X=DPeJCE80SE913E:00LiBCUY>FXiJSV:?HXm[002?H/07cf<?He1cDG_@LdmZbC5420@
@1B158<@Pa1R220<@0PP100801c4>LY1bTG/@J/iJSe9@FU1JTV[@HXmJT6:0091R`03@J]5ZdF/00=5
Z`99c003@J/mRSf:00<mR@04?HY1RCf:?FX2?H/01SeZ?H]1cDG<@J/mRP91Z`04?H/eB34X;@P2:@P0
12T7;@La:34X0Rd700La:358;BP]9bT7;@L]:004:@L03bdW;@L]1RdW=BH/X3e4JZQkK7nCJXQ=ZC34
968XX`02:<@39<@01BBS8:<PXaAR34400PPP50@P0`PP0PQ000d<80P0440a04G4FVUZl6[bJ_=Zm6[e
J]=Ze003J_@016/DKaA_56lD1Fld16le00=_5FlDKa@01FlD00=_5F/EKa@00VlE0flD0Vld00=_=FlD
Ka@00flD00E_=6lDKaA_4flD00=_4`M_5005Ka=_56lDKcA_500:Ka<00f/CKa=[4`04Ja<01FlCKa9_
4f/CJa800f/C00]_4flDKcA_=6lDJa=_4f/CKa=_4V[b00=Zl`=[4`04J_=ZlV[cJa<2J_<4Ja<00f/D
Ka=ZlP03J_800f/CJ_=[4`02J_<4J_8016[aJ_9ZlV[b0V[a0V[b00EZlf[bI_5Vlf[b009Zl`05J_AV
lfKcJ_9Zd@04I_4016KAJ]5ZlV[A1fKA0VKa26KA0fKB0V;A00MVd6KAI]5VdFKBH]9Rd@03H]85H]40
1FJbH[5RdF:`HZl02V:`00=R[f:`H[000V:`0V:a00ER/6:_H[1R/6:a00=NT003GZmR[V:^00=R[P9N
SP03GXmNT5j@00=NS`04FXmNSej>GXh2GXl2GVh015i_GXiNKUj=0Ui/00ENKEi^GVmJKUi]00ENK003
FV]NJei/00ENK0MJK006FTaJCEY=FVeJJeI<1eY<0UI=0UI<0UI=15I<00IFCEI;ET]FBeH[ET/4DT/0
1U9<DRaB;58[CRaB;0=BC0AB;0IB:`03CR]>;4h[00Q>:`06CRa>:dh/CPa>2e890Dh<000222422202
224224400`a1244<@@053403320020PP68=1QV::GZeJL5i^GVd4GVh00eY^GVmNK`03GXh2GXl=GY03
HXl8HY001f9]HTUN1eW6FLEMi5W5009MaP04GNMMj5gXGNP3GPP3HPP00f8YHRYN2@02GPP045h9HPUR
268ZGR]EZ4DSDHIEj68WHTQN25WWGLEEQDf50U65019=QTUWBHQ18b10::A5c5Y<FV]RSVK?J_1JK5Z>
FTaBC3UX98@2300021A0=D@eZReX7>HDaA2U46<23443224010PP200880`Q0Pa100<@HA1146800Q1R
0Q1Q00<<@@`P20000PP00P@000L481CU;JTYbbg]9LhYc`02:Lh052W=:J`URae95>P@YQ3X5@TUS2h?
=U4jDS9B<S8b4BhA<S8^426^6>P2000060`P=F9RZg<XLbYVJ4F7:48@010Q788eITH<DViFSeZ_EVmB
TD8^>JTHP`@1344DP@8@HP05444<@@a13448800232006a1P688LXb3U9>DPaAbT8<@T`bC4:>@]1C4V
=DHeIcUX=DPa9cE8=FTeB358=DTiJSUY=DPeB@02>FX06ce[?H/mRcf:?H/iRcf;@J]5c46[?H/mS3f]
@Li5kTX>>HXXaA0P540DPAB258<@H@a0440<@002320031bT=HPmZCVZ>HXeJCE9?FY5ZdG<AJXmRP8m
R@03@HU1ZT6Z0091RP<mRP03>FPeB35700<a9`0:<DLeAcE7<DLa9bd7;@P]1c47<BL3<@H3;@D00bcU
:>DTa@039<D2:>@01RC38:<PXb2S8<@PY08PX`8PY00378<HQ1bS00<PY00@9:<TY222984`hSf6ALHm
QSTT=></Y2RS::@Ta2S4:<D29:@022RS9:<PXaQR344800PP100512022205120010PP120480@P1PPP
0PQ000T<80@0440a0D6SFTUZkF[aJ_<00V[d00IZe6[EI]AZm6[cJa<3Ka@9Kc@6Ka@00flEKaA_5004
Ka@2Ka<016lDKcA_=6le16lE0VlD00A_4flDKa=_50=_4`03KaA_4flC00=_5003Ka=_56ld009_=003
KaA_4flC00=_4P03Kc9_4VlB009_4P9_4`03Ja=_4flC009_4`E_4P9_4`E[4`=_4`E[4`03J_=[4f/C
009[4`=ZlP9Zl`A[4`03J_=ZlV[b00AZlP=Zl`9[4PIZl@03J_9ZlF[a00=Zl@EZlP9Zl`9Zm003I_=Z
lV[A009Vl003J_1ZlF[a009Zd@QVd@9Vl@aVd@9Vd0=Vd@EVdP9Rd@07H]9RdF;AI[5R/FJbH[400f:`
00=Rd6:`H[001V:`00=R[f:`H[000V:`0V:a00AR/6:^HZmR/09RT09R/003GXmR[V:^00ER[P04GXmN
T5j@GXl2HXl2GXl015j>GXeNSUj?0Uj>00=NKei^GVh00Uj=00=NS5j=GXh00Ui^00=NKEj<GV`02ei/
2EY/00AJKEY/FVaJC09JC@=JK@04FTaJBeY<FT`2ET`00eI=ETaFC007ET`015H[ET]FBeI<0e9<00EF
Be9<DT]BC5I;00ABC0=B;0QB:`Y>:`9>2`03DP]>2e8Y005>300000@8@@a1344<@PD<@@0@324<80`Q
340<80PP320<@@PP240881AR>FINJf:/GXh2GVd01EY^GViJKeY_GY000Uj?0Ui^00=NSUj?GXl03Uj@
00ERT6:?HY1RT6:?00ERT003HXeRBEh7009IaP9Mi@=MaP=Mj09N1`03HPMR9f8W009R:@=N2@=N209N
2@0[GR]IYddSBFIAb5WWHTUN25gWHNEMaUVVEJIEQDf6BFM=Z4E3:40XY46[GVeFBeY^GXiR[f:`FVmJ
BV9ZALX/aA@Q200<02dT;HTUBASW6>HDYA2434800PaR00H<@@PP220<@@a236824680111Q468@HPa2
0Q1100<@H@a122000`PP00l40000364MB37/;NdYcBW>:LlYcRg?9JdUJadX5<H00aBU00D@YACV7FXU
cRX?008^<@8^4@0O;Q0^3bW^6BT4@P00100XhDi9K`Ec26J8EN/`a1PP420D@BC3<DM1k4i`F]5NlE:a
D]=23B3V228<@A1Q468010a10148@@PP320<8110464DHQR37<@Pa1bT8<@XiBcV;@Da9SE600<eA`De
B008<DPeB3E9=DPiJCeZ>F/iJP8iB@@iJP0A=FTiRSf[?HXeJSU[>H`i[3g=>JX]:1bU420D@1AQ584@
PP0246402Q1P440@@10P68<PiBdU;BH]1Rd70RT700@]1bdX;BL]9P8Xi@DXi0<Ta0059>@Pa22S8:<P
Y0028<@39<<032C488@HPab388@LPaR3788HPaR2668DPPDHP`047:@PXb2T9<<39<@01bS49>DTa234
9<@TaBC4008Ta@8Xi@0H:>HXiBcU;>@Xhbd3;></hBS1::4TXRS49:@Ta2S5:<@XaBRU::@XXbBS8:<L
Pa110PPP00<480@Q12400P@P0PPP1P@P00@880@P2208808800<8808<@00;344@@@@0440]0T74GVUZ
kVlCI_=Vm003J_D3J_@3Ka@00flEKcA_=005Kc@6Ka@00fldKaA_5@03Ka@00fldKaA_4`03Ka<00fle
KaE_5@04KaD2Ka@01FlCKaA_4fldKc<00VlC00=_56lCKa<00VlC0VlD0Vld0VlC0VlD1VlC00=_4VlC
Ka800flC0VlB16lC0flB0VlC0f/C0VlC0VlB00=_4f/CJa<00f/C0f[c0V/C0f[c16/C00AZlV[cJa=[
4`=[4P03J_9Zlf[c009Zl`9[4P9ZlP03J_5ZlV[a00=ZlP=Zl@IZlP03J_=ZlV[c009Vl`03I_9VlFKa
009Zl@=ZlPAVl@UVd@03I]9VdFKA00MVd@9Vd0=Vd@9VdPAVd@04H]5RdV;AH]84H[4016:`H]1Rd6;@
0f:`00=R/F:`H[000V:`00=R[f:`H[001F:a0V:_0f:@0Uj@0ej?00=R[V:_HZh00V:^00=N[ej?GY00
0Uj@15j?0Uj>15j?00=NKej>GXd00Uj=00ENSUi^GViNKUj>009NS@9NK@9JK@ENK0eJK003FT]JC5Y=
009JK@03EViJKEY]00=JC004FTeFCEI=ETd7ET`0159<ET]FBeI;15I<0U9<00=BBe9<DT/0159<0e8/
258[00A>:dh/CRa>;0E>:`=>2`03DP]B:e8Z005>3@000Pa21`a100<800@0224010a100P<8@`P3204
00a1=DAFBej;0Ui/00=NKEY^GVh00eY_0Ui_0Ui^00=NSUj?GXl015j?15j@00ANTEj@GXmNS`9NT003
HY1RSej@00ERS`9RT00=HXiRBEh7FLMIaUg5FLEMaEW6GLIMaegXGNL00Uh70V8700=R9V8WHPP01Uh8
00]N2Eh:GRYIaTTS@BA9QUG7GPUIbEgW009QiP0OFJEAQE64CHI9QdfWAD8X@2RS@JYJC5H[FVmNT6:`
H]5NKeXXIXQ=jc365248010P;B@ebbU97@HLiQC54:D00Q1R00@<H@a1344<@@T<@P04448@@A1Q4404
32003`@0000DXR5X=Rd]kBW>9LlYcbW>;NhUSAdY6<HDQ0045:@0:1SV4>LIBBW=<U4b<2h?;O0]kc8>
;NdYRQ2T100801AP@H9^a6kUL^UVBTF8;84H@QQQ68<HY2T7>JY:;E9_E[1:L48=9@L@H`a1464@HPa2
10a100L8@0@0100000@0340DHP0268801QRS7:@Pa2359>H]1P8a9P05<BD]1BcU;>DXi003:>D2:@H0
0bd6:>D]1P02<@L00c3W<>H/iP04;>D3;@D08BcV;>DXiRCV8>HY1B35548<01A0564DPA21464@@11P
440<@0`P324LY23T6<@HY1B36:@DQ1B3468@@@a0440<@00220001P`P444@@A11568DP`@DPP8@HP03
58<LY2C4008Pa0<LY0038<@LY1bT00<PY0039:@Ta2S4008Xi@05:<DXiBSU<@Ha9`02<BH01345;@D]
1Bd60S4W014]9bd7;@L]234X<BTaB359<BPa9S4T<@@]0RcS:<@XXRRS008/i004;>DXaBS5:<@2:<D0
1RBT9:<PXb2S668<@@888003124480@Q00848005220480@P120880031202220212000`PP12080003
220030a0348400@0440]0T75FXY[3VlCI_=Vm09Zm005J_=Zm6[cJaA[4`02Ka<3Ka@5Kc@6Ka@00flC
KaA_5004Ka@4Ka<3Ka@5KaD2Ka@2Ka<00flBKa=_4P04Ka<2Ka87Ka<3Ka@5Ka<00flBJa9[4P02Ja<2
Ka800fkbKa9_4`05Ka82Ka<3Ja<2Ka<2Ka801FlCJa=[4f/CJ_800V[c0V/C00=[56/CJ_<02F[c00IZ
lV/BJa9_4F[aJ_82J_<3J_83J_400f[bJ_5ZlP05J_45J_82I_82J_802F[cJ_9ZlF[AJ]1VlFK`J]5Z
l@04I_48I]401FKaI]5VdFKAI]801fKA00AVd6KAI]5Vd@=VdPAVd@05I[1RdF;AH[9V/P02H[401F:`
H/mR/6:`H]000f:`0V:_0f:`0f:_0V:`0f:a00YR[f:?HXmRSf:_G[1NT5j?GXiNS`=R[PANSP03GXmN
T5j@00ANS`ENSP03GXmNKei]00=NS@04GViNKEi^GVh7GVd00ei/GV]NJ`02GV`7FV`00eY[FVaJK004
FT/2FT`01EY=FVeFKUY]ETd00UY<00=FBeY=ETd00eI=00=FBeI<ET`015I<0UI;0U9;0UI<0e9<0U9;
0U8/00=F:e8[ER/00e8/0e8[00AB;58[DR]>2`9>30=>;003CR]:2dh[00E>2`03DP]>2e89005>3000
00<<@@aR34400Pa100L<@Q1R348<@@`Q344<@P0246803@aR468<@@a1220000`Q<BE>:ej<GXeJKEi^
009JKP03FVmJL5Y`00AJK`03GVmNSej?009NS`ANT0ANT@ANT003HY1NT5j@009NT0=RS`9RT003HXiR
JUh7009Ia`EIaP05GLMMj5gXGPMR1`03HRL00f88GPQN2005GPP025h9GPYJ2UG7ADE194UVELL2FNT0
0eG8EJMAQP03CHD064V6CHMAb4ES<80XXSfZFTaFCEY`H[5VlV;BGXmN:6Z8FRde1aA2200@@Bd4<JXY
B@8M1P046>LDYA2346<3368246800a1Q444<@P053483468242002A10420<80@0000DXb5X;N`Yc@03
9Ll012W?;LlMK1S7111S02H@PaS57>HHaQCU9J`Z3cH`;NlYkbg_=Rhb3RFZ5>D48000320i85iULbIg
:FZWEPP``B1R420D@Q1S68@LaBCU9BHYARf::DPHY@a10Q1Q00D<H@a1344<@@Q1008<@@03220400P0
00880008320@@AB368<DHaA2568HPP8HX`8HY08HP`8DHP0958<HY1RT6:@La2C48:@LY1b3008LQ009
78<DHQA276<HHaQR688DPaR3008DHP0868<LY1c57<@LY1AQ300DH08DP@<@H@0;460@@110300@@QbT
7>@PiB356:@DHP0246801@a1300800`022000P`P00/@8110568HXac48>DY1BCU9<DTiBCV00<Ti@8Y
1@05:>D]1RSU:>D/i@02;>H02bd6;@D]1C4V<DLeAcE8=BPe:CE9=DX00SUY00LiB3U7=DLeAcE8=FTe
J002<DP04359<BP]:2d7;BPa:2dX:@HXiRC59<@X`bSS:<<TXRRS0RcU00PXiBcU;>D/iBcV:<DTYBBT
0R2S00<HH@a1224010@Q40@P10PP00/8@0Q1320000a0:B91iUI:I^iZlVKC009Vm008J_AZlf[cJ_A[
56[dKaA_4`A_509_=@03KcA_56lD00Q_5003Ka=_56lD00E_4`=_50A_5@04KaI_=VlEKa@9Ka<016lB
Ka=_4f/C1FlC0flD00A_4flDKaA_509_4`=[4`04Ka=^lVkbKa86Ka<2Ja<3Ja@00flDJa=_4`02Ka<3
Ja<3J_<00f/CJaA[5002Ja<2J_<00f[bJ_=Zl`04J_<01V/CJa9[4flCJ_5ZlP=Zl`AZlP03Ka=Zlf[b
00=ZlP03J_5ZlV[b00EZlP03I_9ZlV[b00=ZlP9Zl@05J]5VlFKaJ]9ZlP03I_83I]43I]800fKAI]9V
d@03I]43I]84I]43I]04I]42I]82I]400fJaI]5Vd@02H]401F:bH[5R/F:aH]403V:`00=R[f:`H[00
0f:a0f:`00=R[ej`G[0015j@00=N/5j_GXl015j?0Uj@00=NSej>GXl00Uj?00=NSUj?GXh00Uj>00=N
Sei_GXh00Uj>00=NKUi]GVd00Ui^00=JKUi]GVd015i]0ei/0eY]00=JK5Y]FVd00UY]00=JK5Y[FV`0
1EY;0eY<00AJK5I]FVaFC@9JC@04FTaFCEI=ET`3ETd6ET`4ET/00eI<DTaBC002DT`4DT/00eH[DRaB
;003DR`01U8[DRaB;58/DR]>:`=>30A>;09>:`A>2`9>305>2`5B:P5>300000<<H@a1344020a101<<
HQ1R468@HPaQ344<80P0100<8C4UCR]N[Ej^FVeNKEY]GVeJK`02FW0015j@FVmNKej?0Uj>0ej?1ej@
0UjA0Uj@0V:?0ej@00YRT6:?HXmRSf:@H[1V[f9[GRMMi`=Ia`04FLIIaeW6GLL2GNL2GPL0168WHPQR
26870f880V870eh80Uh900YIae66BFIAQUg7GPUR:E6XBFI=QP9=IP==QP0LDJM=QC2P:811R5Y<FViJ
L6:@I]5VlV:_GTYV[5i?>DTH@PP0300Thc69;FPQ1QcV6>LDaABT48<246801@aP584<H11P44001Pa2
00@@HA11444<00<80007100000@048<QJ2V[9Nh00RG?02XYcbW`:LlIBaBU36<<@P`Q58<DPQc39@HL
iQBT7DXQcBh>:NlUcbW=<Ndak2V86>D8@000100HH4FPJ^Mg9W;3HRE1@b10200400`1344<@Pa11242
10002@PP320<@0a1464<HA10320<@@02340010`P344@HA1Q0aAQ0a1100/<8@P0100800`P200400P0
320@HA1R008DP`036:@La234008Pa@<HY00G68@HY1bT78@HHaAS58<LY2348<DLaAbT9<DXiBST9<DT
iB3U788@81AP484DP@0346424600311Q440HXbDV<DLY9RT68>HPiB3V68@DHP<DH@0;464DHAAR568H
PQbT9>Ha9SE7=FLaB003<BP01358=FTeJ35812d600@a9cDV=DLeA`8e9P8a9P<a1P06;@H/iRcW<@Pa
1bcV0S460Rd500Da1C4V<BH]1RCV008La@037>HPiQc5008La@077:DLY1AR564LPBBR::000RAP00@T
HBR2;<@/i08/i@08:>D/aBS59:@Xa2BT668@@P888@03124480@P00l480P88008000<82dRANQFBVK]
I_1VdP9Vl`04J_=ZlV[cJ_<3J_@4Ka@2KaD;Ka@8Ka<4Ka@2KaD00f/EKaA[5@02KaD00flDKa=_4P03
Ka<3Ka84Ka<00flDKa=_4`0;Ka<01F/CKa=_4flCJ_800Vkb0VlC0VlD00E_4flDKa=[4flC00E_5003
Ka=[4f/C009[4`03J_=[4f/C00I[4`03J_=ZlV[b00MZl`IZlP9[4P=ZlP03J_=ZlV[b00MZlP03J_=Z
lV[b00AZlPMZl@9Vl@9ZlP07I_9ZlVKbJ]5VdFKaI_800VKB0VKb16KA0fKB16KA1FK@00=VcfK@I]40
0VKA00AVd6J`I]5Vd09Vd@=R/@04H]5R/F:`H[02HZl2H[0016:aH[1R/6:_16:`0f:_00=R/6:aH[00
0f:`00AR[ej_G[1R[`9R/0AN/0INT005GXmNSUj?GXmNSP03GXl00ej>GVeNK@02GVd01ej>GVmNKUi]
GVaNKUi]00=JKP03GXiNKEi/00ANK09JK@EJKP03FVeJK5YZ009JK003FT]JK5Y/00EJB`06ET]JBeI<
FTeFCEY/0eI<00=JCEI=ETd015I<00=FCEI<ER/00eI;0eI<0UI;00EF:e9;DT]BBe8[00UB;0=B:`03
DP]B:dh<00=>;003CR]>2dh;009>2`05CPY>2dh;CP]B:P01DP`00005360<@0a13448@@0222423240
0`a2468@HP02368010aQ344<80`Q0P@000<<82d4BR/00Uj^00MJKEi]FViNKUj?GW1JL@02FW02GVl0
0ej>GXmNS`02GXl5GY04GY42GY001F:?HY1NT5jAGY000f:@00MRSf:`HXmVcf9[GRQIb003FLL00eW6
FLMIa`03GNL2GPL015h8HPQR26880f8700mR2687GPQN25h9GPQN2EW8DJM9QU65FLER:F8XFLL00UFV
00AIYUF6CHI=QP9=Q@0MBFD/X2R1?FIJBeJ?EU5NTF:`I]9V/69]HXmN/T6[76880@P07<@aRBe88@HL
iaSW6>DDY12346<@HP0246400a22464@HP0434823440:A11344<8@P0320DH1R1588@@P`P5:<URBW;
:PlUkbW?:NlYl2W?6BXDYA2434<@@QAS58<La23558@DPadY8NlZ3bG`:Nl]cC7];L/]ZASV36400P00
00l402d0HZYg8g/TKZ9AabaP200400P0444@HPa122000P@000P800@0200<@11Q364@H0`P0Pa100D<
@111568HXb3400<Ti@087:@HPaR3448@@@P0320<8@8<8003444DHQB3008HY00H8>DU1bCV:>HY1Bd5
:@HTaR35:>H/iRSV:>LTib3W9@LY22dW:@LXibSV;@HeASDV0S4V00L]1abS664DHA21464@HP054640
0aAR6:@U1`04;BL00bD68<DHP`0256800a1R464@H@024442564021AR7:<Pa23V9@HQ1b3V8<H38>H0
1b478>HLaAbU8<DPiAc5008Pa@047<@LY1bT7<@27:@011b368<LPabT0QbU0abT00@LYAbT7:@HP`8L
Y08HY08DQ0<DP`0?48<DQ1B3444<80P0640PH33RAHI1A3dU;:@THRS4008/i@09:<DXa2S48:@XaBC4
668@@PPQ00848A8480H88008320000P0:@=1aeYZJ^iZl@=Vl`04J_=ZlV[cJ_<3J_@00flDKaE_5@02
KaD00fleKaA_5003Ka@00flEKcA_5@04Ka@2Ka<7Ka@016lEKaA_5FlD1FlE0VlD00A_4flcKc9_4`9_
4PE_4`=_50=_4`03KaA_4flD009_509_4`9[4`04Ka9_4flCKa<2K_802FlBKa=_56lDKa=_56lCJa=_
4`04Ka@3Ja@:Ja<2J_<3J_84J_<00f[dJ_=Zl`02J_83J_<4Ja<3J_<5J_801F[cJ_9ZlV[bJ_<01V[b
0f[a00AZdF[aJ_5Zl@9Vl@EVlP03J]5VdFKA009VlP=VdPAVd@=VdPUVd@EVd09V/003I]5Vd6KA009V
d@=Rd@03H[5R/6:`00aR/0=R[`AR/006G[5N/5j`GZmN/6:_0V:`0ej`00=N[ej@GY000ej`0Uj@00EN
Sej>GXmNKei^00=NS`09GVeNK5i/GVeNKUi_GViNKEj=009NSP03GVmJKUY^009JKP9NK@9JK@03FVaJ
KEY]00EJKP03FVeJK5Y/00=JK@9JK0=JB`=JC003FT]JK5I=009FC@9FC005FTeFC5I=ETiFC@02ET`2
ETd2ET`01eH[ET]FBeI<ER]FC5I;009F:`=BB`9B;09B;@IB;09B:`=B2`05DR]>34h/CRa>:`02CP/0
14h:CP]B2dh;0U8;0E8:0E7/00000`aP34088@05224010`Q344<@@a10PaQ014<@0P0200<80P0100<
02S3BNYJ[Uj^GVaNKEi_GViNKei`009JL@03FW1NKUi^00=NSPANS`9NK`03GY1NTEjA009NT@9NS`06
HXmNT5j@GY5NT6:?0V:@00iR/6J_IZeV[F9ZGPQIb5FWFLIEaeW6FNMIaeg70UgW0Uh70Uh80V870f86
00=R1eh8GPP00Uh802eN9f8XFLMAYdE4CD5M`eh8FNQN1UgUHPIIaUF5CHI=QDf4CFA5@bbQ960i95iZ
FZmFDEjAI]1VdFK@HVmRTEkCAL/PH`P1200LY2e7:DLQ1Qd77>HLiABT58<00Q1R00@<@@a2368<H@8<
@@8<8@03224880`Q00<@@@0W420LP2D3>F@aAB347<<LiBF9<Pd^<2G`9LlYkbhA9LlQS1CW5<H@Q0a2
468HY1c46:@<Ha1T7BXV42X@9NlYkbW>;Ld]Zc796>D@P`@000800003581BBGM4009k8`0:ITM5@QP0
300HHabS8>HLY1B3568232005A11340<@@a1364@H0`P224<80a0320DHR34:BH]Ac57:BHY1R3V7:DH
H`02448030`Q444@@111464DHQRS8>HTiRD6:@L]9`<aA`0<;@LTib358<HU1bD68>LPaQc69@LU:23V
0Qc500PPaBCU;@D]1BCU8<DLY1QR0QAQ00@@HA21488@HP@@H@03444DHQB300@HY08DP`03468@@@a0
00L<8003440@HAAQ008DPP<@HP03448@HQB2008DP`<DHP04564@@AAQ444332000a11464@H@025640
1111344<80`Q0Q1100<DHQR368800QAQ00D@@A10344<8@PQ00<<@@033688@@Q1008@HP88000C520m
AEi/NiEkL68Y@F/`Y2R2;>D]1BSU:<@TY2BS9<@PXaQR44400PPQ4P@P0PPP00<480@022000PPP00`<
@000200Y0d77FV]ZkF/AJ_=Vlf[bI_83J_82J_<2J_@016[eJ_I_5VlE1VlD00=_=6lDKa@00VlD00E_
4flDKaA_56lc00a_50=[5@05KaA_4flcKc=_<P03Ka85Ka<3Ka@3Ka<2Ja@00f[cKa=_5002Ka<2Ja<0
1f[bJa=_4flCKa9^lVlB00=_50E_4`9_509_4`=[5003Ja=ZlV[c00=[4`03J_=ZlV[c009Zl`AZlPEZ
l`AZlP03J_5ZlV[b00aZlP04J_=ZlV[bJ_44J_800fKaJ_5Zl@07J_44I_401VKbJ_9ZdV[AJ]1Vd@=V
l@AVd@03I]1VdFKA00EVd@MVd004I/mVd6KAI]06I[001FJaI]5RdV;BH]4016:`0V:_1F:`00=Rd6:`
HZl00f:_00=R/6:_H[000f:`00IN/5j_GZmR[V:_H[02GY000ej?HZiN[`03G[000ej@GZmNS`02GXh0
0ej?GY1NS`02GXl01UZ?GViNKUi/GVeNKP9NSP06GVeNSEj=GXeNSUi_0eY^00=JKEi]GV`00Ui/15Y/
00=JKUY]FTd00eY]00EJK5Y<FTaJJeY/00=JB`9JC09JK009FTaFCEI=ETeFC5I;ETaFBeY=009FC@=F
C005ETeFC5H[ERYFB`02ER/2ET`3ET/2DR/2DR`00e9<DReB;@06DR`0258[DP]>2e8;DPY>2dh<CR`2
CR/014h;CR]>:Th[14h;0E8;0E7/00000`aP32088@06224634403PP0320<80`P200<8BS3ANYJ[ej=
GVaNKEY^FVl2FW02FW4015Y`FVmJKeY_1Ej@00=NSUi_GW000Uj@0ejA00=NSej@GY000Uj@00ANTEj@
GY1RT09R/008IZmV[V:<IVYN:5VWEJEIa@AIa`04FNMMiegWGNL5GPP00f87HPQR1`02HPL2GPP02687
GRMN:5WWDLQ5A4D0GL<2FPP095h7GPIIieFVCFE=ITf6DH==QDE5<<<P@3TUGV]J/5IAG[9ZlVKBI]1R
TEYaE[95k2BT204801B3:BPYAb467>LHiQcU5:DDP`<<@@8<@P03344880`P00<88@8<8@8@@00>444H
H2d2ALE>9e9;@JT]11cU8FTb3BX?9O0Yl08Z400::NlUcQe:6BTM:Ad87>HLaQRU58@248@02b5[8NlU
kbG`9NlYkbW>:J/]ZASU36800P@0010000PP@JA^i7mUOfMfiEWV<60D@AR47<DU1b3V7:@DHP8@@@8@
HP0D368<H@aQ360<H@a1244<80P0320@HB359@LTiB3V7<DHY1B3468<@PD<8@04444@HAAR6:<36:@2
7<D0123W8>HLYART0aR400<DPaB458<01AB400DHQ1R368<LPaR2008DH@8DHP8@@08@H@<@HP05464<
H@aQ340@@@0256800a1Q444DHP02468010a2220880a10Pa000D880P0200800`P008@@@@<@@8@HP03
324880PP00<<8@03344<@0a0008<@08<8003220<@@a100D<@@06444@@Q1256<DPaB20aAQ0aAR1A1R
01X@Ha234:@DPaB2320802R0HRUonWooOo=o]fH_><<XPRC4;>DXiBS49<@TY2C47:<HHP`Q0PPQ4`@P
010880@P220880`P34088000220]0TG6FVYZkV[bJ_=VlPAZl`03J_9Zlf[c00=Zm09Zm@03KaA[5F/D
009[5003JaE_56lD00=_5007JaA_56lDKaA_5FlDKaD016/D0VlD00=_4flDKa@00VlD0flf00E_5FlD
Ka=_56lc009_4PA_4`9_50=[5@04KaA_4fldKcD4Ka@2Ka<2Ja<2J_<2Ka82K_8016lCJaA_56lC0Vkc
00A_4VlCKa=[4`9_4`05Ja=[56/DJaA[4`02J_83Ja<4J_<3J_800f[cJ_9Zl`04J_<LJ_800fKaJ_9Z
l@04J_800f[BJ]5Vl@02I_401FKbI_=Zlf[BJ]400fKA00=VlFKbI]401VKA00AVdVKAI]9VdP=Vd@MV
d09Vd@04H]5V/6J`I]02I]400fJaI]5RdP02H]800f:aH[1R/00;H[0016:_H[1R/6:a0f:`0Uj@00=N
/5j_G[000Uj`0Uj@0Uj?00AR[Uj`G[1N/09NT004GXmNSUj>GXl2GY02GXl01EZ>FXmNSeZ>GVh015j>
00INSej>GViNSEj>GVd3FVh2FVd00ei]FVeJK@02FVd3FVh025Y]FTeJKEI=FVeJKUY]FTd3FT`00eI<
FTaJC@02FTd00eY<FTeFC@03ETd015I<ETeFCEI<0UH/1EI<0UH[00=FC5H[ER/015H[00=B:e8/DR`0
358/00M>:dh;CP]>2dh[CRa>2`05CR/01Th/CPa:34h;CPa>2`5=k00000H<@0`P22088@PP22432200
10PQ324<8@`Q0PPQ0P`Q00`@@A10320@8BBS@LQFSej<GT]NKEY^FVl2FW02FW400ej@FVmJK`02FVl4
GY0015j?GY1NT5j@15jA1Uj@0V:`0V:@00URSfJ>IZiRS6J:GRQIaeVUGL@00UW600=MaUgVGNL00UgW
0Uh82F87031N268WHPMR9Uh6GPMAb44U@@1EY5h8FPQJ1eh7ELMAaTV6CHI=QDf3BFA9QcD5864i95H[
FViFDEjaI_1RdF:aH[9JLUZACRda1P`R100@@bTX;DPQ1acV6<DLiQBU48<222033442324222022240
8`PP320<8110540HH3D2BN=FAdWV>FDX`aBT7DL]bbG_:O4Z4BhA<S4fDC8`:LdMBB4Y9DPQ1QS648D<
QA2V5BTU[2G^:Ph00bW_00LYcRg<;JTHa@Q21008000200003BSPFT=kA7n8NdMZICdQ764@@AAS6:@H
Xa1R008@@@@<@@8<H@0;460<@0a0344880@0000400a1468@PP02468010aR348<@@PQ10PP00/<8@PP
220<@0a1468<@Pa1348@HQ1200@<@@07340<@@a1344<@0PP34400Pa200D800`Q448<@@`Q008<@@8<
@003320@@@a0008@H@D@HP8@H@03444<@@`P00L88084008800<88004324<@@a2348334400`a2344<
@@0234401A1234888@a144800a1100@<@@a0344@H@8<@006364@H@a1464@HQ1Q1Q1R0Q1Q2A1R00T@
HaB46:@DPQAP300`h6kVOn/00Woo00EonW/g><<XPRC4008Xi007;>@Xa2BT:<DTa1QQ32000PPP3P@P
0P@Q00<480PP22001PPP00L40000340XhTGVETYZk`02I_400fKbJ_=Vl`05J_<02V[dKaA_=V[fK_E_
56/DJa=[56/C16/D1VlD0f/E0f/D0V/C00A[56lCKaA_4`A_50=[5003Ja=_56lC00I_4`9_5007KaE[
5F/EJaA[4flBKa<00flD16lC00E[4f[cJ_=ZlVlB009^lP9_4`03Ja=_4VlB00=_4P9_4`M[4`EZl`9[
4`AZlP=Zl`EZlP9Zl`03Ja9ZlV[b009Zla1ZlPEZl`9ZlP04J_5ZlV[bI_82J_87I_400f[BJ]5Vd@0=
I]42I]83I]47I]03I]400fJ`I[5V/@03I[401VJ`H]5R/V;BH[5R/0=R[`]R/0=R/@07H[1RSf:?HXmR
[f:^GZl00V:`0Uj_0f:^00=NSejaG[000Uj?0ej>0ej?0Uj>00MNSEj>GXiNSUj=GXiNS`03GXh2GVh3
GXd015j>FVeJKEY]2EY^00=JKEY=FVd015Y]25Y=1EI=0eI<0UH/00=F:eI<ET`01EI<1eH[00MFBeH[
ET]BC5H/DR]F:`03DR`00e8]DRaB:`04DR`00e8[CR]>:`09CR/014h/CPa>2e8:0Th;0Dg/00000`Q0
2208800222400`a1340<@@0334400`Q122488@0232403A1168<@@0P0300PPSfXEXmNZei[GVeJKUY_
009JL09JL@aNT0ENT@=NT003GY5NT5j`009N/00AH[1RT6:?IXiV[VJ<IX]NBUWXFLIMa5W5FLIMaUgV
GNMMiP02GPL015h8HPMN25h81V87031N2Eh8HPQR9eh7GNMAbD5WBFAEaEWWFNQN9eh7FNQEaeFVDHI=
QDf4BD=5ICDU988a14WZETeFD5jAH]1RdUjbG[=JU5jaETda9``R00088B3W;FPQ9acV7<HHaQBU48@2
344010`Q344<@@a11@`Q01@@@0`P440@HAQP760P`CUR?H8iA2SS7:<@HaT5:JXYkbXA;Q4b<SHa0SYb
00/f437>9FXQ:1SV4:D<Y@bW6D`Q[bW_00@^408]k`04<Nh]ZQC51242100200002Q10AJ5c1Gn8Oheb
`dVV964400`Q0Q1R00@<@0P0220<808<@@06364@HA1Q460<@0a10PQ100<88@@Q12000P@000D880aR
368<HPPQ00<48@8880@88@03220400PP008<@P0524488@PP22088@02244222000``P340<@0023443
2242220010a0244<@@a10Pa000P<HA1Q464@HA1R488DPQ220Q1R0Q1Q00@@@@a1340<@08<@@8<8@05
344<8@PP220<800222000``P340<@@0434800`a1348<@@0336400a1R448@HP0234801112464<H@aQ
0PaR00@@HQ1Q440@H@<@HP03464@HQ1R00D@HP<@H@/@HP0746<DPQAP540`h7M=OnH00goo00AkF4TW
:8<Ta@8Xi00::<@Ta2C59>DXiAQQ300400P0100:1202220010@P12448@@P0`PP0P@P0PPP00`480@0
000882CRALIFBVK=I_5VlVKBJ]<2I_<00f[dJ_=Zl`02J_<01f/CJaEZmFkeK_A_56/C00=[509Zm09[
509_5003KaE[5F/E009[509Zm0E[509[4`9_4`=_50=[50=_4`05KaA_4f/CJ_9^lP02Ka<2Ka@3JaD0
16/CKa9_4flC1FlD00A_4f/CJa=Zl`9ZlP=_4P=[4`A_4`03Ja=[56/D00=[5004Ja=_4f/CJa<2J_<4
Ja<3J_85J_<00f[bJ_=Zl`04J_<3J_800f[cJ_9ZlP02J_800f[cJ_9ZlP03J_801VKbJ_9VlVKbI_=V
lP9Vl`IZl`05J_9VlVKbI_9Vl`02I_85I_400fKbI]9Vd@0=I]400fKBI]5Vd@04I]45I]02I]401F;A
I[1VdFJaH[400VJa00EV/6:aH[9RdV;A009R/003H]5R/6;@009Rd0QR/09R/@9R/09R[`9RS`09GXmN
/5j`G[1N[ej`GZmN/5j_00=N/003GZmNSej>009NSP=NS`9NSP03GXeNSUj>009NSPENS`9NSP=NS@04
GXiNKEi]FVd;FVh015Y]FViJKUY^0UY]1UY=25I=00=FC5H/ET`01eI<00=F;5H[ER/00UH[00=FC5H[
DT/00e9;0U8/0U8[158/00A>;58/DRa>;@9B;003DR]>:dh/009>;0Q>:`05CPa>2e8:DP]>2`01CN`0
0003340<80`P00<88@03340<@@a1008<@@08224<8@`Q324<@A1Q460@@0840008664iIU9_HZ]NJUi]
FViJK`=JL09NL09NK`03GXiNT5Y_00ENT008GXmNT5jAGY1NTEj@GXmNT@ANT09R/00=HXmRT6:?HXiV
[VJ=IX]RBUWXFLEM`eG5FLH01EgV0UgW0Uh80V8700=R1V87HPL00V870eh801aR25h7GNMIaeG7DJII
aEW7GNMN1f88GNQIaUG6DJE=QDf4BFA5ICTU:88`hTWZFViJCUj?H[1Vd`=N/`0@H[1JC3TW428800@0
8>HaIb4W7>LLiQS55:D@I11S36833483344232408@a1340@@110460DH1@P780ThcU3=BD/i2ST58<L
aBEY;Q0fDS9B=U8fDcIc>W<nU4:C>S4akbF]8HdMK26=9LlZ4@02=U83<S401CIB>U8b3bf:5:@00P00
00`40000000402c0IXQoR7n]NdQN23CR30031003220232001@a0440@HA1Q46000Pa00PQ000<8@@Q0
22000`@000<880Q122400PPQ10@P1@PP1@PQ0``Q1@a10``P0`a100D<8@a1344<@@a0008<@@05320<
@@a0440@H00246401AB25:<HXaB256800Q1Q00D<H@a1444@@@a000H<@@L<@003344<@Pa1008<@@03
340<HA1Q008@H006464@@A11448<@Q120Q111Pa100<@@11P36000a1Q0`a100<@@A1Q4640111Q00<<
@0a136400a1Q111R0P`Q00H@HAA0420/`7M:On`3Ool01WLhADTXQ2C5:<@Ta08Xa0089<DXiRCT664<
80@0200400X48003220480@P00P48088800?12040000100XhT74EVYVkF/BI_=VdfKcI]9ZlVKc009Z
l`05J_9ZlflBJ_=Zm002K_@00flDKa=_4`03Ja<2Ka@01F/DKaA_56lDJaD00flD00=Zlf[dJa@00V/D
00=[4f/DKa<00flC00]_56[dJ_=[56lDJa=_4flBKa=_56lC009[4`0;Ka=_4VkcK_=_4flDJaA_56lC
Ka9[4P02Ka<01FlDKa=Zlf[cKa8016[c0V[b00=Zlf[bJ_<00V/C16lC00=_4V[cJ_<01f/C00=Zlf[b
J_<00V[c00QZlV[aJ_9ZlF[bJ_=[4f[b0V[a00=[4V[bJ_804f[b00=VlfKbI_800VKb16[b00=ZdVKb
J]800V[b0fKb00AVlFKbI_5Vd@=Vl@9VdPiVd@9VdP03I]5VdVKA00EVd003I[1Vd6K@00=Vd005I]5V
/6;AI]5Rd@04H[400f;AH[5R/002H[03H]000f:`HZmR/006H[000ej`H[1NT002HXl01f:^HXmNSej`
GZiNSUj^009N[`9N/004GY1N/5j`GZh2GXl2GXh3GXl7GXh2GXl00ei_GXmNS`02GXh00ej=GVeNK@04
FVd00eY^FVeJKP07FVh015Y]FVaJKUY^0UY]1eY=00=FC5I^ETd01UI=1eI<00=F:eI<ET`015I<00IB
BeI;DT]BBe8/DT/2DR`2DR/0158/DR]B:e8/0dh/0U8/0U8[00=>:dh/CR/00Th[0e8[0dh[00=>;4h<
CP/00e8:0E8<00001a1P320<8@Q13448@@a0008<@@8@HP08344<8@`P440@H@a0220<80840006544e
AE9_HZ]NBUi^0UY_0eY`0Ui`0Ui_00=NKUj@GY001ej@0ejA00=NT5j?GY0015j@0Uj?00ARSf:@HXmR
[`9RSP09HXaRBUWXEJEIaEWVFLIIaeWV009MiP=Mi`07HPMN25h9HPQR1f8WHPH00V8700IN2Eh8GPUR
2687GNL2FLL00eG7FLMEa`03ELL06577DJMAYTfVCHI=QDV4BHDi92QP<<95b5Y]FTiNSV:`H]9N/V;C
H[=R/69[>DLD@`88000A8<H]Ab587@HLiaSV5:D@I11S368<@PaS48@<HPa2344<8@02344234024402
42004Qb1;@@mY3f6=BDXa1bS58<Q:2hA>Y@jec[F>]Lf]C[F@_M2n08nn005>YDb<c8c<U<fD`02=W@0
2CJD=W<jLcYc?]@nTc8?7@L88@0200003`@012040000421B:GLTOjioJfZ6AHDL@0P0100<00042200
10`P340@@11P0Q1Q0Pa000@8@@a0340@H@8<@004220400@02202224212451202220010PQ2448@@Q1
0`PQ0P`Q1Pa10P`P2`a10`a000P@H11Q588HaAd67>DHXaB20Q1Q00@<H@aR368@@@@<@@8<@P<<@@03
340<@@a100H<@@04348<H@aQ444246400`aQ368<HP02348344800`a2344<@P0334400`aQ464<HP02
36401Pa0344<H@aQ464@@@@@H@@@HP03464@HQ1R00@@HP08444DHQ1Q420<021PL`Yoj09oo`0@OoYV
]CdY86<PY2C49<DXa2RT9<DXiR34664<00@0220E120030PP120480@Q100000@0:@=1aEZ;Ja1[=0AV
l`03I_9Vlf[b009ZlP04J_=_56[cJ_<2J_@016lDKa=[4f/C16/D00=Zm6/DKa@01F/D0V[d16/D00A[
5FlDJaA[4`=Zm004J_=Zm6/CJa@3Ja<00f/DJa=Zl`02Ja<00flCK_=Zm002J_@016/EKaE[4flC0V/C
00=[56/CJ_@00V[d1F[c1F[b00AZlf/CKa=_509_4`9^l`03KaA[4f[c00YZl`03J_9ZlF[b00=ZlP03
Ja=_4fkb00AZlP03J_=ZlV[b011ZlP=VlP08J_9VlV[bJ_9ZdVKBJ]9VlP9ZdP03I_9VlfKb00MVlPAV
dP=Vd@9VlPYVd@9VdP03I]5Vd6K@00=Vd09V/0AVd003I]5RdF;A009Rd@04H[5RdF;AH]42H[4<H[00
16:_H[1R/6:a0Uja00IR/5j@HXmRSej?GZl5GZh5G[0015j>GXmNSej?35j>00ANKEj>GXiNSPANK@=J
K@04FViJKEY]FVd3FVh01EY]FViJKUI^FVh01EY]00AJCEI>FTeJC@=FC003FTeFCEI=009FC@03ETaF
CEI=009FC@9FCP03ETeFC5H/00MFC09BC@03DTaBBe9;00=BB`9BC0=B;0=B:`=>;09B;09B:`03CR]>
;4h[009>:`04DR]>2dh;CP/4CR`014h<CP]>2e8:0E8<00001`a0320<8@PQ24488@`Q008<@@05368<
@@a1344<800334002PQ0220000@0544eAE9^HZYNJUi]0Ui_0eY`00ANL5i^GViNKP9NSPINS`03GY1N
TEjA009NT@03GY1NSej?00=NT004GY5NT6:?HY02H[002FJ_IXeVSFJ;HTYIj5G7FLIEaP03FLD2FLH0
1eg7GNIMif87GPQN2Eh8009R1P05HPER1V88GPUR2002HPT01687GNMIaeG60U6W00YAYTfVCJI9QTF6
BHI9QdfVCJEAY@99Q00J?B@/PBbPAJMF;EY<GViR[f:aH]=Ve6:cIZiZZSe874<800`17:DY9R588BLM
1QcV5:D@Q08@HP<<@P8<@@8<8@03320<@0a0008<@00@440D@10P560]9D6T>FDeABC3688<823U;Je2
U3je>[D2?]H02D;G@_Q2n3kH>]Pj^3Zg?YHjUP02>YD2=W@023Ic>Y<neD;E@Y<Y[1BV100200004@@0
22000000100m86k4OhYoSG;UFPHd`A00200<00P032000PPP00<<811044000a1P00D<@0a1340<@0`P
00@<@006240880PP22088@PP1P@P00@880@P120480<88@0322088@PQ00<88@8<@003220<8@`P008<
@0@<@@043408@0PP240334002PQ0320<@1AQ588LiRE88@DHPQB20Q111`a10``Q3Pa11A1Q111R0a12
0Pa211110Pa10Pa20Pa10PaQ0Pa100@@@A1Q488@HP/@H@8@@@8@H@04320401A0CNL2Oo001go/NeIA
/337868PPbC4008Xa008::@TaBT78:@HH@`0100881P480848@08000882CS>HAFJfK^Ja=Vd`=Vl`9V
lPEZlP03J_=Zm6/D00E[509Zm003JaEZm6[d009[5003KaA[56/E00AZm0I[5003J_AZlf[d009Zm003
J_=Zm6[c009Zl`Q[4`06J_=Zm6[dJ_A[56lD1F[c00E[4f[dJ_AZm6[c00=[4`03J_=ZlV[b00EZlP=[
4`03J_=^lfkc009_4P03J_=ZlV[b00=ZlP05J_=[4f/CJa=Zl`02J_401F[bJ_5ZlV[aJa800V[c5f[b
00=VlV[bJ_800VKb0f[B0V[A00AVlV[BJ_9Vl@=VlPEVl@03I]9VdFKB009VdP03I]5VdVKa009Vl@03
I_9VdFKA00YVd@EVd09V/0IVd09Rd0ERd@03H[5R/6:_009R[`04H[1R[f:_HZl4H[02HZl00f:`HZmR
[`04H[000f:@HXmRSP05GXh2GZh01Ej_G[1N[ej_GXh00ej?2Ej>15j=1Ei]00=NK5i]FVd00UY^1EY]
0eY^1UY]0UY=00=FCEY=FTh01eY=0UI=00=FC5I;ET`00eI=0UI>00=FC5I;ET`01eI<0UI=0UI;0e9;
0U8/00AFBe9;DRaB;09B:`03CR]B:e8[00EB:`03CR]>;4h[009>:`=>2`03CR]>;4h/009>;004CPaB
:e8ZDPX1DP`00003360<80`Q00888@0524488@PP2208@@0234400`PQ2448@@0424402000100@83DT
EViVZej<GVd4GVl01UY`GW1NKei^GVeNKP9NSP=NS`03GXiNKei`009NL@9NT@03GY1NSej@00=NT004
GY5NT6:@HY02H[002FJ_IZiVS6J<GTYJ25WXELMIaP04FLD01EW6GLMMieh7GPP00Uh900UR268WHRMR
1V8WHPMN2F88HPT00V8800=N1eWXELL00e6W00=EYUG7DJH00U6V02AAaU6VDJI=QDV4AF<m0c22<:15
YeI^FViNKV:?H[5VdVKdI[9Zd6Z[AJXP@PP0300LY2T68BPUJAd77>HDaA2446<@@@a1348232432240
0``P340<@00234007110560@80`P684U1BDV7:@HPaA1300DHad7:JdfDT;D@_Hn]CkF@]M2n3[G=[Lf
USZF>YDjMCYd0SIe00PfUCJD>]Dn]3ZD=S0Hi`@R0P000P@Q010480PP00000210FTEkRgm/Ofe^YTV6
844800`0200<80888007320<@110464@H11034000Pa10P`P0Pa000D<H11Q364<H@a100888@031248
80@Q00P4800522088@PP22088@0324400`PQ324<@0023242320334400``Q344<@@0222400``P340<
@004340031B15:<DY24X7>DHPQB1444<80PP3248@@<<@@0332488@`Q00T<@@@@@@<@HP04464DHQ1R
4643468246<444801A11464@HA1Q46800a1S0a1R00<@HA1134403a1Q0Q110Q1Q00`@@0P0300``5hW
MdeVQeG9>@LTHb1R88<29<@01bS4::@TaBD78:<LH@`0008401<480<8800?22448@@Q120000a08><e
QDX/H/eVlVKCI_AVlf[b009Vl`9Zl`05J_9ZlflCJ_=Zm007Ja@4J_@4Ja@2JaD00f/DJaE[5002Ja@0
0f/EJ_AZm005J_@00f/DJ_AZm002J_<00f[bJ_=[4`07Ja<2Ja@2J_@5J_<00f/CJ_AZm002J_@016[c
Ja=Zlf/C1f[c1F/C0VlB1V[b0V[c00=ZlV[cJ_<00V[c00IZlV[aJ_5ZlF/BJ_82Ja801F[bJ_=ZlV[b
J_<00f[b0f[c3V[b00MVlF[bJ_9VlV[cJ_9ZdP02J]44I_800fKaJ_5Zl@02I_43I]400fKBI]5VdP04
I]8AI]42I]02I]4016J`I]1Vd6K@1V;@0f;A16:a16:`0f:_0f:`0f:_00AR/6:_HZmR[`AR/003GXmR
SV:>00ENSP9N[P04GZmNSej?GXh3GXl8GXh9GXd015j>GViNKUi^0UY^0ei]0UY]1UY^0UY]00IJCEI=
ETeFKUI=FTh9FTd015Y]FV]FC5I=15I>00EFCEI<ETeFC5H/00EFC09FC@04ET]BBe9;DT/3ET`2DT`3
DR`9DR/00dh[CRa>:`02CR/00dh;CRa>:`06CR`00dh[DPYB2P01DP`00004340<80PQ2242344010PQ
124400PQ0`a100<8@@a034000Pa100P8@@Q2100<03DSDReRS6:>15i^0Ui_00=NL5i^GVh00ei^00=N
SUj?GXh00Uj>0Ui_00=NL5j@GY000Uj@00=NSej@GY000Uj@00ANTF:`HY1RT09RS`0:IZmZ[VJ<IXaN
JehXFNQIaeW6FL@3FLD015W6GNIMiUh715h800=R1f8WHPH00V8700UN2688HPMR1V87GNMIb577CJL0
0TVW0TfV02=EYUW5GLEIiUG5CJE9QDUTAFA18bb1;:15YeZ>FTiNKV:>HZmVd6KBH[5V[VJ[BN`/Q100
420LY2CV:FTUJB4W7>HDYA2300@<@@8<8005324880PP320<@@043402440232001110564DH@a10P`0
00L88A248BPakD[B@]E6m`02@_L01d;H?]Pj]cZg>YDjMCIe00<fM007<W<j]CkE?Y@^425;36@00P00
00D400@Q124480PP00800009100m@6kYOhaoKWLWEPT`X@`00088000:320880PP320@@0a0460<H11P
3642340332001`a0460@H1BR6:@@H``Q00888@<400T480<88003120880PP00P88004224<80PQ2242
32400`a1340<@00434002Q10464DXaS58BLLiAR1564@@0`Q10PQ1@PP00<<80a134401`a100<@@@a2
46800Q1Q00@DPQAR464DH@<@HP04464<HQ1R36823487444010a1464@@@a10Pa000T@@0a0320<@0aQ
460@HAAQ46400Q1R111Q00@@H110440@@0<@H@0;320<0220<>0a8cU5<></`R22664LP`029<@02RS3
;<<Xa2d69<@LH@`P100880@03P@P0`PP00<480PP22000PPP0PPQ00X48000220ThcV5DTaRcfKbI]9V
l`9ZlP9Vl`05J_A[4f/CJa=_4P02J_<6Ja@00f[dJ_=Zm005J_@4Ja@016[dJaA[56/D1F[d0V[c0V/C
0V[c0f[b1F[c0f/C0V/D00=Zm6[cJ_<01F[b00=[4f[dJ_@016[c0f[b16[c0V/C0V[c0f[b0V[a00=^
lV[bJ_802f[b0V[a00E^lFkbK_9[4VlA00AZlP04J_=ZlV[bJ_83J_<>J_801FKaJ_9ZlVKbJ_800V[B
00AVdF[AI_5Vl@9VlP05I_5Zl6[`J_1Zd005I]43I]800fKbI]9Vd@07I]4016K@I]5VdFK@16KA00=V
d6KAI]400VJa00AV/6K@I]1Vd0IRd004H[5R/6:`H[02H]42H[400f:`HZmR[`03HZl4H[05HZl00f:?
H[1R/002H[0016:_HZiRSV:>2Uj>0ej?1ej>15j=00=NK5j=GXd00ej=00ANKEi^GViNKP9JKP=NK@=J
K@AJKPAJK@04ETeJKEI^ETd3FTd015Y<ETeJCEY=0UI;00EJC5I;ET]FC5I=00=FCP05ETeFC5I;ETaF
B`02ET`00eH/ETaFC003ET`015I;DRaB;5I;0U9<1E8/0U8[00=>:e8[DR/00U8[2Dh[0Th/00=>2dh/
CR`00Th/0Th<0Dh;0EHY0E8<000224400`a2248<@@0234400`Q23488@P0234400``Q344<@@043440
2@QR200@83D2CP]RS5j?FViJK`03GVl2GW001Ui_GViNKei_GViNK`=NT003GXiNT5i_00=NL0MNT004
GY5NT5j@HY03HXl02VJ_IXeRSF:=GRQIj5W7FLIIa5W50Ug600AMaeh7GPMN1`AN2003HPMN268700=N
200AHPQR1f85HPMMieG8BJI5IT5U@FI5I44S@DA=QEW5DJI=Y@02BHH034UUBFA1A2b1:811QU9>ETiJ
Kf:?H[1Vd09R/@0AHXeVZdh^=>HD01008<@Y1Rf:9FTQB1cW5:D@HPPP340<@@0232000`PP320<@@07
344234004P`P340@H1AQ440880`P56<HQ1bT7<DUBSX@@[E2mdLI@_Pne`8j]`03=YHfMSIe008fM@09
=W@fUC[F?Y@fLbh@7D/@Q@@00080000510448@@Q1244800300002aQPDTY_1W^>MbYVJD54520800@0
20000PPP00<<80a034000PaQ0Q1Q00<<H@a132400PPQ00/<80a0364DXaBT488<HPa2324880@00084
8@D480<48@0312048@@Q00848@03120880PQ00@88@0322088@`Q008<8@03244<@@`Q00@<@@0;340<
H@aQ464@HQBS7>HU9b3U588DH@02320622401P@Q22088@PP224<8@H<@@03444<@@a2008@HP<@H@03
444<@11Q008@H@8<@@05464<HPa2348@H@064442344234000`aQ468@HP0646400aAQ468@HP025680
1Q1R464@HA1Q444@@08@@@07464@@@`P420HPBS28<800QbR00dPXaR3688LPbC3:<@/a2c3<@@a9RcU
764@@002220A12000`PP120880032202224020PP100882D3?JIFK6K`I_<2I]82J_801F[cI_=Vm6LD
J_<00f[d0f/D00=[5F/DJa@00V[c1F[d00EZlf[dJaA[56/E009[5008J_A[56/DJ_AZlfKcI_AZm0iZ
l`9[4`03JaA[5F/D00=Zl`=ZlP9Zl`9Zm0EZl`03J_9Zlf[c00=Zla1ZlP03J_=ZlV[b00MZlP03J_5Z
lV[b00AZlP03J_=ZlV[c00IZl`iZlP03I_5VlVKb00EVlP03I_5VlVKb00=VlP9Vl@03J]1VdFKA00AV
d@EVdPQVd@03I]1VdFKA00QVd@03I]9V/VJb00ARd@05H[5RdF;AH]5Rd003H[000f:aH]5R/@04H[04
HZl7H[000f:_H[1R[`02H[000ejaH[1R[`02HZh016:>GXmNSej_15j?0ej>0ej?00ANSUj?GXmNS`QN
SP03GVaNKEi^00=NK@05FVeJKUY^FViJK@05GVd015Y]FViJKUY^1EY]0eI^00EFCEY=FTeJKEI=009F
CP03FTeJC5Y<00=FB`9FC0EFC@03ETaFCEI=00=FC@04ETaF:e8/DT`2ET/0159;DTaBC59<258/00=B
:dh/DR/00e8[0dh[2dh/0TX<00=>34h;DRT00E8<0004244834400``Q344<@@02344234002PQ1200@
8341BLQRS5j^FViJKei^0Ui_0Ui`00=NKei^GVl00Ui_15j@0Uj?00ANKei`GW1NL0ANT09NS`9NT0IR
S`9VS`9RSP08GRQMaeW6FLEIa5W5FLIMaP9Mi`MN1`0EGPQR1eh8HPMN2688HPIR1F86GNMIadV5>@8i
0d55@D@m8d4TADA9QDf600=9QP0BBFE9QD54<:8TH465DRiFCUi_HY1R/6J`H[5R/6:=J/aFCc340P`0
00PLXc56;HX]RRU86<DDY0a10`a000<@@A1044000Q1000H<80`Q324<8@a13243344244000`a0440D
@00230003235;>Da1abS58@Q:C7_@W<n]D<H?_Tjf0<fUP0;>YHj]SkG?[Hn]CjD?Y<b41dY36@00@02
00000`@112448@02124040@P00040000100m@VJ5MdYkC7;YDNL`X100200<00PP0``P00<@@A1Q4680
0Q1Q00<@@@a134400PPQ00d<80a0340@HA23588@PQ1R348<8@PQ10048@0212001P@0120480@P2204
8@8480@48@0322088@PQ00<88@0922088@`Q324<80PQ344<80a000<<@@0?340<@@a1464@HQB26<@L
iQS4568@@@`P200<8@`P008880<88@03104400PP00<8800432088@`P3243344020a2464@HA1Q444<
@@a0444246400a1P444@H@024642344344000a11448@HP05464546844643564546800`a1444@H@02
464246802a11544PXb326:8LXR336:<HPQbS:<@012cS00La0bd5;>@LP@`P2008800C120422002PQ0
244<80@0460Xhd76ETaVl6Kc0VKB00IZlVKcI_=Vlf[cI_@4J_@4Ja@2Ja<3J_@3Ja@2J_<3J_@6Ja@0
1F/CJ_=VdVKdJ_@00V[c00EZlV[cJ_=Zlf/C009Zm09Zl`=Zm005Ja=Zlf[cJ_=Zm005J_<00f[bJ_=Z
l`07J_<016[bJ_=ZlV[c1V[b0f[c26[b00EZlf[bJ_9ZlV[c00AZlP9Zl`UZlPEZl`mZlP04J_5Zl6[a
J_42I_43I_800fKaI_9VlP02I_802VKBI]5VdF[AI_5ZdFKAI_5VlVKa1FKB2VKA0fK@1VKA16Jb00MR
dV;AH]5RdF:aH[1R/@0:H[001FJ_H[1V[fJ_HZl00f:`0f:a00AR/6:_HZmR[`9R/003H[5R/6:`00=R
[P03HXmR/5j@009NT09NS`MNSP=NS`=NT0=NS`9NSP04GXeJC5Y^GXl2GXh015j=GVeNKEY]0Ui]00=N
K5i]GVd00Ui]0eY^00=JKEY^FVh00UY]0UI=00=FKUI=ETd00eI=00=FCUY^FTd00UY;0eY:0UI;00AF
C5I;ETaFC0IFC@9FC003ERaB:e9;009BB`03ET]BC59<00=B;003DR]B;58[009B:`03DRaB:e8[009B
:`A>:`03DR]>:e8[00A>:`E>;005CR]>;4h;CP]>:P01CP`000062248@@a1324<@@a21`a10P`P0Pa1
0Pa000P880@0200`hDFVGV]NSUY^0Ui^0Ui_00EJL5i`GY1NSUj?00INT0=NS`05GY1NL5j@GY1NT@02
HY000ej@HY1RT003H[07HXl02Uj>GRQIaUVUFLEIa5W5GLEIaUg60UgW15h700=N:5hWGPP015h800QR
2687HPIR1UgWFLMEaTfW0TfX00IAae6WDJMAYe6VCJH2BHL2BHH04DUT@D@d`RAP@HMJKUY=FVmNSf:`
I[5R/FJaIZiZkUY`;<D00P`000PHHRT5<HX]J23V6:DDP`a10Q1100P<8AAR68<DPQAR440<00`P1@a1
00D@@@a1444@@0`P008D@00J320D@2SS?FLmARS2324<@aC7:Jdb<SZD>YDj]Skh>[LjUSZE?]Ln]SZE
=W<fDRg^6@P<H`84000300088@@Q00848@0422088@PP204210003000761B16l6MdUgBfI8@D<LH@`0
200<008<808<@005464@HQ1R468@@@02344222401PPP320<8@a1364@PP8DX`0658<<@P`P220400PP
0P@P00D880@P120880@Q00<48004100480@Q2209224532400``P344<@@0334401`aQ464@HAB248<@
HQ1Q00H<@@0332088@PQ00@88@@88003224<80Q100<<@@03368@HQ1R00D@HP04488DPQ1Q46444683
444244000a11468@H@084684464244001Q1Q584DPQ1Q344@H@D@HP8DHP0856<DHQR17:<PXQbS7:8T
a0@Xi0D/i004;@@T`ab23003100B1203220224002@Q1220400a0:>8mQ58[HZiRdP02I]800fKcI_AV
l`02I_<016KdJ_AZm6/D0f/E0V/D00=[4f/DJa<00V[d0f/D0f/C00=[56[dJa@00V/D00I[4f/DJaA[
56/CJa@2J_@2J_<00f[bJ_=Zl`02J_<4J_@00f/EJ_AZm002J_@=J_<3J_@2J_<00f[bJ_=ZlP06J_80
0f[cJ_9ZlP09J_800f[cJ_9ZlP07J_82J_<8J_85J_<7J_800f[cJ_9ZlP03J_43J_83J_401F[bI_5V
lVKbI_<01FKb00MVlF[aJ_5VdFKaI]9VlP03I_400fKbI]9VdP02I]800fKAI]9Vd@09I]400fK@I]5V
d003I]4016K@I[5V/VJa0VKA16;A0V:a0V:`00QR[f:`H[1V/6K@H[1V[fJ`0f:`00=V[f:_H[000V:`
0f:a00AR/6:_HZmR[`9R/003H[5R/6:_00=R[P03HXmNT5j`009NT09NS`MNSPUNS`06GXiNT5j>GViJ
KeZ?0UZ>1Ui]00=NK5i]GVd00UY]0eY^00=JKEY^FVd00UY]0UI=0eI^00=FCEI^EVh00UI>00=JCEY;
FT/00eY:25I<0UI=00=FCU9=DTd00UI<159;0U9<158/00=B:e8/DR/0158/0e8[00Q>:dh/CRa>;4h[
DR]>;58[0dh[1dh/00=:34X;CPX00DX=000222400`a1244<@@0234401Pa2364<HPaR364@@0D<800@
340880P0200/`DF4HV]NS5Y]GVeNKUi`GVmJKei_GVh2GXh00ej?GY1NT003GY04GXl4GY43GY000f:@
HXmNT002HY04HXl03fJ`HXmRSf:>GRMIYUVUFLEIa5W5GLEMaUg5GLIMiP04GPL00ehWGPMN2005GPP2
HPP00egWGNIMa`03FLL01Uh8HRQR2688GNMAYP99QP0XBJM9QTUTBF=58cC19611QUY>GVeJC6:=H[1R
/FKAI[1V[F[>GY0i1a00300D@BCU;FPY1AbT6:@DPaAQ444<8111588La2346:<DHP`P220644434640
2QAR688LPR21::0mI4WYBNY1QRBS0PPR00@@I2E:;L`f408jDP0:?W@nLcYB=S8^4BG>8H/I212U1282
000010@0224880@Q0P@P00<880@Q22400PPQ00/80000200m@6JWOfMkAg;TCNLd`100008800063208
80`P440@H1220Q1R00H@H@a134488@PP120210001`PP344<HA1Q6:8DPQ1R008<@@03224880PP0084
80@880@4808400<88003224<@@PQ00@88@04324<@@a132423202344010a0320<@0a10a1Q00D@HQ1Q
464@HA1100<@HP04368<@@`Q3244224522001@a0344<@@a144400a1R00<DHQ1R46800Q1Q00@@HQ1Q
444@H@L@HPD@H@D@HP04464<@0a14443464256400aB1588DXP0358800aB3588DPP0258<02QAR56<H
PaQQ784PXR2S8<<T`bS30bd300@]12d5;@D]1@</i0049<<LP``01002000B1203220224002@Q12200
00PP:>91XeI;H/iVlP03I]82I]<2I_<01F[cJ_AZm6/CJ_<00V[d0V/D0V/C0V[c00A[4f/DJaA[50A[
4`A[50A[4`04Ja9Zlf[dJ_<4J_82J_<2Ja<2J_<2J_@00f[cJ_AZm004J_@6J_<2J_85J_<:J_800fkb
J_9ZlP0DJ_8016[cJa9Zlf[c0f[b00=ZlF[bJ_800V[c0V[d00=Zlf[bJ_801F[b00=Zlf[bJ_801F[b
0f[a00=Zl6[aJ_400VKb00AVlfKbI_9Zl@9ZdP07J_5Zkf[`I_1VlFKBI_800VKa0VKA16KB1FKA00EV
dVKAI]5Vd6KA00AVd003I/mVd6KA009Vd004I]5V/FJaIZl2I]03H]42H[42H[0026J_H[1R/6J`I]1R
dFK@I[02H[03HZl4H[000ejaH[5R/003HZl2H[000f:aH[1R[`03HZh01F:>HXmN/5j`GY000Uj?2Ej>
1Ej?0ej>0Uj?00ENKUi_GXiNSEj>009NK@03GVaJKEi]009NK003GV]NK5Y]00AJK@04FVaJKEY/FVd3
FVh2EVh3ETd2EVh015I=FTeJBeY;0eY:00=FC5I;ET/01EI;00=FC5I=ETh00UI=0UI<00EFBeI<ET]F
Be9<009B;0EBB`03ER]B;58/009B;0AB:`9>:`05CRa>:dh[CRaB:`03CR/00dh/CP]>;004CR`2CR/1
CRX1CPd000888@033448@@a1008<@@07348@HaB446<<HQ1Q32000P`Q0P`P00`<@0`P320@@2RP@H=R
JV:]FViNKEi^GVl2FVl02Ui_GXiNSej`GY5NT5i`FY5NLEi`15j?00=NT5jAGY401EjA00ENT5jAGY1N
T6:?00=RT005I[1RSf:?GVeRB003FLH3FLD01Eg6GLEMaUgVGNL00eh72Eh800=MjEgXGNL00UgW00YM
j5h8GPQN:6IYHPMAYTE5ADA9IP99QP0;BFE9Q4E4<:0TH3e6DRiNBeY;HXeRS`02H[403fK@IXiZcV:_
?DPH8@`0540P`bD78<@LXabT688HHP0232002Q10688PiBD59@HPiART58<DHQA10Q1101l@@Q1Q444@
HA1R568Pa3D3=@11HF8XKZQc36ZYEP/`a1@Q200D@R357@PQBB5;8F`MBae:7F/MBQCX38@08@030000
0`@112448@0212431202124222403``1100002BPFVQk97]5L`=RB4ES840800@02008800244000aB1
468@HP0246<00`a23448@@0422400``Q220<@00246400aBS46<@H`02368234422443220222462203
344232000``Q344<@P0234401@Q1344<8@`Q32000Pa200D<@@`P344<HQ1R008<HP06348<@@a2368<
@Pa10Q1R00@<@Pa1344<@@8<@P053448@@PQ22088@0734400a11468@HP02468020a2464@HA1Q440<
@@aQ368246800a1Q468@HP0446474680111Q468@HQ1R0Q1Q00PDHQB26:8LXac38>DU1QcU0aRT0QB3
00PDPQAR56<DHQ0P780PXRS20RS300</hbd3;>@00RcT00<]1Bd6<BH00RcU00LY1BcT9<@LP@P01000
000B120322004@PQ220880@0000882S2@L=FJfK?Ja=VlV[bJ_=ZdfKCI_@00VKc00=Zlf[dJ_@00V[d
00=[5F/DJa<016[c00A[4f/DJaA[50A[4`I[5003Ja=Zlf[c00QZl`9[4`06JaA_4fkcJ_=Zm6[c0f[d
00AZlf[dJaAZl`9Zm0AZl`03J_9Zlf[c00EZl`eZlP=Zl`03J_9Zlf[c00AZlP=Zl`MZlPMZl`03J_9Z
lf[c00=Zl`MZlP03J_=ZlV[b00EZlPEZl@04J_9VlVKbI_<2I_800f[AJ]9ZdP02J_4026K`I]5VlVKB
I_9VlFKbI_46I]84I]42I]8016KAI]1Vd6K@1fKA00EVd6KBI[5VdFJ`009Vd0ARd@=R/@=R/004H]5R
d6;AI]02I[08H[000ej`G[5R/003HZl02V:`G[1N/5jaG[1R[V:_HXmRSV:?0ej@15j?1Ej>0Uj?0Uj>
0Uj?00=NT5i_GVl01Ui_00]NSUi_GVmNKEY]FVaJKEi/GXeNJeY[009JK@06FVaJKEY]FVaJKEY/0UY]
0eI^0eI=00QFKUI]EVeJK5Y=FTaJCEY;0UI;00AFCEI<ETaFB`=FC005ET]FC5I=ETiFC@02ER`3ET`0
0e9;DTaB;002DR`5DT/3DR/00e8/DR]B:`03DR/2CR/024h/CR]>;4h/DR]>:dh/CR/4CR`01Th]BPe:
34X<CR]>:P5>3@0000D8@@PQ224<8@a1008<H@@<@P05364@H@`P22088@0232002@a0320@@1AP8:0m
HEi:HZeJKP02GVd2GVh4GXh2GVl2GW000eZAGW5NT003GXl015i^GXmNT5j@25jA00=NT6:@HY000V:@
00IRSfJ?HXmNS697GNH5FLD3GLD00egVGNMN1P02GPL00eh8GPMN2006GPP01Uh9GNQN1egWGLMMb09I
b09N1`05FLE1@cd2><4m0`02BFH05dUUCHA5@cBP840i9DW/FTYJBEj<HXmRTF:aJ]1V[Vk`HXi1R1a1
300@81bR8>D00QbS00dLPaR2684HHAAQ788LXbd4>F@aAC4U:@HLY002568244401112444@@A1Q0QAR
00HPXcTQ>B1F9GL4Old2Ojd01VjZAHLLHPP1424<8@<8@P0536<8H`QS14808@0500000`@012088002
2203120010PP12448@@Q0PPQ01840000300m@6jTMbAkAFk6DPLd`10P200400P0340@@11P46424680
0a12344<@@04344030PQ324<@@a1444@H@aR468<HQ1R368<H@<<@@04340880PP2202240010a02408
80PP2`a00Pa100D<8@`P320<80`Q008<@@03464@HPaQ00<<@@07324<@@a1344<@0a134002@a100<<
@0a134001Pa100<@@@a134400Pa100<<@11044000Q100`a000@<@@aQ464<H@8@H@04460@@11Q4642
46854640311R464@HA1Q564DHQAQ684HPQc48>@La08HX`06688DPQB2588DHQ110``P00D@82C2;@4X
`Rd3008a1@05:<<Xa2S4:>@/i@04;>@2=BD012SS540400004P@P1PPP00P800@0320X`D6REV]R[6[a
0fKB0VKC00=Vm6KcI_<00V[c0f[d0V/D00MZlf[bJ_=ZlV[cKa9[4`02Ja@4Ja<00f/DJ_=[5003Ja@2
J_@01f[cJa=[4f/CJ_=[4f/D009Zl`=[4`9ZlP=Zl`=Zm0AZl`9Zm004Ja=Zlf[cJ_<3J_85J_<=J_83
J_<00f[bJ_=Zl`04J_82J_<8J_800f[cJ_9Zl`03Ja<00f[cJa9ZlP0CJ_82J_4016KaJ_5ZlFKa1FKb
16[a00AZdFKAI_5VlP=Vl@03I_9VlFKA009Vd@03J]9VdFKA00=Vd@=VdP04I]5Vd6K@I]0:I]48I]02
I[001F:aH[1R/6:`H[400V;@0fK@0VJ_1F:`00=R[f:`H[000V:_0Uj_00IN/5j_GY1NTEj`HZh2HZl2
HXh015j?GXiNT5j@0Uj?0Uj>00ANSej>GXmNS`ANSP9NS`03GY1JKeY_009NS`=NSPANK`9NK@9JK@9N
K09JJ`QJK09JC003FVaJKEI=00=FC@06ETaFBeI;FV]JK5Y]0eY=00=FBeI=ETd00eI=0UI<00AFBeI<
ETaFC@9F;@03ETaF;5H/00ABC09B;006DT]FBeI;ET]BBeH[0e8[1E8Z0U8[0Th[00=>;4h[CR`01dh/
00I>;Dh/CRa>;4h[DRT1CP`00088@@03224<@@a200<<HP05348<@@a2368<H@0236803a1R344<80a0
220<@1108:0m@EHYGXaJCUY_GViNK@03GVh00ej>GViNK`03GVl00ej@FY5NT003GXl00ei^GXmNT005
GY05GY401Uj@HY1RT6:aI[5VS`9RS`07GTUMieW6ELIIaEW6FLD00Ug515gV0eh7168700=N1eh8HPL0
0eh800AN1egWGNMMa`9Ib008FLIIiUW6DJI5IDE4ADE9IP99I@0[CHE9I3S1720`i4W[GTYJBEi]H[1R
TFJaI[1Z[Vk`HZe5Z1a1300@01bR8>DP`abS78<LPQR1784PPR2R:<8iA3UT?HHeABT58<@HPaAQ420<
8@a144400QAQ010DP``P684/`CTPCPIg:G]]Oi1g:VIZ@HLPPQ12420@@08<8@888@03244880@000@0
000510048@@P12448002220222422205224030@0000001aPDPEc9W]TMbERB453860<00840005200<
@11Q464DHP0246802@`Q344<@@a1348<@@a2344<@P0234400a11464<HP0536802A1R368<HPaR364<
HPaQ368<H@0334401@a0344<@@a134000`a10`a000<<80a134400Q1100@@HA1R468@HP<<@@033248
80PP0088800332488@PP00<<@@8<@PH<@@03340<@@a000D<@@03444@@11100@<@@@@@0D<@@@<H@0;
464@@1AQ468@HA1R464D@A1Q344@@@0546400a11544DH@02564011R26:<DPQ1Q0a1000<<@1104640
0Q1100THPR2R<@8e@cET=D@iACDU:<@00RBS00<X`bcT;>@00Rc300L`i3DU?HLi@ab12000000=1200
0`@Q120480021203220224002@Q1200400P0:<4mXE9<GZiVd@03I]84I_<016KCJ_=Zlf[d16/D00=[
4f[cJ_<016[c0V[d00=Zlf/CJa<016/C1F/D16/C00AZlf/DJ_A[4`9[509[4`9ZlP9Zl`=Zm004JaA[
4f[cJ_<3J_@4J_<3J_85J_<5J_800f[cJ_9ZlP05J_83J_<00f[bJ_=Zl`02J_82J_<016[dJ_=Zlf[b
0f[c0f[b2F[c0f[b00=Zlf[bJ_803V[b1fKa0VKb00=Vlf[bJ]800V[B00=ZdFKbI]801FKb00IVlFKA
I]5VdF[bJ]44I]42I]82I]43I]08I]400f;AI]5Vd@06I]000fJ_I[1V/004H[000f:aH]1Rd003I]0:
H[03HZl01Uj_G[1N[ej@GY5N/09R[`9RS`05HXiNSej?GY1NS`03GY002ej>GXmNSej?GXiNKUj>GXmN
SUj?GXh00ej@0Uj?0ej>00=NSei_FVh00UY^1UY]2EY/00AJKEY/FVaJC0AJC@05FTaJBeI;FV]FC004
ETd00eI;ETeFC@04ETd01EI<ET]FC5I<ETd00UH]0UI<00=F;59<DT`00e9<00AB;59;DT]BB`IB:`05
DRYB:e8[DR]B:P03DR/014h[CTa>;4h/0dh[14h/0Th]0Th/0Dh[0E8Y0E8/00000`Q1224<@@023442
36801Q1R464<@@a1220<H@<<HP0>340<80a1320<@0P0680i8E8YFVaJCUY_GViNK@UNKP=NT09NSP9N
KP9NSP9NS`=RS`ENT00<GXmNT6:aH[5VT6J?IXiRSUi:FPQEaUW615W500EMaEgUGNEMiEgV00=N1`=R
1P0EHNIN1Uh7GPMR1eh8HPMR1UgVGLEIYTf6CHEEaEWXFLMEaU6VDJM=QTUU0099I00:CFA9@cd1840`
iDW/FR]J:Ei]HXl2H[402fJ`IXaZcVK=BNTTH@`0400LXR348>@00QbS014LXQb1660PXBcR<>8a0CU2
=FDa8bC47:<HPQAQ320<0111008DH@0?588DP``P540/`BcP@H=RIg<<K^]ZYDgX?D@TPQQR008D@008
444<8@`Q468@Pa1R220400@880<4800422088@PQ224322000`@P22088@02224030`Q200000`0;<1N
RWmULbAZYTgW=<0D80<80006220<@11Q564@H@`P0PPP1@a100H<H@a1344<@@aQ344436802A2258<@
PQ1R488DPaBS58<@P`0336800a1Q344<@@0334400`a0344<@004340010`P340@@11Q0aB200LDHQ1Q
344<8@PP1204000222000`PQ324<@@0334400`aR364@@@0234401Pa0344<@@Q1340<80L<@08@@0<<
@@03340@@11000@@@08<@003344<@0aQ008@H@07340<80a0468@HA1144000P`P00H880`P340@@A1Q
444332000a10464@H@0246401Q1R464@HAAR6:<LX`8LY00<7<@Pa2cS=DE1Z4GX@LQ5j46X>FL`i2RR
0RRS00`/a33T<>D/i33T=BI1Yd6S7:880000100>12000`@Q120880032202240030PQ200400P08:11
X59;I_1RdFKBI]=VdP=Vl`9Vd`03I_=Zlf[c00=Zm006KaA[4f[cJ_AZlf[d1F[c0V/C0f[c00=[4f[d
J_@00f[d00AZlf/CJa=[4`=[50E[4`=ZlP9Zl`=Zm0=[4`EZlamZlP9Zl`03J_AZlf[c009Zl`EZlP=Z
l`03J_9Zlf[b019ZlP03J_5ZlV[b009ZlPMVl@9VlP03I_=Zdf[B009Zd@03I]5VdVKB009VlP04I]5V
lVKbI_42I]44I]03I]42I]82I]43I]02I]401FK@I]5VdFJ`H]400V:a2FK@0fJ_00=R/6;@H]000f;@
0VK@00=R/6:_H[000V;@0f:`00ER[f:^HZmR[ej_009N[P05GZmNSej@GY5N/002HZl2HXl016:>GXiN
SUj?0ej@00=NSej>GXh015j>00=NSej>GXh00Uj>00ENSej@GY1NKei]00=NS@03GXiJKUY^009JKPIJ
K@]JK003FVeJC5Y=00=JC@06FTaJJUY:FV]FC5Y=0eI<00=FBeI<ET`015I=00EFC5I;ET]FC5I=009F
;@9FC003ER]F;5H/009BC004DRaB:e8[ER/7DR/01U8ZDR]B:e8[DRYB:`=B:P03CR]B:dh[00=>:`03
CRa:34X<00=>;004BPa>:dh[DPT1DP`0000324488@a100P<@@04320<@@a134823442224020`Q3448
81AP>B9B:Ej<GXh4GVl025Y_GVmNKei_FVmNKeY_GVl3GY001Ej?GViRSUj?GVl01Uj@00INTEj@GY1N
T5jAGY02GY402F:@IY1VSFJ=GXaNBEX8FLIEa@03FLD00eg6GLEMiP03GNH3GPL3HPH0567VHPIN1eh7
GPQN1f86HPEMiUW5CFA5A4E2ELEJ25GXGNQIie6WBHL2BFH02dUUBFA5@Sd0860`iDh=FT]F:Ui]HXl0
0V:a029V/FJ?J]1Vke8:;84@0A0Q788LXb338<@LXabR788LH22Q9<8/`C31=B8a92SS8<@LXQR1564@
@111564HXQR3588DHP8@800>:<4X`3U2EPQ^Z6jWITE9YcTT:<@LXaR2564@H@8@@@056:<HaARS444<
8002220010PQ220880PP0PPQ00H8@@PQ22488@Q124022442224332402`P0000<046UIZIc16[5GTU5
QBb152800`P000H@@0`P320<80PP2002100<344010a2368<HPaR0Q1S00@@PaB358<DX`<DY00348<@
HQ1R00<<HP05348<@@a2368<@P0234401a1Q468@Ha22588DXaB2008@HP03448<@@a100<<@@L<@P04
368@Ha1S4682344010a0344<@@Q10``P1@a00`a100<@@@a1340010a00P`P00<880`P32000`a000@8
80`P344<@@88808<8007220<8111468DHQB246800QAR00P@HA11568HPaRT7:@LaAc40Qc501HTiBSU
:@DY1BdV<BH]1S46=BI1Z4X;DTeN[Ej/GXa>:T67>BDe13DU=BHe9@8a1@06=BHeAd78AJ@Ti0PP0P00
00<400@P12002`@P00<48@@P12000PPP0PPQ00d8@0PQ320400P08:0mP4i;H/iRdF;BI]=VdP03I_<0
0fKCI_=Zl`02J_<01f[dKaA_56lDJaAZm6[c00EZm09Zl`03J_A[4f/C009[4`9[50AZm004J_=[4f/C
Ja@3Ja<00f/DJa=[4`02Ja<00flBJ_9ZlP02J_<3J_@2Ja<<J_<3J_800f[cJ_9ZlP02J_<00f[bJ_=Z
l`04J_<2J_85J_<3J_82J_<4J_@2J_<4J_85J_<AJ_84J_42J_88I_42I_800fKcI]=Zd`02J]800fKA
I]9VdP05I_8:I]42I]8;I]43H]4016K@H]5V/6J`0VK@1VJ_00QR/6;@H[1R/F;AH[5R/6:a2F:`0V:_
00AN/5j^GZmN[`9NT09NT@=N/09R[`03GXmNSUj>00=NS`9NT0=NSP03GXmNSUj>00ENSP03GXmNKeY_
009JS`9NSP03GXeNSUY^00=JKP03GVeJKUY]00=JKP9JK@=JK0=JK@=JK003EVeJKEY=00AJC@04ET]F
JeI;ET`3ET/00eI<ET]FC006ET`2ET/015I<ETeF;EH]0eI<0UH/00QBC58/DRaB;59;ET]B:eH[2E8[
158Z00=B:dh[CR/014h[00=>;4X<CR`01Dh/0Dh;0Dh:0Dh<0003224234432449344030`R228<@Pa1
320DHCDQCRUR[6:_GViNS`9NL003FW1NL5i`00=NL003FVmNSej@009NT003GXmNKV:>009NS`MNT@9N
T0=NT@9NT00?HXmRKV:<IZaRRf9[GRMMiEFUFLEIaUW5GLIMaEg600=MiP03GPIN1eh7009R1P03HPEQ
iUh600=N1`0?HPIN1F85GNIIaDf5AD=58EFTFPQIieW6FLE=YTV600=9I@0:BDA58D4P960/i4G/FRaJ
:Ej=GY02H[403FJaIY1VdV;?DRT/P10Q544LPQbR7:<Pa233008LXP0/784PXB2R:<4/`C42;BDXi2C4
8<<LXQb1684HHAR26:8LXaR2564@@1QP:<0a03f5GT]^jF[9IVQ9QSTU:<@LXaR2564@H1AP464HXacU
58<<@@`Q224880<88@0322088@PQ00D88@0322088@PP00888004324<80`P420210005R2QBN5VYW<T
J^MF:Ce5::<<00@0200<8110780PXBC268<880@0200880`P0`a100<<HA1144000Pa01@a10Pa200<<
HQ1R46800Q1R00@@Pa1S468<HQ8@HP03344<8@`Q008<@@04444<@Pa23482344010a2344@@0a00Pa2
00<@@Q1144401@a00P`P00D880`P320<80P000H88088008400@80003300<80`P008<808@8007444@
HQAR568@HAAR68<01ART00THQ1RT6:@LaB3U:>D/iBd6;@D00bT50bd50RdV01`]9c57<BPa9c56?HM5
jU8/FV]VjF;:FTQ5YD66@FI1Icf8?FLiAcTW>DPmRDGZBLH]1@`P000400l48004220480PP22022243
22002000200TX3f0CTYR[6KAH]83I]82J_83J_<016[dJ_=Zlf[c0VlC16/D16[d00EZlfkcJ_AZm6[c
009[4`=[509[5@03J_A[4f/D009[4`E_4`=[4`03Ka9^lV[c009Zl`03J_A[5F[d00E[4`MZl`03J_9Z
lf[b009ZlPEZl`03J_9Zlf[c00]Zl`=ZlP9Zl`EZm003J_=ZlVkb00UZlP=Zl`aZlPIZl@IZlPAVl@03
I_=ZdfKB009ZdP9ZlP9VdP04I_5VlVKaI_44I]400f[aI_1Vl002I]400fKBI]5Vd@06I]45I]001F;A
I]5VdFK@I]400VJ`2FJ_00=Rd6:`H[001f:a26:`00=N/6:^GXl00V:?00QNT5jAG[5NT5j?GZmR[Uj?
0f:>0Uj>00=NSej@GXl01Uj>0ej=00ANKUi]GViNSP9NK`03FViJKEi]009NK@9JKP05GXiNKEi]GVeJ
K@04FVh01EY]FVaJK5Y/FVd00eY^0UY/00EFKEY]FTeJCEY>009JC@03FT]FBeI;00EFB`03FTYFBeI;
00MFB`MFC0EF;09B;003ER]B:e8[00QB:`9B:P04DTYB:U8[DRX2DR/6CR/3CR`01Dh[CP]>2dh;DPX0
0Dh<000222400`@P344<@@023482344324463442348020P0220<@C42CRUJSEj?FVl5FW02GW02FW00
0ej@GXmNT002GY03GXl4GY05GY400ej@GY5NT@03GY402f:@HVmRT6:`IZiVS69ZGTQMiUVUFLD015W6
00EMaUgVGNIMiUh6009N1`9R1`03HPEN1Uh600=N1`0>HPIN1Uh5GNIMaE6VCFA58E6UFPUJ1eW7FLIA
YP=9Q`99I@0LAD=1@B1P:<@mZU8/FTYNSUj`H[5R/VJaHY1RdV;?ERT/P100424HHAR17:8LXb337:<L
XR2R9:829:409BS2<@8aABST;>@/hb337:8LPAb27:<Pa1RS688DHAAP784T`C41?HIJKFK=J^eFBce5
<><Pa1RS568DHA1Q460@HA1R46<<@@`P00@88@0322088@PQ00H88@H88005324<80`P420800021000
4CD0FVU_1GMXIZQB:cU56408010P>@1=aTgVETY=icU568<00`P000P<80a0340<@A10464@@0a00P`P
00<<@0a134400Pa100D<@Pa1348<@@a200P@HP8@H@X@HP05448<@@`P220<8@02320534400`PP2008
000520000`PP320<@006340432000`a0440@@@03444232001A11564@@11054400QR300<HPQb37:<0
0b2T0QbT01XPaAc58<DTiBT6;DPaB2e8:BLU9bD78<DLY1c49>DY1RcV<@Ha1Bd5<BH]9S4V<DLeAc4V
0Rd600<]1bdW;@L00RdW00laAcEW>JU5beiZI/UVjeY:ANU1R469BL]5bd67@HP00T6900M5bTX;ALHT
i0PP0004000?12000`PP12088002224030Q1220880@0000802S1?H1>:VK>I_9VdP9Vd`9VdP07J]=Z
lV[cJ_=Zm6[cJ_@00flD0V/D0V/E16[d00A^m6kcJ_=Zm09Zl`05Ja=[56/DJaA[5@02J_@016/CJaA[
4f/C16lC0f/C0flC00=Zlf[dJ_<00V[d00=[56/CJa<00f/C00E_4V[bKa9_4f/C00AZl`03J_9Zlf[b
00EZl`03J_9Zlf[c00=Zm0AZl`04J_AZlf[cJ_<3J_82J_<00f[dJ_=Zm002J_@2J_<7J_83J_<5J_82
J_<;J_82J_46J_83I_42I_8016KcI]=VdV[A0V[B00EZlVKbI]9VlFKb009Vl@03I]5Vd6KA009Vd@05
I_5VdFKAI]5VdP05I]400fKBI]5Vd@03I]02I]401f;BH]5VdFK@I]5V/FKA00MV[`9V/09R/003H[5R
/6:a00ER/@ER/005HZmR/6:`G[1R[`02HXl02F:@GY1N/EjAH[1NSej_HZiNS`03HXh00f:^GXiNS`02
GXl3GXh00ej?GXiNS`02GXh01Ej=GVeNKUj>GVh00ei_15i]0eY^15i]00UJKUY_FVmJKUY]FVaJKEY/
FVd015Y^00IJKEI^EVeJKUY]FTh2FTd00eY;ET]FB`05EV/00eI;ETaFB`04ET/00eI<ET]FC006ET`0
2EH/DTaF;5I<ERaFC58/CRaB:`03DR`8DR/0158ZCR]B:e8Z1E8[14h[0dh/0Th;00=B2dh<CP/00Dh=
0005224324400`PQ1208@@0834402@a2224400`P:>=5ie9=FVeJK`02FW000ei_FW1NL004GW000ej@
GXmNS`06GXl016:?GXmNSej@15jA00ART6:`GY1NT09NT@0:HY1RSei_HXiRSF9[HVUN9eg6EH@4FLD0
0eW6GLIMiP04GNH2GPL01687HPEN1Uh60eh700=R1eh6GNH00Ug601mEYE63AB5AYEX8HRIMiegVFLIA
YTVWBHI9ITUUBF=1@BR09:A1RU8<ER]NSEj`H[5RdFJaH[5RdVKaGTXd`P02424254000ab17:8LXP03
7:<02B2S8:8TXRS2<B<aAC44;></h@028:447:803QRR688DHAR1680LXBC2=B95b58[DTe1YS3R8:<2
68<01AAR464@@11P34000Pa10P`Q0PPQ0`PP00@8@0PQ224880<88@H880<<808<8@0E300800@05415
PVJ4LdEgI6[XCNPdha`P=>9F:7/WOhQgAfk[DR`Xa100008800033208@0a000H<@0D<808<@@033208
00P000<880<<@@888008320<@11Q464<80PP2008808<@004320880@0200310000`P0320<@0023200
0`PP320<800620001@`P444@@@`P22000P`P00`<@A10340@@11P440DH1AQ688HXabT7<D58<D03RC5
9>DXi2cU:>DXaBcU=@HiASTV=BHe1SDV=@H2<BL2=DP03c57<FPaJ2e8:@LPiQbU6:@HXaR27:<Pa2C5
:>@/i003;@D01c4U<BHa9C46;@H]1bd6008]1`0J<@Ha9c57=DHeAd6ZHT]VZ6K;GT]5bT6:@HU5ZDF[
AJY1ZD68ALU>2dh:AJHPX`P0000400h480888084808880<88@09220000P09<0mH58ZI/eVlVKB00=V
d`9VdP04J]9Zlf[cJa<7Ka@00f/EJ_AZm002J_@2K_<00f[cJa=[4`02J_<00f/CJaA[5002Ja@2J_@0
0f/CJaA[4`02Ja<2Ka<7Ja<2J_@00f/CJ_AZm004Ja<00f[cJa=[4`03Ka800f/CKa9Zl`02J_<00f[b
J_=Zl`03J_<3J_83J_<2J_@4J_<01V[dJ_=Zlf[bJ_5ZlP9Zl`03J_9Zlf[c00=Zl`IZlP03J_5ZlV[b
00EZlP04J_5ZlV[bJ_<?J_800fKbI_=VlP02J_83I_400fKbI]9VdP02I]801VKAJ]9ZdVKBI]5VdPAV
d@03I_1Vd6KA00QVd@=Vd0AVd@03I]1VdFK@009Vd@0:H]5Vd6K@I]1VdFJaI]5Vd6J_I/l4IZl00fJ`
H[1R/003H[06H[43H[04HZl2H[03HXl01F:@H[5N/Ej`GY000Uj?0Uj>00=RSV:=HXh01ej>00=NSEj>
GXh00Uj?00ANSUj=GViNK@9NSP07GViNKeZ?GVeNSUj=GXh00eY^15Y]00EJKUY_FVmJKUY]00=JK008
FVeJKUY]FVeJKUY]FViJK09JK@06FTiJCEY=FT]FBeY:0UI;0UI[15I;0eI<1UI;00IFC5H[ER]F:e8[
DT`2ER`2ER/2DR`0158[DRaB;58/258[00=B:U8[DRX00dh;0e8[1dh[00EB:Th;DP]>358;005>3@00
00<8@@PQ22400PPQ0PQ100H48@PQ244<@0a1468234400`Q12248@@02344020P0100801bS?JIBCUZ=
FVl3FW02GW0015iaGW1NL5i`2Ej@00=NSej@GY001EjA00=RSej?GY000eja0ejA00QNT6:>HVaRRUhX
FLIEQEW515W600IMaUgVGNIMiUgWGNH6GPL3GPP02V87GNQMieWXFLMAYTf4BD9=YEGX0UWW00EEae6W
CJM=YdV70095IP0:ADA1@RRP98=1RE8[ET]JKUj@H[03H[402UjaIa=VRcT4624@81A0664LXAbR0QbS
00<Pi23U8<<00b2R00HX`bd4:>@XhbC28:847:<01AbR6:8HPQB268400QAP00lHHB2S<B@eACEV;@<P
XaR36:@HPa11344880a036400`a100L8@@PQ224880Q12408@@0822442206320050`02008021PBL=[
2G=4MdMRJ4W7<>9=ig;TOjmocWoeNhiFKbS4200210001P`Q24488@PQ240<@@8<@0@<8006220<@0`P
220800PP0PPQ00<800PP22000`PP00<400PP220010PP00L<80a1320<80a1468@@@0232001@`Q568D
PaB356800QAQ00HDHQbT8:@PY22U9:@28:@02RC49>DPiAbT68<DHPa1464@HQ1Q0Q1R01H@HA1R564D
PQbT9@L]9c57=FTeB347<BHe9cE8=DLe9S4W=BLeB3U8>FTiA`@e9`0==BPeB3E9=DPaB2dV<DPaAbD6
7<DHYAB456<00QAR00HHPabT8<@/iBcT:>D3;@D00c4V<BDa1P02;BH4;@H03346;@De9C3S@HQEjEi:
GTa=jd69?FTmJ08mR009AJU5bDG9BN]:2dX:?F@LX`P000840184800522088@PQ22088@0210001``0
8<4mPThZH/aRlF;B00AVd`04I[9VdV[cJa<2Ja@6Ka@01F/EKaE_5F[dKaD00VlD00A[4flDKcE[5@A[
50U[4`03Ka=[4f/D00M[509[4`=[50Y[4`EZl`A[4`04J_=ZlV[bJ_82J_<4J_@3J_<3Ja<3J_<00f[b
J_=Zl`05J_<2J_800f[aJ_9ZlP0<J_800f[cJ_9ZlP06J_800f[aJ_9ZlP07J_85I_400fKbI]9VdP02
I]84I]42I]86I]42I_800f[bI]5Vd006I]45H]400fK@I]5Vd@02I]4016;AI]1RdFK@0V;A00EVdFK@
HZmVcfK@00=V/009H[5R/6:`HZmR/6:aG[5R/F;A00AR/@AR/0AR[`=RS`03HY1R/5jA00ANT004GXmN
SV:=HXh9GXh3GXl01Ei_GXmNSUj>GVd00ei^00IJKUZ?FViNSUj=GVd2FVh01UY]GVeNKEY/FVeJKP9J
K`03FViJKEY[009JK09JK@9JC@03FViJKEY]009JK004FTeJCUY=FTd4ET/5ET`00eI=ETaFC004ET`0
0eI;ETaFC002ETd2ER`01EI=ERaB;EH/DR`00UH[00AB:e8/DR]>;09B;0EB:`9B;09B:`E>:`9B:`9>
2`I>:`05DRYB2e8<CPa>2`01BPd00003220<80`P00888@88@@888@05220<@0a1344<8@0222403@@Q
224<8@`Q200400P07891YeZ?HZmNSeY_00AJL004GW5NL5i`GW04GY04GY400ej@GXmNT006GY4016:?
GXmR[ejA0Uja015NTF:AGY5NT6:?HXeVRei8FLMEQEVTFLEIYUW5GLEMiUh500AMiPAN1`9N2003GPUM
jEgX009Mj00^GPQMj5W7DJI9HdU2CHA=ae76CJI9QTV5BFE9I4UUBFI5ATE5@D</XBAR@HMNBUj<FTiN
Sf:_H[1V/6:aGY1W4f:;?BDP@A@P540HPAbQ7:8LXabR8<<L`b338:<256401Qc39<@X`bC37:<HPP<D
HP0368<HXaR200@DPP08688DHQbT:<@/hbC468<HHP8HP`03568<@@`Q008<@@04348<@@a134422240
0`PP3408@@03244722400``P340<800532005@PP320<80P0000401aPCPIVXfkSL^=IhdfSIT1kA7n/
Oleocg]:BNTTPP0220000``Q22488@03224010Q134088@PP0``P010880`P344@HPa1340<@@`Q220<
8A11468DHQ1R56<DQ0@HY00;6:<HY1RT6:@LY23U9>DTiRSU8<DTa@02:>D00bC5:<D`i@02;>D012cV
=BHiAcU80cTW00LiAcUW=DLa1QbT58<DHP0746801AAR68<LaBd6=FP00SUX00XiBCE8=DLiJCUX=DLa
1S4W=BLa9`8a1`04=BLa1S46<@H2<BL2<BP2=DP03CE6;@@]11bT68@DHa1S58@DPaR37:DTaBd4008]
1@04;>DXa2cT<@@3<BD00c4V;@D]1002;@D05c45;@D/i33S=@A5QdVWCLQ5Z45W=@D/aC45=DHiASeV
?FDmI46W@JPmQRcT54000P@000D880@P120480@Q0144800;22088@P0100<82C2?JE>:V;=H_5Rd`03
I]<01FKDJ_AZlf[cJa<00V/D0VlC16lD0flE16lD00A_4f/CJa=[50m[4`M[515[4`EZl`=[4`9Zl`9Z
lP=Zl`08Ja=Zm6[dJ_=ZlVkbKa9Zl`EZlP03J_=ZlV[b00EZlP=Zl@03K_9ZlV[b00MZlP03J_5ZlV[b
00MZlP03J_5ZlV[b00QZlPMVl@QVd@AVl@QVd@03I]1VdFKA00MVd@=Vd0=Vd@EVd005H]5VdFK@I/mR
c`02I]0016KAH]5R/F:a16:`00ER/EjaH]5RdF:`00=R/@=R/005G[1R[V:^HZmR[P04HZl015j?GY1N
T5j?0Uj@00ANSej>HXiRSPMNSP03GXmNSUj?00=NS`0=GXiNSEj=GXeNSUi^GXiNSeZ?FXiNSUj=GVd0
0UY]00=NKEj=GVd00eY]0eY^00IJKEi[GVaNK5Y]GV`2FVd00eY=FTaJK@02FV`01EY]FTeJCEY=ET/0
0UY=45I<1EI=00AF;58]ERaF;09B:`03ER]B:e8[00]B:`9>:`EB:`A>2`A>:`9B:P04DP]B;4h;CPX1
CP`00003240<80`P0088@@888@04244<@@a036023444224010Q122488@PP0PP000DLXT6WEXmN[ej?
00=JL0=JL@03FW1NT5j@00ANT0ANT@03GY1NSej@00INT@07HXmNT6:`G[5NTEjaGY400f:a00MR[f:>
HXaNBUWXEJEMY002FJD2GLD6GNH6GPL04Uh8GPMN25gXGNMMj5WXELM=QTUTBD=AY56VDJE=QDETADA5
I099I@0IBHM5ATUV@D@/XB10?FIRJEj<FTmNSf:_H[1V/F:aG[5Vlf9/@FLXHA@0520HPAbQ7:800QbS
0b3300LLXQR2688L`b349<<P``0268801AbS7:@LY1RT6:<00QB200DDHQB2588HXQRS008LY0047:<H
PQQR78<268<256800a1S368@HP024445344010`Q2448@@Q12`a100D<@0`P340<@@aQ008<@@0F3204
00@0000<02S0CN=ZY6jRHR1V@6jPNdIo[Wn_Ok5VR3eV868@0110344322401@Q12408@@Q122400P`P
00P<@111568DPaRS7:DLa1bT0QRT11bT00PPaAc58>HY1bdW;BP]9bd60RSV00L]1RdW<DLaB357=DPe
:002=BL01SE7>BLe9cU8?FXiJ@8eB@05>FTiJSeZ>FTiB@02>DP2>FP00c469@LHQ00446803A1Q468@
HQ1R568DPac5;@HaB34W>DPeJCUZ008mRP03=DLe9c4W008a9`05;BLa1c47<BL]1P02<@H2<BL2<BP0
1S59=DTe9RcU9<@DHP8@@P0?46<DPaB358<LYBCU?JY:3Sf9=BL/aBRR=B@a9S46008]9P@]1P0>;@Da
1C45=@E1ITVXCJM9QTEV=>@XXbRT;<@`i08a1007=B@e@cE5=BDXa1bS20000P@05P@P00X880PQ3248
00`P9<<iI4h;I/eW4`9Vd`03I]AVm6[d009Zm0A[5004KaA_4flDKaD2Ka@2KaD6Ka@2Ja<016/DJa=[
4f/C0f/D0f/C0f/D0f/C2F/D46/C00=Zlf/CJa<00f/C0f[c0V[b16[c0f[d00=Zlf[bJ_800flB0f[b
00AZlf[bJ_9^lPEZlP=Zl@UZlP03J_5ZlV[b009ZlP=Zl`EZlP03J_=ZlV[b00AZlP05I_5VlVKbI_9V
l@03I_85I]42I_42I_800fKaI]5Vd@07I]400fKBI]5Vd@08I]400fK@I]5Vd002I]400f;AI]5Vd@03
I]001f:aH]5Vd6K@H]5Rd6;A00AR/@03H[1RdF;@009Rd@07G[5RdF:aH[1R/F:`H[400f:`00=N/5j_
HZl00f:_00IN/6:_HZmR[ej@GXl5GY02GXl00ej>HZiNSP04GXh015j?GXiNSUj>0ej?0Uj>00ANSEj>
GXiJKP9JS`03FXiNSUj=00=NSP9NK@QJK@9NK008GV]NK5i<GVaNC5i/FVaFK@9JK0AJC@03FTaJCEI<
00YFC0=FC@03ETaFCEI<009FC@EBC@9BC09B;003DR]B;58/00MB:`04ER]B;58/CP`2CR/3DR/2CR/5
CP/3CR/01U8ZCPY>2e8<CP]B2P5B300000P8@0`P340<@0Q0120880Q00Q1Q00D@H0a0344<@@Q100<8
8@0=24488@PP204401AQ?HEBKej]GViJKeY>FVl00eY`00ENKeY`GW1NT5j?009NT0ANT@=NT0ENT@9R
S`9NT004GY5NT5jAH[42HY002F:?IZiRSF:=GTUN1eVUGLEIa@02GLD2GLH3GNH4GNL2GPH015h7GPIN
1UgV15gW00QMj5W6CHE9I4U2EJ=EaUG50e6V011=YTfWBHI5IdE7AFM1ABbQ840mA5i8FTYJCUj>HZmR
/09R/@0:H]9VlfZ`@HT/PA@0520HPQbQ7:827:<012338<@Pa1c4123300LPXb2R8:<X`bcS:>@Pa002
68<256801A11588DHARR68<00QRS00<LXaR268400aR20QB300DDHa1S468@HA11014<@@8<@P8<@@8@
@@07468DHQ1R444@@0`P20000Q0P018HH3DPCPEVHVZRK/Ec1G]YOhmkSW<]DNX`haaR540DH@a03242
320010PP2408@@Q10Pa100h<@111568HY23V:@HY1bT69>HY1Rd7<BH]1c470S4W00<aB34X<BP00S4X
0S5800<eAcE8=DL00S4W00DaB3E8=DPe9c4W00<e9`8i9`8e9`HeB009=BPeB3U8>FPeB3E79>LHY112
008@HP0=464@@@a1364@H@a1468HY2ST;BDaAcEX>DP00cE700<eASE7<BH00S4600@]1c4W<BLa9`@a
1P09<BHa9c4W<BP]9bd6:<DHQ1AS008@@@0J468DPaB258<HXac4AN]N/eIaAL`/iRR1<@<a9C46;@La
9Rd7;@H]1bT6:@Da1C4U>BM1I`9=b@05AHLm9BbT;<@XX`02:<@2;>@01S44<@<a12cT68@<8@840003
124480@P01<4800>124880PP320400`08<<iIDh:I/a[4fKdI]=Ve09Vm09Zm0=[509_5003Ka=[56lE
009_5@=_5003Ka=_56lD00=_5003Ja=[56/D00E[50E[4`03JaA[4f/C00=[4`03JaA[4f/D00A[51A[
4`03Ja9[4f/C009Zl`=ZlP9[4P9Zl`9Zm004Ja=Zlf[bJ_82Ka8016[aJ_9ZlV[b0fkb00=_4V[bJ_80
0V[b0V[a0Vka00A_4V[bJ_9Zl`AZlP=Zl@03J_9Zlf[c009Zl`]ZlP9Vl@04I_9ZlVKbI_43I_82I]40
16K`I_5VlF[b0VKa2fKA00=VdVKAI]4016KA2FK@00=RdFJ`I[000fK@00AR/6K@I]1Vd09Rd004H[1R
/F:aH[42H[04H]0016:aH[1R/6:_1V:`0Uj_16:_00IR/6:_GXmNSej`GZl2G[03GY03GXh00f:>GXiN
SP08GXh015j?GXiNKEi]0ej=0UZ=00MJSUj=GXeNSEi]FVeJK004FVd015Y/FV]NK5Y/0ei/00=JK5i/
FV/00ei[00=JJeY/FV`00UY/0UY<00EJK5Y<FTaJC5I;00EFC004FT]JCEY=ET`2ETd;ET`2DT`3DR`0
0e8[DRaB;003DR/0158ZDR]B:e8[0e8/1U8[0Th[1Dh;0Th[00M>:Th:CPY>2e8;CP]B2P01CP`00003
240<@0a1008<@@07244<8@a0468@Pa1Q34001`a100T88@@P1000010P>FABKUj<GVd00Ui_00UNL5Ya
FW1JL5i`FW1NL5j@GXl00Uj@15jA0ej@1EjA0V:?0Uj@0UjA00aN/EjAGY5RT6J?IZmRSV:=GT]N1eFU
FLD2FLH3GLH00egVGNMMi`03GNL01eh7GPIN1Uh7GPEMiUWV009MiP9Mi`0>GNQIaU65BDA9@UFUFNQI
ieh7GNMIadfVBJM9Q`95I`0:@DI1AC31:80mA5hXFTYJCUj?H[03H[402F:bI_AV[dF[;8<D01@P788P
`P027:<01Ac38<@Pi23T8>D00RCT014T`b339<8PPBS3;@@iISUW;>@Pa1R3440D@QAQ688HPabR008L
X`8HX`DHPP8DP`066:@DY1RS568@HA111@a100<<8@a134401@a10`a200X<HPa1348<@A11464DHQbT
8<@DH@8<8009564HXabS880X`3f3DPIRYfkY009gC@0:Mg5c;V9[@HPXXQR3568DHA103242320010Q0
3408@@Q10Pa100D<@11Q588PiBTW008]9P04:@DXiRSV:>H3;@H2;BL00bT7:@HY1`03:@L2;@L00bdW
;BH]9`03;BL2<BP3<BL4=BL3=BP2=DT2=BT2=DP063U8>FPeB34W9>LHY0a1444@HQ1Q344@HPaR464<
@11168<Ta2d4<BLeJ3E7>DLe9P8eAP8a9P8]1P04;@La9S4W<BL3;@H00c46<BLa9`02<BP00bdX:>HP
Y@0368<26:@03AS56<@HXa1Q588]9U9aFY5>;cDW:84a12dV008]9`04<BH]9bd7;@L2;BL02S4V<BLa
9ceWALU>2dFX>@@`aBc50bS400XXi33U<><]12SU8<@D@@P0000800<48A8480<48@0<12080000200L
`cUTCP]VcV/DI_=Zdf[c0V[d0V[c00=Zm6/DJa@00V/D1FlD00=_5FlDKa@01VlD00=[4f/DJa@01F/D
0f/C00=[56/CJa@01F/C1f/D3f/C00=Zlf/CJa<01F/C00AZlV/CJa=Zl`=[4P=Zl`05J_AZlf[cJ_=[
4`02J_801F[cJa=[4f[cJ_800Vkb1f[b0Vkb00=_4f/CJa800f[b0f[a0V/B0f[c00AZlV[cJ_=Zl`iZ
lP04I_9VdVKBI]83I]45I_801FKAI]9VlFKbI_4016KA16KB1FKA0fK@1FKA00ARdF;@H[1R/@EVd0=R
d0IR/0=R/@03H]5Rd6:a00ER/003H[5R/6:`00AR/003HZiR/6:_009R/003G[5N/5j`009N/0INT003
GXiRSUj>009NSP03GXmNSUj>00INSP=NKP05GXiNSEZ=FXeJK@03GVd9FVd015i/FVeJKEY]15Y/00=J
Jei[FV/01EY/1eY<1EI<00=JC5I<ET`00UI<00AFCEI<ETaFC09F;@=FC005ET]FC59<DTaB;003DT/4
DR`2DR/0158ZDR]B:e8[0e8/0e8[0dh[0Th;14X<00=>;4h[CR`00Th/00EB:dh[CP]>2dh:005>3000
00<8@0PP32000PPQ00<<8@`P320020a100`<@0`Q3248@@a234<8010P>D=BCF:;GX`2GVl00ei`FW5N
L@03FW000ei`GVmNSP02GXl01ej@GY5NTEjAGY1NSej@00ANT@9NT004GXmNT5j@GY02H[03HY002FJ?
IZmRSV:>GT]N1eFVEJEEaP02FLH00eg5GLIMiP05GNL01f87HPIR1UgUGNAIaEG4009Ia@0?GLIMaeh7
FLEAQDeTAD=AYUWYGNMIaF7UELE=YTV60099IP0;AFI5ADET=>4/XCe3FRQF:UY=GXmR/003H[402Ejb
I_=R[TW];:@D01@P684PXP037:<01R349<@Ti2CT:@@Ti08Xh`0@:<8PP2RR=BE1Z47:=DHXa1R3568@
@AA2688HXabS7:8668801ARR688HPaR36:<00QB200<DHA1Q44401@a100<<8@PQ344010a100h<HPa2
348<@PaR344<@Q11340@@1AQ6:8LXA100P`P01@LXR33;>8`hRc1<@51HdgVIXI^jFk/HX]JC4G;=BLP
XaR2568@H@a00P`P0PPP00/<@0a1348<@A1P340DHAR18<<U1Bd500LXi@03;>D]1Rd6008Y1`03;@H]
1bd7008]1`8Y1`04;@L]9bdW;BL3<BP4<BL01S4X=BPa:34X<BTe:@8eB@<e:@8eB00==DLaAbT68>HH
Q0`Q320<@A11348<HPa246400Pa100LDPR33;@@eASUX>DLeAP03=BD2<BH2;@H012dV<BHaAc4W0bd6
00/a1RdW<@La234X;@TTiR357:DLY1bS008HX`0<5:<HXaRS588@HAb3>DMJKeIa?HT/XS450bdW0S4W
00la9RdW;BH]9S4V<BPa9cU7AJU:2dFX>BDe1BcU;<@00bS40bST00DY1AbT568800@0008880/48003
220480@P00848004220480@P1202124030PQ22040000100LXSUUDRaVcfLCI]9ZlPAZl`03J_9Zlf[c
00=[50a_5006Kc=_56lCKaA[4flD1FlC00E[4flCKaA_4flD009[4`=_4`9[4`9[5003JaE_5F/D00M_
4`I[4`=_4`A[4`=_4`9ZlP9Zl`05J_9ZlF/BJa=Zl`02Ja<3J_<3J_82J_<2Ja<:J_82K_8016[bJ_=Z
lV[b1F[a00=[4VlBJ_<00V[c0f[b0V[c1V[b0V[a16[b00=VlVKBI]800VKB00=VdFKBI]801VKB00AV
lVKaI_5Vl0AVd@MVdP9Vd@=Vd0EVd@03I]1R[fK?00IVd0ER/09Rd09R/0=R/@eR/003HZmR/6:_00=R
[`=R/004G[5R/6:`GXl5GY001Uj?GXiNSUj^HZiNS`9NSP03GXmNSUj>00MNSP0;GXeJSEi]GVeNK5i]
GVaNKEi^FViNKP04FVh01EY]GVaNKEi]FVd015Y/0eY[1UY/1UY;00AFBeI:ETaJ:`IFC008ETeFC5I<
ETaFCEH]ETaF:`=FB`9BB`05ET]BBeI:DT]BC003DR`2DR/00e8ZDR]B:`02DR/2DR`5DR/00dh;CRa>
2`05CR`02Dh[CRa>;4h[DR]>:e8[CPYB2@01DP`00003240880PP00<88@888006348<@@PQ220<@@aQ
10a10P`Q00d<@PaS320<03D2CRaRREi[GXmNL5iaFY5NT002FW0015Y_GVmNKei^0Uj?00=NT5jAGY40
0UjA00=NT5jAGY4015jA0ej@00ENSf:?HXmRT6:?00=RT09R/00;HXiNK5h8EJMIaUG7FLIIaeW6GLIM
iP04GNL01f7VHPMR1F85HNAMi5G5009AY00;FLIIaeWWFNIIaEFUDHE5A4V7ELMQiP02GL@075FVCHE9
ITUWBFI5ITE5BHHdhRR0>B9F9eI;FTiNT5j`H]5RdV:bG[9NdV;ACS0/YA@0520DHAbR0QbS00@La2CT
:><Y0`8Y100<:@<XhbSS;<8TP2RP>DE5b47:=FL]1AbS0QR30QbT00DLa1bS788HPQAR00<DPP04688H
XQRS6:<268<258801AAR468@HPa136800Pa21`a100<<@PaR368010aR00@<H@a1464@H@8DH@0C560<
00`P440P`S43=D8e8cD2<<0dh3dQAHAAj4h9BP]1Z34V9:<00QAR00D@HQ11320@@0a100<<@0<<@@06
440<@1AP684LXbCU0RST00HXiBCU:>HY1RT5:@H2;@H012T5:@LY1Rd60Rd71Bd600@]9c4W<BLa9`8a
:003<@Pa9c4X008a:004<BLa:3DX=DT2=BT013DX<BPe:CDY0cE801Da9bT67<HHY@a2220<8111464@
HPaR468<@@a0440LXbST=DHeIcUX=BH00cDU00<e9S4V;BL00S4W00Da9S57<BLa9bd6008]1`0L;@Pa
1bd8;BPY22CV9<DPaAbT7:<HXaB258<DXaBR6:<DPQQR:81B;V;dBNddi2c5;BP]9bdX;BL2<BL042dW
;BHa9bdW;BP]1cU7?JU1bcf8>BHa1Bc4::@PXbBT0RS400TXiBCU:@LLa1AR20488@PP22402P@P1`PP
0`@P0`@Q00T4@@PQ000001AQ>F=>;6:_Ja@00VKc16[c00=ZlV[cJa<00V/D0VlD0VlE0Vld1VlD0Vld
00=_5FlDKa@00VlD0flC00=_56ldKc@016lD00=[4flDKaD00VlD00M[56/CJaA_56/DKaE_5008Ka<5
Ja<00flCKa9_4`04Ja<2Ka<026lBKa=_4flBJ_9_4VlAKa83J_801F/DJ_=[4f/CKa800V[c2F/C00=Z
lf[bJ_8026[b0V[a00EZlV/BJ_9[4Vkb00IZlP=Zl`EZlP9Zl@=ZlP03I_5VlVKb00=VdP=Vd@MVdPEV
d@UVdP9Vd@03I]1VdFKA00UVd@ARd@03H[1V[f:`009R/0=Rd003H[1V/6:`009R/@AR/003H[5R/6:a
00ER/09R[`03H[1R[f:_009R[`=R/005G[5R/6:`H[1RT003GXl2GY001Ej?GXiNSUj>GXl01ej>00=N
Sej>GXl00Ui_00UNKEZ>GVeNSEi/GVeNK5i]GVh00UY^0UY]0eY^0UY]1eY/0eY]1UY/1EY;00EFBeY;
FR]J:eY<00AFC0=FC@9FC003ETeF;EI<00AFB`IBB`EB;0IB:`03DRaB:e8/00AB:`03CP]>:dh;009>
:`=>;003CR]>;4h/00A>:`5B:`5B2P5>3@0000<8@@PP22001PPQ00<8@@PQ34400`aQ0Pa100d880@0
220<@@aR320<02c1BLQRR5j:GXiNK`02FW000ej?GVmJKP02FVh015i_GViNSej?1Uj@1UjA0ej@1F:?
00URT6:aH[1V/6:?HXiRKEhYFNP01UW600=MaUgWGNL00UgW00aN1f85HPER15gTGL=Ea4V4CHAEaUWW
GNH2FLD01E6UDHE9IDUWDLL00f7U0UFV00m=QdV7BFI9IDE5BFHdhRRP>B5F9eI:FTiNSf;@I]400V;B
00mN/Ej`H]1FLC3W500D81AQ68<La23T9>@Y0bd3;@@00Rd300h/hbcR;@8X`C3P>D95aU9:BPXiIc45
:<@PY1bT0QbS00<Pa22R78800QR200@DPQAR464DH@8HPP8LX`036:<HPaB200<@HP8<@@H<HP03364<
@@PQ00<<@@8<@P@@HP8@H@8DH@06544<01108<8a8SUR0Sf401M1I3e3>@4i8Se3?D8i8S42;@<T`aR3
544<8A12324<@A1Q488@HA1P360<@0a1008<@007320DH1QP7:<Pi2ST9>@00RCU00@Y1BdV:@DTi@<X
i@DY1@8Xi@03:>@/iBd6008]9P<a9`04<@P]1c4X<BP4<BL00c47<BLa:002<BP03S4W=BPa:3E9<DPe
B358;BLPiQRU46<<@@a0444246402`aQ368@@@a0440LXbST=DDeASE7<BH00cDU00<a9S4W;BL00c4V
00<a9c4V<BH00bd701T]234W<@L]9bT7:@HTi2C37<<LXaR3588DPaB25:8HXQR3320LPD7=IaI:3S34
::@]:002;BL01C4W;BLa9RdW<BH00RdW00/]:2d7=DLiIcV8>FLeAS45;>@Xa2BS008Ta006:<@XiBCU
:@HLXaA10PP00`PP1`@P00<880@P22001`PP0P@P0P@Q00<4@@A222400P0000PDH3U1CR]Rcf[cI]9V
lf[c0V[b00IZlf[bJ_=[4f/DJaD3Ka@00flEKcE_=007Ka@01FlCKaA_4flDKa<00VlD00=_4flDKa@0
1VlD00=_4f/CJa<00flD0VlC0V/C0VlD16lC0VlB0flC00E[4flCJa=_4Vkb009_4PA[4`03Ja9_4VlB
009_4`=_4P9_4@03K_9ZlV/C00=[4`04Ja9_4f[cJ_<2J_82J_<2J_801FlBK_9_4V[bK_800V[b0VlB
1F[b0f[a0f[b00AZlF[bJ_9Zl`EZlP9Zl@AZlP9Zl@9ZlP05I_5ZlF[AJ]5VlP02I]83I]44I]86I]42
I_4016KbI]9VdVKA16KB0VKA16K@1VKA0VK@0VKA00=RdF:aH[404F:`0f:a1F:`1f:_00UNSf:`H[1N
/6:`GZmNSf:>GXh01Ej?1Ej>0Uj=0Uj>0Uj=00MNSUj?GXmNSeY^GVeNSP03GXd015i]GVaNKEY]0UY^
00=JKEY^FVh00UY^00EJK5Y]FV]JJei/00AJK0=JK@03FVaJJeY/009JK0AJB`AJBP9JB`AFC09FB`AF
C09F;@03ETaFBeI;009FB`=BB`AB:`EB;0YB:`03CR]B:e8[00=B:`05CR]>;4h/CRa>:`02CR`01Th<
CR]B:e8[CR]>2P5B300000<8@@PQ22400PQ10PQ20PaR00X<@Pa1364<HA22468@H@a13208808<@@08
368<8110<>59af:7GXUNKPANK`03GXmNT5j@009NT0=NS`=NT09NS`03GY1NTEjA009NT@03GY9NTEjA
00=NT00=HXmNT5j@GY1N/F:aHY5R/6:?HXiNKEXZFNT00UWW0UW700EIaUWWGLMMiegV009Mi`0;GPMR
1V8UHPAMaEW4DJE9PdESCJIEi`02FNH01UW6DJI=QdEVAHQAa`9R1P0@GLMEYe6WCHM=QTUVBFE5AD55
>B@/`3U2ERQJBeY?GXl2I]403F;AH[9R/EZ?G[1JTSD8620D81AR7:<PaBCT008]9@<a9@0G<@@a0c43
<B<i@T5RBLENRfJZDR`iJ3DW;>@Xa2S39<<P`b2S8:8LPAb26:<HPP0258801aAQ688LPRC38<@HY1R3
00<DP`0346<@HPaS00H@H`@<HP04464<811R368646801aAR588@@0`P8:4a8SUQ008mQ0=1Q@0B@FE1
QDF3@D4m8SDS;@<Ta1bT420<00`P444@HQ235:<@HQ110Pa000@<@@a0320<808DH@057:<PiBT5:BHY
1P02:>H00bCV:>DY1P02:@D01bSU9<DTaBSU:@H]1bd5008/i@03:@D]1RT600<]1P8]1`<]9`8a1P@a
9`8a:00>=BPa:C59<DTaBS59=FTa9bdV9@LHYA1R444@HP<@H@8@HP09440<@0a0688Ta34T<BHaAS57
008a9P0;<BDa9bdW;BL]9S46<BLaAc4V;@L]1P03;@L4;BL01Rd6:@<Xhac37:<DH@8DHP0<58<DXa1Q
220<Hb47@RiNe4G_<>HXa2dX0S4W00<]9bdX;BP012dW0RdX00PaB3E8=FLiISE6<@@/i2c30bC40RST
00<XiBCU7:<00P`P00<800PP22400`@Q00<480@Q12000P@P2PPP00<480@Q12400P@Q00P4@@PQ0000
01R0>F1>:f:]0fKc00=ZlV[cJ_<00f[c00=[4f/EJaD00VlD0VlE0fle0Vld1flD00=_5FlDKaD00VlD
00I_4flDKaA_56leKc@2Ka@00flCKaA_5003Ja@016lCKaA[4f/C0V/D00A_4flDKaA_50=_4`9_5009
JaA[4f/CKa=_4VlCJa=_4f/C00=_4`03Ka9_4flC00M_4P03Ka=[4f/C00=[4`03Ka9Zlf[c009Zl`EZ
lP9_4P9Zl`AZlP03J_=ZlV[c00MZlP03J_=ZlV[b00=ZlP9Zl@9ZlP03J_5ZlV[b00QZlP04J_5ZdF[A
I_82I]800fKAI]9VdP07I]800fKAI]9Vl@03I_800fKBI]5Vd@05I]87I]402FKBI]5VdFKAI]1VdF;A
H]1Rd@02H[42H]0?H[000f:aH[1R/002H[02HZl00f:?HZmR[`03H[07G[001Ej_GXmNSV:>HXl00Uj?
00MNSUj?GXmNSej>GXmNSP02GXd3GXh00ej=GXiNSP02GXh015j?GXiNSUi^0Uj=0Uj>00=NKeY^FVh0
25Y^0UY/00=NK5Y]FVd00UY]0UY^00EJKEY/FV]JK5Y[00AJC003FT]FC5I;009FB`AFC005ETeFC5I<
ETaFC@06ET`015I;ETaFC5I;0U9;1E8[00=B;58[ER/02E8[00=BBe8[CR/01U8[00E>:dh/CRa>;4h[
00E>;09>305B2P5>30000`Q11@Q200<<@PaR36400PaQ00<<H0aQ44400PaQ0PaR0Pa100P@@1QQ<@95
af9XGXUNSUi_0ei^0Uj>35j?00=NT5jAGY401ejA00=RT5jAGY400UjA00QRTF:@HY1RSfJ>HVeN:egX
15W700EIiUWWFNMMiUh600=N1`06HPIN1F84FLEEYDV40TUS015=YUG6FNEIaEW6DJM9QdE5BHMEaf86
HNMEadf7AFI9QTV50099I@0<ADA5ISe5:80a04h7ET]JCej?I]1V/6KA0V:a00aR/5j?FW4i:1`P544H
HQbT9>@]8bdT<DD3<BD05C4T<@@]1342@F95PTgUHXUbiU8Z?FPe9S45;@@`hR328:8LPQQQ784LPP02
6:<031R258<DPaR2784Ti23U7:@HPaAR56<@HP8@H`<<H`H@H`05468<HPa0340<@@0236800a1R46<@
P`0246<030a1440D@1b0;<11PDG2@J@mQ3US>F@mI08mH`0A@H=5QD5U?FDe92cS9<<DHP`1300@HQ23
6:@@Pa1R444<@00232000`a0440@@00256401aRS8<@U1RTV:@HPiQc6008PaP0;8>DY1BT58<@LY1c5
8<H]1S47<@H]1@02;@H01Rd5:@DXiBT5;@HY1P@]1P@a1P03<BHa1c4X008a:003<BTa:34X008aB@05
=DPa9RdU:@HHY@02344546402A1P340<@110564PXc4S<DDa9P02;BH01S46<BHa9c4W;BL]9P<]1P03
;BH]1Rd600<]1P8a9P03<@Ha9RdU008]0`0@8<<HPQ10444@HQAQ444801126:DaZe[@H_E5l347<@H2
<BL00bdW;BP]1`02:@L3;@L04bdW<DPaB3EX=FLiISE5=B@/hbc39:@TYBC4;><a934U:@HLXa100088
00<88004124880@P1244120:22022243244020Q0000401bQ@H1BBfK<J_82I_<00f[bJ_=Zl`03J_<0
1F/CJaA_56lEKc@016le0Vld0flD1fld00E_=FlDKaA_4fld009_5003KcEc=6lc00Q_4`E_5007Ka=_
56lDKaA_4flDKa<00VlD00=[56/CJa<026lC00=_4VlCKa<00flC1flB1F/C16[c0V[b16[c00=ZlV[c
J_8016[b00IZlf[bJ_9ZlV[cJ_44J_82K_82K_42J_42J_83J_4016[bJ_5ZlFKb0VKc00EZlf[bJ_9Z
lV[a009Zd@03I_5ZdFKA00=Vd@MVdP06I]5VdVKAI]9VlVKB1FKA00=VdVKAI]800fKB1fKA00AVd6J`
I[1Rd@=Vd0=Rd0AR/003H[5R/6:a009R/0AR[`9R/003HZmV[V;?00MR[PAR/09N/@05G[1N[ej`GZmN
/002GXl00f:?HXiNSP03GXh00ej?GXiNS`02GXh2GXd3GXh5GXd4GXh015j=GXaNKUi^1EY^00=JKEY^
FVh00eY^00=JKEY/FV/00UY]0UY^0UY]00=JK5Y[FV/00UY[00IJK5Y<FVaJC5Y;FT`3FTd3ETd00eI;
ETaFB`05ET`3ET/2ET`2ETd2ET/4DT/3DR/5DRX3DR/2DRX00eHZDRYB:P02DRX2DR/014h[DR]B:e8[
14h[14h/0Th<0E8;0E8Z0Dh<00001PQ13448@@Q13448@@<8@P<<HP8<H@8@H@04468<HPaQ36823440
2110540X`T65HVQRZUj`GY02FVl00ei_GXmNSP0<GXl2GY08GY400f:AGY5NT@02GY403F:@HY5RT6J?
IZiRKUh[GNMIaeW8FLMIieWV00=Ii`EN1`0UGPIMi5G5BHA5@dUTAD=AYEG7FNIIaEW6CLM5IT4TAFMA
aegVFLIAYTV5BFI9QTf6BHI9IDE4@F@i9BRQ:<55ieH/ETiNT6:`I[000VJa00mV/6:_HXeBCcT7720D
81QQ8<<Y1355<DHeICU5=DD00S4U01H]12S3;>4e83e1@H=>1f98CNPmAcDU<BD]0c3R9:8PXQb1788T
XQbR6:<HP`8HX`0<58<DHQR18>@Y9abU568@@@a148<DY1B30a2300<@HPaR58<00QB300<@Ha2348<0
111R00@@Pa1S46<@P`8@H`0@344801R1;<4i84W4BLE1YCUT=D<e8S42;@4a8SeS@JH2AJH03SeT=@4/
`QR3324<01AR58<DXaBT468<@110340234401a11440DHAAQ6:8HXabT008La@8HY@097:DHY1RT6:@H
PaAR58<HY1bT008LY@<La@8Pa@049>DXi2T5:@D3:@H4;@H2;@L00c4W;BL]9`02<BP01C4Y<BPa234X
<DT00SE700D]1BCV68@<8A1Q00D@HP8@H@8@@005444LXbd4<DD]9@02<BH00c4W<BHa9P02;@L9;@H0
0bdV<BHa9P02<@H04bd5;@@Xhb3468<DPaAR468@@0`0320Pa4X`KiUcUV/f?Hhe1cDV008a1P05;@L]
1RT6:@HTiP029@D012T5;@H]9c580SEY00TiIcE6<@D/iBS49:@PY2BT;>@00SE500@iIb34564<80D8
80H480T880@88@@8@@8000058:91PU9;I^aVl@02I_<016[cJ_AZlf[c0V[d00A[4flDKaA_5@I_=@04
KaE_56lDKcD3Kc@5KcD036lDKcA_<fldKaA_5FlDKcAc<flcKa=_50E_4`E_5003Ka=_56lD009_4`M_
50=_4`09Ja=_4flCKa=[4flCJa=_4f/C00A_4`I_4P=[4`EZl`03J_9Zlf[c00AZl`IZlP03J_=ZlV[c
009ZlP03J_5ZlV[b009ZlP03K_5ZlFka00=^l@05J_9ZlF[aJ_5ZlP03J_401F[bI_=VlfKcJ_<00f[b
00AZdV[AI_5Vd@9Zd@9Vd@9VlP]VdPMVd@EVdP0:I]5VdVKAI]5V/FKAI[1Vd6J`H]43I]02H]0016;A
H[5R/6:`0f:a0f:`16:_0V:`00ER[fJ_IZmR[V:_00=R[P9R[`AR/003G[5N/5ja009R/004GZmN/5j_
GZl2GXl2HXh00ej>HXiRSP02GXh3GXl4GXh01Ej=GXiNSUj>GXd015j>00ENSEj<GViNKUY^009JK`9J
KP=JK@EJKP06FVaJKEY^FViJKEI=0UY]0eY/00QJJeY]FVaJCEY<FT]JC5Y=1EI=0UI<00AFBeI<ET]F
C@9FC0=FB`9FC09FC@03ETaFBeI;009BB`IB:`03DRYF:U8[00EB:`03ERYFBU8Z00=B:`03CR]>;4h[
00=>:`9B:`04CR]>;4h/CR`2CR/00e8;CP]B2P01DP`00006340<80a1344<@0`P0Pa10PQ10Pa1111Q
00l<@@a0360<H@aR340<810P984mQ6:8HZYJL5Z@FVl00ei_0ej>35j?00=NT5jAGY400UjA00ANT5jA
GY5RT0=NT@03GY1RSV:?009VS`09IZiRKF8ZGNMMaeW8FLMIieWV009Ii`04GNMN1Uh6GPH2GPL02Uh6
GNAEaDUUAFE18dETCJEEaUW50UgV01QAadEV@B=1AE6VFNEIiUW5ELIAYTfVCJE=QTUUAFA5HcTU::<`
hdG8DRaJCEi_HY02I[42I[0036J]IZ]B;CT7720@81A09<<]AC5V=FLeIP8iA@0B<BDa92d4:<<XXBc0
=@0i@DFUCNM5YcTU<><a12d3<@4X`R2R0R2S00<P`b2R6:800QRS00dHPQ1R444HPQc39BLLaA1R348@
Ha234:@@X`025:@448<00a1R48<DP`0258<011B2488@PQ220QB20Q2300`@H`aS448@@231>B15PTW5
@J<i@cDS<B<2;@804BBQ9<0iHdW6CNI9aTFT?D8a0B34328800`Q468DPQB346800a110`a100<@@A1Q
46400QB200PHXQB358<DPQ1R448@@@a20a1100@@@Q11344@@@8DHP0:468DHQRS7:@La2359>DXiBT6
;@H2:@H00bd6;@D]1P02;@L00c46;BLa9`02<BP3<@P2<BP01CE7<@D/i23568@00QAR1Q1R0Q1Q0P`P
00PHPRSS<B@a92d4<@D]1C4V0RdV1Rd600D]9S4V<@Ha9RdV008a9P07<@D]1Rd6;@DXhb356:@00QbT
018LaB2T88<TY3V9JcAkngohGY4eC2c5=BD/i2cU:>DXi2C48<@29>D00bCT:@<]1002;BH043E8=FPi
IcDV;>@Xa2BT8:@LXb2S9<@a1CE5;BHPi1AP10`P0`PP0P@P00<48@Q2120010PP00L800@02208@0a0
22088@02320224002`Q110000000760mH58XI/YZl6/CI_@00V[d00UZlfKDI_AZm6[bJa=_4flDKc@0
1Fle0flD00A_=FldKcA_=0E_=@05KcA_<flcKcA_4`04Ka@00flCKa9_4`03Ka<00flDKa=_5002Ka@0
0flCKaA_4`04Ka<2Ka@00flCKaA_5002Ka<00flBKa=_4`04Ka<3Ja<00flCJa=_4`02Ka<016lBK_5^
lVlA0Vkb00=_4VkbJ_<00V/C16[c00A[4V[bJ_9Zl`9[4`04J_=ZlV[bJ_82J_<00f[bJ_=ZlP03J_84
J_400fkaJ_9^l@02K_43J_48J_8016KbI_=VlfKc0V[b0V[B00EZlF[AJ]5ZdF[`00=Vd@04I_5VlVKB
I]82I]44I]800fKbI]9Vd@06I]44I]82I]42I]83I]4016K@I[1V/6;A0fK@0V;@00IRdF:aH[5R/6:a
H]42H[43H[0026:_HZiV[f:_H[1R[fJ^HZd2IZd3HZd016:^HZmR[f:_0V:`0ej`0ej_0ej^00=R[Uj?
HXh016:>0Uj?1Uj>0Uj=00=NSUi]GVd00ej=00MNKEj=GXeNS5i/GVeJKP02FVl025Y^FVeJKEY]GVaJ
K5Y^FVl2FVh2FV`6FVd00eY/EVeJJ`02FV/01UY/FTeJC5Y;FTaJB`9FC003ETeFC5I<009FC003ET]F
C5I<00=FB`04ETYFBeI;ET`3ETd015I<ET]BBe9;1E8[158Z00QF:U8[DR]B:e8ZERYFBUH[158[00=>
:dh/CR/00Th[0U8[00=>2dh[CR/00dh[00A>2dh:CP]>2P5>300000<<@0`P34400Pa100<<80a12680
0PaR0`a100<@HARS34400P`P00/<H@aR368<@@P0300TXSf4GVUNZeI_009JK`=JL003GXmNKei_009J
K`=NT004GXmJT5j@FY09GY03GY4015j@GY5NTEj@0V:?0VJ?00AVSF9/HRYMi`AIa`9Ii`03GNQMiegW
009Mi`9N1`04FPMMiEW6EJH2DJL2ELL075W7GNIMiUgVELM5IT4TADE=YEgTGNEMiUgWGNIIie6WBHI9
IDUTAF<m9BRT<>=5b58/FTiNKf:@0fJa025ZdF[?J^eF;CTW724@8AQR:<<aIcF7>JXiQcUV>FDa9BSS
9>@X`bc2=@4m8d5TAJIAj4W8@FLe9344;@<a0RS39<@00R3400<Pi2337:<00QRS0QB200H@HaB37<@L
iQSU7<D26>H011d67BLM9adW0Qd700DLiQS66:DDY1B3008@HP<DX`0358<@PaB2008DPP0658<@HPPQ
344L`cDQ0TFT01M9aSeS=B<a92T4:>@HXab28:4iHdWXCPMB1dgUAH@i@bC468@<8@PP344DPQ1R00<@
H@03444<@Q1R00D@HP03588DHQ11008<@@8@HP8@@@8@H@03444@HA11008@@@09320@8111564DHQR3
7:@La1c5008Ti@04:>@Y1BT6:@L2;@H6;@L00bd8;@La1`03<@L01CDV<@D/a22T56<00Q110a1R00D<
@A1Q468@HA10008<8005420PXbC4;@</i003;@D4;@H01Bd7;BHa9S4W<BH00c4600@]9S4V<BH]9P8]
1P8]1@<Xi@0=;@Ha9cE7<@DeB4X_IcE[N5Z`@L`]1bS4;@@00RSU12C400TTiBCT9>@XhbST:@D]1S4V
<BL00S4600d/aBBT78@LPaQR664HPaRS6:8HXaR1200<00042003100:0002100;00001A00?D5=j6K;
J_400V/D1V[d00=_4flDKc@02fle0fld1Fle0Vld00=_<fldKc<00flD16lC00=_56lCKa<00VlC16lD
00=_=6lDKa<00flC1FlD00=_4f/CKa<01FlC00E[4f/DJa=[4flC009[4`9_4`07Ka9^lVkbK_5^lVlB
Ka<00VlB0f[c00E[4f[bJ_9ZlV[c00A[4`QZl`9ZlP9Zl`=ZlP08K_9_4VlCKa9^lF[aJ_9Zl@9ZlP03
J_=ZlV[c00EZlP05J_=VlfKcJ]=VdP02J]83J]42J_4016KaI]5VlFKa0fKb00=VdFKBI]400VKA00=V
dVKAI]400VKA00=Vd6KAI]400VKA16KB0VKA00=VdVKAI]4016KA1V;A00ERd6;AH[5R/F:`00=R/@IR
/09R[`05H[1R[fJ^HXiV[P04HZh016:_H[1R/6:`0V:_1ej`0Uj_00=N[Uj_GXl00f:>00=NSUj?GXl0
0ej?1Uj>0Ui]0Uj>1Ej=00=NK5i]FVh00UY_00MJKUY]FVeJKEi/FVeJKP02FVl00eY^FVaJK003FVd3
EVh2EVd015I/FVaJK5Y/0UY<00EJBeY<FTaJC5Y=009FC@=FC004ET]FC5I<ET`2ET/00eI:ET]FC002
ET`2ETd015I;DT]BBe9;3U8[00=F:e8[ER/0158[0Th/00A>:dh/CRa>;09>:`9>;09>:`A:2`5>2`5>
3@0000@<H0`P34088@8880052248@@a1368<@@02324634400`Q1344<@@02200011QR=D=JJEj/0eY_
0UY`00=NT5i`GW000ei`0ej@00=NSej@GY400ejA0Uj@0ej?0Uj@00mNTEjBGY5RSej@GY5NT6:>HXmR
T6J?IZiRK69:GNL00UW700mIaUW7FLMMaegWGLMMaUgWGNIIieWVFNMIiEW5FLH00eW700=MiegVHPH0
0Ug502eAYTV6ADA5I4fTGL=Qi684FLEIa56UCHI9QDUTAFA5Hd56;<D`hdWYETaNKV:@H[5V/FKBI[5Z
dF[?J/a>;CD7724@8AQR:<<eIT79@NY1bSV7>HHa9Bd5;>@00RcS018e8ce4BJMB2Ei9ER]9b3U5=BD]
0c4Q:><Ta234:>DTi1c36:836:<01ART5:@HY1SU7@H00R4V00TQ9bEY:HXYRbV:9FXYJRV::FT00RE7
00DQ1Qc558@DPaBS00<DXP035:<DPQAQ008DPP0L444@@1AR;@=9`dW5BLI5YCe4<@</hbS49<@LXbC3
<B<iHdFUCNIF1EX4CNI1QC458<DHQ1AR44464646468246433446444010a0464@HA100P`P1A1000/@
HAB258<HXac48<DXi2SU;@HY1Rd5008]1P8XiP03;>HXiRcV00<a1`09<@Ha1C4V<@Ha1BS47:@D@@`P
0088808<8088800=340@HA10320<00`P564Pa2SS;>@]1Bd4<@D00S4U0S4V0S461C4V00<a1RdV<BL0
0S4W01Da1Rd6;@H]1Rd5:>D/iC4W>HU1ZD6Z?HXiRCg;?L`mZCE7<@H]1BcS:<@00bC400<T`b338<<0
0bC30RC400`TaBSU;>H/aBS578<D8A0Q420<00P0100Q000020@000000210?FAJ:6J[Ja82Ja<2Ja@0
0f/EJ_AZm002Ka@7KcD00g<eKcE_=@03KcD6Kc@2KcD2Kc@00flcKcA_<`02Kc@2Ka@8Ka<5Ka@4Ka<4
Ka@:Ka<00f/CJaA_4`06Ka<4K_8016lBK_9_4VlB0V[b00A[4flBKa9_4PIZlP03J_=ZlV[c00IZl`=Z
lP05J_=^lVkbK_9^l@04J_44J_84J_<6J_8016[cI]=Zdf[C0V[B00=ZdF[bJ_400V[a1fKa00=ZdFKA
I]401fKA0fK@0VKA16KB1fKA00=V/6KAI]401f;A1F;@0f:`0V:a0V:`00ER[f:`HZmR[fJ^009R[PAR
[`9R/0=RS`04HZiN/5j?HZl3H[001ej@GXmR[f:^GZiR[Uj>009RSP=NSPANS`9NSP03GXmNSUj>009N
KP9NSPENS@9NK005GVeJKUY^GXiNK@02FVd00ei/FVeJKP02FVl015Y^FVaJKEY^1EY]15Y/00EJJeY;
FVaJK5Y;00=JC004FTeFCEI=ET`6ET/3ETX00eI;ETaF:`02ET`2ET/2ER/00eI;ER]F:`02ER/>DR/0
1e9;DR]B:e8[CR]B:dh[009>;004CR]>;4h/CR`6CR/1CPX1CPd00003460@80a000<<@@032208@@a1
008<@@062248@@a1220<@@PP1@a100L800@0320a959;GZaNT002FVl4FW04GW02GY0015jAGY1NT5j@
15jA00ENT5j?GXmNSej@009NT@04GY9NTEj@HY02GY002F:?HY1RT6:?IZmV[V9:GPMIa`03FLH3FLL0
0eg7GLIMa`03FNL01eGWELIEaEW5HPMR1Uh7009Mi`0LGNIMaUW5EJI9IT4RBF=AXegSFNAMheg4FLAA
YTEUBFA9QDF5AFA1IS34>BE=jEY/GXiRT6JaI[82I]808FKAI]1VcTh^>DPL@@`1444P`c4U?JPmbSfY
>JTeIbdU;@D/i2cU;@De13e5@FI=jE8ZETa1Z3E6<@D]0c43:><Ti@028>D041c47<<HPaRS6:@HXaB3
5:@HiAd67DPQB2EY9H/YZbV:0RV/0RF;00TYS2f/;J`YJRE88@HLiQRT58<00QBS00@DY1BS588DPP@H
PP0J8<<eHdWSCPM5YT65>D</hRS28:<LXb34;@<a93U3?HA5Y5X4GR=B1d65=BDXiQc57:@DHP8@@@03
464@HQ1Q00L@HP<@H@08444@HAAR688HPaR2588HX`8LY0086:<DHQ11440<@110564@H08<@007344@
@AAR588HY2CT:>D00Rd60RdV01<]1bSU:<DXiBd6;@La:34W<@La1S4V<DLa9c4V;>DLY1AR444HP`03
6:@011B368<HPaR30QRS00`HPaRS7:@PaBST:@D]9S4W<BHeAcUX>DP2=BL01CU8>FTiJ3EY=DP00S4W
00@a:3E7<DPa9`8a9P03<BLa9S45008]1@0:<BHeJCV:>FXa:2cU;@H]1BcT:<@2;>@00bS49<@PY002
8:<00b2T8:<Pa0029<@022339<@P`aR37:<TY223544240000``020000007000510001`P0300<00`0
400@81A0008DH004784PXR329<838:804bC4;@H]1RcT<@@e9SU8?FPi9SD5AJQJ9f:;I^m_4f/CKcA_
56lE009_5P9_5@03KcA_=Fle00A_=@06LcEc=7<dLcA_=Fld0fle16ld16le16ld0flD16lC0VlD0VlC
0flD00=_4flDKa@02FlD26lC00=[4f/DKa<01VlC16kb00A[4flCKa9ZlP=Zl`=_4P=_4`03Ka9^lVkb
00=_509_4`03J_=[4f[c00=Zl`04J_9ZlfkbJ_84K_400f[aJ_9ZlP02J_85J_<2J_800f[aJ_9ZlP02
J_<016[bJ]9ZdV[B0f[b00AVlFKbI_9VlPIVl@04J]5VdFKAJ]46I]43I]02I]45I]85I]400f;AI]5R
d@08H]44H]04H[000f:aH[1R/002H[000ej`H[1R[`03HZl2H[02HZl02V:`HXmRSf:`HZmR[Uj`GXmR
Sf:_0V:`00=RT6:?GXl00Uj?0ej>00IR[Uj>GXiNSej@GXl2GY001Ej?GXiNSUj>GXl00Ui_0Uj>00=N
KEj=GXd00Uj=0Ui/00=NKEY^FVh00UY^0Ui]0UY]00EJKUY_FVmJKUY/00=JK@=JC@03FViJKEY]00IJ
K008FT]JC5Y=FTaFCEI^ETeJC@9FB`03ETYFBeI;00EFB`03ETaF:eI<009FC003ET]F:eH[009F:`03
ERYB:e8[00iB:`03CRaB:e8[00A>:`M>;006CR]>2dh;CP]>:dh:0Dh=00001Pa0320@80a0440<@0<<
8003244<@@Q100888@@<@@0A340<@@a1344880P0324a94i:GZaNSUi^GXiJKej@FVmNK`02GXl3GW04
GY001Uj?GY1NTEj@GY5NT0=NS`03GY1NTEjA009NT@9NT003HXmNT6:?009RT005HXmV[fJ_HT]N1`05
FLH3FLL02EW6FNMIieWWELIAaU6VELEMi002GPD00egWGLQIa`02FLL06eW5EJI=ITE3DJAAa5gSFNAR
15WUELEAaU6VCJM9QTF5AFA19CCT?FMF2Ej;GXeRSfJaI[9VdP02I[801FJ`J_1N[dFZ:8800Q0Q00DL
PRC4<B@aASEV008aAP0C<@@/i2S4:<@/iC45=B@iACeV@JI1QcU5<@@X`bd3:><Xi2348<D00Qc400`L
Y1bS6:@HY1B35:<Ha1cU9DLYRRfZ:HX3;J/4:H/032V<;H`]Rc6/<J/]RBU78@DLa1BS488@H@8DPP8D
H@0?688DHQQQ;>8iHdgSBLE1QCUT=B</`B20440DPRST008]0P0<<@4e@SeRDN=N8E85AJHiARcV9>DP
a1AR10`P00@880Q0340<@@8@H@09340800PP340DHAR268<LXac400<Pa0049<@Ti2CT8<D27<@28<@0
42C47<<LXac3688@HA1R68<HY1c4:>DY1Bd5;BHaAc580SE80cU700`iB3U9>DTeBCU8>FTmRSeX=DLa
1RcU<>D2;@D2;@H00bT6;@H]1P02;@H2<BH01Rd6:>DXiBT5;@D]1P8eA`03>DLiJ3UW00<iB003?FPm
RCUY008iJ@8eB@05=DPiJ3E8=BHa9P02<@D01C4U<@D]12cT;>D00Rd600@XiRS59:@TY08TX`<X``04
9:<PXab37:<268802AQR88<XXaaR660LHB1P864LH00364003B10980TP221::8XhRcR:>8X`bcS<@@e
ACUU008iIP03>FM1R4FY0091Z@05ALY9jdh;DRaFB`02GVd00eY^GViJK`02GVl03f9^GXmRSfJ_J]1^
l7<AKa9^d6Z^JZe^kg<AKa9_<P02Kc<2Kc@016leKaE[5FlD16ld1Fle00Ec=6lcKc=_<fld009_=@E_
=0=_=@=_=003Kc=_56lC00I_4`9_50Q_4`9_509_4`M_50=_4`9_5003Ja=_4flC009_4`05Ka9_4flC
Ka=_4P06K_82Ka8016[cK_=^lflB16lC00M_4VkaK_9^lV[bKa9_4`02K_800flBJa=[4`02Ja<00f[c
J_9ZlP02J_82J_401FkaJ_5ZlF[bJ_400f[b16[c0V[b00AZlF[bJ_=Zl`9ZlPEZl@05J_9ZlF[BI]5V
dP02I_43J_800fKaJ]5Vd@03I]43I]02J]03I]04I]44I]85I]400fK@I]5Vd@03H]400f:aH]5Rd006
H]03H[02H[43H[000f;@H[1R[`03HZh2HZl00ej_HZmR/002HXl00f:_H[1R[`03GXl01F:?HZmR[f:?
HXh01Uj>00IR[Uj>GXiNSUj?GY03GXl00ej=GViNSP03FVh00ej>FVeNK@04GXd2GV`00ei]GXiJKP02
FVh4FVd3FVh015Y]FVaJKEY<0UY=00=JKEY=FVd00UY<1eY;00MJC5Y;FTaJCEI^ETeFC002ET/015I:
ET]FBeY<15I;00=FBUH[ET`00UI<00=FBeI:ET/00UH[00=F:U8[DR/02E8[00=>:e8[DR/00U8[00E>
;4h[CRaB:dh[00=>2`=>;005CR]>;4h/CRa>2`02CP`1CP/1DRX1CPd00007340<810P444LY11R4440
0Pa100@<@PaR368<@P8<@@0C368HY@a13448@@a2248880@0444]94hZGXeNSUi]GViJKej@FY400Uj@
00=NL5j@GW000Ui`2Ej@0ej?1ej@00=NSej@HXl00V:@00UR/6:_HXiRBUh8FLQEYeW6ELL00UW70UW8
0UWX00YIieG8DLI9QTF7CJIMiEh6GNIMi`9Ib005FNQIjEW7EJIAQP02EJH01UG6FLEN1eh7FPQEa`9=
a`0`BHM5QSe4>B8hhSD3@HMJ:5i/HXiRKfJaH[5VdF;BH[5V/6[aI_5J;3ST748@81A0688Pa2CT;B@]
9BST9<@Pa22T9<@TaBcS<@@eACEW>FHeARcT9:8PXbC3:@<Y12340Qc4014HXaR26:<HPQB258<HaBD5
:BH]J2V:;HX]Rbf[:J/YRRV;00D][08a[00:<L`aZbf9:DLPi1RT58<DPQ11460256008QAQ688LPC4Q
@H=>1DFT?FDa0SD29:4TXR228:8XhRdS;@8XhC41?F9=hf8QEPA=id67;>DXiBC47:@HPQAQ440DHAR2
0aRS00XLY1bS688HPQbS7:@PaBSU:@D]1@8a9P8]1@07<BDeAcUX=DLa9S57>FP00SV800@iIc4T;@@a
9P8a9@03<BH]1Bd6008]9P07<BHeAcV9?JY1ZT6[AJ/00T6Z00=5ZdG;AL`00TG<0T6[00@mRCUX>DPe
9`<eA`03<DLa9S4W008eB00:<DLeAc56<DHa9RdV;@HXiBSV:>D2;@H01CDW<BLa9S4W<@L00S4600Da
9S46;@H/iRcW00<XiP03:>D]1Bd5008/i0<X``039:<PXb22008PXP0488<PPR23888276801aaQ664H
@AQ1664LPB21008LH@0@760TP21P980/P2bP<:0XX2R0<><e1CeXBNaF;UY?GVh2GXh2GVh01fJ_J]1Z
d6K=J_1_4VlC00=_4P0;LcAcEG<eLcAgE7<cLeAgEG=ELcAc=@02MeH00g=FLeMgEP03MeH017MfNiMk
UgMg0gME00AgMW=ELcA_=0m_=@E_=004KcE_5FlEKc@3KcD3Kc@3KcD2Kc@3Ka@4Ka<3Ka@7Ka<3Ka@0
1FlCKaA_56lDKa<00flD0flC00=_=6leKa@00flC00E[4flCKa=_4f/C00E_4`9^l`06J_=_4V[cK_=Z
lVkb16lC00E_56lCJ_9ZlVlB009_4`9^lP03J_9Zlf[c00=Zl`AZlP03J_5ZlV[a009Zl@05J_9ZlF[c
Ja=ZlP04J_<8J_83J_4016[bJ_5ZlV[a0V[b00=VlVKBI_800fKa00=VlV[BI]400VKA00EVd6KAI]5V
dFK@00=Zd004I]1VdFKAI]44I]85I]4016;AI]5VdFKA1F;A00=Rd6;AH]400f;A0V:a1f:`00AN/6:_
HZmR[P=R[`=N[`9R/003HXmR[f:_00=NS`03GZmNSf:_009RS`04HXiNSUj>GXl7GXh00ej?GXiNS`02
GXl3GXh01Ei_FViJKUi]GXh01Uj=00ANKEj>GXiNK`9JKPEJK@06FViJKEY]FVaJKEY/0UY]00=FCEY]
FVd00UY=00AJC5Y]FV]FC09JC003ET]JCEY=009JC@9FC@=FC003ET]FC5I<009FC00;ETeFC5I<ETaF
:eI<ERaF:eI<ET]FC003ER/2DR/01E8/DR]B:e8[DR`0258[00=>:dh/CR`00dh/00=>34h;CP/00Th;
00=>;4h[CR`00Th/0dh<0Dh;0E8:0Dh=00002A1P420@@110444@HQ1132488@03244534400``Q2448
@@02244030@0000<@2d3BPUJSF:=GVaNKUZ?FY1JL09NT09NL003GVmNL5i`00ANL003GY1NSej@00AN
S`9NT0ENS`9NT0ERS`08HXiRK69XGPQIZ5FXEJMIb0=Ia`0<GLMIieGXENQ=b4VW?DA1ATfWFNIJ1egW
15WX00UIbEG9DJMAZ5G7DLM=adVWBLP00TFX0TVW00=5YceV>DD00cTT00@iA4g8FTQNKP9RS`0KI[1V
dFKAI]5VdVJ_J_5[4FIZ@DLPHP`0420DHAAR68<P`b348:<HPQAR68<LPbBS;<<e0cE5008eA`0C<@DX
XbB29:<Xhbd3:@@ThabS6:<HXQbS7<<HXQB25:<LaBDV:FP00Rf:00H]Rbf[<J/][36/;H`2<J`2=J`0
0c6/=L`ec002=L`01CF[=JTaJ2TV8<@00QRS00<L`b339<<00RS300l]0Cf3CPMFAdFU?FDa0c42;>8X
`bd4=FDmZ3EU<B<00S5400a1YE8UJZ9VQ69WBPTmJ2dV;@He9SDU<>@3;@D00bdU;@D]1@02;BH0234U
<@D]1C4U<BHaASUW?HT4@JX2@JT02T7:ALY5bT6Z@J]1ZD6ZALY5bD6Y0Sf800E1Z468?HLeAc4W008a
9P03=DLiIcf900=1ZPE1R@08@JU1RD69?FPiAcDV<>D/i@8/i003;@@]1BcT008Xi@039<DTa2S4008X
i003:<@Ta2C400<Ta@0;:<D/iBcT;<@XXbS4:<DXY2S3:<@TX`0288<021b366<DHaQS68<LPQaQ7603
64000b1P880PP002880286002R1Q868LHB22::8X`RBR988TXRS20RcS018Xi345=BDeACUV@HQ5ZDG:
BLY=jUG[EP]J:f:=J]5_4W<dLe@6Lc@3MeD2LeD2MeD01WMFMgIgMWMgMgIgEP=cEP04MgIgEW=FLcD2
LeH2MgH01g=FKcE_56leLeIgMW=F009gEP9gE@03LcA_=6lc009_=@9_=0U_=@9_=004Kc=_=7<dLc@2
KcD2KaD00fldKcE_=003Ka@2Kc@3KcD016ldKaA_56ld0flC00=_<flDKa@016lD16lC0flD0VlC0VlD
2flC00A[4flCKa=_4`E[4`03K_=_4flC009^l`03J_=_4VlB00=^lPEZlP9_4PA_4`9^lP]ZlP04J_5Z
l6[`J_02J_49J_88J_400f[`J_5Zl@04J_4016KbJ_9ZdV[A0VKa00EVlVKBI]9ZdVKB00AVd@EVd0=V
d@AVdPEVd@03H]5VdFKA00EVd004H]1Vd6KAI]43H]43H[4016:`HZmR[f:_0V:`00=N/6:_HZl02F:_
0V:^00AR[ej?HXmRS`=NS`ERSP=NSP03HXeNSUj>00INSP9NS`9NSP03GXmNSUj>00UNS@04GXiNKEY^
FVh7FVd4FV`3FT`015Y/FVeJKEY]0UY=00IJC5Y/FVeJCEI<FTd3ETd00eY=ETaFC00<ET`00eH[ETaF
C005ET`3ER/00eHZDR]F:`0>DR/3CR`00dh[CP]B:P02CP/2CR/01Dh/CR]>;58/CP`00U8[0E8Y0E8<
0000111Q440@@0`P0Q1100<<8@PQ22400`Q110a100<8@@PQ22000PQ100`48@@0100<82CTANUJSV:^
GVaNKUZ?FY02FY43GY000ej?GY1NL004GW02GY08GXl3HXl00ej?GY1NS`02HXl2HY001V:?HXiRS69[
GRUEZ@9EY`03FJMIaeW7009Ma`05GNQEjEGYCNU9Z002@HL00dfXFNQJ2004FNP2FNT2ELT0356YBJQ9
Z45W@HM5Z4g8BJQ1QdFXBJU9bP==j`07DNYJ:Ei/GXeRSV:@H[4016KA00UV/6Z^K_5_4VZZBN`XQ@`0
42000aR20QbS01@D@1AQ688HPab2764/XS3R=D@eIc4V;@HXa2RS;@DaASEW<FL]9Bd50RT50RST00`Y
12T5:BH]JCG;>NdekCW]=LdekCW]=Nd2=Ld00cW^?Phmk@02?Nd00ch>@S16D@02AU02@Rl08cg]=HX]
:2dV<DH]9BdT<B<mQdh:DT]NSEIZBNTiJ3E7<BDa1CUXAN]:2TGZ@LXmR3EW=HM1aej9I/I_1f:YEVe:
3Cf:>DT00SDW00LiB3E6<DHeAC56<DDaAP02=FL013E6<BHa9CE60SE700@eASU7>HQ1Z`91b`05@J/m
RCf8>FPmR002?HT01CUX?HQ1ZT6Y@HX00SUX00HmRCUX<@Da1C4W;@H2;@D01c45<BHeAcE7>DHe9SDU
00<e9P06<BDa1C45<@D/i2c40bS400`Ta22T7:@PY2358<@PY22S9:@PXaR2788288<478801AaR764P
HQaQ66800QQ100<D@1Q064000QQ100hD@AQ1644H@AaR888PPB1P740PH2B0::0/hS3R0RcR00He13DU
=@He1SU9AJ/2@HX024G<DNaB34g[DN]J;5j?HXl2GVh01VJ_I]1Vd6K@J_9[4`9_4`07KaAc=G<eLeEg
EgMgLgL00WMg011c=FleKcAcEG=FMgMcEW=ELcE_=6leKcAc=G=FMeIcE`A_=@E_5003JaA_=6ld00=_
5003KcE_=6le00=_=@05LcEc=7<cKc=_=00=KcD2Kc@016leLcA_=Fld0fle00=_=6leKc@00flD0fld
0Vle00I_=6lDKaA_56ldKc<2Ka<8Ka@2Ka<3Ka@00flCKaA_500:Ka<6Ja<3Ja@00f/CJaA_5003Ka<2
J_<3Ka82Ka<5J_<00flBKa=_4`03Ka<016lBJ_9ZlV[c0V/C00=Zlf[bJ_8016[b1V[a1F[b00=ZlF[b
J_801F[b1f[a00IZlV[aJ_9ZdVKbI]42J]42I_401fKbI]9VdVKBI_9VlFKB00]Vd@=VdPYVd@05I]1V
dF;AH]5Vd003I]4016JaI]5R/F:b0V:a1V:`2f:_0V:^00IN/6:_HXmRSf:_GXl3GXh5HXh8GXh015j?
GXiNSUj>0ej?0Uj>1ej=0ej>00=NKEY^FVh00UY]0ei]0UY]15Y/0eY<0UY/00AJKEY=FTeJC@9JK005
EViFCUY>ETeFKP03ETd4ET`00eI=ETaFC@03ET`00eI=ETaFC007ET`00eH/ETaF:`03ER/01EH/DRaB
;58/ER/015HZ1e8[00IB;4h/CRa>;4h;CPX5CP/01dh<CRa>;4h/DR]B:UH9005B300010a10P`Q1PPQ
00L880`P340<@@PQ120880022242228020@P320TXdG9FXiR[Ei[GVh2FXl01UZ@GY1NL5i`GY1NSP9N
K`03GW1NT5j@009NT003GXmNSUj?00MNS`9RS`ANS`0JHXmRT6:@HXmRSV:=HX]NBeh:FLQMj5h8FLME
b5FWFLMN25XYEPUEjTg9DLUEjEWYFPUF2@=J209Ij0EJ2@0@FNYAjUGZENYEjEH:FPUJ:UhZGTaNKF9]
GVeRSV:_H[03I]403VJaI]5VdFKAI/mZcFJ]J]1c<W<_FTlXQPP03002784266005AQQ764HHQR2788H
@AQP::4`hCDS>FLa9S44:>@/i34U>HQ1bD7:?JTiJ003=FP01SE8<BHeB3VZ?Na63P96;`04@Rm6;dI@
AU02@Rl01d8?APi63TH>BRi:;dY@009:D@0HBW9>LU:bDY9:;cg=>H/eJC57=DLiISf7@JM9j5I:FXeB
:d6X>DPe9c47>DQ5ZTGZ0TG800`mQcEW>FLmYdWXDTUNJ6:9GVUBBdWZ>FP2<@L012d6;>Da1BdU0Rd4
0RcT22ST00</i345<BD00RdV00H]1Rd5;@Da1C4U<@D4<BD2<@H012d5;>D]1Rd60RcU12c400`Xa2S3
9:<X`bS2::8X`Rc2::8TXBBR::829:801R22768DHAAQ568HH@8DHP8@@@05468DHAAQ664D@@024440
1AA0560HH1QP64000aA000<L@22088001R1P00`TXRSS;>@Xi2SV<@La:3E8?FPmR4G9BLT2BLX00dWZ
DNYJ2P02GRX015i:HTaRSV:@0fJa00EVdF[bKa9_4VlC009_509_=@9_=005LcAgMWMfLcE_=002LeH0
1W=GLgMgMgMgMeMcE`=_=P9_=@04KcA[56ldKcD8Kc@4KcD00flEKcE_=@02KcD00fldKaA[5009Kc@3
KcD5Kc@5KcD00fldKcE_=@05KcD01FlcKcA[4f/CKc@00Vle00M_=6lcKcA_=6/CKaA_5@02Kc@2KcD2
Kc@016leKaE_56lD0flC0VlD00=_=6lDKa@00flD0VlC1FlD0VlC00=_4VlCKa802VlC1F/C1FlC00=^
lfkbKa800Vkb0flC0Vkc0f[c0flC00=_4VkbJ_800V[b00E_4V/CJa=[4f[c00IZlPIZl@=ZlP9Zl@IZ
lP]Zl@04J_9ZdVKBI]42J]42J_400fKbI]9VdP02I]8<I]43I]83I]400fJ`I]5Vd@03I]42I[001FK@
I[1RdF;AI]000VJ`0VJa0V:a00=R/V:aH[401F:`26:_1V:^00=N[f:^HZh00f:^00=N[V:^HZh01F:>
3Ej>0Uj?0Ui^00ANSEi/GVaNK@=NS@ANSP03GVmJKUY]00ENK@9JK@=JK0=JB`9JK007FTaJCEY=FTeJ
C5Y/FVd00UY>15I=00=FC5I=ETd01EI=2EI<0eH[0UH/00=FBeH[ER/00eH[0e8/00AF:eHZERYF:PEB
:`9>:`06CP]>:dh/CRa>:dh;0Th:00AB:Th;CP]>2`A>3003DP]B2UH8005B300000<8@@`Q34400Pa1
0`Q10`PQ00D<8@a1320<@0Q1008<@@0=324<@@a23488@P@Q320LPD6XFVmR[Ui]GVl00UZ?00QJKeY`
GW1NL5j@GVmNL5i_1Ej@00ANSei_GVmNS`9NT003GXmNT5j@009NT003HY1NT5j@009NT005GY5R/F:@
HY1RS`02HXh015i^GTeNC5h[0ehZ00=NBf9=GTd015i<0UX[00=NC5i/GV`00Ui/00=RK5i<GT`00ei]
00ANCEi]GVmNS`9NK`04HXmR[fJ?I[02IZl01VJ`I[5R/F:bI_=Vm09Rd@9V/@0@I]5V/FJaJZmZcV[@
J]5g<gMAGVhXQ@00100801b19882764278803R2R784LPR21;:4a0CU3=DHe9C45;>D]1CE5>HT2?JX2
>FP00cEX=DPeB002<BH01SE8>HXmkDH>@Nhmc@91kP0;@PhmkCW=>Ldi[3V[>J`iZcg;?Le1kP03@Pl0
33h?@Pi23T7]?J`iJSE8<BH]9S4U=DHmIP=1Y`03?FDiAC45008/i@0B<@HeAcEW=DDe9C4T<BDe9CDT
=D<iI46VALM1QCeV=DD]1RcV12S500hXiBST9<@Ta2S49<@PaBC58<@LXb349<@Pa22T0bC40R2T00<L
Pb2S9<<00R2S0bC30R2S00TPPab2788PPbBT88<LPR1R76400aaR00@PPQb2664HH@8L@@8H@@<H@0@H
H@<D@08H@@09664LPB21784LH21P880TPBBR008X``8]1003:>@/i345008e9P0H=BDiASeX?FPmId69
AJY5bdG<BNa=jeH]FTeF;EH^FTmRT6:?HXiV[VJ_J[1ZdF[b0fka00I^lVkcKaAc=G<fLeL4LcH2LeH2
KcH2LeL017=FLcIcEW=E0W=F00M_=VleKcI_=VlgKcI[=P04KcL2KcH:KcD5Kc@:KcD00fldJaA_=@0<
KcD3Kc@;KcD01VlfKcE_=6lDLcA_=@E_=0U_=@04KcA_=FleKcD2Kc@016lcKa=_56lD0fld00=_=FlD
Ka@01FlD00A_5FlDKaA_50A_4`E_5003Ka=_56lD00M[4`=_4`05KaA_4fkcK_9Zl`02K_<01flCJa=_
4fkcKa9_4f[c00A_4`03Ka9ZlV[b00AZlPQZl`05J_5ZlV[bJ_9Zl@0AJ_800f[aJ]5Zd@03I_4016[a
J_9ZlVKb0f[A0VKA00=VdVKAI]800VKB00=VdFKBI]800VKA00=Vd6KAI]400fKA00EVdVKAI]9VdF;A
00QVd@9V/@04I[1RdF;AH]42H[43I[42H[400f:bH[5R/@02H[42H[03HZl3H[03HZl4HZh3GZl3HZh0
0f:?GXmN/002GZl01V:^HXiRSV:>GXiNS`aNSP9NS`9NKP9NK@ENS@03GXiNKEi]00ANK@QJK@04FVaJ
C5Y<FT`2FV`01EY;FTaJCEI=FTd00UY<0eY=2eI=2eI<0UH[00IF;58]ERaFC5H/DR`2ER/4DR`2ER/2
ERX6DR/3CR/00dh/CR]>:`05CPX024h;CPa>34h;CPaB2e8:ERP1DP`00004244<8@a1324222400``P
340<@@0434400``P340<@@0234403a1R344<@@a1220<@P`P664iIEI^GVeNSej>FViNS`02FVl2GW04
GY04GXl00ej@GXmNT004GY000ej?GY1NT002GY07GY400f:aH[1R[`02HXl01Ej@GVmNKV9^IY000VJ`
00=V/F:AHW000ei`00UNKf:?GVmNKf:?I[1V[f:?HXh00f:?00]V/6KAJ]5VdF:@GY1NL6:AI]5VdVKA
009V/@04I]5V/F:aH[85I]80:VKAI[5V/FKAI[1V[V[?J]1ZdFk_NdmV[STX200000`0664TXb2S88<L
Pab28:4PXRBR::4``CD1?F<i93D4<@D`iBcT<B<]9C4W<BHa9C45;@D/i@</i003;@D]1RdW008aB004
<DTa:358;BP2;BL02BT5:>DTi2CT:>D]1RdV<DPaB@02;DT04C5Z=FTaBC4W;@H/iRc49:<TY2S4;<</
hbd3<@@]0bcR:<800RB200LTXbC49:<TPbRR;<<XXP0288800b21984TX@02980298402R2278<HHQAR
66<LPaR356<DHQQR11AR00<HPQR368800aB20QAR00<DHA1256800aAR11A100LDHAQQ644DHAQQ644D
@00264401AA0640H@1PP64000QPP00<L@B1Q96000bAP0R1000@TPBc2<>8X``8TXP0::<<]12d3;@@a
1BcU;@DeAceW?HT2?HP02d6Y@JY1ZT6ZANaB3Dh<CNaF35Y<GV`00Ui]00ARSF9]GVeRK@9RSP04IY1Z
dFkbKa82Ka<016lDK_A^m7<D0W<e00Qc=W<eLaEc5G<eLcAc=G<d0W<e00A_=G<fLeMgM`9cEP=cE`9_
=P04JaI[5FleLeH2MeD00g<dKcE_=@03KcD3KcH6KcL00flfKcE_=@06KcD017<eKcA_<fld0W<C0fld
1Fle0fld8Fle1Vld1Vle0fld00=_<fldKc@016lc00A_<VlCKaA_50A_=0E_4`9_509_5@=_5003Ka=_
56lC00A_4`04KaA_4flDKa@<Ka<2Ka83K_<3Ka@00fkbKa9_4P02Ka82Ka<7Ka82J_84J_<016[dJ_=Z
lf[a1f[b16[c26[b00EZlfKcJ_9ZlV[a00=Vl@EZl@9Zd@QVd@03I]9VlVKA00aVd@9VdP9Vd@04I]1V
dFJ`I[43I]400fJaI[1R/@06H[400f:`H[5R/@04H[46H[06HZl00f:^HZmN[`02GZl3HZh01V:?GXmN
/5j`GZmR[P=RSP03GXiNSej>00QNSP03GXmNSUj?00=NSP9NKP03GVeNSEj=00=NS@04GVeNK5i/GV`8
FVd4FVh2FVd4FV`2FT`2FTd2FT`4FTd;ETd=ET`01U9=ETeF;EH/DReF;0AB;0=F:`9F:PAB:P9B:`9B
:P9B:`04CR]B:dh:CPX3DPT00dh;CPa>2`02CP/00e8[DPYB:@01CP`00004244<@@a1244934432442
3440311Q468@H@aR220<@Pa1788mIUY^GXaJK0=NKPMNT004GW1NSej?GY03GXl5GY0015j?GY1NT5j@
1ejA0eja00=R/5j@HY000V:@1f:a00ARTV:bH[9R/PAR/@ER/0=RT003I[1VdF:a00AR/@03HY1R/F:a
009R/@06I[5V/V:aI[9VdVKC16KB0fKA0VKB025VdF[?J]1Zd6[?Lbm^l5G;;88/Xc44=@8X`b23544L
PabT8<<PXb22984``SCQ?D<iA3DT<><Xa2S3:><Y1BST9<<012BS1b2300XPY22588@LPb23888LHQA1
440D@@<HHP07568HHQaR78<LHQQR76800Qb300LLHQQQ540@81A0640HH002540021QQ668HHAA0420@
@1QQ56434202520342001aA0640D81PP520H@1A0008@@004420<810Q424242001A11564@@A115440
0QQQ00DH@1A0544HHAQP008H@004644LPR228842760486000b21::4X``029:8012RR984TXRS30RcT
00H/hcD5>BHe9cD6>BL2@FP01d57AFU9RTV[BJY9ZdW:0099b`05BLaAk5H]FTeJCP02FRd02EX/HViR
SUZ?GXmR/VKbH_ARd`02H]802FKCJ_=Zm6[cKa=[4flDKcA_=@03Ka@01VlEKaA_57<DLcEc=P9gE`08
LeIc=VlfLcEcEgMGLeMc=P9c=@05LcIc=G<eLcE_=@03KcH4KcD00g<fKcI_=`04KcH2Kc@3Lc@2LcD0
16lfKcE_=Fle0flf1Flg00=_=VleKcD00Vle0W<d16le0VlD00Ec4g<DLaAc56ld00E_=@=_=0Y_=@04
LcAc=FleLcD6KcD3KcH;KcD5Kc@6KcD9Kc@00flcKa=_5004Ka@3Kc@00flDKa=_5003Ka@00fleKaA_
5003Ka@8Ka<00f/EKaA_4`0<Ka<016lBK_=^lfkd0flD00=_4flBKa<026lC0VlB0f[b00=[4f[cJ_<0
16[c2F[b16[c1f[b0V[c0V[b00=ZlFKaI_400fKa00=ZlF[AJ]400V[A26KA0fKB1fKA00=VlFKAI]40
0VKA0V;B00=VdVKAI]0016KA00ARdF:aI[5V/0IR/@03H]5R/6:a00ER/@ER/0MR[`04H[1R[ej`GZl2
HZl00f:^HZmR/002G[02GZl01V:^GXiRSV:>GXiNS`MNSP05GXmNSUj?GXiNS`03GXh01Uj?GVmNKej>
FXiJK@=NK@=NK0YJK@04FViJCUY>FVd5FV`01UY<FTeJCEY>FTeFCP9JC@03ETaJCEY=00YFC@QFC0EB
C@04EReFC5H/DTh2DT`3DR`00eH[DRaF:`02ERX3DRX00eHZDRYB:P02DRX3DR/024h[CP]>2e8:DRYB
2Dh;CP`4CP/1CPX1CRX1CPd000<<@@03248<@Pa1008<@@0432488@PQ2242244222023400311P464H
XQB2464<@@PQ668mIUI>IZaNK09NK@05GViNKei^GViNS`04GY02GXl015j@GXmNSej?0ej@1Ej?00=N
T5jAGY401UjA00AN/EjAGY1NT09RT0ER/09R/@03HY5R/F:a009R/@03HY1R/F:`00AR/003H[5R/6:`
00]R/0AR/@9V/P03I]9V/VKB009VdP=Vd@9Vd0=Vd@=Zd00JJ/m^kW<AIXe=bDG8FVi>:S44768D@A0Q
444@@1A1660PHBRP;<4e8cU5=@<XX2B1884LH@@HH@8LH@8HH@03544@@@`Q008@@@04440<8@P02002
324332001PP0320@8@P010080@84008<8006324800P0324<80`0110P1@`P00<@@1Q064000QQ000<H
@AQ064000QQ000DPH2B0980PP2B000DPH006980XXBRQ9:8TPBAQ0R1Q00LTXBS3:<8X`bBS9<</h`03
;@@00bST;@@a9@03=DL00cDX<DPiJ003?HT00cUX>FU1ZP02AL/01dG<BNa9c4W<CLaEk5X]00ANC003
HTaRKf9^00=RK`0;IVmVSfJ?IY1RL6JAJ[9^df[BJ_9^l`04J_@01VkdKaAc=6lDJ_A[509_=@9[5P05
JaE_=W<fLcI_=P02LcH027=EKcE_=FlfKcE[5FleKcH2KcD01g<eKcI[5F/EKcEc=W<e00U_5@04KaA_
=FldKcD3KaD00f/EKaE_=@03KcD3KcH016leKcAc<fld0W<d17<e1Fle1Vlf2Fle0Vlf0Vle00E_=6lD
KaA_56ld00E_=@=_=003KcE_=6ld009_=@E_=0Y_=@=_=PM_=@06KcAc=6leLcA_=6lc0fld16le00A_
=7<dKcA_50E_=004KcE_<flcKa<<Ka@4Kc@3Ka@2Ka<3Ka84Ka<00f/CKaA_4`0AKa<01FlDK_AZlflB
J_800V[c00=_4f[cJ_<00flC00=_4V[bJ_800V[b00AZlf[bJ_=Zl`AZlP9Zl@MZlP=Zl`03J_9ZlF[a
00AZlP03J_=ZlV[a009Zl@EVl@EZd@YVd@03I]9VdFKA00YVd@03H]5RdVKB00EVd@07I[1V/F:aH[5V
/6;AH]000V;A0f:a16:`00AV/6:aH[5R/0MR[`03H[1R[f:_00=R[`03G[1N[ej_00=R[P9R[`9N[`03
GZiR[Uj>009RSP03GXiNSej>00iNSP05GXmNSUi^GVeJKP03GVd4GV`5FVd5FV`015Y^FTiJCUY]15Y/
00QJKEY<FTeJCEY>FTeFCUY=0eI<0UY=00=FBeI=ETd01UI=25I<0UI=0UI>00IF;5H[ER]F:eI<DT`4
DR`3ER/3ERX7DRX3DR/2CR/01Th;DPYB2U89CP]>:`A>2`5>2P5>:P5>300000@<@@`P3248@P8<@P06
48<@H`a2320<8@PQ0PQ10`a100l<@11Q468@HQB3468880@0444e958/IZYRS5i^GXh00Ui_0Ui^00EN
KeZ@GY1NT5ZA00UNT003GXmNT5j@009NT0eNT@9NT003HY1R/F:a00UR/@04HY5R/F:aH[43H[07H[40
0f:`H[5R/@03H[400f:`H[5R/P02H[42H[82I[87I]83I]404fKBI]5VdFKAI/mZcW<AK^mR[Ej=H^iN
K469::@PHBB3988PPBB1008TX@08:<8a9CUV>FLa8bcR984TH08TP@03980PP2B100@TX@<TX`8TXP08
984PPAaR744LHB2R:<<Xi08X``<T``8TY08TX`09:<@Xi2cU:>@Xa2BS:<<a1C4600Da10<]10</i003
=BHiB3E800<iA`06>BHiASeW@HQ1RD680SeX00A1ZDFZAJY5ZP95Z@=5ZP0<AJ]5bdW/BNa5bdW/DPeB
34h<EReJCEY^0UY>00IJCEH]FTeNKf:AGY84GY02HY000f:aI]9ZdP02J]801fkcK]9ZdF[BJ_=_5FlD
009Zl`06KaE_=flFJaE_5Flf0Vle00=c=FleKcH00g<f00Q_5FlfLeMc=fleKaE_5Vlf0W<f00I_5G<f
LcI_=VlDKaD3JaD00flfLeI_=P03JaD01f/eKcE[=V/fKcI[5FlE00=[5@03JcI[5FlE00=_5@m_=@03
KaI[5Vle00A_=@A_=P04KcEc=FlfKcH2KcD2LcD00fleLcE_=P02KcD01FlfJcM_=W<fLcD01Flf1Fle
0flf1fle00=_=VleKcD05Fle00=c=7<eKcD016lf16le00=_=6leKcD00fld00=c<fldKc@00Vld1Fle
00E_=6leKcE_=Fld00M_=@04KcA_56lDKa@2Ka<016lDKaE_56lD0fld00E_=FlDKaA_=6le00=_5@04
KaA_4flBKa84Ka<3Ka@5Ka<016lDKa=_4flC0Vkc00E_4flDKaA_4fkd009^l`04K_A_4flCKa<2Ka@0
0f[dJ_=Zl`03Ka<2Ka83K_801V/BJ_9ZlV[bJa9^lPaZlP9Zl`eZlP9VlP03I_5VlVKA009Zd@05J]9V
dFKBI]5Zd@03I]401FKBI]5VdFKAI]8036KA16;A00AVd6KAI]5Vd@9V/003I[5RdF;A00ERd@9R/@03
H[1R/F:a00ER/004HZmR/6:`H[07HZl00f:`G[1N/006GZl2GZh3GXh01F:^HXiRSUj>GXl01Ej>00=N
Sej>GXh00Uj>00=NSEj>GXh00Uj>00=NSej>GXh00eY^00=JSUi]GV`00ei/00=JSEY]FVd00UY]00]J
K5Y]FVeJKEY/FViJKEY>FVeJKUY]009FK@05EViJKEI=ETeJKP02ETh00eI=ETaFC002ET`2FTd;ETd0
0eI<ERaFC002ERd01EH/ETeFCUH]ER`00UH[00IF;59<DTaBC58/DRd4DR`00eH[ERYF:P02DRX2DR/3
DRX01E8[CR]>:dh[CP`00dh;00A>2Th;CP]>2`E>2P5>3@0000@<@0`P2208@@8<@@8<HP05324880PQ
244<@@04224434402``Q200800@0420a14WZHVYRRei/FVd01Ei^00INT5j?FW1JL5i`GXl5GY03GXl2
GY0@GY43HY0016:aHY5RTF:A16:a0f:A00=R/F:bH[400f:`0V:a0f:b1f:a0V:`0f:a00EV/V:bH[9V
/VKA00MVdP=Vd@9VdP9Vd@0>I]1ZcfJ[J/YJB5Y^I_1ZkE8<?HXe9cE8?HU1Z091Z@0:@JY1RT6ZAN]:
34X;ALY5ZT6Z@HT4@JT5@JX2@J/00dG:AJY5ZP02AJX5ALX01dG;ALa5k4X<DRaB;Dh<0095b`95k008
BNa>3Dg/CNaAk5H]FReNC@MJ;@03GTeNKF9]00ENC@ANC003GT]RK6J<009VS@07HVaRSVJ_IXiRKF:>
JZl00V[?0V[@16[A00iZd6[AJ]5ZlVkbKa=ZlfKcJ_=_56lCK_A_56lE0f[d00A_5G<eLcIc=P9_5@04
LcEc57<dMc@2McD2LcD3KaD03G<fLcM_=V/EKaI_=W=EMgMgEW=FKcE[5FlE009c=P9[5@=_5@03KaA[
56lD00A_5@9_=@A_5@03KaI_5Fle00Q_=P=_5@04KaI_=FlfKcD3KaD?KcD5KcH3KcD8KcH00fleLcE_
=@04KcD01G<eKcE_=VlgKcH00g<e00A_=FlfKcI_=Pe_=@E_=P9_=@=_=003KcE_=Vle00I_=@=c=0=c
=@=c=003LcE_=Flf00E_=@A_=003Kc=c<g<c00=c<`03KcA_=Fle00=_=@06Ka=_=6ldKcE_=6lc0Vld
0fle16ld26lD0fld00=_=FlDKa@00Vld00A_56lEKaE_50M_4`=_50U_4`06K_=_4fkcK_=_4fkc16kd
00=^lfkbJ_<00flD00A_4f[bKa=_4P9^lP03Ka9_4FlA00E_4@9^l@9ZlP03J_=ZlV[b00QZlP03J_=Z
lV[b00MZlP04J_=VlfKcI_<2I_802VKaI_9ZlV[BJ_9ZdV[AI_9VdF[B0fKB0VKA0VKa00AVdVKAI]5V
dPaVd@9Vd0=Vd@=Vd09Vd@=Rd@9R/@03H[1R/FJ`009R/@03H[1R[f:_009R[`03IZmR/6:`00QR[`03
H[1N/5j`009N[`=R[P03GZmR[Uj>00ANSP9RS@YNSP=NS@ENSP07GXeNSUi^FViNKej>GVd015i/00AN
KEi/GVaNK09JK0=JK@03FVaJKEY]00AJKP=JK@AJKP9FCP9FC@=JC@AFC0=FC@IFC008ET]FC5I<ETeF
;5H]ETeF;@9F;0=F:`AB;005DReF;58/ER]B;002ER/015HZER]F:e8[158Z0e8[00=>:dh;CR`014h[
00M>:Th[CRY>:U89DPYB:P01CP`00003340<80a10088@@06248<@@Q210488@Q10PQ200D8@@PQ2248
8@Q1008<@@03320880PP0088000<320`hdWZGV]NS5Y]FViNKUi]GViNKei^0Ui_0Ui`0ej@00=NTEj@
GY000Uj?00=NT5j?GY000ej@15jA1eja00=NTF:aHY4016:@16:A0f:a0f:A0f:a0f:`00ER/F:bH[9R
/F:b00IR/@=R/0=R/@=R/PIVdP=Vd`EVdP0;I]5VdVKAJ]1V[FJ/HXeJKej`I_1NS`02DPd02eY?GVmR
SV:?HXiRKUi]GViRSf:^GXh00V:?00=NSei^HXh00f:>00MR[fJ_HY1RSV:@I[5V/P02I[001V:?HXiV
SfZ`J]1Zd@9V[`04I[1ZdV[BJ]83J]400f[BI[9V/P04J_<2J]83J_82J_<01VkcK_9ZlV[bK_=_50=_
5@0AK_A_5FlEKaE_56kdK_=_57<CKa=^lVkcK_9_4g<DKcE_5002J_<00fkcKaAc=003Ka@00flEKaA_
5@03Ka@017<EKaA_56lD0VlE00=Zm6lDKa@00VlE00=_=VlEKa@00VlD00I_=W<fKaEZm6[cKa@2LcD3
Ka@2KcD2KaD01VlDKaE_5F/EKcE_=PA_=@9_5@03LaEc5VlF00=_5P03KaE_=Fle009_=P9_=@9_=P03
JcI_=Vlf00M_=P03JcM_=flg009_=P03KcE_=Vle009_5@03KcI_=Flf00E_=@03KcI_=G<e00U_=@04
KcI_=FlfKcH2KcL<KcH2LcD5KcH01FleLcE_=VlgKcH00W<e00E_=VleKcI_=Vlg00A_=PI_=@03LcE_
=Vlf009_=P09KcM_=VlfKcE_56ldLc=_=6le009_=P03KcE_=Vle00A_=@03LcA_=Fle009_=@=c=0U_
=@=_=004Lc=c4W<BLa82Lc<016ldKcE_=Fld0Vle0fld00A_=FldKc=_=0A_=@E_=09_=@03KcA_56le
009_=004KaA_=6leKcD3Kc@2Ka@3KaD:Ka@9Ka<00flDKa=_4`03Ka<3Ka@2K_<00fkbJ_=_4`03Ka@0
0f[cKa=_4P02K_83Ka85Ka402FkbJ_5ZlV[bJ_=ZlV[cJa9[4`04J_<2J_801F[cJ_9ZlV[bI_401V[b
0fKc0VKb00=VlFKbI_800fKb00EVlFKbJ_9ZlV[B009VdP05I]5VdVKBI]5VdP0@I]401fK@I]5VdFKA
I]1RdFK@00=Vd@9V/@=R/@05H]5V/6:aH[5R/004HZl01VJ_HZmR[f:`HZmR/0ER[`04H[1N/5j`GZl2
HZl2HZh00ej^HXeNSP02GXh2GZh00f:^HXeNSP09GXh00ej=GXiNS@05GXh01Uj=GXiNSUj?GVmNK@IJ
K@03GVaJJeY[009JK0=JK@03FVaJKEY]00=JKP=JK@04FViJKEI=ETd3ETh2ETd4FTd3ET`3ETh2ETd3
ET`01EI=ET]FCEI=ETh00UI=0UH]00AFC5H/ERaB;0AF:`04DRaB;E8]DRd2DR`2ER/01UHZDR]B:e8[
DRYB:`=B:P9B:`03CR]>;4h/00M>:`04CP]B2U8:DPX1DR`00004360<@0a1244234401@Q122448@PQ
24400PQ200@8@@PQ12088@8<@@05244<@@a1324<000220001S3RBP]NK5j<FVeJKP=NKP05FViNKUY^
GViNK`03GW03GY02GXl00ei_GXmNS`04GXl00ej@GY5NT@04GY400ej@GY5NT@03GY400f:AHY1RT003
HY03HY44HY02HY43H[43H[000f:aH[9R/@02H[400f:@H[5R/002H[400f:`H[5R/@03I[000f:aH[9R
/P02H[800f:aI[9Vd@02I]83I]<7I]803FKAI]1Vd6K@H[1JKej@I]5Vlf:`GViRT6Ja00AVd@9ZdPAV
d@04I]9ZlV[bJ_82J_<016[bJ_=Zlf[c0V[B00AVdV[cJ_AZl`9^l`05J]9ZlfkcKa=_4P02Ka<3J_<3
Ka@2J_@026lDKaE_5FlEJ_AZlfkdKa<2Ka@3J_@016lDLcEc=FlD0f[d00E[5G<eLcIc=W<e009_5003
K_AZlfkc00M_5004JaAZlf[dJ_@4J_<3Ka@2J_<00flDJa=Zm006Ja@00flDJaA[5002Ja@016/EKaA_
56lE0f/E0VlE0flD1FlE00=_56lEKcD00fle00=[56leKc@00fle00Ec=G<fKcIc=Vlf009_=`=_=P03
LcE_=Vlf009_=P03KcM_=Vlf00E_=P0:KcM_=VlfKcI_=flfJaI_=W<fLcD2KcH00flFKaE_=@04KcD0
16ldKcE_=Flf3Fle0flf00E_=flfKcI_=Vle00=_=P03LcI_=Vlf009_=P9c=@9_=@9_=P9_=@04LcE_
=FlfLcD2KcD016lfKcE_=Fle1Flf0W<e00=_=6leKcD017<e1Flf0Vle0W<c00A_=6leKcI_=Pe_=@9c
=004KcE_=6ldKc@5KcD2Kc@4Lc<017<bLc=c<fld16le16ld00=_=FldKc<016ld00A_=FldKcA_<`9_
=09_=@9_=003KaA_4fld00E_=0a_5003KcA_56lC015_4`9Zl`04KaA^lf[bK_82Ka82K_<016[cK_=_
4flB0Vkb00=_4VkbK_801FlA0Vkb00A[4VlBJa=[4`9[4P03J_5ZlV[b009ZlP=Zl`03J_9VlV[b00QZ
lP04I_=VlVKaI]43J]401FKBI_9VlF[aI]400V[A2fKA0VK@0fKA00=V/6KAI]001FKA00=Vd6J`I]00
0VK@00ARdFK@I]1Vd0=V/005I]1Rd6K@H[5R/002H[400f:`HZmR[`05HZl00f:^HZmR/005HZl00f:`
G[1N/002GZl3HZh00ej^HXaNS@0=GXh>GXd00ei]GXiJK@03FVd3FV`3FV/2FV`3FVd00eY/FVeJK007
FVd00eY<ETeFC@07ETd2FTd3ET`00eI=ETiFC`02ETd3ET`015I;ETYFBeI<0UI=00IF;EI<ER]F:e8[
ER/2DR/00e8/ER]F:`05DR`01eH[ERYF:UHZDR]F:U8Z009F:P9B:P04DPYB2e8[CP/7CR/01Th/CR]>
2e8[DP]B2P5B30000Pa10PQ10Pa100<<HPaS348010a200@8@PPR22488@@8@@888@<40004;>=9jUi/
GXh4FVl2FVh015i^FViNKUi_0ei`0ej@00=NSej@GY001Ej@00=NSej@GY401UjA0ejB0ejA1F:@16:A
00=RT6:AHY400V:A0f:a0f:`16:a00=R/V:aH[801V:a0V:`00=V/6:aH[400f:b0VJb00=V/FKBI]80
0VKB1FKC0fKB0VKA00QRdF:`GY5JCei_I]5Vlf:`0Uj@00AR/FKBI]9Vd@9VdP9Zl`05I]9VdFKBI]9V
d`02J_<00f[dJaE[5002J_@01FKcI]9VdV[CJ_<00f[d0V[c00IZdf[BJ]9Zlf/DKa@3J_@3J_<00f[d
JaAZm003J_@00f/EKaE[5@03J_<3J_@00f/DKaA_5002J_@00f[eKaI[5@04J_@016[cJ_AZm6[d16[c
1V[d00M[56/EJaEZmF[dJ_=^l`04Ka@016/DKaA[5FlD0V/D00=_56lEKaD00VlE00I_=FlfKcI[5FlE
KcD4KcH00fleKcI_=@02KcD5KcH2KcD00g<eLcIc=P02KcH01G<fMcEc=G<eKcH00W<f00=_=g<gLcL0
0g<g1g<f00=_=flfKcH00flf0flg16lf17<f00=g=G<fLcH016lf0fle00=_=6leKcH00flf1Fle0flf
00=_=FlfKcH00flf0Vlg2flf00Uc=GMELcE_=VmFKcIc=FleKcH00fle16lf00Ec=FleKcI_=V/f009_
=P03KcEc=G<e009c=@A_=@E_=P9_=@9c=@05KcE_=VlfKcI_=@03KcH3KcD2Lc@4KcD00g<dKcE_=@0:
KcD3Kc@2Lc<4Kc@3KcD2Kc@01FlcKcA_=FldLc<016ld0fle0Vld16le2Fld16lD00M_5FlDKaA_56lE
KaA_5@06Ka@3Ka<3Ka@2Ka<00flBKa=_4P06Ka<016[dJ_=Zlf[b0VlB00=_4flDKa@00Vkc00A^lVlB
Ka9_4P9ZlP07K_9_4VlBK_9ZlF[bJ_400V[b00AZlf/CJa=[4Q=ZlP9VlP08I]5VdVKAI]5ZdFKAI_9V
l@9Zl@03J]9VdFKA00=Vd@04I]9VlVKbI_82I]44I]04I]400fK@I]5Vd003I]44I]0016:`H]1RdF;@
0V:`0VJ`00IVd6;AH]5R/F:`H[42H[000f:_H[5R/003H[06HZl3GZl3G[02GZl4HZh00ej]GZiNSP0=
GXh3GXd015j>GXeNSEj=1Uj>00=JKUi]GVd03eY]00IJKUY]ETeJKEY^FV`3FVd01EY=ETeFCEI^FV`0
1UI=00EJCEI=ETeFCEI>009FC`03ETiFCEI<009FC004ET]FBUI;ET/5ET`00eH[DR]B:`04DR`00eH/
DRaB;003DR`01EH/ER]F:eHZDR/00UHZ00EB:U8[DR]B:U8:009>2`Q>:`9>;004CR]>2dh;DPX1CN`0
0004244<80PQ2242344010aR36<<HPaR0Q1S00<<@PQ224801@PQ00<880PQ20000P@000D802RRANUN
S5j^009JK`03GVmJKei^009NKP03FViNKUi`009NL003GVmNL5i`009NS`=NT0=NT@03GY1NSej@00MN
T@03GY9NTEjB00=RT@ERT0URT@03H[5R/6:`00=R/005H[5R/V:bH[5R/P02HY82H[84H[45I[42I[80
0fKBI]5Vd@05I]400fKBI]=Vd`03I]<04FKBI]5VdFKAH]5R/5j@GVmNKV:`I]=R/Ej?HY5VdV[AI]40
0fKB0fKA0fKB00=VdfKBI]800fKB00IVdfKBI]=ZdV[cJ_82J_<00f[bJ]9ZdP04J_8=J_<5J_@7J_<0
1F[dJ_=Zm6[dJ_D00V/E0f[d0f[c0V[d00U^m6kcK_=Zm6[cJ_AZmF[dJa@00flE00E[5F[eJ_EZm6lC
00A_5@U_=@03LcE_=W<e009c=P05KcIc=W<fLcEc=P02LcD00g<dLcEc=002LcD5LcH5LcD00g<fKcIc
=P03LcH00g=GMcEg=@05LcH00g<gLcIc=`02LcL5LcH00flgLcIc=P02McH027MFLcIc=VlfLcIg=GME
McD2MeD3McD4LcH01FlfLcE_=FldKcD016lf0Vle00M_=W<fLcE_=W<fKcI_=@06KcH00flgKcIc=P02
LcH6KcH3KcD7KcH00fleKcI_=P03KcH2LcD01VleKcI[=F/EKcE_=PM_=@07KcI_=FleKcE_=VleKcH0
0Vle00=c=FleKcD00Vle00=_=VleKcH00Vlf1fle00Ac=G<dLcAc=0E_=@=_=0M_=@9c=0a_=003Lc=_
=6ld009_=09_=@03KcA_<fld00]_=@A_=003KaE_56lD00E_5003Ka=_<fld009_5008Ka=_56lCKaA_
4flDKa=_50]_4`=Zl`03J_9_4Vkb009^lP04Ka9^lVkbK_84Ka8016[bKa9[4flB0f[b00=ZlF[bJ_80
3V[b00=ZlF[bJ_801V[b00IVlFKAI]5VdV[BJ]44I]401F[aI]5VlVKbJ]4016KA0VKb0fKA0fK@1FKA
4fK@00=RdFKAH]400V:`0V:_00AV[f:`H[5R/@9R/0ER[`9N[`04GZiR[V:^HZh2GZl01V:^HZeR[F:]
GZeR[09NS0aNSPQNS@MNSP03GXeNKEY]00=JKPAJK@03FVaJC5Y/009JK09JK@9JKP9JK@=JK0=JK@9F
C@04ETaJBeY<FTd3ETd2FTd00eI=ETiFCP03ETl00eI>ETeFC002ET`00eI;ETYFB`06ET/2ER/01UI;
DT]BBe8/DR]F;0AB;003ERaB;58/00QB:`=B:P=B:`M>:`05DR]>:dh;CP]B2P01DP`000D88@8<@@8<
HP05348<@@a236<8@P04224322000`PQ324<80022000122RALUNK5j=0UY_00INKeY_GViNSf:`GY02
FW000ei`FW1NK`02GW000ej@GXmNT002GY04GY43GY06GY400ejBGY5NTP03HY44HY02HY43H[43HY40
0f:BH[5R/@05H[47H[800f:aH[9R/P05H[43I[42I[8016KBI]5VdFKA0VJa0VKA00=VdVJbI]<00fKC
0fKB00UVdF;AH[1NTEj@GViR/6;CH[400V:A00IV/FK@J]9ZdVKBJ]86I]800fKCI]9Vd`05I]800f[C
J]9ZlP04J_83J]83J_<00f[bJ_=ZlP08J_<00f[dJ_=Zm006J_@5J_<3J_@016[eJaE[5F/E16[d00AZ
lf/EKcE_5@9^m004KaA_5FlEJaD5KaD00f/FKaI_5P05KaD00flFKaE_=@03KcD:KcH6LcH01VlfLcIc
=W<eLcI_=P9_=`=_E`Yc=P9cE`03LeIgMG=G009cE`03MeIcEW=G00EcE`04LeIgEW=GLcL3LeL01GLf
MeIgEWMFLeH00W=G0gMF0W=G0WLf00=g=G<fLcH00Vlg00A_EflfLcEc=@=_=P03KcM_=Vlf00Y_=P06
KcM_=VlfKcI_=flf0W<f0flf16mF36lf00M_EFlfKcI_EVlfKcEc=@02KcH3LcH00g<eKcEc=002Lc@0
1G<eKcE_=VlfKcD02Vlf00A_=FlfKcE_=@9c=@03KcE_=Vle00I_=@05LcAc=G<eKcE_=P02KcD3Kc@7
KcD2LcD00g<dKcA_=004Kc@00fleKcA_=@04Kc@5KcD3Kc@6KcD00fldKcE_=004Kc@3KcD00flEKcE_
=008Ka@2Ka<3Ka@01FlCKaA_4flCKa801VlC0V/C0VlC0f[c2flB00E[4f[bKa=_4f/C009Zl`9ZlP04
J_5ZlV[bJ_<4J_83J_42J_800f[aJ_9ZlP03J_800fKaJ_9ZlP03J_83I_4016KAI]9VdF[A16KA0VKa
0VKb00EVlFKBI]5VdVKa00=VlPIVd@03I]1VdFKA00EVd@]Vd0ARd003H]5R/FJ`009R/09R[`04IZmV
/6J`H[42H[06HZl2GZl00f:^HZmR[`02HZl3HZh2GZd00ej/GZeNS@02GXh015j^GZmN[ej^0ej?0ej>
00=R[Uj>GXd01Ej=15j>0Uj=00ENKEY]FVeJKEY_009JKP=JK@06FViJCEY=FVaJKEY/0UY]00=JKUY]
FVd00UY]00=JK5Y]FV`00UY/00AFKUI=FTaJB`9JC0IJC@9FCP=FC`03ETiFCEI<009FC003ET]FBUI;
00IFB`03ER]BBe9;00=BB`EB;003DReB;58/009B;0EB:`9B2`9B:`=>:`9B:`E>2`9B:`9>:`5B:`5B
:@5B30001PPQ00D<@@Q12448@@PP00888@0312488@PQ00888@8880@<8008300801b2@JMNJej<FTmJ
K`=NKP03GXiNKUY_009JL003GXmJKej?00=NT004GXmNT5j@GY04GY42GY000ej?GY1NT@03GY4015j@
GY5NTEjA0f:A16:@00=RTF:aH[400V:a00ANTF:AHY5RTPAR/@03HY1R/F:a00ER/P03H[5R/V:b009R
/PER/@=V/@03H[5V/FKA009Vd@MV/@9V/P=Vd`=VdP08I]5Vd6:`FVmNKV:`I_=R/P9RT@03I[5Vd6[A
00=ZdPUVdP9Zd`05I]9VdfKBJ]=ZlP02J_<2J_83J]8016[bJ_=Zlf[c16[b16[c00=ZlV[cJ_@02F[d
0V[c00=^lf[cJ_@00f[d00=_5F[dKaD00f/E16[d1VlD00=Zm6/EKaD016lE0flF00A_5FlfKaE[5@=_
5@M_=@04LaE_5FleKcH2LcH017<eLcIc=W<f0W<e00Ec=VlfKcIc=W<e009_=PA_=`03KeMc=g<f00=c
=P07LcEg=GLeMcEgEGMeMgH00gMF00McEWMFMeIgEW=FMeIgE`09MeH00g<fMcEg=@03MeD00gMFMcIg
EP02MeD01WLfMeIg=WLfMcEg=PAc=PEc=@=_=P03LcI_=W<f00E_=P04KcE_=VlfKcL4KcH00fleLcEc
=P02KcH5KeH7KcH02FmFKcI_=VleLcAc<fldKcI_EP08KcH7LcD7KcH3KcD3KcH4KcD2Lc@8KcD00fld
LcAc=@02LcD00fleLcE_=@05Kc@5KcD00g<dKcA_=006Kc@01FleKcA_=6ldKc<00fld16le16ld0fle
0Vld00=_<flDKc@01Vld0fle00=_=6lDKa@016lC00A_56lCKa=_4`=_509_4`03Ka9_4flC00I_4`=[
4`9_4`9Zl`A_4P9_4`9^lP04Ka9[4flCJa<3Ka<00f/CJ_=Zl`02J_800f[aJ_9ZlP05J_8016[aJ_9Z
lV[b2F[a0f[b0f[a0V[A00=VdF[AJ]401FKA00=VlFKAI]400VKA1FKa00AVlVKaI]5Vd@9Vd003I]5V
d6KA009Vd@03I]1VdFK@00]Vd004I/mVd6:`H[02H]000f:`HZmR[`02HZl2IZl00fJ`I[5R/@02H[0:
HZl016:^GZiR[V:^0Uj^00=N[Ej/GZ`00Uj=0ej>0ej^00=NSej>GXh01Ej>00=NSEj<GXd01ej=00AN
S5j;FVaJK@=NK@=JK@03GVeJKEY^009JK@03GVeJKEY]009JK@03FViJKEY=009JK@08FVaJBeY/FVaJ
JeI<ETeFC0=JB`9JC0AJC@9FC@9FCP03ETmFCEI=00=FC003ET]FBUI;00=FB`04DT]FBeI;ET/2DT/4
DR/4DR`2ER`2DR`00dh/DR]B:`03DR/4DP/014h<CP]>:e8[1dh;0e8[0E8Z0E8X0E8;000322400`Q1
344<800234401PQ1224880@P22448@@88@0>220<80a0320<8@PP320801AQ>FENJf:]FU1JK`=NKP9N
K`04FVmNKei_GXl5GY0015j?GY1NT5j@15jA00ANT5jaGY1NT0UNT@06H[5RTF:@HXmNT6:A1F:a00AR
TEjBHY5RTPMR/@ER/P03H[5R/V:b00=R/PAR/@UV/@03I[9V/FJa00=V/@9V/P9Vd`=VdP9Vd@06I]1R
/5Y^FTeR/6;B0V:b00MRTVJbI]9ZdF[BI]9Vd@03I]82I]<00fKBI]=Vd`02I]82J]<3I]<4J_800f[B
I]9ZdP02J_84J_<00f[bJ]=ZlP03J_<00f[dJ_=Zl`07J_@00f[eJ_AZm003J_<2J_@016/EJ_AZm6[d
0flE0V/E00AZmF[dJ_A[5@=Zm004KaE_56lELcH4KaD5KaH2KcH00g<fKcI_=P03KaH016leKcI_=Vlf
0VlE0g<E0W<f0Vlg00=c=WMFMeH00g<f1Vlf16lg00=c=g=GLeL00W<f00Qg=WLeMcEg=GLfLeMcEW=G
0g<g00=cEgMFMeH00WMF0g=G00=gEgMFMeH01GMF00EgEGLeMcAg=7ME009g=@03McIgEWLf00Eg=P03
McEgEGLf00=c=P9c=@9c=P03LcEc=Vlf009c=P03KcIc=Vlf00Q_=P9c=P05KcE_=VlfKcIc=P02KcH5
KeL00fmFKcI_=P02LcH00g=FKeI_EP02KeH017<dLc=g<G<d0Vlf0VmF2Flf0Vle00=c=FleKcH01flf
0Vle1Flf00A_=G<dLcAc=0=c=@I_=@03LcE_=Flf00A_=@=_=0E_=@9_=PA_=@=_=003KcE_=6le00A_
=003Kc=_=6ld00=_=@03LcA_=Fld00E_=@A_=0=_509_=0E_=@9_50A_4`I_509_5@Y_4`I[4`9Zl`E_
4P04J_=^lfkcKa83Ja<3Ka800f/CJ_=Zl`0BJ_83J_45J_84J_43J]401F[aJ]5VdVKAI]800VKa26KA
0VKB00EVdFKBI]5VdFK@00AVd@03H]5VdF;A00QRd@EVd09R/003H]1R/6:`00ER[`9V[`AR/003HZmR
/6:`009R/0QR[`9N[`AN[P03GZeNSUj=009NSP=NS`03GXiNSej?009NSP03GXmNSUj>009NS@03GXaN
SEj=009NSP03HXeNSEj=009NS@07GXaNSUj?GViNKEY]GVd01UY]0eY^00EJKEY^FViJKEY=009JK@06
FViJK5Y/FVaJKEI;0eI<00=FBeY;FT/00UY<0eY=00IFC5I=ETaFCUI=ETh2ETd3ET`4ET/00eI<ET]F
B`04DT/2DR`00e8[DRaB;003DR`00e8[ERaB;003DR`3DR/0158/CRa>;58<0U8;0Th<34h;0Dh:0E89
0E7[00000`Q1324<@@0634452243220332003@a0320<80`P30080111<B=BBej=FW1JKei]009NKP03
FViNKUi^00ANKP04GXiNSej>GXh3GXl3GY000ejAGY1NS`04GY07GY401V:AGY5RTEjAHY1NT@iR/@QR
/P03H[5R/V:a00=R/PAR/@=V/@=R/@=V/@04I[9V/FJbI]84I[83I]82I]42I]002fK?H[1RSei]HXmR
/FJbHY5RTVJcI]800V[B00EZdf[BI]9VdV[C00IVd`06I]9VdfKCJ]=Zlf[C0V[B1f[b0f[c0V[b00=Z
df[bJ_802V[c0V[d00=ZmF[dJ_@00f[c0f[d00=^m6lDKa@00VlD0VlE00=[5F[eJ_@00V/D16[d1VlE
00A_=FlfKaI[5P9_5P03KaE_5VlF009_=P9_5P03KcI_=Flf009_=P=_5@06LaEc57LeLaI_5flf0W<f
00IcEW<fKcIc=GLeLcD2KcH2LcH2LeH01GMGKcI_=flgMeL00W]G00EkEWLfLcEg=WLe00=c=P03MeIg
=W<f009c=PAgEP06McIc=W<fMeIkMWMf0W<f00=gEW]DNcD017]D00UkDg]DOeAkEG/fMcIg=G]ENe@0
0g]E0WLe0WLd1G<e1G<f00=g=G<fLcH00W<e0Vlf00=c=W<eKcD00fle1Flf00M_=fmGKeM_EfmFKeM_
EP05KcH2KeH01g=FKeEc<fldMc=c=6le00a_=P06KcEc=G<eLcAcEFmE3Flf0g<e0W<d0W<e0Vle0W<e
00A_=G<eLcEc=@9_=@04LcE_=FleLc@2Kc@3KcD00g<dKcEc=P02LcH016lfKcE_=Fld0fle3Fld0Vle
0Vld00E_=FldKcA_<fld00A_5003KcA_=Fle00A_=@03KaE_56lC00=_4`A_50=_5@05K_E_56lCKa=_
4P06Ka<00flBJa=[4`04Ja<5Ka<00flBK_9^l`02K_<016[bJ_=Zlf[c0V[b00I_4V/CJa=[4flBJa<H
J_84J_401F[`I]5ZlF[bJ_400VKB00AVlVKaI_5Vl@=Vd@03I_5VlVKA009Vd@03I]9VdFKA00]Vd@MR
d@EVd09V[`=R/0]R[`03H[1R/F:a009R/0=R[`04H[1R[f:_GZl5GZh2GZl015j^GXiN[Ej>0ej?1Ej>
0ej?00YNSUj=GXaNReY[GXaRSF:>HXeNS09NS@9NK003FVeNK5i/00ENK09JK@9JK003FVeJKUY^00=J
KP03FVeJC5Y/009JK@=JC@06FTaJBeY[FV]FK5Y[15Y;0UY<0eY=0UY<00AJBeI<ET]FC@=FC003ET]F
BUI;00EFB`=BB`9B;004DR]B;5H[DR/2ER/00eHZER]B:`03DR`3DR/0158/CRa>;58/0U8<0Th<1Dh;
00=>:dh;CR/00dh;00=B2dh:DPP00E7[00000`Q1344<8@07344010`Q344<@@a11@`P0Pa00``P00T8
00@0320a0dhZGXiJKeY>GVh00Ui_00EJKei^GViNKUj>00=NKP03GXmNSUj>00=NS`ENT005GXmNT5j@
GY5NT006GY42HY42GY4015jaH[1R/EjA0V:A00=NTF:aH[801F:a00ANTF:aH[5R/@UR/P03H[5R/V:b
00=R/PQR/@9V/@05I]5VdVKBI]9V/@02I[82I[<3I]83I]4036KBI]5RdF:^HXeRSf:`I[1RT6:AH[9V
dP9ZdP04J]=VdVKBI]87I]<00fKBI]=Vd`03I_<3J_82J_<3I_<?J_<00f[dK_=Zm003J_@2J_D6J_@4
K_@016lEKaA_5F[d0V[e00E[5FlEKcI_5F/E009Zm004KaE_=VlfLcH5KcH016/fJaI[5Vlf0W=G00U_
EflgKcI_=VlFKcIc=g=GLcL00W<f0WLf00Mc=FlEKaE_5FlFKcIcEP02MeL00g=GLcIc=P03MeH017MG
NeIgEg=G0Vlf00=_=g<gKcL00VlF00A_=g=HMeMcE`=_=P03LcMkEWLf009c5@9c=P08MeIg=W<fMcIg
EW]hMeQcF09gE`Ec=@09McEg=7LdNcAg57LdNcEk=WLf009g=@03NcEg=WLf009g=P9g=@Ec=@03KcE_
=W<f00=c=P06LcEc=W<fLcEc=6le36lf16lg0VmG00=_EW=FKcH00Vlf00Ac=VmFKeIcEPEcE@03LeI_
=Vlf00a_=P05LcEcEG=ELeE_E@03KcH00fleKcI_=P06KcH00fleKcIc=@04LcD00g<fKcI_=P0:KcD0
0fldKcEc=003KcD2LcD00g<fKcI_=P02KcH00fleKcA_=@04KcD2Kc@00flcKcA_=004Kc@4KcD2Kc@0
0fleKcA_=002Kc@01flcKcAc<flCKcA_=FlE00=_=@03KaE_=FlD00M_4`03KaA_5FlD00=_509_4`03
Ka9_4flC00=_4`03J_=_4V/C00A[4`M_4`03K_9^lfkc00AZl`06Ja=ZlV[bJ_9[4f[c1V[b00=Zlf[b
J_802F[b00=Zlf[bJ_801V[b16[a00EZlV[cJ_9ZlVKA009VdP03I_9VlFKa00EVl@03I_9VdVKA00EV
d@05I]9VdFKBI]5VdP05I]401F;BH]5RdF:aH]400V;B0VKA0VK@0fJ_0V:_00=R/6:_H[000f:_00=R
/6:_H[000f:`0f:a00=N/6:`HZl00V:`0V:_00AN/5j_GZmN[P=N[`AN[P03GXiNSej?00=NS`03GXiN
Sej>00ANS`06GVmNKEj=GXeNSUj=0ej>00=NSEi/GV`01Ui/00AJJei/GVaNK0AJK@MJKP=JK007FVeJ
CEY=FTaJBeY<EVd00UI/00=JJeI;FT/00UY;0UY<0eY=15Y<00=FBeI<ET/00eI;0eI:0UI;00=BC5I;
ET/00U9;0U8/00=B:e8/DR/00UH[00AB:eHZER]B:`=B;0=B:`04DRa>;4h/DR`2DP`00dh/CPa>2`06
CP/00dh<CRa>3002CP/1CPX1DPT1DN/00004344<80`P320434402@a2468@HPa2368<@@a0320<@003
320030a0464@HA10320400P0;>AB:Uj^GXmJCP=NK`03FVmNKUi^00ENKP=NSP=NS`ENT003GXmNT5j@
009NT003GY5NT5jA00QNT@05H[1R/F:@GY5RT@03GY47H[400f:AH[5R/@08H[800fJbH[9R/P03H[86
H[44I[43I]4016JbI[5V/VJb0VJc00=VdVKAI]8016KB00]VdFK@IZeNK6:>HZmV[V9^HY5R/FKA009Z
d@04I]9VdFKBI]85I]<8I]800f[BJ_9ZlP04J_<00f[dJ_=Zl`07J_<00f[dJ_=Zl`02J_<3K_<2J_@0
16[eJ_AZmF[e1F[d00=^lfkdK_@00VlE0VlD00=_5F[dJ_@00VlE0V[d00aZlf[dJ_=Zlf[dI]=Zlf/D
J_=Vlf[cJa@3I_@3JaD01f[dJaE_5F/EJ_AZlf[d009_5@9Zm0A_5003J_AZlf[c009Zm005J_=Zm6Kc
I_=Zl`02Ka@00f/DKaA[5003J_@2J_<2I_@6J_@026/EJ_AZm6[dJ_E[5F[dK_@2J_<3J_@3Ka@00f/D
JaE[5002Ka@2Ka<00fkcK_A_5002Ka@00flEKaA_5@02K_@00flDKaE_5004KaD02F/EKaIc=W=FKcEc
=WMFMeEc=004LcD2NeD01WLeLcEc=GLdMc=c=@A_=P9_=@03LcE_=Vlf00A_=P=_=`03KcI_EVmF009c
EP9_=P05LcIcEVmFLeI_EP03LeH016lfLeIcEVlf0Vle1flf0Vle0W<e0VmF0fle00A_EW<eKcE_=@A_
=PAc=@04KcIc=FleLcD;KcD8Kc@2KcD3LcD3KcH2KcD00fldKcE_=@02Kc@00fleKcA_=002Kc<3Kc@2
Kc<4Kc@3KcD4Kc@2Kc<01G<bKa=_4fldKaD01VlD1VlC00=_4VlCKc@01VlC0flB0flC00=ZlflBK_80
1F/C0flC0flB0fkb00=_4V/CJa<00V/C00E_4V[bJ_9ZlV[c00=ZlP03K_9ZlV[b00eZlP9Zl@IZlP05
J_5ZdF[aJ_5Zd@09I]400f[aI_5Vl@0EI]4016;AG[1RdF;B0f;A00=VdFK@IZl00VK@00=V[f:_HZl0
26:_16:`0V:a00=R/6:_GZl016:_00MR[Uj?GXmNSf:^GZmR[P02GXh2GZh3GXh4GXl01Ej>GXmNSUj?
GXh00Uj?00=NKej>GXh01Ej=00=NSUj=GXd00Ui[0Ui/00=NS5i/GV`015i/00ANKEY]FVeJK@IJKP9J
K004FTaJBeY<FV`2FT`2FT/015I<FV]FK5Y[0eI;00QJBeY<ET]FC5Y=ETeJK5I<0UI;0UY:00=FBUI;
ETX015I:0UI;00EFC5I;ET]BBe8[009BB`9B:`03ER]F:UHZ009F:P9B:`03DRaB:e8[00=B:`=B;005
DP]B:e8[CR]B2`02CP/3CR/2CP/00dh<CRaB;002CP/1CPX1DPT1CN/000D<@@@@HP0:48<DQ1B448<<
@@a0320<@0`Q344446802aB2560400@0:>A>:Uj=G[1JKUi^GVl00UY_0UY^1Ui^00=NSUj?GXl00Uj?
00=NT5ZAFY400Uj@00ENSej@GY1NTEj@00QNT@03G[5NTEjA009R/@03HY1RTF:@00=NT@AR/@04GY5N
/V:aHY43H[49H[83H[43H[82H[45I[42I]82I]401VKBI[9V/VJbI[=V/PIVdP0=I]=VdVKAI/iRSEi_
GY1R/69_HY5V/VKAI]800V[B00AVdVKcI_=Ve0QVd`9Vl`9VdP03J_9Zlf[C009Zl`03J]=Zlf[d00UZ
l`03J_AZlf[c00=Zl`06K_=_56lEJ_AZmF[d0V[e16[d00=ZmFkdK_D00VlE0V[d0V[c00AZdfKCI]=V
/PAR/@05H[1R/F:AHY1NT002H[4025jaGY1N/EjbGY9NTEj@GY44G[83H[8016:aH[9R/V:b16:a0V:@
00AR/F:bH[9NT@=NT0IR/@9V/PAR/P07H[=R/Ui`FVmNT6JaH[400V:@0V:a0f:b00=R/F:AHY400VJa
00AV/6:@HY1R/09ZdP03I[5RSfJ?009Zd@09I[5RTF:@I[1VdV[cJ_AZdfJb009V/@07J]9ZdfJbI]9V
/F:aI]<00fKD00=Vlf[dJaD00Vlf0Vle00I_=W<eLcEg=G<fMcD2LcH00g<DLcEc=@04KcH3KcD6KcH2
KcL00g<gLcI_E`02KeH5LeH00fmFLeI_EP02LeH016lfLeIcEVmF0Vlf00=_=FlfKcH02Vlf00A_EW<e
LcEc=@=_E@=_=P03KeI_=W<e009c=@04KcE_=VlfKcH5KcD3KcH<KcD00g<fKcEc=@02KcD4KcH3KcD3
Lc@3KcD5Kc@2Kc<4Kc@00fleKcA_=@03KcD6Kc@01FleKaE_56lDKaD01FlD00E_4flBKc=_<Vld009_
509_4`03La=_4flB009_4P03Ka=_4VlC009_4`04J_=_4VlBJ_<5Ja<3Ka<4Ka800f[bKa9[4`03Ja<0
16lBJ_=Zlf[c16[b00=^lV[bJ_800V[b00=Zlf[bJ_8026[b0V[a1V[b00EZlF[AJ_5ZlF[A00UVd@04
J]5VlFKAI]83I]42I]800f;AI]5VdP02I]800fKAI]9Vd@06I]402FKBH]9RdF;AH]9RdF:bH]5R/@02
I[02I]000fJ_HZmR[`07HZl8H[0016:_H[1R/6:`0V:_00QR[Uj?H[1NT5j?GZmR[Uj?0ej>0Uj?00=N
SUj?GXl01Uj?1Uj>0ej=00QNKUj=GXiR[Uj>GXeNJei/0UY]1Ei]00=JKEY^FVh01EY^0UY]0UY/00=J
BeY<FT`00UY<00MJK5i;FT]JCEI=FVaFK@05ET`00eI=ETaFC002ETd4ET`2ET/01EY:ET]FBeI;ERX0
0UI:00EFBeI<ERaF;59<00ABB`9B:`03ER]F:UHZ009F:P=B;0EB:`9B;09B2`9B:`03DP]B2Th;00I>
:`9>3005DPa>2dh;CP]>2@01CN`00007340<80`P320<@A1S46800Pa10Pa200H<@@a2344<@0`P3242
320030`Q320<811Q688DH0P0204Xi4GXEVeNS@9NK@05GViNKeY_GViNK`04GVh00ej>GXmNS`04GXl3
GY000ej?GY1NT002GY09GY400f:AGY5NT@03GY400f:aGY5RT002HY000f:AH[5R/@03H[400ejbH[5R
/@02H[42H[800f:aH[9V/P04H[84H[43H[800fJbI[5V/002H[42I[42I[800fJaI]1V/@02I[800fKB
I]=VdP07I]802fKCI]5VcV:^GVmNT5i_HW1RTFKBI]400f[B0VKB0fKc1fKC0VKc16[c00EZdf[cJ_=Z
lf[B019Zl`04J_AZlf[dJ_<4J_@016[eK_A^m6kd0f[e00I[5F[dI]9V/F9_HW02GVl02UY>FTeJC5X[
EPYB2eX/ER]B2eH/0UH]00aB;E8=DPeB;EH_ERiJCUI?ERiB;UI?ERl2ETh00eH]ETmJC`02FTl00eY>
FTeFC@02FTd01EI=FTmJL5Z@GY000Ui_015JKUI<FTaJCEi]FVeJCUi^GVmNL5Y?GVmNLEi`GVmNT6:@
00=RS`07HVmRSf:@HY1R/F:bHY400V:@00AVSfJ`IZmV/0AV/@9V/009J[1Z/FZ`I[5V/V[BJ]5VdV[C
009VdP05J]=ZdVJbJ[9V/P02IY401F:@I[9V/V:BGY800Uia00ERTEj@HY5VdV[c009[5003JaE_5Flf
009_=P04KaI_5FlELaD2LcD3KcH2KcD00g<eKcE_=@06KcH5LcH4LeH017<fLeIc=W<f1W=F00A_=Vle
LcE_=P=c=@03KcEc=Flf00I_=P0;LcE_=G<eLcEc=7<eKcI_=FlfKeIcE@05LcD00fleKcI_=P03KcH2
KcD2LcD8KcD00g<eKcE_=@03KcD00g<dKcE_=@07KcD3Lc@5KcD2Kc@00flcLc=_=002Kc@00flcKcA_
=002Kc@4KcD5Kc@00fleKaA_5005Ka@2Ka<026lBLa1_4FlAJ_5ZlflDKa<6Ka800flCKa9_4`05Ka<3
Ja<00flCJa=_4`05Ka<01FlBK_9^lVkbKa<00f/C00I_4V[cJ_=Zlf[bJ_<2J_800fkbJ_9ZlP0;J_84
J_42J_8016[cJ_9ZlV[A0f[a0f[A00=VdFK@I]401FKA00IZdFKaI_5VlV[bI]44I]800fKAI]9VdP02
I]85I]4016K@I]5VdVKB0V;A00AVd6;AH]5V/P9R/@05I[5V/6K@I]1V[`09HZl3H[04HZl00ej_HZiR
[`02HZl3HZh01ej?GY1RSf:?GXmNSUj?00=NSP9NS`ANSPANS`03GXiNSEj=00]NS@9NK09NJ`03FVaJ
KEY]00EJK@IJKP03FVeJK5Y/00=JK0=JC09JJ`04GTYJBeY=FTd2FV`015I<ETeFCEI^0UI=0UY=00EF
BeI<ETaFC5Y/009JC004ET]FBUI;ET/4ETX015I;ETaF;5H/0e8/00EF:e8[ER]B:eH[00AF:PeB:`05
DRY>2dh:CR]>:P03CR/3CP/01Th<DPa>2e8;CP]>2@5=k00000D<@@`P320<80`Q008<@@03224880PQ
00D<@@0A320<8@`P320<8A0Q320@@1AQ440400P09<A1bEI_GZiJK@02GVd2GVl015i^GVmNKUY_0Ui_
00=NSUj?GXl015j?0ej@00=NSej@GY000Uj@35jA1Eja00=R/6:@HY001F:a00ANTEjbH[5R/PMR/@AR
/P05H]=VdV;BH]5R/@02H[800fJbH]5V/002H[43H[801FJbI[5V/FJaI[800fKC00=VdVKCI]800fKB
0VKC00mVdVKAI/mR[eY>GW1RSf:@H[5RdVKBI]=VdV[BJ_800VKc0fKC00=Ve6KCI]<00fKC0fKc0V[c
00AZm6[cJ_=Zl`9Zd`aZl`=Zm003J_=Zm6[d00=Zm007J_=Zm6[dJ_AZmF[dK_<016[d00mZmFKDH[=R
TEi^FR]F2U7XDNUB2UH:DPUAjDgYDNX00U8:00==jE8:ER`00U8/00AB;EH]EReB;09B30EB;@09DRaF
CEI=DReB358;DPaF35H/009F;@03ETeFC5I=009FC@04FTeFCEH/ER`4ER/01EH9ER]J:eH/FR`00UX]
00=JCEY<FTd00Ui^00ANKEi^GVeNK@9NC004GVeRKf9`GY02HY02HXl2IXh4IXl3IY001FJ?IZmV/FJb
I]801FKA0fJa00IV/6JaI[5V/FJ@HY02HY42GVl02Ei>FReJ;Ei>HY1VdFKBJ_A[5@06KaD016lDKaE_
5Fle0flf00=c=G<fKcD01flf27<f2W=F00A_=W=FLeIcEP9_=P=c=@9_=@Q_=P09KeEc=G<eLcAc=GMD
LcE_=VmF00e_=P03LcIc=G<e00a_=@03LcE_=G<e00I_=@=_=P=_=@9c=0=_=@9c=0=_=003KcE_=6ld
00A_=0A_=@E_=003KcE_56lD00I_5005Ka=c<g<ALa5_4@02Ka<00flDKa=_4`04Ka<00flBKa=_4P06
Ka<7Ja<4Ka84K_8026lCJa=[4flCKa9Zlf[bJ_<2J_8016lBJ_=ZlV[b0Vkb2V[b0f[a00=ZlV[aJ_80
0f[b0V[A00AVlVKAI_5Vl@9Vd@03J]5VdFKA00=Vd@9VdP06I_9VlFKbI_9VdVKA0fKB00=VdFKBI]40
0VKA00AVdVKAI]5Vd09Vd@03H]5VdVKA009Vd@04I]1RdF;AI[83H[4016J`H]5R/F:`16:_1V:`00=R
/F:`H[000V:_00MR[Uj`HZmNSf:_H[1R[`02HZh00ej`GY1RS`02HXl2GXl3GXh2GXl4GXh3GXl3GXh0
0ei^GXeNS@08GXd5GV`2FV`6FVd3FVh00eY]FViJKP03FVd4FV`01UY<FT]JBeY<FV]JC0AJC@04FTaF
CEY/EVh2ETd2FTd3ET/2FT`2FTd015I<ET]FBeI;0UI:0eI;00=F;59<DR`00U8/0eH[00=B:e8/DR/0
0eHZ00=B:dh/DR/02E8[0Th[0Th<00A>;4h[CR]>:`A>2`9>;09>309>2`5>2P5>300000D40@PQ2208
8@a000@88003244<@0a100@<@@03324<80`P00D<8008200000@07:@mREZ?GZiJK@9NK@05GViNSej>
GXmNKP03GVl00ej>GXmNS`08GXl3GY000ej?GY1NT@07GY4015j@GY5NTEjA0Uja00ER/EjAHY1RT6:`
009R/@08H[9R/EjAGY5N/F:aH[9R/@9RT@04HY1R/6:aH[02H[400f:bH[5RT@02H[42H[03H[8016:a
I[1R/F:a0f:b00=V/VJaI]400VJb2FKB00IVdf:aI]5Vd6K?HY02GVl00f:>HXmR/@04I]800f[BJ_9V
dP03I]800fKCJ]=Vd`04I]84I_<016[bJ_=Zlf[c0f[C1F[c00=ZlV[cJ_<01F[c16[d00I_56[dJ_AZ
m6[cJ]<3J_@00flDK_9^lP02J_801f[aI]9R/UY?ERaJ;5X800=F2004DNUB2EHYERX2DPX01UH:ERYF
2EH9ERYF:`=FC005ETeFC58<DP]B3002DR`01U8;DRaF:eH[ERaFC09F;007EReF;5H[ERaFC5H/ERX0
0UY;15H[00EF:UX[ER]F:UY;00=JBP9JB`=J:`04FT]JC5Y<FT`2FR/00eY<FT]NBP03GT/00ei=GVeN
K@02GVd00ei/HVaRK002HV`0169[HVaRKEi^0V:?00ARKF:?HXmRS`9RT004IZmR[f:>HXl2HXh00fJ_
IXmVS`02IXl2HXh0369^GVeNC5i<FT]J:ei<FTaJCEj>I]5ZlP9_5003JaA_5Fkd009^m09_5@03KcE_
=Vle00I_=@E_=P04LeIc=W<fKcL4LcH;LeH00flfLeE_=P06LcD00fleKcI_=P06KcH00fleLcEc=@02
LcD017<dLcE_=Vlf0W=F00=c=FleKcH00flf00=_=FlfKcH00Vlg00=_=W<eLcD016le00Ec=FleKcE_
=Fld00I_=@Ac=@9_=@9_=P=_=@07KcA_=G<dKcEc=6ldLc<00Vld00=c=6ldKcD01fld0fle0Vld0flC
0VlD0Vld0flD00=_4flDKa<03FlC0flB1VlC00=[4flCJa<00f/C00=Zlf[bK_801Vkb00a_4V/CJa=[
4flCKa9^lV[aJ_9[4flBJ_<7J_8016[aJ_9ZlV[b16[a00=ZdF[aJ_400f[a0V[b0V[A00AVlVKaI_5V
l@QVd@9VdP03I_9ZdF[A009Vd@03I]9VdFKA00=Vd@03I]1VdFKA009Vd@04I[1Vd6K@I]02H]401FJ`
I]5V/6K@H]400f:a00=V/FKAI[000V:`0V:_00=V[f:_IZl02F:`0V:_00MR[V:_GXmNSf:_H[1R[`02
HZh015j`GXmRSf:?0V:>00AR[Uj>GXeNS@ENSP04GViNSUj?GXl2GXh00ei^GXiNS@08GXd00ei]GVaN
K003GV`3FV`00eY]GVeNK002GV`00eY]FVaJK@04FVd6FV`00eY[FTaJB`02FT/2FT`3FTd015Y<FVaJ
JeI]0UI=00=FC5Y<FT/00eI;00AJC5I<ETaFC0AFB`05ETYFBeI;ET]F:`02DT`2DR`3ER/0158[DRaB
:e8[0eHZ258[14h[1Dh/1Dh;0Th[00A>;4h<CP]>2`9>2P5>300000D8@@`Q344<@@`P00888@08220<
@@a1364@HPaR468<HP<<@@04324<80`P220332002000200HPcEWDW1N[ej>GVd2GVh3FVl01Ei_GY1N
Sei_GXh015j?1Uj@00ANTEj@GY5NT0UNT@03GY1NTEjB00=N/@03GY5NT6:@009R/0=R/@08G[5N/Ujb
G[9R/EjAHY5R/@9RT@=R/@09H[9R/F:bH[5RTF:@GY5R/6:a00=R/P=Rd@03I[9R/V:b009R/P03I[9V
dFKB009VdP=Vd`AVdP9Vd`0<I_=VlFK@IZmRSei_GViNKf:@H[5VdVKA16KB0fKC00EVdVKCI]=Vdf[b
00MVl`07J_9Zlf[bJ_=^lf[cJ]801F[c00AZlV[cJ_=Zm0EZl`AZm004J_EZm6[dJ_@2KaD04FlFJaE[
56lCK_5^lV[bJ_5R/EY?FTeNCEX[FRUJBEXXFTT01EY:0eY;00YJ:EXZGTaJKEY<FTeJKEY=FVeFC@MF
C006ET]F:eI<FVaJKEY<0UY>00=FCUI=ETd00UI<00EF:UH/FTeJKEY;009J:P03FVaNJei/00=NJ`07
FV]NJei[GV]NBUXYFT/015i/00ENBei/HXaRSEi/009NK@08GXiNKEi]GXeRSF:;GV]RJ`9NB`07HVaR
SV:?HVmNKV9]HXl00V:>0f:?00ER[f:?HXmRSej>00=RSP08HXmV[f:?IXiRSEi/GT]JBP9JC00;FT]J
:UX[FTeRT6JaI_=Zlf/DJaEZm@02K_@00f[dJ_E[5@02JaD00f/eKcE_=@02LcD00fleKcI_=P06KcH3
KcL5KcH016mFKcI_=Vlf0W=F0g<f00AcEW<fLcE_=@=c=@9_=@M_=P=c=@=_E@07KcE_=VlfKcIcEVlf
KcD01Flf00=_EFlfKcH00flg0Vlf16le00=c=FleKcD02Fle00=c=G<dLcD00Vle00=_=VleKcD00Vle
00=_=6leKcD00fle00=_=6leKcD01Fle1Fld00=_=FldKcD01Fld2VlD2VlC0VlD00A_4flBKa9_4PI_
4`03Ja=_4f/C009[4`9Zl`03Ka=^lVlB00=^lP03Ka=_4V[b00=Zl`I[4`9Zl`=ZlP03K_=ZlV[b00=Z
lP04J_=ZlV[bJ_42J_801f[AJ]9ZdV[bI_9VlFKb00=ZdP03I]9VlVKb009VdP03I]5VdVKB00IVdP08
I_9ZdVKAI]5Vlf[bI_9Vd@9VdP9Vd@03I]9VlVKA009Vd@=Vd09Rd@04H[5V/6KAI]42H]43H[4016:`
H[5R/F:a0f:`00=R[f:^H[000V:a26:`00AR[ej?GXmN/09R/09R[`9N[`03GXmNSV:>009RS`=NS`IN
SP9NKP03GXiNSej>009NSP04FViJSUZ>GXd5GXh00ej=GVeJK008FV`015Y]GXeNJeY[0eY]00AJK5Y]
FViJKP9JK@IJK003FTaJBeY;009JC0=JC@9FC@=FC09FB`03ETaJBeI<009FC006ET]FC5I<ETaFBeI<
0eI;0eI<00EF;59<DTaBC5H/009F:`03ERaB;58/009B;0EB:`05DRaB:e8[DR]>;005CR/5CR`4CP/3
CR/014h/CPa:34h;0Th:0Dh<00000`aQ344<@@0334400`PQ22088@0222400`Q1344<8@0232023443
32003PPP320<80a0100801QR>FQBL5j>FViJKEi]GVh2FVl00ei_GViNKP04GXh00ej?GY1NT007GY0<
GY4015j@GY5N/UjA0V:`0V:@1F:`0eja00=R/EjbH[401F:a16:b00ER/FJaH[5RT6:?009RT09R/@03
H[9R/F:a00AR/@=R/P05I[9VdFKAI]5VdP02I[85I]8016KCI]9VdF[a0VK@00YRSei]FRaNCej@I[5V
dVKAI]9ZdP9VdP03I]=ZdfKC009VdP=ZdP03I]9Zlf[C00=Zl`03J_9ZdV[b00=Zl@9ZlPAZl`=ZlPIZ
l`9Zm003KaAZm6lE00=_5@0BJ_A_5F[eJ_A[56[cKa9ZdF[bJ]9Vd6:?GViJCEY;FTYNBF9[0V::1F:;
1F:<00]RSF:>HXiRSUi^FVeNSF:=GXaNSF:>009NS@04GXaJBeY;GV`2GXd015j>HXiNKei_0UY>00=N
KUi]GXd00Uj>00ENKEY<GXaRS69[009RS0=NK09RS0ARJP05HXYRRf9[HVaRS003HXd00fJ=HXiRSP03
HXh2HZh4HX`00fJ/IZeRS002IXh02VJ?I[1VSf:>IXmV[f:>HVeRSVJ_0f:?1V:_00=V[f:^HXd00VJ]
00=RS5i[GTX00UXZ00QNBUi;EPYB2eY>I[5VdV/D1f[d0V/E00A_56ldKcE_=P9c=@e_=P04KcE_=Vle
KcH3LcD01G=FLcIc=W=FLcH00Vlf00=c=G=FLcD00W<e0Vle00=_=VleKcH00Vlf17<e00=c=7<eKcD0
0flf0fle00=_=W<eKcD016le00=c=6leKcD01Flf0Vle0g<e00=_=G<eLcD00W<e16le0W<d26le0W<e
00=c<g<dLc@00fle00=c=6leKcD01Fle0Vld00=_<fldKc<00Vld00=_=FldKc@00Vld1FlD0VlC00=_
56lCKa<00VlC0VlD1flC0VlD00=_4flBKa800VlC00=_4VkcK_<01VlC00=[4flBKa8016lB1Fkb0f[c
0f[b00AZlf/CJa=Zl`AZlPMZl`9ZlP03J_5ZlV[b00EZlP03J_5ZdV[A009ZdP08I]9ZlV[bI]5VdVKA
I]9VlPAVdP04I_9VlFKbJ]83I]83I]42I]83I]47I]0026KAH]5RdFK@H]5VdF;AI]44H[05H[42H[00
0fJ_H[1R/003H[000f:_H[1R/004H[02HZl2G[0016:`HZmR[f:_16:^00ANSf:?GXmNS`ENSP04GXeN
SUi^GVh2GXh00ej=GXiNKP03GXh01ej=GXiNSUj>GVeJKEi/00=JJ`03GVaJK5Y]009JK@=JK09JJ`06
GVaJKEY]FVeJK5Y]0eY^0UY]00=JK5Y[FT/00UY/00=JBeY:FTX00UY;00AJC5Y=FTeJC@9FC@04ETaJ
BUY:FTX2FT/2FT`00eI<ETYFB`02ET/015I<ETeFCEI<15H[00EF;59<DTaBC58[009F:`EB;09B:`AB
;0=B:`=>:`=B:`03CRaB;4h/00=>:`=>2`=>:`04CRa>2dh;CP/2CPX1CP`00003364<@@a100<<@@03
224880@P00888@0624488@PQ220<80a00Pa100h<8@a122488@PP340<@P@0568iIe9@GXiJKeY^0UY_
0Ui^00ANKei^GViNKPANS`ANT0=NT@=NT0eNT@03GY9R/F:@009RT09R/0=R/@03H[1N/Eja009N/@=N
/P03H[5R/V:b00ER/P07I[9R/FJaHXmRSUi_GY000V:a00=R/V:aH[401F:a0VJb00MVdVKAI]5VdFKB
I[9V/`02I]<3I]800fKCI]9VdP02I]402f[@H[1RKeX]FRiNLFJaI]9VdFKBJ]800VKB0f[C1F[B0V[C
1F[c0V[b00=ZlF[bJ_800V[b1f[c00=ZlV[cJ_@01V[d1flE011Zm6lEJaA[56lBJ_9ZdFKAHY1RSej?
GViRSF:^IZiVc`EZcP9VcP04I/mVd6[?IZh4I]000fKAI]9Vd@02I]0016K?I]1Vd6K@0VJ_0VK@00=V
cfJ^I/l00VK@00EVdVKAI[5V/6Ja009V/0AVd@03I/mV[fK>009Vc`=Vd0AVc`9VcP=ZcPIZd09Zd@05
I]5Vd6K@I_5ZlP02J_402F[@J_1Zkf[`K_1Zl6k`K_5Zd@04J]84J_800f[cJ_9ZlP06J_83J_4046[b
J_5ZdFJ_IXiRS5i;GV]NC5X[ENYF2eY>H[5Zm6[c0V[d00=ZmF[dJ_@00V[d00E[5FlEKcE_=VlE009_
=@03KcI_=Fle00=_=@9_=P03KcM_=Vlg009_=P04KcE_=VlfKcH2KcD00g<eLcIgE@02LeH00g<fKcIc
=P03LeH2LcD2KcH00g<fLcEc=@03LcD016lfKcEc=G<e0g<f0Vlf00=_=G<eLcD017<e0fle00Ac=7<e
LcEc=@A_=P04KcEc=G<eLcD2KcD2LcD8Lc@:KcD00g<dLcEc=006KcD00flfKcE_=@02KcD2Kc@00flc
KcA_<`02Kc@3KcD2Kc@016lCKaA_56lD0VlC1VlD0VlC00=_56lCKa<016lC00A_56lCKa=_4P=_4`=^
l`E_4`9Zl`9_4P9^lP03Ka9_4flC009^lP05Ka9^lV[bJ_9Zl`03J_8016[cJa=[4f[c16[b2F[c26[b
00EZlF[BJ]9Vlf[b009VdP04J_9VdFKBI]47I]800fKAI]9Vd@03I]800fKAI]9VdP02I]83I]43I]03
I]401FK@I]5RdF;AH]001F;A00=R/F:`H[001F:a0V:`00=R[f:`H[000f:`00=R[f:`H[001F:`0ej`
00AR/6:_HZmR[`9R[P9N[P03GZmNSej?009NS`05GXiNSej?GXiNS@03GVh00ej>GXmNSP02GVh3GXh0
1Uj=GXiNSEZ>GVeJK@=NK003FVeNK5i]00IJK@=JK0=JK@04FVaJKEY^FVh3FVd00eY^FVaJK@02FV`5
FT/2FT`3FTd00eI<ET]JBP02FTX015Y;FTYJBeY:0UY;0UI;00EFC5I=ETeFCEI<00AF:`05ERaBC59<
DTaB:`02ER/5DR`00e8[DRaB;002DR`00dh/DR]B:`03CR/3DR/014h[CRa>;58/0U8[0Th[00=:2dh[
CR/00Th[14h;0Dh[0Dh:0DX=00000`a132488@02224010Q1344<@@`Q10PQ00D880`P320<@0aR008<
@@8<@P0;22888@a0224000`P<BE>;UY^FXmNS`02FVh6GVh2GXh2GXl4GY000ejAGY1NT@02GY0015j?
GY1NT5j@15jA00=NT5jAGY401EjA0V:@0f:`0f:a0f:`0UjA00AN/V:aGY5R/@=R/P0;H[5R/V:bH[9R
/F:@I[1RSf:>HVeRT007H[42I[44I]42I]800fKAI[9V/P02I[<01FKCI]9VdVKBI]<00VKB00]ZdV[@
J_1R/F:?GTiNCejAI[5VdVKA009ZdP05I]9ZdVKBI]=VdP04J]801V[bJ_=Zlf[CJ_9Zl`UZlPEZl`03
J_9Zlf[b00=Zl`9^l`05KaAZm6[dKaA_5@02K_D016lEJ_AZm6[d0Vkd00QZlf[bJ_5Zd6J?GVmRSVJ_
0VK?00AZl6[aJ_5_4@=^l003Ka5ZlF[a00QZl@IZlPaZl@=ZlP9Zl`03J_9Zlf[c00=Zl`9ZlP03J_5Z
lV[b009Zl`EZlP9Zl@03Ka5^lF[a009ZlP04Ka9_4flCKa<4Ka@3Ja@6Ka<2Ka8026lAJ_5VdF[BK_9V
df[cJ_@2Ka@4Kc@6KcD3Kc@04FlDKa=ZlV[aJ]1V[V:<HV]NJei;FR]F2UX<GViVdF[bJ_<00V[d00=Z
lf[dJ_<00f[d00I[5FlEKaE_56leKcH3KcD2LcD4KcH2KcL3KcH2KcD6KcH016mEKcIcEW=F0W<f00=c
EG<eLcD00flf0W<e00Qc=7<eLcE_=VleLcIc=G<f16lf00=c=FleKcD00fle00Ec=FleKcE_=Fld00=c
=007LcE_=VlfKcEc=GMDLc@00fle00=c=FleKc@01Fle00=c=6ldKc@01Fle00=_=6leKcD00fle00E_
=6leKcE_=Fld00M_=@=_=0E_<`04KcA_<fldKc<4Ka<00flDKcA_=002KaD01FlDKa=_56lCKa@00VlC
00=_4VlCKa801FlC0flB00=_4f[dKa<00flC00E[4flCK_=^lf[c009_4P9^lPE_4P04Ka=^lVkbK_82
J_8016lBJ_9ZlV[b0V[c1V[b1f[c0V[b00=ZlF[bJ_800f[B00EZlF[BJ]9VlV[b00=VdPEVd@9VdPIV
d@=VdP04I]5VdVKBI]83I]44I]03I]401fK@I]5RdF;AH]1R/F:`00=R/@AR/0AR/@9R/003HZmR/6:_
00=R/0=R[`04GZmR[f:`H[02GZl00ej`HZiR[P02HZl2HZh00f:=GZiN[P04GXl2GXh025j?GXiNSUj=
GXiNKEi_GXl7GXh01Uj=GXiNSEj=GVeJK@=NK003GVeNK5i/00=NK09JK003FVeNK5Y/00EJK004FVeJ
K5Y^FVd2FTd00eY]FTaJC009FT/4FT`00eI;FTYJBP03FTX2FTT00eY:ETYFB`02ET/2ETd2ET`4ER/0
1EH/DRaFBe9;DR/00UH[1E8/1E8[00A>;4h;CR]B:`=>:`=>2`03CR]>;58[00Y>:`A>2`5>2P5>3@00
0PPP0PPQ00<<8@a134400Pa110PQ00@880`P320@@0<<@P0=46<<H`Q2248<@P@0000802d5CPiJKEZ>
GXh00UY^0ei^0UY_00=NSej>GXl00Uj?2Ej@0Ui`00=NT5jAGY001EjA00ANTUjAGY5NT@9NT005HY1R
/6:`H[1RT003H[43H[001UjAH[5N/V:aGY5R/@UR/P07H[5R/6J^GVeRT6:aH[0016:a16Ja00=RdFKA
I]400fKA0VKB0V:c00EVdfKBI]9VdVKC009VdP0<I]5Vd6K`H[5NT5Y>GTmRTFJaI[9VdVKC0V[C0fKB
00=Zdf[BJ]800V[B00EZlV[cJ_=Zlf[B00=Zl`=ZlP=Zl`03J_9Zlf[b00QZl`06K_=^m6kdKaA[5FlE
0Vkd0Vke0VlE00=_5VlEKa@00Vkc00]ZlV[AJ/iRSF:>I]1ZlF[bKa9_<flb00Q_<`03KcAc=6lc00A_
4`=_4P03Ka=c=6le009_=003Kc=[4flC00=_<`03LcA_=6lc009_=09[=0E_=@03KcA_=Fle00]_=@07
KcA_=FleKcE_=7<dMc@017<e00Mc=7LeMcEg=GMELcE_=P02LcD00gLeMcAg=002Mc@027<dLc=g<g]B
Ng1k<WLBNc<4Nc@01GLeMcIg=WLfMcD00W<f17=F00AgMWMELcEc=@9c=00?KcA_4f[aJ]1V[V:=GVaJ
:eXZFPYJ;6:?I]5Zm6[e00EZm007J_E[5F/DJaE_5FlDKcD00flf00E_=G<eLcEc=Vlf00E_=`9_=P05
KeI_=VlfKcI_EP05KcH2LeH2LcH00g=ELeI_=P03KcH5LcD3KcH3LcH3KcH2KcD2KcH4KcD01G<eKcEc
=7<eLc@00W<e0VmE0flf0W<d00=c=FleKcD01fle0fld4Vle00=_=VleKcD00Vle1Vld00I_<flDKaA_
56ldKcD2Kc@00flCKaA_5002Ka@00f/EKaE_5@02Ka@01FlCKaA_4flCKa802FlC00A_4VlCJa=[509_
4`03LcA_=FlC009^l`05J_=_4VlBK_9_4P02K_8016lBKa=_4VlB1F[b00=[4f[cJ_<00V[c16[b2V[c
0V[b00=ZlF[bJ]800f[B00AZlFKbI_5VlPAVdPEVd@=VdPEVd@9VdP03I]5Vd6KA00EVd@9Vd003I]5V
/6KA009Vd@06I]1VdF;AH]5Rd6;A16:a0f:`1f:a0V:`00AR[f:`H[1R/@=R/09R[`06H[1N/6:`HZmR
/6:_0V:^0ej_0ej^00=N[ej?GXl00Uj?00ENSUj?GXmNT5Z>009JS`9JT00:FVmJKUY^FXeNSUi^GXiN
Sej>GVd2FVd2FV`00eY]FViJKP02GVd3GV`3GVd00eY/FVeJK002FV`01UY^FVeJKEY]FViJK@9JC@03
FVeJCEY=009JC0MJB`05FTaJBeY;FT]FB`07FTX00eI:ET]FB`03ET/01EI<ERaB;5H/ET`00UH[00IB
:e9;DT]BBeH/ER/6DR`0158[DRaB;58/1Th/0Th[0dh;0dh[0Th;2Dh[14h;0Dh=0002220922401PPP
320<80`Q320@@08<@@8<@P0;2488@@Q224888@@0344Xi4W/GVaN[P02GVh01Ui]GViNKUi^GVmNS`=N
SP9NS`]NT003GY5NT5j@00ANT@9NTP03GY5R/6:`00ART0=R/0=R/@=R/003HY1RTEjA00UR/@=R/P05
I[5R[fJ]HXeRS`02H[000f:aI[5V/@0;I]42I]83I]<6I]801F[AJ]1Zl6;AHY000UY>00ERL6JaI]9V
dVKC009Zd`03I]9Zdf[B00MZdP=ZlPUZl`EZlP9Zl`=Zm09^l`9^m09_50=^m005K_E_5FlEK_A_5002
Ka<016kcJ_9ZdF[@0VJ]00AVd6[aKa5_4`9_<`07Lc9_<flcKc=c<flcLc<00Vlc0fld00=c=7LdMe<0
0g<c00Ac<VlcKcA_=0E_<`Q_=09_=@03LeE_=Fle00A_=@03LcAcEG=E009_=P03KcEgEG=E00=c=@03
MeEg=G<e009g=@04MeAgEGLeMcD2Ne@02WMDMcEgE7MDNe=gM7MDMeEgE7Md0W]d00IkU7ngNgEgDG^B
Oo/8Ool01gonNi]gFGMGMeIgMWMd00IgM@0DMeEgE7MCNg=kE7LdLcA_=6[aJ]1V[V9]GT]NBEX9FPYN
C6K?JaA[5@MZm09[509_5003KcE_=Vlf009_=@04KcIc=G<eLcD2KcH02FlgLcM_=flgKcI_EFmFKeE_
EP02KcD3KcH2LeH3KcH00g=ELeI_=P03KcH3LcD3KcD4LcD00fleKcIc=@0;KcD017<dLcEc=7<e0g<d
0fle00=c=G<dLc@00W<e1fle00=c=6ldLc@01fle0Vld00=_<fldLc@01fle16ld00=c<fldKc@00fld
0VlD16ld00=c<flcKa<00flD16lE0VlD0VlC00=_56lCKa8036lC00I[4flCKa=_4flDKa<2Ka800fkb
Ka9_4P04Ka<3Ka83J_83K_83J_82J_<4J_86J_<016[bJ_=Zlf[b0V[B00IZlF[bJ_9Zlf[bJ]43J_40
0fKAJ]5Vl@02I_4?I]400fK@I/mVd@02I]45I]04I]400fK@I/mVd002H]400fK@H[1Vd003H]45H[02
H[4016:`H[5R/F:`0V:_00MR/6:_H[1R/5jaH[1R[`02HZh00ej?HZiR[P02HZl2HZh4GZl3GZh016:^
HXiNSej>15j?0ej@00MNTEZ@FVmJKeY^GVaJK@02GVd2GVh00eY_GViJK@02GVd2GVh00eY^GVeNK@03
GV`4GVd015Y]GVaJK5Y/0eY]00=JK5Y]FVd00UY=0UY]0UY=00=JC5Y;FT/01UY;15Y:15Y;15Y:1EI;
00=BBe8[DR`00UH/00=FBeH[ET/00e9;00EF;5H[ER]B;58[00=B;008DR]B;58/DRa>;58/DR]>;0=B
:`03CR]>2dh;00=B:`03CP]>2Th:00=>:P03CR]>:Th[009>:`A>2`5B2`5>3@0000<8@0PP22401`PQ
0``Q00@880@0320@@0@<@@0<2448@PPR248<@P@0344Xi4G:GVaNSUi_15i^0ei_00=NSUj?GXl00Uj?
2Uj@0ejA00=NT5jAGY400UjA0UjB00=RTF:@HY001F:@0V:`1F:a00ER/6:aHY5R/F:A009RTP03H[9R
/F:a00=R/@=R/P05H[5R/6J_H[1RT002H[0016;AI[5V/FJa0fKA0VJa00=V/VKBI]8016KB0fKC1VKB
00UZdV[AJ_5VlV:`GVmJCf9_I[0016KC0f[C00AZdV[CJ]=Zd`AZdP03J_9Zlf[c009Vm0EVl`03J_=Z
m6[c009ZlPIZl`04J_AZlf[dJ_@4Ka@3K_@2KaD02g<DKaA^lfkcJ_9ZlF[`IZiVcf[aJa800Vlc0Vld
00=c=7<cLc<01W<c00Ac=7=DLeAcE@=c=004LeEcE7=DKe@2Le@016mELeAcE7MD27=D17=E0W=D27MD
17ME0WMd0WMe00IgUGMeMeEgEGMeNg@4MgD2NiH017^GNgEkMG]d0W^E00YkMG^ENiIofGolOoeooWoK
OkUof`]oo`08Ni]kNG^INiUk^GnjOkUk^09kU`0=NkQkUg^FNgEkLgMcMeAg=G<dKa=ZlF[AIZl00V9[
00INBeX:GRYV[flDKaD2J_D7J_@016lDKaE_5Flf0Vle00ac=FlfKcE_=W<eLcIc=G<fKcI_EflgKcH4
KeD2KcD8KcH00fmEKcI_=P03KcH2LcD017<fKcI_=Vlf0g<e00A_=G=FLeIcE@Ec=@M_=@Qc=@04LcIc
=FleLcD2KcD00flfKcE_=@0:KcD016ldKcE_=Fle0fld0fle00=_=6leKcD00fle16ld00=_<fldKc@0
0fld0VlD00A_5FleKcE_=@=_<`04KcA_56lDKa@2KaD3Ka@=Ka<5Ja<00f[cKa=_4`02Ka@00flCKa9^
lP02Ka<3Ja<2Ka<00flBJ_9ZlP02J_85K_82J_8016/CJ_9ZlV[c0V[b00=Zlf[bJ_<00V[c00AZlV[c
J_9ZlP=ZdP04J_9ZlfKcJ_<3J]83J]43I_4@I]4016K@I]5VdFKA1FK@1VKA0V;A00ARd6:`I]1Vd0=R
d@9R/09R[`03H[1R/F:`00ER/0=R[`=N/@9R[`05HZiRSV:?HZiR[`03H[04GZl4GZh00f:^GXiNS`05
GXl00eZ>FXmJS`02FVl2FTh01EY]GVaNSEj=GXh00Ui^00=NKeY^FVd00UY]0eY^15Y]00=NK5i]GV`0
0Ui]0Ui/0UY/0eY]00=JK5Y]FV`00UY=00IJKEY=FTeJCEY<FT/5FT`01EY;FTaJC5Y<ET/00UY<00AF
C5I:FTYJBP9FB`03ETaFBeI<009FB`9BB`05DRaBBe9;DTaF;002ET/3DT/01E8/ER]F:eH/DR/00e8/
00=B:e8/DR`00e8/1U8[0Th[00=B:dh[CP/00Th;00A>2ThZCRY>:P=>:`M>2`5>3@0000<8@0`P2240
0`PQ00<880PQ22001@PQ1@a100h880a0120<@PPQ324<@@PP320T`d6XFT]JJei^0ei]15i^00=NSUj?
GXl00ej?15j@0ej?1Ej@00=NSej@GY000ejA00=RTF:aH[0016:`1F:@00ER/6:aH[5R/F:`009RT09R
/@9RTP03H[9R/F:a00=R/@=R/P07H[5R/6J_HXmRT6:?I[0016Ja0fKA00=Vd6JaI[400VKB0VJb00=V
dVKAI]800VKC0VKB16KA00UVdV[AJ_5VdFJ`HY1J;Ui^I[000fKC0VKB0f[B0f[C0f[B0V[b0V[c0VKd
0fKc1V[c1f[b0f[c00UZm6lDKaA_56lCKaA^m6[dK_@00VlD00]^m6kcK_=ZlV[aJ_1VcVK@Ja5_<Vlc
009c<`03Mc=c<g<c009c<`09Mc=c<g<cMc=c<g<dLeAcDfmD00Ec=09c<`EcE007Le=gDgMBMe=cDg=D
Le<00WMC00=gE7=DLeD00W=D1WMD0gMc00IgM7MDMeEgM7MeNg@3MgD02gMdNiEkMGMeNgEkMWMeMgIk
UW^hNiH00g^G0W^F0gng00QofGoJOo]ongomOmao^gon2goo00Ao^WnHOiYo^P9of`03OmUo^Gni009o
^@0FNkQkUg^FNiEkLg]bMe=g=6ldKa=ZlV[@IXaRJei;FPUEif9]I]5_56[dJ_D8J_@3KaD00fleKcI_
=@02KcH01fleLcEc=G<eLcIc=Flg009_=P=_E@0:KeI_=FleKcE_EVmEKeI_EFmFKcH2KeH016lfKcE_
=Vle0W<e00E_=FlfKcE_=G<f00=c=@03KcI_=Flf009_=P=c=@U_=@Ec=@03LcAc=Flf00M_=@03LcA_
=Fle009_=@03KcA_=Fle00E_=@03KcA_=Fld00E_=004Lc9_=6leKcD3Kc@01VlDKcA_<flcKcA_<`9_
=0A_509_=@04KaE_=6ldKc<?Ka<00flBKa=_4`06Ka<3Ja<2J_<016lBJa=_4VlB0fkb0VlB0f/C00=_
4flBK_800f[b1Fkb00=ZlV[aJ_800V[b0V[c00AZlV[aJ_5ZlP9Zl`9ZlP=Zl@03J]9ZdF[B00=ZlP05
I]9ZdF[AJ]5Zd003J]400fKaI]5Vd@02I]400fK`I]5Vd003I]42I_8026KAI]1Vd6K@I/mVdFKBI]45
I]001VKAI]1VdFKAI[5Vd@9Rd@04H]1Vd6K@I]03H]02H[02HZl2H[02HZl4H[000f:^HZmR[`03H[02
HZl00f:^HXeRSP02HZh2H[03GZl01Uj^GXiN[Ej^GZeN[P=NSPANS`06GXiNS5Y/FVaJKUI=0UI<00EJ
K5j;GXaNSEj>00=NKP03FViJKEY]009JK@03GVeJKEi]00=JK@03GVaNJei[009NK003FVeNK5Y/00AJ
K003FV]JK5Y<00=JC@=JK@03FTaJBeY<00=JC006FVaJBeY;FTaJCEY<0UY;00AFBeY:FTYJBP9FB`06
FTaFBeI;ET]BBeI;0U9;0UI;00EBBeH/DR]F:e8[009BB`06DR]F:eH[DR]F:e8[0U8/00=B:e8/DR`0
0e8/1U8[00EB:U8[DR]>:e8[009>2`03CPY>:ThZ00=>:P04CR]B:Th;DPX2CPX1CP/1CPX1CP`00088
80033248@@PQ00@88@04244<8@`Q324234401@aR348<HPa236800Pa100`<8@PQ200400P0100PXcfW
FV]NS5i_GVh2GVd00ei^GXiNSP05GXl00ej>GXmNT003GY02GXl3GY0015jAGY1NTEj@0UjA00=NT5jA
GY400UjA2F:@00=NT6:@H[400V:a00=R/6:aH[400V:a0V:B00=R/V:aH[801V:b00IR/FJaI[5R/F:A
H[44I[43H[4016JaI]5R/FJb16:b00=VdVKAI]8016KC0VKB00AVdFKBI]9ZdP9Vd@05I[1NKeX_HVmV
d002I]<00fKcI]9VdP02I]8016[BI]9VdV[C0V[b00=ZdV[bJ_800V[c1FKc00EZlf[CJ_=Zdf[b00EZ
l`03J_9Zlf[c00=Zl`03J_A_56lD009_50=_5@=_500@K_A^lfkcK_9ZlV[aJ]5[4VmDNgAgU7MCMc=c
=G=ELc@7Lc<016ldKeAcE7=D1W<d00=c<g=DLe@01G=D1g=C0WMD00AcE7MDMe=gD`IgE004LeEgM7Md
Mg<3Mg@4MgD00gMdMiAgM004Mg@01GMfMiIkUW^FNgH00g^G00=kV7]gNgL00W^G00MkV7^iOkQk^GnH
NgMkVP0:Ool01GoLNiMoUg^INkX017^i0g^G0g^H0W^G011kUG]dNg=kM7LdKcAZlFJ_IZeNK5X8DJMJ
2f:aJ_=[5@9Zm003J_=Zm6[d00AZm004KaE_56leKcD5KcH4LcD017<fKcI_=Vlf0fmE00=_EVlfKcH0
36lf00Y_=G<eMeAg=G<fLcEg=G<eLcAc=@Q_=PU_=@04KcI_=G<eMc@2LcD2KcD3KcH5KcD01W<dKcE_
=G<eKaA_=0M_=@9_=09_=@08KcA_=FldKcEc=6ldKcE_5@9_=003LcAc=Fld00A_<`9_=0A_5003KaE_
5Vle009_=@04KcA_56lDKa@9Ka<00f/CKa=_4`07Ka<3Ja<01VlCJa=[56/CJ_=ZlP9Zl`=^lP9_4P=[
4`03Ka=^lVkb00=Zl`05J_9^lVkaK_9^l@02J_43J_82J_<4J_82J_<2J_83J_43J_801V[BI]9ZlVKc
J_9VdP=Zd@MVd@03I_1VdVKA00AVdP9Vd@AVd003I]5VdVKA00=Vd0=Vd@9Vd004I[1VdFKAH]43H]03
H]43H[45H[02HZl4H[000f:_GXmR[`03H[02HZl00f:^HXiR[P02HZh7G[02GZl00ej^GZmNS`02GXh3
GY002ej?GXiNRei[FVeFKUI>DR]F:UY[FX/00Uj=00=JSUY^FVh015i]1UY]0UY^00=JKEi/GV`00Ui/
0eY]15Y/00=JJeY/FVd00eY^0UY/0eY<0eY=00=JC5Y=FT`01EY<0UI<00=FBeY<FT`00UY=00AFC5I;
DTaFB`=BC004DT]FBeI;DT/2DR`0158[DT]BBe9;0eH[0U8[0e8/00=B:e8/DR`00U8/00=>;58[DR/0
0e8[00=>:e8[CR/00Th[0dh;00A>:dh:CRY>:P=>:`03CRa>34h;00=>2`5>2P5>300000<88@`Q3240
10a100<<8@PQ22400PPQ00<<80a134400Q2300<@HPa2344010a10P@000P800@07:91YUj;HZaJKeY>
0Ui]00=NKUj>GXh01Ei^0Uj>15j?15j@00ANSej@GY1NT0=NT@9NT004GY5RT6:@HY42GY43HY0016:a
GY5RTF:A0V:a0f:`2F:a0V:b0f:a00=R/V:aH[400V:a00AV/VJaI[5R/@9V/@IR/@03I]9R/VKB00=V
dP03I]5VdVKB00AVd`=VdP9Vd`0:I]9VdFJ`GViJCf:?I]1VlfKDI_<4I]84J]83J_8;J_<3J_87J_<2
K_<02F[bJ_=Zlf[dKaA[56lDKaE_5003KaD03VlDK_A^lf[bK_9ZlV[aJ_9_=7MeOm9k/g]aMc82Lc@0
0gLcLcAc<`02Lc<01GLcLc=c<g<cLcD00W<d0W<c17<d00=c<g=DLe<02G=D0g=C00=cE7MCMc<00gMC
00=gE7MCLe@00W=D00MgDg=DMeAgLgMbMg=gD`02Me@7Mg@00gMcMgAkL`03MgD2Mg@017]dNgEgMWMg
17]g00AkMG]fNgEkMP9gE@04MgMgVG^kMk/2Nk/01G^iMiQgV7NHMgH00WMe0W]e00EkMW^FNgIkMW^G
00=kUP0FNiMkMWNHNiQkUg^HNiMk]g^COg9c=6lCJ]5V[V9/FRQAYeG/HY1ZlVlEJ_@3J_<5J_@01f/D
Ka=_56leKcI_=Flf009_=@Qc=@=c=09_=@9c=@A_=@07KcIc=G<eLcE_=W<eKcD00g<e00Mc=VlfLcEc
=7<eLcA_=@02KcH00g<fKcI_=P02KcH;KcD00g<eKcEc=@02KcH4KcD2LcD3KcD01G<dKcE_=FleLc@0
0Vld1fle0Vld1fle00=_5FldKcD016ld1Flc00=_=6lcKa@00flD1VlE16lD56lC00M[4flCKa=_56[c
Ka9ZlP02J_<4K_801FlCJa=_4f/CKa<00Vkb0f[c00IZlVkaK_5^lFk`J_03J_46J_82J_43J_87J_44
J_8016KBJ]9ZdVKA0V[A1FKA00=Vl6KAI]800fKB0VKA16K@00AVdFKBI]5Vd@MVd003I/mVd6K@00=V
d09Rd003H[5RdF:a00AR/@03H]5R/F:`009R[`ER/09R[`IR[P=RSP9R[P=N[`05GXmNT5j@GY1R/002
G[000ej@GXmNS`03GXh2GXl03Ej<HXYNJUi/FVeF;4gZERYJJej:GX]NS5j=009NSP03GXeNKEi]009N
K@EJK@9JKP05GVeNK5i/FV]NK004FVd01UY/FV]JJeY[FVaJK@9JKP04FVaJJeY;FT/2FT`3FTd00eY/
FTeJC006FT`3ET`2FTd2FT`01EI;ETaFBe9<ETd00UI<00=F:eI;DT/0159;00=FBe9;ET/00UHZ0U8[
0e8/2e8[00M>2e8[CR]B:dh[DR]B2`02CR/3CRX2CR/01Dh/CPa>358/DP`00Th;0E8:0Dh<00000`a0
320<8@0434400``Q22488@0222400`PP324<@@02344234804``Q220<@11R48<<@@PP320@81R1>F=N
JUj/FTmJCUi^GVeNKUi_00MNKP04GXiNSej>GXl5GY000ej?GY1NT002GY03GY42GY02HY002F:AGY5N
TF:@HXmNT5jAG[5NT@03H[42HY000f:`H[5R/@02H[4016:bH[5R/F:a0f:b0f:a1V:b2f:a00=V/VKB
I]8026KB0fKC00iVdVKCI]=Ve6KcI]=V/69^FRiRKfJ`I_=Ve6Kc0fKB00=ZlV[BJ]8016[B00=ZlVKc
I_<02F[c0V[b1f[c16kc0V[c00M_56/DJaA_56lEKaA_5@02Ka@2K_@2K_<2J_8016KAJ_9_=7Me0W^c
00=gDgLbMc<00g<d0g<c00EgDgMBMc=c<g<d00Ac<`=c=09cE@03LeAcDg=D00acE09g<`=gD`06MeAc
E7=DLeAgE7MC1GMD00=gDgMDMe<01WMd27Me00YgEGMdNgEkMGMfMgMkMW]eMgEkM@AgM@07MgIgMgMg
MiQgN7=gLeD00W=D0WMe00=gM7MeMgD01W]e00AkMW]eNgEkM@9kMP0DMiMkMW]gNiQk^GniNkIkLWLd
Ka=^lFK?HXeRJEG8DL]NCVKAKcE_5@IZl`9Zm003JaA_4flD009_=@9_=P9_=@Ic=@03LcIc=G<d00Ac
=09c=@03KcEc=G<e00]c=@06LcI_=W<fLcE_=G<e17<f16lf2fle00Mc=6leKcE_=FlfKcEc=@02KcD0
1G<eLcAc=7<dLcD01Fle0W<d5Fle0Vld1Flc0Vld16lD0flE00I_56lEKaA_56lEKcD2Ka@;Ka<3Ka83
Ka<3Ka@016lCKaA_56lC0VlB16[c0Vkb00Q_4V[cJa=[4flCKa9ZlV/C0V[c00IZlV[aJ_5ZlFk`J_03
J_4;J_87J_402V[bJ]9ZdV[bI_=ZlV[BJ_5ZdV[A1VKA1fKB1FKA00=VdVKAI]400VKA26K@00=V/6K@
H[000V;@26:a0f:`00=R[f:`G[400eja0V:_00AR[V:_HXmRS`9R[P06HXiR[V:>HXmR[ej`0Uj_00EN
Sf:?HXmRT6:`00AN/00?GZmNSej>GXiNSej=GXaNRUiZGV]JBUH;ERYJBUY/009NR`04GXaNSEj=GXh2
GXd6GVd015Y]GVeJKUY^0eY]0UY/00AJKEY/FVeJK@AJK09JK@9JKP04FVeJJeY<FT`2FV`00eY]FTeJ
C@04FTd:ET`2FT`2ET`015I;ETaFCEI=0UI<259;00EFBeH[ER]F:e8[00EB;003DR]B;58/00=B;0EB
:`05CR]B:e8;DP]B:`02CP/014h[CRY>:Th:0Th;14h<00=>2dh:CPT00Dh<00000`a0320<@@043440
1@`P324<8@`P32400`PP00<<80PP22400PPQ0P`P00`@H122464<@0`P420HPCTQFTUNReY>GVh2GVd0
0ei^FViNKP09GVh01Ej>GY1NT5i`GY000Uj?0Uj@15jA00INT6:?HXmRSf:@HY42GY401F:@HXmNT5j@
G[400UjA00AR/F:@HY1RT0ER/0=R/@AR/P=R/@ER/P07H[5V/F:aH]5VdFJaH[400f:`00AR/FKAI]5R
/PAVdP03I[9VdVKA00=VdP03I]=VdVKB00=Vd`08I_AZm6KAHViJ;Ui=IZmVdP9Vd`9VdPQZdP=ZlP03
I_=Zlf[b009Zl`04J_9Zlf[cJ_<6J_82J_<4K_<01FkbK_=^lflCJ_<00f/D0VlD00=_4fkcJ_<00Vkc
0Vkb011ZlV[BJ_5_<g=DMg=gDWLbLc9g<WLdLcAc=G<cLcA_=09c<`03Lc9c<g<c00Ec<`9c=004LcEc
=7=DLe<=Le@3Mc<00g=CMe=gE002Me@01WMCLeAcE7MDMe=cE09gE0=gD`03MgAgLgMd00=gM0EgE@05
MgAgMGMeMgEgE003Mg@00gMfNgEkM002Mg@2Ng<2Mg@4MgD00gMfMeIgM@02MgD2NgD3Ng@4NgD017]d
Ng=kM7]c17]d019kMG]dNgEkMG]fNiIkUGnAMc=c<FkaJ]1V[F9YENQAbEX[IZl2Ka@6J_<00f[dJ_=Z
l`02Ka<01FlDKcE_=FleLcD00fle0g<e0W<f00=c=G<dLcD00g<d1g<e00=_=G<eLcD01W<e0Vlf00A_
=G<eKcE_=@E_=P03KcE_=Vle00]_=@03LcA_=6ld00M_=@=c=0E_=@05LcAc<g<dKcE_=003KcD016lD
KcA_=Fle0fld0fle00=_5FleKcD00fle0Vld26lc0flC00I_56lEKaA_4flDKaD5Ka@4Ka<5Ka82Ka<4
Ka84Ka<01FlDK_A^lfkcJ_<00flB0f[c00=^lV[bJ_802F[b00A^lV[aJ_5Zl@9Zl0EZl@UZlPMZl@04
J_9ZdV[BJ]82I]8016[AJ_1ZdF[A0VKA0VK@1FKA16KB2FKA1fK@00=V/6J_IZl00VJ_16:`16:a00=R
/6:aH[000f:_00ER/6:aH[5R/Eja009R[`04HZiR[f:?HXl5HZh2HZl00ej`GZmN[`03HZh2HXl00ej@
H[1R/002GXl2GXh2GXd00ej<GX]NRP02GTP01EHYETaJC5i[FV`00ej;0Uj<15j=00ANSUi_GVeNK@MJ
K@=JK09JC0IJK09JK@04FTeJKEY]FV/2FT`00eY/FT]JC005FTd3ET`5FT`6ET`2ET/00eI<ETeFC002
ET`4DT/2ET/2DT/00eH[DR]B:`02DR/5DR`01UH[DR]B;4h/DRa>;09>:`9B:`04CPYB:e8;DP/2DPX2
CP/2CPX00dhZCPY>2`02CP/2CP`2CP/1CPX1CPT1CP`000<<@@0:368<@Pa1224<80`Q344<@0`P3442
34802A0Q344<@@PQ200<80a0360@PP0236401`PP320HPCTRETUNS5j?00=NKPAJK`INK`03GXiNSej>
009NK`ANS`9NT0ANT@06GY1NSej?HXmRT6:A0UjA00ART6:?GY1NT0=N/@05GY5RTEjAGY5RT006H[43
H[800f:aH[9R/@02H[45H[800f:aI[5R/@04H[44H[02H[42H]83I]800fJbI]9Vd@02I]83I]<036KB
I]=VdfKCI]AVm6KAHXmNCf9^IZmVdP=Vd`03I]9ZdV[B00IZdP04J_9VlfKcI_<2J_87J_<00f[bJ]9Z
lP04J_84K_<00fkbK_=^l`02J_<00f[dJaA[5003Ka@016kcK_A^lfkc0Vkb00IZlV[aK_9_<fldLc@4
Lc<00g<dLcEc=@03Lc@:Lc<3Lc@00g<eLeAcD`0<Le@3Le<00g=DLe=cD`06Me@3Le@00gLdMcEgE004
Me@9MeD01GMDMgEgEGMEMe@027Md00=gE7MdMg@00gMd0gMe00AgM7MeMgEgM@9gM0=kM004NgEgM7Md
Mg@9NgD017MdMgIkMW]e0W]d00]kLGLbMc5_4V[AIZmRJeH9ENUJ2FJ_00YZl`04K_=_4flDKa@2KcD3
KcH3LcD00fleLcEc=@02LcH7LcD2KcH00fleLcE_=@03KcD00g<fLcEcEP03LcD2LcH2LcD7KcH00fle
KcI_=@0>KcD3KcH:KcD00fldLcAc=002Lc@00fleKcA_=@02KcD016ldKcE_=Fle0fld2fle26ld00E_
<flCKa9_4flE00M_509[4`A_4`03Ka9_4flC00e_4`=^l`04J_=_4V[cKa83J_<00f[bJa=Zl`0;J_87
J_4;J_800f[aJ_9ZlP03J_82J]800f[AJ]9ZdP02I]801FKAJ]5ZdF[AJ]801fKA1FKB1FKA2fK@00=V
/6K@IZl00VJ_16:`1f:a00=R[f:^HZh00f:`15j`00AR[f:`HZmNS`AR[P04HZmR/5j`G[02GY001Ej?
HZmRSf:`I[000V:?1Ej?0Uj>00=NS5i[GX/00UY:00IJBeY<FVeJKEi]GV`2GXd2GVh4GXh015i_FVmJ
KUY^1eY]00=JK5Y]FVd00UY/00=JKEY/FV`00eY/00IJKEY/FTeJCEY]FT`3FTd00eY<FTeJC@05FTd2
ET`5FT`2ET`01UY<ETaFC5I=ETaFB`EFC0IBB`9B;0=B:`EB;0=B:`=B;0A>;09>:`04DR]>:dh;CP/3
CPX3CP/014h:CP]>2dX<14h;0Th:0Dh90Dh<00000`a13248@@022444224234002@PP344@H`a2324<
@@aR2248800334003122464<H@a1200DHCDQCRUNS6:=GVeNKP=NK`9JL004GW1JL5i`GW02GVl4GVh2
GXh3GXl2GY03GY42GY03HXl01V:@HY5NTF:AHY1RS`9RT004GY5R/EjAGY42HY401EjAH[5R/F:aHY40
16:a16:b0f:a0f:b0V:a00=V/VJaH[400f:a00=V/6:aH[000f:?00AR/F;BI]9VdP9R/P03I[5VdVKA
009Vd@AVdP=Vd`9Vl`06J]5RT5i?HViV[fKB0fKC00=VdV[BJ]801f[B0fKB00AZdV[bJ_=Vl`EZl`04
J_9Zlf[cJ_83J_<01FkcJ_=^lfkcK_800fkc00A_4flDKaA_50E^m09^l`09Ka=_4VkaK_5_4W<bKcAc
<g<d00Ec<`04KcAc=7<dLc@=Lc<00g<dLeAcD`05Le@00g=ELeAcE003Le@8Le<3Me<00gMDMe=cE002
Le@8Me@00g=EMeEgE008Me@027McMeAgM7]dMgAkDgMDMe<4Mg<3Mg@2Mg<3Ng<00gMdNg=gM009Ng@2
NgD3MgH5NgH00g]eNgIkM@02Ng<03W]CMc=g<FlCJ_5V[f:<FR]F2Uh8IZi[4flCK_<4J_<3J_8016kc
Ka=_4flD0fle0Vlf27<e00=c=7<eLc@00W<d17<e00A_=G<eLcEc=@9_=@03KcIc=Flf00Ec=@Y_=@03
KcI_=Fle00e_=@03KcI_=Fle00M_=@I_=0=_=@=_=0E_=@=_=003KcE_=6ld00E_=0U_=@06Lc=_=6lc
Kc=_4VlC16lD00=_4flDKa@01VlC0VlB00=ZlVlCKa<036lC00A_4VkbK_9_4P9_4`03Ka9^lVkb009^
lQaZlP04J]9ZlF[aJ_42J_83J]800f[AJ]9Zd@02J]82I]800fKbJ_5Zd@02J]400f[BI]9VdP04I]44
I]86I]43I]001FJ`IZmV[fJ_I/l00fK@00=VcfJ_IZl00VJ_16:`1F:a00=R/V:aHZl00V:_00AN[f:^
HZiR[P9R[`=R/0MR[`03H[1N/5j`009N/09R/00:HY1RSf:>HXiNSV:?GXmNT5j_GXl2GXh015j<GVaN
JUY:0eY;00EJK5i/GVaNSEj>009NKP9NSP04GViJKUj>FVh3FVl015Y^GVeJKEY]15Y/0eY]15Y/0eY[
0UY<3EY=1UY<0eY;0UX[0eI<00AFCEI<ET]FB`=FC003ER]FBe9;009BB`03ET]F:eH[00]B:`03CR]B
:e8[00=>;004DRa>;4h[CR/2DP/00e8:CPY>:P02CRX2CR/7CP/2CPX00e8:CPUB2001CP`000042448
8@PR228622401@a1244<@@a234400Pa200<8@PQ124400Pa100h<@0aQ360<HA1R100@@342BPUJK6:;
GVeNKUi`0ei_00IJL5i`GW1NL5j@GXl3GVl015i^GXiNSUj>1Ej?1Ej@00=RSej@GY000ejA00=RTF:@
HXl00V:@00ANT5jAG[9R/@9NT@05G[5NTV:bH[5RT@05H[49H[82H[4046JbI[5R/F:bH[5V/V;AH]9R
/F:@GXiNKei`H[5V/VKB0VKC0VJb00=VdFKBI]801VKB00QZdfKcI_=VdF:AGTmNKfJ_0VKB0VKC00=V
dV[BJ]802f[B00=VdV[bI_<00f[c00=Zm6[cJ_<01F[c00I^lf[cJ_=ZlfkcK_86K_<016[dK_=_56kd
0VlE00=^m6kcK_800fka00=_4W<bLc<00W<c0g<b00Ac<g<dKcA_=09c=0ac<`9c=0IcE09cE@IcE0Qc
D`9gD`03MeAcE7=D00=cE0AcE@05MeEgE7MDMeAgE@03Me@3MeD3Me@2Mg<3Ng<2Ng800g]CMe=gD`02
Me@3Mg@7Mg<>Ng@00g]eNgAkM@03Ng82Ng@3Ng<02g]CNc9g<VldK_5V[f:<FT]EjUhZIZh00VlD00=^
lf[dJ_@00V[c00EZlV[cK_=^lflC009_50A_=@05LcIc=FleLcEc=P04LcD00g<dLcEc=002Lc@00gLc
LcAc=003LcD01FlfKcE_=G<eLcH017<e26le1Vlf00=c=FleKcD036le00=_=W<eKcD01Vle00=c=6ld
Kc@016ld3fle1fld2Fle0Vld0Vlc00=_<VlDKa@00flD00A_4flDKaA_509_4`=_4P9_<`03KcA_56lD
019_4`03Ka9^lVkb009^lP=_4P9ZlP05K_9ZlV[bJ_9^lP0@J_801V[cJ_9ZlV[aJ]5Zl@9ZlP05J]9Z
dF[BJ]5VlP03J]82I]800fKbI]5Zd@02J]400fKAI]9VdP04I]45I]84I]43I]001VKAI]1V/6J`I]1V
c`=Vd003I/mV[fJ_009V[`9R/09V/003H[5R/6:a00=R/@=R/006HZmR/6:_HXmR[V:_0f:`0Uj`00=R
/6:_HZl00f:_0V:`00=N/Ej`G[000Uj`00MR/5j@HXmRSf:>HXmNS`02GY000ej?GXiN[P02GXd00eY<
ETYJ:P02FT/2FV`00eY]GVeNS`02GXl2GVh00ej>GXmNK`03GVl2GVd3FVd2FV`00eY]FVaJKP02FVd4
FV`01EY[GVaJJeY]FV`00UY=00=JKEY=FTd02EY=1EY<00=JBeX[FR/00UY<0UI<0eI=00=FC5I=ET`0
0UI<00=F:eI;DT/00U9;00AF:eHZERYF:PEB:`03DRaB:e8[00AB:`03CR]>;4h/00=>;09>:`06DP]B
:e8ZDRY>:Th;0Th[14X;00=>2dh/CP/00dh;0Th:0E880Dh<00000`a124488@0322400`a022488@02
22401@`Q2448@Pa132800PPQ01088PQ1244<@@a0440@H0aP340400`P<@=9jEi/IZYNJ`ENKP=JL006
GW1NT5j?GVmNKUi_0ei^1Ej>1Uj?00=RSej@GY000ejA00=RTF:@H[0016:@00]NTF:aGY5NT5jaGY9N
/V:aHY5R/F:b00AR/@AR/P05H[5R/V:bH[9R/@02I[82I[403FJbH[5R/F:bH]9R/F:`GXiF35H=GW1R
T6:a009VdP04I]5V/FK@I]4:I]801VKAHY5JCei=IZmVd@9VdP03J]9VdV[A00AZdP9ZlP04J]9ZdF[A
J]42J]84J_84J_<2J]<3J_<00f[bJ_=Zl`02J_<4K_82Ka<2K_<01F[cK_A_56lDJ_@00Vkd00I^lV[b
J]1Z[fkaKa83Lc801g<cLc9c<g<bLc=c=6ld009c=09c<`05Mc9c<g<cLc=c<P05Lc<00g<dLc=c<`04
Lc@4LeD9Le@00g=CMe=cD`03Le@017=CMeAcE7=E0g=D00=cEG=DLeD00WME1gMD0gME0WMD00AkDgMC
Ng=gL`9kLP06Ng5kDGLbMc9g<gLd2WMD00=kLgMcMg<00W]c0g]d0W]c0WMc00IkLg]bNg9gDg]CNe83
Ng46Ng803G]BNc9_=6kaJZiVS5Y;DLUJ2FJ]Ja9c4fkc00AZm09Zl`9^lP03Ka=_56lD00=_=006LcAc
=G<eKcIc=G<f1g<e17<d0W<e00=_=G<eKcD00Vle0g<e2Fle00=c=6leKcD00Vle0flf00=c=FleKc@0
0Vld0fle00=c=6leKcD016le00=[56leKcD00Vld00Ec=6leKcE_=G<d00I_=0e_=@Y_=09_=@03KcA_
56lD00=_=@06KcA_56lcKa=_<Vlc0VlC1flD00A_4flBKa9_4P=_4`9_50=_4`04Ka9ZlflCKa<2Ka84
Ka<2Ka8016kbKa9_4flB16kb1F[b00=^lV[bJ_803F[b00=ZlF[bJ_800V[b26[a16[A00AVlV[aJ]9V
d@9VdP03I_9VdFKA00=Vd@9VdPAVd@AVdPIVd@03I]1VdFKA009Vd09V/005I/mVd6K@I]1Vc`02IZl2
I]0016:`IZmV/6:`16:a0f:`00=R[f:`HZl00V:_00=RSf:^HZl00f:`00=N/F:`H[001V:_0ej_00IN
/5jaG[5R/6:_HZh2HXh01V:?GY1NT5j@GXmN[@9NS@06GXiFCE8:FRYJBeY:0eY<00EJK5Y]FVeJKEi]
009NKP07GVmJKUY^GXiNSEj<FV`00eY]0UY/00=JKEY/FVd00UY]15Y/0Ui/0Ui[00=JJeY<FT`00UY]
0eY=00=JC5Y=FTd00eY=2UY<00AJBeI<ETaFC0IFC@03ETaB:eI;00=BB`07ET]F:UHZERYF:e8[ER/0
0U8[0U8/0U8[00=>:dh;CR/01Dh[00=>34h;CP/00U8Z00=B:dh[CRX00Th;1DX;00=>2dX<CP`00Th<
00A>2dh:CPY>205=j`000Pa100T<@P`Q22488@a0224880PQ32400Pa200<@Q11R32400PPQ0`Q10Pa1
00@@8110344<@P880006;>=5bEY]I/]NJei^0ei_15Y`00ANL5Y`FW1JL09NL0ANK`03GXiNKUj>00QN
S`=NT003HY1RTF:A00=RT005HXmRT6:@GY1NT@03G[42GY89H[4;H[800fJbH[9R/P05H[801F:`FTiF
3UX^GY000V:b00AVdVKAI[5Vd@IVdP9Vd@=VdP07I]5RTEY?FTiRSfKBJ_800V[B0fKB00=ZdF[BJ]80
26[B16[b16[c00=Zdf[cJ_<026[c0Vkc00=_4VlCK_<00Vkc00AZm6lDJ_AZm09Zm@0:J_A^lf[bJ]1Z
[fkaKa9_<W<bMc42Lc8017<cLc9c<flc0Vld00=c=7<cLc<017<c00=c<W<cLc<00W<c0g<d00E_=7<d
LcA_=7<e009_E@9cE@UcE004Le=cE7=DLe@3Le<00g=DLeEcE@04LeD017=DLeEcEGME0WMD00IcE7MD
MeAgE7MELeD3MeD027MDMe=kDg]cMgAgLgMDMc<2Mc8017LcMcAg=GMC1GMD00=gDgMcMg<01G]c1W]d
00QkLg^CNi1kLWMCLcAc57<C0WLc00AkDW]bNg5kL@9kLP0@Ng5kDW/bLc=_4V[?IZeNC57:EPURS6/B
Ka=^lf[dJ_D2J_@00f[cJ_AZl`02Ka<2Ka@01VlELcEc=7<dLcEc=P=_=P04LcIc=G<dLcH2KcH;KcD0
0flfLcEc=@03KcD3LcD4KcD00g<dKcE_=@02KcD3KcH01VleKcIc=7<dMc=c=09_=@03LcE_=Fle00=_
=@03LcE_=Vle00]_=@9_=003LcA_=Fle009_=@03KcA_=Fle00a_=A9_=004Ka=_56lDKc@5Ka@00flC
La=_4`02Ka<2Ja<3Ka@5Ka<00flBKa=_4`03Ka<00f/CJ_=Zl`02J_82Ka<2K_<3J_<4J_800fkbJ_9Z
lP09J_8016[aJ_9ZlV[b0f[a00=ZlV[aJ_400f[a0V[b00QVlF[AJ]5ZdF[BJ_9VlVKa0VKb0fKB00IV
dF[BI]9VdVKAI]85I]45I]8:I]42I[001FK@H[1V/6K@I]400fJ`00EV[f;@H[1V/6:`00=R/@03I[1R
/FJ`009R/003H[5R[f:`00AR[`9NT09R/003HZmR/5j_009N[`=N/003GZiN[ej_00=N/003GY1NSf:^
009R[P9NS`9NT005GXmNSUj>GXiJK@02DPX2FT/00eY:FT]JC003FVd2FVh00eY]FViJKP03FVh01Ei]
GXeNSEj=GVd00eY]0UY/00AJKEY^FVeJKPAJK@05FV]NK5i[GVaJC003FVd2FTd00eY<FVeJK002ETd0
0eI>FTeJC@02FT`015Y=ETaJCEY=0UY<0UI;00EF:eI<ETaFCEI<00=FC@04ETaFCEI<ET/4DT/3DR/0
0eH[DR]B:`03DR/0158/DR]B:e8[2Dh[00A>2dh[DR]B:`E>:`=:2`04CR]:2dh;BP`4CP`00dh;CPY>
2@01CN`00003344<8@`Q00<<@@07340880PQ224<8@a246<00Q230P`Q00@880PQ244<@@8<8@0<420@
H0a1208400P088=1Z5Y]IZUNJei^2eY`15i`0Ui_0Uj>25j?1F:?16:@00ARSf:=HXmRS`9RT0=NT@MR
/@03H[9R/F:a019R/P0;I[9R/VJ`HY5RL5i?GW1RTFJbI]9Vd@02I[45I]83I]43I]802VKAI[5NKeY>
HY1R/FKAI]9ZdVKB36[B00=ZdF[bJ_400V[b00=Zlf[bJ_<036[c00=ZlVkcKa8016kc0Vkd0VlD00]Z
m6[eJ_A^lfkbK_1ZcfkaKa9c<G<b009g<@03Lc5c<W<b009c<PEc<`03Mc=c<gLb009g<P9c<P=c<`06
Kc=_=6lcKc=c<W<c1G<d00Ac<gLcLeEcE@EcE004Le=cE7MDLe@3Le<00g=DLeEcE@04LeD00g=DLeEc
E@06Me@01GMCMg=gEGMDMeD00WMD00agDgMBMe9kM7MCMcAc=7LbMc5g<gLdNc<2Ne<4Mg<00g]bNg=k
L`03Ng<01g^BNg=kUG]eNg=kMG^G009kU@06Ni5kSW]AMc9_4V/B0V[b01M_4WLbMc9k<G]BNg5kDg]`
Ne1k<G<cKa9ZcfJ]GTaF2eX9HXa[4W<cJ_9Zm6/E009Zm09Zl`05K_=ZlflCKa=_5002KaD00fleLcA_
=@04KcH2LcD00g<dLcEc=P02LcD2Lc@2LcD3KcH00g<eKcEc=@07LcD00fldKcE_=@03KcD00g<dKcE_
=@04KcD3KcH5Lc@2LcD016leLcEc=G<d1Fle2G<d00A_=FldKcAc=09_=@9_=15_=@03KcA_56lD00M_
5003Ka=_=6ld00M_50=_4`09KaA_4flCKa=_56lCJa=_4flD00=_4`03Ja9_4VlC00U_4`06J_=Zm6kc
J_9^lfkb0Vkc00=Zlf[dJ_<01Fkb1f[b00=^lV[bJ_802V[a00AZlV[aJ_5Zl@=Vl@=Zl@=ZlP03J_5V
lFKa009VlP=VdP03J]9VdVKA00MVd@EVdP=Vd@03I]1VdFKA00EVd@03I]1V/6Ja00=V/005I[5V/6J_
H[1V[`05I[000fJ_I[1V/004H[400f:`HZmR[`02HZl2GXl2HZl02F:^GZiN[Uj^GZmN/6:`G[1N[`02
GZh01Ej_HZmNSf:?GXl01F:^00MN/5j@GXmNSUj=GVaJK@02FT`2FV/3FTX01UY/FTaJKEY_FViJK@=J
KP9JK@ENK09JC003FVeJK5Y/00=JK005FVeNKEY^FViJC002FV/015i;FTaJC5Y=0UY]0UY<0eY/00=J
C5Y=FTh00UY=0eY<00=JCEY<ET/025I;0UI<0eI;00=BBeI;DT/00U9;00=FBeH[ER`00e8/0UH[00=F
:U8[DR/0358[00E>:dh;CP]B:dh[009>:P9>:`06CRY>2dh;CP]>2Th[0Th;14h<0Th;0Dh90Dg/0000
0`Q122488@0224400`a1340<@@033445348234400`PQ344<@@0234403A0P460<HPPQ000401R2?HMJ
KV:[GVeNKUY_00UJL0=NT09NL09NK`=NSP03GXmNT5j@00=NS`IRS`04HY1NT6:@HY04HXl2HY02HY42
H[401F:bH[5N/V:aGY400f:a3F:b00=Vdf:bI]800V:b00IR/F:bH]=VdfJbHY42HW001F:@I[9VdfKA
I]800VJb16KB00=VdFKBI]8016KB00IV/V:@FTiNL6:cI[82I]800fKCI]9VdP09J]800f[CJ_9ZlP02
J_800f[BJ_9Zl`0<J_<016kcJ_9ZlVkb1Vkc0VlD0V[d00M_56lCKa9^l6[@K_5_<P03Lc800g<cLc9c
<P03Lc84Lc<00g<dLc=c=004Mc800g<bLc=c<`02Lc<016ldKc=_<g<b1g<c00=c=7=ELeD017=D0W=C
1G=D00=cDg=DLeD01G=E00=cE7=ELeD01WMD00=gLgMCMe@00gMD00IgDgLdMeAkM7MELcD2La@017Lc
Nc5k<W/b0W]B00AkLg]dNgAkL`AgL`04Ng=kM7]dNg<2Ng@2NgD02g^EOkMo]gnfOkAkL7MBMc=c4g<c
Mc@00WLc00=c4g<BKa800WLb00igDW]`Ne5k<G<cKa=Zd6J<GTaAbUG8HVaVdF[b2F[c00=_4VlCKa@0
0flE00A_=FlfKcI_=P9c=P07LcEc=W<eLcI_=VleLcD00W<d0Vle16lf0W<e0W<f1G<e2Vle0W<e00E_
=FlfKcI_=Vld00=c=004LcE_=FleKcH2KcD00g<dLcE_=@02KcD00g<eLcAc=004KcD6Kc@3KcD2Kc@A
KcD00fldKaA_5003Ka@01FlCKaA_4flDKa<00Vld0Vle00A_=6lDKaA_=09_4`I_50=_=@9_5004Ka=_
=6ldKc@>Ka<2K_<01VkbJ_=Zlf[dKaA_4`9^l`9^lPaZlP03J_5ZlV[a00IZl@9ZlP9Zl@04J_9VlFKa
I_44I_83J_800fKaI_9VlP03I_8016KBJ]9VdFKA0f[@16KA0fKB00=VdFKBI]802FKA16J`00AV/F:a
H[5R/@9V/003IZmV/6J`00=V/003IZmV/6J`00ER/@9R/0=R[`9R/003HZmR[V:_00=N[`=N/003GZmN
/5j_009NT09RS`04H[1NSej?GXh2HZh00ej_GXmNS`02GXd02Ei/GVeJC5i]GXiNSei^GVeNK002GVd0
0eY]FViJKP03FVh00ei_GXiNSP03GV`2GV/00eY<FVaJK@05FV`2FVd2FVh015Y<FV]JBei;0UY<0UY=
00=JKEY/FV`015Y/00=JC5Y=FTd01EY=00AFC5I;ETaFC0EFB`=FC0=FB`EBB`9FB`04ERaB;58/DR`4
ER/00e8[DRaB:`0:DR/014h[CP]>2dh;0Th[00=>:Th:CPX00dh:00I>2dh:CR]>2dh[CP/4CP`1CP/1
CPT1CN`000<88@<8@@03340<80`P00H88@05324<@@a134488@0234403a11440DP0aP320400P0788m
IeI>HXeNSej>FViJK`04FW02FVl3FW0015j?GVmNSei_1Ei^00=NKej?GY000ej?0V:?00ANSf:?HXmR
S`9NT09RT0ERS`9RT09RT@=R/@03G[5NTF:a00=R/003H[5R/V:b009R/P05H[5R/V:bH[9R/@03H[80
0f:aH[9R/P04H[400f:bH[5V/@02I[400fJAHY5Vd@02I]42I[400fJbI]5Vd@03I]43I]802FKCI]9V
dVJaHXmNKeY@G[=V/P03I]83J]800fKBJ]9ZdP05J]82J]<01F[bJ]5ZdF[BJ_<00V[C36[c0V[b00=^
lVkcK_801Fkc00A^m6lDK_A^l`9_4P06K_1ZcfkaKa9c<G<b0W<c1g<b0W<c00=c=7<cLc<00W<b0WLb
00Ec<W<cLc=c<g<b00=c<`=c<PIc<`9c=0]cE09cD`04LeAcEG=ELeD6Le@4Me@00gMCMeAgE006Me@0
17LeMcA_56kc0Vkb00U_4gLAOc5oD7maOe9k<gLdNeD00W]D00AkDg]cNe=g<`=kD`=kL`0;NgAkU7nD
Ni9kLWMCMc=gDgLbMe9kD@02Ne82Mc<05FlBI]1^l7L`Ng5kKg/aNc1g<flCJ]1VS5X[BHU=QeHXH[1V
/6KAJ_1Zl@02J_82J_<01VkcJ_=^lVkcKa=_509_5@=_=@05KcI_=FlfLcE_=P02KcD2LcD3Lc@2KcD5
KcH017<eKcI_=W<e0g<d0Vld26le17<e00=_=VleKcH00fld0W<d1Fle00=c=6leKcD00Vle00Ac=G<d
LcAc=0E_=@A_=0=_=@9_=0M_=@9_=0=_=@9_=004LcA_=6leKc@5Ka@7Ka<5Kc@00flDKa=_4`03Ka@5
Ka<2Ka@00f/CKa=_4`05Ka<4Ka86Ka<01FlBK_9^lVkbJ_<00flC00=ZlfkcK_800Vkb2f[b2V[a0V[b
16[a0VKa0VKb00EZlV[aJ]9ZdVKb009Vl@=Zl@EZd@9Zd0=Vd006I]5Vd6KAI]9VdFK@1FKA16K@00=V
dFJ`I[000VJ_00=V/6K@I[400V:a00AR/6:aIZmR[`AV[`05I[1Vd6K@I[1R/@03H[05HZl4HZh2HXh2
HZh4GZl015j`GXmNT5j@0f:?00=RSUj?GXh01Ej>00=RSEj=GXd00Uj=00ANKUi]FViNKPANK@9NKP=J
KP04GXiNKEi]GVd3GV`2GV/00eY]FVaJK@07FV`2FVd015Y<FV]JJei;0UY<0UY=00=JC5Y;FT/01EY;
00AJC5Y=FTeJC@AFC0iFB`EBB`03ET]F:e8[009B;003DR]F:UH[009B;003DR]B;58[00MB:`03CR]B
:dh:009B:`E>2`9>:P=>2P04CP]>2Th[CPX4CP/2CP`1CP/1CPT1CP`000<88@042488@@Q134423204
22401P@Q224<8@a2344<8@888@0>344<@Q11468<H@aP200<81R2=DIBCUj<GZmNS`9NT0EJK`05GW1N
Kei`GY1NL002FW000ei_GViNK`03GVl2GY0015i`GVmNSej?1Ej@00=NSej@GY000V:@16:?00=NT5jA
H[400f:A1F:a0f:`0V:a1f:b00=R/F:bH[801F:b0V:a00AV/F:bI[5R/@9V/P03I[5V/VJb009V/@=V
/PQVdP09J]9VdfKBJ]9V/5Y>ERiNTF:b00=VdP03J]9VdV[B00=Zd`9ZdP9Zd`9Zl`9Zd`9ZdP03J_5Z
lV[C00mZl`03J_9Zlfkc00E^l`04K_A_56kcK_82Ka<2K_42Ka800g<aKc=_<`06Kc<7Lc<4Lc801g<c
Kc=_<g<cLc9g<W<b00=c<`03Lc9c<g<c00Ac<`9c=0IcE003KeEcE7=D009cE09cD`04LeAcEG=ELeD2
Le@4LeD00g=DMeAgE003Me@03g=EMeEgE7MEMgAgMGMDNeE_569]GT]RK6k?K_1^l@02Ka82Ka<01Fld
KaA_=FldKcD00W<d00Qc<gLcMc=g<gLdLaAc=7Ld0WMc00=kLW]BMc<00WLc17MC01]gE7MCNe=kDWLB
J]5^cg/>Og5kKg/aMc5c<fkbJ]1Z[5XYDLQAaeY9HXiR[fK@I]5VdV[cJa@00f[d00AZlfkbK_=_4`9_
509_5@9_=@03KcI_=Flf009_=@Ac=@06LcAc=G<eLeEgEG=E0fmF0Vlf00Ec=VlfKcE_=G<e009c=004
KcE_=VleKcH3KcD016lfKcE_=Fle1Flf0fle0W<d26le00=_=VleKcD066le0Vld0Vle00=c=6ldKc@0
0Vld00=_=FldKc@00VlD00E_4flDKa=_4flB00=_4`03Kc=_=6ld00A_=003Ka=_56lD009_500:Ka=_
56lDKaA_4flDJa=[56lDJa<5Ka<00f/CKa9_4`05Ka<00f/CKa9Zl`02J_<00f[bJ_=Zl`03J_<2K_<0
0fkbJ_=ZlP0:J_84J_401V[bJ_5ZlVKaJ_9Zl@9ZlP04I_5ZdFKAI]42I_82I_<01F[bJ_5ZlV[aI_80
16KA00=ZdF[@J_800V[A0VKA0V[b00AVlVKAI]5Vd@9VdP03I]5Vd6KA00=Vd@03H]5VdFKA00=Vd004
I[1V[fJ_IZl2I[03I[42H[42H[02IZl2I[02IZl00f:_H[1R/007H[001V:^GXmNSej?HZiRSP=R[P=N
/006GZmN/5j?GXmNT6:`0f:?1Ej?1ej>00ANKeY^FViNKPQNK@=NSP9NK@=JK@9NK003GViJK5Y]00MJ
K008FVeJK5Y<FV]JK5Y[FVaJC09JC@04FTaJBeY;FT/4FT`4FTd4ET`00eI=ET]FC002ET`8ET/8DT/2
DR`2DR/01UH[DRaB;58/DR]B;0QB:`03CR]B:e8[009B:`9>2`06BPa>2dX;CP]>:dh:14h;00=>:dh:
CP/00Th;00EB2dh;CPa>2e8:005>30000`PQ0PPR0`PQ00<<80PP22001@PQ0P`Q10PQ0`a200X<@A1P
220801AQ=DE>;Uj=HXiNSPIJKP04FVmNKei`GXl2GW001Ui_GW1NKej>GXmNK`ANT003GW1NSej@009N
T004GXmNT5j@GY02GXl7HXl2HY02H[400ejAHY5RT@02H[45H[02H[46H[83H[46H[82H[402VJ`H[5V
/F:bI[9V/FJ`I[5V/V:b1FJb0VKB0fJb0VKB00YZdFKBJ]9ZlV[@GViJCUiaHY5V/P9VdP=ZdPEZd`03
J]9Ve6[C00=Ze004J]=ZlV[aJ_8@J_<8K_<00fkdKaA^lP02K_800flBK_5^l@02Ka400g<aKc=c<`07
Kc<6Lc<01WLbLc9c<VlcLc9_<`9c<`=c<P=c<`03Lc9c<g<c00=c<`04Lc9c<g<cLe@3Lc<7Le@2Le<3
Le@00gMDLeAcE004Me@3Me<6Me@037MEMgEgMGnDNeIZdEF2EJ=J9fJ;J/e^c`=Zd09Zd@=Zl@03J_9Z
lFlB009_4P0:Ka5_4VkbK_9ZlVlCMc9gDgMBMe<3Ne<2Me<2Me@057MENe=kLGn]Ma5ZdVZ^MbigDWMA
Nc5g<G<cKa9Zd6J/HVYRJf:<IZ`2I/l01VJ_GViNKV9_I]5ZlP9[5003J_=_4Vkc009_5004Ka=_56lD
Kc@5KcD00flfLcEc=004Lc@2LcD00g<dKeEc=@03KcD3LcD00fleLcEc=@02Lc@017<eKcE_=Flf0fle
00=_=VleKcD00fle0flf00=_=G<dLc@00W<d00Ac=FleKcEc=1I_=@03KcAc=7<d00=c=003KcE_=6ld
00a_=0=_509_4`04Kc=_4flCKa<2Kc<4Kc@2Ka@2Ka<016lDKa=_4flC0flD0flC00=_56lCKa@00flD
2VlC00=_4VlCKa<00V[c0fkb0V[b00EZlfkcK_=^lf[c00]ZlP9Zl@04J_9ZlF[aJ_47J_801F[aI]5Z
lV[bJ_<00VKc00AZlV[aJ_5Zl@EVd@=Zd09Zd@9Vd@03I]9VdFKA009Vd@=VdP03I]5Vd6KA00IVd@EV
d09V[`03I[1R/6:a00=Rd@9R/@06H[1V[f:_H[1V/6J_1V:_1F:`00AR[f:?HXmRS`9R[P03HXiR[V:^
00AR[`9R[PIRS`03GY1R[ej_009NS`03GXiNSej>00=NS`05GXiNKUi^FViNKP02GVd2GV`00ei]GVaN
K003GXd00ej>GViJKP02FVh01Ui^GVeNKEi]GVaJK@AJK0=JJ`05FVaJJeY[FV]JK003FV/00eY/FTaJ
C003FT/015Y<FVeJKEY]15Y=25I<2UI;1e9;00QFBeH[ER]B:eH[DRaF;58/2U8[0e8Z0U8[24h;00=:
2dh;CP/00Th;00U>:Th:CP]>2U8:CP]B2dh:DPT00Dg/00000`a1320<@@0322400`PP22488@062243
244522402``Q344<@@a0200401A1=BE>;Uj=HZl01UY^00AJKeY`GW1NT0ENL003GVmNSUj?00iNT09N
S`MRS`9RT005H[5R/UjbH[9RT@06H[401F:`H[5R/F:bH[4016:b0f:a1V:b0V:a00=R/6:aH[400V:b
00AR/FJ`I[5V/P9R/P04I]9V/VJbI[83I]801FJbI]=V/fKBJ]800VKB00QVdF[`HXmNKUi_HY5R/VJb
0VKB0V[B00=Zdf[BJ]800f[B00EVdf[CI]AVe6[C009Zl`03J_5ZlV[c00iZl`05J_AZlfkcK_=Zm005
K_@01VlEKaA^lVkbJ_=ZlP9^l@03Ka9c<Vlc009c<`=_<`=_=004Kc=c<g<cLc@6Lc<017<bLc=_<flc
0W<c0g<b27<c0g=D0g<c1g=D00=cDgMCLe@00W=D00=gE7=DLe@017MD0gMC00=gE7MCMe@00gMD015g
EG=FLeIoM7]FHRe=0DeRGRMVRf[=J/mZlF[AJ]1ZdFkb00A^l@9^lPI^l@0UKa9c4WLbMe=g<gMCMe9k
DWMBMeAgDgMDMe=gM7]bOi5o[WLCHW1VK7<?LeAgDW]ANc9c=6lDJ]5V[FJ<HXeVSF[_Kc=_4V[@IZl0
0UX/00INKVKAI_9[4V/CKa<3Ka@01FlCLaAc56lDKc@016le00=_=W<eLc@00g<d0W<e0Vle00A_EFle
LcAc=0Ac=@9_=@03LcE_=Fle009_=@I_=PE_=@=_=P9_=@=c=0=c=@03LcA_=Fle00A_=@03KcI_=Fle
00]_=@9_5@A_=0M_=@03KcA_56lD00I_509_=09_50U_4`I_5005Ka=_56lDKaA_4`03Ka@3Ka<01FlD
Ka=^m6kdKa@01VlC0VlD0VlC00=ZlflCKa<00VlC00AZlf[bJ_9^lP=Zl`04K_=Zlf[cK_<>J_83J_48
J_83I_<3I]8016KcI_9VlV[a1FKA0V[@00AZdFKBI]5Vd@9VdP=Vd@AVdPIVd@9VdP03I]5Vd6K@00=V
d003H[1R/F;A00ARd@AR/@03H/mRd6:`00=R/0ER[`03H[1R/F:a009R/@03H[1R[f:?00AR[`9R[P9R
S`03HZmR[V:^00=RSP=RS`=NT0=N[`03GXiNSej?00ANS`03GViNKeY_009JKP04GViNKEi[GVd5GV`0
0ei^GVmJK`02FVl2GVh015i]GTeNK5Y]15Y/00AJJei/FV]JK0=JJ`EJK09JC003FT]JC5Y<00UJC@QF
C0YFB`IBB`03ET]F:eH[00EB;0QB:`9F:P=B:P9B:`08CR]>2dh;CP]>:dh;BP]>2`=:3004CP]>:dhZ
CPX2CP/01E8:CPYB2U8:DPT00E8<000334001``P22488@PQ320<@0a100D88@03244<@@Q100@88@0<
220400@P224880@0000<8344BReNS5j>0UY^0ei^00AJKUi^GVmNK`ENL007GVmNKUj>GXiNSej@GY40
0ej@0ej?1Ej@15j?16:?00YRSV:?HXmRT5jAG[9R/EjBHY5N/PAR/@03H[1R/F:a00ER/@03H[9R/F:`
009R/@9R/PER/@03H[1R/F:a00=V/P=V/@03H[9VdVKB00MVdP03I]=V/fKB00AVd@0:J]1V[ei<FTeR
L6:aI]5VdVKAI]84J]82J]4016[BI]9VdVKC0V[C0V[b00=ZlF[bJ_<01f[c0V[b0f[c00=Zm6[cJ_@0
0V[c00A^lf[dJ_A^m09^m@A^l`03K_9Zlf[B009Zd@04Ka5g<7<bLc82Lc<2Kc<3Kc@017<cKc=_<flc
0W<c16lc00=c<VlcKc<00flc0g<b0Vlc0W<b1W<c00=cE7<cLc<00g=C1G=D00=cDgMCLe<01G=D0WMD
00MgDgMDMe=gDgLcMe=gDP05Me<04GMELeEkDfkcFJY4h4E1GVM^cFk_J/mV[V[?K_5^d6Z`J]000Vk@
00E^l6[@J]1^cfka009^l09^d004K_5c4WLbMc<2Me82Ne409GMBMe=gDgMCNe9kLg]bOg1oKVlDGRiR
BVl?MgAkDg]ANe9g=6lDJ_5V[UiZGTQN9fJ<J_1_<W<cJ_1V/5X/EPYJCFKAKa5[4VlC00=_5006Ka=c
57<DKaA_=6le0Vld0Vle00Qc=G<dLcAc=7LcLcAc<fld16le00=c=7<eLcD01Vle0Vld00=_=FlfKcH0
2Fle0flf16le00Ec=7<eLcEc=G<d00=_=@03LcA_=Fle00U_=@09LcA_=6ldKcA_5FleKaE_4g<b009c
<`=_=@9_=09_=@9_=09_509_4`=_509_=003KaA_4flC00I_4`04Ka9_4flDKa@3Ka<00flDKa=_4`09
Ka<01FlDKa=^m6kdJ_@016lC00I_4VkcJ_9ZlfkbK_<2J_801flCKaA_4f[cJ_9^lfkb00=Zl`03J_9Z
lf[c00IZlP04J_5ZlVkbK_83J_801FkaJ_5ZlF[@J_400f[b00AZlF[bJ_9VlPUVdP03I_9ZdFKA00AV
d@04J]1ZdFK@I]43I]8016KAI]1Vd6K@1FKA00=Vd6KAI]000VKA0VKB00=VdFK@I]000fK@00IR/F:`
H[1Rd6:aH[03H[401V;AH[1Rcf:_H[1V/09R/0ER[`9R/003H[5R/6:`009R[`MR[P03HXiR[V:^00ER
[P9RSP05HXmR[ej@GY1N[`03GXh3GXl3GXh00ei^FVmJL002FVl015i^GVaNJei]0Ui/00ANJei/GVaN
KP9NK`9JK`9NKP04GVeJKEY<FVd7FV/015Y/FV]JJeY[0eY/00=JJeY;FT/00UY;0UY<0UY=3eI<15I;
00=JBUI;ET/01UI;0e9;00=FBeH[ETX01E8/258[00=F:U8:DPX00U8Z0U8[00=>:dh;CP/00Th;00E>
2Th;CP]:2dX<00=>2`04CRY>:e8ZCPX2CP/2CPX1DPT1DP/0000;364@HA10320<8@PQ324<@A1Q340<
@@0422400`Q2348<@P0224400`PQ24488@0222402@Q134440000320]14H<GVaNSP02FVl00ei_FVmJ
K`02FVl00eY`GW1NL004GW02GVl00ej?GXiNS`05GY03GXl5GY000ej?GY1NT004GY000f:`HXmRT002
HY0016:aG[9N/Ujb0UjA00=R/F:@H[4026:a0f:b3F:a00=V/VJaI[800fJb00=R/VKBI]800fKB0VKC
0VKB0VKC00aVdV[AI]5ZdFKBI]1V/6:?FReNKf:@I[03I]82J]<5J]83I]<00f[CJ_=ZdP02J_88J_<3
J_800f[cJ_AZl`03J_@2J_<00fkcJ_A^m@02K_D01FlFK_A^lfkcJ_<00V[b00EZdV[AK_5_4GL`009c
<P03Kc=_=6ld009_=003Lc=_<g<b00m_<`03Lc=_<flc009_<`9c<PAc<`03Kc=c<g=D00QcE0=cD`04
LeAcDg=DLe<2LeD2Le@00gMDMe=gE002Me<027LcMcAgDgMDMe=gE7MCMg<2Me@02W]BJ[1EJD30BF=J
BFJ]JZiVS6J=169/00AVKFJ>IXiVSP=VS@0:IZiZ[FZ]JXeVK6J?K_5c<W]CMe85Me<06GMBMe=gLg]c
Ng5kD7m?K_=N;V9:L`mgEG]CMe9kDg<eKaAZdFJ]FT]EieG5GTYVd6[a009_4`06J_5Vd5X[DNYJCFK@
0VlC00Y_=6lDKaA_=7<DLcAc=G<dKcE_=0E_=@9c=003Mc=c=6ld00I_=@E_=P9_=@04Mc=c4g<dKcD2
KcH9KcD3KcH5KcD3LcD01FleKcI_=FleLcD03Fle00=c=6lDKaD00VlE00A_57<BLa=c<`=_=@9_=004
KcE_=7<cKc@>Ka@00flCKaA_4`02Ka<2Ka@4Ka<00flDKa=_5009Ka<7Ka@2Ka<3K_<00f[cK_9ZlP02
J_8016kbJ_=Zlf[c0V[b00IZlf[dJ_=Zlf[bJ_<5J_8026kbK_5^lFkaJ_9^lVlBKa<2J_800fkaJ_5Z
lP02J_42J_8016KaI_9VlVKB0VKC2VKB00EVdFKBI]5VdF[@00=Zd@AVd@=Vd0IVd@04I]9VdFKAI]03
I]400fK@I]5Vd@02I]42H]800f;AH[5R/@05H[401F:`H]1VlFKAI[0016:`0f:_0V:`00=R/F:`H[00
0V:`0V:_00=R[V:_HZl00V:_00=V[f:?HXl00f:^00aN[Uj>HXmRSf:@H[1N/5j@G[1NSej>GXd5GXl0
0ej>GXmJK`03FW02FVh01Ui/GVeNK5i/GXeNSP9NKP06FVmJKUY_FVmNKeY^0ei^00=JKUY/FV`00Ui[
00=JJeY/FV`01eY/00=JBeY<FT`00UY<00=FCEY=FTd00UY=00AFC5I=ETeFC@EFC003ETeFC5I<00AF
C09FB`04ETYFBeI;ET/:DT/00e9:DT]B;003DR`5DR/0158/DR]B:e8[0U8:0U8[00=>:e8[CR/00Th;
00=>2Th;CPX00Th;00=:2dX<BP`00TX;0Th[0dh:0Th;0Dh:0E890E7[00000`aQ460@H00332001@`Q
344@H0`P34002@PQ00<480@012000PPQ00/<@0a134440@`Q:@A5jej<HZiJKeY`009NK`AJL09NK`AN
L003GXmNKej>00=NSPQNS`ANT005GXmNT5j@GXmR[`03GY000f:?HY1RT@02HY001EjAH[5NTF:@H[40
0f:`2V:a00=R/V:aH[402V:a00=V/6JaI]4016Jb00=VdVJbH]800fKB0VKC015VdVKAI]9VdfKBJ]5V
dF[AJ]9ZdFKAI[5RKeX]GTaR[VKA009VdP9Zd`9VdPIZdPIZlPIZl`04J_9ZdV[BJ_83J_<5J_@01fkc
J_A^mFkeKaI^mFkd009^l`04Ka=_4V[cK_<2K_4016k_L`i_<G<a0Vlc0Vld00=_<flbKc<00W<a00=c
<VlcLc<01G<c0g<b1flc00Ac<g<bLc5_<`=c<P9c<`9c=0McE0IcD`03Me9gDg=D009gE003Me=gDWMC
00=gDPAgD`AgE00>MeEkLfZaEHY0`DE2FRQNBUi;FRUEae76ELIEa@9Ei`03DLMEj5H9009J200;FPMJ
9eXVFRMJ1UWWFRUV[flBNe=kDP03Me<2Ne<097]BNg9kLG]bNg1kD7/aKaARL6J=L`mgE7]DMe9g<W<d
Ka=Zd6J^GVeEbE6VGTYV/6[BJ_5_4W<bKa1V/5H>EPYNJfK?Ja5_4P9_4`07KcA_=G<eLcEc=6leLc@0
1Fle00=c=6ldLc@01Fle0Vlf00=_=FlfLcH016lf0Vle00=c=6leKcD01Vle00=c=FleLcD01fle1W<e
00=_=FlfKcD046le0VlE00I[5FlEKaA_4g<CKc@3KcD2Kc@01FlDKa=c<FlcKc@016lD00=_=6lDKa<0
0VlD4FlC00=_56lCKa<02FlC00=_56lCKa@00flD00IZm6kcK_=_4V/CKa86K_801V[bK_9^lVkcJ_=^
l`EZl`9ZlP03K_9^lFka00=^l@]Zl@04I_5ZlF[BI]83I]<:I]82I]400f[AI_5Zd@04J]42J_400fKA
J]1Vd003I]04I]42I]801VK@J/mV[VJ`I]5Vd0AVd@ERd@04I]5RdF:aH[42IZl2H[0016J_HZmR[f:_
0fJ_0V:_0V:`00=R/F:`H[000f:`0V:_0V:`00ER[f:>IXmRT6:?009RSP04HZiN[V:^GXl2GY001F:`
G[1N/5j@GXl01ej>0ej?00=NT5Y`FVl00Ui^0Ui]0ej=00=NKUj>GVh01Ei^00AJKUi^GViNKP9JKP04
FVeNK5Y[FV/2FV`00eY]FVaJK004FV`00eY[FTaJC007FTd015Y<ETaFC5I=35I<0UI;00=FBUI;ER/0
0UH/00EB;58[DR]FBe9;009FB`=FBP05ET]B:e8/DR]B;005DR/0158/DR]B:e8[0e8:00=B:U8[DR/0
0U8[00A>2ThZCPY>2PU>2`9>2P05DPU>2Th:CPY>2@01CN`00009360<@110320<8@PQ344<@Pa1008<
80@88@0312088@PQ00888@0?22088@PQ224880`P3408@@@0220Ta4GZGX]R[UY_00=NK`05FVmJL5Y`
GW1NK`03GW0015iaGY1NT5j?0Ui_00=NSUj?GY001Ej@00=NSej@GY000ej@00=NSf:@HY000V:@1Ej@
0V:A00ART6:aH[5R/@9RT0=R/0YR/@=R/P03H[5R/V:a00ER/@03HY5RT6:`009R/@03I[9VdVKB00=R
/P9RdP03H]=VdVKC009Vd`03I]5VdVKC00=VdP9ZdP08J]5ZdV[AIY1NCEi<HXiR/09VdP9Zd`03I]=V
dV[B009VdP03J]=ZdV[b00IZlPIZl`03K_=Zdf[C00AZl`EZm003J_=Zm6kd00=^m@0;KaA^lfkdKa=_
4VlCK_A^lVkaK^mc3`03Lc801g<cKcAc<g<cKc9_<g<b009c<@9c<P9c<`03Kc=c<W<c009c<`03Lc9c
<flc00E_<`9c<`=c<PAc<`9c=0QcE09cD`06Me=gDWMCMe9gDg=C0WMD00YgDgMBMe=gDW]AMe=gE7MC
Mg=gD`=gE00;McEgEG]dJ]9IjdSQBB=AQUhWFPQAa@03DJD01EG5ELMEj5GXDNP00U7800eEj5H7ENME
ieH9FPUEieX9HXi_4WLcMe9gD`02Mg<00gMCMg=kLP03Ng4057]`Ne1oLW=FI[=Z[g<AMeEgE7]cNe9c
<flCJ_5V[Ui]ELUAQV9/I]42J]401F[bKa=_<VLCH[000UH:00QNK6[`Ja9_4VlCKcA_=Flf36le00=c
=6leLcD017<e00=_=FlfKcH00Vlf0Vlg0Vlf1fle0W<d00=c=FlfLcD017<d00Ac=FleKcE_=@=c=@04
KcEc=G<eKcH3KcD00flfKcE_=@09KcD00flfKcE_5@03KcH016lEKc=_=6ld0fle00Q_56lCKa=_4g<b
Lc=_56ld26lD0flC00=_56lCKa<01VlC00=_56lCKa<02FlC00A_56/DKa=_50=_4`E_5003J_AZlf/C
009[4`=_4`9^lP9_4`=^lP=Zl`05J_9[4f[cJa=Zl`02J_84K_4:J_43J_800f[aJ]9VdP03I]<4I]83
J]82I]801F[BJ]5VdFKaI_800fKA0V[A00=VlF[AI]401FK@16KA00MVdVKAI]5Zd6J_I[1V/@02I]43
I[400fJbI[5Vd@02I]44I[08IZl5HZl<H[001F:?IXmVSf:@HXl00f:^00ENSV:_G[1R/5ja009N/09N
T09NS`MNSP9NS`03FY1JL5Y_009JKP03FVeNKEj=009NS@03GVeNKUj>00ANKP03GVeJKUi^00AJKP03
FVeJK5Y/00=JK003FVeJK5Y/009JK003FT]JK5Y[009JC0MJC@03FTaJ:eY<00iFC003ET]FBUI;00IF
:`04ET]BBeI;ET/4ERX0158[DRaB:e8/0e8[00MF:e8[DRaB;4h/DRaB2`02DPX00e8ZDR]B:`03DR/2
CPX014h;CR]>2dh[14h;0Th:00=B2Th:DPT00e8:0Dh90Dh<00000`aP340<80052242324234400`Q1
224480022202100010PQ2408@@a00PPP00X<80a0340400`P8<=1YUiZHZaNS`=NKP04FVmJL5i_GVl2
GVh00ei_GW1NL002GY001Ej?GVmNKei^GVl01Uj@1Uj?00ANT6:@HY1RT0INT003GY5RTF:A009RT@04
HY1RSf:?I[04H[02H[400f:AH[5R/@02H[400f:`H[5R/@03H[43H[001f:aHY5RTF:AHY1R[f:`009R
/@05I]9R/V:bH[5Rd@03H]801F;CI]=VdfKCI]401FKB00]VdFKBI]5ZdF[@IZmRSei]HViRSfJa009V
dP04I]=VdVKBJ]82I]800f[CJ_9Zl`08J_84J_<00f[bJ]=Zd`02K_<4J_<2J_@3J_<016kdK_E^mFkd
0flC00U^lfkbJ_9ZdFJ_J/m^kg<?Kc800W<b00Ic<fldLc=c<g<BLc83Lc42Lc82Lc<00flcLc9c<`02
Lc<2Lc86Kc<2Lc<017<bKc=_<Vlc1g<c1W=D0g=C0gMB0W=C0WMC00=g<gMCMe800WMB00=g<gMCMe80
0WMC011gE7MCMeAgE7MeNeA_4f9>EHEAQV9:IXYRS6J=IXiV[P=V[`08J[1V/69_GTiRKfJ`I]1R[`=N
KP0;HXmV/6[bLc9g<g]BMg=kDW]CNe9kL`02Ng83Ng4097]ANg=gEV[cJZic4GMEMeAkLW]BKcA_4f[@
IZeRJeGXELERK6[aKa9ZlV[cK_9c<flcI]1NCEH;FR]V[V[bKa9_4fldKcE_=P=_=@9c=003KcA_=Fle
00=_=@=c=0Ac=@9_=@A_=P9_=`04KcI_=FleKc@2KcD00flEKcEc=@02Lc@017<eKcEc=G<e17<d16le
1G<d1Fle0flf2Vle0VlE0Vle00=_=6lcKc<00fld00A_56lCKa=_4`9_=004Kc=_4flCKc<4Ka@2Ka<0
1FlDKa=_4flCKa@01flC00=_56lCKa<01FlC00A_56lCKa=_4P9_4`03KaA_4f/C009[4`9_4`9^l`9_
4`9^l`04J_=[4f/CJa<7Ka82K_8016[bJ_=Zlfka0V[b00=[4f[bJ_800V[b00A^lF[aJ_5Zd@UZl@=Z
lP03J_5ZdV[B009Vl`=VdP03I]5VdV[B00EZdP05J]5ZdVKaI_5Vd@04I]000fKAI]1Vd008I]04I]40
16JaI[1V/FJa0fJ`0VJa00=V/VJaI[400fKA00IV/6:`H[1V[fK@IZl>HZl5H[0016:?H[1R/6:`16:?
00=RSV:^HZh00V:^00=N[V:^GZl00ej@00=NSej>GXh01ej>0Uj?0eY_00AJKUY]FVeNK@=NS@9NK@=N
KP04GXeNKEj=GVd2FVd2FVh2FVd5FV`00eY]FVaJK003FV`2FT/2FTX015Y<FT]JC5Y<0UY=00AFC5Y;
FT]JB`9FB`EJC003FT]FC5I<00AFC006ET]FBUI:ETYFBeI<0eH[00AFBe9;ET]F:`AF:PUB:`EB;006
DR]B2UHZDR]B:U8[0Th;0dh:00=>:dh:CP/014h;0Th:00AB2Th:DPU>2@=B2@5B300000<<H@a03240
1@PQ00H<8@a1344<@@a024432243244634402@a0320400P07:8mYEiZGX]NT003GVl015Y_FW1JKeY_
0Ui^00=NKei`GW001Ei`00=NKei`GY001EjA1ej@00=R/6:?HY000Uj@00=NSejAGY000UjA0f:A0V:@
0f:?16:`00QR/F:AHY5R/F:bH[5R/V:a1F:b0f:a00IR/V:aHY5RTF:@HXl4H[44H[83H]801F;CI]=V
dVKBI]401VKB00AVdfKBI]5Vd@9V/008GVeNKei^HY1V/FKBI]=VdP9Vd`03J]=ZdV[b00UZlPEZl`05
J_9Zlf[CJ]=ZlP04J_<2J_@00f/DJ_AZm004K_@4Ka<016kbK_5ZdF[@0Vk`00I_4FlbLc9c<W<cKc<2
Lc<2La800g<ALc9c<P02Lc<01g<dKcA_=6lcKcA_<g<c009c<PA_<`A_=0=_<`9_=09c=09c<`03LcAc
<g=D00EcE0=cD`03Le9cDg=C009cD`03MeAgDgLc009gD`=g<`=gD`03MeAcE7=D009gE004LeAgE6le
J]<2J[4016kbMe=gE7MD0WME0WMF00AkEWMEMeIgEP=kEP=gEP06LeIgEWmFOeAkE7]C0W]b00AkLg]C
MeAkD`=kM00JNg9kLg]aNg9gE7=GI]9VKFlALcEgE7]CMc9_=6lCJ]1V[F9[FNQEaFJ<J_9_<fleJ_A^
l`9_5008J_5R/5Y=EPYRSfKbKc=cE@I_=@=c=0E_=@=c=004KcEc=FleKcD6KcH3KcL026lfKcE_=Fle
McA_57<DKcD2Lc@5KcD00g<dKcE_=@04KcD3Lc@017<eKcE_=W<e0fle16lf2Fle0VlE0VlD16ld0flD
0VlC00=_56ldKc@00Vld1flD0VlC1flD16lC1FlD2FlC0V/C0f/D0VlD00A^m6kcK_=_4`9^l`03J_=Z
m6/C009[4`9_4P9_4`04J_=ZlVkcK_82J_801F[cK_9^lVlCJ_<01V[b00AZdV[bJ_5ZlP=Zl@=ZlP=Z
l@04I_9VlFKbI_85I_<2I]86J]84I]8016KAI]9VdVKB4VKA0VJa1F:a00=V/VJaI]400VKA00AV/6Ja
H[5R/@9V/09V[`eR[`9R/005G[5R/6:`HY1NT002HY0016:?HY1RT6:@0f:?00ER[ej?GXiNSUj?00AN
T0INS`ENSP04GVmJKUI=FVh2FVd01Uj>GXeNSEj=GXiNK@ENKP03GVeJKeY^009JK@03FTeJK5Y^00IJ
K@03FVaJKEY/00=JK005FT]JBUY:FTaJC@02FT`5FTd2ET`01eI;FTaJBeY=FTaFC5Y;00MFC0AFB`AF
:`05ET]BBe9;DRaB:`03ER/00e8[DRaB;009DR`2CR`00e8/DR]B:`02DR/00dh[CP]>2`03CP/00dh[
CP]>2`04CP/00dh:BP]>2P05CPX1CPT1CP`00003364<@0a000D88@@<@@0934088@PQ224<@@aR3488
@@PQ00888P05224<@@a13208800210001QbQ@HAFBEZ;FVmNKP9NK`03FVmJT5Y^00=NKP9NK`QNL003
GY1NTEjA00ENT@04GY1NTEjAGY02GXl5HXl00ej@GY5NT@02HY42HY03HXl6H[03H[400f:`H[5R/@07
H[83H[4026:bH[5R/F:aHY1RSf:@H[43I[45H[400f;BH[9Vd`02I]801VKAI]9VdVKBI]5VdP9Vd`9V
dP0:I]5Vd6K?HXmJCei_HXmR/FJaI[82I]<016KBJ]9ZdV[A0f[b00=ZdV[bJ_800f[b1V[c00IZlV[B
J]9ZlV[cK_<6J_<3K_<00fkbK_=_4`03Ka<00flBK_5^l@02K_400fk`Ka5_<P03Lc8016lcLc=_<g<C
0W<c0W<b00M_<g<cLc=c<fldKc=_=002Kc<5Lc82Lc<2Kc@4Kc<3Kc@2Lc@2Kc@7Lc<017=DLe=cDg=B
17=C00=cE7MCMc@00WLd0WMD0WMC00=gDWMCMe<00WMD00IgDgMbMe=gE7<fKaD2J]8017<CMe=oM7nB
0WnC0Wmd0WnD00=oMGmdOgD017nD00=o]7nDOi@00WnD00EoTgmdNg=kM7]e00=kM0AkM@0GNiAoTGnC
Ng=c=VKAHXeg<G]dNg=g<WLaLc=_4f[@IZeN:5G5FLEVSF[aKa9Zl`02K_<02V[dJ_9_4VKAHXmF35H]
I]5[4G=F0Vle0g<d00Ec=G<dLcAc=7<e00=c=006KcAc<g<cLcA_=G<e0Vle00=_=W<fKcH00flf0flg
0Vlf0fle00Ac=G<dLcAc=0U_=@03LcA_=G<d00Ac=0Ec=@=_=@=_=PI_=@06KcA_=FlEKaE_57<D17<C
00A_4g<CKaA_5@9_509_=004Kc=_=6ldKa@2Kc@8Ka@8Ka<2Ka@=Ka<00fkcKaAZm002Ja@2Ka@01fkd
K_=^lfkcK_9^lflC009_5008Ja=_4VlBKa9Zlf[dJ_=^l`9^lP03J_9^lVkb009^l@03K_9ZlV[a00YZ
lP9Zl@=ZlP=Zl@AVl@03I_9ZdVKB009VdPMZdPAVdP9Vd@03I]9VdFKB00=VdP0:I]5Vd6KAI]5V/FJb
I]9VdFKBI]46I[45H[42I[401FKAI]1V/6J`H[000f:a0VJ`0fJ_2V:_0V:^0V:_1f:`0f:_16:`00=R
[ej?GXl00Uj>1Ej?0Uj@15j?00]NSUj=GXiNSUj=GVeJKEY^FVaNK5j>00ENS@INK@9JKP04FVeJK5Y]
FVd3FVh015i]FVeJKEY]0eY[0eY/0UY[00=NBeY<FTd00eY=00AFBeI<ETaFC09JC@07FTaJBeY:FT]F
BUI;FT/01eI<15I;0eI:0UHZ00=F:eI;DR`00eH[1U8/00=>;E8/DR`01E8/00E>;58/DRaB358/009B
:`03DP]>2dh;009>2`03BP]>2dh;00A>2`03CPY:2dh:00E>2P5>2@5=k00000<<H@a134401`PQ0Pa1
00T@HA1R344<@@a236<<HPa1324010PQ014<811R340800@07:8mI59:GXaJKeY^GViNKeY`FY1NKej>
009NKP9NK`04GW1JL5i`GW02GY000ei`GY1NT@05GY43GY03GY42GY05HXl2HY03HY44HY001F:`HY1R
/6:aH[001F:a00=R/6:aH[401f:b00=R/F:bH[401F:a00=RSf:@H[000fJa00MR/F:AGVmRT6:`I]9V
/P08I]83I]<3I]802VKAI]1R/Ei`GVmRSf:@H[5V/VKB0VKC00=VdV[AJ]800V[b0V[C00=ZdV[bJ_80
26[c16[b00IZlfkcK_=^lfkdK_<2J_@016[cK_=^lfkb1FlC00A_4VkaK_5^l09^l@03Ka5_<g<b00=c
<P=_<`05KcA_<flcKc9_<`03Lc<00fldKc=_=003Kc<2Lc<2Lc85Lc<00g<bKc=_<`04Kc@00g<dLc=_
=004Lc<2Mc<01G<cLeAcE7=CLe8017=C00AcE7=ELeEcE@=cE09gE003Me=gE7MD009gE00>Me=gDWMB
Mc=cEG<eKaAZdVkbLc5gE7]cNeAg=0=kD`05Me=gE7MDMeAkD`05Ng8017]cNgAkMG]e0W]c0g]d00=k
MG]dNg@00W]e01EkM7^DOk9kTW]CLcE[57<CNc5oLg]CMc9k<GLcK_=Zd6J]GRUIieh7IZd00V[b1F[c
00M_=6lDI]5JCE7/FViVl002Kc@016leLcAc=7<d0g<e00=c=7<eLc@00W<d00=_=FlDLa@01Fle1flf
0Vlg00I_=VleLcAc=6leLcD5KcD2Lc@4LcD00fleLcAc=003Lc@00fleLcAc=@03LcD4KcD2KcH01Vle
LaAc57<cLcAc<`9_=003KaA_5FlE009c509c4`=c4P03La=_56le009_=@9_=003Kc=_=6ld00A_=0A_
509_=003KaA_4flC00I_4`04KaA_=6lcKc<2Ka<2Ka@6Ka<01fkbK_=^lf/DJ_A_56lC00=_509^l`03
K_9_4fkc009^l`=_4`04Ka9Zlf[cJ_<2K_<00fkbJ_9^l@02K_42K_800f[bJ_5ZlP08J_800f[aJ_9Z
l@03J_82J_400f[AI]9VlP04J_800fKBJ]9ZdP05J]86I]800f[AI]5VdP03I]8016KAI]9VdFK@0VKA
00=V/VKBI]800VKB00=VdFJaI]401FKA0fJa16KA0VJ`00=R/6J`H[400V:a0fJ`00=R/6J_I[000V:`
1F:_00AR/6:_HZmR[P9R[`9R/005G[5N/5j`G[1N/@03H[03G[4016:`G[1N[ej_1Uj?00ANSUj?GY1N
T0=NS`03GXiNSEj>00MNSP03FXiNSUj=009NS@04GVaNKEi]GVh3GVd3FVh3FVd00eY^FVmJK`02FVh0
1UY/FVeJJeY]FVaJK@AJK003FV]JC5Y=00=JC@03FTaJCEY=00=JC@9JB`03FTUJBeI;009FB`04ETaF
;EI=ET`3ETd01EI<ET]FBeI;ETX00eH[00=F:UH[ER/00UH[0e8/0UH[258/0e8[0dh/0Th[0U8[00=B
2dh;CP/00Th;00=:2dh[BP/014h;0TX;1Th:0E890E8<0004344030Q12248@@Q1224880a0240<HA1R
34488@<<@@0524488@PQ22480002220030a1464@@0P0684i8E9:GZeNSei^GVeNKP9JK`=NKP04GVmN
KUi_GVl3GW000ei_GY1NT003GY03GY44GY03GY42GY07HXl3HY0016:?HY1RT6:a0f:`00=R/F:`H[40
16:a00=R/6:aH[401f:b0V:a00QR/6:aH[1R/FJaH[5R/6:>0fJ`0fJa0V:`00=V/6JaI]400VKA0fKB
0VKA1fKB0VKA00QV/V:AGViRKV:?HY1V/VKB0VKC00AVdV[BJ_9Zl@EZdP=ZlP03J_=ZlV[B00=Zl`MZ
lP04K_9^lfkcK_@4K_<026kbKa=_4VlCLa5_4VkbK_44K_001FlAKc9c<G<bLc400Vlb00=_4flcKc<0
0Vlc00=_<VlcLc<00W<c0Vlc00=_=6lcKc<00g<c0W<b1G<c00Yc<VlcKc=c<g<dKcAc=6ldLc=_<`=c
<`07LcAg=7LcMe9cE7<cLe<00g=B00EcDg<cLc=c=7=E009g=09gE0=gD`0FMeAcE7=DMeAgDgMBMe=g
<gMDNe=c=6lEJ]5_4FlcMc9g=7LeNe=kDW]CNg84Ne<02G]BNg5kLW]ANe9kDg]eNgIkM@02Ng<017]b
Ng=kLg]d0g]D01IkM7]cNg5kL7]BMc=c=7<cMc9kDG]CNc=g<W/`Mc9^lV[?IXaN:EWXGRQZcP9_4`03
J_9Zlf[c009Zl`0;KaA_=6[bI[1F;Ui=I/m[4VlCKcAc<`02Lc@2LcD00g<dLc=c=002Lc<00g<dKcE_
500<KcD3KcH2KcD2Kc@00fleLcAc=@05KcD00g<dKcE_=@03KcD00g<dKcEc=002Lc@01FleLcAc=7<d
KcD00W<d0Vle00E[5FleKcE_=G<c009c4P9c<P9c<`03KcA_56lD009c<`0:La=_4VlBLa9c4G<CLc=_
=FlfKcD2Kc@3Ka<00flcLc=_=005Kc@2Ka@:Ka<3Kc<<Ka<01FkcKaA_56lDKa<00f[d00=ZlfkcKa80
0VlC00A^lfkdKa=_4P9ZlP03J_=Zm6[d009^l`9ZlP03K_5ZlVka00=^l@03J_5ZlV[b00EZlPAZl@9Z
lP9ZdP9Zl@03J]5VdF[B00=ZlP03J_5ZdV[B009ZdP04J_9ZdV[BJ]86I]85I]42I]82I]4016K@I]5V
/6KA16KB0fKA16KB1VKA0VJa00IV/6K?IZmV[f:`H[45H[0016:_I[1R/6:`0f:_0V:`1V:_00=R/6:_
HZl016:`0f:_00QN[ej?GZmR/5j`GZiNSej>1Ej?0ej>15j?00=NSUj=GXd01Uj=00=NSUZ>GXh00ej=
00=NK5i]GVd00Ui^00INKEi^GVmJKeY^FV`2FVd00eY^FVmJK`02FVh01UY/FVeNK5Y]FVaJK@9JC09J
K003FV]JC5Y=009JC@04FTaJK5Y/FT`3FTd00eY<FTYJBP03FT/01UI:ETaF;EI=ETaFCP9FC@03ETaF
:eI:009FBP05ER]FC5I;ETYFB`03ER/5DR`00eH[DR]B2`02DR/3DR`00e8[DRY>2P03CR/00dh:DP]B
2`02DP/3CP/01Dh:CP]>2Th;CR/00dh;00=>2TX:CPX01Dh:0E880E8;000030Q1324<@Pa1244<@PaR
36<<@PPP3248@@D<@@<8@@032248@@PQ00<880<<8006200D@3D2CPYJSEj@0UY^0eY_0ei_0ei`00QN
Kei`GVmNL5i_GY5NT5jA0Uj@00ANTEj@GY1NT09NT@=NT0=NT@ANT0=RS`ART003H[5N/Ejb00]R/@UR
/PIR/@04I[5R/F:`H[03I[07I[400fJ`I]5Zl`05I]82I]43I]801fKCI]9VdVKAI]9R/F:@009RKP0?
HXmR/FJbI]=Zm6[cJ_9Zlf[bJ]=ZdV[CJ]9Zdf[B009ZlP03J_=[56[d009Zl`03J_9Zlf[c009Zl`04
J]=Zlf[cJ_82K_<00fkdK_=^l`05K_<016lCM_5^lVkb0fka00QZdFkaKa9_<WMALc5c<Vlb0Vlc00E_
4flcKc=_<flb009_<`03Lc=_=6ld009_=0=_<`04Lc=g<W<bLc84Kc<00g<cLc9_<`03Kc<017<cKcA_
=6lc0Vld00=_=G<dLc@00W<d00Ac<gMDMe=c<`=cD`05LeAc=7<dLcAcE@02Mc@2Me@00g=CMe=gD`02
Me<2Me@4Me<2Me@02W=EMcAc=6lCJa=_4g<DMcAgE7]C0W]c0W]e00=gE7LcNe<00W]c00IkLW]BNe=k
MG]fNgD2Ng<00g]bNg=kL`02Ng@00g]eNgAkM002Ng8057]aNe9g<gLcMcAgE7MCMeAkDg/bNa1g4Fka
JZiVReX9ENQRBf[`Ka<7J_<02VlCJ_5Vd5i]FR]RSV[@Ka9c=7<c0W<d00E_=G<eLcEc=7<e00=c=003
LcE_=Fle00]_=@=_=P9_=@9_=09_=@03LcE_=Vle00E_=@9_=PE_=@9c=@03LcI_=Fle009_=@9c=003
LcEc=Vle00=_=@05KaAc4gLBLa9c<`04Kc@01FleLcA_=7<cKc@00flc0Vld00=_=FlfKcH00flE00A_
56lcKcA_4a=_509_4P06J_9_4flCKaA_4flD1flC0VlD0V/D00=[5F/DJa@00V/C0flC0VlD00A_4f[c
J_=ZlPEZl`9ZlP03J_5ZlV[a00=^l@03J_5ZlV[b00AZlP9Zl`04J_9ZlF[bJ_45J_801F[AJ]9ZdVKB
I_800V[c0V[B00=VdV[BJ]800f[B16KB00=VdfKBI]801FKA00=VdVKAI]4016KA0VKB00=VdFKBI]40
0fKB1fKA00IVdVJbI[9V/FJ`I]07H[02H[46H[000f:_H[1R/002HZl3H[04HZl4H[03HZl3H[02G[00
0ej^GZmNS`05GXl00ej>GXmNSP05GXl2GXh5GXd2GXh00eZ>FXeNSP02GXh2GVh00ei]GViNKP02GVh2
FVl01EY^FVeJKEY]FVh00UY_0UY^0UY]00AJK5Y]FVeJK@AJK003FV]JK5Y<00IJC004FTeJC5Y<FT/2
FTX015Y;FR]J:eH[0UH]00AFCEI<ETiFCP=F;@=FC003ERaF:eH[00EF:`=B;003DR]F:eH[009F:`9B
:`9B;004DPaB:e8ZDRX3CR/5DP/5CP/00dh:CP]>:`03CR/01Dh:BP]:2dX;BPX00dh:0E880E8;0000
0`a132488@02224324400`a132488@0822431243220222402@a0200400`P<>95b5I^FXiJKP03FVl0
0ei_GXmNL003GW03GVl015j>GVmNT5jA0Uj@00ARSUj?GY1NT0=NT@05GY1NSej?GXmNT004GY400f:@
GY1RS`02HXl2HY001EjAHY1R/F:aG[8036:a0V:b0f:a0f:b0f:a00=RdFJaI[401VJa1FJ`00=RT6:A
HY000V:`00AVdFKBI]5V/PAVdP03I]5VdVKB00AVdP09I[9V/F:`HXiNCEi^HY5R/FKC009VdP03J]9Z
df[B00EZd`03J]9ZlV[b00=ZlP9Zl`03J_9Zlf[c009Zm003J_=Zm6[d009Zl`Q^l`04Ka=^lfkbK_82
K_<2K_401V[AJ]1_4VlbNe1g<P=c<PE_<`04Kc9_<g<bLc<4Kc@00flbKc=_<`02Kc<2Lc<00fldLcA_
=002Kc<3Lc83Kc<2Lc<00g<bLcAc=002Lc@01G<eLcAc=FleLc@00W<c00=c<W<cLc<017<d00AcEGLd
McAgE0AgD`06MeAcE7=DMeAgDgMB0gMC00UgDWMCMe9g<gLdKaE[5G<EMcD00W]c0W]d00MkMG]gNgQk
VGnGOiIoM@02Og<027]dNgEkMW]eNgAkLg]aNg84Ng@01g]cNiAkUG^DNg5kDg]A009kDP0@MeAgDg]C
Ne9kDG/?L_1^l6Z/IVYEj578GVaZcf/BJ_86J_<02fkbK_1VcV:<FPQJ:fJ<Ka1c<gLcLc<017<d00=c
<g<eLcD00Vle0W<d00A_=FldKcE_=0e_=@05KcA_=FlDJaA_=@03KcH016leKaA_=7<e36le00=_=6le
KcD01Fle00A_=6leKaAc509c4`03La9_<flC00]_=003Lc=_=Flf00=_5P03KaE_56lc00A_4`04KaA_
4flCKa<3Ka@00flCKaA_5002Ka@4KaD01FlDKa=ZlV[cKa@00VlC00E_4VkcK_=^lflC009_5004Ja=_
4flDKa@3J_@2Ja@2J_<016lBK_=^lVkb0fkc00=ZlflBJ_<016[c0V[b00=ZlF[bJ_400f[a36[b0f[a
0f[b0f[B0fKB1f[B00MVdV[AI]9VdVKAI]9Vd`02I]800fKAI]9Vd@08I]44I]8<I]401VKBI[9V/VJa
I[1Vd09R/0=R[`03IZmR/6:`00AR/@=R/003HZmR/6:`00ER/0AR[`AR/003HZmR[V:^00IN[`04G[1R
[ej>GXh2GXl5GXh4GXl2GXh7GXd015Z=GXeNKUj>0ei^0Ui]0ei^00=JKeY^FVh00UY/00=JJeY]FVh0
0UY^00EJKEY/FVaJK5Y<009JC@04FVaJC5Y[FV`3FV/2FT/00eY<FT]JC002FT`2FT/3FTX02UY;FTaF
C5I<ETeF;EI<ET]BCEI>0eH^0UH]0UH/1eH[0e8/00=B:eHZERX00UHZ1e8[00AB:Th[CR]>:`9B2`03
DPYB2e8;00A>2`=>2P=>:`03BP]:2TX;00962`05BPY>2Th:CPUB2001CN/00003344<8@PQ00888@@8
@@03344<@PQ20088@P0424488@PQ224312401@@P220880PP24000`PP00T000`0;<=5b5J?FXiJKeY`
FVl00ei_0Ui`0UY`00=JKei_GY000ej@0UjA00ANT6:?HXmRS`9NT09NT@05GY1NSej?GXmNT006GY40
0ej@HY1R/002G[001EjaGY5NTF:aH[800V:B1f:a1F:b0V:a00=V/V:bH[800f:b0VKB1FKA00AV/V:a
I[9Vd@9V/@9R/008HY1NT6:@HY1R/6:aH]5Vd@EVdP04I]5VdVKBI]82J]8036KBI[9V/VJbIY1NCUi^
GY5RTV:cI[9V/@9VdP06J]9Zdf[CJ_=Zdf[c1f[b00=Zlf[bJ_8016[c0V[d00=Zlf[dJ_@00V[d00=[
56[cK_<016kc0Vkb00Y^lflCK_9^lF[AJ/mZdFlbMe5gD`9c<P04Kc=_<VlcKc<2Kc83Lc83Kc<2Kc@0
16lbKc=_<fld0g<b0fld0Vlc0g<b0Vlc0g<c00=c<W<cLc@00W<e0Vle00=_EG<dLc@00W<c00Ec<W<c
Lc=c<g<d00=cE@9g=003MeAgDgMC009gD`05MeAcE7=DLeAgE002Me<00gMBMg=gDP02Me801WMcMeAg
=GMENgAo]@9o]`07OmYofGniOkYog7olOm/00WoI00Ao^7ngOkIoUP9kM@06NgAkLg^BNg=kMG]d0g]e
00AkUWoFOkIkTP9kL@04Mg=gDgMDMe<2Ne802g/aN`mfkfk`JZiVK578CLYNSf[`Ja800V[b00=Zlf[C
J]<00V[c00]^lW<bJ_1VceXZFP]NBfl@LeAgE7<c00Ec=0=_=@04LcE_=G<dKcD3Kc@5KcD00fldKcE_
=@05KcD00fldKcE_=@03KcD2LcD00g<DKaA_=002KcD01G<eLcAc=FleKcH01Vle00=_=6leKcD01Fle
00=_=6leLa@00g<D00=c4g<cLc<00Vld1fle00=_=7<cLc<00Vle0Vlf0fle00=_=6lDKa<00VlC00A_
56lCKa=_4`=_5003Ka=_56lD00A_509_5@M_5003Ka=^lfkc009_4`04Ja=_56/DJa<4Ja@3J_@2J_<0
0flBJ_=^l`02K_8016[bK_=ZlflB0f[c0V[d3F[b0f[c16[b0f[a00=ZlVKbI_<00V[b16KB1F[B16KB
00EZdVKBJ]9VdVKC009VdP03I]5VlVKA00QVd@AVdPIVd@03I]9VdFKA00=Vd@07I]9V/VJbI[5V/6K@
H]001f:`0f:a36:`0f:_1F:`00AR[ej?HZmN/0EN[`07G[1NT5j?GXiNSej>GXl00ej>1Ej?0Uj>2Ej=
00=NSUi]GVh00Ui^0ei]00QJKUY_FVmJKUi^FVaJC5Y/15Y^00AJKEY/FVaJK09JK@9JC@03FVaJJeY/
009JK005FV]JBeY;FTaJB`03FTd2FT`015Y;FTaFBeI;0eI<00]FCEH]ETaFBe9=ERaF;EH^EReF;5H]
009F;0=F:`03ETaF:eH[00AB;09B:`9F:PIB:`I>:`03DR]B2e8;00=>30A>2`03CPY>2dh[009>:`03
BR]:2dX;009>:`05CP]>2Th;CPU>2001CN/00004340<80PQ224224422242344334800`a12448@@03
224212400`@P22088002220030Q022040000300TXTG8FZmN[eY^FW1NK`=NKP07GVmNL5Y`FW1NL5i_
GXl00Ui_15j@0Uj?00IRSUj>GXiNT5jAGY03GXl2GY05GY42HY03H[001Ej`H[1NTF:aH[800V:B1f:a
1F:b0V:a00=V/V:bH[800f:b00AR/FJbI[5R/@=V/@9R/@0>I[9VdFKAI]1V/6J_GViJCUi_FTiNKV:?
H[5Vd@EVdPAVd@04J]5ZdV[CI]82I[801V:@GVmNCei`HY5RTP9V/@04I]5VdV[AJ]83J]<016[cJ_9Z
lV[b0f[B16[b00=ZlF[bJ_800f[c00=ZlV[cJ_@00V[d00=[56[cJ_<016kc0flC00Y^lfkbK_9^lF[@
J_5_4WMAMe=c<PA_<P03Kc=_<Vlb00Ac<P05Kc9_<flcKc=_<P03Kc<3Lc82Kc@00g<cLc9c<P09Lc80
17<cLcAc=G<e0Vle00=c=G<cLc<00W<c00Ac<W<cLc=c<`9c=006LcEcEGLdMcAgE7Lc0gMC0gMD00=g
DgMDMe<01WMB0WMC0WME00IkTgoFOoUo]gnhOmX2Oo/2Oo`01gokOmYo]gnEOkEo/g^B00AkL`04Ni9k
U7]cNg@3NgD05g^DNi=o/g^@Ng1kDGMcNe=gDg]CNe9kD7/aM`mbl6k>IXeRBe78DN]R/FlAKa<00V[b
00=Zdf[cJ]<00V[c00a^lVlbJa9Zl6:?FReNJf[^Ka9c=6lcLc<2Lc@4Kc@00fleLcA_=@04KcD00fld
KcE_=@03KcD4Lc@4KcD01fldKcE_=FleLcA_=G<d009_=@04KcA_<fleKcD2LcD7KcD3Kc@9KcD026ld
KaA_56lDLa=_<g<bLc<2Kc@2Lc@4KcD2Kc@02G<cKcAc<fleKaE_56ldKcE_=008Ka<3Ka@00flCKaA_
5007Ka@00flCKaA_4`02Ka<00flDKa=_4`02Ka<016kcJ_9_4f/D0V/C00=_4flDKa@00VlD00=^m6[c
Ka<00VlC1Fkb00MZlVkbK_9ZlV[cJa=Zl`03J_800f[cJ_9ZlP03J_801f[aJ_9ZlV[bJ_=ZlV[c00AZ
lP=Zl@05J_9VlVKbJ_5ZlP04I]800f[AJ]9ZdP02J]84I]83J]8026KBI]=VdVKBI]5ZdVKAI]8@I]42
I]801FKAI[5V/6J`I]400fJa00AVdFJ`I]1Rd0AR/003HZmR/6:_00MR/003HZmR/6:`00ER/0=R[`04
G[1R/6:`HZl2HXl2GXl00ej`HZmR[`03HZh015j_GXmNSej>0f:>15j>0ej?0ej>1Ej=0Ui/0Uj=0ei]
00=NKUi]GV`00Ui]00=JKUY_FVl00Ui]0ei/0UY]0UY^00IJKEY/FVaJK5Y]FT`2FTd015Y<FV]JK5Y/
15Y;00=JC5Y;FT`00UY=00AJC5Y;FTYJC0=FB`EFC006ER]FC5H/ERaF;EH/1UH[0UI<0UH[158/2E8[
1dh[0U8;00=>2dh<CP`014h<00M>2dh:CPY>2dh[CRY>:`02CP/00dh:CP]>2P02CP/1CPX1CPP1CN/0
000334488@PQ00<8@@888@@<@@04368<@@a1244522404P@0220880PP2448@0PP200400`P788mQeI_
FXiJKUY`FVmNK`MJL0ENK`05GXmNT5i`GXmNT003GXl3GY03GXl00ej@GY5NT@05GY4016:aH[1NT6:`
0eja00AR/EjBHY9R/P=R/@UR/P03I[5R/FJb009R/P04H[=R/V:bH[82H[43I[43H[4026JbI[5V/FK@
I[1V[fJ>HXl2GVl016:@I]1VdFKA1fKB00AVdF[AJ]9VdP9Vd`05I]9VdfKBH[5NT002GY42HY401FJa
I]5VdV[AJ]800V[C0f[c00=ZlV[BJ]800f[b00EZlf[bJ_9ZlV[c009ZlP=Zl`IZm09Zl`03J_A^m6kd
009_509_4`E^lP05Ka9g<GMCMc9c<P04Kc<2Kc8017<bLc=_<flc0Vlb1Vlc0flb00=_=6lcKc<00g<b
00Ac<g<bLc9c<P9_<`04Lc=c<VlcKc@4KcD00fldLc=c<`05Lc<3Lc@02W<eLeEcEG=DMeAg<gMCMeAg
DgMD0WLc2WMC019gE7MEMeEgM7]bNiAkLg]dNgEkUW^GOkMoUWnGOiIkM7]aNg82Ng42Mg<00g]cNg9k
LP04Ng<02GMdNg=kLW]bNg5kKg]`Ne9gD`02Ne<03W]BNg5kCgL`M`i^l6[=IVaEjE6WFR]R/F/BKa82
J_8046[cJ]=Zlf[cJ_A^lflCJa=ZlV;AFTmNC6J^J_5_<fld5Vle00=g<g<dKcD026le17<d00E_=Fld
KcE_=Flf00Y_=@03KcA_=Fle009_=@03KcI_=Fle00A_=@9_509_=004Lc=_=6leLcD2Lc@2KcD2KaD0
26leKcI_=FleLaAc5GLDLa@2Kc@00flDKa=_4`06Ka<2Ka@4Ka<4Ka@01FldKaA_56lCKa@00flC00I_
56lCKaA_4flDLa@2K_<3Ja@2Ka@02FlCKaA_5FlDJ_=[4flCJ_=^l`03K_801F[bJ_=^lVkbKa<00V/D
00=[4f[cJ_<00f[b00=Zlf[bJ_<01F[b16[c0f[b00AZlF[bJ_9ZlP9Vl`03I_9VlfKB00=VdP04I]5V
dVKBJ]<2I]<00fKBI]=Vd`04I]82I]<00fKBI]5ZdP04I]83I]400fKBI]5Vd@04I]400fJ`I]5Vd@05
I]43I[42I]401FKBI[5V/FK@H]400V:a00ER/6:aH[5R/F:`00=R/@aR/004HZmR/6:_H[02G[001V:`
HY1RSej?GY1N/09N[`08HZiNSf:^GZmNT5j?GXiNS`9RSP=NSP03GXmNSUj>00=NSP04GXmNSUj>GXh3
GXd2GVd015j=GXiNKUi^0Ui]00INK5i]GVeJKUY_FVh4GVd00ei/FTeJK@02FVh01UY]FVaJK5Y/FVeJ
K09JK@=JK003FT]JC5Y<009JC09JC@9JC004FTeJC5Y<FT/8ET`00eI=ETaFC002DR`01UH/ER]F:eI<
ERaB;0MF:`EB;0=B:`03DRaB:e8[00=>:`=B:`9>:`Y>30E>2`05BP]>2dh;CP]:2`04CP/1CPT1CN`0
0005244<8@`Q244<@@02244010PP340<@0a010a100<8@@`Q22400`PQ0PPP00d<@0Q12448@@Q03408
80P0664eA59>GXeJKP02GVl02EY_FW5JLEY`FVmNT5j>GXmNT002GXl4GVl00ei`GY1NT@04GY03GXl3
GY06GY400f:@H[5R/002H[000ej@HZmN/@04H[4:H[82H[400fJ`I[5V/@03H[800f:cH[9R/P02H[44
I[400f:aI[5V/@02I[401FKAI]1VcfJ>HXl00V:@00=V/6K@I]400VKA1FKB0V[B0V[A00AZdV[CI]=V
d`=VdP06H[5RTEjAGY5RTFJa0VKA00=ZdF[BJ]<00V[c00=Zm6[cJ]8016[B1V[b0Vkb00=^lf[cJ_<0
1f[c00AZm6kdK_A^m0A_509_4`07K_5^lV[aJ_1_4G<bMc000W<a0Vlb00=_<flbKc<00W<B26lc1G<b
00A_<g<bLc9c<09c<@Ac<P9_<`03Lc=c<W<b00Ac<`03Lc9c<g<b009g<P9c<`Ec=09g=09gE09gDP04
Mc=gDgMCMe<3Me801gMCMe9gDWMBMe=g<gMD00=gD`03MeAgDgMD009gE005Lc=g<g]CMeAgD`03Mc<0
1WMCNe=kLW]CNe9kLP=gLP05Me=gDWMCMe=gE002Me<4Me804W]ANe9kDgMCNe9kDg]aOi5oS7/_M`m^
kVZ]HT]EbUG7HX]Vd09Zl@03K_9ZlV[b009ZlP08J_=Zm6[cKaA_EV/CI]9NK`9NK@03J]1cE7=F009_
=PMc=@e_=@9_=003KcEc=7<d00M_=@M_=0]_=@9_=004LcAc=FleKcD2KcH6KcD017<cKcAc<fld2Fle
0flf0VlE0W<D0Vld0VlC1FlB00A_4flBKa=_4`9_4P=_4`05KaA_4flCKa=_4P0>Ka<4Ka@2Ka<01fkc
KaA^m6kcKa=^lVkc00E^lP04K_=^lVkbKa<3Ja<3J_<4J_88J_<016[bJ_=ZlV[a1F[b00AZlfKcI_=V
l`9VlP9Vl@04J]5ZdV[bJ]<2I]<01FKBI]=VdVKBJ]<00VKB0VKC00=VdVKAI]4026KB0VKA1FK@0fKA
00=Vd6KAI]401VKA0VKB00=R/FJ_H[400V:a00=V/F;AI[4016:a00=R/6:_H[001V:`2F:_00AN/6:`
H[1RT09NT006GXmR[V:_HZiNSej>0ej?0Uj>0f:=0Uj>0Uj=00ANSUj=GXiNSPANS`9NSP07GViNKEj>
GXeNK5j=GVh00Ui]00=NK5i]GVh015i^0ei]00=NC5i/FV`00UY^0eY]0eY/00AJKEY/FVaJK09JB`03
FTaJK5Y=00=JC@IJC0eFC09F:`9FB`UF:`EB;0YB:`M>:`03CRa>34h<00=>3003CPeB34h;00]>2`5>
2P5B2@5B300000<8@@`R34400PQ100@<@@a0344<@@8<@08<@@03364<@@`Q00@88@0332488@PQ00<8
8@0=244<HPaQ344801AQ=DABCUj^GY1NSei?FW000UYa0ej@00ANSUj@GXmNT09NS`9NT004GXmNT5j@
GY44GY000f:?GY1NT002GY02GY400ejBGY5NT@02GY400f:@H[5R/004H[000ejaGY5R/@03H[400f:b
H[5R/P06H[85H[47H[800f:aI[9V/@02I[43I]84I]4016K@I[1V/FJ@0fJ`16KA0VKB00IVdfKBI]9Z
dVKBJ]82J]<3I]<02FKBI_=ZlF:`HW1NL6:bH[5V/002I]42J_<016[dJ_=Zlf[b1V[B0V[b0f[c0Vkb
00=^lf[cJ_<00V[c00=Zm6[cJ_@00V[d00AZlf[dK_A^m0A_509_4`9^lP07I]1ZlFlAKa9c<G<bLc40
1G<b0W<B00=c<fldKc<01flc00=c<W<aLc400g<b00=_<G<aLc400g<b0flc0g<c1G<b00Ac<g<bMc9g
<@9c<P9c<`09LcAg=7LcMc=gE7LeLeEg=7MB009g<`YgDP03Mc=g=7MD00=gE003Me=gE7MD009gD`Yg
E0=gD`08Me9gDgMCMeAgDg]CMe=gE0=gD`AgDP0AMe=g<g]CNe=gDW]AOi5oCW/_La5ZcfJ>FNYEbUhZ
J/i_4P02J_42J_84J_<2JaD036/dKeI[4fKbH[1NKUX/J]1cE7^GKcIc=PEc=@=c=1Y_=@=_=0e_=@04
KcAc<g<dLcD3KcD00flfKcE_=@06KcD2Kc@9KcD00flfKcE_=@06Ka@2Ka<00flBLa=_4`06Ka<00g<C
Ka9_4`04Ka@2Ka<00flBKa=_4P0<Ka<9Ka@2K_<00fkbK_=^lP02K_83K_<01FkbKa=_4flCKa801F[c
0f[b26[c00=Zdf[bJ_801V[b0V[c0VKc0VKb0fKa00=VlVKcI_<00VKC00=VdVKCI]800f[C00=VdVKC
I]<00VKB00AVdFKBI]5Vd@EVdPAVd@=Vd0=Vd@03I]1VdFKA00IVd@9VdP05H[5V/6J`I[1V/@02H]45
H[4016:`HZmR/6J_1V:`00=R[f:`H[000V:_00=R[V:`HZl00ej`0f:`00UR[f:^GZmN[ej`H[1RSej@
GZl00Uj^00=R[F:>HXd00V:=1Uj>15j?00ENT5i_GViNKUj>00=NS@06GXiNKEi]GVeNKUi]0ei^1Ei]
00=NK5Y/FVd00UY]1EY/00=JKEY/FV`00eY;0UY/00=JKEY=FTd00eY<00=JCEY<FT`00UY<0UX[1EI<
00=FCEI<ET`00UI<00AFBeH[ET]FB`=F:`03ETaF;58/009F:`=B;09F:`=B;003DR]B;58[009B:`03
DRaB:e8[00U>:`03CRa>34h<00A>30U>2`04BPa:2dgZCPT1CN`00004248<@Pa1344224401@a0220<
@0a034400`aQ00<<H0`P32002@PQ00h8@@a1344@HP`P564e958]GXeNSej>GViJL5Ya0Uj@0Uj?0ej>
00=NSej>GVh00Ui^00=NSUi_GY000ej@0ej?0ej@00=NSej@GY001EjA00=R/EjAHY000f:@00AR/5ja
GY5RT@AR/@04H[1R/F:bH[84H[42H[05H[45H[800f:aI[9Vd@02I]43I]801fKAI[5V/FJ`I/mV/6KB
00=V/@03I]1V/FJa009Vd@9VdP04I]=VdVKBJ]43I]803f[CI]9ZdfKCI]9Vl6[`I]1RT5i_HY5RT6J`
I]1Vd@02I]8016[BJ_9ZlV[b1V[B0V[b0f[c0Vkb00=^lf[cJ_800V[c00EZm6[cJ_=Zlf[d009Zl`9^
l`03K_A_56lD00=_4`04Ka9^lVkaK_82Ka42Ka800flAKc9_<P02Lc400flALa9_4P02Lc82Kc<016lb
Kc=_<Vlb0VlB00=_<W<bLc800g<b0W<a00A_<FlbKc5c<P9_<`04Lc9_<flcKc<6Lc82Lc400gL`Lc5g
<@02Mc82Lc<2Mc801GLdLcAc=GLdMc<00gLb1GMB00EgDGMBMe9gDWMC009g<`03MeAgDgMD00=gD`05
Mc=gDWMCMeEgE002Me<00gLcMe=gD`06Me<00gMDMcAgE007Me<017LcMe=gDWMB0gMC0WLc00ikD7L`
Nbe_3fk_IZmJ2U6XELYVS6l=Ka5^l6[a16[b0V[c0VlD0Vlc00Y_<V/BI]1NSUX/HXe_4WMgMeIgE@Qc
=@03LcA_=Fle00=_=@03KaE_56ld00A_=0U_=@I_=003Kc=_=6ld00]_=@=_=0=_=@03LaA_=Fle00M_
=@=_=09_=@03KcA_=Fle00A_=09_=@=_=09_50=_4`04Ka9c4flCKa@7Ka<5Ka@2Ka<7Ka88Ka<00flD
Ka=_5004Ka@2Ka<9K_83Ka<016lBJ_9ZlV[c0V[b00=Zlf[bJ_8016[b1V[c00=Zdf[bJ_800V[b0f[a
0V[b0V[c00=VdVKAI]400VKA00IVlFKbI]9VdVKCI_<:I]85I]400fKBI]5Vd@03I]42I]800fKAI]1V
d003I]0016KAI]1Vd6K@1VKA0fJa0VJ`00AV[fJ`H]5Rd@AR/@05H]5R/F:`HZmR[P09H[000f:_HZiR
[P02HZl00ej`GZmNT002GY000f:_HXmRSP02HZh00ej?GY1NS`02GXl2GZh00f:]HXeRS@02HXd3GXh0
0ej=GXiNSP02GXh2GXl00eY_GVmNSP02GXh3GXd>GVd00eY/FV]JK002FV`2FV/00ei/FVaJK004FV`4
FT/00eY<FTeJC@06FT`015Y;FTaJ:eX[1EI<00EFCEH[ER]FBeH[00AFB`=F:P03ER]FBeI<00MF:`9B
;0EB:`9B;0=B:`9>:`9B:`04CR]B:dh;CP/6CP`<CP/1CPX1CPT1CN`00003248<@Pa10088@P03244<
@@a100<<@@<<HP03364<8@`Q00@88@0322888@PQ00<88@0;344<HA1R324@HCDTDPaJC5Z>GXmNKP03
FW05GY02GXl2GVl3GVh00ei_GY1NT009GY05GY402Uj@GY5NTEjaGY5R/EjAH[5NTEja0UjA16:a00=R
/6:aH[400V:a00ARTF:aI[5R/0aR/@04I[9V/FKBI]83I]<2I]801FJbI[5Vd6JaI[800VKB00=VdFJa
I[400VJa00AVdFKBI]9Vd`9VdP05J]9VdfKCI]=VdP02J]<2I]<02V[BKa9ZlFK@GTiJ;Ui^HZmV/FKA
0VKB2V[B0V[b00=Zdf[cJ_<00V[c00=^lf[cJ_<00V[c00=Zm6[cJ_@00V[d0f[c0V[d0flD00U^lflD
K_=_4fkcJ_9^lV[bK_800VlC0Vlb00Ac<W<aLc9_<`=c<`M_<`03Ka9_<Vlc00=_<P9c<P08Lc5c<Vlb
Kc5_<VlcKcA_<`9_=004Kc=c<g<cLc<2Mc8017<bLc5c<GL`0WLa0W<b00Ac<gLbMc=g<`9g=09c=003
McAg<WMB009g<P=g<`05Mc9g<GMAMe5gDP03Mc<00gLdMeAgE002Me@01GMCMe9gDWMCMc@00gMC00Ig
DWMCMe=gDgMBMe<2Mc<01WMDLeEgE7LeMcAgD`AgE003Me=gE7MC009gDP9gD`0@MeAg<g]CNc5g47<@
J/mV[eY=DLYAYeh/I/m_46[aJa84J_<01F[bJ_=ZlflCKa@00Vlc00]c<V/BJ_1RSUX/GRYZd6mELeEc
=7Ld009c=@03KcEc=Flf009_=P9c=@A_=@9_5@03KcA_=Fle00Y_=@03KcI_=Fle00=_=@9_=0A_=@03
KcI_=Fle00I_=@03KcA_=Fld009_=003KcEc=6lD009_=0M_=@9_=003KcE_=6ld00I_=09_=@9_=0M_
4`03KaA_4fld009_5003Ka=c4flC009_4`=_50I_4`03Ka9_4flC00Y_4`I_5004Ja=_4f[cJ_83Ka87
K_82J_<00f/CJ_=Zl`03J_8:J_<2J_@2J]<3J_<3J_43J_82J_<2I]800fKAI]9Vd@02I_800fKBI]=V
d`05I]800fKbJ]9VdP08I]85I]43I]86I]43I]02I]400f;AI[5V/@02I[401VJ`I[5V/6J`IZmV/0MR
/@aR/008H[5R[f:_HZmR/6:_G[1N[`ANT007HXmRSUj>HZiNSf:_G[000Uj_0Uj^0Uj>0f:=00ANSej>
GXiNSP9NS`9NSP04GXmNKei_GVl3GXl2GXh3GVd00eY^GViNKP03GVd00eY]GVeNK@02GVd2FVd4FV`0
0ei/FV]JJ`05FV`5FT`2FTd015Y>FTeJCEY<0UY=00=FCEY<FT`00UX[0eI<0UI=00IFCUI<ERaF;5I<
ET/3DT/00eI;ERYF:P02ET/00eH/ER]F:`03ER/01UH/DRaB;58/DR]F:`9B:`AB;0=B:`I>:`=>2`=>
30M>2`04BP]>2dh;CP`2CP/1BPX1CPT1CN`00003348<@@a1008<@@8<8@@88@<8@@0334488@PQ0088
8@053448@@PR24888P0222402P@Q100880PP124@@C4SBLUNJej^0UY^00=NKUY_FW001Ej@00ANSei_
GVmNK`9NKP9NSP=NS`ENT003GXmNT5j@00ANT@ANT003GY5R/F:a009R/@03GY5N/V:b00=R/@03H[9R
/F:`00AR/09R/@03I[5V/6:a00AR/@=V/@03H[5V/FJa009V/@03I]5VdVKB009Vd`9VdP9R/P03I[9V
d6Ja00AVd@AV/@04I]5VdVKBI]<2I]801F[BI]=VdfKCI]800V[C00]Ve6KCJ_9_4flBKa1R[eY?FTeR
SV:`009Vd@04I]9ZdV[BJ]82J_86J]8016[bJ_=ZlV[C0V[c00=^lf[cJ_<02f[c0V[d0VlD0Vkd00=_
5FlDK_@00fkc00QZlVkaK_5_4FlBLc=_<VlB0VlC00=_<g<cLc<00flc0VlC0flB0flc0g<B00Ec4G<a
Lc5c<6lb009c<P04Lc=_<g<cLc<4Lc8017<aLc9g<7La0gL`0W<a17Lb0WLc0g<c00=g<gLbMc800WLa
00Ug<WLaMc5g<7LaMc1gDG]@Me800gLc00=gE7MCMe<00WMB00MgD7MBNe5gDGMBMe5kD@03Me8027MA
Mc9g<WLbMc=g=7LcMc@2Me@01g=DLeEcE7=DMeAg<gMC00=gDP0@Ng=kDgmbNeAg4FkaK]1Z/69]FRaF
35i=I/m[4VlAK_83J_82J_<016[BJ_9[4flC0Vlc00ac<W<aKa5ZkfJ_FR]J26:=Ja=cE7<cMc<2KcD0
1W<eLcA_=FleKcIc=@=_=@9_=P03KcE_=6ld00E_=@=_=0M_=@04KcAc=6leKc@<KcD2Kc@00g<cKcA_
=002KcD4Kc@5KcD01VldKcE_=FldKc=_=09_4`M_<`04KcA_<flcKc<5Ka<00flcKaA_5003Ka@3Ka<0
0flDKa=_500>Ka<016[cK_=Zlf[c0flC16lD0flC00A_4V[bJ_9ZlPU^lP=Zl`9ZlP06J_5ZlV[bJ_=[
4f[d1f[c1V[d00=Zlf[bJ_800V[a0f[A00=ZlV[BJ]800V[B00=ZdF[BJ_8016KB00=ZdV[AI]400VKa
0fKA2FKB0fKA00AVdVKCI]9Vd@9VdP=Vd@9Vd0=Vd@03H]5V/F;A009R/@06I]1VdFJ`I[1V[fJ`1f:a
00=R/6:_HZl01F:_2F:`00=R[ej`HZh00V:_00=N/6:`HXl016:>00=R[Uj^HZh00ej>00=RSV:=HXd0
0V:=0ej>0ej?0ej>00=NKUj>GXh00Uj>0ei^00=NKEY^GVh01Ei^00=NKEY^GVd00Ui]0eY]15Y/00=N
K5Y[FV/00eY/1EY]15Y=00AJCUY=FTeJC09JC@03ETeJC5Y<009JB`9JC003ETaFCEI<00AFC@03ETaF
BeI;00AFB`03ETYF:UHZ00=F:`03ERYF:eH[009F;09B;004DR]F:e8[DR/4DR`2DR/00dh[DR]>:`05
DR/ACP/00dh:CPUB2001DN/00005248<8@a1348<@@02324;22401P`P344<@@a13688@@888@0;2444
@@@P100000a1<@99b6::HZiJK`02FVh00eY_FW1NT004GY001Ej?GY1JKeY_GVh00Uj>15j?00ANT5jA
GY5RT0INT09RT004GY5NT5jAGY02HY43H[400ejAG[9R/@02H[42H[800f:aH[1R/@02H[401F:`H[5R
/FJaI[0016:a0V;A00IRdVJbI[9R/F;AH[42I[43I]85H[8016:aI[5V/FJa0fKA00=V/F:aH[400VJa
0fKB1VKC00eVdVKCI]=Ve6[cI_=ZlVlCLcAVlf:aHY1R/002H[4016JbI]5VdV[B0V[b00=Zlf[BJ]80
0V[B0V[b0V[c00=ZlV[CJ_<03V[c1F[d0Vkd00M^mFlEKaA_56lCK_=^l@02J]0016kaKa5_4VlB0flC
00=_4VlCKa800flC1FlB00A_4g<dKa=_4`9_4P05Ka=c4VlBKa5_4P02La800gLbMc=c4`03Lc<2La80
17<ALc9g<GLb0gL`00Ac<GLaLc=g<`=g<P04Mc=c<g<cLc<8Mc800gLaMc9g<@02Mc800gLcMe=g=002
Mc@01gMDMe=gDgMCMc9gDg]B009g<`07Ne9kDg]CNe=gDgMBMe<00WLc00=gDgMDMc@00W=E00]gEG=E
KeIcEGMdMeAg=7<dMcAg<gLd00=g<`0;LcAc4VZ_IXiNC5XZER]RSfKAJa9_=002Ka<00flDKa=_4`04
Ka<046lDKcA_=6ldLc9g<G<bKa1Vcei;FPURSVlCLeAc<gLc1W<e0flf0Vle0flf1fle1Fld00=_=Fld
KcD04Vle0W<d0W<c00E_=6leKcE_=Fld00E_=@04KcA_=FleKcD2Kc@016lcKcA_4flC1flc00=c<flc
Kc<01flC1FlD00=_=6lDKa<01FlD00=_4flDKa@00flD1FlC0VlD16lC00I_56lCKaA_4flDK_@2K_<3
Ka<016[bKa=_4flC0V[c00I_4VkbKa9_4f[cJ_@2J_<00f[bJ_=Zl@02J_800f[cJ_AZm002J_@00f[c
J_AZm002J_<5J_@2J_<3J_83J_400f[AJ]9ZdP03J]8016[AJ]9ZlV[b0f[B0V[A0fKa1FKA2fKB00AV
dfKBI]9VdPAVd@06I]1VdFKAI]5V/F:a16;A00ERd6;AH[5R/6J`00MR/@AR/0=R[`IR/005H[5R/6:`
H[1N/@02G[001V:^HZmR[ej`H[1NS`ARSP03HZiN[V:^00ERSP03HXeNSEj>009NSP04GXmNSUj?GXl2
GXh01Ui^GXiNSUj>GXmNSP9NKP03GVmNKEY^00ENKP07FViNKUY^GVeNCEY]FTd00UY]15Y/00ANK5Y[
FV]JK@=JK0EJK@=JC@04FTiJCEY=FTd3ETh2FT`02EY;FTaJC5Y<ETaFCEI<ETiFC@02DTd00eI<ET]F
B`05ET/00eH[ERYF:`03ER/00e8[ER]F:`02DR`7DR/00e8/DR]B:`04CR/00dh;DR]B:`03DR/7CP/0
1dX<CP]>2dh;BP]>2dX<009>2`03CPYB2EH8005Aj`000PPQ00@880PQ324<8@8<@@06320480@01244
80@Q0`PQ00<880`P32000Pa100<<8@PQ224010Q100d8@P00340]0TW7HVUN[5Y=FViNKEY^FVmJL004
GY0015j>GVmNKej@1ej?00ANT5jAGY5RT0=NT0ANS`=RS`9NT0=RT005H[5RT6:@H[5R/002H[42HY80
1F:aH[1R/F:bH[400V:`0fJ`00AR/FJ`I[1R/@9Rd@ER/@=V/@03I[9R/F:b00ER/P04H[5V/FJaI[43
I]001VJ_HXmRT6:`I[5V/P9VdP9Vd`EVdP0?I]=Zdf[CJ]9Zlf[bI]9VlVKBI]5RSf:`HY1RTF:a009V
d@03J_5ZlV[b00=ZdP03J_5ZlV[b009ZlP03J]9ZlV[B009ZlPAZl`03K_=Zlf[c00QZl`9Zm005J_E^
m6kdK_E^m002Ka@02W<CKa=^lF[@I[1V[fK?J_1Zcf[@0V[a0Vka00AZlF[AJ]1Zl@E^l@03Ka9^lF[b
00A^lP03Ka9_4FlA00A_4@A_4P03Ka=_4VlB00A_4P=_4@9_4P9_4`9_4P9c4P=_4`M_4P07Ka=_<W<b
Lc5c<W<aLc800Vlc00=_=6lcLc<00W<b00A_<g<bMc9g<P=c<`=g<P9c<P=g<@04Lc9c<g<cKc@3Lc<3
Kc<7Lc<03FlCJ_9Vd6J_IXeRK5i=FTeR/6[bKcAcE6ld00=_5007KcE_=6ldKcA_4flBKa<00fld00Yc
<WL`Le9c<F[_HXeJ:F9]J_9cD`9c=0Ic=@03LcI_=Vlf00=_=@A_=PE_=@9_=005Lc=_<g<bKa=_=00@
KcD2KaD016leLc=c<g<b0W<c00=_=6leKcD00fle00A_=VleKcEc<`A_=0=_509_4`I_<`03Lc=c4W<B
009c4PM_4`A_509_=004Ka=_56lDKa@5Ka<2Ka@00flCKa9_4`0<Ka<01FlBK_=^lfkcJ_800f[c00E_
4VlCKa9_4f[c009[4`05Ka9_4flCJ_=Zm002J_<2J_800f[aJ_9ZlP05J_<01F[bJ_=Zlf[cJ_801F[c
00AZlV[BJ_9ZlP9Zl@04J]5Zd6[AJ_82J]42J]8016[AJ]9ZdF[A0f[B0V[A2VKA2FKB00AVdfKBI]9V
dPAVd@03I]1VdFJ`00AV/@08H]5R/F:aH[1Rd6:`H[5R/0IR/@ER/0=R[`9R/003H[5R/6:`00ER/003
G[1N[ej_00=R[P03G[1R[ej?00ARSP03HZiN[V:^00IRSPENSP03HXeNKEj>009NSP05GViNSEj=GXeN
SP02GVh2GXh00ej=GXiNK@04GVh01UY^GViNKUi]GTeJK@9JC@EJK004GVaJJeY[FVd2FV`00eY<FVeJ
K@03FVd00eY<FTeJC@02FTd2FT`00eI>ETmFCP02FT`025XZFR]JC5Y<ETaFCEI<ETd2ETh00eI=ET]F
B`04ET/00e9;ET]FB`05ERX015H[ERYF:eH[2e8[0Th[0e8[00A>2e8[DR]B:`a>2`04BPa>2dh;CP/2
CPX1CPT1DPP1CN/00003344<8@a2008<@P8<8@03248<@@PP008880848@<88@03220<80`P00<<@@8<
8@8<@@0:3688HPQR120802cR@HENBEj[FVh2GVh2FVl3FW001UY_GY1NSei_GXmNT0MNS`9NT003GY5N
T5j@00INT0=RS`03GXmNT5j@00ERT004GY5R/5jaH[42HY83H[42H[801V:`I[1V/6J`H[1R/P9R/@AR
/PAR/@=V/@03I[9R/F:b00ER/P0<H[5V/FJaI[5VdF[AI[5V/69^GVmRT6J`0fKB1VKC00MVdVKCI]9Z
df[BJ_=ZlP02I_<2I]802FJaHY1NT6:@H[5R/6KAJ_5Zl`02J]<3J_83J_<00f[bJ]9ZdP02J_84J_<0
0f[dK_=ZlP07J_<5J_@4K_@4Ka@01flCK_=^lVkbK_5ZdFK@00=V/007I]1VdFK@I]5Vd6:_IZl00V[@
00AVd6J`I]1Zd@9R[`0:I]5ZdFKAI]5Vd6K?I]5Vd6J`I/l2J]42J_401FKAI/mV[fJ_I]000V[a00=Z
d6J_IZh00V[@00=ZlV[aI]000VK@0V[`0V[@0V[a00AZd6[AJ]5ZdP9Zd@08J_5ZlV[aJa5ZlF[`I]1Z
l@9_4`04Ja9ZlF[aJ_82J_401V[bJ_5ZlVlCKa9Zl@=Zd0=Zl@0<J]1ZdF[AJ]5ZlFk@K_5c4V[aI]1Z
lV/C1V[b00]Vd6J_HXiVSV[@J_=[56leKeI_=Fld00Q_=@E_=00<Kc=c<WL`Me9c<V[`IZmJ2UX/I_5_
<fmE0Vlf00=_=G<eLcD00W<e0flf3Vle00E_=7<cMc5_4Vld00i_=@9_=P08KaEc5FleKaA_=7<CLa9c
<`I_=@07KcI_=G<eMcAc=7<cKc@01VlD0Vld0Vlc0Vld00Ac4g<BMa9c4`=_4`=_5003Kc=_=6lD00=_
509_=005La=_56lDKaEc5006Ka@:Ka<01VlcKa=_4flCKa9_4`9^l`9Zl`=Zm09Zl`03Ka9[4f/C00E[
4`IZl`=ZlP03J_=Zm6[d009Zl`EZlP05J_=ZlV[cKa=^l`03J_<03VKcJ_9ZlV[bJ]5ZdVKcJ]5ZdV[A
J]9ZlVKbJ]82J]42J]800f[AI]5Vd@07I]47I]82I_<4I]800fKAI]9Rd@02H]400fKBI]5Vd@05I[42
I]42H[42H]400f;BH]5R/P06H[400f:`H[5R/003H[000f:_H[1R/@03H[401F:`H[5NTEj@GY401Ej`
00IN[ej`HZmNSf:^GXh3HZh00ej_GXmNS`03HXh00ej?GXiNSP03GXh00ej=HXeRS@02GXh00ej?GXiN
SP03GXh01Ui^GXiNSUj>GXeNSP=JKPAJK`08GVmNKUi^GViJCUY=FVeJK0=JK@06FVaJKEY]FViJKEI=
15Y]00AJK5Y^FVeFC@EJC@=FC`9FC@03FTaJ;5Y<009FC09FC@=FCP03ETeFC5I;00=FB`04ER]BBe9;
DT/2ER/2ERX3DR/2ER/7DR/0158ZDR]B:e8[0Th[00AB:dh[CR]>:`9B:`]>2`=:30=>2`04DPY>2Th:
CPT1CN/0008<@@8<@P03344<8@PQ00888@88800412088@PQ220222433202344010`P340<@0`Q0Pa1
00h<H@aR340802BQ@H=JBF:ZGZmNKUj?FVmNT5Y_15i_00=NSei^GXh02Uj?2Ej@0f:?0f:`0f:@00AR
/F:`H[1R/0MR/@9R/P9R/0=V/003H[5R/V:b00AR/P9R/@03I[9R/VJb00=V/P03I[5V/VKB009VdP9R
/P0<H[5V/FJaI]9V/VJaI[1VSei=GTiRSfJ`0VKA0fKB16KC0VKB16[B00MZlVKcI]9VdVKAI[5R/@03
HY000f:AI[1Zd002J]801F[CJ_9ZlV[bJ_<01f[b1F[c0Vkc2F[c00=Zm6kcK_<01Fkc0VlC0Vkd00A^
lflCKa=^lPEZlP03J_=ZlV[b009ZlP0@J_5ZdF[@J]1VdFJ`I]1Zd6[AI]1V/6:`I[1ZdF[bJ_43I]47
I]002FKAJ_5ZlVKAI[5V/6KAI]1Vd@02I[003FK@J_9VdFJ`J]1ZlV[@IZmZd6[bJ_5ZdFKA00AV/@03
I]9ZdFKA009Zl@04J]5VlF[bI_82I]801f:aI[1VdF[bJ_5VdFKb009ZlP03I]9ZlF[a00EVd@AZlP04
Ja=_4f/CJ_82I]85I_8016[cJa=Zlf[c0Vkc00=_4f/EKc@01fle00Ec=6leKcE_=Fld00A_=@9_=00;
Kc9g<G=BLe9[4FK?FPUF36K@Kc9cEP02KcH5LcD3KcD01G<eLcAc=6leLc@00Vld1Fle0Vld00Uc<flc
Lc5_4FlDKcAc=6leLcD00flf16le0fld0Vlf00E_5G<EKcI_5FlD00=c4`9_=0E_=@04LcE_=FlDKa@9
Kc@5Ka@4Ka<00g<CKcA_=004Ka@00fldKaA_5005Ka<2Ka@00flEKaA_5005Ka@01FlCKa9_4flCKa@0
16lC0flB0VlC16lB0VlC00=_56[dJ_<00V[c0f/C00=[56lDJa<00V/C00M_4f[cJ_=ZlfkcJ_=ZlP02
J_<4J_@00f[cJ_9ZlP04J_800fkaJ_9Zl@03J_8026[cI_=VlfKcJ_=ZdV[bI_<2J]8026[aJ_9ZlFKb
J_9ZdV[aJ]83J]400fKAJ]5Vd@03I]45I]85I]400fKBI]5Vd@05I]42I]85I]400fJ`I[5V/@04I[42
H]42H]83H[43H[800f:aH[1V/003I[000f:`HZmR/006H[43HY001F:aH[1N/F:aH[000V:_1f:^00MN
/6:_H[1RT5j@HXmNS`02GXh01F:>HXeNSUj>HXd00Uj=00ENSUj?GXiNSUj?009NSP06GViNSUj=GXeN
S5i]0Ui_00=JKUY_FVl00eY_0Ui_00=NKUY_GVh015Y^00AJKEY/FVeJK@9JKP=JK@05FVaJKEY/FVeJ
K002FVd3FTd015Y>ETmFCeI?0UI>00=FC5X/ET`015I<15I=00=FC5I;ET/00eI<0e9<0U8[15H[0eHZ
1e8[0e8Z158[00Q>2e8[DP]B2Th;DR]>:e8[1Dh;00=>2Th;CP/01dh;0Th:0E890E8<000336823480
0``Q22488@0222400`Q022488@0322401``Q320<80`P340<@@`Q00<88@0<324<@@a1368<@A0P9:4m
HeY9H/aR[ei^0UY`0UY_0Ui_00=NSejAGW001Ej?0Uj@1Ej?2Uj@0V:@00QNT6:`G[1R/5j@GY5R/F:`
1V:a00=R/V:aH[800V:b0V:a0V:`00=R/F:bH[801F:b0f:a16:b00AV/VJaI]9VdP9Vd`04I]9R/VJb
I[43I]801fJbI[5V/F:?GTiVSVJ_009Vd@9VdPEVd`9VdP9ZdP03J_9ZdVKB00=VdP04I]5V/F:`HXl2
HY001F:AI[5VdFKBJ]<00f[c00AZdf[cJ_9ZlP9Zl`AZlP9Zl`=ZlPAZl`03J_AZlfkc009^l`04J_=Z
m6kcKa@9K_<00fkdKaA_5003Ka<5Ka@01FlCKaA_56lDKa<00Vkb00=^lflDKa@00Vkc2VlC00=_4Vkb
K_800VlC00A^lV[bJa=_4`E_5004LaA_56lDKa@3Ka<00flDKa=_4`03Ka<4Ka@3KaD2Ka@00flCKaA_
=004KcD00fldKcE_=@05Ka@2Kc@5KcD016ldLcA_=6ld0Vle00=c=FleKcD00flf0fle00=_=W<eKcD0
0Vle00=c=FleKcD00Vle00E_=WMFMeMcEVlf00A_=@=c=@04KcEc=6ldKc@3KcD03g<eKcE_=6ldLc=_
<g=CKcAVd5X[ENaRSV/ALeI_=P04KcD2LcD016lfKcE_=G<e17<d0Vld0Vle0flD16ld00=c<fldKa@0
0Vld0Vle1Flf00E_=FlEKaE_5Fld009_=@9c5@04KcEc57<DLa82La<2Kc@7KcD4Ka@01FldKcE_=Fle
Kc@02VlD16ld00E_56ldKcA_56ld009_50E_4`9_5003KaE_56lD00=_5003KaE_56lC00E_4`=_5003
Ka=_4VlB00Q_4`9Zm09Zl`9[4`03JaA[4f/D00A[4`]Zl`06J_AZlf[cJ_9Zlf[b0fkb00=^lF[bJ_80
16[b1fKc00AVlV[bJ_9ZlP9VlP04J_9ZdV[aJ]83J]400f[BJ]5ZlP03I]45I]801VKAI]9VdFKAI]9V
d@9VdPEVd@03H]9VdVKB009VdP9Vd@03I]1V/FJa00AV/@9Rd@03H]9R/VJb009R/@AR/P9R/@=V/004
H[1R[f:`H[03H[400f:`GY5RT002HY000f:aH[1R/@02G[42G[0015j_HZmR[f:`0ej`00ER/6:_H[1N
T5jA00ANS`9RSP03GXiNSej=009NS@ANSP9NS`=NSP=NS@9NSP03FXmJKUY_00QJK`EJKP03FVeJK5Y]
009JKPAJK@0=FVaJKEY/FVeJK5Y]FVaJKEY=FTiJCEI>ETl00eI>00=FCEI<ET`015I<0UI=0UI>00=F
CEI;ET/015I<0U9<0U8/0U8[00=F:e8[ERX00UHZ158[00=B;58[DR/01U8[0Th[0e8;00=>2e8[CR/0
0U8[2Dh;00=>:dh;CP/00dh;0Th:0Dh<0002368010aQ344<8@`Q0`PQ0PPP0`PQ0P`Q00X<80PP320<
@0`P324<@@PQ22088@8<@@0?340<H@`P300PXCU2ETYRZej=GViNL5Y`GY1JKei^009NK`=NL006GY1N
Sej>GXiNSej@1Ej?0ej@00=NTEj@GY401Uj@00=NTF:`G[001F:`0f:a00=R/6:aH[400f:b0V:a00ER
T6:aH[1R/6:a00=R/P04H[5R/V:bH[84H[400fJbH[9V/P02I[4016;AI]5VdVKB0V:b0f:a00YR/V:c
I[=V/VJaI[1VSf9/IZeV/0=Vd@EVd`9VdPMZdP9Vd@06I[5V/6:?HXiNSV:@0VJa00AVdV[CJ_=Zl`9Z
d`05J_=ZlV[bJ_9Zl`04J_82J_<00fkaK]5^lP02K_<5J_<00fkbK_=^l`02K_<00fkdK_=^l`02K_<2
Ka<3K_<00fkdKaA_4`04Ka<8Ka@016lCKa9_4Vkc0VlE00A_=FlELcEc=@9_5004Ka=_56lDKa<2Ka@4
Ka<2La<3Lc@026ldLcAc=7<dKaAc57<dMc@3Lc@2Kc@4La<00g<cLaAc5002LaD01fleLcE_=VleLcEc
=6le00=c=003KcEc=G<e00I_=@9c=@05LcAg=G<dLcEc=006Mc@4LcD3KcH5LcD00g=FLeEc=@07LcD0
0flfKcE_=P02KcD00g<eKcE_=@04KcD3Kc@00g<dKcE_=@04Kc@02G<cMg=cMV[aGVeAjeY;J^m_=002
KeH2KcD2LcD01FleKcI_=FleLcD00g<d00Ac<fldKcA_=@=_=09_50I_=003KaA_=6le00E_=@03KcI_
=Fle009_=@03KcA_=Fld00=_=@9_=008Lc=c4g<CKc=c<fldLcA_=09_=@=_=0=_5003Lc=_=6ld009_
=003LaA_56lD00A_50Q_=0=_4`03KcA_56lC00M_4`=_5004Ka=_56lDKaD3Ka@4Ka<3Ja<2Ka<00flB
Ka=_4P05Ka<026kcJ_=Zlf[cJa=[56/CJ_<2Ja<01F[cJ_9ZlflBK_8016kc1f[b0V[c0f[b16[a00AZ
lV[aJ_9Zl@9ZlPMVl`03I_9ZlV[a00=ZlP03J_5ZdF[A009Vd@03I]9ZdFKB009Zd@03J]1Vd6KA009V
d@=VdP9Vd@03I]1VdFKA00=Vd@=Vd09Vd@03H]5VdVKA009VdP03I]5Vd6J`009V/004I[5VdFKAI]02
H[42H[8016JbH[5R/F:a0f:b0V:a00ER/6JaH[1R[fJ^009R[`=R/@9R/003HXmR/6:`00AR/003G[5R
/6:`00=R[`04H[1N/5j`G[03H[001Ej@GY5NT5j@GXl00f:>00=NSUj?GXh00Uj=15j>0Ui_00=NSUj=
GXd01Ej=00ANKEY]FViJKPAJK`QJKP03FVeJK5Y/00=JKP=JK@EJK003FVeJK5Y/00AJC@9FCP9FC@9F
B`03FTaFC5I<009FC003ETeFC5I=009FC@9FB`08ER]FC5I<DTaF;58/DR]B;09B:`03ER]F:UHZ009F
:PAB:`=B;003DR]B;58/009B:`09CR]>2dh[DPaB2e8:DP]>2dh[00a>2`04CPY>2dh;CP/3CPX1CNd0
008<H`03348<@@a200<<@P03344<80PQ00D88@L<@@<8@@<<@@09224400P0688iA58[GXaNSEi^009J
L09JK`04GViNKei_GW04GY0015j>GXmNT5j@1Ej?1ej@0UjA00=NT5jAGY400UjA00EN/F:`H[1R/5ja
00AR/@03H[1R/F:a009R/P03G[9R/V:a009RT09R/005H[5R/V:bH[9R/@02H[84H[43H[800fJbI[5V
d@02H]84H[83H[42H[8036JbI]9V/VJaIZmRK6J^I]1VdFKBI]5VdP9V/`AVd`9VdP0AJ]9VdV[BJ]=Z
lf[BI]9VdFK@HZmRSUi^HY1R/FJaI]9Zd`05J_<3J_83J_<2J_82J_<026kcK]5^dV[BJ_9ZlfkcJ_<5
K_<00f[cK_=^l`03K_<00fkdKa=^m003K_<3K_@3Ka<7Ka@00flCKaA_5002Ka@2KaD016lFKaE_5FlE
0Vle0Vld16lD00=_5FlDKa@01FlD0Vle00Ac=GLdLcAc=0=c5004KcAc=7LdLcD7Kc@4KcD4KcH017<f
KcI_=Vlf0Vle0W<e1flf00=_=G<eLcD00g<f17<e00=c=7<eLc@00W<e00=c=VlfKeL00Vlf00M_=G<e
KcEc=FleKcI_=@02LcD00g<dLcEc=@03KcD016lfKcE_=Vle0g<e00=_=FlfKcD00fle00=c=FleKc@0
0fle00i_=6leKcEc<gMcMiI[4V:>EP]J:FK>Ja=_EFmF26lf00Ec=FleKcE_=Fld00=_=@E_=0=_5003
LcE_=Fle009_5003KaE_=Flf00=_=@03KcI_=Fle00=_=@03KcI_=Fle009_=@07KcA_=FldKcA_<fld
Lc<00fld16le00=_=6leKa@00VlD00=_=FldKaD01flD26ld00=c=G<cLc<016lD00=_4flDKa@00flD
00=_4flDKa@01flD00E_4flDKaA_56lC00=_50M_4`05Ja=_4f[cJ_9^l`02Ka@2Ja@7J_<2J_801F[c
K_=^lfkcJ_<00f[b1f[c1V[b00=ZlF[bJ_800V[c2FKc0V[b0V[B0f[a0V[B00EVdV[BJ]9ZdV[A00=V
d@03I]9VdFKA009VdPIVd@03I]9VdFKA00AVd@=Rd@04I]5VdVKBI]83I]46I[42H[87H[401fJaH[5R
/FJaH[1R[fJ_009R[`9R/003G[5R/F:`00AR/004HY1NT6:`G[42H[0:G[02GY42GY001Ej?HXiRSV:>
GXh00ej?00ANSUj?GXmNS`ANK`INSP=NK@9JKP=JK`03FViJKeY^00AJK`03ETmJKUY^00AJKP04FVeF
CEY]EVh5FVd00eY/FT]JC004FTd00eI=ETaFC@02ETd2ET`4ETd01EI?ETiFCUI>ET`00eI;00EFC59<
DTaF;5H[00AB;003DR]F:eHZ009F:PAB:`=B;003DR]B;58/009B:`04CRa>:dh[DP`2DP/2CP/014h[
CP]>:dh[44h;0Dh=000236<4348010`Q244<@0`P1`PQ00<8@@a134401`a100<8@@PQ12400P@000P@
@CDUCP]NS5j>GViNKeY_0Ui_00=NSUi^GY0015j@00=JKej>GXl03Ej?00ANT5jAGY5NT0ANT@04GY1R
T6:@H[05H[4016:`H[5R/F:a0f:b00=R/F:@H[400f:`00ER/F:bH[9R/F:b00AR/@03I[9R/VJb009V
/P03I[5VdF;B00=VdP9R/P0=H[5V/F:aI[5VdVKAI]9V/VJaIZmVSVJ^I]000fKA0VKB0V[C00MVdVKC
I]=ZdfKBJ]9VdP03J]<03FKCI]9VdFK?IZmRSUi]HXmR/FJaI]9ZdV[C009Zl`03J_9ZdV[b00MZlP9Z
l`07J_9Zdf[BJ]9^lV[bK_<00V[c16kc00EZlfkcK_=^lfkd00E^l`9^lP03Ka=_56lD00=_4`E_50=_
4`9_50Q_5@04KcE_=6ldKc@4Ka@00flEKaA_5@02KaD8KcD00g<dKcAc<`02Kc@3KcD00g<dKcE_=003
Kc@9KcD016lfLcE_=Vlf0W<e00=_=VleKcH00Vlf00A_=FlfKcI_=P=c=@9c=P03KcIc=W<f009c=@9c
=0Ac=@03LcI_=Vlf009_=PAc=@03KcIc=G<e00Ec=@03KcI_=Flf009_=P03KcEc=G<d009c=@05LcIc
=FlfLcE_=P02KcD00g<cKcE_=@03KcD036ldLc9gDW=dKa5VceX/FRUV[F[aKeA_EPI_=P03KcEc=G<d
009c=003KcEc<fld00M_=09_509_5@]_=@03KcA_=Fle00A_=P9_=@03KcA_<fld009_=0=c<`=_=0A_
=@07KcA_=FleKcE_56leKc@00flD00Ac56lDKa=_50U_=0U_50=_5@E_5003Ka=_56lD00=_5004Ka=_
56lDKa@3Ka<00flDKa=_4`0;Ka<00f/CJ_AZm002J_<4J_800flBK_9^lP03K_<01VkbJ_=ZlV[bK_9Z
lPAZl`EZlP9Zl`AZlP9Zl`EVl`AZl`9ZlP9ZdP06J_5VlFKaI_5ZdFKA0f[B00AZdFKBI]9VdQaVd@03
I[5V/6J`00=V/@UR/@=V/0=R/0ER[`YR/004G[1N[ej`H[06G[000ej@G[1N/002G[400ej`GY1NS`04
HXhBGXl00ej>GXeNK@03GVh4FVh2FVl00eY@FW1JL002FVl2FTh2FVd015Y<FVeJKEY]0eY^0UY/0UY;
00=JC5Y=FTd00UY=00=FBeI<FV`00UI=0UI<0UI=0UI>0UI?00=F;UH]ET`00eI;0UI<00aF;5H[ER]F
:e9<ET]BBe8[ER]F:UH[ERX8DR/2DR`2DR/014h/DR]>;4h[0U8;00=>2dh[CR/00dh[2Dh;00=>2Th;
CP/00dh;0Dh:0Dh=00000`Q2348<@P0534800`a1348<@P0336<3348234400`Q122488@0334423480
2`QR2488@PP1200<@C45BN]JKF:_FVh015Y_0Uj?0Uj@0eY`00=NT5j?GXl01ej?00=NT6:?HXl00f:?
0Uj@00ANTEj@H[5Rd`9N/P04GY5RT6:aH[05H[401F:`H[5R/F:bH[400f:b0V:a00=R/6:aI[400f:b
1f:a00IR/VJbI[9V/V:bI[85I]801V:bI[9V/6:aI[5V/P9VdP03I]=VdVJ`009V/@AVd@=VdPEVd`03
I]9ZdV[C009ZdP0>J]=Ve6KCI]9Vd6J_HZiRSV:?H[5V/FKBJ]5ZdP9ZlP03J]9ZlV[b00IZlP04J_=Z
lV[cJ_<2J_@00fkcJ_=Zl`03J_<6K_<00f[dKaA_5002K_@5K_<3Ka@3Ka<4Ka@4Ka<2Ka@00flEKaA_
5@06KaD00fldKaE_5006Ka@016lEKcE_=Vlf3Vle00=_5G<eLcD02Fle0flf00E_=FlfKcEc=Flf009c
=@03LcI_=Flf009_=P04KcE_=VlfKcH5LcH3KcH7LcD2LcH4KcH4LcD00flfLcEc=@05LcD5KcH00g<e
LcAc=002LcD00g<fLcA_=@02LcD01G<dLcEc<flDLc@00fle00a_=7<cMe5cDflbJ_5NKEXXHXaVlF/C
KeD2KcD4KcH2KcD4Lc@00g<cKcA_=002Kc@2KcD016ldKaA_56lD0flE1Fle00=c=FleKcD00Vle00A_
=6leKcE_=@9_=PA_=@U_=0]_=@07KcA_56lDKaAc56lDKa<01Fld00=_56ldKc@00Vld2FlD0flE00=_
56lCKa@00flD0VlE0flD00A_4flDKaA_50=_4`03KaA_4flC00Q_4`=_4P03Ka=Zm6[c009Zl`=^lP04
Ka9^lV[bK_83K_<01f[cJ_9ZlV[bK_9ZlVkc00=Zl`04J_9Zlf[bJ_84J_<3J_82J_<5I_<2J_<6J_80
0fKaI_9VlP03I]82J]800f[AJ]9Vd@02I]8LI]44I[4016KAH[5R/F:a0fJa1V:a0V:`0V:a0V:`0f:_
2V:`00=N/5j_G[001Uj`0ej@0ej`0Uj@00=NSf:>HXh00V:>00=NSUj?GXl03Uj?0Ui_0Ui]0Ui^00EN
KEY^FViJKUi]009JKPAJK`03FViJCUY>009JK@03FVaJKEY]00EJKP9JK003FT]JC5Y=00=JC@03ETaF
KEI<00IFC@9FCP08DTmF;eH]EReFC5I;ETaFB`9FC004ERaF:eH[ER/3DT`00eH[DR]F:`02DR/2DR`6
DR/2DR`2DR/4CR`2CP`3CR`4CR/2BP/00dh;BPa>2`03CP/00dh:CP]>2`02CP/1BP/1CP/1BPd00088
@@032248@@`Q008<@@07248<@Pa2368<H`aR34400`a20`a10`PQ0Pa10PQ100`8@PQ1248<@PPP448]
1D7:FViRSV:?GVl3FVl3GVh01EY_FW1JKeY`GY0035j?1F:?00=NT5jAGY400UjA00EN/EjAHY1R/F:`
00ER/@03H[1R/F:a009R/@9R/P04H[5R/6:`H[02H[400f:bH[5R/@08H[43I[801V:bH[5R/VJbI[5V
d@9VdP03I[5V[ej?009R/@=VdP03I[5VcfJa009VdP9Vd@=V/@9VdPAVd`IZdP0<I]=ZdfKBI]1V[fJ^
HXiRSf:@H[5VdF[A0V[a00=ZdF[BJ_800f[b0f[B16[b2F[c1Vkc00EZm6lDKaA_4fkd00E^l`04K_A_
4flCKa<2Ka801FlCKaA_57<CK_801flC00=_56lEKaD016lE00=_=FlEKa@01FlD00I_4flDKaE_5Fle
KaD4Kc@6KcD016ldKcE_=FlE16le00=_=6leKcD016le0flf16le00=_=W<eLcD00Vle00I_=VleKcE_
=FlfLcH5KcH01G<eLcIc=VlfKcD027<e00Ac=VlfKcI_=PAc=@03KcIc=G<e00=c=@03KcEc=Flf00A_
=PIc=@05Lc=_=G<eLcAg<`02Lc<2Kc@2KcD016ldLc=_<g<b0W=C00I[4FJ^GRMNBfJ^J_43Kc@01Fle
KcI_=VlfLcD00fle00=c=6leLc<026ld0VlD0flE0Vle00=_=6leKa@016lE00E_=FldKcA_=6le009_
=PA_=@I_=003Kc=_=6ld00U_=@=_=0=_5004LaA_4g<CKa@3Kc@3Ka@2Kc@01G<CKa=_4flDKc<01VlD
00=_5FlDKa@00VlC00=_56lEKaD00flD0flC0flD2flC00=[4flCKa800VlB00=_4FlCJ_800f[c00=^
lFkbK_800Vkb00=^lfkbK_<00fkc00AZlVkbJ_9^lP=ZlP9Zl`AZlPAZl`9ZlP03J_5ZlV[c00EVl`03
J_=ZlV[b00=ZlP04J_5ZdF[aJ_82J]800fKAI]9ZdP03J]43I]800fKAI]1Vd@07I]44I]03I]43I]08
I]45I[400fJ`H[5R/@05H[45H[03H[42H[03HZl00f:`HZmR[`02HZl5H[02GZl00f:_GZmN[`02GY00
0ej`GZmNS`06GY000ej?GXiNSP02HXh00f:=GXiNSP02GXl2GXh00ej?GXiNS`05GXl2GXh2GXl02Ei_
GVeNKEY]GVeNSEY]FViNK@04FVd3FVh02eY=FVeJKEY^FVeJK5Y]FVaJKEY^FVl00UY^00AJK5Y;FT]J
C0=JC@05FTaJJeI/EVaFK@02ETd2ET`2ET/01EI<ETiFCUH]ET`00eI;00=F:eI<ET`00UI<0UH[0U9<
00AB;58[DR]F:`9B:`9B;003DR]>:e8[00MB:`9>;005CRe>;4h=CPa>;@02CR`5CR/7CP/00dh:CP]>
2`02CP/1BP/1CPX1CP`0000524488@PQ224<@@04348236800`a12248@@02344334800`a122488@02
32401@a1248<@@Q224400PPR00L40111:>E1ZeI_G[1NT002FW02GY0015i^GVmNSej@15jA3Ej@0f:@
00=NT5jAGY4015jA00AN/EjAGY5R/0ER/@03H[1R/F:a009R/@9R/P03H[5R/6:a00=R/@03H[9R/F:a
00eR/@08H[9V/VJaI]5VdVKAI[1Vd09R/@07H[9VdfKCI[9V/FK@I]400VKB00=VdFKBI[400fJb00EV
dVKCI]=Vdf[C009ZdP9VdP03J]=ZdV[C009Zl`0;J_5Vd6J_HXiRSej?HY1V/FKAJa=ZlP02J]83J_<2
J]<3J]82J_8<J_<01FkcJ_=Zlf[cJ_@00VlD0Vkd1Fkc00=^m6lCKa<01flC00A^lVlCKa9_4`=^l`03
Ka=_56lE00=_5@A_=@E_5003KcA_56lD00A_5@Y_=@03KcA_=Fle00I_=@=_=006KcE_=VlfKcI_=flf
16le00A_=W<eLcEc=@Ac=PQ_=P03KcE_=Vlf00I_=P05LcIc=G<fKcI_=`02KcH016leKcIc=G<e1Flf
0W<f26lf00=_=G<eLcD00W<e00Ag=7<fLcEc=@9c<`03LcA_=Fld009_=@0BLcAc<fldLc=gE7MCKc9Z
kUhWFRYNJfK`KcAcE6ldLcA_=W<f1Flf1Fle00A_=6lDKaA_509_=0M_=@9_=003Ka=_56lE00Q_=@03
KcI_=Fle00A_=@M_=0]_=@03KcA_5FlD00=_5004La=_=6ldKc@6Ka@2Ka<00flDKcA_4`02Ka@00fld
KaA_5004Ka@2Ka<3Ka@6Ka<00flDKa=_5005Ka<3Ka@2Ka<00flBJa=[4`03Ka<2K_801fkcJ_=Zlf[c
J_9Zlf[b009_4P03J_=^lf[b00A^l`04J_9Zlf[cJ_<2J_84J_<8J_800f[aJ_9ZlP05I_<2J_<8J_83
J]89I]8<I]400fK@I]5Vd@03I]400fK@I]5Vd@03I]800fKAI]9V/@05I[48H[43H[07H[46H[0026:_
H[1R/6:`HY1NT6:`G[03GZl015j`GZmNT5j_25j@00=NSej>GXl01ej?0Uj>25j?15j>00=NKEY]FVd0
0Ui]00ENK5i]FViJKUY]00MJKP=JK09JK@EJKP06FTiJKEY<FTaJBeY<0eY=00AJC5Y/EVeFC0AFC@04
ETaFBeI;ET`2ETd015I>ETaFC5I;0eI<00EF:eI<ETaFC5H[009BB`03DTaB;58/009B;003DR]B;58/
00UB:`04CR]>;4h/CRd2BRd3CRd014h/CR]>;4h/0Th[0Th;00A:2dh;CP]>2PA>2`9:305>:`5B2@5=
j`00010<@@PQ22888Pa1348<@@Q1348<HPaQ22440@@02408@@@<@@@<8@D<@@0;24<80P@0320XiD6[
EW1RTEi?GVmJL002GY000ej>GVmNL003GW02GY02GY45GY0@GY4015j@HY1R/6:`0f:a1F:`0V:a0V:b
00=R/FJ`H[000VJ`16Ja00QV/6:`I[1R/FKBI[9VdVJb1FJa0VJb0fJa00EVd6J`I/mRSfJa00=VdP03
I[9V/FK@00AVd@04I]9V/FJbI[83I]800f[BI]9Zd`02J]800fKBJ]=ZdP02J]800f[cJ_9^l@02J]00
2VJ_HXiNCEi_HY1V/6KAJ]5ZdV[b0V[c00=Zdf[BJ]<00V[B0V[b3V[c00A^lf[cJ_AZm0=^l`9^lP=^
l`03K_9_4flC00M_4`03Ka9^lVkb00=_4`9_4P03Ka=_56lE00=_5@A_=0=_5003KcA_56lD00=_50A_
5@E_=@A_=09c4`A_=09_=@9_=008Lc=_=7<eLcIc=FlfLcI_=PA_=@03LcE_=W<e00M_=P=_=@04KcIc
=VleLcD2KcD00flfLcI_=P05KcH00g<fKcI_=P02LcH01fleKcI_=VlfKcE_=Vle00=_=P03LcEc=W<e
009c=PA_=PEc=@9_=@9c=09c4`9c<`0CKcA_=FldKcAc<fldLcAgM7]bLe=^kUi8FRYJBVK?Kc=gDflc
Lc<00W<e1Flf1Fle00=_=6lDKa@00flD1Fld0Vle0Vld00Ec<VlCKaE_57<c009_=11_=@9_=003KaA_
=Fle009_=@03KcA_=Fle00=_=@=_=0=_509_4`03La=_=6ld009_=0=_509_4`E_5003KcA_56lD009_
51U_4`03Ja=_4V/C00=_4`03J_=^lfkc00=_4`=Zl`=_4P03J_9^lV[b009ZlP03K_=Zlf[c00=Zl`03
J_9Zlf[b009Zl`MZlP=Zl@=ZlPEZl`03J_9ZlF[b00EZlP03I]9ZdV[B00EZdP03I]9VdFKA00EVdP04
I]5Vd6KAI]82I]400fKBI]5Vd@06I]400fK@I]5Vd@03I]800fKAI]9V/@05I[42I]400fJaH[5V/006
H[42H[06H[401V:`H[5R/F:aH[1R[`9R/0ART003GXmR[Uj_00=R[P9R[`9R/0=NT09R/005GY1NSUj>
GXmNSP06GXl2GXh6GXl2GVl015j>GXeNSEj=0Ui]00EJKEi/GVaNK5Y]00IJKP9JK@AJK003FV]JC5Y<
00=JK@9JKP05FVeJCEY<FTaJB`03FT`00eI;FTaJC006ETd3ET/<ET`5ET/01E9;DRaB;59;DR`00U8[
0eH[258[0U8/1dh/00E>:dh/CR]>2dh:009>2`03BP]>2dh;009>2`04CPY>2dh<CP`2CP/1DPP1BN/0
00033448@@Q100<8@P062288@PQ2248<@@Q10PPQ0PQ10PQ20`Q10P`Q00P<@@a246<@Q0aS348<HaAS
0P`P00LTa3f[EY5NT5i>GVmJL002GY000ej?GY1NT004GW03GY02GY43GY0@GY4016:AHY1R/F:`0f:a
00=R/6:aH[400V:a16:b00=R/F:`H[000fJ`0fJa0fJ`00=V/FJbI[800VJb0fJa0VJb00=R/VJbI[80
0VJa0fKA0VJa00IV/VJcH[=V/fJbI[42I]82J]42J]800f[CI]9Vd`02I]84J]<016[BI]9Zdf[C0V[B
0V[c00iZlF[AJ]5V/6J?GViNKei^I[1VdF[AJ]9ZlV[c0V[C00=ZlV[cJ]801V[b2V[c00=Zm6[cJ_@0
0V[d1Fkc00Ac5FlDK_=^lPY_4`9^lP03Ka=_4VlC009_4`04Ka9_4flCKa@2KaD=Ka@4KaD00fleKaE_
5@02Ka@2Kc@01G<CKa=c4g<CKa<00fle00E_=6leKcA_=G<d00=c=@05KcE_=VlfKcE_=002Lc@2LcD0
0flfKcE_=P02LcH00g<eKcI_=P03KcH016leKcI_=Fle0g<e1Vlf00=_EflfLcH017<f1flf0flg00I_
=W<fLcIc=VlfLcH3KcH01FleLcEc=G<eLcH00g<e00Mc=7<CMa=c4g<DKcE_=P02KcD03FldKcE_=GMC
Ni5gDfl?IXaJ2ei;I/m[4g=C009c<`03LcA_=Flf00A_=PI_=@04KaA_5FlDKa@5Kc@3KcD02FldLcAc
<FlCKaA_5FlDKcE_=00GKcD00fldKcE_=@03KcD3Kc@00flEKaA_5002Ka@017<CKcA_=6le0Vld16lD
00=_4flDKa@00Vld00=_5FlDKa@00flD4flC00=_4VlCKa<01F/C2VlC0V[c0VlB00=ZlV[cJ_<01F[c
0V[d0V[c00=ZlV[cJ_800f[c1V[b0f[a0V[b00=ZlfKcJ_@00f[c1F[b00AZdfKCJ_9VdPEZdP=VdP=V
d@AVdP03I]5Vd6KA00=Vd@=VdPAVd@04I]1VdFK@I]42I]801V:aH]9VdFJbH[5V/PMV/@9V/0=R/@04
H[1R/F:aH[43H[05H[48H[02HY02HXl01Ej?G[1R[V:_HZh00V:?00IRT5j@GY1NT5j`H[02GY000f:`
GXmNS`03GXh4GXl00ej>GXmNS`03GXl01Ej@FVmJKeY_GVl00Uj>00=NSEi]FVd00UY]0Ui]0UY^0eY_
0UY^0UY]00EJK5Y]FVaJK5Y[009JC0MJK@9JK003FT]JC5Y<00AJC09JC@AFC@9FB`UFC003ERaFC5I<
009FC@05ETaFBeI;ET]BC004DR`2DR/00eH[ET]B:`08DR/2DR`5CR`2CP`00dh;CPa>3004CP/00dX;
CP]>2`02CP/00dh:CP]>2`02CP/1CPX1DPT1CN/00088@@<88@@88P032488@@Q100888@88@@88@P<8
@@05224<8@a1348<HP0334803Pa1460@@1118:@iRE9aHY1NCUi_GW1NT5Y_GXl2GY000ej?GVmNL002
GW07GY06GY401F:@HY5NTEj@GY400eja0UjA00=RTF:@HY001F:`2F:a0V:`2FJ`00AV/F:aH[5R/@AV
/@04I[9R/V:bI[83I[45I]401VKBI[=V/fJcI[9V/@=VdP04J]5VdFKAI]42I]802F[CI]9ZdfKCJ]=V
dV[BI]9ZdP03J]<2J]83J]4026JaI[1RT5i?GTeRSfKAJ]82J_82J]84J_800f[BJ_9ZlP05J_8;J_<2
J_@3K_<00fkdK_=^l`02K_<2K_88Ka<2Ka801FlCKa9_4VlBKa<00flB00=_4flDKa@00flD1VlC1VlD
0flE00=_=FlEKcD00VlD00=_=7<CKa<016lC0fle00=_=6leKc@01Vle00M_5FleKcAc<fldLc=c=004
KcD5LcD2KcH01G<eLcAc=G<eKcD017<e00E_=VlgKcI_=Vle00A_=P03LcIc=G<f00M_=P=_=`I_=P04
KcE_=VlfKcH5LcD3KcD02G<cLaAc57<ELcE_=W<eKcE_=002KcD02W=DNg1kLWM@J/mF;5H[GVaVlF/A
0Vlc00=c=6ldKcD00Vlf00A_=G<fKcIc=PI_=@9_50=_=09_<`07Ka=_=6ldKc=_4W<aKa<00VlE0W<D
0Vld1Vle00Ic=7<eKcE_=FldKcD3Kc@3KcD3Kc@016leKcA_=6ld0fle16ld0VlD00Ec56lDLa=_=6lC
00=_=004KaA_4flCKa@3Ka<8Ka@<Ka<2K_<5Ka<2Ka801VlCJa=_4f[bJa9Zl`9_4P9_4`I_4P=^lP9_
4P=Zl`=ZlP9Zl`04J_AZlf[cK_82J_83J_<6J_83J_42J_82J_<00f[dJ_=ZlP02J_82J]8016[AJ]9Z
dfKC0VKB1F[B0VKB16KA16KB00AVdFK@I]1Vd0MVd@03I]1VdFK@009Vd0IVd@MV/@0;I]5VdVJ`H[1V
/6:aI[1R/6:_H[1V/002H[4016:`H[5R/F:`0f:a0V:`00ER[f:`HZmR/6:_009RT0=RS`03HXiNSf:^
009R[PARS`04GXmNT5j@H[03GXl00ej>GXmNSP03GXh2GXl01F:?GXmNSej?GXh00Uj?0Uj@00=JL5Y_
GXl00Ui]00MNSEj>FVeJKEi]GXiNK@02FVh3FVl2FVh00eY]FVaJJ`03FV`3FV/00eY/FTaJC@03FTd0
15Y<FVaJK5Y;0UI;0eY<00=FBeI<FTd015I=0eI;00]F:eI;ETaFBeI<ET]BBe9<ERaF:eI<009FC@03
ETaFBe9;00=BC0=B;09B:`03ER]B:e8[00=B:`03DRYF:e8[009B:`04DRaB34h/CR`3CP`00dh/CPa>
3002CP`4CP/00dX<CP]>2`02CP/3CPX2CP/1CPX1DPT1CN`0000324488@PQ00888@888P03328<H`aS
00<<@P032488@@Q20088@P<8@@888@0?344<@Pa232488@`Q344@@0`P420LPcE8CU5R/6:@009NL003
GXmNT5j@00=NT0=NL0INT0QNT@03GY1RT6:A00ENT@04G[5NTEjAHY46H[42H[83H[42HY42H[4016:`
H[5R/F:a1VJa00=R/F:bH[400f:a0fJa0fKB0VJb0fJa0VKA0VKB00=VdfJbI[800VJb16KB00=ZdFKB
J]800VKB1VKC00=Zdf[BJ]<00V[C0VKC0V[C0f[B00UVdVKAHY1RL5i=HVmR/FKAI_800V[B1F[b00=Z
lf[bJ_800f[b36[c0f[d0V[c00E^lf[cK_=^lfkb00A^l`9_4`=^m0I_4`05Ka9_4flCKa=_4P02Ka<0
0f/DKaA_5008Ka@2Ka<3Ka@5KaD016lFKaE_5Fle1flD36le00=_5FleKc@00W<c00=c=FlfKcH00fle
0g<e00Ic=W<eKcI_=W<eLc@3LcD2KcD2LcD00gLeLcIc=P02LcH2KcL3KcH00fleKcI_=P06KcH5KcL4
KcH01FleKcI_=VlfKcD017<e00I_=G<eKcE_=7<DKa@2La@00fleLcEc=@02KcD03flfLeEkTgnbOg5Z
lEY>DP]F:f:>Ja5_=7=DKcA_=@07KcH6KcD2Ka@4Kc@2KcD01W<eKcA_<fldLc=_=@9c=@03LaA_56ld
009_=0E_=@04LcE_=FlEKaD3KcD00flDKcA_=@02KcD2KaD:KcD3Kc@00flEKaA_5002Kc@2Ka@2Kc@0
0flDKa=_4`05Ka@00flCKaA_5004Ka@8Ka<016lDKa=_4fkb0fkc0flC00A_56lCKa=_4`9[4`03J_9[
4f/C009[4`=_4`03Ka9ZlV[c009_4P=^lPEZl`=ZlPEZl`04K_9ZlV[bJ_82J_<:J_801F[aJ_=ZlfKc
J_<00f[b16[B0VKC00=VdVKcJ]800f[B0fKB16KA1FKB0VKA00=Vd6KAI]400VKA00=VdVKAI]401fKA
0fKB0fJb00YVdVKAI[5V/FKAI]9RdVKAI[5V/09R/@03H[1R[f:a009R/@=R/003H[5R/6:a00=R/@03
H[1R[f:`009R/003HZmNT6:?00ARS`06GY1R[ej`HZmR/6:@0V:?00ANSej@GY1NT09NS`03GY1NSej?
00UNS`9NSP9NS`=NT09JK`9JKP09GVeNSej?GXmJSUZ?FViJKeY^00EJK`05FViJKEY/FVeJK002FT`4
FV`4FTd01EY<FT]JBeY;FT`01eY=0UI>0eI=00=FBeI<ET`015I=00AFC59<DTaF;0AFC003DTeBBe9;
009BB`QB;0UB:`9B;003CRa>34h<00A>30E>2`08CR]>2dX<CP]:34h<CP]>2PA>2`5>2P5>2@5>3000
20PQ00L8@@Q2348<HPa2248<@P0224832442224232400`a132488@0322403@`P200<01A1=BM>D5j>
GXmNL5i_GViNSej@009NL003GY1NL5i`00ANT0ANT@9NT0ENT@=RT@ANT@03GY1NTF:a00ER/@AR/PIR
/@=R/005H[5V/FJaI[5R/@06I[44H[43I[42I]400fJaI]5Vd@05I]47I]801fKAI]9VdVKBI]5VdV[A
009Zd`EVd`9Zd`=ZdP03I]9VdfKC00EZd`9ZdP9R/@05GViRKf:?I]1VdP06J]84J_85K_<5J_<3K_<2
J_<2J_@2K_@00flDK_AZm002K_<00fkbK_=^l`03K_<4K_@3Ka@00flCKa9_4`0;Ka<00flDKaE_5@02
KaD7Ka@7KaD2Ka@00flEKaA_5002KaD026lDKcA_=6ldKcE_=VleKcH7KcD3Kc@00flDKaE_=P02KcH2
KcD00fldKcEc=@02LcD017<fLcEc=G<e1fle00=c=FleLcD01flf00=_=FlfKcH00Vlf00=_=G<eKcD0
0flf0flg0Vlf0Vle00Ac=FlfKcI_=PIc=@Ec=09c<`=c=@0@KcE_=VlfLcIgLg^BOi1[4Uj?EReF2ei<
J_5cEGMCKc@3KcD3KcH00g<fLcEc=@02KcD6Kc@00fleKcA_5004Ka@3Kc@00fleKaA_5002Ka@4Kc@0
1G<cKcA_=6ldKa@00flE16le00=_=6leKcD03Fle36ld00=_<flCKa<00VlD1flC0flD1VlC00A_4VlC
KaA_50=_4`9^l`9_4`9_50A_4`05Ka9^lf[cJ_=_4P04Ka<01FlBKa=_4flCKa800fkb1F[c0f[b16[c
1F[b16[c0V[b0V[c00YZlV[BJ_9ZlV[aJ_9ZlfKcJ_=ZlP9ZdP05J_5ZdV[bJ]9ZlP03I_<5J]82I]83
I]46I]82I]401VK@I]5VdFKBI]5VdP9V/@=Vd@04I]9VdFKAI]44I]800f:bI]9VdP03I]42I[42H[40
1VJaI[1R/F:aH[1R[`=R/@9R/003HZmR/6J`00=R/@9R/006HZmR/6:_HZmR[V:?0f:@00AR/6:@HY1R
T0=R/004HY1RSf:?GXl2GY08GXl2GY05GXl3GXh00ej?GY1NT002GY000eY_FViJKP02FVh015Y]GVeN
SUY^0UY_0eY^0eY_00EJKUY/FVaJC5Y]009JKP06FTaJJeY/FVaJC5Y=0eY<0eY:00=JC5Y=ET`015I<
0UY=0UI=00=FC5I=ET`025I<00EBC5H/ERaF;59<009FC0IBB`IB;0aB:`03DP]>2e8:00=B2P=>2`9>
2P9>2`06BPa>2dh<CPa>2dh:0dh;0Th:0E890Dh<000222422446224234801Q1R368<@PQ222888@88
@@032248@@Q100H88@0<24480000200@8345BRmNSUj?GVmNL5j>0Ui_0Ui`00=NT5i`GW002Ej@1ejA
00=RT6:AGY400UjA00ARTF:@HY5RT0mR/@03H[1R/F:a00=V/@03H[5R/V:a00EV/@04I[1R/F:aH[44
I[400f:aI[5V/@06I]42I]800f;BI]9VdP02I]802FKAI]9VdVKBI]5VdV[AJ]9VdP05I]<4J]<00f[B
J]=Vd`02I]<3J]<03f[cJ_9ZlVKBI[5RT5i^HXiVd6KbI]9Zlf[bJ_=ZlP02J]8016[bK_=Zlf[c1Fkc
16[c00=^lf[cJ_<00Vkc0fkd00=^lf[dJ_@00V[c00=^lfkbJ_<00fkc1Fkd0flD2VlC1FlD1VlE1FlD
1flE0flD16lE00A_56ldKcA_=0A_=@03KcI_=Fle00I_=@03LcA_57<D009_=@03KcI_=Flf00=_=@Ac
=@E_=@07LcE_=FleKcEc=FleLcD00flf00Ac=VlfLcIc=PE_=P06LcIc=G<eLcEc=Vlf0Vlg26lf00=_
=G<eLcD00W<e0Vle00Ec=FleKcEc=G<d009_=0=_=@0@LcEc=VlfKeIcEG=DNg9_=6KAFTeJ;5i<I/m_
=7MDKc@3KcD6LcD00fleLcA_=@06KcD00fldKaA_5004Ka@2KcD00flEKaA_5002KaD016lDKaE_=Fle
0W<d00=c<fldKa@00Vle16lf1Vle0Vlf2fle00=_=6leKaD016lD00=_=FldKc@00Vld16lD1VlC0flD
0VlC0VlD00E_4fkcK_=_4flD00M_4`03Ja=[56/D009_4`=^l`=ZlP03K_=ZlflC00=_4`E_4P9_4`EZ
l`=ZlPEZl`04K_9ZlV[bJ_84J_<2J_801f[CJ_=ZdV[bJ_=ZlV[a009ZlP9Vl`03J_9ZdV[B00AZdP04
J_9VlfKcI_<5J]83I]83I]45I]82I]400fK@I]5Vd@04I]8026JaI[1VdFKAI]9VdFKBI]43I]8016:b
H[=R/fKB0VKA00AV/FJbI[9V/P9R/@05I[1R/F:aH[5R/003H[43H[000f:aH[1R/@02H[43H[002V:a
HZmR[f:^HZmRSej@H[1N/6:`0V:@0V:`00AN/F:`HXmRT09NS`03GY1NSej?00ENS`ANT0ANS`ANSP9N
S`03GY1JKeY_00AJKP=NK@03FViJKeY_00=JKPAJK`04FVeJK5Y]FVd2FVh2FT`3FV`01EY=FTaJC5Y<
FT/00UY:00=JC5I<ET`01EI<0eI=00=FC5I=ETd015I<00IFCEI<ETaF;59<DR`5DT`5DT/00e9<DRaB
;004DR`3DR/00eHZDR]B:`06DR/01U8;CP]B2U8[DP]B:`=>2`9>2PA>2`9>30I>2`5>2P5B2@5>3000
0PPQ00<880Q122401PPQ00H<@@aR468<HPQ22282224010Q122488@a10PPQ00<400PQ22400Pa100P<
80P0100<02cTAPeFCUY_0Ui_00=NSei_GVl00Ui`00=JL5i`GW002Uj@0ejA0Uj@00=RT6:?HY000UjA
0V:A00=RT6:aH[000f:a0V:A00=RT6:aH[400V:a00AR/V:aHY5RT0ER/@9V/@03H[5R/V:a00=R/@9V
/@03I[1R/F:a00MR/@9V/@EVd@03I[5VdFKA00UVd@9Zd@03J[5V/VKB009VdPAVd`05I]9Zdf[BJ]=Z
dP03J]<02fKBJ]=ZlV[bKa9ZlVKAH[1NKUi<IZl00VKA00AZlV[aJ]5ZlP9ZdP=ZlP9Zl`A^l`AZl`03
K_=Zlf[c00I^l`=Zm0E^lP9^l`=^m09^l`03KaA_5FlD00Y_4`04KaA_4flCKa<4KaD3Ka@2KaD2Ka@0
0fldKaA_5005KaD3Ka<01FlDKaE_5FlEKa@00fld1Fle00=_5FleKcD01Fle0fld17<e00A_=VleKcE_
=@A_=P03KcE_=6ld009_=@03LcAc=Fle009_=@03LcE_=Flf009c=P04LcEc=W<eLcH2KcH016leKcI_
=W<f0g<e00=c=VlfKcH02Vlf00=c=FleKcD00fle17<e00=c=6ldKc@00fle011c=6leLcIc=W=EMgAk
TW=EJ_9NSUX;FRYRSV[aLc9_=0E_=@=c=@03LcAc=G<e00=_=@05KaE_=FleKcE_=004Ka@00flCKaA_
5002KaD2Ka@4KaD3Ka@01FldLa=c4g<cLcD01Vle00A_=6leKcA_=@9_5@A_=@=_=004KcE_=6leKcD2
Kc@00fleKaE_5003Ka@00flEKcA_=004Ka@2Ka<00flBKa=_4`03Ka<4Ka@016lCKaA_56lD0VlC00A_
4VlCKa9_4P=_4`9_4P04Ka=_56[dJ_<2K_<6J_8016/CKa=_4flB0Vkb0f[b00=^lVlBKa800f[c00=Z
lV[cJ_800V[b1F[c00E^lV[bJ_9ZlV[c00=ZlP08J]5ZlV[CJ]=ZdV[bJ_=ZlP=Zl@03J_9Vlf[b00=Z
dP05J_9ZlF[BJ]9VdP02J_84J]8016[AI]9VdVKB1VKA00EVdVKAI]5VdFK@00=Vd@06J]5VdFKAI[5V
/6Ja1fKA0VJa00AV/f:cH]=Vd@9V/@05I[9R/V:bH[5V/@03I[04H[401VJ`IZmR/6:`H[5R/09R/@ER
/09R[`=R[P04HZmR/5jaH[02HY0016:?GXmN/5j?0V:?0ej?00=NSUj?GXl01Ej?0ej@15j?00MNSUj=
GXiNSEj>GXeNS`02FVl4FVh00ei]GXiNK@08FVh2FVl2FVh015Y]FVaJKEY]0eY<00=JBeY<FT/00eY<
0eY:00=JC5I;ET`01UI<0eY=0eI<00=FBeI<ET`00eI<00AB:e8/DRaB;0=F;0EBB`AB;09BC005DT]B
:e8ZDR]B:P02DR/00dh[DR]B:`04DR/0158;CP]B2U8;0U8[00EB:Th;CPY>2U8:00=>2`05BP]>2dh;
CP]:2`04CP/1CPX1DPP1CP/000888@0322088@PQ00<88@<8@@04248<@@a2348234400`PQ2448@@03
344522402P`Q340@@110300@033TANeFCUj?0Uj@00INSej@GY1NL5iaFY47GY0;GY42HY000ej@HY1R
T002HY000ejAH[1R/@02H[42HY47H[42HY400f:aH[1R/@02H[800f:aI[9R/@04H[82H[400fJbI[5R
/@09H[43I[82I]800fJbI]9VdP0:I]800f[AJ[5V/P02I[82I]86I]<00fKBI]=ZdP04J]<00f[cJ_9Z
lP02J_<01fKBI[1RSUh/GVmR/FKA009ZlP03J_=ZlV[b009ZlPmZl`03J_A^lf[c00=^l`=^m006K_=Z
lf[bJ_=^lf[d0Vkd00E^mFkdK_=^lW<C00=_50=_4`03KaA^m6kd009_5004Ka=_56lDKa@<KaD00flD
KcE_5@05KaD2La<00gLCLaA_5006Ka@3KcD2KaD=KcD5KcH00fleKcI_=@0>KcD3KcH2LcH00g<eKcI_
=P02KcH3KcL2LcH00fleLcI_=P03KcH2KcL7KcH3LcH00fleKcI_=P03KcH6KcD047<dKcEc=G<eMeEg
MG^CMgE_<f:_FRaIjF9]J_5c<W=D16le1g<e00=_=VleKcD016le16ld00=_4flDKa@00VlD00I_=FlD
KaA_5FlfKaH2KaD2Ka@02FldLa=c57<DKcE_5FlfKcE_=P02KaD:KcD00fldKaE_=@07KcD3Ka@01Fle
KaE_=FldKcD016lD26lC26lD0V/C0VlC0VlB0flC0VlB00A_4flDJ_A_4`9^l`EZlP9Zl`06Ja=_4Vkb
K_9^lf[c0V[b00=^lV[bJ_801F[c00=ZlV[cJ_803f[b0V[C00AVdVKcJ_=ZlP=Zl@05J_9VlfKcJ_=Z
lP02J]82J]4016[BI]9ZlVKB1F[B00=VdVKCI]801FKA0fKB0fKA0fKB00AVdFKBI]9VdP9Vd@9VdP=V
d@9V/@06I[9VdVJbH[9RdVKA0VJa00IR/V:cH[9R/V:aIZl7I[001F:_H[1R/6:aH[000f:a0f:`00AR
/F:_H[1RS`9R[`=N/@05H[1NT6:?HXmNS`02GY000f:?GXmNT008GXl2GY04GXl3GXh00ej?GXiNSP02
GXh015j=GXiJKUY^0eY]00=JKUi]FVh00eY^0eY_0eY^0eY_00=JKUY]FV`00UY]00=JC5Y]ETd02EY<
0eY=00AFC5I=ETeFC@EFC003ETeF;EH/00IFC0=B;005DTaF;5I<ERaBC003DT/00e9<DRaB;@04DRd0
0e8/DR]B:`03DR/3CR/3DR/2CR/4CP/01E8;DR]B2U8ZDPX00Th:0Th;1Dh<1Dh;0E8:0E880Dg/0002
224010PP22488@PQ1@Q100D88@Q12448@@`Q00<88@04240<@0PP120622403``P440@@0`P420/i4G/
GXiR/5Y^GXiNSej@GXmNL002GW400ei`GY1NT003GY02HY000ejAGY1NT@07GY42HY001F:?GY1RSf:?
HY000V:`0f:a0f:A2F:a00AR/6:aH[9R/P=R/@03H[9R/F:a00AR/@04I[9R/VKBI[86I[402VJbH[9V
/VJbI]9VdfKBI[9VdVKC26KB00=VdfKBI]800fKB00=ZdfKCJ]800V[B0V[C00=Vdf[CJ]<01F[B0V[b
00aZdV[bJ_=ZlVK@IZiNKUY?HY5V/FKBJ_82J_<6J_83J_<00f[dJ_=Zl`07J_<5K_<00f[dK_AZm002
J_@016kcK_AZm6[e0fke00A^m6kcK_5_4P9_4`E_509^m09_5@A_50M_5@=_5P9_5@A_50A_5@9c5003
La=c57<C009_4`05KaA_5FlEKaE_5005Kc@3KcD5Kc@4KcD01FlfKcE_=FleKcH04fle00A_=W<fLcIc
=@E_=P05KcM_=VlfKcI_=@02LcD00g<fKcI_=P06KcH017<eLcI_=Vlf0W<f0g<e0W<f00=_=W<eKcD0
1Fle00m_=7<dLcEg=GMDNi=kM7MCI]1J;5GXGTaZl7=BKc@01W<e00Ec=6leKcE_=GLc00E_=@03KcA_
4flc00=_5003Ka=_56lD00=_5003Ka=_56lE009_5@03KcI_=Fle009_=008La=_56lDKaE_5VlfKcE_
=P9_5@03KaA_5Fld00=_5@9_=@=_=003KaE_=Fle009_=@06KcA_=FleKcE_=6lE0flD0Vld1FlD26lC
16lD1FlC00=[4flCKa<01FlC0flB0flC00=^lfkbK_800fkb0V[c0V/C00IZlVkbK_9^lf[dJ_<4J_84
J_<00f[bJ_5ZlP0>J_800f[cJ_9ZlP02J_800f[cJ_9ZlP03J_400f[bJ_=Zl`02J_85J]400f[BJ_9V
dP05J]8016KBI]=VdVKA0V[@16KA00=VdVKAI]8016KB00AVdFKBI]=VdP9Vd@9VdPEVd@AV/@04H]5V
/FJaI[83H[<016:bH[5V[f:_0fJ_16:_0f:`00=Vd6;AH[000f:`00=R[f:`HZl01f:`00=R[f:`HY00
0V:`00=NT6:?HXl00ej?0Uj@0ej?00ANSUj?GY1NT0ANS`03GXiNSej?009NS`04GY1NSej>GXd4GV`3
GVd3GVh2FVh015Y_FViJKUY^0Ui^15Y^00IJKEY/FVaJJeY/FVh2FVd015Y<FT]JBeY;0UY<1UY=0eI=
1EI<00=FCEH]ERd01eI<0e9<00=B:eH/ER/015H/0U9<00MB;E8^DRiBCU8]CReB;00;DR/00dh[DR]>
2`04CP/5CPX014h;CPa>34X<0dh<0Th;00E>2Dh:DPY>2U89005=j`0020Q100<<@@Q1344010PQ0``Q
00<88@Q134400PQ10`PQ00`<8@PQ320<811P340800`09:=1bei^GZl2FVl00ej?GY1NS`04GW000eZA
GW5NT002GW000ej@HY1NT00:GY401Uj@H[1N/6:`GY1RT0iR/@9R/P03H[5R/6:a00IR/P05I[5V/VJa
H[5V/P05H[800fJaI[9V/@03I[400fJbI]9VdP04I]<5H]<6I]82I]<00fKBI]=Vd`03I]<3J]82J]<0
16KCJ]=Zdf[B0f[C0f[B16[b00=^lV[aHXl00UY?00ARTFJbJ]9Zl`=ZlP03J_=ZlV[c00=Zl`03J_AZ
lf[d00QZl`=^l`9^m09Zm@EZm003J_=Zm6[d00=_5@04KaA_4flCKa<3K_@3Ka@017<DKaE_5FlE0flC
0VlD0flE0VlD00A_5FlFKaI_5P9_5@E_50E_5@06KaAc56lDKaA_4flD0flE0VlD0Vld1Fle1Fld16le
00E_=VleKcE_=Flf00I_=@03LcE_=Vlf00=_=PM_=@=_=P07KcE_=VlfKcI_=FlfKcL016lf00=c=W<e
LcH016lf0W<f0g<e16lf00=c=W<eLcD017<e00=_=VleKcD016le00i_=7<dLcAc=GLdMe=kM7]BJ_5J
;EX:FRaVcg<a0Vld00=_=G<eLcD01Fle00=c=7LcLc@016le00=_=6lDKa@00flD00A_4flDKa=_4`9_
5003KcA_=FlD009_5@E_=@05KcA_4fldKaA_5@04KcH00flEKaA_5002KaD016lDKaE_5FlD0fld00=_
=FlEKcD00Vle00=_=6leKcD00Vle00=c=FldKa@00VlD0fld0flD1VlC0W<C00A_=6leKaA_515_4`9^
m006K_=_4flCK_=ZlVkb0f[c00E[4f[cK_9^lVkc00=Zl`=ZlP03Ja=Zlf[c009ZlP9Zl@9ZlP=Zl@=Z
lP9Zl@03J_9^lV[b00=Zl`QZlP04J_5ZdV[BJ]82J_84J]4016[BI_9VdVKB0f[B00=ZdfKCI]<00VKB
0VKA0V[@0VK@1FKA2fKB1FKA0VJa00=V/VJaH]400f:a00=R/V:cH[800V:a00=V[fJ`HZl00V:_16:`
0V:a00=RdF:`H[4016:`00=R[f:`HZl01f:`00QR[f:`H[1N/6:`GY1RT6:?1Ej?00ANT5j?GXmNSP9N
S`03GY1NSej?009NS`03GXiNSej?00ANS`06GY1NSUi]GVaNSEi/15i]0Ui^0UY^00AJT5j`GY1JKP9N
KPAJKP04FVeJK5Y/FV/2FVd00eI^FVeJK003FT/4FT`3FTd015I<ETeFCEI=0UI<00AJC5I<ETaFC@9F
;@03ER]F;5I<009FC003ETeF;58]009BC003ER]B:eH[009FC09F;005DTaBBe9<DReB;P02DRd2DR`6
DR/00dh/DRaB:`05DR/2CP/00dh<CP]>2P03CPX3CP/5CP`2CP/3CPX1CNX1CNT1CN/000032448@0PQ
00<88@D<@@@88@07220<8@a1344<8@PQ244010PQ00H<8@PQ320<@11P4402200012BS@JQNK5j=0UY_
00=NKei^GVh015i`00ANLEi`GW1NK`ANT0=NT@03GY1NTEjA00ANT@ENT005HXmRT6:@H[5R/002H[40
0f:AH[5R/@08H[400f:`H[5R/@04H[401VJbI[5V/FJ`I[5V/PER/P9V/PEV/@=V/P03I]9VdfKC00=R
d`9RdP9Rd@03I]5VdVKB009VdP03I]=VdVKB009VdP9Vd`9ZdP05J]5ZdV[BI]=Zd`05I]86J]802V[b
J_5^l6J`HY1NKei`I[5VdF[A1F[b0V[C00=Zlf[bJ_<00V[d26[c00=^lVkcK_@00Vkd1F[d0f[c00=Z
m6kcK_@00Vkd00A^lfkdK_=^m0=^l`9_509^m003KaE_56lD00E_4`04KaA_5FlDKa<2Ka@4KaD00flD
Ka=_4`03Ka<01VkdKaA_5G<DKaAc50=_5003Ka=_56lD00A_509_=0=_=@9_=005KaA_=6ldKaE_5008
KcD016lfKcE_=Fld0fle16lf00E_=FlfKcE_=G<e00Q_=@08KcIc=VleLcE_=F/fKcI_=@9c=@03LcIc
=Flf00A_=P9c=P=_=@04KcI_=flgLcH3LcD2Lc@3LcD5KcD3Kc@3Lc@037LcNe=kDF[aHXmJ:eH<HVaZ
kflcLc=_=09c=@E_=@=c=0A_=@03KcA_56lD009_50]_4`03KaA_=Fld00=_=@05KcAc4g<cKaA_5@03
KcH00fleKaA_5002Ka@00flEKcA_=@02Ka@3Kc@5KcD01fldKaA_4fkcKaA_4flc00=_4`=_<`A_5003
Ka=c4VlC00=_4`03KaA_=6ld009_=004KaA_4flCKa@7Ka<00flBKa=_4`02Ka<01VkcK_A^m6kcKa9_
4`9^l`06K_9ZlV[cJaA[4f[c0V[b0V[c00=^lf[cJ_801f[b0V[a0V[b0f[a0f[b0V[a00EZlVkaJ_9Z
lV[c00AZlP=Zl`9ZlP05J_5ZdV[AJ]9ZlP05J]4016[aI_9VdVKB0f[B00AVdVKCI]=VdP=Vd@=Zd003
I]1VdFKA009Vd@03I]1VdFKA009Vd@MVdPEVd@9V/@08H[5VdFJ`I[1R/FJaI[9R/P=R/@9R/0=R[`=R
/09R/@03I[1R/6:`009R/0MR[`05GXmR[f:`HZmR/002HZl00f:`HZmR/003HY000f:?GXmNS`03GXh0
0ej?GY1NS`02GXh5GXl00ej>GXeNS@06GXl2GVd3GV`4GVd2GVh3FVh015i]FVeJKEY]1EY^00AJK5Y[
FV]JJ`9JK005EVeJKEY/FVaJB`02FV`2FT/01EY:FT]FBeI;FT`02UI<0eH[00AB:e9<ETaFC@9F;007
ETaFBeI;ET]FBUI;ET`00UH/00ABBeI;DR]B;0=B;@9B;0AB:`9>:`03CRaB;58[00AB:`E>2`05CPY>
:U8YCRY>2P04CP/3CP`2CP/01DX;CP]>2Th9CNT00Dg[00001Pa124488@PQ22088@8<@@05364<HPaQ
3448@@0222401@a1368@H`aR34400`PQ00D8@@PQ22488@a1008<HP08360<80`P300TXd67FTaN[`9J
T003GXmNKUi^00ANL005FW1NL5i`GW1NT@03GY03GY400ej@GY5NT@05GY4015j?GY1NT5ja0ejA00=R
/F:`H[401F:a0V:B1F:b1f:a00AV/V:aI[9V/@MR/PMV/P05I[=V/VJbI]9Vd`04H]<01FKCH]=RdV;B
I]400VKB16KC16KB00AVdf[CI]9Zd@9ZdP=Vd`AVdP=ZdP=ZlP0=J]9ZlV[aI]9V/F9`GU1RTFJaJ]9[
4flDJa@00V[b16[c00=Zm6[cJ_@00V[d1V[c00=^lfkdJ_@01F[d1F[c00AZm6kcK_A^m09^l`03KaA^
lfkc00=^l`9_50=_5@M_50]_5@9_509c5004Ma=_5FlDKaD=Ka@2Kc@3KcD3Kc@7KcD4KcH6KcD00flf
KcE_=@02KcD2LcD00g<fLcEc=003KcD3KcH3KcD2KcH2LcD027<fKcI_=VleKcIc=G<fMcD4LcH3KcH3
KcD2KcH00flgLcIc=@02LcD2Lc@3LcD2KcD00flfKcE_=@02KcD017<eKcE_=G<e0WLc00YkDVlCJ]5N
KEH<GTaVd6mEMeAc<`9c=@A_=@9_=PQ_=@I_50A_4`05KaA_4flCKa=_5002Kc@3KcD3Kc@2KcD3KcH2
KcD00fldKaA_5005KcD00fldKaA_=002KcD2KcH01FleLc=c57LCK_<016lC00Ac<fleKcA_509_4`9_
50=_4`04KaA_4flCKa<2Ka@016lCKaA_=6ld1VlC00=[4flCKa<01FlC0Vkc1FlC0V[c00A^lV[bJ_=[
509[4`AZl`03J_9Zlf[c00=Zl`YZlP9Zl@AZlP07J_5^lF[bJ_9Zdf[cJ_800f[c1V[b0V[B00QZlVKB
J]9ZdV[AJ_9ZdFKb0fKB0V[B0VKB00=VdfKBI]803FKA00=Vd6KAI]400fKA00=VdVKAI]801FKA00=V
/F:aI[4016KA00=V/F:bH[401F:a16:`0V:a0f:`00=R/F:`H[001V:`2F:_00AN/F:`H[1RS`9RT003
HXmNSej?00=NSP=NS`9NSPENS`06GXiNSEj>GXiNSej>0Uj?00=NKei]GVd01Ei]2UY^00=JKeY^FVh0
0eY^00AJKEY[GVaJJ`9JK@03EVeJK5Y/00=JK003FVeJC5Y<009JB`9FB`03ETaFCEI<00=FC003FTaF
C5I<00=FC09F:`04ERaBC5H/ETd2ER`00eI<ET]FB`03ET/01EH/DRaF;59;ER/00U8/158]00=B;58[
DR/00U8[00A>:dh/CRaB;09B:`9>:`I>2`9>2P03CRY>2Th:00I>2`05BPa>2dh;BP]>2`02CPX1CPP1
CN`00006244880a022088@Q10Pa100D<H@a13608@@PQ008<8006224<@@a13448@@`P10PQ0PQ1014<
@@aQ368<@@`P220<81bR>DABC5j_GY5JT5j?GVeNKUi_00=NL004GW5NL5i`GY07GY400ej?GY1NT@04
GY4015j@HXmRT6:@15jA00=NT6:`G[401F:a0V:B0V:b00=RTf:cHY<00V:b1V:a00=V/F:aH[400f:a
00=V/F:bI[8026Jb00MV/fJbI[9V/VKBI]=Rd`04I]<4I]85I]<3I]82I]<016[CI]9ZdV[B16KB0f[C
00=VdV[BJ]8016[B0V[b00UZdVKBI[5RTEi@HW1VT6KAJ]400f[b00E^lf[cJ_=Zlf[b00=Zl`=Zm003
J_=ZlV[c00=Zl`=Zm0AZl`I^l`9^m09^l`03K_A_56kd00A^l`03K_A_5FlD00A_5003Ka=_56lD00=_
50Y_5@03KaAc57<D009_5003KaEc56lE00Y_509_4`03KaA_=6ld00=_=@=_=09_=@A_=0]_=@03LcE_
=Fld00A_=0I_=@03LcE_=Flf00M_=@03KcIc=Vlf00=c=@=_=P=c=P03KcIc=W<e00=c=@04KcIc=Vlf
LcH2LcD00fleLcAc=003Lc@2Kc@00fleKcI_=P02KcH2LcD03flfLcEg<gMDNe=cEFlAIZmF3EX/I]1_
EG=DLc=_=002Lc@00g<eLcA_=@02JaD00flDKcE_=004KcD3KaD4Ka@016lCKaA_4flC16lD00=_4flc
Kc@00fle1Fld0Vle00=_=VleKcD00fld00=_=FldKc@01Fld00I_=FlEKaE_5FleLc<3Ka@4Ka<4Ka@4
Ka<01FlBKa=_56lDKa<016lD2VlC0flB0VlC0VlB0Vkb16lC0fkc00E^lVkaJ]5^lVlC00=_4P04K_=Z
lV[bK_82J_82J_<9J_82J]400f[aJ_9ZlP02J_8016[aK_5ZlF[b1F[c00=ZlV[cJ_800V[a0f[b0V[B
00AZdF[BJ]9ZlP9ZdP04J]5ZdVKBI]83J]82I]800fKCI]9VdP0:I]82I]400f[@I/mVc`02I]0;I]40
1FJ`I]5Vd6KAI[000VJa3F:a1V:`0V:a16:`1f:^00MR[f:`H[5R/6:_HZiNS`02H[02GXl5GXh00ej?
GXiNS`05GXl00ej>GXaNSP05GXh015i^GVeNKEi/0Ui]0Uj>0Ui_1EY^00ANKUY^FViJK`EJKP07FVeJ
K5Y/FVaJKEY/FVd015Y/00=JKEY=FTd00UY=0UY;0UY<0UY=00AFC5Y<ETaJB`AFC09F:`9F;003DTaF
;5H/00=FC09FB`03DT]F:eI;009FB`EF:`9B;003ERaB;58/00IB:`9B;003DP]>:dh[00U>2`03DRY>
2Th:00]>2`03DPY>2Dh8005=j`0010PQ00@8@@a1368<H`8<@@05340<8@`Q320<@002224010a12448
@@Q10PPQ0188@@a136<@H`aR344@Ha1R3488@0PP68<i94h[FZmJTEY`GXl2GVh2GVl01Ui`GY1NTEjA
GW5NT0ANT@04GY9NTEjAGXl7GY400f:?HY1RT002HY42GY401ejaG[1N/EjaG[9R/F:b00=R/@9R/P=R
/`9R/P=R/@07H[9R/F:aH[5R/V:aI[800fJa00=R/VJaI[801FJb0f:c0fJb00=VdfKBI]<01VKC0fKB
16KC0VKB1FKC0V[C0f[B1F[C0fKB00=Zdf[BJ]800V[b00]ZdV[bJ_9V/69^FRaRKfJaI]5ZdF[b00YZ
l`9Zm0IZl`=Zm0=Zl`I^l`9^m003J_A^m6kc00=_5004K_A^lfkdK_@2K_D3KaD7Ka@9KaD4Ka@00g<C
LaA_5@03KaD8Ka@00g<CKaA_4`03Ka@00fldKcE_=@06KcD4Kc@2La@2KcD00flfKcE_=@08KcD2Kc@2
Lc<5Lc@00g<eKcE_=P07KcD016lfKcE_=Vlf17<e00A_=W<fKcI_=PAc=@9_=@=_=PEc=@9c=0I_=@E_
=P0?LcEc=7LdMgAkM7]fLc=V[eH<EPUNKFKcJa=_=7<c009c=003KcEc=G<d009c=@03LcAc=Fld00A_
=@04KcI_5FlEKaD5Ka@2Ka<4Ka@00flcKcA_=003KcD5Kc@2KcD2KcH01FleKcA_=FldKcD01Vld00=c
<fldKa@00flE00A_=6lDKaE_50=_4`E_509_=09_5003Ka=_56lD00I_50m_4`05Ka9^lVkcKa=^lP02
K_<00f[dK_=^l`02K_<00fkbK_=^lP06K_83J_84J_<00f[bJ_=ZlP05J_82J]45J_8016[cK_9ZlV[B
0V[c0fKc00=ZlV[cJ_800V[a0f[b0V[B00MZdF[BJ_9VlfKBI]5Zd@03J_83J]82I]800fKCI]9VdP04
I]82J]82I]83I]4016JaI]1Vd6K?0fK@0fKA0fKB00=VdFJaI[400fKA00AVd6KAI[1V/@YR/@04H[1R
/F:aH[46H[02H[44H[02HZl00f:^HXmRS`02HZl2H[03G[42G[04GY02GXl00ej>HZiRSP02GXh00ej?
GXiNS`02GXl2GXh015j=GXiNSej?0Uj>0Ui^0Ui]00=NK5i]GVh00Uj>00=NKeY^FVl00UY_0UY^00AN
KUY>FViJK`EJKP05EViJKEY]FVaJK@06FV`5FTd01EY<FT]JC5Y<FTd015I<00=JC5I<ET`00UI<0UH/
0e9<0UH/0eI<00AFBeH[DT]BB`=FB`EF:`03ERaB;58/009B;0IB:`9B2`04DR]>:dh[CR/8CP/3CPX6
CP/014X<BP]>2dh;0Th:0Dh90Dh70Dg[00000`Q12248@@0234400`Q1344<@@03344010Q1344<@0a0
0`PQ00@880PQ22488@8<@@8<H@@<@@<<@P08344@HS43ANYFSeZ@FW1NK`ANKP03GVmNL5Y`009NL003
GXmNT5jA00=NT@04GY1NSej?GY05GY4015j@HXmRSf:?0V:@0ejA00AR/5jAGY5N/PAR/@05H[1R/F:a
H[9R/`04H[800f:aH[9R/P05H[44I[4016:aI[5V/FJa16Jb0V:b00=R/fJbI[800fJb1fKC16KB00EV
dfKBI]=VdfKB009Vd`03I]9VdfKC00MZdP9Zd`03I]=VdVKB00=ZdPAZlP0:J_5^lFKAIZmN;5i?I[5V
d6KAJ_82J_<016[bJ_=Zlf[c0f[b2V[c00AZm6[cJ_=Zl`M^l`9^m006KaE^lfkcKa=_56kd0Vkc00=^
m6keK_D00Vke00M_56lEKaE_56lCKaA_4`02Ka@016lEKaA_56lD1FlE0VlD16lC00=_56lEKaD01flD
00Ac56lCLa=_4`=c4`=_509_=003Lc=_=Fle009_=@=_=0=c<`E_=@03LcA_=Fle00E_=@9_=003Lc=_
=6ld00=_=@=c=003KcEc=Fle00Y_=@03LcE_=Fle009_=@9_=P=c=@03LcA_=Fle009c=P06KcIc=G<e
LcE_=G<e2Fle00A_=VlEKcIc=@9_=@0?McAgMG^DMgE_<VJ^FR]F25i;I]5[4fldMc9c<g<d00E_=@=c
=0E_=@03KaA_5FlE00E_509_4`A_5003Kc=_=6lc009_=003KcE_=6ld00=_=09_=@03KaE_=Fle00=_
=003KcE_=6ld009_=006Kc=_=6lcKc=_4flD0VlE0VlD00Mc56lDKa=_4g<BLc=_=004Ka@00flCKaA_
5006Ka<2Ka@3Ka<00flBKa=^lP03Ka82Ka<2K_<2Ka<026lBKa5^lFkbK_=^lVkcJ_87K_<00flBK_9^
lP06K_82J_82J_<8J_84J_43J_83J_44J_83J_<2J_83J_43J_85J_4016KbJ_9ZlV[a1F[B0VKB00=V
dFKBI]801VKB1fKA0VK@00=VcfK@I]000VK@00IVdFK@I]5VdFKBI]42I[400fJ`I]1Vd003I]000fJ`
H[1V/004I[0016JaH[5V/6J`2f:`00=R/F:`H[000V:`00=RSf:_HZh00V:?00AR[f:?HY1R/0=NT003
GXmNT5j@00=NT004GXmNSUj>GXh3HXd3GXh3GXl01Ej>GViNSUj>GVl015i^0Ui]0ei/00ANKEj>FViJ
KP=JK`=JKP03FVeJC5Y^00=JKP=JK@04FVaJKEY/FVd3FV`2FT/2FT`01EY=FVeJKEY<FT/00eY:00=F
BeI<ET`02EI<00=BC58/DR`00U8/15I;00=F:e9;DT/00e9;1EHZ0UH[0U8/2U8[00=>:e8[CR/024h;
0dh:1Th;00=:2dh;CP/00dh:0Dh90E870DgZ0002244010a12448@@Q110a10PaR0Pa100<<@0`P2240
0`PQ0PQ1014<@@Q23448@@PP324<@@Q134888@@0124<8Bd5AN]BT5JA00=JL003GVmJKei_009JK`9J
L0ANT0=NT@04GY1NKej?GY03GY4015jBGY5NTF:?0V:@0V:A0UjA00EN/F:`GY5R/Ejb009NT@9R/@03
H[1R/F:a009R/P04G[=R/V:bH[45H[800f:aH[9R/@03I[401F:aH[9R/F:bI[400fJb00EV/F:bH[9R
/fJb00=V/`03I]9VdfKC00EVd`=VdP04I]=VdVKBI]84I]<4I]83I]<016KBJ]9ZdVKB0VKC0fKB0V[B
0V[b0V[c0V[b00Y[4f[aIY1NCf9`I[5VdV[bJ_=Zd`9ZdPIZlQ5Zl`9^l`04KaA^m6kdK_@2K_<00fkd
KaA^m006K_@01FkeKaA_5FlEKa@00flC0VlD1flE0VlD1FlC0VlD0VlE00=_56lEKaD01VlD00E_4g<C
La=c4flC00=_5003Kc=_=6ld00E_=@=_=09c=003KcE_56le00M_=@03KcI_=Fle00U_=@03LcEc=6le
009c=@05KcEc=G<eLcEg=005KcD017<eKcE_=Fle0Vlf0W<f0W<e00=c=6leKcD00flf00=_=FlfKcH0
0flf00=_=FlfKcH01Fle17<e0fle00ecEW=EKcA_<f[@HVeF25i;I]1_4W=ELc=c=00=KcD00flfKcE_
5@04KaD2Ka@00flCKaA_5002Ka@016ldKcE_=6lc0Vld0fle0fld00E_=FlEKaE_5Fle009_=003LcA_
=Fld009_=004KcE_=6ldLc<2Kc@6Ka@01W<DMa9flG<BKcA_509_=0M_50E_4`9_50A_4`03K_9_4VlB
00=_4`9^l`=_4`03La9^lVkb009^lP9ZlP05J_=ZlV[cJ_=Zm002Ka@2J_<00f[bK_9^lP02K_82J_83
J_<3J_800f[cJ_9ZlP03J_85J_42J_83J_44J_800f[CJ_=Zl`04J_8016[aJ_9ZlF[A16[a00EZdFKb
I_=ZdV[A00AZdP03I]9VdFKB00AVdP9Vd`AVdP06I]5VdVKBI]9VdFKB0VKA1FK@00=VdFK@I]401FKA
00=Vd6KAH]400fJ`0fJa00=V/6J_I[000VJ`1F:a3V:`00=RT5j@HXl00V:@0f:?00=R/5j`GY0025j@
0ej?0V:>00ANSUj?GXiNS`=NSP03GXmNSUj?009NS`ANKP05GXeNSUj>GXiNK@02GVl5FVl3FVh00eY]
FViJK@04FVh2FVd00eY^FVeJK003FVd2FV`7FT`01UY;FTYFBeI;ETaFB`aFC003DRaBC59<00ABC003
DRaBC59;00=BB`9F:`03ERYF:eH[009F:`=B;0EB:`04DP]B:e8[DR/3CR/ACP/00dX<CP]>2`02CP/0
0dh:CPUB1`01CN/0000324088@a100D<@@03324<@@a100<<@@03340880`P00<88@<<@@0524448@@0
224<@@022442248200001PPP:@E1beJaF[5JL09NL@03GW1JKei_009NK`03FVmNL5i`00ANL003GY1N
TEj@009RS`05GY1RT5jAGY5NTP02GY4016:?HY1RT6:A0ejA00=N/F:`GY401V:a0V:`0f:a0f:b0V:a
1V:b00=R/FJaI[4016Jb00=R/VJaI[801FJb00=R/VJbI[<00VJc00EVdVKCI]=VdfKB00IVd`=VdP04
I]5VdVKCI]<6I]82I]<00f[BJ]5Zd@03I]8016KAI]9VdVKB0V[B0V[b0V[c0V[b00M_4FKAHY5NKf:?
I[5Vd@02I]8016[CJ]9ZlV[b26[c00=ZlV[cJ_<00V[b0fkc1F[c00=^lfkbK_<02Fkc0Vkd0Vkc0Vkd
00A_56lEKaE_4`9_4P=_4`04KaA_5FlEKaD3Ka@00flCKaA_4`04Ka<00flDLaA_5002Ka@2KaD2Ka@0
16lCKaA_56lD0g<C0VlC0VlD00=_4g<CKc@01Fld00=_=FldKa@00VlD0fld0VlD00=_=G<cKcD00fle
16lf0fle16lf00=c=FleKc@00fle0Vlf00=c=FleKcD01Fle0W<e00Ic=6leKcI_=W<eLcH2LcD01W<d
KcE_=FleLcE_=@Ec=@04KcIc=VlfLcD3KcD01VlfKcE_=FlfKcEc=@A_=@0FLcA_=6lcJ_5V[EX7EPUR
S6[aLeAc=6leLcA_=G<dKcEc=6leLcAc=FleKcH3LcD01VlfKcE_5FlEKaAc50=_50=_4`03KaA_=6ld
009_=09_<`=_=004KcE_=6ldKc@2KcD3KaD2Ka@:Kc@4La<4Ka@00g<BL_5c4@02Ka@016ldLc=_=6ld
1flD0flC00M_56lCKa=_4fkcJ_=^lP02Ka83Ka<00fkbKa=_4`03Ka<2K_801VkcK_9ZlV[bK_=^lP9Z
l`03J_AZlf[c009Zl`AZlP06K_9ZlVkcJ_=ZlV[c0V[b0V[a16[b2f[a1F[b0V[c00EZlV[BJ_9ZlV[a
009Zd@9Zl@08J]5ZlF[aJ_5ZlVKbJ_9Zd@MZdPYVdP06I]5VdVKBI]9VdFKB16KA1FK@1FKA0VK@00AV
/6JaI[5V/@=Vd@03I[5V/6J`009V/003H[1R/F:a00AR/A1R/0ERT003H[1NT5j@00UNT0=NS`03HXmR
SUj?00ANSP03HXeNSUj?009NS`9NSP=NKP03GXaNSEj>00ANK`=JK`AJKP03GViJKUY^00QJKP03FVeJ
CEY]00=JK@03FVaJC5Y<00EJB`03FTYJBeY;00=JB`04FTaJCEI<FT`4ET`015H[ETaFC5I<0U9<1E8/
0e9<0UH/00AB;5H[ER]F:P=F:`05ERYF:eH/ER]F:P03DR/01U8ZDR]B:e8[DRY>2`=B2P04CP]B:dh[
CP/6CP`;CP/00dh:CPUB2001CN/0008880H<@@@8@@033448@@PQ00D88@0324488@PQ00888@04244<
@Pa1344224803@PR104000a19>DeRTibF[5JL5YaGW5NL5Y`009JK`04GVmJKei`FW03GW001UiaGY1N
T5j@HY1RS`9NT09NT@04GY9NTEjAHXl2HY04GY401EjaGY5NTF:aH[8016:a00=R/6:aH[400f:a0V:b
0f:a1F:b00=R/FJaI[4016Ja00AVdVKAI[5V/@9V/P9R/P9VdP04H[=V/fJcI]82I]<2I]82I[85I]82
I[400fKAI]9VdP06I]83I]<016[CJ]9ZdV[B1fKB00EVlf[bI]9ZdV[c009ZlP0;J_5VdVJaHVmNKf9_
I[5VdV[AJ]9ZlP0;J_<4J_82K_800f[bJ_=Zl`04J_<6K_<00f[dK_=^l`03K_<016kdKa=_4flC1FlD
1FlC00=_56lEKaD00VlE0VlD00=_4flDKa<016lC00=_57<DKaD01FlE1FlD0flC0VlD0VlC00A_56lC
KaA_50E_=0E_509_=004KaAc57<DLa@2KaD2KcD4KcH3KcD4KcH00g<eKcE_=00?KcD00g<dKcI_=P03
KcH01g<fLcE_=FlfKcE_=Vle00Ac=@9c=P=_=P03LcIc=Fle00E_=@04KcA_=G<dKcD2Lc@02gLbLeA_
=6/BI]1J:E89GVeZl7<dKc@00Vle00=c=G<dLc@00W<d1Fle00Ec=FleKcI_=FlE009_5003KaE_56lD
00=_5003Ka=_=6ld009_=003KcE_=6ld00=_=0=_=@05KcA_=FleKcI_=@03Ka@3Kc@2Ka@5Kc@01W<C
Ka=_4g<CKaA_5@9_5003La=c4W<C009_50A_=09c50E_5003Ka=_56lD00I_50E_4`9^l`E_4`9^lP06
K_=_4flCK_=ZlflC1V[c16[b00=ZlfkcJ_<00V[c00=ZlV[cJ_802F[b2F[a0V[b00=Zlf[bJ_8016[b
00IZdV[bJ_5^lF[AJ_42J]400f[aJ_9ZlP03I_800fKAJ]9ZdP05J]8<I]800fKAI]9VdP02I]85I]40
0fK@I]5Vd@05I]42I]06I]44I[400f:aI[1R/002H[05H[45H[03H[48H[04HY000ej@G[1R/002GY00
0f:`HXmNT004GY0:GXl3GXh00ej@GXmNK`02GVl00ei^GXiNS@02GXh2GVl2GXl3FVl7FVh00eY_FViJ
KP04FVh3FTd3FVd2FV`2FT`3FT/7FT`00eY;FTaJC@02ET`5FR/00eH[ETaF;003DT`3DR`2DT`00e9=
DReFC@04ER/015HZER]F:eH[0UXZ0UH[0e8[0U8Z00=B:dh[CR/00Th;0U8;00=B:dh[CP/014h<1dh;
0Th:1Th;00=>2TgYCNP00Dg[000222000`PQ2448@@033445244422400`PP34088@02344232422443
34402``Q328<@`PR100@@2SU=HY:DEZ?FVl00UYa0eY`00ANKei^GVmNK`ANL004GY5NT5j@GY02HXl2
GXl2GY03GY400f:?HY1NT004GY400ejaGY5R/@05H[42HY0016:aH[1R/6:`0f:a0f:`0f:a0V:b00=R
/FJaI[000VJ`0VJa0fKA0VJa00IV/V:bH[9R/VJbI]82I[800fKBI]=VdP03I]800fJaI]9VdP02I]83
I[400fKAI]9VdP03I]800fKAI]9VdP02I]<01VKBJ]=ZdV[AI]9Zd@AZdP=VdP=ZlP03J_=ZlV[b009Z
lP0;I]5V/F9`GVmRTFKAJ]1ZdF[BJ_=ZlP09J_<4J_800fkbJ_9^l`06J_<5K_<00fkbK_=^l`05K_<=
Ka<2Ka@3KaD00flDKa=_4`06Ka<4Ka@3KaD2Ka@7Ka<01VlDKa=^lflCKaA_4`M_500;Ka=_56lDKa=_
56ldLc=_=7<CLaA_5002KaD016lDLc=_=Fle0Vlf1fle00=c=FleKc@01Fle00=c<fldKc@01Fle0Vld
00=_=FlfKcH00flf00Ac=FleKcE_=P=_=@=c=@03KcE_=W<f00E_=PA_=@=_=0=_=@0?LcAc<gMCMeEc
E6lCJ_1NKEH/FT]VcVlCKcA_=Fld009_=@03LcA_=Fle00A_=@05KcA_=FleKcI_=@02KaD02FlDKaE_
56lCKaAc56lDKa=_5006Kc@2Kc<7Kc@00fleKaA_5003Ka@2Kc@7Ka@4Ka<2Ka@016lCKaAc57<C0flD
0fld16lD0flC00=_56lCKa@00VlD0VlE00=_56lCKa<00flC00A_4VlCK_=^l`E_4`9^lP04Ka9^lVkb
K_82Ka83J_83J_<2J_87J_<00f[bJ_=ZlP05J_800f[aJ_9Zl@0<J_400f[bJ]5ZdP02J]8016[bJ_=Z
lf[b1f[a0V[A00=ZdV[AI_400f[A16[B36KB0fKA0fKB1fKA00=Vd6KAI]400fKA00=V/6K@I]001VKA
00EV/F:aH[5R/F:`00=R[`04H[1V/6:aH[43H[0016:_H[1R/6:a0V:`00=RT6:`H[0016:`1F:?00AR
T6:`H[1NT09R/004HXmNT5j@GY02GXl00ej>GXmNS`04GXl3GXh2GXd00ej>GXmNS`03GVl00ej>GViN
S@02GVd00eY^GVmNK`03GVl015Y^GViJKUi^0UY^0UY>00MJKeY^FViJKUY=FVeJKP06FTd015Y/FTaJ
C5Y<1EY;0UY=00QFC5I;FTaJBeI<ET]FC5Y<15X[0eH[00=F;59<DT`01E9<00EBBeI<ERaF;5H[009B
;003ER]F:U8[009B;0=F:`03EPYB:e8[009B:`06DRYB:e8ZDPYB:Th[0U8;0dh;00=>34h[CR/00Th;
0Th:2Th;0Th:00=B2Th:CPT00Dg/00000`Q022088@022442344336800`a124488@06224324443440
1@aR348<@@`Q34800Q1S00L<@@a08:@eJDY@FXmJL003FW4015ZAGW1NKei^0Ui_00ENT5iaGW1NL5ia
00ANT0=NS`9NT0=NT@05GY1NTEj@GY5NT003GY43G[4015jbG[5N/F:a0V:@00ARTF:aH[5R/0=R/@=R
/0AR/@03H[9R/FJb00UV/@03I[9R/V:b009R/P03I[9VdV:c00=Vd`IVdP=V/P04I[5VdFKAI]46I]80
16KCI]9VdVKB0fKC0VKB00EZdF[BJ]9ZdVKB009ZlP=Vl`9Zl`0;J_9Zlf[cJ_9^lVKAIY1NCUi`I[9Z
l@02J]800f[cJ_9Zl`07J_<00f[CJ_9Zl`03J_83J_<2K_<3J_<6K_<00f[cK_=Zm004K_<00fkbKa=_
4`02Ka@2K_@00fkcKa=_4`03Ka<2Ka@5KaD2Ka@5Ka<2Ka@00flEKaA_5@04KaD3Ka@01FlCLa=_56lD
La@00flE2VlD0VlE00=_=FlDKa@00fld1FlD00=_=6lDKcD01Fle0Vlf1fle17<d00=_56leKcD016le
00=_=7<dLc@02Flf0Vle00=c=7<eLcD00W<e1flf2Fle00m_=VleLcAc=7=ELcA_=F/BI[5J;E88IZiZ
lVleLeL036le00=_=W<fLcD00flE0VlD00A_4flELaE_=@9_5@=_5003KcE_=6le00A_=@06KcA_56ld
KcE_=6lE1FlD00M_=FldKcE_=6lDKcA_=@0>Ka@01FldKcE_=6lDKa<00flD0flC0VlD00E_5FlDKaA_
56/D009_4`04KaA_=6lCKa<3K_<00fkdKa=_5004Ka<01VlBK_=^lfkbK_=[4`9Zl`03J_9Zlf[b00QZ
l`03J_AZlf[c009Zl`=ZlP=Zl`mZlP9ZdP04J]=ZdV[bJ_<3I_<4J_800f[aI_9ZdP02J]4016KAJ]9V
lV[A1f[B3VKB0fKA1FKB2VKA0VK@00AVdFKBI[5V/@IR/@=R/003H[5R/6:`00MR/003H[5R/6:a00=R
/@=R/0=RS`06GY1RT6:?HXmNT6:_1ej@35j?0ej>0ej?0Uj>0Uj=00=NKEi^GVh01eY^00=NKUY^GVh0
0eY^00=JCUY^FVl00UY^0UY=0UY]00=FCEY=FTd00UY=0UY<0UY=00=JC5Y]FT`00UY<00YJCEI<ETaF
C5Y=FVaFKEY/FTeJC09J:`9F:`04ETaF:eH[ER`3DT`00e8/DTaBC003DT`4DR`00eH[DR]B:`05DR`2
ER/6DR/3DRX00dh[CP]>2`08CP/5CPX9CP/00dh:CPU>2@01CP`00003240880PQ0088@@P<@@<88@04
24488@PQ220422422444224234403a1P440@@1bS=DQ:D5Z?FY1JLEY`GW5JTEi`GVmNKP02GVl3GW00
0eiaGW1NK`03GY000ej?GY1NS`04GY02GY43GY02GXl00ej@GY5NT@02GY4016:aGY5NTF:@1F:a2F:`
0f:a00=V/F:aI[4016Ja0f:a00=VdFJbI]800fKB00EVdF:bI]=VdVJb009VdP04I[9VdFKAI]43I]80
0fJbI[5Vd006I]42I]800fKCI]9VdP04I]<2I]82J]49J]800f[CJ_=Zd`02J_801f[aJ]5Vcei^FU1R
/FJa009Zd@04J]9Zdf[CJ]<5J_<6J_87K_<016[cJ_9Zlf[c2fkc00=^lVkcKa<00VlD0Vkd16lC3FlD
00A_4flDKaA_5@9_509_5@e_509_5@03KaA_4flD00Y_5@I_50Ic4`03KcA_=Fld009_=0=_=@04LcE_
=FldLc@3Kc@3KcD00fldKcE_=@05KcD3Lc@2KcD5KcH016leKcI_=Vlf1g<e00=_=VleKcD03Fle00e_
=7<dLeEcE6ldJa=VdEX]ENQRJf[@LcEgM`03KcD3Lc@3KcD2LcD00fleLcE_=@02KaD01VlDKaE_56lD
Ka=_50I_5@9_5004KcA_=FlEKaD2KcD7Kc@5Ka@01VldKaA_56lDKcA_=@9_5003Ka=_=6lD00E_5003
Ka=_56lC009_4`9_509_4`=_50=_4`03KaA_5FlE009_50U_4`E_5003Ka=^lfkc009_4`A^l`03J_AZ
lf[c00=^lP=Zl`=ZlP9Zl`04J_AZlf[cJ_8:J_<00f[bJ_=Zl`04J_<2J_82J_<016[bJ]=Zdf[c0V[b
00AZlfKcI_=Vl`9Zl`9ZlP07J_5VlV[bJ]5ZdV[bJ]401f[B00=ZlVKBI]800fKB1FKA0fKB1VKA16KB
1FKA00AV/FKAI]1Vd@=Vd09Vd@03I[5R/F:a00QR/@9R/003I[1R/6:`009R/0AR[`03H[1R/F:a009R
/@04H[1RSf:?HXh2HXl2HY002f:?HXiRSf:>HXmNSej@GY5NT5j?GY0045j?0Uj>0Ui]0Uj=00ANKEi^
GViJKPENKP03FViNKUY^00=JKP04FVmJKUY^FVl2FVd01EY=FVeJKUY]ETd00eY=00=JC5Y;FT`00UY=
0UY]00=JCEY<FT`02EY<00AJBeX[FR]J:`=FC004ER]F;59<DT`2DR`4DT`3DR`2ER/2ERX015H[DRaB
;58/2E8[00I>:e8ZDRYB:U8[DP/9CP/7CPX6CP/014h:DPU>2Dh80Dh;0007244334400`aQ344<@002
24400`PQ244<@@0234400`Q0224<@@03244010PQ2448@@@Q0PPP0P`P00P@822S=DI:;UY^FY5JL5i`
0UYa00ENL5j?GViNKUi_00ANL004GW5NT5j@GY42GY000ej`GY1NT004GY400ej@GW1NL004GY02GY43
HY45HY09H[400fJ`I[5R/@05H[43I[42H[42I[42I]42I]83I]<01VKBI]=V/fJbI[5VdP9V/P=Vd@05
I]9V/VJbI[9VdP05I]45I]86I]<2I]800f[AJ]9Zd@08J]82J]<3J_<3J_401V:@GU1NL6JaI]9Zd@=Z
d`9Zl`UZlP03J_=^lfkc00=^l`03K_A^lf[c00EZl`Y^l`A^m09^l`A_4`03KaA^m6lD00Y_5006Ka=_
56kdKaEc56lE0VlD00=_4flDKa@02FlD00Ic4g<DLaAc56lCKa@<KaD4Ka@00flCLa=c4P02La<00g<D
KcA_=@03Kc@017<eKcE_=G<e0Vle00Ac=FldKcA_=0M_=@04KcA_=FleKcD2Lc@00g<eKcE_=@05KcH0
16leKcI_=Vlf0fle00E_=W<eLcEc=Flf00=_=@9c=@M_=@9_=P=_=@06LeEgEFmFJaAVlei^0UhZ00=V
[f[cKeL00fle0g<d00=_=G<dLc@00W<e00Y_=VleKcE_=FlEKaA_5FlDKaE_50M_5@9_5005KcA_56lD
KaA_5@03KcD2Kc@00flDKcA_4`03Ka@2KaD2Ka@016lCKcA_=6le0VlD00=_4flDKa@01fld00Ac4flC
Ka=_4`9_5003Ka=_56lD00A_4`03KaA_5FlE009_50U_4`E_5003Ka=^lfkc009_4`A^l`=Zl`=^lP=Z
l`03J_9Zlf[b00EZl`03J_9Zlf[b00EZl`03J_9Zlf[c00UZl`05J_9Zlf[bJ]=ZdP04J_87I_<016Kb
I]9VdVKc0VKb00=ZdV[bJ]4016[B0VKB00=Vlf[dJ_@00VKC16KB00AVdF;AI]9RdPEVd@EVdPYVd@04
I]1VdFKAI[4<H[43H[000fJ`H[1R/002H[000f:_H[1R/003H[401f:@H[1RSf:>HXmRT6:?009RT0=R
S`0:HXiRSej@GY1NTEj@GXmNT5j?GY0;GXl2GXh3GXl2GXh00ej=GVeNK002GVd00eY^GViNKP03GVh6
FVh00eY_FViJKP05FVh015Y_ETiFCUI>0UY>00=JCEY;FV`00UY]0UY=1EY<00=FC5Y<FTd00eY;00=J
C5X[FT/00UX[00YF:eH/ETaF;EH/DReB;59<DT]BC09B;@9BC09B;005DR]F:eHZERYF:`07DR`0158[
DRaB;58/0Th[0e8Z0U8;2Dh;1dh:1dh;00=>2Th9DPT00Dh<0004244422400``P324<@00334022243
34400`Q13408800334400`PQ3408@@02244030`Q220880@0300HPSDUBPeFKUZ?FVmJL09JL@05FW1N
Kei^GViNK`05GW04GY001Ej?GY1NT5j@GY400ej@15i`0Ui_0ej?00ANT6:@HY1NT0ART0UR/@03I[1V
/FJa00AR/@04H[1V/FJ`I[05H[42I[4016KAI]9VdfKB0V:b0VJb00=V/FKBI]4016KA00EV/FJbI[9V
/VJa00EVd@=VdP03I]5VdVKB00=Vd`9VdPAVd@03J]5VdV[B00UZdP9ZlP0?K_9ZlF[aI]5RTEi`HY1V
/FK@J]9Zlf[dK_AZlfkc00EZlP04K_=^lVkaJ_85K_<9J_<00f[bK_=^l`05K_<00fkbK_=^l`02K_@0
0fkcKa=^l`04K_<01FkdKaA_56lDKa<01flD0VlC16kc00E_56lCKa=_56lC00A_509_4`9_5003Ka=c
4VlC00=c4`A_50=_5@03KaA_5FlE00=_5@04KaA_=6lCKa@2Ka<01W<CKaA_56lDKcA_=@=_=004LaAc
5G<eLc@3KcD5Kc@5KcD016ldKcE_=Fle0W<d0fle1Flf1Vle00=c=6leLcD00W<e1Fle00=c=FleLcD0
0fle00=_=6leKcD016le00]c=7]DLeI[=F[dI[1NBf9;IXeZlF/E00E_=@Ac=003LcE_=Flf00A_=A9_
5003KaE_=Fle00=_=0I_509_5@9_5003Ka=_=6lC009_509_4`M_50m_4`E_50U_4`A_5006K_=_4Vkb
K_9_4flB1Fkc0V[b0fkb0f[c2F[b00=Zlf[bJ_800V[c0V[b00=ZlF[cJ_<00V[c00EZlV[cJ_=ZlV[c
00EZlP06J]9ZdF[BJ_9ZdV[b1VKc1FKB00=ZdV[bJ_400V[a00AZdF[BI]9ZdPIVdP=Vd`9VdP=Vd@03
I]9VdFKA00=Vd@9VdPIVd@=V/@AVd@=V/0AR/@=R/004I[1R/F:aH[42H[02HZl6H[02HZl02F:`HY1R
T6:@H[1R[f:^HZmRS`02HY03HXl3HXh2HXl3GXl00ej>GXmNSP0;GXl015j>GViNSUj?0Uj>0Ui]1Ei/
00ANKUi]GVeNK@9NKPUJKP03FVeJCEY]009JK@04FTiFCUI>FVh2FTh00eY]FT]JC003FTd3FT`2FT/0
25Y<ETaJC5Y;FTYJBeI:ET`3FR/02eH[ERYFC5I<ETeF;58]DTaBBeI;ET`00UH/158/0U8[0UHZ00EF
Be9;DRaB;58[00=B;004DR]>;58/CR`2DR/3DRX2DPX00dh;CPY>2`05CP/:CPX5CP/00dh:CPU>2@01
CN`000@8@@D88@8<8@03320<@0a000888@8<8@L<@@05244<@@QR36<<HP02344030`P100801AR=BI:
3EY=FViJKeYaFW9JL@9JL004FViJKeY_FW05GVl6GY03GY44GY001Ej?GY1NL5i`GVl00Uj?00ENT6:@
HY1RT5j@00=RT0IR/@=R/PMR/@=V/@03I[1R/F:a00AR/@04I[9VdV;CI]83H[8016:aI[9V/VKB1FKA
00EV/FJbI[9V/VKB00=Vd@EVdP03I]5VdVKB00=Vd`9VdP=Vd@AVdPAZdP03J]=ZdV[C00=ZdP0=K_9Z
dV[bJ_9ZlfKBGW1NCei`I[5VdV[CJ_@00V[c00=ZlV[cK_<00V[b00EZlf[bK_=^lV[c009^l`03K_9^
lfkb00]Zl`E^l`04K_A^lfkcK_<2K_@4K_<4K_@:Ka@4Ka<01VkdK_=^lfkcKaA_4`9_5003KaE_56lD
00I_509c4`04LaA_56lCKa<3Ka@3KaD00flDKaE_5@04KaD00fldKc=_5003Ka@2KaD4KcD016lEKaA_
5FlE0W<e00=_=FlEKaD016le00=_=6leKcD01Vle0g<e00=_=FlfKcH016lg0flf16le1G<e0fle0g<e
0Vlf0fle00=_=6leKcD00Vle00a_5FldLcAc=7=FKcE[4f[@IVeRC69/J]02Kc@6KcD01G<eMcA_=Fle
KcH016le1flD00A_5FlDKaA_4`M_5003KaE_=Fle00=_=@9_=0A_509_5@A_5003Ka=_56lD00M_515_
4`=_5003Ka=_56[c00A_4`I_509_5@05K_A^lfkbK_9_4P02J_<2K_<016kbK_=^lVkc0fkb0f[c0f[b
00AZlf[bJ_9ZlP=Zl`9ZlP9Zl`=ZlPAZl`9ZlP=Zl`IZlP05J]9VdV[BJ]9ZlP07I_<00f[BI]9ZdP02
J]8016[bJ]9VlVKb0VKB0V[B0VKB00=VdfKBI]<016KC0VKB0fKA0VKB00ERdfKBI]9VdVKC009VdP03
I]5VdVJa00EV/@AVd@=V/@9Rd@ER/@04H[1R/F:aH[47H[02H[400f:`HZmR/002HZl3HXl01f:_HZiR
[f:_H[1NT5j?009RS`=RSP03HXmRSUj>009NS`03GXiNSej?00mNS`=NKP04GVeNK5i/GV`7GVd:FVh5
FVd015Y>ETiFCUI>0UY>00=JCEY;FT`00UY=15Y<0UY;0eY<00=FC5I;ET/00eI;1UI<00=BCE8]DRd0
0U9<00AF:e8/ERaF;0AB;0=B:`03ERYF:e8/009B;004DR]B;58/DR`3CR`00e8/DR]B:`02DR/00e8;
CP]>2`09CP/3CPX00dh;CPY>2`08CP/3CPX1CNd00088@P0324488@PQ00D88@03324<80`P00<8808<
8@043208@@`Q32443442244534401@`Q204DHSDUBP`00UY]00=NT5jAFW800UYa00=JKei^FVh01Ei^
00AJKei^GVmNS`=NT0ANT@9NT0ANS`0<GY1NL5i`GXmRSV:?GY1RT6:?HY1R/F:@1F:`2f:a0f:`0VJ`
00=R/6:aH[400V:a0V:b0fKB00=R/V:aI[800VJa0VKA0VJa0fKA16Jb00AVdVKAI]5Vd@EVdP03I]5V
dVKB00]VdPMZdP03J]=ZdV[B00=ZdP0;J_=Zm6lEJ_9RTEY@HW1V/6JaI]9Zd`03J_801F[cK_=^lV[b
J_<00V[b0V[c0V[b0fkb0V[b0f[c0Vkc16[c1Fkc00=^m6kcK_@026kc0Vkd2FlD00=^m6lDKa<016lC
0Vkc4VlD0flC1VlD1VlE00E_56lCKc=_=6le00=_5@03KcI_5FlE009_5@03KaA_5FlE009_5@03KcI_
=Fle00A_=@03KcA_=Fle00=_=@9_=005LcAc=FleKcIc=@02KcH4KcL00flfKcE_=@03Lc@3LcD00g<d
LcEc=@09LcD017<dKcEc<fld0fle0fld00]c<gMEKc=_4Vk`IZiNBehZJ/m_4fld00I_=@03LcE_=Fle
00=_=@03KaE_=Fle00M_4`05KaA_4flCKa=_5002Ka<00g<DKaA_5002Ka@2KaD3KcD00fldKaA_5005
Ka@01FlCKaA_56lCKa8016lC16lD5flC0Vkc0VlC16lD00A_4flDKaAZm09^m09^l`9_4P05Ka=Zlf[c
J_=ZlP03J_<00fkcJ_9^lP0=J_8016[aJ_9ZlV[c0f[b00=Zlf[bJ_801F[b00=Zlf[bJ_800f[b00=Z
dV[CJ]<00f[b1FKc00=ZlV[BJ_4016[B2VKB00=VdfKBI]<00fKC00AVdVKAI]5Vd@AVdP04H]=VdfKC
I]<3I]82I[86I[47I]42I[48H[4;H[04HZl00f:^HZmR[`03HZl016:^HZmRSf:?0V:>0f:^16:>0Uj>
35j?00ENKej?GXmNSei_00=NKP]NK@UJKPAJK@03FTeJKEY]009JK@AJC@04FT]JK5Y]FTd7FT`3ET`0
0eY;ET]FBP02ETX00eI;ETaFC005ET`3DT`0158[DRaF:eH/158/0e8[0UHZ158[0e8/0dh/00=B;58[
DR/00U8[00=B2dh;DPX0158:4dh;0dh:0Dg]000224801@a2248<@@a132400`a10P`Q0`PQ0PPP00<<
8@a134400P`P00@<@@Q12448@@L<@@0D34880AAR<@A5jeY/GXiN[eZAFW5JLUY`GW1NKUY^GViNKei^
FVmNK`=JK`03GXmNT5j@009NT0=NT@ANT003GXmNT5i`009NL006GY1RSej?GY1RT6:?0V:@00IR/F:`
H[1R/6:aH[04H[45H[82H[45H[06H[45H[8016:aI[9V/FJa0VKA0VJa0fKA00EV/VKBI]=V/VKB00=V
d@EVdP03I]5VdVKB009VdP9Vd`QVdP04J]=ZdV[BJ]83J]<00f[BJ]=ZdP02J]802F[cJ_A_5FkcI]9N
Kf9`HY1RT@02I]84J_<2K_<3J_85J_<016kcK_9^lV[b1F[c0Vkc00=^m6[cJ_@00V[c0fkc00A^m6kc
J_A^l`=^m0A^l`03KaA_5Fkd00I_509^m0=_5003Ka=_56lC009_4`9^m0Q_5003KaE_56lE00I_509_
4`U_50=_5@03KaA_4flc009_=005KcEc=G<fLcI_=P04KaD00flDKaE_5002KaD7KcD00fldKcE_=@02
KcD2KaD4KcD2LcD01G<fLcEc=VlfKcL00Vlf00=_=G<eLc@00W<d00A_=G<eLcEc=0=c=@A_=PAc=@03
McEc=G<d00E_=@9_=00<LcAgE7]BLc9_4F[>GRYN26J>J_5c=7=F36le00=_5FlDKa<01VlC0flD00E_
4flDKa=_4g<C00U_509_=0=_509_5@E_50E_4`E_50=_4`03KaA_4flC00=_4`=_50Y_4`9^l`03Ka=_
56lC00=_50=_4`=_5004J_=_4flBKa87J_<3J_@2J_<00f[bJ_=Zl`02J_<6J_82J_42J_800f[cJ_9Z
lP03J_<00f[bJ]5ZdP03J_800f[cJ_9ZdP03J_800f[BJ]=Vl`02I_<3J_83I_<01FKBJ]9ZlF[BJ]40
0V[B2VKB0fKC00AVdVKCI]=Vd`iVdP03I[5V/VJa00EV/@MVd@04I[5V/6J`I[46H[49H[02H[42H[03
HZl5H[0016:_H[1RSf:?0V:>00AR[Uj>GXiR[P=RSP03HZiNSUj?00]NS`9JK`03FXmNSUj?00ANKP=N
K@03FViNKUi^00ANK@03FVeJKUY^00EJKPIJK@04FTeJKEY/FVd3FTd00eY>FTeJC@02FTd3FT`2FTd5
ET`00eY<ETaFB`02ET/2ET`3ETd4ET`2DT`0158[DRaF:eH/158/158[15HZ00EB:e8/DRaB;4h/00EB
;09>:`9>2`03DPYB:U8:009>2Q=>2`9>2P59jP5=k00000L8@Pa2348<@Pa1220<@0033443324010PQ
200800`P0Pa100H8@0a0320<@@Q1344322403P`Q2448@@Q1320880P0544a0dG9FV]N[5j=FW02FW40
0eY`GVmNKP05GVh01Ei]GViJKeY_GXl02ej@00=NSej@GY000ej@0Uj?00ARSej?HXmRS`9RT0=R/003
H[5R/6:a00=R/@9RTP=R/P9R/@IR/0IR/@=R/P=R/@IV/@03I]5V/FKA009Vd@04I[5VdVJaI[42I]45
I]800fKAI]9Vd@06I]82J]84I]801F[CJ]9ZdV[BJ]<00VKB1F[B00eZdf[cJ_=_4V[AI[1NKUi_HY1V
/FKBJ_=_5003K_<00fkbJ_9ZlP06J_<2J_800f[BJ_9ZlP05J_<2K_<4J_<7K_<3K_@4K_<00fkdKaA^
m005Ka@4K_@8Ka<00fkcK_A_5007Ka@2KaD6Ka@3Ka<00flDKa=_4`05Ka<4Ka@01VlBLa5c<fldLcA_
=0M_5@9_50E_=09_=@03KaE_=Fle00E_=003KaA_5Fle00=_=@06LcE_=W<fLcE_=W<e0flf00=_=G<e
Lc@00W<d0fle00=c=6leKcD02Flf0Vle00=_=6leLcD00Vle015_=6lcJ_9_<g<bNe1g<FlAJ/mRJeX6
HV]Zcg<cLgI_=6/D009_=@03KcA_=Fle00=_=@04LcE_=FlDKa@9Ka<00flDKa=_4`06Ka<4Ka@3Kc@2
Ka@4KaD4Ka@00flCKa9_4`02Ka800flCKaA_5003Ka@6Ka<00flBKa=_4`03Ka@:Ka<2J_801VlBKa=_
4flCKaA[4`9_4`03J_=_4flD00=_4`03Ka9ZlV[c00AZl`03Ja=[56/D009Zm09Zl`03J_9Zlf[c00=Z
lP04J_5ZlV[bJ_83J_45J_83J_<00f[BJ]5ZdP02J]4016[bJ]9ZlV[B0V[a0V[A00AZdV[bJ_=ZlP9Z
l@=ZlP9VdP03J]5Zl6[a009Zd@04J]9VdV[bI_89I]800fKAI]9Vd`02I]<4I]89I]400fKBI[1V/@02
I[400fJ`I[5V/@03I[44I]400fJaI[1V/002I[06H[4:H[02H[402EjaH[1R[ej?HZmNSej`H[1N/@02
H[02HXh00f:=HXiNSP02GXh00f:^HXiRS@02HXh00ej>GXmNS`02GXh015j?GXiNSUj>0ej?00ENSUi_
GVmNSej=00INK@03GVaNKEi^009NKP=NK@9NK003FVaJKUY^009JKP03FVeJK5Y<009JC@9JK@9JC@03
FTaJBeY;009JC09JC@9FC@9FC0=JC003FTeJC5I<00IFC0EFB`MFC003ERaB:eHZ00AF:`9B;005DR]F
:U8[DRYB:`05ERX2DR/00dh[DR]B:`03DR/3CR/2CP/2DPX3CPX5CP/00dh:CP]>2`04CP/00dX;CP]>
2`02BP/2CP/00dh:DPY=jP01CN`000@<@P8<@@06340<@@a1344@@A0P0P`Q00H<80`Q340<HQ1S3683
34401@Q134488@PQ32400`Q100l88@PP10080110<>91QUY:GZaNSEi_FW1JLEY`GW001Ui_00=RT5i_
GW003Uj@0ejA0Uj@0ej?0Uj@0V:?00ART6:`H[5R/0IR/@ER/PeR/@AR/PAR/@08I[9V/FJaI[5VdVJa
I[9V/@9Vd@EV/@03I[9VdVKB009VdP04I]=VdVKBI]43I]800fKCI]9VdP02I]85I]<3I]84I]<3J]<0
26[BJ]=Zdf[bK_9ZdFKAHY02GW001FJaI]=Zlf[cJ_400fkc0f[b1F[c1F[b1F[c0Vkc1V[c0Vkc0V[b
0Vkc16kd0V[d00I_56lEKaA^m6kcK_@3Ka@2K_@00flDKa=_5002Ka@00flCK_=^l`02K_@<Ka@00flE
KaA_5008Ka@4Ka<4Ka@2Ka<01W<CKcA_=6lEKaA_5@9_5PA_5@9_50=_=0A_=@03KaE_=Fle00E_=@03
LcEc=6le00E_=@9c=@M_=P03KcEc=G<d00Q_=@E_=PY_=@05KcA_56ldLc=kD002Lc802Fk`JZiJ25X:
IXe[4G=FKcAc=002KcD00fldKcE_=@07KcD016lDKaE_56lD0flC00=_56lCKa@02FlC0VlD0fld0VlD
00=_=6leKaD01VlD00=_4flBKa800VlB0flC0flD2FlC0flD1VlC0VlD00A_4flDKaA_509_4`=[4`04
JaA[4flCJ_<3Ka<016lBKa=_4flB1F[c16[d0f[c00=ZlV[cJ_800f[c00=ZlF[bJ_801f[b1V[c0V[b
00=ZlF[BJ]800V[B00AZlf[bJ]9Zl@9ZdP05I]9ZlV[bJ_9Zl@02J_801VKAI]9VdVKAJ]5Zl@9Zd@03
J]9VdVKB00QVdP9Vl`MVdP03I]5VdVKA00UVd@=V/0IV/@05I[1V/FKAI]9Vd@03I[000f:`H[5R/@06
H[4016:`H[5R/Eja0V:a0f:`1F:a0f:`0eja00IR/5j@HXmRSf:>HXl3GXl01Uj>HXeRSF:=HXiNSP9N
S`9NSP9NS`9NSP=NS`06GXiNKei_GVmNKEY^0ei^00ANSUi]GVaNKPAJKP=NK@03GVaJK5Y^009JKP04
FXmJKUY^FVd2FTd01UY]FTeJKEY=FTaJJ`=JC09JC@04ETaFCEI<ET`3FT`3FTd8ET`01EI;ETaFC5I=
ET`00UH/00IFC5I;ETaFC5H[ERX3ER/01E8[DRaB:e8[ER/0158[0eH[00=B:e8/DR/0158[1Dh[2dh;
00=>:dh;CP/01Th;0TX;00A>2dX;CP]>2`9B2P5=j@5=j`000Pa100D<@Pa134488@PP00H<8007340@
@11Q468<H@a124400PPQ00D<@@Q134488@`Q00@8@@<8800:300@82RR?FAFBUj[GXiNKUi_FW0;GW09
GY000ejAGY1NT005GY42GY0016:?GXmRSej@0V:?0V:@0f:`2V:a0V:A00=R/F:AHY400V:a0V:b0V:a
00=V/6:aH[800f:b00=R/FJaI[400V:a00=R/VJbI[800VKB00=V/FJbI]401FKA0fJa00=VdVKAI]40
16KB0fKA00=VdVKCI]<01fKC00EVdV[BJ]9ZdVKB00IZd`9ZdP=ZlP9Zd@0:I[9RLEi`HY5V/V[BJ]5Z
lF[bJ_<4J_85J_<5J_85J_<2K_<3J_<00f[bK_9ZlP06K_83K_<00fkdJ_AZm003Ka@5K_<016kdKa=_
4flC1FlD0Vkd1FlD00=c4flCKa<01VlD00=_5FlDKa@026lD0flC0flD1FlC0VlD0VlE00=_5VlEKaH0
0flE1VlD0fld00=_56ldKc@00fle0VlE00=_56leKc@01Fld1fle0flf1Vle00=c=7<eKcD00fle00=c
=FleKcD02fle0fld00ic<W]AMe9gDVk`J/iNBeGYGRYZl6ldLcA_=7<c0g<d0Vle00=_=6leKcD00W<e
00=_=FlEKaD00VlE16lD00=_4flDKa@01flC1VlD1fld1FlD00=_4flBKa800VlB4flC00=_4V[bKa<0
0VlD0flC0Vkc1FlC00E[4flCJa=ZlflC00A_4P04Ka=Zlf[bJ_82Ja<00f[cJ_AZm003J_<3J_800f[c
J_9Zl`02J_<00fkbJ_9ZlP07J_84J_<4J_800f[aJ_9Zl`03J_<2J_83J_42J]800f[bJ_5Zl@02J_40
16[AI]5VdFKA1F[A36KB0VKA0fKB0VKA00EVd6KAI]5VdFK@00=Vd@MVd09Vd@IV/@=V/0AV/@]R/@03
G[5R/F:a00ER/0=R/@9R/006HY1R/6:`G[1R/5j@16:?00INSej@H[1NSf:>HXd2HXh00f:=GXiNS`04
GXl3GXh2GXl00ej>GViNKP07GVh2GV`01Ei^FViJKUY^GVh00Ui]00ANK5i[FVaJK@EJKPMJK@03FTaJ
JUY;00=JB`9FB`=FC0=JC0=FC003FTaFC5I<00YFC007EReFCEH/ET]F:eI<ET/00eHZ0UH[1e8[00AB
:U8[ER]F:`MB:`9>:`04DR]>:dh[DR/ECP/014h:CP]>2dh:0Th90E870DgZ000020a2344<HQ2346<<
@Pa1324232000a10344<@@034682344020`Q22488@PQ3448@@a1224424402`a1224<80a1440@82BR
>FEFBej/HZh00Ui^00AJKeY`FW1JL09JL@MNT09NL003FW1JTEj@009NT0INT@03GY9NTEjA009NT@9N
T006HXmNT5j@HY1RSf:@0f:`2V:a0f:B0V:A00ER/F:bH[9R/V:a009V/@9R/@=R/P03H[5V/FJa009R
/@06H[9VdVKBI[9VdVJa0fKB1FKA0VJa00=VdVKAI]8016KB0fKA0VKB00=VdfKBI]<01FKC00IVdV[B
J]9ZdVKBI]<6J]<016[cJ_9Zlf[c0V[b00EVdUj@GTmNCf:A009VdP03J_9Zlf[c009ZlQ1Zl`=^l`AZ
l`03K_=Zlfkb00A^lP9^l`=^m09Zm09_50M^l`A_4`A_509^m003J_A^m6lD00=_509_4`A_5003KaE_
56lE00Y_5004Ka=_56lDKa@3Ka<00flDKa=c4`02Ka<016lDKaE_5FlF1FlE2VlD0Vld0VlD00E_=FlE
KaA_56lE00]_=@03KcI_=Flf00A_=PA_=@04LcEcEG<dLc@2KcD00flfKcE_=@04Lc@9KcD03FldLc=g
<WLcLc9_4V[`HZmF35H9I/m[4W<d009c<`=c=0M_=@03KcI_5FlE009_5@E_5008KaE_56lDKa=_56lC
La=_4`A_509_=09_50=_=0E_5004KcA_56lDKa<6Ka8016lCKaA_56lC2FlD00Q_4flDKa=_56lCKaA_
4flD16lC0Vkc00=_4VlCKa<00VlC0V/C00=[56[dKa<00VlC00AZlV[cJa=[4`9Zl`9[4`IZl`=ZlP05
J_=ZlV[cJ_9Zl`0:J_84J_<5J_83I_<016[bI]9ZdVKb16[b0V[B00AZlF[BJ]9Zd@9VdP9Vd@05I]1Z
dF[AJ]5Vd@04I]83J]84I]82I]45I]801fKAI]1VdFKAI]9VdFKB009Vd@MVd003I]5V/FJa009V/P=V
/@9V/11R/@05G[9R/F:aH[1V/003H[03G[45H[03G[03HXl3GY000ej?GY1RSP02HXh016:^GXiNSUj>
1Ej?00ENSUj?GXmNSej>009NKP04GXiNKUi^GVh2GVl015j>GVaNK5i^0eY^00INKUY^GVeNKEi/FVd8
FVh3FVd015I=FTeJKEY[0eY<00AJBeY<FTaJC@9FC09JC0EFC09F:`YFC008ETeFC5I<ET]F:eH/DT]F
B`9F:`=B;0MB:`03DRaB:eH[00YB:`9>:aE>2`9>2P9>2`9>2P5>2@5B1`5=jP000Pa100D<@Q1S58<@
P`aQ008<@@04320@HAB2468334800`a132488@0722432443344234002@`P300LPSUUDTaN[5j=GVaN
K@02FVl3FW000eYaFW1JK`02GY000ej?GY1JL003GW04GY000eiaGW1NL@03GY400ejBGY5NT@02GY42
GY0016:?GY1NT6:@0V:?00=RT6:`H[000V:a00=RTF:aH[401F:a0V:B00AR/V:aH[5R/@=R/P03H[5V
/FJ`00=R/@9R/P03I[9V/FJa00=R/@9R/P9V/P04I]5VdVKBI]89I]45I]83I]46I]82I]<00fKBI]=V
dP03J]82I]801FKCJ]=Zdf[CJ_<00V[C00]ZlV[cJ_=Zlf[bI_9V/6:?FTmRL6Ja00=VdP03J]9ZlV[b
009ZlPUZl`03J_9ZdV[b009Zl`=^l`AZl`03J_9Zlfkb00A^lPA^l`05K_AZm6[dK_=Zm008K_<016lB
Ka=_4flC0flD0Vkd00=Zm6kcK_<016kc00=_4flDKa@01FlD00=_4flDKa@016lD16lC0flD26lC0flD
1VlE3FlD00=c56leLa@00VlC00=_=6lEKcD05Vle0fld00E_=G<eKcE_=6le00Ec=005KcE_=6ldKcA_
=@02KaD2Kc@3Lc<026lCJa9VdUY>FPUR[F[bKc@2Lc<2Lc@00fleKcA_=@02KcD00g<dKcE_=005KaD0
0flCKaA_5005Ka@00flCKaA_4`03Ka<2Ka@3Kc@2Ka@00flCLa=c4`04Ka@00flCKcAc4`02Ka<3Ka80
16lAK_5_4FlC0VlD0flC1flD00=_4flDKa<026lC0fkb0VlB1FlC0V/D00QZm6lDJaA_56[dJa=[56/C
1F[c2V[b00A^lV[bJ_9ZlP9^lP05J_5ZlV[bJ_9Zl@07J_801F[aJ_9ZdV[BJ_800fKB00=VdFKbJ]80
0V[b00AZdV[AJ]5Zl@9ZdP9VdP03J]9VdFKA00=Zd@9Vd@=VdP=ZdP06I]9ZdFKAI]5VdVKA1VKB16KA
0VKB00=V/VKAI]401fK@0VJ`00=VdFJbI]800VKA00AV/FJ`I[1R/@9V/@03I[1R/6J`00ER/@03H[1R
/F:a00AR/@9R/09RS`9R/0=N/0ER/0=N/0=RS`=NT09NS`9NSP9RS@03GXiNSEj>00ENS`=NSP03GXmN
SUi^00=NSP9NKP9NK`04GXiNK5i/GVd3FVh2GVh2GVd00ei/FVeJK@05FVh00eY/FVeJK@02FVd015I=
FTeFCEY<15Y;00AFBeY;FTaJB`=JC09FC09FC@03ETYF:eH[00EFC09F:`AFC006ETYF:eH[DR]F:e8/
0eH[0e8/1e8[00=B;58[DR/01U8[00=B:U8[DR/01dh;00=>2Th;CP/01Dh;00=>2Th;CP/01dh;0dh:
0TgZ0Dh90E7W0DgZ00001PQ1344<@Pa2344<@P@<@@03468@P`a200<<@P03344880PQ00P88@88@@@<
@@0<220400P0568eADh/FXeNSEi]GVmJL5i`0UY`00ENLEYaFY5JL5j@009NL09NT004GW1NLEiaFY43
GY02GW4:GY46GY04HY02HY48H[43H[800f:aH[9R/P05H[8=H[42I[800fKBI]5VdP02I]800fKAI]9V
dP04I]82I]42I]82I]<:I]800fKCI]9Vd`02I]<5I]82I]<5J]<00f[BJ_9Zl`02J_<00f/CI_5V/@02
HVl00f:AI[9VdP02I]801V[BJ_9ZlV[bJ_=ZlPUZl`03J_9Zlf[c009Zl`03K_=Zlf[c00IZl`9ZlPE^
l`04K_AZm6[cK_<3J_@00fkcK_A^l`03K_<00flBKa=_4`04Ka@016kdJ_AZm6kc0fkd00A^lflCKa=_
4`=_509_5@U_5003Ka=_56lD009_5003KaE_56lC009_4`M_50I_5@E_509_5@E_5004KaE_56leLa@2
Ka@8KcD00flfKcE_=@03KcD5KcH01VleKcI_=VlfKcE_=PA_=@04LcE_=FleKcD2Kc@017<cKcE_=Fle
0VlD00A_5FleKaA_5@E_=@07KcA_<fKcGW1J:V:<I_400fld0fle00E_=6leKaA_57<d009c=@=_5@03
KaA_5FlD00m_5003KcA_=Fld009_=005Ka=c4g<CLc=_=@04Ka@00g<CKa=_4`06Ka<5Ka@3Ka<5Ka@0
0flCKaA_4`03Ka<2Ka@00flCK_=^lP02K_801FlBK_9_4VlCKa@00flC0V/D00EZm6/CJaE[56lD009[
4`9Zl`04J_9Zlf[cJ_<:J_8026lBJ_5ZlF[bK_9ZlV[aJ]82J_8016[aJ_9ZlV[c16[b00=ZlF[bJ]40
0V[A16KB1FKc00=ZlV[BJ]800f[B0fKB00EZdV[AJ]5ZdF[B00]VdP0:I]=VdVKBI]5VdVKAH]5VdVKA
I]02I]42I]800fJbI]5Vd@02I[05I]03I]400fJbI]9Vd@02I[42I[0026:aI]9V/FJ`H[1V/6:aH[0:
H[44H[001EjaG[1N/5j`G[400f:`0eja0Uj`00INT6:?HXmNT5j?GY04GXl5GXh3GXl00ej@GXmNS@04
GXh015j?GXiNSUj?0ej@00=NL5Y`GVh00Ui^0eY^0Ui^0Ui]1EY]0eY^00UJKEY^FVeJKEY=ETeJKEI^
FVd00UY=0UY<0UI<00EJCEY<FTaJC5I<00AFC@UFC09F:`=FC003ETYF:UH[009B:`04DRaB:e8[DR/5
DR`00e8[DRaB:`02DR/3DR`7DR/00dh[CP]>2`06CP/01Dh:CP]>2dh;CPX024h;00=:34X;BP/00TX;
0Th;0dgZ0DgY0E7X0Dg[000534402PQ122488@`Q344@H@aR348<8P`Q2`PQ00@<8@Q1324<@@8<@00<
320<@@PP200DHS4UBP]JSEj=GVeNKeY`15i`00ANT5ZAGY1NT0=NL003GY1NL5ia009JL09NL003GY1N
TEjA00MNT@04GY9NTEjAHY42HY000f:?HY1RT002HY02HY400ejAHY5RT@02HY49H[43H[800f:aH[9R
/P03H[800fJbI[5V/@02I[45H[42I[47I]46I]83I]4016KBI]=VdfKC2VKB00=VdFKBI]800fKC00=Z
dfKBJ]800VKB16[C0V[B0V[b0V[c00Y[4flBI]5V/6:?IY1V/FKAI]9Zd@9ZdP9ZlPYZl`03J_9^lV[c
00QZl`=^l`04J_=^lfkcJ_82K_8>K_<016kbKa9_4flC0VlD00E^m6kcK_=^m6lD00A^m004K_=_4flC
Ka<>Ka@01flCKaA_4flCKaA_5FlD00A_4`M_509_5@9_5003KaE_56lD00=_50Q_5@9_5003LaA_56lD
00Q_=@03KcI_=Fle00=_=@U_=P04LcE_=VleKcD3Lc@3KcD016ldLc=g<G<c16lD0Vle00=_56lEKcD0
0flf00Y_=G<cLe=[4fJaFT]JBVK`KcA_4`U_=0=_5@05KaAc57<CKaAc5003Ka@00fkcKaA_500:Ka@4
Kc@4Ka<00flDKa=_5002Ka@5Ka<016lDKa=_4flC1FlD3FlC0flD0flC26kb00=^lf[cJa@00V[c00Q_
4flDKa=ZlflBJa=Zlf[b0f[c2V[b00=ZlFl?J/l02F[a0f[b0V[c0V[b00YZdF[@J]1Zd6[aJ_9ZdVKB
J_9Vl`AZlP=ZdP03I]9ZdV[B00EZdP04I]9ZdV[BJ]82I]82I]400fKBI]5VdP03I]801VKCI]9VdVKA
H[5Vd@9VdP04I]5Vd6KAI[07I]45I]06I]44I[4016:aI[5V/6J`16:`2F:a00=R/5jaH[000f:`0Uj`
0Uja16:`00IR[ej`G[1N/6:`GY02HXl01Ej>GXmRSej?HXl00ej?00ENSUj=GXeNSEj>009NS`03GXiN
SEj=00=NS@ANSP9NT006FW5NLEY`FW1JKei^0eY^00AJKEi^GViNKP9JK@9JK003GVaJK5Y<009JK@03
FViJKEY=00EJK@9JC@05FTaJCEI=ETeJC@03FT`00eI<ET]FC00;ET`3ER/5ERX2ER/00e8[ER]F:`03
ER/00e8/DT]B;002DR`6DR/00eH[DR]B:`05DR/00e8;CP]>:`05CP/00e8:CPY>2P08CP/014X;AP]5
jdH;0Th;00=:2dh;CP/00U8:00=AjTgZDNT00Dg[00000`aQ344<@@02344010PQ12088@`Q0Pa10PQ2
00<88P`Q22401@PQ00<8@@`Q32400`PQ10`Q00h<@@a0344@@0PP58<]9TH<FXmNSUi]FVmJL5i`0eia
0UY`1ej@00EJTEiaGW1NL5j@00aNT@04HY5RT6:AHY43HY02GY02HY001V:AH[5NTF:aH[9RTPER/@9R
/P05H[5R/V:bH[9R/@06H[800fJbI[5V/@03I[400fJbH[5V/P03I[800fKBI[9V/P03I]42I]801VKC
I[9V/VJbI]9Vd@9VdP=Vd`IVdP=Vd`AVdPAVd`04I]9ZdVKBI]83J]<01F[BJ]=ZdV[CJ_800f[c0V[b
00MZd69_HTmRKfJ`I]5VdP02J]800f[bJ_=Zl`07J_<2K_<2K_8016kcJ_=Zlf[c0f[d00EZlfkcK_=Z
lfkc00=Zl`03J_9^lVkb00A^l`03K_A^lfkc00Q^l`05K_9^lfkcKaA^m003K_<016kdJaE_56[d0fkd
0flC3VlD00=_4flDKa@01FlD0flC1flD00=_5FlDKa@00flE1FlD1FlE00=_56lEKaD00flE00=_56le
KcD00fle00Ac=6leKcE_=P9_=@=_50Ic=@04LcI_=VlfKcH3LcD5KcD01W<dLc=c<gLBLa=c509_50=_
=@9_5@=_=@0;LcAg<g<BKc9[4V[AGVaJBVJ_K_9_=002Ka@5Kc@01G<cLa=c57<DKaD00VlD00=_4g<D
Ka@00VlD00=^m6kcKa@00Vkd0VlD0VlE36lD0flC0flD1FlC1VlD00=_5FlDKa@03FlC1FlD00=_4fkb
K_800Vkb00=_4VkbK_800Vkb00=ZlV/CJa<00flC0V[c1F[b0f[c00AZlV[cJ_=Zl`AZlP9[4`03Ka5^
lF[a00IZl@EZlP9Zl`9ZlP06J]5^lF[@J]5ZlFKb0V[B00AZlVKcJ_9Zl`AZdP=VdP03J_9ZdV[B009Z
dP9VdP04I]=VdV[BI]84I]42I]84I]<7I]8>I]401F;AI]1VdFK@I[401VKA16:a00=V/6:`H[000V:`
1F:a16:`00IR/EjaG[5N/F:aH[03G[001UjaH[1R/6:@GY1NS`INT005HXmNSV:?HXmNT004GXl2GXh2
GXd015j>GXmNKej>1Ej=15j>00ENSej@FW1JLEY`009JK`AJKP03FVeJKUY^009JKP04FVeJK5Y/FV/2
FT`2FVd00eY^FVeJK@06FVd00eY=FTaJC@02ETd00eY=ETaFC002ET`3ET/9ET`3ER/00eI<ETYF:P02
ERX02UH[DR]B:e8[ER]B:eHZETYF:e9<158/1E8[0U8/0e8[00EB:U8[DRYB:e8;019>2`=:3003DR]>
2dX;009:2`06CP]>2Th:CNY=jDgX0Dg[000334000`PQ22088002224010`Q340<@@Q10Pa100<<8@PQ
22401@PQ0`a100@88@`P224<8@@<@@0<340@H0`P468]1T7<EVmNSEY]GViJKei`0Uia15i`0ej@0ei`
1Uj@00=NL5j@GY000ej@0UjA0Uia00=NTF:@HY400V:A26:@00ERTEjAH[5N/V:B00ER/@IR/PAR/@04
I[9R/V:bI[83I[44H[400f:bI]9VdP02H[800fJaI]9Vd@02I]43I]84I[8016JaI[9V/VKC1FKB00=V
/VKBI]8016KB0VKA00=VdVKCI]<00VKC00=VdV[BJ]800V[B16[C00AZdV[CJ]9ZdP=ZlP07J_5Zcf:?
GTiNCFJ?I[000VKA00=ZdV[bJ_800V[c0V[b1F[c00A^lfkbK_9^l`=Zl`=Zm09Zl`03K_=Zlf[c00=Z
l`04J_9^lVkbK_85K_<00f[cK_=^l`06K_<3K_85K_<00fkdJ_A_5003Ka@5Ka<4Ka@00fkcK_A_5002
Ka@2K_@2Ka@00flCKaA_4`05Ka@2Ka<4Ka@00flCKaA_<`03Ka@4KaD9Ka@7KaD2Ka@2Kc@00g<cKcAc
<`02KcD00flfLcE_=@04Kc@01G<dLcEc=FlfLcD016lf1Fle16ld00=c<W<cKc@016lD26ld00Y_<g<A
La5_4FkaJ_1V[UY:HXeZd0=_5003Ka=c4flC00=_=003La9c4flC00=_5005Ka=_56lDKaA_4`02K_<0
0f[cK_=^m006Ka@5Ka<5Ka@00flCKaA_4`03Ka@7Ka<016lDKa=_56lD0VlE00=_56lCKa<03flC0VlB
1Fkb00M^lFlBK_9^lVlBJa=_4P0<J_800f[cJ_9Zl`02J_<8J_83J_400f[bJ_5Zl@05J_400f[bJ_=Z
l`02J_87J_400f[AJ_5ZlP02J_85J]800fKcI]9VdP03J]802V[AI]5VdVKCI]9ZdVKBI]5V/FKA0fKB
0fKC0fKB00AVdFKBI]9VdP9Vd@03I[1VdFK@009Vd@03I]1VdFKA00=V/09Vd@03H]5Vd6KA00=Vd@06
I[1Vcf:]I/iV[f:`0f:a00YV/6:`H[1R/6:_H[1R/F:`I[1R/@UR/00:HZmR[Uj?GXmN/F:`HY1RSej?
GXh3GXl01Uj`GZmNSej>HXeNSP9RS`ANS`03GXiNSEj=009NS@9NSP04GXeNS5i/GX`6GXd01ej>GXmJ
KeY`FVmNKUY^00=NKP03FViJKEY^00=JKP03FVeJK5Y/00=JJ`04FVaJC5Y<FV`2FT`2FVd3FTd2FT`0
0eY=ETeJC@02FTd3ET`015I;ETaFBeH[25I<1UH[0UHZ00AF:e8[ER]F:`EF:P03DT]B:e8/00IB:`04
ER]B;58/DR`2DR/3DRX2DR/<CP/00dX;CPY>2P03CP/2BP/00dH<BP]:2`02BP/01dX:CPY>2Dh:CNY=
jE7W005AjP0000D<@@`P320<8@a100@88@06344<HPaS3488@PPR1PPQ0`Q100@<@@`Q32088@<<@@8@
HP0>344@@0P0324XiCV:CU1JSUY]GViJT5j@FY5NL@ANL0=NT004GW1NLEiaFY42GW001Ej@GY5NLEia
GW0015j@0UjA0Uia2EjA0f:@00MR/EjAGY5NTEjBHY9R/P05H[45H[800f:aH[9R/@07H[83H[42H[85
H[<01F:bI]9VdVKBI]400VKB1FJb00=V/FJbI]800VKC0VKB00=VdfKBI]800fKB0VKC0fKB1VKC0VKB
0f[B16[C00=VdV[BJ]800V[B0V[b00AZdFKAI[5RT@9RT005I[5VdF[BJ]5Zl@0@J_<3J_@00f[cK_=^
l`02J_<01F[dJ_=ZlfkcJ_800Vkb0fkc00=Zm6kcK_<026kc16kb0fkc0Vkd0V[d00A[5FlDKaA_4`A^
l`04K_A_56lDKa@3K_@2Ka@2K_@5Ka<5Ka@026lCKaA_56leLaE_5FlDKaD3Ka@5KaD00flCKaA_5002
Ka@=KaD00flDLa=c<`02KcD3KcH2KcD00fldLc=c<`03LcD2KcH3KcD3KcH4KcD4Kc@2Lc<017LcMcEc
=G<e0fld1Fle00Q_=6lcLa9c4GL?Ka5^l6K?0V9/00AZd6lDKa=_50=c4`04KaA_=6leKc@9Ka@2Ka<0
0fkcKaA_5007Ka@00flCKaA_500CKa@00flCKaA_5002Ka@2KaD01FlDKa=_4flCKa@036lC00=_4Vkb
K_800flC0fkb0flC00A_4V/CJa=[4`QZl`=ZlPEZl`03J_9Zlf[c00EZl`QZlP=Zl@03J_9Zlf[c00UZ
lP05J]5ZlF[BJ_9VdP05J]84I]82J]800f[AJ]9VdP02I]85I]42I]84I]<2I]800fJbI]5VdP02I]84
I]400fK@I]5Vd@02I]002fKAI[5V/FJaI]5RdF;BH]5RdV;AH[400VJa0fKA00=V/6:aH[001F:a0V:`
00UR/F:`H[5R/F;AI[5R/6:@G[0016:`00IRT6:?HZiNSf:_G[03H[05GY02GZl015j?GXiRSV:>0V:?
15j?0Uj>0ej=0Uj>00=NSEj<GVd015i]0Uj>00ANSEj>FViJKP9NKP05GVeJKUi^GViNK@07FVh4FVd2
FV`00eY<FVeJK002FT`2FVd3FTh3FTd00eI=FTeJC@04ET`2ETd3ET`01EI=ETaFC5I<ER`00UI<00=F
:eI<ER/01EH[00=B:e8/ER/01UHZ0U8[00=B;58[DR`00U8/00QB:e8/DRaB;58<CPaB;4h[0U8Z0U8[
00=B2dh;CP/024h;00=B:e8ZDRX00Th:0Th;00I:2dX<BPa634X;BP`4BP/2BPX2CNT1DNL1DNX00003
224880PP00d88@0312488@PQ00H88@8<8@8<@@04340<80`Q3442320220001RC5>HUBD6:_GViNSP=N
T0ENL004GY1NTEjAGY02GW400eZAGY1NT002GY42GW47GY000ejAGW5NT@04GY47HY4015jAHY5RTF:a
0V:B00AR/V:aH[5R/09R/@03H[9R/F:a009R/P03H[5R/V:a00]R/P03I]9R/f:c009R/P06H[=R/V:b
I]9V/VKA0VKB16Jb00IV/FK@I[5VdFKBI]<3I]82I]<6I]8016KAI]9VdVKB0fKC00IZdf[BJ]9ZdV[C
J]84J]<016[cJ_9Zdf[C0f[b00a^lV[bI[5VT69_HY1VT6JaJ]5Zd6k`J]42J_86J_<00fkcJ_=^l`04
J_<4J_@4J_<00f[dJ_=Zl`02K_<00fkbK_=^l`02K_<00f[cK_=^l`06K_<2K_83K_42K_801VkcK_9_
4fkdJ_AZm@9_5@9_4`=^l`03K_9^lflD00=_509^m09_5003K_=_4flC00Y_4`03KaA_5FlE009_5@=_
509_4`9_50=_5@03Ka=_56lD00M_509_5@=_50=_5@04KaA_4g<CKc@5KcD01VlELc=_=6ldKaAc50E_
=@04LcE_=G<fLcD2KcD9Kc@2KcD00fldLc=_=007Kc@016lCLa9c4GL?0Vl?00UZcVJ=GRYZ/6ldLcA_
=7<BLa<00VlD00=c<g<eKa@016lD00=_=6lDKa@01FlC1FlD00=_5FlDKa<00VlC00=_56lEKaD00VlD
00=_4flDKa@00VlD0VlE00A_56lCKaA_4`9_509_5@04KaA_4flCKa<3Ka@00flEKaA_4`09Ka<00flB
Ka=_4`04Ka<2Ka800flCKa9ZlP03K_802V[bKa9[4VlBJa=_4f/CKa9Zlfkc1F[c16[b16[c00=ZlV[c
J_<036[c1f[b00=ZlF[bJ_801F[c00IZlV[AJ]5ZdV[bJ_<4J]8016[AI]5ZdVKB0f[B00=ZdFKBI]80
0VKB1FKA1fKB1fKA26K@0VKA0fJa00AVdF;AI]5R/@9Rd@03I[5R/F:a00IR/@03H[1R/F:a00AR/@]R
/09RT003HXmRSV:?00MRS`=NT09NS`9NSP9RSP03HXmNSej?009NS`03GXiNSEj=00=NS@05GXiNSEj=
GXaNK@03GVh01eY^GViNKEj<GVaNKEi^00=NK005FVeNKEi]GVaJK@09FVh00eY]FTaJK@03FV/015Y/
FTaJKEY]0eY>15Y=0UY<00=FBeI<ET`00UI<00EFCEI<ETaF;5H]00QFC0AF:`04ET]F:eH[DR/4ER/5
ERX3DR/8DR`01E8[CR]B:U8ZERX00e8[00AB2U8ZDR]B2`9>2`03CPY>2dh;00=>2`=>2P9>2`9:2`06
BPa:2dX;CP]:2dh:0dX:00=>2DgYCNL00DgZ000<224232400`PQ2448@@0222400`Q232488@042240
0`a1368<@@023203220220001``09:@mR59?HZiRT5Y_00EJL09NL09NT@=NT003GY5JTEjA009NT@07
GY1NLEiaGY5NT5jAGY000Uia00=NTEj@GY401UjA1F:@0V:A00ANTF:AH[5R/@9RTP9R/PAR/@08H[9R
/F:AH[5R/VJbH[9R/@UR/P9VdP07H[9Rdf:cI[9V/f:cH[800VKB00AV/VKAI]9VdP9V/P09I]9V/VKB
I]1VdFKBI]=VdVKC009VdP9Vd`04I]9VdfKCI]<2I]800fKAI]9VdP05I]<5J]83J]<2J_<016[bJ_=Z
lf[c1F[b00aV/69_GVmRT6J`J[1ZdFkaJ_9Zdf[cJ_8<J_<00f[dJ_EZm002J_@3J_<00f[dJ_=Zl`02
J_<016[bJ_=Zlf[c0V[d0fkc00=Zm6kcK_@016kc1Vkb00=^lflDKaD00VlE00A_5VlEKaA_4`9_5004
Ka=^lfkcKa@3KaD016keK_A^m6kd0VlD1flC00A_56lCKa=_4`9_50A_5@04KaA_4flDKa@5KaD8Ka@4
KaD3Ka@3KaD017<DLa=_4fld1Fle00=_5FldKc@00VlD0flE0fle1Flf00A_=FldKcA_=0Q_=@03KaA_
=6lE00=_509_=003KaAc57<c009c4P0?Ma1_47<@J_1VSEhZIXmZlg<dLeEg4W<BLa=_=Fld00E_50A_
=0=_4`I_509_5@05KaA_4flCKa=_5002KaD4Ka@00flCKaA_5007Ka@2KaD2Ka@3Ka<01FlDKa=_56lE
Ka@056lC00=_4V[cJ_<016[c0V/B00A[4flCKa=_4`=Zl`07K_=Zlf[cJ_AZlV[cJ_801F[c00=ZlV[c
J_<03F[c1V[b00=ZlF[bJ_800V[c1F[b00AZlF[bJ_9Zl`AVdP=Zd@9ZdPYVdP04I]5VdVKBI]85I]<4
I]86I]45I]03I]401FJaI[9V/VJaI[000V;A2F:a00=R/6:aH[400f:a00=R/6:aH[0036:`00ENT6:?
HXmRSf:@009VS`=RS`=NT09NS`=NSP9RSP03HXmNSej?009NS`INSPANS@06GVeNKUi^GVmNKUi]0Ui/
0Ui]00ANK5Y]FVaJK@9NK@03GVaJKEY]00AJKP03FVmJKUY_009JKP0:FVeJKUY]FVeJK5Y]FVaJKEY=
FVh2FTh4FTd2FT`00eI;ETaFB`04ET`2ERd015I=ETaFCEI<0eI=00=FC5H/ET`00UH[00=F;5H[ER/0
0eH[0e8[00=F:e8[ERX00UHZ0U8[2U8/00=>:e8[DR/0158[00=B:U8:DPX0158:1Th;0Th:1dX;0dh;
00I:2dX:BPY9jDgYCNP1CN/000d88@04324<@@a1364246800`a132488@0422401@a124488@`Q3200
0PPP00T<810P200<822S?FI>;F:]GXl00UY_15Y`0Ui`0ej@00=JL5j@GY0015j@0Ui`1Ej@0Uia00=N
T5j?GY000ejA00ENT5jAGY5RSej@00ART09RT@03HY1RTF:a009R/@9R/P06HY5R/F:aH[1R/FJa0V:a
00ERTF:@HY1RT6:a00]R/P9R/`9V/P08H[=VdVKCI]9V/VKAI]9Vd@9V/P04I]9V/VJaI]02I[44I]80
26KCI]9VdfKBI[=VdfKDI]<4I]85I]<4J]800f[bJ]9ZdP03J]800f[bJ]5ZlP05J_802F[aJ]5V/F9_
GTmRKVJ^JZmZd@02J]800f[cJ_9Zl`04J_<01F[CK_=^lV[cK_<00f[c16[d26[c00AZlV[cJ_9Zl`9Z
m0=^l`03J_=^lfkc00E^l`I^lP9^l`=^m003KaA^lflC00A_4`9_50=_5@04K_E^m6kdK_@2Ka@5Ka<0
0fkcKa=_4`03Ka<3Ka@3KaD00flDKa=_5003Ka@00flEKaA_5004Ka<8Ka@00flCKaA_4`02Ka@2KaD0
16lDKc=_=6ld0Vle0flE0VlD00=c4flDKa@00fle00=_=6leKcH016lf00A_=FldKcA_=0U_=@03KcA_
5FlD00=_500>Ka=_56lDKaAc4g<BM`mc3g<@Ka5V[ehZHViZlP9_4P03La5c4VlC009_509_=003KaA_
=6ld00=_=003KaA_4flC00I_4`=_50A_4`I_50E_4`A_5003Ka=_56lD00=_50A_4`04K_=_56lDKa@9
Ka<2Ka82Ka<016lBKa=_4flC16lB00=ZlfkcK_<00V[c00E[4f/BJa9[4VlB009_4`03J_=ZlV[c009^
l`9Zm0EZlP=Zl`AZlPAZl`03J_9Zlf[c009Zl`03J_9Zlf[b00IZlP=Zl@04I_9ZdV[BJ_83J]800f[a
J_9ZdP05I]84J]4016[BI]9VdVKB0VKA00=ZdFKBI]800VKB0VKA16KB1FKC16KB16KA1fK@00AVdFJa
H[5R/@=V/003H[1R/F:a00ER/@UR/003H[5R/6:`00UR/09RT003H[1RSf:@009RT0=RS`03HXiRSej?
00ANS`=NSP03HXeRSV:>00ANS`ENSP04GXmNSEj=GXd2GV`01Ei]GViNKUi^GVd01Ei/0eY/00=NK5i[
GV`00UY/00AJKEY^FViJKP9JK`=JKP04FVeJKUY]FVd2FV`015Y[FT]JBeY]0UY>00AJCEI<FTeJC@9J
C09FB`03FTYFBeH[00AF:`MFC003ET]FC5I<009F:`03EReF;5H[00=F:`=B:`9F:`=F:P9B:`=B;09B
:`=B2`03DPaB:dh[009B:`9B2`AB2P9B:@=B2@03CPY>2dh;00=>2`9>2P03BPY>2TX;00Q:2`9:2P03
BPQ9jE7X005=j`000`PQ00@88PPQ224400L88@07244<@@aR348<@@a2328010PQ0`Q10PPQ010<8@PQ
320<8110300<81b2?FE>2f:<FViJD5i`FW1JL@=JL09NT0=JT@eNT09NL@=NT0=NT@9NT0=NT@03HY1N
TF:A00IRT@03HY9R/F:B009RTPER/@07GY5RTEjAHY1RTF:@H[402f:b1F:c0V:b00=VdVJbI]400VKB
00AVdfKBI]9V/PAV/@03I]9V/VKB009VdP=V/P9Vd`04I]AVdfKCI]87I]<2I]85J]800f[AJ]9ZdP08
J]802F[bJ_=VdV:AGU1NCfJ?I[1Zd@02J]800f[CJ_=Zl`04J_<7K_<00f[cJ_AZm002J_@<J_<2J_@0
0f[cJ_AZm003J_@5K_@8K_<4K_@016kcK_A^m6lC0flD0flE0fke0Vkd1VlD0VlC16lD00=_4flDKa@0
0flE2VlD0flC0VlD0VlE0VlD0VlE00A_56lCKaA_50E_5@04KcA_=FleKcD3KaD01fleKcA_=7<BKa=_
56lE00A_=@I_=PE_=@03KcI_=Fle00M_=@M_500<Ka=c4WL@La1_4FlBJ/mRC5i>I]9^lFlB0W<B00Mg
4g<dKcA_=7<DLcEc5003Ka@2KaD01FlDKa=_4flDKa<026lD00=_5FlDKaD016lD0flC0flD00E_4flD
Ka=_57<C00E_5005Ka=_56lDKaA_4`05Ka@3Ka<00flDKa=_4`08Ka<4J_<01VlBJ_=^lfkcJ_A[509[
4`08Ja9[4f/CJaAZm6[cK_=Zl`9^l`04J_=Zm6[cJ_<3J_83J_<01F[bJ_=Zlf[cJ_8026[c0V[b00EZ
lf[bJ_9ZlVKc009Zl`05J_9ZdV[BI_=ZlP04J]800f[bJ_5VlP04I_82I]800fKAJ]9Vd@07I]82J]80
0fKBI]=VdP06I]82I]<01FKDI]=RdfKCI]8026KA0fJ`0fKA00AV/F:aI[5V/0=V/@MR/@=R/0ER/@03
H[1R/F:`00QR/004H[5RT6:@HY02GY000ej?HY1RT002HY03HXl00ej@GXmNT005GXl00f:>GXiNS`0:
GXl00ej>GViNK002GV`2GVd2GVh00eY^GVeNK@02GVd5FVd01Ei/FVeJKEY]FVh00eY_0UY`0eY_00IJ
CUY^FVeJKEY/FVd3FT`9FTd2ET`025I;ETeFC5H/ETaF:eI<ETd2ERd7ET`4ER`4ER/2DR/3DR`5DR/5
DR`01U8<DP]B2dh;DP]>:`9B:`9B:P05DPY>2U8:CPYB2@03DPX00dh:CP]>2`02CP`00dX<CP]>2P02
CPX00dX:BP]:2`02BP/5BP`2BPX00dX9BPY=j@01CN/000<88@8<8@03344<8@PQ00H88@<8@@888@84
8@@88@042288@PPQ2203224234003110200<01QP>B=9jUi<FViJD5i?GW1NL@=NL003GY1NL5ia009N
L@ENT003GW1NT5j@00ANT09NL0ANT0QNT@03HY1NTF:A00IRT@03HY9RTF:A009RTP0:H[5RTF:AH[5R
T5jAGY1NL6:@HY42H[400fJaH[9R/P07H[83I[83I[<01FJbH[9V/VJbI]400VKB0VKC00=VdVJbI[80
16Ja0fKA00EVdVJaI[9V/VKB00EVd`03I]9VdfKC00AVd`9VdPAZdPIZd@IZdP0;J_9^lf[aI[9NLUia
HY1V/6JaJ]9ZlP02J_<00f[CJ_9Zl`02J_<3K_8016[bK_9^lVkb0V[c0f[d26[c0V[d0f[c00EZm6lC
J_=^lf[c009Zm09Zm@9^m@A^m0=^l`04K_9^lfkcK_@6K_<4K_@3K_D00flEKaA_4`06Ka@3Ka<3Ka@2
Ka<2Ka@00flEKaA_5002Ka@00flCKaA_4`06Ka<5Ka@00flEKaA_5003Ka@00flCKaA_5004KaD8KcD0
2FldKa=[4FlbKa9c4g<DKaA_5@02Ka@3KcD2KcH6KcD2KcH016leKcA_=6ld16le00=_5FlDKa@00VlD
00E_4flDKa=_4g<B009c4@07Ka9^l69^FRiZdFkaKa800VlC0Vld00Ec<flDKaA_5FlD00=_5@06KaA_
=FldKaA_4fkc16lD16lC3FlD26lC0VlD0VlC0flD00=_4flDKa@01FlD1FlC16lB0flC0V[c00E_4fkc
K_9^lfkb009^l`9Zm003J_=[4V[c00EZl`04J_9^lVkbJ_85J_<6J_800f[cJ_9ZlP02J_82J_<016[b
J_=Zlf[c16[b0V[c00UVlf[cJ_=ZlV[BJ_=Vlf[cJ_801F[a1fKa00=ZdF[BI]801FKB16[B0fKB16KA
0VKB0fKC00AVe6JcI[9VdPeVd@IV/@05H[5V/FJaI[5Rd@04H[43H[02HY0016:AH[5R/6:_2V:`0f:@
00ARSf:@HY1R/09RT0ERS`9RT0=NT003GXmNT5j?00YNS`ANSP03GViNK5i/00=NK004GViNSUi_GVh2
GVd2GVh3FVh3GVd00eY^GViJK`02FVl6FW000eY_FViJK003FV`3FTd00eI=FTeJC@09FTd3ETd3ET`0
0eI=ETiF;@05ET`00eH/ER]F;003ER`01e8/ER]F:eHZER]FBe9;00AB;09B:`9B:P05DR]B;58/DRaB
3002DP/5DRX2DPX5DPT2DPX3CPX01e8;CP]>34h<CP]>2Th9009=j@0>BPY:2dH;BPY:2dh;BPa>2dX:
BPU:2TWYBPY9j@59k00000D88@`P324<8@a100L<@P8<8@033448@@Q100888@032288@PPR00888@03
2448@PPR00D88@03220<@110008<0009640e0dW[FTaNSeY@GTmNL5ia009JL003GW1JL5i`009JL005
GW5NL5j@GW1NL@03GW02GY000ejAGY1NT002GW000ej@HY5NT@03GY4015jaGY5NTEjA0Uja00=NT5jA
GY401V:A00=RTV:AHY400V:B00IR/F:AHY5RTF:@GY02GVl00ej@H[5R/@02H[46H[801V:cH[9R/VJb
I[=V/P9V/`AV/P03I]9VdFKB00AVdP03I[9VdVJa00=V/@=Vd@04I]9V/FJbI[86I]<2I]85I]<2I]80
1F[BI]9VdVKBJ]801V[A0V[B00mZlV[cJ_=ZlV[cJ_9Vdf:BFW5JKf:AI[5VdV[BKa@00V[c00EZlV[c
J_=Zlfkc009^lP07J]9^lVkbK]9Zdf[bJ_<00V[d2f[c0f[d00AZlf[dK_=Zl`9Zm004K_E_5FkeK_D3
K_@7K_<016kdK_=^lVkb0fkc1Fkd00=^mFlEKaD00VlD00A_5FlDKaA_509^m003Ka=_56lE00=_509_
4`9_5003KaE_56lD009_509_4`9_50E_4`M_5004Ka=_56lDKaD5Ka@2KaD4KcD4KaD00fleKcA_=002
Lc<00fldKaA_5002Ka@017<DLc=c=Fle0flf16le16lf0Vle00=c=6leKcD00fle0VlD00A_4flDKa=_
509_4`0<La9_4W<AKa5^l6:?FRiV/6kaKc=_=6le0fld1VlD00Q_5FlDKcEc=FleKa=^lfkd0flD0flC
3FlD2FlC0VlD0VlC1flD00=_4flDKa@00flD0flC00=_4VkbKa<01VlC0Vkc00=^lVkcK_8016kc00IZ
lf[bJ_=Zlf/CJ_<3J_82K_8016kcJ_=Zlfkc0f[c2V[b00=Zlf[bJ_<01f[c0fKc16[b00EZlfKcI_=Z
lVKa00=ZlP9VlP03I_5VlVKB00=VlP03I_5VlVKB00EVdP9ZdPEVdP03J]9VdFKB00=VdP=Vd`9V/P03
I[5VdVKA00iVd@03I[9R/F:a00=R/@03I[5V/6Ja00AR/@=R/003HY1RTF:A009R/@=R/003H[5R/6:`
00ER/0=RT007HXmR/6:`G[5NTF:aGY000ej?00=RSf:@GY000ej@00ENSej@GXmNT5j?00=NT0MNS`=N
SP03GXeNK5i/009NK@=NK`03GVeNK5i]009NKP9JK`06FViNKEi=GViJKUi^0UY^15Y_0eY`00=JKeY^
FVd00UY]00=JK5Y=FTd03EY=0eI=0eI<00=FCEH]ERd015I<0eH[0UH/00=F;EH/ER/00UH[0UHZ00AF
Be9;DT]BC0=B;004DR]B:U8ZDR/3DR`00e8[DRaB:P02DRX2DR/00dh[DRYB2P02DPX00e89DPY>2P03
CPX01E8:CP]B2U8;CP`00Th;00A>2TgYCNU=j@9:2P03AP]:2TX;009:2`07CNY9jTh9CNU9jTX:BNX0
0DG/0002220232000a1R48<@H`0234800a1S348<8@0334402`Q134488@PQ12488@@Q2248@@a12440
1PPQ0Pa000d@@0a0320D@3CSBN]NC5j>FTiNCei`GTmJD003FW001ei`FW1JL5Y`GW1NT5i`009JL09N
L@9NT003GY5NT5i`009NL0=NT0ANT@9N/@9NT@9NT09NT@ART@03GY5RTF:A00=RT@0:HY9RTF:AHY5R
/F:?GXmNCUi_HY04H[46H[8016:cH[9VdVJb16Jc00=V/VJaI[400VJb00AV/FJbH[5R/P9VdP9V/PEV
/@9Vd@04I]9V/FJaI]45I]<4I]800f[CI]=Vd`03I]8016[BI]9VdVKB1f[A0V[B16[b00QZdV[bJ_AV
dUjAFU1RT6:`0VKA00AVdV[BJ]9ZlP=Zl`06K_=^lVkbK_=^lFkb0V[B0V[b46[c00E_4f[dK_=Zm6kc
009Zm003J_E_56kd009^m0M^l`9^m005K_9^lFkcK_=^m005K_<3K_@00flDK_A^m005Ka@00flCKaA_
5004Ka@4Ka<4Ka@2Ka<3Ka@5Ka<6Ka@00fkcKa=_5005Ka@00flCKaA_5002Ka@2Kc@2Ka@4KaD016lD
KaE_56lD0g<C0VlD00Ac4g<cLcAc5@]_=@9_5004Lc=c=7<dKcD2KaD2Kc@6Ka<02W<CLa9c4VlALc5Z
d5i?HVe^l6lc1Fld0VlD00=_5FldKc@01VlD00=_4fkcKa@00VlD1FlC00=^lflDKa@00VlC1FlD0VlC
0flD00=_4flDKa@00flC00=_56lCKa<02FlC16kc16lC0fkb00e_4VkbKa=_4flBJ_9_4VlCKa9^lVlB
K_=^lP02K_<5J_<4J_83K_800f[bJ_=Zl`02J_<3J_82J_4:J_87J_<016[bI]9ZlV[b0V[B00AZlfKc
I_=VlP9Zl@06J_9ZlfKcI_9VlFKA0VKB0VKb00EVlFKbI]5VdFKb00AVdP=Vd@AVdP03I]5VdVKB00AV
dP9Vd`03I]9VdFKA00=Vd@03I[5VdFKA00UVd@08I[5R/F:aH[5R/6:aI[1V[`9R/003H[5V/6:`00=R
/0ER/@=R[`IR/003HY1RSf:?00ERS`04H[1NTEjAGY03GXl016:?GXmNSej@15j?00INSUj?GXmNT5j?
GY02GXl00ej>GXmNS`02GXl01Uj>GViNKEj<GXeNK09NK@9NK`06GViNJei/GVeNKUi]0eY^00QNKEi=
GViNKUi]FVeJK5Y]0eY^00EJKeY@FTmJCUY^00AJK@=JC0=JC@9JC003FT]FBeI;00EJC@9FC@=FC09F
:`IFC09F:`=F;09F:`AF:P05ET]BBe8/DRaB:`02DR`00e8[DRYB:P02DP/2DR`2DR/3DP/0158ZDR]B
:e8Z0Th:00EB2U89CPY>2Th;00=>2P03CP]B2e8;009>2`03CPY:2TWZ009=j@03BNU:2TX:009:2P9:
2`99jP==j@59jP5=jP59k00000@88@`P344<@P8@H`0446@@Q0aS34<2348232401@a12488@PQ22280
0`Q200X<@@a2344<8@a1244<@@Q13448@@8<@00=440@@A10660`hdFYGTeNSeY>FU1NL5i?GW002UY`
0UYa0UZA1Ej@00=NL5j@GW000Uj@0UjA00=NTUjAGY401ejA0f:A00ENTF:AHY5RTF:@00ART@AR/@05
HY5RT6:AHY9R/P02H[43H[801F:cH[9R/f:bH[<00f:b00=R/fJbI[800VJb00=V/FJbI[800VJb0V:b
0fKB00=V/VKBI[400fJb0fKB0fKC0fKB00=VdfKBI]8016KB00=ZdVKCI]<00fKC16KB1V[A00=ZdVKB
J]8016[B0V[b00UZlfKcH[9NL5i_HY5R/VJaI]800V[B00=Zlf[dJ_<00f[c00AZlVkcK_9^lP9ZlP03
J_=ZlV[c019Zl`04J_AZlf[cK_@7J_@3K_<2K_@016[dK_A^lfkc0fkd0fkc00A^m6kcK_=^m0A^l`03
K_A_56lD00M_5003KaE_56lD00=_4`A_509_4`9_5003KaE_56lC009_5003Ka=_56lD00=_50A_4`=_
5006KaEc56lCKa=_56lC16lD00=_=FlEKaD016le16lD00Mc56lDLaAc57<cLaE_5@02KcD4LcD00flf
KcE_=@02KcD2La@00gLcKcA_=002KaD00fleKcA_=002Ka<2Ka@5Ka<03FlAMe9ZlEi?HTaZkflcKa=c
4flDKcE_5Fle009_5@9_=@03KaE_56lD00=_509_4`A_50=_4`03KaA_4flD009_5004Ka=_56lDKa@2
Ka<2Ka@3Ka<2Ka@016leKa=_4flC1VlD1VlC0fkc00=_4flDKa<01VlC00A^lflCKaA[4`9Zl`=[4`03
Ka9^lfkc009Zl`=Zm09Zl`04J_9^lVkbJ_83K_85J_<7J_8016[cJ_9ZlV[a16[b0f[c0V[b00IZdVKB
J_9VlfKBI_<3J_83I_<016[bJ]9ZlVKc0VKB00=VlVKBI]8036KB0fKA00EZdFKBI]5VdVKA00AVdP=V
d`9VdPUVd@9VdP05I[9R/F:aI[5R/@02I[400f:aH[9R/@03H[401FJ`H[5R/F:aI[0016:`1F:a0f:`
1Eja0V:`0V:@0f:?0V:@0Uj@00=NTEj@GY000ej?00=NT5j?GY001ej?0Uj@1ej?00aNSUi^GViNKEj=
GXiNKUj>GVmJSei_GVh2GXh2GVh025i]FViJKUY_GViNKEi=GVd3FVh00eY_FViJKP02FVh015Y?FTiJ
CUY^1eY]0eY=0eY<0UI<00=JCEY<FTd00UI<0eI=0UI<00AF:eI:ET]FB`EFC007ER]F;5H/DRaF;58[
ERX015H[00=BC58/DR`0158/0U8[00EB2e8<DRa>;58[009B2`AB:`03CR]B:e8[009>2`03CPY>2dh;
00=>2`03CPY>2dh;00=>2`9>2P06CNU9jTgYCNU9jTH:1TX:0TgY00==jTWZBNT00DW;000010PQ324<
8@PQ1P`R00H<8@PQ3248@@PQ2442248322801PPQ344<@@a1244<@@8<H@8<@@0<244<@0a0340@@AAQ
664`hSeWERaJKEY>0Ui_0Ui?00=JKei_FW0025Y`0Ui`2Uj@00=NTEjBGY4015jA00=NT5jAGY4015jA
1F:A1F:@00ERTEjAHY5RTF:@009R/@9RTP04H[9R/FJaI[44H[800f:cH[9R/P04H[82I[86I[44I[80
0fKAI]9VdP04I[800fJcI[9VdP02I]82I]<4I]800fKAI]9VdP03I]800fKAI]9Zd`03I]<00f[BI]9Z
d@08J]400fKBJ]9ZdP04J]802F[bJ]5ZdFKAHY1NKei?GW1RT@03I]82J]<3J_<00fkcJ]9ZdP02K]40
16kbJ_9ZlV[b36[c00=^lf[cJ_<01F[c0fkc0VlD00IZm6lDKaA_56[dK_<4J_<01F[dK_A^m6kcK_@0
1Fkc00A^m6kcK_=^l`A^lP03K_=_4flD009^m0E_5003KaE_56lD00=_4`A_509_4`9_5003KaE_56lD
009_50]_4`04KaA_4fkdKa@6Ka<8Ka@00fleKaE_5@02KaD00g<DKaA_5002Ka@2KaD016leKaA_56lD
0VlE00E_=FlEKaEc56lD00E_=09_509_=003KaA_4flC009_509_4`0=La=_4flCKa5c<F[aHViNBV[?
Kc=c4VlCKa@01FlE0Vle16lD0flC00A_56lCKaA_4`E_50I_4`E_50I_4`9_5004Ka=_56lDK_@4K_<5
Ka<01FlBK_=^lfkbKa800VlC00=^lflCKa<00VlC00E^lfkdKaAZlflB009_4`04Ja=_4flBKa82K_82
J_<2J_@3J_<016kaJ_5^lFka1Fkb1F[b00=^lF[aJ_401V[b16[a00IZlV[cJ_9ZlV[BJ]42J]800fKB
J_9Vl`02J_8016[aI_9ZdVKB0f[B0fKB00=ZdVKBI]803VKB0VKA36KB0VKA00AV/FKAI]5Vd@=V/@06
I]5VdVJbI[9VdVJb0VJa00IR/FJ`H[5R/FJbH[42I[43H[42I[4DH[02HY04H[05GY06GXl2GXh=GXl2
GXh2GVh00ei]GVaNK@02GVh015j>GXmNKUi^1Ei]0eY^00=JKEi=GTd00UY]00AJKUY_FViJK`IJKP03
FVeJK5Y/00=JK@=JC@9JK@03FTeJC5Y<009FC005ET]JBUY;FT]JC002FTd01EY<ET]FBUI:FTX00UI:
0UI;15I<0UH[00AF;58[DR]F:P9F:`04DRaF;59<DR`2CRd9DR`00e8[DP]B:`04DR/3CP/01Dh[CP]>
2dh;CPX00dh;00=>2Th;CPX00dh;0Th:00==jDWZBNX00TWZ00=:2Th9CPT00dh914gY0DWZ0DgX0DW:
00042245324322400`a12488@@0224800`Q122488@0322400`a1368<HP0434400`a2344<@@022200
2P`P440D@2c2?FE>;5I]FViJKei_0Ui`00AJKei_FW1JL0MNT09NL0INT09NL003GY1NTEjA009NT@03
GY9NTEj@009NT0MNT@ART@=RT003HXmRT6:@00ART09R/@=R/P05H[5V/FJaI[9R/@09H[82I[88I[40
1FJbI]9VdFJbI[4016Jb00=V/fKBI]<026KB00=VdFKBI]800fKB00=VdFKBI]800fKC00=Zdf[BJ]80
0V[B1V[A00=VdV[BJ]8016[B00IZdF[bJ]5ZlV[AI[42HVl01F:@H[1V/VKCI]@016[c00I^lfkBK]5^
dF[AK_42J_8DJ_<2K_<01FkbK_=^lflDKaD00VlD00=Zm6[cJ_<00V[c00=Zm6[cJ_@00V[d00A^lf[c
K_=Zm0=^l`04J_A^lfkcK_<3K_8016lBKa=_4flD0Vkd0flD00=_5FlDKaD00VlE16lC0flD0VlC0VlD
00E_5FlDKaE_5FlD00=_4`E_50=_4`E_509c4`E_4`04KcA_56lDKa<2Ka@00flEKaA_5@02KaD5Ka@3
KaD5Ka@2KaD3LaD2Ka@4Kc@6Ka@2KaD2Ka@3Ka<2Ka8026[bIZmJ:F[?Ka=g<W<BKa@3KaD2KcD00flE
KcE_5004Ka@02FleKaA_56lCKaAZlfkcK_A_5007Ka<3Ka@9Ka<4Ka@02VlEK_A^m6lCK_=_4flDKa=_
56lC0Vkc0V[c0flC00=_56lCKa<016lC00=_56lCKa<016lC0VlB0f[b1f[c00Q^lV[bK_5^lVkaK_9^
lFkb16[b0V/C00=^lV[aJ_401F[b0V[a00AZlV[cJ_9Zl`=ZlP03J]9ZdF[A009ZdP08J_9VlfKcI_9V
lFKbJ]9VdP=ZdP9VdP03J]=ZdV[C009Vd`AZdP9VdP9Vd@03J]5ZdV[B009ZdPYVdP03I_=VdVKB00IV
d@06I[5V/VJaI[5VdFKB0VJb00AR/FJbI[5V/@MR/@=V/@AR/A9R/09RT006H[1N/5j`G[1NT5jA15j@
1Uj?0ej>2ej?00ANSUj?GXmNS`9NKP9NK@INKPANK@04FViJKeY^FTh5FVd00eY^FVmJK`02FVl6FVh2
FV`2FVd:FTd00eI<ET]JBP02FT/2FT`2ET`00eH[ETYFB`03ETX2ET/4ET`2ER/01EI<ER]B:eH[DR/0
358/0e8[00=B;58[DP/0158[00AB2dh;CP]>2`9>309>2`04CPY>2dh;CP/3CPX3CP/01Dh:BPY9jTWZ
CNX00TgY00E:2Th9CPU=jDWZ00I=j@5Aj05=bP001PPQ0``Q0Pa10`Q10Pa100<8@@PQ22401@PQ0`Q1
00<<@@Q1224010PQ00X<@0`P320@02RR?FI>;5Z=GXiNK@=NK`03FVmNKeY_00=JK`EJL003GVmNL5i`
009NL0ENT0INT@9NT003GXmNT5jA00MNT@=RT@03HY1RSf:?00MRS`9RT0AR/@=V/@03H[5RTV:B00=R
/P04H[5R/V:bH[82I[82I[400fJ`I[5V/@02I[42I[84I[45I[800fJaI]9VdP04I]8016JaI]5VdFKA
1FKB0fKA00MVdVKCI]9Zdf[BJ]5VdP03J]401F[BJ]5ZdF[AI]801V[B00iZdF[bJ_9ZlVkbJ_9Zd6J_
HViNKV:@I[5VdV[C0f[c00QZdf[BK]5^dFkbK_5ZlF[b1F[c0V[b3V[c00=^lfkbK_<02f[c16[d16[c
0fkc00=Zm6kcK_<00Vkc00=^lVlBKa<00flC0VlD00=_4flDKa@01FlD16lC00M^lflCKaA_56lCKaA_
4`02Ka@2KaD00flDKa=_4`02Ka<2Ka@2Ka<2Ka801VlCKaA_56lDKaE_509c4`E_4`=_5005Ka=_56lC
KaA_4`02La@3Ka@3Ka<00g<DKaE_=P02Ka@00flCKaA_5005KaD00flDLaAc<`03Kc@3Ka<2Ka@2KaD2
Ka@6Ka<026[bJ]1J:FJ^Ka5g<FlBKa@7KaD2Ka@4Ka<2K_<3Ka<2K_<016[cKa=_4flC0f[c00A_4flD
KaA_50A_4`03Ka9^lVkb00=^l`07K_A_56lDKaE^mFkdKa800Vkb00I^lfkbK_=^lV[bK_<3Ka<00f[c
J_A_5007Ka<016lBJ_=Zlf[c0flC0VlB1V[b0f[c16[b00A^lVkaK_9^lPIZlP=Zl@05J_9ZlF[aJ_5Z
lP03J_45J_800f[BJ]5Zl002J]42J]800fKBJ_9ZlP03J_4016[BJ]5ZdV[B0VKB00=Zdf[BI]800VKB
0f[B00=VdV[AI]400VKA00=ZdF[BJ]8026KB00=VdFKBI]800fKA00=V/FJ`I]0016KA00AV/F:aI[5V
/@=Vd@9V/@AR/@03I[1V/F:a00aR/A1R/09RS`06HY1R/6:_G[1NT5jA15j@1Uj?0Uj>00=RSEj>GXl0
25j?00=NSUj?GXl00Uj?0Uj>0ei]1Ei^00QNK5i]GVeNKEY^FVmJKUY>1EY]00IJKUY_FVmJKeY?FTh4
FVh01EY]FTaJC5Y<FTd00UY]00=JCEY<FT/015Y=00=FC5Y<FT/00eY:00MJBeI<ER]F:eI<ER]FB`03
ETX01EI;ER]FC5I<ER`01UH[00=F:U8[DR`00e8/00=B:e8/DR`01E8/0U8[00=B:U8;DP/01E8;00AB
:dh;CP]>2`9>:`9>2`04DPY>2Th:CPX2CP/4CPX014gZBNY9jTWZ0TgY0Th900A>24h9BNY9jPE=j@5=
j05Ai`5Ab@000PPQ1@`Q10a200<<HQ1S36800PQ200<8@@PQ22401@PQ1@Q10`PQ00@<8@Q1340<808<
00069:<mIdh/FXiRSUi^0ei_00=JKeY`FW001UY`00=NL5Y`GW0015i`0Uj@4EjA00=NT5jAGY4015jA
00=RT6:?HXl01f:?00=RT6:aH[4016:a00=V/F:bH[800f:b00=R/F:bH[400f:b0V:a00=V/FJbI[40
0fJb00EV/FJbI[5V/FJ`009V/@MV/P04I]9VdfKBI]<2I[82I]800fKAI]9VdP03I]800fKAI]9VdP09
I]85J]83I]86J]803V[bJ_=ZlVlCKa9Zd6J@HViNKf:@I[5VdV[cI_@2J_@00f[cJ]9ZdP04J_85J_<2
J_8?J_<2K_<7J_<2K_<01VkdK_=Zlf[dJ_=^l`=Zl`=Zm003J_=Zm6kc009^l`04K_A_4flCKa<2Ka@0
16/DKaA_56lE1flD16lC00Q^lflCKaA_56lCKaA_4flD0flE0flD00A_4flDKaA_5@9_5003Lc=_=6lC
00E_5004Ka=c57<DLa@8Ka@00g<CKaA_5002Ka@00flEKaA_5002Ka<2Ka@00fleKcIc=@04Ka@5KaD2
La@9Ka@2KaD2Ka@2Ka<036lcKa=_4flCKcEZlEi;IZm^l6lAKa=_50M_5@=_509_4`04KaA^m6kcK_<3
Ka<2Ka@2Ka<01V[cJ_AZm6[dJ_=_4`9_50A_4`=^lP03Ka=_56lE009_5005Ka=_5FkeK_=^lP03K_<2
Ka<00fkbK_=^l`02Ka<2Ka@2J_@016lDJ_AZm6[c16lC0f[c0VlB1f[b00=Zlf[bJ_<00V[c00=ZlV[c
J_800V[b00=^lV[bJ_8016[c26[b00EZlF[bJ_9ZlV[a00AZlP05I_=ZdV[AJ_5ZlP03J]8016KBJ_9V
lf[B0VKA00EVdV[BJ]9ZdV[C009VdP03J]9VdVKB00=VdP04J_9Zlf[bJ]42I]401FKBJ]9ZlV[bI]80
16KA1fKB00=VdFKBI[401FKA00AV/FJbI[9VdP=Vd@03I[5R/F:a00=R/@03I[1V/F:a00IR/@=R/0AR
/@AR/004G[5R/6:`H[03H[42H[02HY000f:?HY1RT002GY001EjAGY1NT5j@GY4015j@1Uj?00=NSUj?
GXl00Uj?00=RSej@GY0015j?0ej>00=NSej>GVh01ei]0eY]00EJKUi^FViJKeY^00EJCP04FVeJKUY_
FW02FU0015Y?FViJKUY^0UY]15Y=0UY]00=JCEY<FT`01EY=00=JC5Y;FTX00UY:0UI:15I<00AFCEI;
ET]FB`=FC004ER]B;5H/DR`2ER`2ER/00eHZDR]B;003DR`00e8[DRaB;004DR`7DR/00e8ZDR]B2`02
DP/2CP/3CP`2CP/00e8:CPY>2P03CP/2CPX00dX:CPY=jP02BNX00dgZBNY:2P02BPX01Th:CNU=jTX:
CNU9jP9=jP03CNU=j57W005=b@0000<88@`Q32401@`Q1@a10Pa200<8@P`Q22400PPQ00<880PQ2240
0PPQ0`Q10PPQ00H88PPQ2248@0PP320220001QQR=DI:2eZ>FXeJKP=NK`03FVmNKeY`00=NL003FW1N
L5Y`00INL0QNT0INT@=NT0YNT@04HY1RSf:?HXh6HXl00f:@H[1R/003H[0016:aI[5RTV:B0f:b0f:a
0f:b0V:a0VJa0fJb00=V/FJ`I[001fJa0fJb16KB1FJb00=VdVKAI]401FKA1fKB0VKC00AZdVKBI]9V
dPeZdP9ZlP05J_5_4F[AJ[1RK`02GTh00f:?I]9Zd`03J_@016[cJ]=Zdf[c0V[b1F[c16[b16[c00=Z
lV[cJ_<016[c0f[d00AZlfkcK_=^l`EZl`9^l`9^lPQZl`03K_A^lfkb00=^l`06K_A_56kcK_=_4flE
0VlD00=^lfkdKa@026lD0Vkd00=^lflCKa<00VlD00I_4flDKa=^lfkdKaD2Ka@3Ka<00flDKaI_5@02
KaD2Ka@3Ka<00flDKa=_4`03Ka<6Ka@01flEKaA_56lCKaA^m6[d009_5@03LaA_56lC009_4`9_509_
5@M_5003KaE_56lD009_50A_5@E_5003KaE_56lD00E_4`09J_=[56[bIZmV[V[?Ka5_4flD00=_5@=_
=@9_5@=_5003Ka=_56kd00A^l`05J_=_4VlBKa9Zl`02J_@2Ka@00fkcKa=_4`05Ka<3K_8016kcKaA_
56lD0VlC0VlD00E^m6kbJ_9_4fkc00=_4`05Ka9_4flCKa=^l`03K_@4J_@00f[cKa=_4`02Ka<016lB
J_9_4VlB1f[b00=Zlf[bJ_<01F[c16[b2f[c0V[b00=ZlF[bJ_401V[a00IZlV[BJ]5ZdF[BJ]44J]80
0fKBJ]9ZdP07J]83I]8016[BI]9VdVKA0VKB00=ZdF[@I]0036KA1FKB00=VdFJaI[400fKA00AVd6KA
I]5Vd@9VdP=Vd@IR/@03I[1V/F:a009R/@04H[1R/F:aH[43I[02H[04H[46H[06HY0016:`HY1RT6:@
0ej@0ej?00=NT5j?GXl01Uj?0V:>0f:?15j?0ej>0Uj?00ANSUi^GXiNSPENS@ANK0=JK@03GVeNKUi^
009JKP0;GViNCEi=GViJCUY]FViJKeY`FU1JC`02FTh3FTd00eY]FTeJC@04FTd3FT`4FTd00eI<FTaJ
B`05FTX00eI;ETaFC009ET`01E9=ETiF;EH]ER`00UH[00=F:U8[ER/00e8/00=B:e8/DR`00e8/00=B
:dh[CPX00dh[0U8[00AB:U8[DRYB:P9B:`04DP]>34h<CP`2CP/0158:CPY>2Th:0Th;00A>2TX:BPY:
2PA9jP0:CNY>2Th:BP]:2TgZBNY:2TWZCNX3CNT1CNP1CLL1CLT000888@0332488PPQ00888@8<8@8<
@@05348<@@a2344<@P0222432202224232401`PQ344<@@Q122488P@Q00888@8<@00820000111<BE5
jeI^FViJK`9JL09JK`=NK`ANL003FW1NL5i`00=NL09NT003GY5NT5j@009NL003GY1NTEjA00ENT@AN
T0=NT@=NTPANT@9RT0IRS`04H[1R/F:aH[43H[02H[42HY89H[800f:aH[9R/@02H[400fJbI[5V/@03
I[06I[4:I[83I]800fKAI]9VdP04I]46I]83I]<00f[CI]9VdP02I]<00fKBJ]5Zd@07J]800f[CJ]9Z
dP02J_802F[aKa=^lf[BI[5RKV9]I[5VdP02I]<4J_<016[bJ]9ZlV[b0f[c16[b16[c0V[b1V[c16[d
00=ZlfkcK_<00V[c00EZdf[cJ_=ZlVkc009^lP03J_=Zm6[c009Zl`0;J_AZlfkdK_A^lfkbK_A_56kd
K_=_5003K_<00fkdJ_AZl`02J_@3Ka@00f/DKaA_5002Ka@016kdK_=^lfkc0VlC0VlD00E_4flDKa=^
lfkd009_5@=_5003Ka=^m6ke00=_5@9_50=_4`05KaA_4flCKa=_5002Ka<5Ka@016lEKaA_56lC0VlD
0flE0VlD00=_4flDKa@016lE3VlD00=_5FlDKa@00VlD00=c56lDKa@00flD0VlC00]c<flDJ_=ZlV[a
J]5RSf[?Ka5_4flD00U_5@04KaA_5FlCKa@2K_@3K_<3Ka<00flBJ_=Zm002J_@00flDKa=_4`06Ka<3
K_84Ka<00flDKa=_5002Ka@016lCKaA_56lD1FlC00=_56kdK_@00fkd0f[d0V[c0flB16lC00=_4V[b
J_801F[b00=Zlf[bJ_<02F[b36[c0f[b00MZlF[bJ]9ZlV[aJ_9Zl@02J_8016[BJ_5ZdV[A2F[B00=Z
dF[BJ]800V[B00=VdVKAI]800fKB16KA0V[A0VKA1FKB1FKA0fKB0VKA00=V/VJaI[800fKA00IVd6KA
I]5VdFKBI]43I[4<H[43HY42IY000fJ?I[1R/005H[43H[000f:@HXmRT002HY001F:?HY1R/5j`H[00
0V:@00ARSf:>HXmRSP9NS`03GY1NSej?00INS`03HXmRSV:>009NK`=NS`ENSPANKP04GXiNKUj>GVh5
GVd01EY]FVaJKEY^FVd015Y^00IJCUi=GTeNCEi^GVd2FVh00eY_FTmJCP02FTh01EY]FTeJCEY]FTd0
0UY<2UY=0UI<00=FBeY:FTX00UY:00=FBUI;ET`025I<0UI=00EBCe8^ERiF;EH/00=F:`YB;004DR]>
:e8[DRX7CR/3DR/2DP/00dh<CP]>2`02CP/5CPX2CP/014X;BPY:2TgZ14WZ00U>2U8:CP]>2TX;AN]9
jdWZCNX00TgY00==j4g7CLL00Dg900000`Q122488@05224010`Q344<@@a210a100<88@PP22000PPP
00@<80a0340<@0H88@0=12488@Q1320<@0`P200@@S46BN]FKUj`FVl00UY`0UY_0Ui_0Ui^00=NKei`
GW000Ui`00=JL5i`GW000Ui`00=NT5jAGY000Uj@1ejA0Uj@00ANL5j@GXmNT0=NT@=NTPANT@9NT0MR
S`=R/@=R/09R/@04HY9RTF:BH[82H[43H[88H[42I[42I[02I]000fJ`I[5V/@04I[400fJbI]9V/P07
I[800fKBI]5Vd@05I]4=I]8016KCI]9ZdF[A1f[B00EVdV[BJ]9ZdV[b009ZdP9^lP07K_5Z/6J>GTeR
KfJaI]800f[b00AZlF[AJ]5Zl@UZlPMZl`03K_=Zlf[c009Zl`=Zm004J_=^lf[bJ]84J_82J_<00fkc
K_9Zl`04J_<01V[dJ_=^m6kdK_=^lPI^l`9Zl`03J_A^m6[d009^m0=_5003J_AZlf[c009Zl`I^l`07
Ka=_56lDKaA_4fkcK_@016lD0Vkc00E^m6keJ_EZm6lD00e_4`9_509_4`9_509_4`=_50=c50=_4`=_
509_5@03KaA_4fld00A_50A_4`03La9_4g<C009_5004K_=_4flDKa<4Ka@5Ka<026lBJa9ZlV[AHViV
SFk`Ka<5Ka@2KaD2Ka@00flEKaA_5002Ka<4K_<2Ka<00flBK_9^lP03J_<2J_@2K_<8K_87Ka<5K_<0
0fkdKaA_4`03Ka<7K_<5J_<FJ_82J_47J_800f[cJ_9Zl`05J_<2J_82J_42J]801F[bJ_5ZlV[aI_40
0f[a16[A1V[B0f[A0f[B0fKA00=Vd6KAI]400fKB16KA00=Zd6KAI]800fKB00=VdFJaI]400VKA0VKB
0VKA0fJa00EVdFKBI]9VdFK@009V/09Vd@9V/@9R/0IR/@9R/0ER/@9RT@9VT003I[1R/6:_009R/0=R
/@9R/003HXiRSf:?00=RS`9RT007H[1N/6:`HY1RSf:>HX`00V:>0Uj>1Uj?00ANSUj?GXmRS`9RSP=N
K`=NSP03GViNSUj>00INKPMNK@07FVaNK5Y/FVeNKEi/FVd00UY^00UJKEY=FTaNC5i=FVeNKEY^FVd0
0eY>0eY<0eY=00=JBeY<FT`00UY=00=FC5Y=FTd01EY=0UI<00AFBeY:FTYJBP9FBP03ET]F:eI<00=F
C00:ER]FC5I<ETaFCEH]DTiB;UH^ERd2DR`015H[ERYB:e8[1e8/00MB:dh[DRYB:U8YDR]>:`03CP`0
0dh;CR]B:P04DR/4CP/8CPX014X;CPY:2TgZ14WZ00=:2TGZANX00TWZ0TG[00=9jdWZBNX00TWY0DgX
0Dg70Dg900000`a122488@0422400`PR224<8@05344010Q122488@PQ0PPP00<<80a134400Pa11@PQ
00<48@PQ24400Pa000L@HA1R46<a1DG:EVmJS`03FW001Ei_FW1JL5Y_GVh015i_00=JL5i`FW000UY`
15i`0ej@25jA00ANLEj@GY1NT0ANT@=NTPINT@03GY1RT6:@00ART0QR/@AR/P=V/@04H[5R/V:bH[83
H[4026:bI[5V/VJaI[9V/FKBI]46I[43I[800fJaI[9V/P02I[801FKBI[9V/VJcI]800fJa00=V/VKB
I]800VKB0VKC1VKB00=VdfKBI]800fKB0V[A0f[B0VKB0f[C1F[B00=ZdF[BK_800Vkb00UZd69^HViR
KfKBI]=Zlf[bJ]400V[B16[b00=ZdV[cJ_<02F[c00AZm6kdJ_=Zd`MZl`03K_=^lV[b009ZlPAZl`03
K_=Zlf[c00=Zl`05J_AZlf[dK_=^m007K_<2J_<016kcK_AZm6kd0VlD00=^m6kcJ_<00f[c00EZm6kc
K_=^m6lC00=^l`04Ka=_56lEKa@2K_@016[dKaA_56lD0Vkd00A_56kdJ_AZm0E_5003Ka=_56lD009_
5004Ka=_56lCKa<2Ka@016lCKaA_56lD0VlC1FlD00Ac56lCKa=_4`I_5003La=_=FlD00=_509_4`03
La=_=7<C009_4`03KaAc56kc00I_5003K_A_4flC00=_4`08Ka9ZlVkaJ]1RKV9;K_1_=09_4`=_50=_
5@I_509^m0=^l`04Ka9^lVkbK_84J_<3Ka<00flBK_=^l`02K_<4Ka<3Ka@2Ka<00fkbK_=^l`04K_<3
Ka@4K_<01FkbK_=^lf[cK_<016[c00=[4f[cJ_<01V[c36[b00AZlF[bJ_5Zl@MZlP03J_=ZlV[c00AZ
l`03J_9Zlf[b009ZdP=Vl`IZlP04J_5ZdV[AJ_83I]801V[CJ]9ZdV[BJ_9Zd@9ZdP06I]9VdFKAI]5V
dV[A0fKA0VKB0VKA0VKB00=VdFKBI]800fKB2VKA00MV/VKBI]5VdFKBI]5Vd002I[000fKAH]5R/@02
H[42I[44H[43H[06H[42HY04H[05H[42G[42GXl3HXl3HY0016:`G[1NT5j?0V:?00=RSEj>GXh025j?
00ANSUj?GXmNSP=NS`03GVmNSej?009NS`03GViNSUj>00=NKP03FViNKUi^00ENKP03FViNKEi^00=N
K@9JK@EJKP03FTeJC5Y<009JK@03FViJKEY^009JK@9JC006FTeJKEY]FVeJCEI<0UY=00=FC5I=ETd0
1EY=0eI<00=FBeI:ETX00eI:00=FBeI<ET`01EI<0eH]00MF;58]DRiB;U8]EReF;002ER/2DR/7DR`0
0dh[DR]B:P02DRX00e8[CP]>3002CP`:CP/7CPX2CP/3BP/014X:BP]:2dX;0TW[00E5jTG[BNY9jdG[
0095k006AN]9jTWZBNY=jDg70Dg:00001PQ022088@PQ22888@888PP88@H8800332088@`Q00D88@04
24488@Q1240234003A1Q468@HRST>HQ>CeY]FVmJL5Y_GViJKei_009NKP9NK`05FVmNKeY`GVmJL005
GW05GY06GY42GW42GY00169`HW5RLF:A25jA26:A00=RT6:aH[400V:a16:A26:a0V:b0f:a00=R/V:a
I[001VJa0fJb0VJa00AVd6KAI[5R/@9V/@AV/P05I[5V/VJcI[9V/@04I[85I]<2I]801F[BI]9VdVKB
I]<016KB00AVdF[AJ]5Zd@9ZdP9VdPAZd`IZdP08J]5ZlF[AJ]1ZdFZ`I[1V/@9VdP=ZdP07J_9^lVkb
K_9^lF[BJ]<00f[c00=ZlV[CJ_<00f[c00=^lf[cJ_<00V[C1f[c00=^lfkbJ_800V[b2f[c00=^lfkd
K_<01Vkc0f[c00=^lfkbK_<026kc0V[d00IZlfkcK_=^lf[cKa82K_<01flCKaA_56lDKaE^m6[d00=_
50A^m0I_509_4`E_5003K_A_56lC00I_50A_4`A_509_4`03KaA_4flC00E_4`05KaA_4flCKa=_5007
Ka<4Ka@3KaD3Ka@2Ka<03VlBK_9^lV[bJ_5^lF[@IXiRBfk`LcAc<W<BKa<:Ka@2K_@00fkcK_9^lP03
K_800f[bK_9ZlP02K_801FlBKa=_4VkbKa800Vkc0VlC0Vkd0Vkc00=^m6kcKa<00flC0fkc00=^lVkc
K_@00Vkd00=Zm6kcK_<01Fkb00=^lfkbKa800flB00=ZlflCJ_@00f[c00=Zm6[cJ_<00f[c1f[b00AZ
lF[bJ_9ZlP9Zl@AZlP03J_5ZdF[b009ZlPAZl`IZlP9Zl`0:J_9Zlf[cJ_9Zlf[bJ]9ZlF[AJ]84I]80
1F[CJ]9ZdV[BI]800f[A0fKA1F[A0VKA00=VdVKAI]401VKB0fKA16Ja1fKA00=Vd6KAI[400VJa00IV
/6K@I]1Vd6J`I[48H[4>H[000f:aH[1N/@04GY06HY000f:AHY1RS`02GY03HXl00f:=GXiNS`08GXl0
0ej>GViNSP09GXl015i^GXiNSUj>0Ui^00=NKei^GVh01Ei^00IJKUi]FVeJKUi^GVd3FVd5FVh2FVd3
FTd01eY]FVaNJeY/FTaJCEY]009JKP03FVeJCEY=00AJC@9FC@MFC004ET]FBUI:ETX2FTX015I;ETaF
C5I<15H[00YF;5H]ERaF:eH/EReB;UH^DReF;0=F:`03ERYF:eI;009BB`=B;09B:`=B:P9B:`04CR]>
34h<DPX2CPX01Dh;CPY>2U89DPX00dh:0U8:14h:14h;00=:2dX:BP/00dW[0TWZ0dW[0TG/0TW[0dWZ
0DgY0DgX0DW;000>224322092243244010PQ2448@@Q10PPP00T8@0aQ368<@RC4=FQ:;UZ=FVl00UY`
1Ei_0UY_0UY`00ENL5i_GVmNL5Y`00=NL09NT003GY5NT5j@00ANT0ANL@06GW1RL69`HY5RL6:A2EjA
1f:A1F:a16:A0f:B0V:a0V:b00=R/F:bH[8016:b1F:a0fJa0fJb00EV/FJbI[5V/VJa00EV/P03I[5V
/VJb00MV/P=VdPAVd`9VdP03J]5Z/FKB00AVd`EVdP9ZdPMZd`MZdP09J_9^lFlCJ_5ZdFJ@HY1V/F[C
00=ZlP04K_9ZdV[BJ_83J_<016[bJ_=ZlV[C0V[c0f[b0V[c0V[d26[c1Fkc1f[c16kc00=^m6kcK_<0
0Vkc1F[c00=Zm6kcK_800Vkc0Vkd00E^lflDK_A^m6kc009Zl`05J_A_56lDJ_A_5004Ka<2Ka@2KaD2
J_@016lDJ_AZm6[d0Vkc00=^m6lDKa@00flD00=^lfkdKa<00VlC16lD00M^m6kcK_=_56lEKaA_5@02
Ka@3Ka<;Ka@016lCLa=c4flD2flC0VlD0flE0flD0VlE00=_56lCK_<00fkc00U[4flCJ_9Zd6J=K_5c
=7<cLa<00W<D00=_56lEKaD01VlD0Vkd1Fkc00I^lV/CJ_9ZlVkbKa84K_800flBK_=_4`02Ka<3K_@2
K_<00flBKa=_4`03Ka<3K_<01FkdK_=^m6kcJ_@00Vkc00U^lVkcK_9^lfkbJ_9^lf[cJ_800VlB1V[c
00=Zm6[cJ_<00f[c0V[b00=Zlf[bJ_800V[b00=ZlF[bJ_800f[b00EZlF[bJ_9ZlV[a00]ZlP03J]9Z
lV[b009Zl`9ZlP03I]9ZdV[B009ZdP03J]5VdV[b00AVdP03J]=ZdVKB00AVdPIVd@03J]5ZdV[A009Z
d@IVd@=VdP=Vd@03I[9V/FJa00=V/@EVd@03I]1VdFJa00=V/@AV/0IR/@04H[1R/F:aH[45H[000f:a
H[1R/007H[000ejaGY5RT00;HY000ej`H[1RT002HXl016:>HXmNSej@1Uj?00=RSUi^GVh01Ej?00EN
SUi_GVmNKej>009NS`03GY1NKeY_009NK`03GViNSUi^00ANKPEJKP04FVeJKUi^FVh4GVd015Y]FViJ
KUY^0UY=0UY]00=JJeY]FV`00UY]00=FCEY]FVh01UY=0UI=1eI<00=FBeI:ETX00eI:00=FBeI<ET`0
0UH/0eH[0eH/00AF:eH/EReF;@9B;@9B;09F:`9F:P04ER]B:e8[DT`2DR`5DR/3CR/2CP`01U8:CPY>
2Th;CPYB2P9F2@04CPY>:dh:DPX2CPX2DPX2CPX01Th;CPY>2Th:BPY:2`=9j`99jP03BN]5jdG/0095
j`03BN]5jdWZ0099jP99j@59k0002PPQ00@880PQ22488@D880P88@06244<@@PQ34048@@00PPP00`8
@0aQ368@@RC5=FQ:;UY]FTiJKeY`FVl4GVl2FVl00eY`GW1NL002GVl00eY@FW1JL003GW000ej?GY1N
T002GY001Ej?GVmNL5i`GW400Uj@0Ui`0V9_00=RL5j@GY400UjA0ejB00=NTF:AHY400f:A00ART5jA
HY5RT@AR/@03HY1RTF:A009RT@9RTP06H[9R/F:aH[5RTEjA1F:a00=R/V:aH[400f:a0fJa0VJb3FJa
1VJb0VJa0VKB00=VdFKBI]<00VKC00IVdV[BI]9ZdFJaI]83I]<4I]82I]400fKBJ]9ZdP02J]82J]<3
J]800f[bJ]9ZdP02J]802F[AJ_5^lFk`J]5V/69_HW1V/@02J]400f[aJ_9ZlP02J]86J_800f[CJ]9Z
d`04J_800f[BJ]=Zd`0;J_<3K_<2J_<2J_@00f[cK_=^l`08K_<4J_<01FkcJ_=ZlfkcK_800Vkc00E^
m6kcK_=^lfkd00=^l`A_5004J_A^lfkcK_<2Ka<00flDKaE_5@02J_@016lDKaEZm6[d0fkc1FlD1Fkc
00=_4flDKa@00VlD0Vkc00=_4flDKa@00Vkd00A^lflCKa=_4`M_5003Ka=_56lC009_4`05La=c4VlC
Ka=_4P09Ka<00flDKa=_5005Ka@00flEKaA_5004K_<03F[cJ_9ZlflCJ]5VSV[AK_5c<VlCKaAc4flC
00Y_5003K_A^lfkb00=^lP03Ka9^lVkb00M^lP9_4P9^l`=^m004K_=^lVlAKa83Ka<01V[cJ_9^lfkb
K_=ZlP9^l`03J_A^lf[b00E^lP9ZlP03J_=_4VlB009_4`9ZlP03J_=ZlV[b00AZl`03J_9Zlf[b00IZ
lP03J_5ZlV[b00AZlPIZl@9ZlPAZdP9ZlP06J]9ZlV[cJ_=ZlV[A0fKB16[B00=ZdFKBI]802FKB0V[B
00AZdFKAI]5VdPAVd@03J]5VdFKA00aVd@04I]9V/FJaI[03I[43I]400fK@I[1V/@04I[401VKAI[1V
/6J`H[1R/@=V/@9R/@MR/003HZmR/F:`00ER/004HXmR/6:`G[43H[000f:_HXmR[`02H[0026:@HXmR
Sf:?HY1N/5j@GXl2HXl015j>HXmNT5j@0Uj?16:?00=NKUj?HXh015j?00ANSUi^GVmNK`9NKP9NSP03
GXmNKeY_009NK`ANKP06GXeNKUi]FTeJKEY^0UY]00MNKEY^FVeJCEY]FViNK002FT`015Y^FVeJCEY]
0Ui]00AJKEi/FVaJK09JC003ETeJKEY^00IJC@UFC003ET]FBUI:00=FBP03ET]FBUH[009F;0EF:`03
ETaF:e8/00=F;0=B;09F:`9F:PmB:`07CR]B2Th:CPY>2dh:DPX00U8934h:00A>2DX:BPY:2PE9jP03
BP]5jdG[009:2`03BNY5bDWZ0099jP99j@59j`0040PQ0`PP20PQ0Pa100D880`P22088@PP0088@08<
@@09448LY357APiJCEI=FVmJL5Y^00ANK`9JK`07GW1NTEi`GW1NKei`FW000Uia0UjA00ANT5jAGW5J
T@=NS`04GY1NL5i`GVl6GY04GY44GY800ejAHY1RT@02HY43GY400f:AH[5R/@02H[45HY42H[400f:b
H[5R/@07H[43H[8016:aH[9R/F:a0fJa00=R/FJaI[400fJa00IR/FJaI[5V/FJbI[42I[8016:bI[9V
/VJa0fJb00IV/FJbI[9VdVKAI]84I]<2I]800fKAI]9VdP05I]<2I]83I]45I]82J]<016[BJ]=ZdV[C
0VKB0V[B00=ZdF[bK_400V[b00AVT69_HVmZ/@9ZdP9Zl`9ZlP03J]9ZlV[b009ZlP03J]9Zdf[C009Z
dP=ZlP05J]9Zdf[CJ_=ZlP09J_<00f[bK_=^l`06J_<00fkcK_A^l`04K_<3J_<016[dJ_=Zlfkc1V[c
0fkc0Vkd0fkc0V[d16lD0Vkd0VlD0VlE2F[d00QZlf[dKaA_56kdKaA^m6lD0fkc00A_4flDKaA_50=_
5@9_509^m09_5@A_4`03K_A_56lC00I_50=_4`03Ma9c4W<B00a_4`9_509^m005KaA_5FlEK_E^m003
K_<00f[cJa=Zl`02J_<01FKAHXiV/6[aKa800VlD00=_5FlDKaD00VlE1flD00=_5FkcK_<00Vkc00A^
lV[bJ_9ZlP=^lP9^l`9_4`03J_=^lfkc00E^l`05K_9_4flCKa=_5003J_@01F[cK_9ZlV[bJ_<00V[d
0Vkc0fkb00=^lf[cJ_<00V[c00EZlV/CJ_9ZlV[a009ZlPIZl`03J_9Zlf[b00=ZlP04J_=ZlV[cJ_<:
J_801F[cJ_9ZlV[bJ_<016[b0f[B0f[b00=ZdVKBI]800VKC00=VdV[BJ]803VKB00=ZdFKAI]400fKB
1FKA00EVdVKAI]9VdVJb00EVd@04I]9VdFKBI[84I[45I]42I[400f;AH[5Rd@02I[400f;AH[5R/@08
H[4026:`H[5R/F:aH[1R/F:`H[43H[03H[4016:`G[5N/Eja1F:`0V:_00=R/6:?HXl00V:?00=NT5jA
GY400UjA1Ej@15j?00ARSf:>GXmNSPANS`9NK`03GViJKei_00ANKP03GXmNKeY_009NK`0:GViNKei_
GViNSUi_GViJCUY]FVh3FVd3FVh2FVd01EY/GVaJK5Y^FTd015Y<00IJKEY=FVeJKEY^FVd2ETd015I>
FTeJCEY=0eY_00=JCEY<FT`01eI<0eH[0UI;00=FC5H[ER/00UH/0eH[00EB;5H[ETaF:eH/00=F:`03
DRaB:e8/00=B:`03ER]B:e8[00AB:`05DRaB:e8[CP]B:`04CR/3CP/00dh:CP]>2P04DPX014h;CPY>
2dX;0Th;1Dh:00=>2DX:BPX00TX:00E:2dW[BN]:2TW[0095j`04BN]:2dX:BN/4BNX1BNT1AL/00007
344<8@`Q324<@@`Q32000PPP0PPQ00<48@PQ22400`PQ0PPP1`PQ0`a10P`P0`PP00d88@PP340880`P
688a9DX<FTeJKEY^FTiNKP08GVl01EY`GVmJL5i_FW000Uia00=NL5Y`FW000eYa00=NKej?GY000Ui`
00=NKej>GVl01Ej@0Uia1UjB00=NTF:?HY000f:A0UjA00ARTF:@HY1R/@9RT@04GY5RTF:AHY02H[42
HY400f:aHY5RT@05H[45H[800f:aI[5V/@07I[44I[84I[42I[800fKBI[5V/@02I[44I[800fKBI]5V
d@02I]82I[82I]82I[46I]85I]45I]800f[BJ]=Zd`03J]<2J]82J]42J]83J_8016[BI[5V/FJa0V[B
00IZdf[bJ_9ZlV[BJ_82J_<3J_800f[BJ_9ZlP02J_800f[BJ_9ZlP06J_84J_<00fkcK_9^l`02K_<5
J_<2K_<00f[CK_=^lP04K_<4J_<2K_<00f[dKa=_5004K_<016kbK_=^m6kc0Vkb16kc00=^m6lDKa@0
16lD1f[d1fkc00=Zm6kcK_<00Vkd00A^lflCKa=_4P9_4`M_5003K_=^m6lD009_50U_4`03KaA_4flC
015_4`=_50=^m004KaE^mFkdK_@2K_<01V[bK_5ZlF[bJ_=Zd09RSP05J_5_4VlCKaA_5@02Ka@2KaD6
Ka@00flEKaA_4`02K_<5J_<3K_<016[cK_=ZlflC0fkc00=_4fkcK_<00fkc00=^lVkcK_<00VlD00=Z
m6lDKa<00fkb0f[c16kb0fkc00AZlfkcK_=^lPIZlPIZl`EZlP9Zl`04J_9Zlf[cJ_<4J_84J_<01f[b
J]9ZdV[BJ]5ZlV[a009ZlP04I]9ZdV[BJ]42J]82J_82J_<00fKcI]=Vd`0?I]84I]4016KBI]=VdV[@
16KA00=VdVKAI]800VJa2FKA1VJa16KA16;A00IR/FJaI]5V/F:aI[42I[05H[4016:`H[5R/F:a1f:`
0f:a00AR/5jaG[5N/@AR/005HZmR/6:_HZmRT004HXl00ej@GY5NT@02GY82GY42GY001ej?GXiNSEj>
GVeRSF:>009NS`03GXiNSej?009NK`=NKP03GVeNKUi^00=NKP=NK`9NKP04GVmNKUi]FVh2FTh00eY]
FViJK@04FVd3FV`015Y[FVaJC5Y]2EY=00=JCUY]FVd01EY=0eI=00=FC5Y<FT`035I<2UH[00AB;5H[
ER]F:P=F:`03ERYB:eH[00AF:`EB:`05DRaB:e8[DR]B:P02DPX014h;DPYB2U8:0Th:00=>2dh:CP/0
0e8:1Th;0dh:0dh900==jDWZBPX00dWZ00A5jTWZBNY9jP95jPA9jP99j@5=j@5=j059b`001@a100@<
8@`P224880@88@0324488@PQ00L88@0412488@PQ2442344010`P22088@PP0PPQ00`400`P200801AR
=BE5jeH]GXiNKei=GVh2FVl6GVl2FW000eYaFW1JL002GW43GW03FW43FW0025ZAGW1NKej>GVmNSejA
GY02GY4015iaGY1NTEjA0ejB0UjA00ARSf:@HY1RT@=NT@05HY5RT6:@HY1RT@03GY400f:AH[5R/@02
H[4016:AH[5RTF:A1F:a1F:b00=R/FJaI[4016Ja1fJb16Ja16Jb0fJa16Jb00=VdVKAI]801FJb00AV
dVKAI]9V/PEVdP=Vd@MVdP03J]9Zdf[C00=Vd`9ZdP06J]5ZdV[BJ]9ZlV[c0VlD00AZlV[BI[5V/@9V
dP9ZdP=ZlP9Zl`04J_9ZdV[BJ]82J_800f[cJ_9Zl`07J_800f[cJ_9Zl`02J_<2K_801FkcJ_=Zlf[c
J_800f[c00A^lVkcK_=Zl`9^l`03K_9^lfkc009Zl`09K_=Zlf[cJ_=Zm6lDJ_AZlfkd00A^l`03K_A^
lfkb009^lP9^l`03J_=^lf[d00E_50MZm003K_=^m6kc009^l`03K_A^lf[d009Zm0=^l`A_4`9^l`03
K_A_56lD00=_50A^m09_50=_4`9_5004Ka=_56lDKa@?Ka<017<CKa=_4flC0VlD0Vkd0flE00=ZmF[d
Ka@00VlD00=_4flAK_400V[A00QZcfJ^HXmVdV[cKaA_5Fle1VlE16lD0VlE00A^m6[dJ_=Zm0=Zl`04
J_AZlfkcK_<2J_<01F[dK_=^lfkcKa<02Fkc0VlC0VlD00E_4f[cJ_=Zlf[d009Zl`EZlP9^l`05J_=^
lfkcK_9^l`05J_85J_<6J_86J_<3J_87J_<01F[BJ_9ZlV[bJ_400V[b00=Vlf[bJ_8016[b00=ZdVKB
I]800fKC00AVdVKCI]=Vd`YVdP=Vd@EVdP03I]5ZdVKA009Vd@03I]9VdFJb00=V/@9Vd@03I]9VdFKA
009Vd@EV/@EVd@=Rd@03H]9RdF:a009V/@9R/@03I[5V/6J`00AR/@9R/003H[5R/V:b00=R/@AR/0=R
/@03H[1N/Eja00EN/@03HZmR/6:^00IRS`03HY1NTEjA009NT@05GY1NTEj?GY1NS`02GXh3HXh00ej>
GXmNS`02GXl015j@GVmNKej>0ei_1Ei^0ei_0Ui]00MNKei^GVeJKEi^FViJK@06FVh01UY]FVaJK5Y/
FVeJK0EJK@03FTeJCUY=009JC@03FTiJCEY=00IJC@9FC@EFC003ETeF;EH]00IFC0]F:`03ERaB;58/
009F:`05DRaF:eHZERYF:`09DR/01E8/DR]B:e8[DRX00U8:00=>2e8:DRX00e8:0dh;00=B2Th:CPX0
1Th;0Th:0TX:0Th90TgY00E:2TWZBNY9jTX:00I9jP9=jP05DNY=jTgYCNQ=b001CLX00005340<80a1
344<H@0232001`PP24088@a1244<@@Q1008<8@@88@0322088@PP00D88@0332488@PP008880042244
00PP3202200021AQ=B=5bEY<GXiJCUi=FVd3FVh5GVl5FW03GW0015Y`GVmJL5ia15Ya011JTEi`GVmN
SEi^GVmNL5j@GY5NLEi`GXmNTEj@GY5NTP9NT@05GY1RSf:?HXmRT002GY400f:AHY1RS`03HY0016:A
GY5RTF:@0f:`00=R/F:AHY400f:A1f:a00=RT6:aI[4016Ja00=V/VJaI[401VJa00AV/6JaI[5V/@AV
/PIV/@9VdP03I]5VdVJb00AV/P05I]9VdFKAI[5V/P04I]83I]43I]800fKAI]9VdP02I]82J]83I]<8
J]8026[bJ_=ZlV[bJ[5RT6JAI]83J]82J_82J_<016[bJ]9ZdV[B0V[b00=ZdV[bJ_800V[b0V[B00EZ
lV[BJ]9ZdV[A009Zl`03J_9^lVkb009^l`9Zl`04J_9ZdV[bJ_82K_801F[BJ]=ZdV[CK_800Vkc00UZ
lfkcK_=^lf[cJ]=VdV[cK_@01fkc1Fkb00=^lf[cJ_<016kc0VlD0f[d00AZlf[dJ_AZm0U^l`06J_A^
lfkcK_9^lfkb0VlB0fkc00A^m6lDKaA_50=_4`04K_=^m6kdK_@2Ka<2K_<2Ka<4Ka@3Ka<3K_<9Ka<0
2W<BKa=_4flCK_A^lfkdKaE_56kd0V[d00m_56/DKaA_4VlAJ_1ZdF[?J/eRSUi>I]5ZlVleKc@00flD
00=^m6[dK_@016lD0VlE00E^m6kcJ_=Zlf[d00EZl`9^lP07J_9^lf[dJ_A^lflBKa<01Fkc16kb0VlB
00=ZlflCJ_<00f[b1F[c00AZlVkcK_9^l`9Zl`9^l`03K_9ZlV[b00AZlPQZl`=ZlP05J_=ZlV[bJ_9Z
l`04J_8016[cJ_9ZlV[b16[c00EZlV[aJ_5ZlF[B00AZlP=Zd@9ZdP03I]9ZdVKB00=VdP03I]=VdVKB
009VdP03I]5VdVKB00AVdPAVd@EVdP9Vd@03J]1Vd6K@00=Vd@04I]1V[fK@I]84I]44I[400fJ`I]5V
/@04I[400fKAI[1Rd@02H]401VKAH[5R/F:aH[1R/@=V/09R/@AR/003H[5R/V:b009R/P9R/@03I[1R
/F:`009R/@04H[1R[ejaG[42H[43G[42HZl00f:^HXiRSP02HXh2HXl2GY02GY400ej@GXmNT003GXl0
25j>GXeRSF:=GXiNKEi^GXh2GXl4GXh3GVl00ei^GVeNKP02GVh2GVl00ej>GXeNK@02GVh01Ei]FVeJ
KEY]FT`00UY]0UY^0UY]00IJK5Y[FV]JJeY/FT`6FTd00eY>FTeJC@02FTd00eI;FTaJC002FTd:ET`0
0eI=EReF;@02ET`@ER/2DR`4ER/3ERX00e8[ER]B:`07DR/01dh[DR]B:e8ZCPYB2Th;00EB2P03CP]B
2Th;00=>2P=>2`03BP]>2dh;00A>2PA>2@05BPY=jDWZBNY:2P0:BNX00dWYCNQ=a`01CLX00003340<
80a1008<HP04344<80PQ344236800`aS348<@@0234400``Q22488@02124:2242220010@P22488@a0
0PP000DD@3D2AJQNJej>009JCP03GViJKeY_009JK`9NK`9JD09JL004FW5JL5Y`FW03FW42FW000ei`
FW1JL003FW000ei`GVmNSP02GXl015jAGY1NLEia0Uj@00ANTEj@GY5NT@=NT003HXmRT6:@00=NT@9R
T@04HY1RTF:AHY03HY400f:aH[1R/002H[43HY4:H[42HY48I[43I[82I[400fJ`I[5V/@05I[87I[40
1fKBI[5VdVJbI]=VdVJb009VdP03I]5VdVKB00EVdP=Vd@=VdP=Vd@AVdP=Vd`9VdP03J]9Zdf[B009Z
dP0:J]=Zlf[cJ_9Zlf[BI[5RT6J@I]82J]83J_85J]800f[bJ]9ZdP02J_83J]800f[cJ]=Zd`02J]80
1F[bJ_=Zdf[CJ_800Vkc0Vkd00=Zm6[cJ_8016[b00EZdV[CJ]=ZdVkb00M^l`03J_=Zm6kc009Zl`E^
l`E^lP04K_=^m6lDKa@4K_<00f[dJ_=Zm008J_@3K_<3K_@01VkcJ_A_56lDK_A_50=^l`04J_=^lf[d
J_@6Ka@00fkcK_A^m002K_@2K_<016kdKaA_56lE1VlD00=c56lDKa@00flD00=_4flDKa<00flC0VlD
00M_4flDK_=^m6lDJ_A^m002J_@2KaD016/EJaA[56lC0V[a00aZcV[=HXeJ;V:>J_9_=F/EKaEZm6kd
Ka@3KaD2Ka@3KaD00fkdK_=Zm002J_@016[cJ_AZm6[d0V[c00A^lVkcK_=Zl`9Zm004Ka=_56lCJ_@6
K_<00fkbKa9_4P02J_<016[dK_=^lfkc1V[c00=Zm6[cJ_<01V[c00=ZlV[cJ_8016[c00=Zdf[bJ_<0
0f[c36[b00EZlf[bJ_9ZlV[c00AZlP03J_5ZlV[a00IZlPAZdP=VdP05J_9Zlf[cJ]=ZdP0=I]800f[A
I]9VdP05I]84I]4016KBI[5VdFKB0fKA00=V/FKAI[400fJa0fKA1FJa00=VdFJaH]4016;A26:a1F:`
00QR/F:bH[9R/F:bH[5R/V:a0V:`0f:a00=R/5jaG[401Eja00ER/5j@HXmRSf:>00ARS`ENT0ENS`08
GXiNSEj>GXiNSej>GViNSP=NK`04FVmNSej?GY02GW02GVh00ei]GViNKP02FVh00ei_GXiNS`02GVh0
0ei]FViNKP05FVh3FVd015Y^FVaJC5Y<0eY]1EY=00IJCUY=FTeJCEY<FT/2FT`00eY=ETeFC@09ET`0
0eI>EReF;@02ET`00eI:ER]F:`04ER/2ET`7ER/6DR`2ER/00eHZDR]B:`06DR/2DP/3CR/00e8[DP]B
2P03CP/00e8:DRYB2P02CPX7CP/014h:CP]>2dX;14X:0Th900=:2DX:BPX01DX:2DWZ0DWY0Dg80DW:
00000`a0320<@@02344010PQ220880PP30PQ0PPP10PQ00T8@@`Q224880@022088@`Q32000Q1000/<
8110<>91QUiZGXeJL5i?GViJKeY^00AJK`=JL09JK`9JL004GW1NLEY`FW02GVl01ei^GVmNKUY_GY1J
Kej?00ANK`ANT004GY5NT5j@GXl5GY000f:?HY1RT003GY43HY400ejAHY5RT002HY0015j@HXmR[f:@
3V:a16Ja0fJA0VJ`00=V/FJbI[800VJb0VJa00=V/6JaI[000VJa0VJb0VJa00=VdFK@I[401VJa00IV
/VKBI]9VdVJbI[42I]43I]800fJbI]9VdP0:I]42I]800f[BI]9ZdP03I]800f[BJ]=ZdP02J]<00fKC
I]9VdP02J]8026[bJ]9Z/FJ@I[5ZdF[aJ_8<J]83J_800f[cJ]=Zd`05J]8016[CJ_9^lfkb0V[B00EZ
df[bJ_9ZlV[B00AZlP9ZdP03J_9Zlf[c009Zl`05J_9^lV[bK_=Zl`04K_<:K_800fkcJ_=^l`04K_<2
J_<016[dK_=^lfkd0flD00=^m6kcK_<00Vkc16kd0VlD00=Zm6kcK_<00Vkd1Vkc0Vkd0VlD00A^m6kc
K_A_50M^m003J_A_56lD00Q_5005Ka=_56lCKaA_4`05Ka@00fkdK_=^l`03Ka@00fkdK_=^l`03J_<0
3VlCJ_9ZlV[bJ_5ZkVl=IZiJ;Ei<J_5_=FlDK_<3K_@6Ka@026kdK_=^lfkcJ_A^m6[dJ_<4J_@01F[c
J_9^lfkcK_@00Vkc00A_4VlCKa=Zl`=^l`04K_A^lfkcK_82Ka82K_<016[dK_=^lfkc1F[c00=Zm6lD
Ka<056[c0f[b00EZlF[bJ_9ZlV[a00AZlP03J]9ZlV[b009ZlPUZl@04I_5ZlF[bJ_86J]83I]82J]80
16[AJ]9ZdV[A2VKB00=ZdFKAI]401FKB0fKA00=VdVJaI[400fKA00=V/FKAI]400fKA00AV/FKAI]5V
d09Vd@EV/@=Vd@9Rd@QR/@IR/0ER/@9RT0=R/004HY1R/F:@H[02H[400f:`HZmR/003H[02HY0016:?
HZiR[f:@0V:?0V:@00ARSf:>GXiRS@=NSP04GXmNSV:=GVd5GXh5GVl2GY02GW0015i_GViNKEi]0UY]
00=NKEi^GVd00Ui]0Ui/00ANKEi^FViJKP=JK@05FTaJKEY]FViJK@02FTd00eY]FTeJC@05FTd015Y>
FTeJCEY;0eY:00AJC5Y=ETeFC@eFC003ET]JBUHZ00QF:`03ETYF:eH[00AF:`03DRaF:eH/00=B;003
DR]F:U8[00EB:`04CR]B2e8[DRX2DR/014h[DR]B2e8:0dh;1E8:1Th;00A>2Th9BPY:2`9:2P03CPY>
2Dh900E>2@=:2PA9jPQ9j@59b059bP0000<<@0`P34400`PQ0PPP0``P2PPQ00D880`P22488@`Q00<<
@@0732488@`Q340<8@PQ32000Q1000L<81A0;<8mIEY;GXeJKP04GVh015i_FVmJL5Y_0eY`00=JKei_
GVl01Ei`15i_00=NKUj@GY000ej@0Ui_00=NSUi`GY000Uj@00ANTEj@GY1NS`ENT003GXmRT6:@009N
T@=RT@04HY1RTF:AHY43GY42HY0>H[400f:AIY5VT@02IY401FJ@I[5VT6J@I[000V:a00IV/VJaI[9V
/FJ`IZl2I[02I[43I[8016JaI]9VdFKA1VJa1VJb00=VdFKBI]800VJb1FKB1VKA00=VdV[BJ]800V[B
00IVdV[BI]9VdVKCI]85I]<2I]82J]8026[AJ_9ZdV[AI[5Z/F[BJ_83J]84J]<7J]800f[bJ_=Zd`02
J_<016[bJ]9ZdV[C0f[c00I^lVkBJ]=Zdf[bJ_<4J_82J_<2J_86J_<00f[bJ_=^lP05K_<9K_800fkc
J_=^l`03K_<4J_<016[dK_=^lfkc0flD1Fkc0Vkd00=Zm6lDJa@00V[d0V[c00=^lfkdK_<026kc0fkd
16lD0fkc1Fkd00=_4flDKa@01flD00=_4flDKa@016lD1Vkd00MZm6lDKaA^lfkbK_=ZlP02K_803FlB
J_9V[f[`Lc5Vd5i>HVeZd6lDKa=^lflD009^m004KaEc56kdK_<6K_@01F[dK_=^lf[cJ_@00f[c00=Z
m6[cK_<016kc00A_4VlCKa9Zl`9^l`03K_AZm6[c00=^l`03K_9^lfkc009_4`03J_AZlf[c00AZl`03
KaA[56[d01AZl`UZlP06J_5ZlV[BJ]9ZlV[c0V[b1f[a1F[b2F[B16[A0f[B00=VdVKCI]803fKB0fKA
0fKB46KA1fJa00=V/V:aH[4026:a00=R/6:aH[401F:a00IRTF:aH[5R/F:`H[45HY02H[43H[000f:_
HY1RS`02HY0016:_HZiN/5j@16:@00IRSf:>GXiNSUj?GXh3GXl01ej>GXmNSej?GXiNSej>00ANK`03
GW1NT5j@009NL09NK`06GViNKEi]FVeNKEY^0ei]0Ui/0UY]00=JKUY]FTd00UY]00AJK5Y]FVeJKPAJ
K@9JC@9JC0=JC@05FTiJCEY=FT]JC003FT/00eY=ETeFC@0=ET`00eI;FTYF:P0;ER/00e8/ER]F:`03
ER/00eH/DRaB;002DR`3DR/00eH[DR]B:`02DR/2CR/3DR/014h[DR]B2e8:2Dh;00=>2Th;CP/00dh;
0dX;0TX:00=>2Th9CPT01Dh90dX:14WZ1dWY0DW90DW80DVZ00000`a032088002224010@022488@PQ
0P`P2PPQ00D880`P22488@`Q00D<@@05320<@0`P2248800232001P`0540/`SeTERYJJ`9NC09JK@03
GVeNKUi^009JK`03FW1JD5Y`00INK`=NL004GVmNKUi^GVh3FVl01Uj?FVmNKei^GXiNK`=NT003GXmN
Kej?00=NSPANS`9RT0=NT@9RT004HXmNT6:@HY43GY400f:@HXmRT006H[400f:@H[5R/@02H[4016:A
H[5RTF:`0fJa0fJA00MVT6J`H[5R/FJbI[5V/P02I[43I[02I[42I[88I[400fJ`I[5V/@06I[82I[40
0fKAI]9VdP02I]800fJbI[5VdP08I]43I]82I]402FKBJ]5ZdV[BI]9ZdfKCJ]=VdP04J]82J_801Vkb
J]9Z/FJ@I[5VdP=ZdPAZd`9ZdP04J_9ZdV[BJ]82J_800f[BJ_9Zl`02J_<00f[bJ]=Zd`03J_<00f[B
J]5Zd@06J]86J_84J_<6J_82K_<01F[bK_9^lVkaJ_800fka0fkb0Vkc0Vkb0fkc0f[c0Vkc00=_4f[c
Ka<01Vkc00=^m6lDKa@00VlD0Vkd0V[c0Vkc00=^lVkcK_<02Fkc16lD00E^m6kcK_=^m6kc009^m003
K_=^lVkc00E_5005J_=_4flCKa=_4P05Ka<01FlDK_A^mFkdJ_@01F[c0f[b00E^lVkaK_5ZlF[`009V
d00:I]5NKV9/J/mZlVlBK_=_4fkcK_@4K_<01V[dK_=Zm6[dK_A^l`IZl`03J]=Zlf[c00I^l`04Ka9_
4flBJ_83K_<00f[dJ_=^l`03K_82Ka83Ka<:J_<00f[bJ_=Zl`0;J_<>J_8016[aJ_9ZdV[A16[b0f[a
00]ZdF[aJ_5ZlF[bJ]9VlV[BJ_9ZlF[b00MZdP03I]9ZdF[A00=Zd@03J]9VdVKB009VdP03I]5VdVKB
00=VdP=Vd@EVdP=Vd@03I]9VdFKA009V/@9V/003I]1VdFJa00=R/@9Vd@=V/0EVd@06I[1V/FJaI[9R
/F:b0V:a00=R/6J`H[400f:a0V:`16:a0V:A00ER/F:@HY1RT6:`009R/@03GY1RT6:@00=R/004HY1R
Sf:_HZh2HXl01V:_H[1R[f:_G[1RS`=RT003HXmRSV:=00INSP=NKP9NSP04GXeNSUj=GXh2GVl00ei^
GVmNK`05GVl03Ui^GVeNK5Y]FVaJKUi]FVeNCEi<GV]JKEi/FV`3GV`015Y<FV]JKEY/0eY]0UY=00AJ
BeY<FTaJC0IJC@03FTaJBeY;009JB`EFC004FTaFC5I<ER/3ET`3ER/015I<ET]JBUHZ1eH[00EFBeI:
ER]F:e8/00EF:`IB;003DR]F:UHZ00=B:`0:CR]B:dh;CP]B2e8[CP]B:e8;DPX3CP/2DR/2CP/2CPX0
0dhZCPY>2`02CP/4BP/00dX:CPU>2@03CPT01TX9CPU>2Dh8CPU:2P=5jP99jP03CNU9jDWY00A9j@99
b059ZP0000<<@@`P32402PPQ00<8@@PQ22400PPQ00<<@@Q122400PPP0PPQ0P`Q00<<@PaR34800Pa1
00D<@0PQ224880`P00880008440/`Se4CPYJ:ei[GTaNKP9JKPAJK`=JL0=NK`03GViNKei_00=NL004
GVmNKUi_GXl3GY001Ej?GY1NT5j?GXh00Ui_0ej?00=NKej?GY000Uj?15j@1ejA00=RT5jAGY400UjA
0f:A00ART6:AHY5RT@=NT@9RT@=RTP9RT@=R/@03H[9R/F:b009RTP03IY5VT6J`00=R/@=V/@05H[5V
/6JaI[5V/P04I[42H[4016JaI]5V/FJa0fJ`00EV/FJbI[9V/VKB009V/P9V/@03I]5VdVKB00EVdP03
I[5VdFKA00IVd@05I]9ZdV[BJ]5VdP02J]4016[BI[9ZdVKC0VKB0f[B0V[A0f[b00MZdVJaHY1V/V[C
J_=ZdP05J]<2J_86J]83J_801F[cJ]=Zdf[cJ_@00f[c00AZdV[bJ_9ZlP=Zl`9Zd`=ZdP9ZlPMZl`03
J_9Zlf[b00MZlPE^lP=^l`03K_9^lfkc00EZl`9^l`06Ka=_5FlDK_A^lf[c0fkc0V[d0flD00A^m6[d
J_=Zm09Zl`I^l`03K_A^lfkc009^l`9^m004KaE_56lDK_<3K_@01fkcJ_A^lfkcK_9^lfkd00E_50=_
4`03Ka9_4flC00=_4`=_5@03K_EZm6[c009Zl`03J_AZlf[c00=Zl`0=K_9^lf[cJ_5VlFKAH]5NKf9]
I[1ZlFkaK_<00Vkd0Vkc00I^m6lDKaAZm6kdK_<:J_<00f[CJ_=Zl`03K_<01fkbK_=_4VlCKa9^lVkc
009Zm09Zl`9^l`A^lP9_4`mZl`9ZlP9Zl`03J_9Zlf[c00AZl`05J]=ZdV[CJ]=Zl`03J_82J_<016[b
J]9ZdV[a1F[b1f[B0V[b0V[B0VKb00=Vlf[bI]801F[B16KB00=ZdF[BJ]800VKB00=VdFKBI]8026KB
0fKA26KB00AVdFJaI[5V/@9V/003I[5VdFJa00IV/@03H]5VdFKA009Vd@EV/@09H]9R/V:bH[5RdF:a
I[1R/F:b009R/@9R/0ER/@06GY5R/F:@H[5RT6:?1F:@1F:`00=N/F:_GXl016:?00=R[Uj`HXl00f:?
00=RSV:?HXh00Uj>00=NSej>GVh00Ui^00ENSUj?GXiNSej>009NKP=NK`04GViNKei_GVl3GW001Ei?
GVmNKUi]FVd00UY^00ANKUY^GVeNK@=JK@03FVaNK5i/009NK004FV]JKEY]FVh2FVd2FTd3FT`;FTd0
1eI<FTeJCEY=FTaFC5Y<009FC003ER]FC5I<009FC004ET]FC5I<ET`<ER/2DR`2DR/00eH[DRaB;007
DR`3DR/00e8;DR]>:`03CP/3CR/2CP`9CP/6CPX01DX;BPY:2dX;BPX00dh900=:2DX:BPX00TgY00=B
2TX:ANX014G[00=5jTWZBNX00TWZ0dWY0TW80DW:000334401@Q122488@PQ24400`PQ0``Q10PQ1@PP
0`PQ0``Q10a10PPQ00`880`P3208010P9<8i@dWZFT]RS5i<GVh2FVl2FTl00eY@FVmJK`04GVl00ei^
GTiNKP05GVl01Ui^GVmNKei_GXmNK`INKPANSP9NS`9NT0=NT@MNT0QNT@04HY1RTF:AGY43HY43GY40
1V:AHY9RTV:bH[5RT@AR/@07I[5R/V:BHY9RTF:`I[000f:a16Ja00=V/6JaI[400fJa0fJ`1FJa0VJ`
0VJa0VJb00MVdVJbI[9V/VJaI]9Vd@05I]800fJaI]9Vd@07I]400fKBJ]9ZdP03J]400f[@J[5Z/@02
J]42I]8016[BJ]5ZdF[A0V[@00aZdF[aJ_5ZlF[AI[5RT6JaI]5ZdF[BJ]<2J]800f[CJ_9ZlP09J]80
0f[CJ]9Zd`05J_<01V[CJ]9ZdV[BJ]=Zl`9Zd`EZdP]ZlP03J]9^lV[b009^l`A^lP03K_5^dVkc009^
l`9ZlPY^l`04J_=^lfkcK_<3J_<00fkcJ_=^l`02K_<01F[cK_=^lfkcJ_<01fkc0fkd0fkc0Vkd00=Z
m6kcK_<01Fkc00I^m6lCK_=^lVkcKa<3K_<016kdKa=_4flC0VlB1FlC00IZm6keK_E^mF[dK_<2J_<0
0f[dJ_=Zl`06J_<02V[`H/mVd6KAGVmNCF:?J]5^lFlC16kc0fkd16kc3F[c26kb00AZlV[dJ_AZl`=^
l`A^lP03J_=ZlV[c015Zl`=ZlPEZl`05J]=ZlV[CJ]=Zl`07J_801F[BJ_5ZlF[aJ_802f[B00=ZdF[a
J_800f[b00=VdV[BJ]800f[B00=ZdfKBI]804FKB00=VdFK@I]402FKA26Ja00=R/FJaI[400VJa00EV
dF;AI]5VdFJ`009V/@04H]5V/FJaI[45H]400f:aI[1R/@02H[45H[04H[43H[02HXl3HY02HXl00f:@
H[1R/002H[000ej`HZmNS`03HXh00f:?HZiN[`02HXh01V:=HXiRSV:?HXiNT0ANS`03GXiNKUi^00QN
KP05GVmNKUi_GViNK`03GW000ei?GViNKP03GVd2GVh5FVh00eY]FVaJJ`04FV/2FV`2FVd00eY^FVeJ
K@03FVd5FTd00eY<ETaJC006FTd00eI<FTaFC003ET`2ER/01EI<ET]FBeI:ET/01eI<1UH[00MB;58[
DR]F:U8[ERYB:`02DR`00e8;DRaB;004DR`00e8;DR]B:`02DR/00e8ZDR]B:`02DR/2CR/00dh<CP]>
2`02CP/2CPX00e8ZCP]>2`03CPX01Dh9CPY>2Th:CPT00TX:00Q:2Dh8CPU>2DX:BNU9jTgY0TWZ0TX:
0dG[00=9jdWZBNX00dWZ0TWY00=9j4W8BLL00DW90004244010PR2448@@Q10PPQ0``Q0Pa10`PQ00D<
8@PP3208@@PP00@88@<<8@<<@@0=244<8@PP320880P0420PXcE5BNYJC6:=GVd00UY>00AJKeY?FTiJ
D0INK`06GTiNKUi^GVmNL5Y`1Ei_00ANL5i_GW1NKP=NK`04GXiNSej>GVh2GXh3GXl015j@GY5NTEjA
1Uj@0UjA00=NTUjAGY8025jA0f:A0ejA00ART6:aHY9RTPIR/@04I[5R/V:BH[82H[4016:`H[5R/F:a
0V:b00=V/F:aI[400f:b0V:a16Ja16J`16Ja1VJb00=V/FKBI]401FKB00=V/FKBI]4016KA1FKB0VKA
1F[A0V[B0fKB0f[A00=Zd6[AJ_400f[a00QZdV[AHY5RL6J`J]5ZlVKB0f[B0V[C1F[B0f[C00=ZdV[C
J]<00f[c00MZlV[cJ_=Zlf[bJ]=ZdP04J]<4J]800f[CJ_9ZlP02J_85J]8016[bJ]9ZdVkb0f[b16kb
00A^dVkbK]=^l`AZl`]^l`MZl`M^l`04J_=^lfkdK_<2K_@4K_<00f[dK_A^m002K_@016kcJ_=^lfkc
0fkd00=_56kcKa@00VlD2Fkc26lC00=_56kdJ_@00Vkd00A^lf[cJ_=Zm0MZl`0;J_9Zl6[bJ_5VdUj?
FTeNKf[AKc9_4`03K_@3Ka@3K_<01F[dJ_=Zlf[cK_<00V[b26[c0V[b00a^lV[bK_9^lVkaK_9^lf/C
J_=Zm6kcJ_<3K_<2J_8DJ_<3J_88J_<2J]82J]42J_8026[BJ_9ZlV[bJ]9ZlV[aJ_8<J]8016[aJ]9Z
dV[c0fKB00AZlV[BJ]9ZdP9VdP03I]=VdVKB00mVdP03I]5Vd6KA00EVd@03I]9VdFKA00AV/@9Vd@IV
/@03H[5V/FJa00QRd@03I[5R/F:a00=R/@03H]5R/F:a009R/@MR/0=R/@9R/09RT009HXmRT6:@HY1R
Sf:`HZmN/F:`009NT09N/009GZmNSf:>HXiRSf:^GZiR[Uj>00ARSP06GXiNT5j@GY1NSej@1Ei_00EN
Sej>GViNKUi_00=NKP04GVmNKUi_GVh2GTl00ei_GTiNKP04GVd7FVh00eY]FVaJK005FV`2FVd3FVh3
FTd00eY]FTeJC@04FTd3FT`3FTd2ETd:ET`00eI;ETaFC007ET`00eH[ERaF;003DR`2ER/015HZER]B
:e8/0e8[1E8/00=B:e8/DR/00e8[00=B:Th[CR/00dh[0Th<14h;00=>2Th;CP/00dh;0Th:00=>2Dh:
CPT00Th900=>2TgYCPT00dh900A:2TgYBNY9jP=:2P03ANY5jdG[00=5j`03ANY9jdWZ00=9jP03BNU9
j4g70059b@000`Q100@88@PR224<8@D88@<<8@<88@0522088@PP224880052243324334403PQ1220<
@0PP100<01bS=BE5jUH/FV]JC5Y>FTl2FVl2FTh7GVl025i>GVmNKei_GW1JL5Y_GVh7GVl00ei^GVmN
SP05GXh4GXl4GY000ei_GY1NT004GY02GY400ejBGY5NT@04GY400ej@GY5RT@02HY42GY401F:AHXmR
T6:AH[400V:A16:a00EV/F:AI[5R/FJa00=R/004I[1V/FJAIY42I[401F:`I[5V/F:aI[400f:a00=R
/6JaI[000fJ`16Ja00AV/VJaI[5V/P=V/@9Vd@9VdP03I[5VdVJa00AV/@AVd@9VdPAVd@03I[5V/6[A
009Zd@EVdP9Zd@AZd0EZd@05I[5VT6J?J]1Vd@05J]800f[CJ]9ZdP03J]800f[CJ]9ZdP02J]84J_82
J]800f[bJ_=ZlP02J]84J]<4J]800f[CJ_9ZlP02J_89J]83J_82K_<3K_800fkcK]=^l`04J_<2K_<4
K_85K_<7J_<6K_<016kbJ_=Zlf[c16kc00A^lV[bK_=_509^m0=^l`03J_=^lfkc00E^l`03J_A^lfkc
009^l`03K_9^lfkc00A^l`03K_A_4fkc009^l`9_4`04Ka9ZlFkaK_82K_@01fkcJ_9Zlf[cJ_9Zlf[b
00=Zl`0=J_A[4f[aJ]1Vd6KcH[5NCEi^J]1_4FlCK_@016lD1Vkc0f[c1F[b16[c00=ZlVkbK_8016kb
0Vka00E^lVlCKa9_4fkd00=^l`=ZlP=Zl`AZlPIZl`03J_9Zlf[b00AZlP03J_5^lF[b00=ZlPEZl`9Z
lP03J_5ZlV[A00=ZdP04J_9ZdF[AJ]83J_4:J]83J]42J]801F[bI]9VdVKBJ]8056KB0fKA0fK@1fKA
16Ja0VKA00EV/6JaI]5VdFJa00QR/@ARd@9V/@QR/@QR/0=R/@9R/004HY1RSf:@HY04HXl01f:^G[1N
Sej?GY1N/6:_009NS`=RSPANSP9RSP9RS@04GXiNT5j@GY04GXl01Ei_FViNKUj>GXd015i^00UNKEi^
GViNKEi^GTeNCei^GTh00Ui^15i]00=JK5Y^FVh00UY^00=JKEY^FVd02EY/00=JKUY]FTd01EY<15Y=
00MFC5Y<FTaJC5I<FTaJC@02ETd:ET`2ER/7ET`2ER/00eH/DRaB;002DR`2ER/2ERX00eH[DR]B:`02
DR/2DP/3DR/0258ZDR]B:e8[ERYB:e8ZDP/3DR/00dh[CP]>2`04CP/00dh:CP]>2`02CP/2BP/00dh:
CPU>2@08CPT01TX9BPY9jTX:CNU:2P=9jP07ANY5jdG[AN]9jdG[ANX00TWZ0dWY0DWX0DgW0DfY0000
10Q22448@@PR0P`Q00<<@@PQ22401@Q100<88@`Q34400`Q200<8@@@Q22401`PQ0P`Q0`a10108@@a0
220400P068<a9T7:DTmJKEY=FTiFCUI?FVmJC`9JCP9NK`05FVmNKei_GVmNKP02GVl5FW06GVl3GW03
GVl3GY04GXl5GY000ejAGY1NT003GY02GY400ejBGY5NT@0;GY400f:AH[1RT005HY42H[42HY4016Ja
H[5R/V:a0f:`00AV/6JaIY5VT@9V/@9VT@9V/@04H[5R/V:bH[82H[47I[42I[800fJaI[9V/P0?I[44
I]800fKCI]9VdP02I]800fJbI[5V/@07I]82I]45J]4026[BJ]5ZlV[AI]9V/FJ?I[02I]82J]800f[C
J]9Zd`08J]<2J]82J]<3J]84J_87J]<3J]800f[cJ_9Zl`02J]<7J]85J_83J_<016kcK_9^lfkc1F[c
36kc1f[c1Vkc0f[c00=ZlVkcK_<00Vkc0VlD00=Zm6kdK_@00Vkd00EZlf[dK_A^m6kc009^m004K_E^
m6[eJ_@3K_<016lBKa=^lfkc0Vkd16kc00=^m6lDKa<00flD00I_4VkbK_=ZlfkbK_<8J_<046/CJ_=Z
lF[@I]5Vlf:aGViNKfK@Ka9_56[dKaE_56[d0V[c00=^lfkdK_<026[c00=Zdf[bJ_<01F[c1F[b1Fkb
0f[c00=ZlV[cJ_<01F[c00=ZlV[cJ_8016[c0f[b0V[c00=^lf[bJ]800V[b00AZdF[aJ_9^l`MZlP03
J_5ZlV[a009Zd@=ZdP03J_9ZdV[B00=ZdP03J_5ZdV[B00=ZlP9ZdP05J]5ZdV[BJ]9Zd@03J]8EI]80
0fKCI]9VdP03I]82I]4016JaI]5VdFJa1FKA00AV/FKAI[5V/@EVd@03H]5R/F:a015R/@9R/008H[5R
/6:aH[5RT6:`H[5R/0=R/@=R/003HXmRT5j@00IRS`04GXmNT5j@GY02GZl015j?GXiNSUj>0V:>15j?
0Uj>00ANSf:>GXmNS`ANT0ANK`03GViNSUi^00=NK`04GViJKUY^FVl2FVh6GVh015i]FVeNKEi]15Y^
0eY>00=JKUY/FVd00UY]0eY/0eY]0UY=1EY<00=JCEI<ET`01eI<00=FCEI>ETd01eI<00=F;5I<ET`0
0eH[0UI<00=F;5I<ET`00eH[00AF;58/DReB;@=B;0MB:`9B2`UB:`05DRYB2e8[CR]>300=CP/5CPX2
CPT8BPX00dh;CPY:2P05BNX00dG[ANY5jP02ANX00dWZBNU9j@03BNT1CLL1CLT00004248<@@a13443
3243224010Q12488@@`Q0Pa100T<@PQ224488P@Q22848@@R22801@PQ0P`P00H<@0a13448@0aP3402
20001A12;@I1bUI`GY000UY>0eY?0UY_0UY>0eY_00=NKei?GTl00ei_00AJKeY`GW1NL0=NK`YNL09N
T003GXmNSUj?00INS`MNT0iNT@03HY5RT6:?009RT005GY5RTF:AHY5R/@02HY45H[4026:`IZmV/6J?
IY1VTFJ@IY45I[4016:aH[9R/V:b0V:a1fJa0VJb00=V/FJbI[8036Ja16Jb0VKB00=V/FJbI]800VKB
00AV/fJbI[5V/@9VdP03I]=VdVKB009VdP04J]5VdF[AJ]44J]83J_82J]402VJaHY1RT6:AI]5ZlV[B
J]=Vdf[C0fKC1V[C0f[B0V[b3V[B0V[b0V[c00=Zdf[BJ]800V[B26[b0f[c1Fkc00=ZlV[cJ_<01Fkc
0V[c1fkc1V[c1Vkc0f[c1Fkc00=ZlflCJ_@00VlD00A^lfkdJ_AZm09^m003K_=Zm6kd009^m@04J_E^
m6kcK_84Ka<00fkcK_A^m005K_<2Ka@016[dKaA^lfkc0Vkb00AZlVkaJ_9ZlPMZl`9ZlP0@J_5Zd6[A
I_9V/5i]GTeV/6[bKaAZm6kcKaAZm6[cJ_@5K_<7J_<00fkcJ_=Zl`04J_<3J_83J_<016[bK_9^lVkb
16[b2F[c00AZlV[cJ_=Zl`]ZlPYZl@04J_9ZlF[aJ_42J]000f[AJ]9ZdP02J]84J_800f[aJ_9ZlP03
J_800f[BJ]5Zd@02J]45J]84I]82J]800f[AI]5VdP09I]83I]401FKBI]5VdFKAI]803VKA0VJa1FKA
0VJa2f:a00=V/6:`H[400V:a00=R/6:aH[400V:a00AR/6:@HY1RT0=R/09R/@AR/003HXmRT5j@00MR
S`06GXmNT5j?HZiNSV:=0Uj>0ej?0ej@00ANSf:>GXiNK`ANS`05GY1NKei_GViJKP05GVh015i_FVmJ
Kei^0UY^00=JKeY^FVh01ei]00AJKUi]GVeNK@9NKP06FViJCUY>FTiJKUY/15Y]0UY^0UY]0UY=1UY<
1EI<0UY=1EI<0UY=3UI<00=F;5H[ER/00eH[00AF;58/EReF;@9B;09F:`03DP]B:e8[00=B:`04DRaB
2e8[DRX3DR/00e8ZDPYB2P04DPX014h;CPa>2dh;14h:1dh;0Th:00=>2DX9CPT00Th91TX:00E:2dW[
BN]:2dGZ00=9jP99j@03ANY5jDGY00=9j@03ANQ9jDWY0099j@5=a`59b@0000<8@Pa134400`a100@8
8@Q1344<@P88@P0624488@a1248<@@Q20`PQ00D88PPQ12488PPQ00888P<88@03324<@@a1008<@@0:
340<@@PP100<8RCV?JY>D5I^FVl5FTl4FVl00eY`FVmJK`0;GVl2GW05FW03GW0015jAGW1NL5i_25j?
25j@35jA0f:A0f:@16:A1f:a0V:`0VJ`00=VSfJ@IY000VJ@00=VTFJaI[400VJa00AR/F:bH[9R/PAV
/P05I[5R/FJbI[9V/@06I[8:I[42I]85I[802VJaI[9V/VKBI]=Ve6[CJ[9V/VKB0fKC0fKB0V[B00AV
dV[BJ]9Zd`=ZdP=ZlP09J]5VdVJ`HVmRT6JaJ]9VdfKB009Vd`06J]=Ve6[eK_AZdf[B0f[C0V[B0V[b
3V[B00=ZlV[cJ_<00f[c00=ZlV[BJ]8016[b0f[c0f[b0V[c00=^lf[bJ_800f[b0V[c16kc0f[c0Vkc
00=^lVkcK_800Vkc0V[c00A^lf[cJ_=Zl`E^l`AZl`E^l`08KaA_4flDKaAZm6kcK_AZl`EZm003K_A^
mFkd009^m004Ka=_4VkbK_83K_<2K_@7K_<2J_@00f[cK_=^l`05J_86J_<3J_803V[aJ]1VdFKBIZmN
KEY<HVeZd6[cJ_A^lfkdKa@4J_<2K_<00f[bJ_=Zl`05J_<00f[bK_=^l`05J_<2J_86J_<5J_89J_<0
16[bJ_=Zlf[c1f[b0f[c0V[b0V[A26[a0f[A00=Zd6[aJ_800V[B00=ZdF[BJ_800f[b00=ZlF[bJ]80
0V[b00AZdf[BJ]9Zd@AZdPIVdPEZdP=VdPQVd@06I]9VdFKBI]5VdVKA0fKB2FKA0VJb00EVdVKAI[5V
/FJb00AV/@aR/@03I[1R/F:a00ER/@=R/003H[5RT6:a00=R/003G[5R/F:a00AR/003HY1NT6:?00IR
S`=NS`05HXiNSV:=HXiRS`03GZl3GXl00ej@GXmNSP05GXl01Ej@GVmNKei^FVh00ei^00=NSUi^FVl0
0UY_0eY^0eY_0UY^0ei]0Ui^0UY^00AJKEi]GVeJK@AJCP03FViJKEY^009JKP0;FVeJKUY]FViJCEY>
FTeJC5Y=ETeJC@04ET`4FTd3ETdBET`015H/DTaF;5I=1EH/0UH]00=B;5H[DP/00U8;0e8[0Th[00=>
;58/DR/00U8[00=B:U8[DRX0158:1Dh;00=>2U8:CPX024h;00=:2dX:CPX00dh90TgY1TX:00]:2dW[
BN]9jdX;BPY5jTWZBNQ=j4X9009:2P03CPU:2TX:00=:2P99j@59b059Z@0000<<@Pa134401Pa10Pa2
00<8@P`Q22402`PQ00<40@PQ22401@PQ00h8@@PQ22488@`Q34080113:>HiRDX=FVeNSeY_1EY?0eY_
00=JL5Y_FVl03Ei_1EY`1Ui`00=NKej?GXl025j?0ej@0Ui`0ej@0UjA00ANT5jAGY5NT0ENT@06HY5R
/F:@HY1RSej@16:A00=RT6:AH[400f:a00AV/F:`I[1RS`EVS`9VT0ER/@9R/P03H[5V/FJa009V/@03
H[5V/FJa00=V/@9V/P03I[5V/VJa00MV/@AVd@03I[5V/VJb009V/P=V/@9VdPAV/P=Vd`AVdP04J]5Z
dV[AJ]83I]83J]82J_82J]800fKAI[5V/@03I[400fKBI]=Vd`03I]<3J]83J]<00f[BJ]=ZdP0?J]80
0f[bJ_=Zl`03J]<2J_85J]800f[CJ_=Zl`02J_82J_<00f[bJ]9ZlP07J_800fkbK_=ZlP02J_801V[c
J_9ZdfkBK]=^lP9^l`IZl`E^l`AZl`9ZlP9^l`9Zl`05Ka=_56kcI]5ZlP02K_<4J_<02f[dJ_=Zm6kd
J_A^lfkbKa5^lFkbKa<02fkc00=Zlf[dJ_<00V[c0f[b0V[a2F[b00]^l6[@J]5VdFJ_GVaNBf9[J/m_
4fkd009^l`03J_=ZlV[c009ZlP03K_9ZlV[b009ZdPAZlP04J]9ZlV[bK_<5J_<3J_83J_<00f[bJ_=Z
lP04J_83J_<01FkcJ_=ZlV[bJ_<016[b00=Zlf[bJ_800f[b1F[c0V[b00=ZdF[bJ_4016[a26[A00=Z
lF[AJ]400V[A0V[B0V[b00=ZlF[bJ]801F[B00=ZdF[cJ]800V[B46KB0fKA00=Vd6KAI]401FKA00AV
/FKAI]9VdP=Vd@07I[5VdFKAI]5V/FKAI]800VJb0fJa2F:a0fJ`1F:a1F:`0f:a2F:`0V:a1F:`00ER
T5j@HXmRSej>009RS`ENS`03HXeNSV:=009RSPENSP03GXmNSUj>00=NSP04GVeNSEj>GXh3GVh01eY^
GViNKUi^GVeNKUi_00=JKP03GVmNKUY^00AJKP05GVaNKEi^GViNK@02FVh00eY]FTaJC002FT`01EY=
FTiJCUY^FVd00UY^15Y=00=JKUY=FTd00UY<00=JK5I=FTd01EI<0UY=00IFC5H]EReFCEI<ER/3ET`0
0eH[ETYFC003ET`7ER/2ET`015H/DRaB;58/0UH/0eH]00=B;5H[DP/00U8;0e8[0dh[158[00=B:U8[
DRX0158:1Dh;0dh:1Th;00E:2dh:CPY=jTh:009=j@05CPU=jDWZBPY:2@03BPX6BNX01TWYBNY9jTWW
CPE5i`95j@=9j@03ANU5jTWY0099j@59b059bP002@a10Pa200<8@@`Q22401@PQ1@Q10PPQ00@88PQ2
2448@@H88@8880083208010R9<DiIdX=GVeJK`MJC`AJK`9JCP9NK`05FW1JKeY_FVmJL005GVl4FW03
FW45GW07GY03GXl00ej@GXmNT002GW05GY0:GY43HY400f:@HY5NT@04HY43H[401F:AH[5RTF:aH[00
16:@00AR/6J@IY5V/@=R/P=R/@=R/P03H[5V/FJa00=R/@=V/@9V/P03I[5V/VJa00MV/@05I]9VdFKA
I]5V/@04I[82I[43I[8016JcI[9VdfKC0fJc0fKC00=VdV[AI]8016KB1F[B00=ZlV[BI]800VKB1FJa
0VJb00=VdfJcI[<00V[B00AZdfKCI]=Zd`9Zm09Zd`EZdP03J_9ZdV[C00AZd`04J]9ZlV[bJ_<3J]<0
0f[cJ_9ZlP03J_82J]82J]<02V[cJ_9Zlf[bJ_=ZlV[BK_=Zlfkc0V[b1F[c0V[b0V[c00=Zdf[cK_<0
0fkc26[c16kc2V[c00E^lf[dK_=Zlf[b009Zl`9Zm0=Zl`9Zm003J_=Zm6[c009_4P9^lPA^l`03K_A^
lfkc00E^l`EZl`04J_9Zlf[cJ_82J_<8J_802f[aJ]5ZlVKbI]1NK5i;IXe^l6[bK_801f[c16[b1F[B
00=Zdf[cJ_<01V[c00=ZdV[CJ_<01F[c00=ZlV[cJ_<01f[c1F[b0f[c00=ZlV[cJ_<01f[c1V[b00=Z
lF[AJ]4016[A1f[B00=ZdF[BJ]800f[B00AZlF[BJ]5ZdP9VdP=ZdP03J]=ZdVKB00AVdP03I]5VdVKB
009VdP9Vd@AVdPaVd@9V/@IVd@9V/@AVd@=VdP=V/@03I[9R/F:a00MR/@9RT0ER/@ER/0=R/@ER/004
G[5R/6:`H[03G[43H[0016:@GY1NTEj?16:?00MNT5j?GXmNSej>GXeNSP02GXl00ej>GXmNS`06GXl3
GXh2GXl2GXh3GVh00ei_GViNKP03GVh5FVh3GVh3FVh01UY]FViNKEi^GXmJK`9JKP05FTeJC5Y<FTaJ
C@02FTh3FVh2FVd3FTd00eY^FTeJC@02FT`01UY=EViFCEI<ET]FC09FC@=FC0=FC@06ER]FC5I<ERaF
C5H[15I<00AF:e8/ERaFC0=F:`=FC004ERaB;58/DR`3ER`5DR`2DP`00e8/CRa>:`04CR/3DR/2CR/:
CP/00dh:CP]>2`07CP/01e8;CNY=jTh:CPU>2TgY00A:2P03BP]:2TX;00A9jP04CNY=jDh9APX2BNT0
1Dh8BPU9jTX:CNT00TWY00I5jTWYBNU=j4WYBLP1BLX00004364<@@a1320734400`Q122488@022204
22401@Q1344<@@Q134400PPQ00H88PQ12448@@PQ24422242220232001`P0320PY3U6BN]JC5Y]00AJ
C`QJK`9JCP04GVmJKeY_FVl3GVl00eY_GVmNK`03GW03FW02FW45GW000ej@GW1NL003GW06GXl2GY00
0ei`GY1NT004GY0@GY42HY44H[43HY400f:@H[1RT004H[43I[43H[85H[400f:bH[5R/@04I[400fJ`
I[5V/@02I[801VJaI[9V/FJaI[9V/@AV/P=V/@05I[1V/FJaI[5V/P03I[45I[800fKBI[9V/`02I[@3
I]@01VKBJ]5VdF[AI]9Zd@9VdPIZdP04I]5ZdVKBI[43IY000f:`H[5V/P03I[82J]82J]<3I]800f[C
J]9ZdP07J]801V[CI]9VdVKBJ]=ZdPAZlP03J]9ZlV[b00EZlPAZdP03J_9ZdV[B00AZdP04J_9Zlfkc
J_82J_<5J_801FkcJ_=Zlf[CJ_<00fkc2F[c1Fkc2F[c00E^lf[cJ_=Zlf[b00aZl`03J_9^lFkb00e^
l`06J_=ZlV[cJ_9Zlfkc1F[c00=^lVkaK_400V[A0f[b00aZdF[aJ_9VlVK?GV]J:VJ;J/e^l6lAKa83
Ka<5J_<3J_83J]801V[bJ_=Zlf[CJ]9Zd`=ZlP9Zd`UZl`9ZlPEZl`QZlP]Zl`03J_9ZdV[b00=ZlP04
J_5ZdF[AJ]47J]800f[CJ]9ZdP02J]82J]43J_42J]42J]800fKBJ]5Zd@02J]401V[BI]9VdVKBJ]5V
d@9VdPAVd@AVdP9Vd@04I]1V/FJaI[45I]400fKBI]5Vd@06I]400fJaI[1V/@03I[43I]44I[43H[44
I[4:H[4=H[001EjaH[1R/6:`G[401F:`00ART5j@GY1NS`ERS`=NS`03GXiRSEj>00mNS`9NSPANKP06
FViNKUi^GViNKEi^0eY^0ei^00QNKEi^FViJKUY]GVaJKEi]1EY^00EJKEY<FTaJC5Y=009JCP9JKP03
FVeJCEY<00MJC@9JC005ETeJCEI;FTYFC002ETd:ET`3ER/2ET`2ER/015H/ETeFC5I:15H[00=F;5H[
ER/015H[158/00IB2e8/DRaB;58;DR`7DR/2CR/9CP/7CPX01Dh;CPY>2Th:BP/00TWZ00M=jTh:CPU>
2TgZBPY>2@02BPX014h:BPY5jdGZ14WZ0TWY00=5jTWYBNT00dWY0TGY0TWY00=5jDWYBNT00TWX0DW8
0DW:000010aR348<@@a10Pa200@<@@a2348<@@88@@888@0322088@PQ00<88@03324<@@a10088@@08
24888PPR2288@PQ12488@@888@888009320@@110564Ta3U6BN]J:ei]019JK`9NK`03FVmJL5Y_009N
K`9NL003GW5JL5Ya009JL@9JL006GW1NT5i`GY1NL5Y`15i`00=NSej@GXl00Uj?15j@0Ui`15j@45jA
00=RTF:aH[400V:a0f:A00=R/F:`H[400V:a00=RTV:bH[400V:a0f:b00ER/F:AHY5V/F:a00=R/P08
H[5V/FJaI[5V/6:aI[5R/@=V/@04I[9V/FJbI[44I[8016JaI[1V/FJa16Jb0VKB00=Vdf[CI]<00fJb
00=VdVJbI[<00fJc00IVe6KCI]=VdVKAJ]42I]43I]85J]801V[cJ_9VdVKAI[5V/09RT006HY5V/FJb
I[9VdV[B0V[C00=Vdf[CJ]800f[B00EZdf[BJ]=ZdV[c00=ZdP05J]=VdVKBI]9Zd`03J]82J_87J_<0
16[bJ]9ZdV[B0V[b00UZdV[AJ]5ZdF[BJ_9^lf[cK_<00V[b00=Zlf[bJ_800V[c0f[b3f[c00A^lf[c
J_=Zl`=^l`MZl`=^l`mZl`9ZlP03K_=^m6kc009^l`9^m003J_=^lfkc00A^l`04J_=[4f[cJ_<2J_82
K_<2J_<01F[BJ]5ZdFkaJ]401F[b0VKb00QR/5i]FRYRBF[=Ka5_4VlC0V/C26[c00AZlV[BJ]9ZlP9Z
l`9ZdP05J]=Zlf[bJ_9ZdP02J]<9J_<2J_85J_<3J_801f[aJ_9ZlV[bJ]=Zlf[b00EZl`IZlP03J]9Z
lV[b009ZlP03J]9ZdF[B00MZdP03J]=VdVKB00AZdP9Zl@AZd@03J]9VdVKB00AVdP=Vd`AVdP9Vd@AV
dPAVd@09I]1V/FJaI[5VdFKBI]5VdVKA00=VdPIVd@03I[5V/6Ja009V/@04I]5V/FJaI[48H[43I[49
H[400f:`HZmR/002H[02H[401F:`H[5R/EjAH[001eja0f:`0V:a00ART5j@GY1NS`ERS`=NS`=RSQ1N
S`ENKP=JKP=NKP=JKP9NKP9NK@AJKP=JK@9JKP03FVmJKUY>009JCP9JC004FTeJCUY>FTh2FVd00eY=
FTaJC@06FTd2FT`01EY=ETaFC5I;ET`00UI=1eI<00MJC5I<ER]F:eI<ET]FC003ER/2ER`01EH[ET]F
BeI;ER`02EH[1e8/158[00=B:U8;DR/00e8[00=>:dh;CP/01dh;2dh:0TgZ00E>2U8:CP]>2TX:009>
2P=>2@03CPY:2TX;00=9jP04ANY9jTH:BNX2ANT00dGZBNU5j@02ANT2BNT00dgYBNU9j@03BNT1BNL1
BLX00003364<@@`Q00888@L8@@@88@0422088@PQ3243344224400`PR22488@0222400`Q12488@@02
22403@PP320<8110560HPRC4=BE5bEiZGXeJKUY>00=JK`05FTmJKeY_FTiJC`08FVl2GVl00eY_FW1J
K`02GVl015Y@GTmJD5i_15Y_00MJL5i`GW1NL5j@GW1JL004GW000ei_GXmNS`02GXl4GY03GW06GY06
GY400f:AHY1RT003GY400f:AHY1RT004H[42HY401f:@HXmRT6:@HY5RTV:b009R/@03H[1R/F:a00=R
/@9RT@=R/@06H[9RTF:AIY5V/FJ`0V:`00=R/FJaI[400fJa00AR/FJaI[5V/@9V/P04I[5V/6JaI[43
I[85I[45I[8016JaI[9V/VJb0fKC00=VdVKAI]401FKA00=VdV[BJ]8016[B0V[b00]ZlF[AI[1RSf:@
HY5RT6JAI[9VdV[B009VdP05I]=V/VJbJ]5V/P04J]82J_83J]800f[CI]9VdP07J]84J_8016[BJ_9Z
lVka0V[A16[B0V[A00=ZdV[AJ]8016[B00=ZlV[cJ_801f[b36[c00=^lf[cJ_800V[C00=Zlf[bJ_80
0V[b66[c0V[b00=^lV[bK_<00fkc16[c1Fkc00AZlf[bJ_=ZlP9Zl@9ZlPEZd@=Zl@0=J_9ZlF[aI_5V
lV:aGVeF2UX8JZi^l6l@K_000flB0f[c16[b00=ZdF[BJ_800f[b0f[B0f[b00=ZdV[CJ]<00f[c0fkc
0f[c0V[b0f[c00=ZlV[cJ_801F[a00=ZlV[CJ]<01V[b0f[B00=ZlV[BJ]800V[B00AZlV[BJ]5ZdP9Z
d@aZdP=Zd@03J]1ZdF[B00=Zd@9VdP04I]5VdV[BJ]85I]85I]43I]84I]400fK@I]5Vd@02I[44I]42
I]85I]42I[42I[05I[42I[05H[400fJaI[1V/@03I[400fJ`H[1V/006H[401F:`IZiR[V:^H[000V:a
00IR/6:aH[5R/F:`G[43H[03G[400f:`HY1RT004HXl3GY000ej>GXmNS`04GXl01Ej>HXeNSEi]HXh0
35j?00=NSUi^GVh015i^0eY^0ei^00=JKUi^FVh015i]15Y^1EY]00EJKUY]FTeJCEY>00=JC09JC@03
FVeJC5Y=00=JC003FTeJC5Y<00=JC@9JC0=FC004ET]FC5I=ETd3FTd01EI<FTaJC5Y<ET`00eH[00=F
BeI:ET/00UH[00AFC5H[ER]F:`=FB`QF:`03DR]F:UH[009B;003ERaB;58/00AB:`9B:P05DPYB:U8[
DR]>:`09CP/00dh:CRY>2P04CPX0158:CPY>2Th:0e8:0Th:00=>2dX:BPX00dh900=:2587BNT01TWZ
0dWY00=5jTGYANT00TGY0dWY0TWX0TWY00A5jTWYBNQ=i`59b@001PPQ1PQ11`PQ00@<8@a1344<@@88
@@0322888@PQ00888@88@P0422888@PQ2242320244001QAQ7:<a1467GVYNS@=JCP=JC`9JK`=JC`QJ
K`03GVmJKeY`009JL09JD09NC`04GVmJKei_GVl6FW000ei`FW1NL003GW002Ej@GW1NSej?GY1NTEj@
GY5NT003GW42GY4015j@GY5NLEi`15jA00ERT5jAHY1RTF:@00=NT@9RT@05HY1NTF:AHY5NT@02HY40
0f:@H[1R/@02HY42HY82H[400f:`HY1R/@02H[800f;CI[9RT@04H[42HY401FJAHY5R/6:aH[000f:a
0fJa00AR/VJaH[5V/@9V/P08I[5V/6JaI[5V/VJaI[9V/@UV/P03I[5V/VJa009V/P03I]=VdVKB00MV
dP03I]=VdVKB00=ZdP9VdP04I_=ZlV[bI]42I[42HY000f9`I[5V/P02I]801FJbI]=VdVJbJ[401F[B
00=Zlf[CJ]800V[B0fKB0V[B00=ZdF[BJ]801F[C1F[B00=ZdF[BJ]800f[b26[B0V[b00EZlf[bJ_9Z
lV[C00]Zl`03J_AZlf[d009Zl`04J_9Zdf[CJ]<2J_<4K_<AJ_<2J_87J_<00f[bJ_=Zl`07J_<5K_<3
J_<3J_8016[cJ]=ZdV[A0V[B0V[A1V[a00MVlF:aGViF2ehZIZeZl002K_400fkbJ_=Zl`03J_<3J_82
J]42J]83J_<00f[bJ]9ZlP04J_82J]<2J_<4K_<3J_<00f[bJ_=Zl`05J_<6J_82J]<00f[BJ_9ZdP0F
J]800fKBJ]9ZdP03I]82J]801FKBJ]5ZdF[bJ]800f[A1FKB00=VdFKBI]800fKB00EVdFKBI]9VdVKA
00=VdPMVd@9V/@YVd@EV/@03I]5V/F:a00UR/@03I[1R/6J`009Vd@03I[5V/6:`00=R/003H[5R/6:a
009R/007I[1R[f:`H[1RT6:aH[000V:a0Uj@00AN/6:`H[1R/0=N/@03H[1NT6:?00=RS`ANT0MNS`03
GXiRSF:>009RSP03GXmNSUj?00ENS`04GY1N/EjAGY03GVh3GVl9FVh01UY]GVeNKEi]GViJK@=JKPEJ
K@03FViJKEY>009JCP03FTaJKEY=00MJC@9FC0=JC0=JC@IFC09FC@EFC003FTaF:eH/009F;006ER]F
BeI;ET]FC5H/15H[00AFBe9;DT]BC0EB;003ER]B:e8/009F:`IB;0=B:`AB:P03CR]>2dh;00Y>2`04
CPY:2dh;CP/;CPX3BP/3CPX01Dh9DPU=j4gYCNX014WZ00A9jDWXCNQ62@95jP95j@=9j@05BNQ=jDWY
ANU5jP02BNT1CNH1CLT000L88@D8@@L88@03324<@@PQ00T88@0312888PPR00888@8<8008440<810P
668a1465FTQNR`=JCP03ETiJCeY_00mJK`9JL09JL@05FW1JCUi_GVmJK`02GVl00eY_FW1JL003FW00
15j?GW1NL5i_1Ui`1Ej@0Uia1EjA0Uia0UjA00=NT6:@HXl016:@00=NT6:@HY400V:A15jA0f:A00=R
T6:_HY000f:A00IR/F:AHY1RSf:@HY43H[43HY43H[44HY400f:`I[5V/004H[000f:aI[5R/P02H[42
I[400fJbI[5V/006I[49I[85I[43I]82I]<3I]83I]<00f[CI]=ZdP02J]8016[CI]9VdVKB0fKA00EV
/F:@HY1RT6JA00=V/@06I[9VdVKBI[5ZdFZa0V[B0VZb00=ZdVKBJ]4016[B00=ZdF[BJ]800V[B1V[C
1F[B00A^dF[BJ]9ZlP9Zl`9ZlP9ZdP03J]=ZdV[A00MZlPAZl`=Zd`9ZlP9Zl`9Zm0AZl`AZd`9Zl`9Z
lP=^l`YZl`03J_9Zlf[c00iZl`03J_9Zlf[c00=Zl`9^l`=^lPA^l`EZl`9ZdP03J]5ZdV[B009Zd@03
J]1Zl6[a00=Zl008I_1Vd6:?FReN:fJ]J]5ZlP9^lPEZl`AZlP03J_5ZdF[B00]ZdP04J_9ZlfkbK_<2
K_8016[bK_=^lf[c0f[b00=Zlf[bJ_800f[b0V[c16[b96[B16[A1FKA0V[A0fKA1fKB2VKA0fJa2VKA
0fJb0VKB00=VdFJaI[401f:a00=V/FJ`I[000f:`0VJ`00=V[f:_H[000f:`00=R[f:`H[003F:`0f:@
00=NT6:`H[001F:@00=RSej@GY002Ej?00ENSV:=HXeRSF:>00=NSP03GXmNSUi_009NKP04GXiNSej?
GVl3GVh015Y^GViNKUi^1eY^00ANKUY]GVeJKP9NKP04FViJKEY^FVd3FV`00eY]FTaJC003FVd00eY=
FTaJC@03FT`2FTd:FT`7ET`00eY<ETaFC003ET`3ER/4ER`015H[ET]F:eI;1EH[00IF:UH[ERaB;5H[
DR`3ER/2ERX3DR/2ER/2DR`3DR/2ERX2DRX2DPX=CP/9CPX00dgZDNY>2P02CNX01TX:BP]:2dh;CPY:
2P99jP03CNY=jDgY009=j@=9jP04BNU9adgWAPT2ANX4ANT2BNP00dWYANU9j@02BNT1BNP1BNL1BLT0
01088@<8@@03344<8@PQ00L88@0722888@PQ22488PPQ22000P`P00X@@0`P320DH3D2@HIJBUZ<FTeJ
CP9JK`04FTmJKeY_FVl2FTh9FVl4FW001EYaFW1JL5Y_FW001EY_0eY`00=NL5j@GXl00Ui`0Ui_15i`
00=NT5i`GW000Uj@00MNL5ZAGW5NLEj@GY5NT002GW43GY42GY000f:@HXmRT005HY02HY43GY45HY43
HY03H[4016:AHY1RSf:@0f:A2V:a00=RTF:`I[400VJa0V:a00AR/6:aH[5R/PAR/@03I[9V/FJ`00IV
/@AV/P05I[=V/VJbI[9VdP02I[800fJaI[9V/P02I]800fKCI]9VdP02I]<01VKBI]=VdfKCJ]=Vd`=Z
dP03I]9ZdfKC00=VdP9Vl`03I]9R/F:A009V/@9VT@AV/P04I[5V/VJbI[83J[401F[BJ]5VdV[AI]80
0V[A0f[B00=VdV[CJ]<016[C00=ZdV[CJ]801F[B00EZlV[cJ_=Zlf[b009ZdP05J_=ZdV[BJ_9Zl`03
J_801V[cJ_9Zlf[cJ_AZl`AZd`03J_=ZlV[c00AZm0=Zl`06J_AZdf[CJ]=Zlf[b0f[c16kc5F[c0V[b
0Vkc1V[c00=^lfkbJ_801Vkc16[c00=Zdf[BJ]800f[B0V[A0V[a16[`00QVcf:>FP]N:fJ]I]5ZlV[c
0fkc0f[c16[b00AZlF[BI]9VdPAZdP03J_9ZdV[B009ZdPEZlP9Zl`=ZlP06J_=ZlV[bJ_9Zlf[b0V[B
0V[b0f[c00=ZdV[bJ_804V[B00=VdV[BJ]802f[B0V[A16[B00=ZdF[BI]800fKA1F[A00=VdFKBI]80
1FKB0VKA0VKB1fKA00=V/FKAI]402FKA00=VdVKCI]<00VKB0VKA00=V/F:aH[401F:a00AV/FJ`I[1R
/@=R/003H[5R/6:a00IR/003HZmR/6:`00AR/003G[5R/F:a00AR/0ART003HXmRT6:@009R/005HY1R
Sej?GY1R/002HXl00ej>GXmNS`03HXl2GXl00f:=GXiRS@03HXh01Uj>GXmNKUi_GViNS`ANK`04GViN
Kei_GVl3GVh>FVh01eY]FViJKUY/FVeJK5Y]009JC004FVaJKUY^FVh2FTd3FT`2FTd2FT`00eY=FTaJ
C005FT`7ET`00eY<ETaFC006ET`00eH]ERaB;@02DT`00eH[ET]F:`02ER/2DR`00eI<ER]F:`02ER/2
DR`5ER/00e8/DR]F:`02ER/00e8[DRa>:`03DR/2DRX00e8:CP]B2`09CP/014h:CP]>2dh;2Dh:0dgZ
00==jDgZBPX00TX;00=>2dh:BPX00TWZ0TgZ0dgY00M9jDWZBPY=jDW8BNQ5j@02ANX024GYBNU:2DX9
CNM9idWXANT3BNT1BNP1BNL1BLX001888@053448@@`Q2248800<22400`PP320<800244002Q0P660e
0D65ERYFC5H]ERiJCUI>0UY?0UY_0UY>0eY_00=JCUY_FVl00eY_0eY`00AJKeY`FW5JL09JK`05GVmJ
CUi_GVmJK`03FW000ei`FW1NS`05GVl3GW0015j@GVmNKej?0Ui`00UNT5i`GW1NKei`GY1NLEjAGW40
0Uj@00=NKej?GVl00V:?00=RKf:?HW000V:@0V:A15jA16:A0V:@00=RSf:@HY000f:@00ARSf:@HY1R
T@AR/@03HY1RTF:A00=RT@9V/@=R/003I[5R/F:a00=R/007H[5RT6:aI[5R/FJbI[401fJ`0VJa2fJb
00EV/FJbI[5R/VJb009VdP03I[9VdVKC009VdP08I[5VdV[AJ[9V/VKBJ]=Vd`AVdP03J_9ZlfKA009V
/@ERT@=V/@=V/P04I[5Z/FJaI[42I]400f[AI]9Zd@04J]42I]86J]83J_84J]800f[bJ_=Zl`06J_82
J]86J_84J_<2J]<2J]800f[cJ_9Zl`02J]<4J_<00f[bJ]=ZdP02J]<00f[BJ_9Zl`02J_<00fkcJ_9^
lP02J_8:J_<2J_89J_<3J_86J_<3J_800fkbK_=^l`03K_<4J_<00f[bJ]9ZdP03J]800f[bJ]5Zl@02
J_4026[`J^mZkfK=GVaEjUX8IX`2J_800f[cK_=^l`04J_801F[BJ_9ZlF[aJ]400VKA00=VdV[BJ]80
1f[B00=ZlV[BJ]800V[B0V[b00AZdF[BJ_9ZlP9ZdP03J_9Zlf[b009ZdP9ZlP03J]=ZdV[B009ZdP03
J_9ZdV[B011ZdP03I]9ZdV[B00EZdP07I]9ZdV[BJ]9VdVKAJ]400fKA00EVdV[AJ]5ZdFKB00AVd@03
J]5Z/F[A009Vd@=VdPMVd@03I]9VdFKA00EVd@05I[5VdFKAI]5V/@07I]401FJbI[5V/VJcI]800VKA
0VJa00IV/6:`I[1R/F:`H[43I[000f:aH[1R/008H[02HZl016:^HXmRT6:`0V:@00AR/5jaH[5R/@AR
/0ART09RS`03HZmR/6:`009RS`=NS`06HXmRSV:=GXiNSf:?15j?0Uj>00YRSEj>HXeNSUi]GViNSUj?
GViJK`ENKP05FViNKej?GXmNK`03GVh;FVh2FVd2FTd00eY<FVaJK002FV/2FT`3FVh2FTd3FT`2FTd3
FT`00eY;FTaJC004FT`5ET`2ET/00eY;ETaFC004ET`3ER/01eH/DTaBC59<DR]F:eHZ009F:`03DRaF
;5H/00AF:`9B;0AF:`03DP]B:eH[00=F:`9B:`07DP]>:e8;DP]B:U8;DPX01dh;00E>2Th;CP]>2dh:
00=>2`03BP]>2Th:00I>2P9=jP9=j@99jPE:2PA9jP9=jP=9jP05BPY=j4WWBNQ5j@02ANX3ANT014GX
BPM5idWX0TWY0TGY0TW80DW:00032245124322400`@Q22488@02224010`Q2248@@Q10PPQ00<880PQ
224020PQ00l8@Pa3348<8@`P340@@0`P560`hCeUBPYB;EI<ETd00UY?00AFCUY?FTmJC`9JCP9JK`9J
CPUJK`9JL003FW5JKei_00ANK`03FVmJL5Y`00=JL0=NL09NK`ANL003GY1NL5i`00=NL0=NT003GXmN
L5i`00=NL@INT003HY1RTF:@00=RT003HY5NTEjA00=NT@04HY1RTF:AHY42GY46HY000f:?HY1RT002
HY43H[44HY4016:@HY5V/VJa0V:A0f:a00AR/V:aH[5R/@9R/P=R/@03I[5R/FJ`00IV/@IV/P=R/PMV
/PAVdP=Vd`03I]9V/VJb00=V/P05J[5VdVKBI]=VdP02I]<2I]8016KcI]9VdVJa0V:a16:A0VJa00=R
/FJbI[800fJa00=VdVKAI]8026KB1f[B00=Zlf[bJ]800f[B0V[C0fKC00=ZdV[bJ_802f[B00=ZlV[c
J]<00V[B0V[C0f[c0f[C0f[c00=Zdf[BJ]800V[C00EZdV[cJ_AZm6[c00EZlPQZl`=Zd`03J_9Zlf[c
00QZl`03J_9Zlf[c00QZl`05J_9ZlfkdK_AZl`04J]<00fKCI]9VdP05J]8016[bJ_5ZlF[a0V[`00QZ
kfK=HVeEjUWWIX]ZdF[B0f[c0V[b0f[B00AZlf[bJ]9ZdPEVdPUZdP04J_9ZdV[BJ]82J_800f[cJ_9Z
lP02J]800f[bJ_=Zd`02J]<016[cJ_9Zdf[C1V[B00=VdV[BJ_802f[B00=ZlVKBI]800VKB1V[B16KB
0V[A0VKA0VKB00=VdFKBI]800VKB16KA00=ZdFJaI[400VKA26KB0VKA00=V/FKAI]403FKA00IV/FJb
H[5R/FJaH[42H[82I]401fJaI[1R/6:`I[1V/FKA009VdP03I[5R/6:`00YR/0=R[`9R/005G[5R/6:a
H[5N/@06H[4016:@HY5NTEjA0V:@00=R/6:@HXl00V:?15j?00=NT5j?GXl025j?00UNSUj?GXiNSf:>
GViNSUj?GVh00ei_0ei^0Ui_0ej@00=NKei^GVh01UY^00=JKeY^FVh00UY^0eY]00AJKUY]ETeJK09J
J`9JK@=JKP9JC@=JC09JC@IJC09JC@03ETeFC5I<00MFC003ETeFC5I<009FC005ERaF:eH[ER]F;002
DT`00e9=ERaF:`02ER/015HZDR]B:e8/0eH[258/1E8[00EB:U8;DR]>:e8[00=B2`04CPY>2dh;DP`2
CP`5CP/00dh[CP]>2`09CPX014X:CPY>2TgZ0TWZ00==jTWZBPX01DX:00A:2dWZBNY=j@E:2P03BNY9
jDWY00=5jP=5j@0:APU:2DH9BNQ9jDgYANU9jDGXBNL1BLX0008880<88@888P0312888@PQ00888@04
12488@PQ224232401@Q1224<8@PQ22002PPQ00@88PPQ22488@<<8006200@82S1>FA5jUI=0UY]0eY>
00=FCUY?FTh00eY>00=JCeY>FTh02UY_0UY`15Y_0ei_00=JKeY`FW001Ei`0Ui_00EJL5i`GW1NL5j@
00ENL006GY1NL5j?GXiNKei`1Uj@0UjA1Ej@0V:@1EjA00=RT6:?HY000f:A00=NTF:AHY002F:@0V:a
16:A00=RT6:?IY000VJA00=RTF:aH[402F:a0V:`00AV/6JaI[1V/AMV/P03H[9VdVKB00AVdP=V/P9V
/@03I]9ZdVKB00=VdP=Vd@=VdP05I[5RTF:?IXmR/003I[400f:aI[9V/P03I[42I]46I]800fJaI]9V
dP02J]84J]400f[BI]9ZdP05J]8026[CI]=Zdf[CJ]9ZlV[BJ]4?J]83J]<00f[cJ]=ZlP07J]<4J]80
2F[cJ_AZlfkcK_9ZlVkbJ]5ZlP06J_<00f[dJ]=Zd`02J]<00f[bJ_=Zl`07J_<2J_86J_<00f[bJ_=Z
l`06J_<5J]<7J]803V[AJ_5ZlF[aK_1_46[_I/eRSEG[FNQVS6K?J_83J_<016kbJ]9ZdV[b0V[c00QZ
lV[BI]9Vdf[BI]9ZdVKB2V[B1f[b0V[B00=ZlV[BJ]<016[C2V[B00=ZdF[BJ]8016[B00AZdF[BJ]9Z
dP9ZlPMVdPAZdP04J]5VdF[AI]87I]48I]8016KAJ]5V/6K@0VKA1FKB00=V/FJbI]4026KA2VJa0f:a
00=V/FJbH[400V:a56:`00ERT6:?HXmV[f:?00ER/005H[5NTF:aH[5NT@03HY02HY401EjAHY5RT6:?
HY001V:?0ej@45j?1Ui^0ei]00=NKUi_GXh00eY^00=NSUi^GVh02EY^0eY]00=NC5Y<FVd00eY]0UY[
00=JK5Y]FVd00UY=1EY<00=JCEY<FT`01EY<0UY=00AFCEI<ETaJC0AFC003ETeFC5I=00EFC0=F:`03
ERaBC5I<009FC004ERaF:eH[ERX2ER/3DR/00eH[DR]B2`06DR`00e8[DRYB:P05DRX0158[DRYB:U8Z
0Th:00A>2e8;DPaB309>30E>2`U>2P03BPY>2Th:009>2PE=jPI:2P09ANY9jTWYCPU5jDX8BNU9jTG[
0099jP03BNU9jTGY00M5j@07BNU5b4WYANU9jDG7BLH00DVY0002220422400`PR12888P02228010@R
22448@PQ0PQ10Pa100D<@Pa122488@PP00<88@0322088@PQ00L88@0@220<80P0200@82S2=D=5jEI^
FXeJKEY>FTeJCUI>FTl2FTh2FTlEFVl5GVl00eY`GW1JL@02FW4015Y`FW5JLEZA25j@00ENL5i_GViN
Kei`009NT003GW1NT5j@00ANT@=NT0QNT@=RT09RT@ANT@=RT0=R/006HY1R/F:aH[5RT6:a0f:A00=R
/FJ`IY000VJa00=RTF:aH[4026:a00AR/V:aH[5V/0=V/@MV/P03H[9V/VJb00eV/P9R/`AVdP=Vd`03
I[9V/FKA00MVdP09J]1VdFKAI]9VdFJaIY1RSfJ?00AV/@=R/@03I[5VdVKA009Vd@03I[9VdVKB00=V
dP03I[9VdVKB00AVdP04J]5ZdV[CI]<2I]83J]84J]<2J]800f[bJ]9ZdP09J]801V[CI]9Zdf[BJ]=Z
dPAZd`9ZdP9Zd`04J_=Zdf[cJ]<5J]801F[CJ_AZlfkcK_800f[B00=ZlV[cJ_<016[c00=Zm6[cJ_<0
0f[C0V[c00=Zm6[cJ_<036[c00=ZlV[cJ_801V[c1F[C26[B00AZdF[BJ_5Zl09_4@07J^iNSUH;FRYV
S6[@J_400V[c00IZdf[AJ]=ZdV[CJ_82J_<01f[bJ]=Vdf[BI]9VdFKB009ZdP03I]9ZdV[B00IZdP=Z
lP03J]=Zlf[b00=ZlP03J]9Zdf[B00=Zd`=ZdP9ZlPIZdP03J]=VdV[C00EZdP03J_9VdVKB00IVdPAZ
dP04J]5VdF[AJ]42I]42I]83I]42I[42I]800f[CJ_=VdP04I]800fKAI[1V/@02I]47I]8:I]43I[42
I]46I[42H[43H[84H[4BH[001F:_I[1VSfJ?HXl016:`00EN/EjAGY1NT5jA009NT005HY1RTEjAGY5R
T@02HY001Ej@HXmRSf:?HY000V:?0Uj@1Ej?0Uj>2Uj?00ANSUi^GVeNK@INKPaJKP03GVeJKEY>009J
CP9JK@03GTeNC5Y<00AJK@AJK003FVeJCEY=00EJC0=FC0EJC0=FC@=FC009ER]FC5Y=EReFCUI<ETeF
C5H/00AFC09F:`03ERaBC59<00=BC006ERaF:eH[DRaB:e8/1e8[1E8/00=B:e8ZDRX00U8Z0e8[00IB
:U8[DRYB:e8:CP/2DP/2CP`6CP/8CPX3BPX00dX;BPY>2P03BPX3BP/2BN/2BPX2ANX2BNX01TX:APY=
j4WWCNQ9jP95jP03BPU9jDWZ0099j@07BNQ5j4GYBPY9jTGYBPX00dWY0DGX0DWV0DW9000222052240
10@R22888PPR0P@R00@48@Q12448@@<88@0332488@PP008880X88@<880<<8007440P`SDRANUFC5j;
FT`00UY=00=JCUI>FTl00UY>00=JKeY?FTl015Y?25Y_00AJCUY?FTmJC`AJK`ENK`06FVmJL5YaFW5J
TEY`0eYa0ej@00QJL5j@GY1NT5Y`GW1NKei^0Ui_0Uj@00=NL5j@GY002Ej@1UjA00ART6:?HY1RT0EN
T@04GY1RT6:@HY05H[000f:aHY1RT@02HY42H[400f:?HY1VS`02HY43H[42HY46H[401F:@H[5R/6:`
I[000VJa2fJb00=V/FJbI[802VJb00=R/VJbI]800fKB00AVdfJbI[5Vd09Vd@0:I[5V/VJbI]9VdF[@
I]1VdFKBJ]42I[400fJ@I[1V/003I[0016:@H[5R/FJa1VKA0VKB0fJb1VKB00AZdF[BJ]=VdPMZdP9Z
d`YZdP04I]9ZdV[BJ]83I]8;J]83J_83J]802F[CJ]9ZdV[CJ_AZlfkbK_5ZlP03J]84J_83J]<00f[c
J]=ZlP02J]82J]<6J_<3J]<016[bJ_=Zlf[c2f[b00=Zlf[CJ]<00V[C16[B1f[A00]Zd6[`Ka1ZcUj=
EPYN:6J<I/mZl6[b009Zd`EZdP03I_=Zlf[b009VdP03J]5VdFKA009VdP03I]5ZdV[B00IZdP03J]5Z
lF[a009ZdP03J]=ZlV[b009ZlPAZdP9Zd`YZdP04J]5VdVKBI]87J]8;I]82I]4016[AI]5VdFKA0VKB
0VKA0fJa1VKA0fKB00AVdFJ`I[1V/@UVd@=V/@IVd@=V/@AVd@04I[5V/6:`I[03I[400f:aH[9R/P02
H[800f:aH[1R/006H[000f:_H[1R/004H[001F:@HXmR[f:^HXh00VJ?0V:?00=RT5j@GY000Uj@0ej?
15j@0f:A0f:@0V:?0V:@00=RSej@GXl01Uj?00ANSUj?GXmNS`ANSPANS`03GXiNKUi]009NKPENK@04
FViNKUi^GVh7FVh035Y/GVaJC5Y]FTiNKUi]FVeNBei<FTaJK@9JKP03FVeJC5Y[00=JK09JK@9JC@UJ
C0AFC003FTeFC5I<00=JC003ETaF;E9=00=FC0=F;09FC09F:`03DR]B;59<009FC007DTaF;58/DR]B
;58[DR`01e8[158/00=B:e8;DP/00U8Z00AF:U8[DR]B:`9B2`03DPY>2e8:009B:P9B2`03CP]>2Th;
00A>2`E>2PM:2P04CPY>2Dh9BPX3BNX00dG[BN]5j`02ANX2BNT3BNX034WYCPM5iTX7BPU:2TX9BPQ9
jDWZBNU9j099i`03ALM5bDGZ0095j@05BNU5jDGZALQ9aP01AJT00005224880`Q22888@0622800`@R
2288@P03244522400``Q22088@0222423242344422400``P3248800332001a107:8e8dGYDRaJJeY<
009JCPAFC`MJC`EJK`05FTiJKUY^FVmJKP07FVl5GVl2FVl2FW401EZBGY5JLUY`FW400UY`15j@0UY`
0Ui`00ANKei`GW1NT09NL003GY1NTEjA00ENT@9NT0ENT@9NT004GY5NT5jAGY02GY400ejBGY5NT@02
GY43HY0015j@GY5R/F:@0f:A00IRT6:aH[5R/F:@HY42HY000f:AH[5R/@03HY42HY88H[401F:`H[5R
/F:bH[4016Ja0V:a0V:b0VJb00=V/FJbI[801FJb00AV/FJbH[9V/P9R/PAVdP03I]=V/VJa00=Vd@03
I[5VdVKB00MVdP9Zd`03I]9V/6J`009V/003I[5R/F:`009R/@03I[5V/VKB00=VdP03I]=V/VJc009V
/`03I[9VdVKB00MVdPEZdP05I]9ZdV[CJ]=VdP09J]84I]83I]<01VKBJ]=Zdf[CJ]9Zd`=ZdP03J]=Z
dV[b009ZlPAZdP03J]5Zdf[C009Zd`9Zl`04J_A^lf[CJ]83J]<01f[BJ]=ZdV[CJ_=Zm6[c00AZd`03
J_=ZlV[c009Zl`AZd`04J_9Zlf[cJ_<4J_82J]82J_84J_<3J]<01VKCI]9VdV[BI]9Zd@=ZdP9Zd@9Z
l@9Zl009J/iNSUH;FNQRJfJ^K_5ZdF[b009ZdP=Zd`06J_9VlfKcI_=VdVKC0VKB16KA00=ZdF[BJ]80
1F[B00AZdF[BJ]9ZlP9Zd`9ZdP9ZlPMZdPMZd`04J]9ZdF[AJ]45J]86I]800fKCI]9VdP06I]8CI]43
I]800fKAI[5V/@02I[48I]4016KBI[9V/VJb0fKA0fJa00EV/V:aI[9V/F;A00IR/@=V/@04H[9R/F:b
H[83H[4@H[000f:_HXmRS`02HXl00f:@GY1NT@02GY000f:`G[1NT002GXl2GY000ejAGY1NT@03HY00
0ej@HXmRT002HY000f:?GY1NS`05GY06GXl01Ej>GViNKUj?GXh00Ui^0ei_00=NKUY^GVh015i]0Ui^
00=JKUi^FVh01eY^00=JKEY^GVh00Ui^00aNKEY^FTaJCUY=FTiJKEI^FVeJCEY<FV`2FT`015I=EViF
C5Y=1eY<0eI=1eI<00EJC5I<ETeFCE9=00AFC09F;09FC09F:`04ERaBC59<DT`6DR`00e8[DRaB:`02
DR/2ERX2DR/3DR`01Th/CR]>:dh[DRYB:`AB:P04DP]>2e8:CP/4DPX2CP/01Dh:CP]>2dh;CPX01Dh;
14X;14X:00E>2Th9CPU>2TgZ0099jP=:2`9:2P0:BNY9jDWYBNY9jDWXCPM:24X7BPT2APX00dH9BPY:
2@02BNP014W6CNE9adWY0dGZ00E5jDGZANY5b4G70055Z@000PQ100<88@PR22801@PR00<88@PR2440
0PQ10PPQ00<8@@PQ224010PQ00<880PQ32400Pa100D8@@`Q224880PQ00<8800=324<80`0320@81R2
<B=1Ydh/FT]JC5Y=FTl015I?1UY?1EY_1EY^1eY_1Ui_0UY_1EYa1EY`0ej@0ei_15i`15j@00=NTEia
GY400UjA00=NLEjAGY0035j@0UjA00ANTUjAGY5NT@ART@INT@9RT09R/003H[5RT6:A009RT0IRT@9R
TP03HY5R/F:a00ER/@06H[1R/F:aH[9R/FJa0f:A0V:a00=R/VJcI[<00VJb0VJa1FJb00=V/FJbI[80
0fJb0VKB1FJa0VKA0VJa0fKB0fJb0VKB00AVdFJaI[5V/@9V/09RS`05I[1R[f:`GViRT003H[4016Jb
I]=VdVKC0VJc0VJb00AV/FJbI[9V/PAVdP04I]5ZdF[AJ]43J]800fKBJ]9Zd`03J]<016KBJ]=ZdV[B
0V[A00AVdV[BJ]=Zd`MVd`03J]=ZdV[A019ZdP03J]=ZdV[C00UZd`9ZdP03J]=VdV[C00=Zd`9ZdP9Z
lP05J]=Zlf[CJ_=Zd`09J_83J]800f[bJ_=ZlP03J]<4I]<00f[CJ]9Zd@03J]82J]403F[aJ_1_46lA
J/iRSE7:ELMRBVJ^K_1Zcfka00IZdP03J_9VdVKB00AVdPIVd@04J]5ZdV[BJ_82J]801F[AJ]9ZdV[b
J]8016[b26[B1F[C00=Zlf[CJ]800VKA0f[A0f[B00=VdV[CJ]<00fKC0VKB00=VdfKBI]800VKB00=V
dFKBI]405fKA16Ja0fKA0fJa00=VdFKBI]800VKB00=VdFK@I[000VJa16:a0fJa0fJ`16Ja00=V/6:a
H[400V:b16:a26:`1f:@1F:?00=RT5j@GY402Uj@1F:?00=NSf:?HXl00f:?1Ej@15j?0Uj>0ej?15j>
0Ui^0ei_00=NSUi^GVh00eY^00ANKEi^GViJK`=NKPEJKP9JK@9JKPANK@9NC@9JC@05FVeFKUY]FTeJ
B`04FT`00eY]FVaJC005FT`2ET`3ETd7ET`3ER/3ET`00eI=ETaBC004ER`3ER/7DR`0158[DRaB:e8/
2E8[00E>:e8[DR]B:e8;009B2PEB:P04DPY>2Th:DPT3CPX0158:CP]>2Th;14h:1Dh;0dX;0TX:0Th:
0dh900M>2TgYBNY9jTX:BP]9j`02BPX3BNT01dWXBNU9j4h7ANI:1TGW00=5j@07BNQ=j4WWBNM5aTgV
BNL00TGY1DGZ0DG80DWW0DG:0002248234823284228422442444224234401@PQ3248@@Q234800`PQ
00D880PQ22488@`Q008<@@0:320800P0684]0cf7CRaJJeI;FTd4ETl00eI@FTmJC`05FTl4FVl4FVh0
0eY_FTmJL005FVl00ei_FTiNK`02GVl00eY_FW1JL002FW03FW48FW02GVl00ej?GY1NL004GW02GY03
GY42GW02GW4=GY0@GY400f:AHY1RT003HY08HY43HY800f:AHY9R/@05H[4016:`H[5R/F:b0V:a0V:A
00=V/F:aH[4016Jb00EV/fJbI[9V/V:b00aV/PEV/@04I]9VdFKBI]83I[801VJcI[9VdfKCI]9V/@AV
d@08H[1RT6:@H[5V/6JaH[5RTPAR/P9VdP05I[=VdfJbI[9V/@05I[84I]801FKAJ]5VdFKAJ]400VKB
1VKC0fKB0f[B0VKB26KC00AVdV[BI]9ZdP=VdPMZdP03I]9ZdV[b00=VdP03I]=Zdf[C00YZd`03J]9Z
dfKB009Vd`=Zd`03J]9Zdf[B009Zd`05J_=Zdf[cJ]=Zl`05J_802F[cJ]=ZdV[BJ]=ZlV[cJ_9Zl`02
J]<00fKDI]=Vd`02I]<00fKBJ]5VdP04J]803V[bK_1c<FlAJ]1RSe7;ELURJfJ_K_5ZdFkcJ_<2J]<2
J_83J]800fKCI]9VdP02I]86I]400f[AJ]9ZdP0:J]800f[bJ]9ZdP07J]85J]<2I]<2I]82I]45J]82
I]84I]<3I]8016[BI]9VdV[B1fKA00=VdVKAI]402fKA0VKB00AV/VKAI]5Vd@AV/@04H]5R/F:aI[42
I[85I]82I]400fJbH[5R/@03H[403FJ`I[5V/FKAI[5V/6JaH[5V/6JaI[1V/F:a00=R/PER/@03HY1R
/6:`00=R/0=R/@04HY1R/6:`H[06HY001ej@GY5NT5jAGY1NTEj@00=NT@9NT0=RS`=NT0ERS`ENT0EN
S`03GXiNSej?00ANSP=NKP=NK`9NKPEJKP9NKP03GVmNKUY^00=JKP03FVeJKUY^009JKP9JK@0;FViN
KUi]FVeNC5i=FTeJCUY]EViJK@03FTd3FT`00eI<FV]FC@02ETd3ET`4ETd01eI>ETeFCEI<ETeFC5I=
009F;@9F:`AFC0EBC003DReF;5I<00AF:`YB;0IB:`03DRa>;58[00=B2`9B2P03DRYB:e8[00=B:`03
CP]>2Th:009>2PE>2`05CPY>:ThZCPY>2`03CPX00dh;BP]:2`03BP/2BPX3CPT5BPX014W[BPY:2TX9
1DWY00Y:2Dh8BPQ:24WXBPQ:2DgYBNQ=j099j005BPU:24GXANU5b@03AN/2ANX1ANT1BNP1ALX000<<
@@04244<@@`Q324522432447224010a0364<@@`Q1PPQ0PPP0P`P0`a100/@@0`P200DHBd3?HM>;5i[
ET]JCUY?009FC`03FTmFCeY?00=JC`04FTeJCUY>FTl3FVl01eY^FTiJCUY>FTmJD5Y`00EJK`03FTiN
Kei_009NK`03FVmJL5Y`009JL003FU1JLEYa00AJL09JK`9JL09NK`03GXiNSei_00ENL0=NT003GY5N
LEia009NL004GVmNL5i`GW02GY03GW05GY02GY42GY000ej?GY1NT@07GY42HY44HY000f:?HY1RT002
HY400f:BHY5RT@02HY42HY83HY45H[400f:`H[5R/@03H[400fJaH[5R/@03H[401FJaH[9RTV:BH[80
0VJb00=R/VJbH[400VJb0VJa1VJb1FJa00AVdVKAI]9V/@AV/P05I]9VdfKCI[9VdP03J]402VKBI]5R
/6:@H[5V/F:aHY5NTF:A0V:a00QR/VKBI]9VdVKCI]9V/VJa1FJb00=VdVJaI[400VJa16KA0V[A2FKB
0f[A0VKB1FKC0V[C00=VdfKBI]801FKB1F[B00AZdF[BJ]9ZdPAVdP03I]=VdV[C00=Zd`05I]=Zdf[C
J]9VdP02J]<016[BI]9VdVKC16[C00=ZdV[CJ]800V[B00=Zdf[cJ_<00V[C1F[b00=Zdf[BJ]800V[B
0V[b00AZdVKBI]9Zd`=Vd`=VdP9Zd@AZdP0:J_9^kg<`J_1V[ei_EPeJ2f9[IZl2J]400f[BI]9ZdP06
J]83I]8016JaI]9VdFKA0VKB0V[A26[B00=ZdF[BJ]8026[B0V[A1F[B00=ZdfKCI]<00fKB0VKA00=Z
dFKBI]8016KB0fKC00=ZdfKBI]400fKB0f[A2VKA00=V/FKAI]400VKA0VJa0fKA0VKB00AV/FKAI]5V
d@AV/@04H[5V/FJaI[42I[84I]800f:bH[5R/@06H[401VJaI[9V/FJaI[1R/09R/@=V/0AR/@03H[9R
/F:a009R/@03HY1R/F:`00AR/0=R/@ER/09RT09RS`9RT006GY5R/5jAGY1NTEj@0UjA00=N/F:`GY00
0f:?0ej@0f:?0V:>2Uj?15j>1Ui^00=NKei^GVh00ei^1EY^0Ui^00=NKEY]FVd00UY^0eY]0UY^00=J
KEY=FT`00UY]15Y<0UY=00=FKUI=FTd00UY=00=FBeY<FT/00UI;0eI=1EI<00=FCUI=ETh00UI=0eI<
00=FCEH]ERd00UH[0eI<0U9<0e8/00EF;59=ERaF;5H[00]B;003CRaB;58[00EB:`03DRa>;58[00=B
2`9B2PAB:P03DPY>2Th:00A>2PE>2`A>2P03CP]>2Th:009>2P05CP]:2dX;BPY:2`02BPX3CPT5BPX0
14W[BPY:2DX90TWY00=5bDG8BNT00dGY00A9j4WWDPE9i`99j@04BNQ9idWXANP3ANT2ALT01T79ALU5
jTWYANU9a`59Z@0000D<@@Q12448@@`Q00d88@88@@05348<@@a13448@@0922433202344244002@`P
564Xhcf6CRaJC5Y/FTiJC`04ETl4FTl3FTh01EY?FU1JD5Y?FVl00UI?0UY?00AJD5Y`FVmJK`9JCP9J
K`ANK`03FVmJL5Y`009JL0EJL@EJL004FW5NL5i`GXl4GW001UjAGW1NL5j@GY5NT09NL@9NL004GVmN
L5i`GW03GY0015i`GW5NL5ia0ej@1UjA0Uj@1ejA00IRT5j@GY1NT6:@GY43HY43HY85HY4016:BHY5R
TF:A1F:a0f:`00AR/F:AHY5R/@ER/P04H[5R/V:BHY86H[83I[800fJaI[9V/P06I[8016JaI[9V/VKB
1fJb00=VdVKCI]800VKC0VKB00UVdf[dJ_=V/VJaHY9RTF:aI]800V:b00=R/FJaH[800V:c16KC00=V
dVJbI[801fJb1FKB00AZdV[cJ]9ZdP=VdP9Vd`9VdP=ZdPeVd`IVdPAZdP=VdPIVd`03I]AZdf[C009V
d`9Zd`03J]9Zdf[C00MZd`9ZdP9Zd`EZdP=Zd`03J]9ZlV[B00IZdP9Zd`9ZdP9Zd`IVd`03I]9ZdV[B
00EZdP0=K_1_46[`I[1NKeH=EP]RK6:_I]1VdV[CI]@00V[C1fKB00=V/VKBI]800fKA0VKB36[B00=Z
df[BJ]800V[B0V[C00=VdV[BJ]4016[B0f[C0VKC2fKB0fKC0VKB00QVdFKBI]9VdVKAJ]5VdFJa1fKA
0VJb0VJa0fKA0VJa0fKA00AVdVJaI[5V/@9Vd@9V/@04I]5V/F:aH[42I[42I[800f;BH[9R/P03H[82
H[400f:bH[5R/@03H[400f:bI[9V/P04H[42HY4016:`H[5R/F:A16:a00AR/6:aH[5NT@ER/0ER/@9R
/09RT0=RS`9RT003GY1R/5ja009NT@04GY1NTEjAGY42GY03HXl3GY08GXl2GXh2GXl3GXh01Ej?GXiN
KUi^GXh00Ui^00=NSUj?GVh00ei_00=NKUY^FVh00UY^00mJKeY^FVmJKUi^FVeJCEY]FViJKEI>FViF
CUY=FVd015Y^1UY=00AFCEI^ETeFC@AJC@=FC003ETiFCEI>009FC@=FC004ETiFCEI>ET`3ETh00eI<
ETeF;@03ERd00eI<ERaF;003DRd2DR`00eH/DReB;009DR`00dh]DRaB;005DR`4DR/0158/CRaB:e8<
158;00=B2Th;DRX00U8:0Th:00E>2dh:CPY>2Th;00=>30M>2`=>2P03CP]:2dX;009:2`9:2P9>2PI:
2P04BN]:2TWZBPX3BNX2BNT3ANT01DWYBNQAiTW7CNP00TWY00A5j4WXANU9j@A5jP95j@04ANY5bTW9
BLP1BLX000H88@@881P88@8<808<8@8<@08@@007564Xhcf6BP]JC5I<ETd00UY>00=FCUY?FTl015Y?
0UY>00AJCEY?ETmJD0QJC`=JK`=JCPANK`EJK`05FW1JLEYaFW5JL002FW4015Y@GW1NL5Y`35i`0Uj@
00ANL5i_GVmNL09NK`9NL09NT0ANL003GY1NTEjA015NT@ERT@03HY9R/V:B009RTP03H[9RTV:A00=R
T@06HY9RTF:AH[5RT6:a1F:`00ERT6:aH[5R/F:b00AR/@=V/@MR/P=V/P9V/@03H[5V/VJb00iV/P9V
dP03I]=VdVKB00AVdP07I]=VdVJbI[9R/V:BHY400V:a00=V/FJbI[800VJb00=V/fJbI[800fKB3FJb
16KB0V[B00=ZdFKBJ]<01V[C2fKC1F[C0fKC00=Zdf[BJ]8016[B00=ZdfKCI]<00VKC1f[C0V[B00=V
dV[CJ]<00f[C1f[B00AZdF[BJ]5Zd@eZdPIZd`0:I]=ZdfKCI[=VdfJcI]=Zdf[BJ]44J]803F[AKa1Z
lVJaGVmF35GYGV]R[fK@J]9ZlfKD009Vd`9Zd`03J]9VdVKB009VdP03I[9VdVKB00AVd@03I]9ZdV[B
00UZdP03J]5ZdV[B009ZdP9Zd`03I]AVdV[B00EZdP04I]9Zdf[CJ]<?I]89I]42I[46I]400fKBI[=V
/P0:I]43I[42I]4:I[400fJbH[5R/P03H[82I[800f:bH[5R/@06I[83H[400f:bHY9RTP04H[45H[03
H[44H[000f:_H[5R/@03H[400f:`HY1RT002HY001f:?HY1RT6:@GY1R/5ja009NT@04GY1NTEjAGY42
GY03HXl00ej?HXmNS`09GXl:GXh00ei^GXiNSP07GVh00eY^GVmNK`05FVh015Y]FViJKUY^0UY]00=J
KUY_FVh00eY]0eY=0eY<15Y=00=FCEI<ETd01EY=00AFCEY=FTeJCP9FCP04ETeFC5I<ET`3ETd01UI<
ETeFCUI=ETaFC@9F;@08ETeF;EI<ETaF:eH/DReB;0=F:`03DRaF:eH[00EF:`06DRaB;E8]DReB;58[
1e8/0e8[00E>:e8[DPaB:e8;009B:`9B2`=B2P9>2PE>2`I>30A>2`=>2P9>2`03BP]:2TX:00E>2P03
BPY9jTWZ00E9jP04ANY9jTWZBNX2BNT3ANT2BNP00dG8BLQ9j002ANP7ANT01dWYANU5jDGZALY5bDW8
0055ZP001@PQ0PPP00<88@`P320030PQ00<880PQ224010PQ00T88PPQ22488@`Q320<8@`P32400Pa0
00/<@A1R464XhcUUBNYB;5I<ETeF;UY>009FCPEFC`AJC`03ETmJD5Y?00QJC`9JK`9JCP9NK`QJK`03
FW1JD5Y@00=JD003FW5NL5i`00ENL0ENT0=NL0=NT0MNL0ANT0ENT@=NT0ENT@03GY1NTEjA00YNT@9R
T@URTPERT@QR/@05HY5R/F:aH[5R/P02H[45I[44H[8016:cH[9R/VJb0V:a00EV/V:aH[5V/V:c009V
/P03I[5V/VJb009V/P04I[=V/VJbI[82I]83I]<;I]801F:cHY5RT6:@H[400VJb00=V/FJbI[8016Jb
00=VdfJbI]800VKB00=V/VJcI[8026Jb00IVdfKBI]=Zdf[BJ]42J]82J]<3I]<00fKBI]=Vd`09I]<0
0f[CJ]9ZdP02J]83I]<00f[CJ]9ZdP05J]800f[CI]=Vd`02I]<6J]<00fKBJ]9Zd`05J]<7J]800f[A
J]9Zd@02J]42J]82J]45J]82J_83J]84J]<00fKCJ]=Zd`02I[8016JcI]=Zdf[C1F[B00mZdFlAI]5R
/5Y^FRaJ2V9/H[1VdFKBJ]=Ve6KCI]@00f[C00=VdfKBI]800fJb00=VdVKAI]400fKA0VKB2V[B1V[C
00=Ve6KBI]801F[B00AVdV[BJ]9ZdPQVdP03I]=VdVKC009Vd`QVdPMVd@AVdP03I]=V/fKC00AVdPIV
d@03I[5V/VJb00=VdPUV/@03I[9R/F:b00IR/P04I[9R/V:bH[42I[800fJaH[5R/@09H[400f:`H[5R
/@04H[400f:`HZmR/003H[05H[42H[000f:?HY1RS`02HXl2HY000ej@GY5N/@02GY401Uj@GY5NTUjB
GY5NT09RS`03GXmRSej?00QNT0=NS`]NSPANKP04FViNKUi^GVh4GVl8FVh2FVd3FVh00eY]FViJCP03
FTh3FT`2FTd2FVd015I=FVaFKUI>25Y=0UI>00AFCEI<ETaFC0=FC@06ETaFCEI>ETiFCEI>0UI=0UH]
0eI<00=F;5H]ER`02eH[00=F;5H]ERd00U8/00=F:e8/DR`0158/0dh/0Th[00AB2e8<DR]B2`9B:`9B
:P9B2P03CPY>2dh;00E>2`I>309>2`03CPY>2dh;00=>2`E=jPA>2`04BP]=jTgZCNT4BNX7ANX3ANT0
0dWYANU9j@0=ANT2ANX1ALT1BLP1AJX000@88@8<8@04320<@0a0220:2243220422400`@Q22888P02
2242324432002@a0344<@@aR464X`cE4ALUB:`02ET`015X/FTiFCUI>0UI?0UI@00=FCeY?FTl035Y?
0UY>00=JKeY>FTh01EY>1EY_00=JD5Y?FU000UY@0UYa15i`00=NKei`GW000Ui`0ej@00=NL5i_GVl0
0Ui_1ei`15j@1EjA0ej@1ejA00=NT5jAGY4025jA1F:A0f:B00=R/V:BHY400ejA00ARTV:AHY9RT@9R
T003H[5RT6:@00=RT@=R/@03H[9R/F:a00EV/@03IY5R/V:b009R/`9R/PMV/P03H[9V/VJa009V/@=V
/P04I[=V/VJbI]85I]<00fKBI[9V/P07I[82I]8026JbI[5RSei^GY1R/FJaI]82I[4026JAI[9V/VJc
I[9R/VKBI]<5I[82I]85I[801FKBI]=ZdVZaJ]400V[B0V[C0VKC0fKB2VKC0V[C0V[B00=ZdF[BJ]80
0V[C1F[B00=ZdF[BJ]<00fKC1f[C00=VdV[BJ]<01F[C1f[B1V[A00=ZdV[AJ]401F[B00=ZlV[BJ]80
0V[B1F[C0V[B0fJb00=VdV[BI]801F[B00UZd6kaI]1R[ei]EPYJ:V9/I[000VKB00UZdV[CI]=Ve6[C
J]9ZdfKCI]8016Jb00=V/FKAI]400VKA0VKB00=ZdV[AJ]801V[B0V[A00AZdV[AJ]9ZdP=Zd`QZdP9Z
d@9ZdP03J]=VdfKB00YVdP03I]=ZdfKB00AVdPUVd@UVdP=V/@AVd@9VdP9V/P05I]9VdFKAI[5R/@03
I[45H[400fJaI[9V/P03H[8016:aH[9R/V:a0fJa0V:a0V:`00AR/F:@HY1R/0AV/09R/@9R/P03H[5R
/6:`00=R[`9R/0AR/@9RT003HXmRSV:>00ERS`03GY1NTEj@00=NT09NT@03GY9NTEj@00ARS`03GXmN
T5j@00MNT003GXmNSUj>009NSP04GViNSUj>GXh4GVh01Ei]GViNKUi^FVh00ei^00AJKUi^GViNKPQJ
KP9JK@06FViJKeY^FVeJKUi^0eY>0eY<0eY=00AJC5Y/FVeFC@QJC@03FTiJCeY>00QFC003ETeFCUI>
009FCP9FC@9FC0=F:`03ERaF;EH/009F:`EF:P9F:`04DRaF:eH/ER`2ERd00e8/ER]B;002ER/00e8/
DPaB;003DR`01E8[CR]B:e8[DP/00e8[0U8;0U8:00=>2Th;CP/02Th;00=:34X;BP/00Th:00IB2Th;
CP]>2dgZCPX3CNX2BNX3BP/00dWZCNY=j@03BNT3BNX01DGZBPY5jTGZANT00TGZ00=5jDGXBNP00TWY
00=5jDGXANP00dGX24GY0DWY0DG80DFY000422400``Q344<@@03344@224010a234<<@`Q20PPQ00<<
8@PQ32400``P00d<@0a12444811Q8:<a946YETaJSEY]FRaJCP02ETh2ETl00eI@EU5JD007FTl5FU02
FTl2FTh2FVl6FTh015Y_FW1JL5Y`2EY@0ei`00ENKei`GW1NT5j?00=NT004GW1NKei_GVl9GW02GY05
GY43GY0CGY45HY43HY800f:aHY5NT@02GY49HY4016:@HY5RTV:A0f:a00=R/V:aH[401fJa0V:b00=R
/f:bH[800V:b1FJb0V:b00=V/VJaI[400VJa00EV/VJcI[9V/VKB00EVd`9V/P03I[5V/VJb00EV/P=V
dP08I[9V/6:@GTmRL6JaI]9Vd@9V/@9V/P03I[=VdfKC009Vd`04I[9V/fJcI]<3I]85I[83I]82J]42
J]82J]<2I]<4I]8;I]<00f[CJ]9Zd@06J]800f[CJ]9ZdP02J]800f[CI]=Vd`08J]<00fKCJ]=Zd`05
J]<6J]8016[CJ]9ZdV[A2V[B0V[b00=Zlf[CJ]8016[C16[B00AV/VKCJ]=Vd`9VdPEZdP08J]1Zl6K@
HZmNKUH<FP]RK@9VdP03I]=ZdfKD009Ve004J]=ZdV[BI]<2I]83I[8016KBI]5VdFKA0VKB00=Vdf[B
J]801f[B0V[A1V[B00=Zdf[BJ_<016[B00=ZdF[BJ]800V[A00AZdV[CI]=Vd`QVdP9ZdP03J]=ZdVKB
00AVdPMVd@03I]9VdFJb00QVdP=V/@AVd@03I]9V/VJb009VdP03I]5VdVJa009Vd@03I[5R/F:a00AR
/@03I[5V/VJb00=R/P03I[5R/FJb009R/PER/@03I[1R/F:a00=V/@=V/09R/@04H[9R/F:aH[45H[04
H[42HY42HY06HXl01Uj@GY5NT5jAGY1R/09NT0ANT@05GY1RSf:?HXmNS`09GY02GXl8GXh01Ei^GXiN
KUi^GXh00Ui^1Ei_0ei^1EY_15Y^00=JKEY^FVh01EY^0UY>0eY<0eY=00AFCEI^ETiFCP]JC@IFC09F
C@=FCPAFC@04ETaFCEI<ERd2ER`015H]ERaF:eH[1EHZ00AF;58/DReB;09F;003EReB;58/009F:`9F
;0EB;003CRa>:dh[00IB:`9B2`9B2P03CPY>2dh;00]>2`04DP]>2dh;CPX6CP/2BP/2BN/014WZBP]:
2dX;1DgY0TWY0TWZ0TX:00I:2dgZBNU9jTGZBNX3BNT2ANT01DGXANU5jDGYANP00TGY1DGZ00=5jDG8
ALP00DFY000422400``Q22488@0?22400`PP22488@0322400`PR22488@04224222000``P220<8@02
22002A11664e946YDRaJSEY=FRaJCP04ETh01UI@EU5FCeY=FTiJK`=JC`06FTiJCeY@FU1JL5Y@0UY?
15Y>0UY_15Y>00=JKeY`FU000UY@00EJL5i_GVmNKeY_00MNK`06GW1NKei_GXiNSej@0Ui`1Ei_2ei`
00INLEjBGY5NSej@GXl3GY02GY42GY000f:@GY5NT@09GY48HY4016:aHY1RT5jA1f:A00MRT6:AHY5R
T6:AH[9RT@03H[03H[400fJaH[5V/@04I[43H[82H[42I[82I[46I[82I[400fJ`I[5V/P03I[800fJa
I[9VdP04I]801FJbI]5V/VJaI[8016KB1FKA00MV/F:@GVmRL6:aI]1Vd@02I[4026:bH[5V/F:aI]9V
/VJaI[82I]<2I]800fKAI]9V/@03I[84I]801FKAJ]5ZdF[BJ]<00VKC0fKB00=ZdF[BJ]<00fKC00=V
dVKCJ]<00V[C00=Vdf[CJ]800V[A00=ZdV[AJ]8026[B0f[C0f[B36[C2V[B00=Zdf[BJ]<00f[C1V[B
0V[C0f[B0f[C0fKC00=ZdV[CJ]<00fKB015VdFKBJ]9ZdV[AJ/mZkfK@HZmNKUX]EPYRSFJbJ]AVe6[D
00AZd`04J]9ZdFKAI]42I]800fJbI]9VdP03I]400fKBJ]9VdP09J]800fKBI]5VdP02I]82J]4<J]80
0f[AI]9VdP07I]84J]42J]800f[AI]9VdP03I]8;I]47I]83I[44I]400fKBI[9V/P02I]83I]44I[45
H[42I[401FJbH[5R/F:aI[000VJa0V:b00=R/F:`H[400V:a0fJ`0V:a00=V/FJ`I[000fJ`1F:a00=R
[f:`H[000f:a00IRT5jAHY5RTF:aH[06HXl4GY0015jAHXmRSV:?0Uj@0UjA1Ej?15j@0Uj?0ej@1Ej?
25j>15i^1EY^00=NKUY^GVh01EY_0eY^00=JKEY/FV`00eY]00IJCUY^FTiJCUY^FVd6FTd00eI>FVmJ
CP07FTd3ET`00eY<ETaFC004ET`2ETd2ETh00eI=ETaFC003ET`015H]ERaF;5H]0eH/0UH[1EHZ00=B
;5H/DRd0158/00IF;58/DR]B;5H/DR`3DP`00e8/DR]>3002CR/5DR/00e8;CP]>2`02DPX00dh:CP]>
2`07CP/00dh:DPY>2P05CP/00dh:CP]>2`02CP/2BP`00dg/CN]9j`04BNX2CNT014gXBNU9jDWY0dWZ
00A5jTWZANY5jP99j@04ANY9jDWYBNT3ANT6ANP3BNT01TG9ALY5b4WWAJI9a`55Z@0000<48@PQ2240
4`PQ0PPP0PPQ0P`Q0PPQ00<88P@Q22401@PQ00d880PQ220<8A0P664e0T6WCR]JS5I;FRaJCP02ETh2
ETl2EU0015I?FTeJCUY>0eY?00=JCUY?FTl00eY@0UY?0UY@00EJCeY`FW1JL5Y@009JCP9JK`05FW1J
D5YaFVmJL002FVl3FW06GVl015i`GVmNKUi^0Ui_1Ei`00=NKUi_GW000Ui`00=NT5i`GY0015i`0eia
00ANTEj@GY1NS`QNT0iNT@MRT@04HY1R/F:aH[45HY400f:@HY5RT@02H[401V:BH[5R/FJaI[1RT0=R
/@03H[9R/F:a00=V/@=R/P03H[5V/FJa00AV/@=V/P06I[5V/VJaI[5V/6Ja16Jb00AV/FJbI]9Vd`9V
dP03H[9VdVKB00AVdP9Vd`03I]9VdFKB00AVdP07I[5RSei^GVmRT6:aHY400f:a00QR/6:aH[9R/VJb
I]9R/fKC1FKB16Jb0fKB00AVdFKBI]9VdP=Vd`=VdP03J]5ZdV[C00=Vd`9VdP04J]9Zdf[CI]<2J]<2
J]800f[AI]5ZdP06J]800f[CJ]9Zd`02J]<3J]801VKCI]9VdfKCJ]=ZdPEZd`=ZdPEZd`04J]9Zdf[c
J_<4J]<016KCJ]=ZdV[B0V[C00EZdV[CJ]=Zdf[B009Zd`03I]AVdfKC009Vd`03J]9VdVKB00EVd`9V
dP0=J]5Zd6[`I]1R[Ui]DNYF2F9]I[5VdVKCJ]@00f[C0V[B0V[A00AVdFKBI[9V/P9VdP03I]1VdFKA
009Vd@06I]9ZdV[CJ]9VdV[B0V[C00=VdfKBI]8016KB00EZdV[CJ]=ZdV[A00MZdP03J]5ZdV[B009V
dP9Vd`EVdP9Vd@05J]5ZdV[BJ]9Zd@02I]800fKCI]9VdP0;I]47I]87I]400fKBI[9V/P03I[801VKA
I[1V/FJaI[9V/@ER/@9V/@9R/@03I[5R/F:a009R/@=R/PIR/@06H[1R/F:aH[5V/6Ja0fJ`1F:a00=R
/6:aH[400V:a0UjA00IN/F:aGY5NTEjaH[03HY02HXl3GY001UjAGY1RSf:?HY1NS`=NT0=NS`04GY1N
Sej?GXl3GY0015j?GY1NT5j@1Ej?0Ui^0Uj>0ej?00ANSUi^GViNK`MJKP03FXmJKUY_00IJK`03FViJ
KEY/00AJK@9JCPAJKP03FVeJCEY=00=JCP9JC`03FTiJCEY=00AJC@AFC003FTaFC5I<00AFC003ETeF
CUI>009FCP9FC@=FC003EReF;5H]00=F;@03ERaF:e8[00=F:P03ER]B:e8/00aB;09B3004DRa>;4h/
CR`3CR/3CR`00dh[CPa>2`02CP/00dh:DPY>2`08CP/3CPX6CP/014X;CP]>2dX;0dX<00==jdW[BNX0
0dgZ0TgY0dWY00E5jDGZANY9jTGZ00A9jP03BNU:2TgY0099j@E5j@95j095i`=9j006ALQ5bTG9BNU5
YTW70DFY000F224322001PPQ324<8@`Q22488P888@848@<88@0322088@`Q008<800:668a0Cf6DR]N
Jei/FTaJCUI>FTl4ETl01EI>FTeJCUY>FTl01EY>00QFCeI@ETmJCUY?FU1JL5Y_0eY`00=JD5Y>FTh0
0UY_0eY`00=JKUY_FVl015Y_00ANKei^GViNKP9NK`03GW1NKei^00=NKP05GVmNL5i`GW1NK`02GVh0
15i_GW1NL5j@0Ui`00=NKei`GW000Uj@00=NTEiaGY000ej?00=NT5j?GY000UjA0ej@3UjA16:A00=N
TF:aH[400V:@00=R/6:@H[400V:a00=RTEj@HY000f:A0f:a0V:@00UV/6:`H[1R/F:`H[5V/F:AI[40
0VJ`0V:a00=R/V:aI[400VJa00AV/6JaI[5V/@9V/P9V/@=V/003I[5V/VJb009V/P06I[5VdVKAI]9V
dfKB0VKC0VKB0fKA0fKB16KA0VKB0VKA00MV/5j?FTmNKf:@HY5R/@02H[000f:aH[9R/P02H[400f:b
I]9Vd@03I]800fKAI]9V/@04I[800fJaI]5Vd@02I]800fKCI]9VdP03I]801V[AJ]9ZdVKBJ]=VdPAZ
dP04J]=Vdf[CJ]<2J]800f[AJ]9ZdP0:J]802VKBJ]9VdVKBI]=ZdfKBJ]=ZdV[A0V[b00=Zdf[BJ]<0
0f[B0f[C0V[B00=Zdf[cJ]800V[B1F[C00IZdF[BJ]=Zdf[BI]85J]82J]<01FKCJ]=Vlf[AI]400VKB
16KC0VKB00]ZdF[@J_1Vcf:]GVaAbEH:GVeV/FKB00=ZdP9VdP05J_9ZdV[AJ[1V/@02I]801FJaI]9V
/FK?I]000VKA00EZdF[BJ]9ZdV[A009ZlP03J]=VdfKC009VdPEZdP9Zd`05J]9ZdF[AJ]5VdP03J]84
J]400f[BI]9VdP03I]85I]42J]400fK@I]5Vd@02I]800fKCI]9VdP08I]4016K@I]5VdFKA16KB0fKA
00=V/FKAI]401FKA16Jb00EV/FJ`I[1VdFJb009V/@03I[1R/FJ`009V/006I[5R/FJaI[1R/F:`0V:a
16:b00=R/F:`H[001V:`00=R[f:`I[000VJ`00=R/F:@H[4016:a00=RT5jAH[000V:`00MN/6:`GY5R
/EjaH[5NT@02HY02HXl5GY001Uj?HXmRSUj=GXmN[`=NT003GZmNSej>009NSPaNS`04GViNKEj=GXd2
GXh3GVh00ei]GVmNKP06GVh00eY^GViJK`04FVl2FVh2FVd2FV`5FVd00eY/FV]JK@02FVh00eY<FTeJ
KP02FTh2FTl00eI=FTaJC@05FTd3ET`00eY<ETaFBP04ET`00eI=ETiFCP02ETh00eI=ETaF:`02ET/0
0eI<ERaF;@02ERd2ER`2ER/3ERX2ER/2DR/00e8/DR]B:`06DR`2DR/00e8;DR]B;003DR`3DR/014h/
DRaB358;0dh;00EB2dh:DPY>2U8:009>2PA>2`05BP]>2Th:CPU>2P02CP/4BP/01Th:CP]>2dW/BPa9
k099j`04BNY=jTgZCNX2CNT00dgXBNU9j@02ANT4BNT2ANT2BNP01TGYBNU9b4WXALQ9j0E5j095i`05
BNM9adW7ALM5j@02ALT1ALP1BLL1AJT000d88@032288@PQ20088@P0322888@PQ00H88@8<8@032488
8PPR00<88PD88@0<320800`P668a0Sf6DR]J:ei[FT]JCEI>0UY?00=JCEI>ETh00UY=0eI>0UY>00UJ
CeY>FTiFCeI@ETmJCUY?FU000UY`0UY@00AJLEY@FTiJCP9JK`9JD003FVmJKUY_00IJK`=NKP9NK`9N
L005GVmNKUi^GViNK`03GW04GVl01Uj@GW1JTEiaGW1NK`9NS`06GY5NT5jAGY5NT5j?15j@00=NTEj@
GY001Ej@1ejA00=RT5jAGY400UjA0V:A00ER/EjAG[5NTF:a00=RT0=R/@05HY1RTF:AHY5RT005H[43
HY0016:aH[1RT6:`0V:A0fJa0f:a00ER/V:aI[5V/FJb00AV/@05I[9R/VJbI[5V/006I[42I[8;I]80
16KAI]9VdVKB1VKA00]Vd6KBI]9VdVJbH[5V/6:@GW1RT6:`00IR/@03H[9RdF;B00IVdP=V/P9V/@9V
d@AVdP03I]=VdVKB00AVdP9Vd`=ZdP9VdP03I]=Zdf[C009ZdP04J]5ZdV[BI]84J]83J]400f[BI]9V
dP03I]82I]<2I]801V[BJ]5VdV[bJ]=VdPAZdP9Zd`9Zl`9Zd`AZdP07J]=VdfKCI]=VdV[bJ_<00V[C
0fKB16[B0V[C0fKC00=ZdV[AI]4016KB00=VdfKBI]800V[A00MZlFK@IZeNKEH:FP]NKP02I]800f[B
J]=Zd`02J_<01V[bJ]9VdVZaI[5Vd`9V/P03I[5VdFK@00=Vd@05J]5ZdV[BJ]9ZlP02I_800fKcI]=V
d`03I]82J]82J]<2I]<016[bJ]5ZdF[A1F[B16[A00AVdVKCI]9VdP=Vd@9VdP9Vd@04J]5Zd6KAI]43
I]8016KCI]9VdFKB2VKA0fKB00=V/VKAI]400VJa00AV/VKBI]9VdP=Vd@03I]9V/VJb009V/@04I]1V
dFJaI[82I[400fJ`H[5V/002I[05H[400fJ`H[5R/@05H[4:H[02I[000f:`H[5R/@03H[42H[000f:@
GY1R[`03G[000ej_G[1N/003G[001V:`HY1RSf:?GY1NT@ANT003GXmRSUj>009NSP03GXmNT5j@00EN
S`05GZmNSUj>GXiNS`02GY05GXl00ej>GXeNS@02GXd2GVd01Ei^GXiNSUi_GVh00UY^00ANKUi]GVeN
K@9NKP06FViNKUi^FViJKeY^0eY]1EY/0UY]00=JK5Y[FVd00UY^00=JK5Y]FTd00UY=0UY>00=JCEY<
FTd01UY=15I;00IJBeY<ETaFC5I;ETd3ETh00eH_ETiF;003ET`3ERd015H/EReF;5H/0UH[1EHZ0U8[
00=B;58[DR/00U8/00AB:eH[ERYF:PAB:`9B;003DR]B358;009B:`04CRaB;58<DP/7CP/2CPX00e8:
CPY>2`04CP/00dh:CPU>2P02CP/5BP/2CP/014X;BN]9jdW[0dWZ00==jDgZCNT00dgY00=B2DgYBNX0
1TWY0TWX0TWY00=9b4WXALP00TGY00=5jTGYANT00dGY00=9j4W7ALP014G90DG80DG70DG:000=2240
10PR348<@Pa20PPR2@PQ00H<8@PQ22888PPQ228422432202200021QQ;>8iIDG9BP]J:EX[FTd2FTh0
0eY=FT]JC@04FTd2ETh035Y=FTiJCeY>FTeJCUY?FTiJCEY>FVmJL0AJD004FW1JKeY=FVh3FVl2FVh5
FVl00ei_GViNK@02GVd00ei^GVmNK`02GVl3GVh7GVl01Uj>GY1NT5ZAGW5NT0=NS`08GY1NSejAGY9N
TF:?GY1RT0=NT0ANS`03HXmNSej?009NT0ANT@03GY1RSf:@00=RT@=NT@03H[1N/6:`00IR/0=RT003
H[5RT6:?00AR/09R/@03H[1V/F:`00=V/09R/003H[5V/F:a009R/@04H[1R/F:aI[42I[85I[400fKB
I[=V/@02I[000fK@I[5V/@03I[4026JbH[9R/VJbI]5VdVJaI[84I]8<I]402fKBI_9ZlVKBI]1R/5Y?
FTiNKV:@HZl00f:@00AR/6:aI[5R/PMVdP9V/P9V/@EVd@9VdP03I]5VdV[B009ZdP9VdP03I]=VdV[B
00=ZdP9Zd`07I]=ZdV[BJ]9ZdfKBI]<00VKB00=ZdV[AJ]400f[A0f[B16KB00MVdFKBI]5ZdF[BJ_9V
dP03J]801F[CJ]9VdV[BJ_800f[B0f[A00=ZdV[CJ]<00f[b00=ZlF[bJ_8016KB16[B00=ZdfKBI]<0
0VKC0V[B0V[A00=VdF[BJ]800VKB00iVdF[AI]1VdV;@HZeNJeX:GRYRSVKBI]1VdFKB0V[b1FKB00AV
dFKBI[=VdP9Vd@05I]1VdFKBI]9ZdP02J]<00f[bJ_5ZlP02J_800fKcI]9VdP03I]801V[BI]9VdfKC
J]=ZlP9Zd@IZdP9Zd@03J]1ZdF[B00=VdP04J]5VdFKAI]42I]8016[AJ]1Zd6K@0fKA0fKB1VKA00=V
d6KAI]4026KA0VJa00IV/VKBI]=VdfKBI]46I[43I[05I[401FJ`IZmV/6JaH[400VJa00AVdFJ`I[1V
/0=V[`04H[1V[f:`H[02I[000f:`I[1V/002I[000fJ_H[1R/002H[03H[400f:@HZmR[`06HZl2HZh0
15j_HZmR[f:_0V:^0f:?00INT5jAGY1NT5j?GZl3HZh00f:]HXeN[P02GXl00ej>GXmNS`02GXl01Ej^
HXeNS5j=GXh015j?00=NSUj?GXh00Uj>0Uj=15i/0Uj=00ENSUi]GVaNK5i]00=NK0=NK@04GTaNK5i[
FVd2FV`2FVd6FV`015i/GV]NJei/0UY]00YJJeY=FTiJC5Y:FT]JC5Y;FTYJC0AJC@9JC09JB`=JBP05
FT]JC5Y;FTYFC002ETh2EU000eI?ETiFC@03ETd2ERd02EH[ERaJ;5H[FR]F:UHYERYF:@03ERX2ER/2
DR/2DR`2DR/2DRX3ERX00e8[ER]B2`02DPX01EH[DPYB2dh/DR`00U8;00E>2dh:CP]B2dh;009>2P9B
2P9B2@04CPY>2dh;CR/2CPX00e89CPY>2`04CP/00dX;CPY=jP03CNX014WZCNU=jDgY0TgX00A=jE7X
CNU=j@U9j@E9j095j0E5b095b@95b095a`E5b095a`55Z@0000<48@PQ224030PQ00<8@PPR228030PQ
1PPR0PPQ0PPP00X<80P0200DHBSS=DI1bTh]FV]JC0=JCP03FTeJBUY<009JC@06ETaJCEY=FTeJC5Y>
0UY?0eY>00IJCEY<FVeJKUY_FTl3FU02FW02FVl00eY^FVmJK`02FVh4FVl2FTh015i^GVeNKEi^1ei_
00=NKUi_GVl00ei_0Ui^00=NSUj@GY000UZA00=NT5j?GY000ej@0UjA2Ej@00MNSf:?HXmRSf:>HXmN
T005GY401Ej@HY1NTF:AGY400eja00=N/5jaG[400eja0V:`0V:@00ARSf:@HY1R/@=RS`03I[1R/6:a
009R/@AR/004HXmRT6:aH[43H[0016:aH[1R/F:a0VJb00=V/FJ`I[000VJa00AV/V:bH[=V/P9V/003
I]5RdFJa00AV/P05H[9R/FJaI[1Vd@02I[8016KBI]=VdVKB1FKA00=RdFKBI]801FKA0VKB00AVlfKb
I]9V/@9R/@06H[1NKUY_HY1RSVJ_0V:`0f:a00=R/VKBI]400VKB00=VdfJbI]800fK@00MVdFKBI]9V
dVKAI]1Vd@05I]800fKcI]9ZlP03J]800f[CI]=Vd`03I]83I]<3I]801FKAJ]5ZdF[AJ]801FKB0fKA
0VKB00=ZdF[bJ_8016KB00=Vdf[CJ]<00V[B00=ZdF[BJ]800V[A00AVlV[bJ]9Zd`=ZlP04J_5VlVKc
I_<4I]83J]83J]<3I]<00fKBJ]5Zd@02J]4046KAI]9VdFKAJ]1Vd6KAH_5R[EY;EPYN:F:<I]1VdFKB
0VKc1fKB0fKC1FKA0VKB0VKC00EVlfKbI_9VlVKB009Vl`9VlPAVdP08I]=Zdf[CJ_9ZdFKAJ]5VdP=Z
dP03J]5Zd6[A009Zd@05J]9VlfKBI]9ZdP05I]8016KAJ]1ZcfK@0VKA16KB1FKA00=VdVKAI]401FKA
0fKB00=VdFJ`I[400VKB0VKC00=VdVKAH[800f:b00ARdVJaI[5V/09V/@=V/P03I[5R/F:`009R/004
H[5V/FJaI[43I[05IZl2I[02H[001f:aI[1V/FJ`H[1V[f:_00=R/006I[5R/F:aH[1R[f:^16:_00AR
/6:?HXmR[P9N/004H[1R[f:_HZh2HXl00ej?GY1NT002GY02GZl00ej?GZmR[@02HZh02Ej^GXmNSej>
GXmNT6:`GXmNSP02GXd00ej<GXiNSP03GXl015j>GXmNSej?0Uj>0Ui]1Ei/1Ei]0ei/0ei]0Ui/00=N
Jei/FV`00eY]15Y/00MJJeY/FV]NJeiZFV]JK002FT`01EY]FTaJBeY9FTX00UY;00EJBUY<FTeJCEY<
009JC@04FTaJBUY;FTX3FT/01UY:FTUJBEI;ETaFC@9FCP03ETeFC5I;00=FC@04EReFC5I:ER/2FR/2
ERX2ERT015HZERUF:EHZ0UH[00AB:e8/DRaB;09B:`9B:P9F:@05ERYB:e8;EP]F2P02EP/015HZDR]>
;4h<0U8;14h;0e8:0e8900YB2Th:CP]>2dX<CP]>2Th9DPY>2PE>2`03CPU=jTgY00E=j@03CNQAj4gX
009=j003BNU=jDW900==j0=9j@03BNQ5j4WX0099j003BNU5j4GY0095b004BLQ9adW9ALP2ALT00dG8
ALM5a`02ALL4ALP1ALL1ALH1AJT000@48@<88@0312488@PQ00@88@04324<8PPR228=224522800`PQ
2448@00422001a108<<aAT7[EVmNSEY<009JCP05FTeJBeY9ETYFB`03ET`015Y=FTaJJeY=0UY?00=N
CeY>FTd00UY:00EJBeY]FVeJKEY?00=JD003FW1JKeY>00QJKP9JCP05GViJKEi/FVeNK@02GVh5GVl3
GVh4GVd2GXh5GY002Uj?GY1NSej@GY5NLEi`GY1NSej@1Ej?00ANT6:?HXmRS`=RSP03HXmNT5jA009N
T@9NT0=RT00:H[5NTF:aGY5R/5j@GY5N/EjbG[43H[001F:@HZmRSf:aHY000V:?00QRSVJ_IZmR/6J`
HY1V/F:`0V:@0V:?00EV/6:`H[1R/6:_009R/006H[5V/FJaI[5V/6J_0VJ`00=V/F:aH[400V:a0fK@
00=VdFJaI[400VJa00QV/V:aI[5V/6K@I[1VdFJb0VJa00=VdVKAI]402VKA0VK@0VKA0VKB00eZlV/C
J_=VdF:`GVmNKUi]HXiRSF:?HZmRT002H[02H[400fJaI]9V/P02I]801FKAI]1V[fK?I]0016KA00IV
d6[@J]5ZdVKBI]43I]84J]89I]8016[BI]9VdV[B1F[A1fKA0VKB0f[a00=ZdFKBI]800VKB00=ZdVKB
J]401V[A00AZlF[`J]5ZdP9ZlP0:J]9ZlF[bJ_9VdV[bJ_=ZlV[BJ]44J]8016KBJ]=VdfKB0V[B00AZ
dF[@I]1Vd0=Vd@9Zd00;Ka9[4V:]FRUEj5hXIXUVcVK@J]9ZlP02I_<3I]800fKAI]9V/P03I]84I]40
0f[@J]5ZlP02J]8016KBI]5VdFKA0VKB0fKA00=VlFKbI]800fKB00]ZdVKBI]5VdF[@I]5ZdFKAJ]5Z
d6[?009Zd09Zd@9VdP03I]=VdVKB00AVdP05I]5Vd6[?J]1Vd002I]43I]87I]44I]02I]400fKBJ_9Z
d@02I[000fK@I]5VdP03I]801FKAH[9R/V:bI]800f:a00AV/6JaI[5V/P9V/@07I[1R/F:`H[1V[fJ`
I[400V:a0VJ`0fJ_16K@0fJ_00AR/6J`IZmV[`9V[P03HZiV[f:_00=V/003H[1R[f:_00=R[P07HZmR
[V:?HY1RSf:^HZl00f:`00=R[f:^HXl00f:?00UR[f:`G[1N[Uj?GY1NSf:]GXh00f:^0ej>00URSUj>
GXeNSEj<GX]NRUj<GXh00Ui^00=NSUj=GXh015j>0Ui]15i/00=NJei/GV`01Ui/00ANKEi/GVaNJ`9N
BP9NJ`9JJ`=JK09JJ`05FVYJJei[GVUNJ002FTX2FT`01EY;FTYJBEY8FTT00eY:00QJBeY<FTaJJUY<
FTiJC5YZ0UY[0eY;00=JBEXYFTP00UY900AFBUI;ET]FB`9FBP07ET]FCEH]ETaFBeY:ETX015XY15HY
00=F:5HYERX00UH[00=B2e8[DR/00U8[00=F:UHYERP00eHY00AF:UH:EPYF2`9F:P9B:`0<DP]B2U8:
DP]B2Th;CPYB2U88DPUF25H90U7Y00=AjTh:DPX00dh:0dh90Th:00=AjU8:CNX01DgY00=9jTgYCNP0
0TgW0dgX0dWY00Q=j4gWCNQ9jDgYBNU9j4GW14WX0TGX00A5b4G7ALM5a`E5b003ALM5aDG70095a`=5
Y`55YP59a@55Z@001@@Q00<88@@R12400P@Q00H88@@Q22488P`Q328622400`PR22488@0522452282
224324402`Q0244800`P6:8]ASg<DY5JS5Y;FRd00UY=00=JBeI:ET/015I;0eY;00mJCUY?FTiJCUi=
FT]JBEY8FTYJBeY]FVaJCUY@FVl00UY^00=JKEY/FV`01UY^0eY]00EJC5Y]FVeJC5Y]009NK@03GViN
Kej>009NKPENK004GVeNK5Z>GXh5GXl00ej>GXmNS`04GXh00ej?GXiNSP02GXh3GXl00ej@GXmRS`02
HXl2HXh015j>GXmNT5j@0ej?00=R/6:@HY0016:@00ARSej@GY5N/@9N/P04H[5R/6:@HY04HXl4HXh0
16:=HXiV[VJ_0VJ`16:?00EV[f:_HZmR/6:_00AR/003I[1VSfJ?00=V[`03I[1R/6:`009R/0=V[`9V
/005I]5V/FJaI[5R/@02I[000fK@I]5Vd004I[43I]09I]42I]05I]4026[bKcE_=F/DI]9V/6:_HXh3
HXd02ej>HXiRSf:`H[5VdV:aIZmV/6K@I]400VK@00=V[fJ`IZl00VJ`0VK@0V[@0VKA00=VdVKAI]40
0fKA00AVdVKAI]5Vd@]VdP9Vd@9Zd@IVd@9Vd09Vd@9Zl@03J]5VdFKA00EVdP9Zd@04J]1ZdF[AJ]43
J]02J]401f[BJ_9VlVKaI_9ZlV[c009ZdP=Zd@04J]9ZdFKAJ]44I]400fKBI]5Vd@02I]4016K@I]5V
dFKA0VK@00U[4FK`GX]J:578HTMZbFK>I]000VKA0VKB00=ZlfKBI]401fJa0fK@0V[@00EVdFKBI]9V
dFK@00YVd@=VdP9Vd@=Vd0=Vd@9Zd003J/mZd6[@009Vd@UVdP03I]5Vd6K?009Vc`9Vd0UVd@9Vd004
I/mV/6J`I]02I]400fJaIZmV[`03I[02I]43I[42H]43H[42I[0016K@I[1V/6:a16J`00=Vd6J`IZl0
0VJ_00=R/6J`I[000fJ_0fK@00MV[f:_HZmR[f:^HZmV[`02IZh016J_IZiV[f:^0V:_00EV[f:>HXiR
Sf:`00AR[`08HZiRSf:?HXmRSUj?HZmN/09NS`03HXiR[V:^00AR[P06GZmN[Uj_GY1NSej>0Uj?0Uj>
00ER[Uj>GXiRSEj=00ANS004GXYNK5i/GV`3GXd3GXh2GXd015i[GVaNJei/0Ui[00=NJUi[GVX01Ui[
00=NK5i[GV/00ei:0UiZ0UYZ0eY/0UY[0UYZ00=NJUiXGVL00UiY0eY:0UY800=JAeY8FTP00UY90eY;
00EJBUY<FTeJC5YY00=JBPAJB@03FTQJBEY800EJB@03ETUFBUI<009FC005ET]FBUI:FTUJB002FRP0
0eXWERQF:002ERP015HYERYF:UH:1E8Z0UHY0eHX15H800=F2EH8DPT00U890UH900AB2Dh:DPU>2P9B
2@03DPQF2588009Aj0AAj@04CPU>24h9CPP3CPT8CNT014WZBPY9jDgX1DgW00I=j4WXBNQ9j4gXBNP2
BNT5BNP00dGXANU5b00:ALP014G7ALE5aTG614FW0DG70DG50DFX0002128312421283124010PQ1248
8PPR10PQ00<880PQ22400PPR1PPQ1@PR1PPQ00d8@0Q1220<81B1:B@mZU9_FV]F:UH]ER]JC006ETX0
4eY:FTUJBUI:ETaJCeI=ERYJ:EY9FTQJAeY8FVUJJeY;FTeJKeY^00AJJ`04FVYJK5Y/FV`2FVh01EY]
FVaJC5Y<GT/00eY<00AJCEY/GVaNKP9NK@0:GVaNJei[GV]NBei:FTYJJei/FXd:GXd02ei[HX]RS6:;
GV]RRf:<GXeNKEi^HXh00Uj?00=RSf:@HXl00Uj>00=RSEj>GVh00Ui]0Uj>0V:^0V:>00ARSf:>HXmR
S`9NT007GY5N/EjaH[5RT6:?HXh00f:=00=RS69/HV`00V9/00ARRf:<IXaV[@9VSP06IZmVSV:>HXiR
SF:>0V:^0V:_00QR[V:>HXeRSV:=HXiV[VJ_0fJ^00=R[V:]HZl00V:^0VJ^1FJ_00=R[fJ_IZl02fJ_
00AV/6K@I]1Vc`QVd003I]5Vd6K@00AVd@0:I]1V[fJ_IZiRSV:=HX]RS5i[GV`2GVd015j>HXeR[6J]
0V[`00EVd6J_IZmV[fJ]00AV[P04J/iZcfK?I/l2I]03I[400fKAI]1V[`02I]04I]44I]82I]401fKB
I]5VdFJ_I]1V/6Ja00=Vd@06I]1VcVJ^I]1Zd6[?0V[@16KA0fKB00UVdFK@J/mZcf[@I]1VcfK@J]00
0VK@00=Zd6KAI]401FKA0f[A0VK@00=Zd6K?JZh00VJ_0VJ`00=Vd6[AI]000VK@0f[@0VK@00UVcVJ/
GZ]NIUXWFPMNAVJWI/`00fK?00AVd6J`I[1V/0UV[`0=I/iZcf[?J]1Vd6J`I]5Zd6[>I/iZcfK@J]40
0VKA0VK@0VK?0fK@00IZd6K@I/mZcfK?J]02I]001F[@I]1ZcfK@I/l00VK@0VKA00=VdVKAI]4016KA
0VK@00=VcfK>I/d00VK>00AVcfK@I]1V/09Vd0=V/@03I]1V[fJ^009V[P9V[`9RS`05IZmV[VJ_IZmV
[P04IZl01VJ`H[1R/6:`I[1R/09R[`=V[P=R[`07IZmR[f:^HZmR[V:=IZd00VJ_2F:_00AR[VJ^IZeV
[@=V[004IZeV[VJ^IXd3HXd00f:<HXeRS@02HZl4HZh4HXh2GXh2GXl00ej>HXiRS@04HZ`00f:[HZeR
[P02GXl00ej>HXeNK@02GXh00f:<HXeRS@02HX`00ej<GX]NR`02GXX2GVX2GV/00ej;GXaNJ`03GXd0
0f:]GX]NJ@02GVX01ei:GVYNBUi9GTQNAeiY009NJP03GX]NJUiY009NJ@ANJP0>GVUJAeY9FVUJBUYZ
FV]NS5Y[FTUNJ5iWGTMNAP9NI`04GTMNAUi7GTL4FTL3FTP02eiZFTUJBEY;FTeJBeI9ERYFBUHZERT0
0UXX00=F:EY8FTP01UY700YJB5Y9FTYFBeY<ETYJBUY9FRQJ9`=J9P9F9`9F:0=F:@03ERQF:EHX00=B
:@=F:005EPQF1eX6FPIF1`03EPH02EH7DPMF1eH6EPMB1dh8CPM>:005DPL2DNL4DNP00dgXCNM=i`03
CNL4CNP01DgYBNU=jDgXBNP00TWY0TWX0TWW00==idWWBNL00TWV00=9idW7BLL01TW700A9idWXBNQ5
b095a`=5b0I5a`04AJE5aDG5AJD2AJH014FWAJI5YDFT0D670002124712800`@122448P0212800`PR
22488@05224422832245228722402`Q0340<01RP9@<eQdH;ERYF2UHZER/015I:1EHZ0UI:00mFBeI=
ETaFBUXYFTQJBEY8ETUJBUI/FVeJKUY>FT`00UY:0eY900=FBUI;ET`00UI=00EFC5I;ET]FBeY:009J
B`9JC004FVeNK5i]FVd4GV`025Y<FTYJBUY;FVaJJeY]FV`2FVd00eY^FVeJK@02FVd015i/FV]NJei[
15iZ00=NJei/GV`00Ui/0Ui]0ei^00ENKEj>GXeNKEi/00=NK@ANSP07GXeNSUj=GXiNKUi_FVl00Uj@
00EJTEj@GXmNSf:?009RS@0?HVeRSF9]HVaRJf9/HV]VRfJ:IXaRS69]HViRSV9]009RS@03GVeRSF:>
00MRSP03HXmRSV:^00=RS@03GXeRSF:>00ARS@03IZiR[f:_00ER[`05HZiR[f:_HZmR[P06IZl016:_
IZmV[fJ^0VJ_00AR[fJ_IZmV[`UV/09V[`9V[P9R[P9RS09NJ`9JB`08GVeNSF:/HZiR[F:>HZmR/09V
[P=VS003IZeV[VJ^00=V[P9V[`04I[1V/FJaI[05IZl3I[02I[4016JbI[5V/VJa0V:a00AR/6J_HZmR
[`ER/0=Vc`05J/mVcfK>IZmVd003I[04I[42I[000fK@I/mV[P05I/l4I]000fKAI]1Vd@02I]03I[00
16J_IZiV[VJ]16J^16J_019V/6J_I[1V/6K@I/mVcVK;HXYNJ5X7EPQNJ6:YHZaV[FZ^IZh4IZl00f:>
IZmV[`06IZl3I/h01FK?I]1VdFKAI/l00f[>16K@00MV/6J^I/iV[VJ_I[1Vd002I[000fJ_J/mV[P02
IZl01fJ`I/mVcfK>I/mVcVK?009V[`03I[1R/FJa00AV/@06I[1V[f:_IZiVcVJ/0VJ]00=V[VJ_H[00
0fJ_0fJ`00YV[fJ^IZiV[VJ]HZiRSF:>HXmV[`9V[P9VS@03IXiV[VJ^009V[`ER[`9R[P04HZaV[F:]
HZh2HZl3HZh00f:_HZiR[P02HZh01F:]HZiR[V:_HZh00V:_0ej?0V:>2F:<00ARSF9/HXaRS09RS@04
HXiRSF:>HXd5GXh01Uj=GVeNKEi]FViJK@9NS@06GX]NS5j;GXaNRej<0ej=0Uj>00ENSej>GViNSF:=
009RJ`=NJ`04FV]JJUYYFVP2FVT01EYZFVUJJUiZGV/00ei/0Ui[00ENJUi:GTYNBUY:009NB003GTMN
JEiY009NJ@05GTQJAeY8FTQJB@03FTX4FTT01EY:FT]FBeY:FTT00UY80UY700AJAUi7GTMNA`=J9`04
FTMJAUY7FRL2FRP02EXYERYF:UY9ETYFBeI:ERUF:P02ETX015HYFRQF:E8Z0UI90UHX00=F9eXWFRL0
0UHW00=F:5HYDRX00UHZ00=F:EH8ERL00UXW0UH700EF9eH8CPQB2E8Y009B2P9B2@0:CPY>:Th:BPY>
2Th9DPQF25H7ENL4ENH015GUENIAiU7V0U7W00Q>1dh8BPM624X7BPQ>1e870TgW00=Aie7XDNP00TgX
0dgW0dgU0TgW14WX00=9jDWXANP00TGX0TGW0TWW00=9iTWWBLL00TW714W600=9adG7ALL01DG700=5
b4G7ALL024G70TG600A5aDFUAJE5YP95Y`03AJI5YDF40051Q@0000<8@@@Q12801P@R00@40P@11244
8@840P0510480@P120488@0212401@PR22488PPQ20400P@100<48PPR22800PPR00@88@P122488@@8
808@@0078<0ThCUT@LM:2EH8FTP00UHY00AFBUHYETYFB@9B:P04DP]B2U8[ERX3ETX03UHYFRQJAeY8
EPUB:UHZET]JK5I;FT]JBUHYERX3ERT01EHZER]F:eH]ER`00UH[0eHZ00=J:UY:FTX00UY:00=JBEY;
FT`00eY;0Ui;00UNBUY:FTUJBEY:FT]FBUY<FV`00eY<00EJK5Y<FTYJBUY900=NB@04GTQNBEi:FTX2
FTT015i:GV]NJei<0Ui/00UNC5i/GVaNK5i[GVaNSEi]FVd00ei]0Ui/00=NJei/FVd00UY=00=NKej?
FVl00UY_00YNKUi]GVaNK69]GVeNK5i]HV]RJP9VJ@05HVQRJV9[HVaRK@03HV`01ei;GTaNK5j=GV]N
SF:>009RS@=RSP04HXeNSEi[GV/2GX`00ej;GXaRR`02GV/2HXd016:>HXeRSV:>0ej>0V:>00ARSF:<
HXaRS@IRSP=RS@9R[@06HXiRSF:^IZmR[f:>0VJ_0f:_0VJ_0VJ^00QVSFJ^IZmR[F:/HX]RJEiZ0Ui:
00ANK5i;FTUJBP9NB`9NK09RK003HVYRJfJ<009VS0=V[@03IXaVSVJ>009VS`05HY1VSfJ>IXeVSP02
IZd01VJ^HZmV[f:`I[1V/@9R/@9R/006HZmR[V:/HXaRRf:=0V:?00IRT6:?HZiV[VK>IZh2IZd2IZh0
0fJ>IZmV[`03H[000fJaH[1V[P02IZh00fJ]IZiR[P02IZh00fJ]IZiV[P02IZh00fJ_I/mV[`04IZl0
1VJ^IZeV[6J;IXYVR`=VS006IZiV[fJ>IXiV[fJ>0fJ_019VcfK=I/YRREXWENUIjEiXHXURZfJ[IXaV
[VJ>IXeRSVJ>HXh3HXd016J>IZmV[fJ^0fJ]00=V[6J^IZh00VJ_00EV[VJ/IZeV[FJ_009V/008IZmV
[VJ/IZaVRfJ]IZiR[P9V[`05IZeVSFJ<IXaV[@03IZh2IZd036J/IZeV[FJ^IZmR[f:?HY1V/F:`I[1R
[`9R[P9V[003IXYVZfJ/009V[@04HXiRSF:>IXh2HXh02fJ>IZiVSF:=IXeV[FJ=HXaRSFJ_HXh00VJ<
00=VJf:<HX`00V:<0V:=00mRSV:=HXiRSV:=HXaRRf:8HXYRRf:<HXiNSUj<GXd016:<00MNS6:<HXeN
SEj<HXeRSP05GXh01F:=HVaRJf9[HX`00f9[0V:<00ARJf:;HX]RS09RJ`03HXaRJf9[009NK0ENK@06
GVaNJeY:FTaJCEY<0Ui/0Ui[00aNRei[GVYNJeiZGV]NK5i]GViJKei^GVd2GV/00eiZHVUNJP02GVX0
15Y:FTUJB5HX0UY800IFBEY9FTQNAeiYGVX4GT/01EY:FTUJBEY:FTT01UY800=NB5Y8ERP00UHX00=J
:EXZERX00UY:00EJBEYYFTUJBUY;009F:P03ERUF:5HX009F:09J9`0>FRIJ9eXXEPQF1eXWFRIF9eH8
ERUF:UH:EP]B2`9F:P03ERUF:UHY00AF:@9F:004ERUB:E8YERP2EPP4EPL00e88EPQF2@02EPT2EPP3
EPL01U87DNIAie7WDPQAj0A=j@07CPU>24h9CPU:2E88CPP0157W00=EiU7VDND0157U157V00E>1dX7
BPM>1TX700A=iP==i`06CNQ=b4W7CLI9aTW50Tg50TW600=9adWWBLL00dW70TG80TG700=5aTG5BLD0
1DW600I5YDVTBJE9YDFUAJH4AJL2ALL4ALH00dFV@JE1YP02@JH01dFV@JE1YD6UAJA5YDFT00E5Y@51
P`55P`0000@48@A102848PX48@0310488@P100880@0622448@PQ22448@PQ1`@Q00<88@@120400`P1
0PP00PPP00P<8110684P`c56@L]>35I<0e8<00A>358/DRaB;09>3@9B3006DPeB;58]DRaB3E8<0eH[
00EF;58/EReF;EH^00=F;@0:ERaB35H/ERaF:eH/EReB;UH_DRl2DRh00e8/DPaF;005ERd02eH/EReF
;EH^FRiJCeX^FReJ;5X]FR`00UH/00=F;UH]ERh00eH^00=FCeH^DRh015H]00IJ;5X]FRaJ;5X]ERh3
FTh2FTd2FTh00eX^FTiJC`05FTh2FTl00eY@FTmJD003FTh00eY_FU1JD002FW0015Y@EU1JD5Y@0UY?
0ei?00EJCei?GTmNCV9>009RC@06HTaRCF9=GReNCV9>0Ui>0Ui?00ANKeY_GVmNK`INL003GVmJKei_
009JCP03FVmNKei`009NL004GVmNKUi_HW07GW000ei_GW1NL002GVl5GW000f9`HVmNT003GW001f:@
GY1NT6:@HY5RLF9`00IRT@03IY1VTF:@00=RT003HXmRT69_00ANCP=JCP07FTeJ;UY>GTmNCUi=GTh0
0f9_00ERL6:@HVmRKfI_009VL0IRL0=RT003HY5NT6:A009RT@9RTP03GY9NTEjA009NT@=RT005GY1R
LF9aHW5RT@02H[42I[400f:AHY1RT002HY07HY44HY000f:AGY1RT@02HY000f:AHY1RT@04H[44HY42
HY0016J?IViVKVI_0VJ@0V:@00ERTF9`HY5RTF:@009RT@0<H[5V/FJaHXiNC5X:EL]EjeY=GXiNSf:?
0VJ@00IVL69`HW1RL5i`GVl2HVl2HW0016:AHY1RT6:@0VJ@16:A00EVTFJ@I[1VT6Ja00=RT@04GW1R
SfJ@HXl3HY0016:AHW5RKfJ?0VI_00AVT6:@HY5RT@ERT09RT@04GY5RLF9aHW43HY401f:@GY1RSf:?
HXiRSf9_009RL007GW1RL69`HVmRL6:AHW400f9_00MRL69_HVmRKei`HW5RL002HVl3HVh2GVh00ei_
HVmRL003GW02GVl015i^GVeRKei^0Ui`00IJL5i_GW1NKUi`GVl3GW001Ei_FW1NL5i`GVl00Ui`00=J
L5i`FTl00Ui_0Ui^00ANCUi?GVmNK`9NKP03GTiNKUi>009NKP03GTmNKUi_009NCP03FTiJCeY?009J
CP04GTmJCUY>FTh3FTl2FVl015Y>FViJCUY=1EY>0UY?00AJD5Y?FTmJCP9JC@03GTeN;EY=009J;@03
FRaF;5H[009FC005EReF;5X/FTaNC@02FRd01EY=ERiF;UY>ERd00UH/00EF;UH/ERaF;5I<00AF;004
ER]F;5H/ER`2EP`00eH]ERiFC002ER`2ERh01E8/EReF;58/CR`00U8/0UH;00=J2UXZEP/00eH;00AF
:UH[ER]B30=Ak003DPeB358<00=B300=DRaB34h<DPaF;58;DPa>34X=CPa=k57[EN/00U7[00E>2dX<
CP]B357/00=Aj`08EN]F2e7ZCN]=jTWZCN]9j`==j`99j`03CN]9jdW[0099j`05CN]9jTgZDNY=jP02
CLX00dgZCLU=b@03CLT00dW9CLU=b@02CLX5BNX014W:BLU9bTW:0dW;0TW:00=9bDVYBJP00TVX00A5
bDG:ALY5bP95ZP06ALY5ZDFZAJY1ZDFZ0dG914FY1DF80dFY0T6Z00=5ZTG:AJT00d6Y00E1ZT6Y@HTm
R46900<mR@03@HQ1Z46800I1R051Q@51P`51Q000\
\>"], "Graphics",
  Evaluatable->False,
  ImageSize->{756, 504},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000;d0001n1000`40O003h00O00=gVGNJMi/00WNK
00AcVgNKMi]gV`EcW0AgV`03MiagVgNL01MgV`=g^`]g_0=k_003Mkak_7^l00ik_0Uk_BMkg@IkgPAo
gAMogRAoo_mooaaoo`EooPaooaUooP03OomooWon00iooP9ogP9og@9kg@0>Nmak^g^kNk]g^gNKLgYc
VV]HHaE:42D<36D48P888@0312488@PP00P480032208@0@P00h48009020000@0120880Q0244<H@Q1
008<H@033448@@Q10088@@03344<HPaQ00P<H@@8@@04340<H@aQ3643244924001@a0364<H@a12440
0`a10Pa00`aP00D<H@aP364<H@aR008<H@8<HP03364<@@Q100<8@@8<H@88@@052248@@Q1244<H002
364324401Pa0360@P@aQ360<@0P8@007340<@@a0240<@0aQ34000`Q10`Q00Pa00PQ100<48@PP2440
0PQ100<<H@aR36400PQ11@Q00`@P2PQ00P@P00@880Q02448@0848088@0042448@0Q0240224442401
220000EgVP03Mi]gVWNK00EgV`05MiagVgNKMiYgV`03Mi`017NKMiYgVWNJ4WNK00=gW7NKNk/01g^k
1G^l0g^k0W^l00=k^g^lNk`03G^l0W^m0g^l1g^m0W^n1g_M0WoM00AkgG^lNkak_0AkgAYog@9ogP=o
g@EogPAog@UogPEooPAogP9ooP=ogQQoo_moobUoo`=ooP9oobAooP=og@9ogPAog@0ANmak_7^kNk]k
_7NLMi]_FF/iG]E9l23;58H<8@`P3248@@02220812000`PP1204800612000`PP1208800412020203
120224400`QQ344<H@0236423683344236400`b2468<HP0736422442240010aQ360<@@Q10PQ000<8
80Q024000Pa00PQ000<<H0aQ26000PQ11@aQ00D@H@aQ360<H0aQ008<@003360<H@aR00@<H@06344<
@0Q02408@@aQ0PaR0PaQ00H<@@Q12448@@aQ264236400`aR364<H@0236401@b2364<H0Q0244010Q0
0PQ10`a100@<@0Q0240<@0D8@@03240<H0aP008<H@@8@@04268<HPQQ244C24001@Q11448@0PP1200
10Q10PQ000@8@@Q02408@0<8@@88@04<@04880001GNJ00AgVgNJMiYgVP=gV`03MiagVgNJ009gVP05
Mi]gW7NLMiagV`04MiXAMi/01WNLMi]gVgNjNk]k^PAk^`Ek_0=k^`03Nkak^g^l00mk_09k_@=k_0Mk
_@9k_P03Nmek_G^m009kg@9og@9og09k_09kg@05OmekgG_MNmekg00JOmd2Omh3Omd4Omh4Omd:Omh3
Ooh5Omh2Ooh3OmhHOokoOol[OolOOoh2Ood6Ooh8Omd2Nm`017^lNk]k^g^l0WNL00IkW7=kJaQ1/11V
00023204220L120010PP240<@0a00Pa10PaQ0Pa100L<H@aR368<@121360<H@024645364010aP2208
80a11@a00`Q000<880Q024000PQ000`<@120364<@0Q02448@0aP340<H121460434001@Q0220<80a0
36000Pa000P@H0a0324880`P2408@@a10PaQ00<@PQ1R34400PQ10`Q00`a00PQ00PaP00@<H@aP3408
@0D8@@848088@@03220480Q0008<@0032448@0Q10088@003340<H0aP008<@004244<@@a034423643
244C240212022403244624000`PP1204800222011201220122000003Li]gVgNK00QgV`9gW004Mi]g
VWNJMiX2Mi/2Mi`3Mi/00gNJMi]gV`09Mi/2Mi`5Mi/2Mi`00gNlNk]k^`05Nk/5Nk`00g^kNkak_008
Nk`00g^mNkak_007Nk`6Nkd5Nmd00g^mNkik_P06Nkd>Nmd<Omd00goNOmeog@08Omd:Omh4Omd?Omh0
0gonOmiogP05Omh5Ooh00goNOoiooP06Ooh7Ool00gonOomoo`3oOol^Ool;Ooh00gooOoiooP0FOoh0
0gomOmeog@04Omd3Nmd2Nkd03G^lMiagVgNKOiYgNfKF>Fh40P00420<80`Q00<880<48003124480@P
00@48003220480@P00h48003220<80`P00<<@003344<H@QQ008<HP0@364<HPaR364@HA10220<@A1Q
468<PQ22368<H@a0320236400`aP340@H@0234000`a13408@@0324401@a1340<@0aP34000PPP0Pa0
00<@H0a034000PaP00<<@0PP24000Pa000T880`P340<@11Q440@H0a022000Pa00`Q00PaQ00H@P@aP
220880Q1240234002`aP364<H0Q01208@0a12448@0Q136400PQ100@<@@aQ2648H0H8@@88@003244<
@0aQ00@<H@@<H08<@003360<H@a100D8@0052448@0Q02448@003244324022444240010Q12648@@A1
0`Q100<8@0Q124000PQ000<88@@Q120010@P0@PP0@@P00000g>LMi]gW00:Mi`01GNKMiYgVWNJMi/0
0gNL1GNK0gNL1gNK00=g_7NLMi/00gNK0W^K00=kW7NlNk/037^k2W^l00=k_G^lNk`02G^l0g^m0W_M
00=kg7^mNkd00W^m0W^n17_M0g^m1W_M4GoM0goN2WoM6GoN0Won0goN0Won0WoN37onogoo?Goo2gon
00=oogonOoh00Won0Woo4Won0gom17oM0g_M00ik_G^lNkagVgNJMgQoVG=JH[Da;001100@80`P10PP
0`@P00<48@@P12000P@02@@P00<400@P120010@P00H400@P220880a044033402344010QQ368DXa22
0`aQ00L@@0a1220880a0364@PP0336401Pa0320<@@aQ460<@0L<@@88@@@<@003220400PP00<8@08<
@003240<@0a000<<80D<@003440<@0a000888003224880PP008<@004364DXQB13402220224023400
2PaP364@H@aQ3608@@@Q2248@@aR0PaQ00/<@@a0364<H@aP2408@@aQ2448@0PP0088@004340<H0aP
3602364010a0360<H1200Pa000<880a024401PQ000@8@@`P2408@0@8@@052408@@Q1120880022400
0`@P2408@00324001@A12448@@Q024400`Q00PQ100H880@P100000@P220122400003LiagW7NL00Ig
W004MiegW7NLMi`3Mi/00gNJMi]gW002Mi`5Mi/3Mi`6Mi/3Mi`4Mi/2Ni/00g^LMkak^`06Nk/3Nk`0
0g^kNkak^`0:Nk`00g^mNkak_009Nk`2Nkd5Nmd3Nkd2Nkh5Nmd3Nkd5NmdAOmd3Omh9Omd5Omh3OmdB
Omh00gonOmiogP02Omh2Ooh2Omh00goOOomooP0:OokoOollOol?Ooh3Ool6Ooh2Ool9Ooh4Ood5Omd0
17_LNmek_7^l0W^k00UgVWMGMgUcFEYC8:P00@@0440010PP4P@P0P@01`@P0PPP0Q1000<LY11R3440
0PaR00<480aR48<00a1Q00HDPaRS440@@0`P2202364010a1220<@0aP1`aQ00<<H0a0220010a100@<
HQ1R364<@08880D8@0053408@0a0340@H00334002@aQ360<H0aQ340880a0344<@00434402@aQ488D
XaB1340<@@Q13448@00234000`aQ488<H@03364234401@QR38<<PPaQ34400PQ000L<PPaP340480Q1
3448@00322000`a1468<@@0224001`a02448@@aQ460<80a000T8@007220<80a0364@PPaR34800`a1
0`Q10PQ000T8H0aP3408@0@P2404@@Q114400PQ000<88@Q124400PQ10PQ00PPP0@@P0@PP0@@Q0000
0g>LMiagW002Mi`01GNMLiagW7NLMid00WNL17NK00AgVWNKMiagW0IgV`=gW0egV`9kV`03Nkag_7^k
00Ik^`=k_0=k^`=k_003Nk]k_7^l00Ak_003Nkek_7^l00Yk_004NkekgG_LNmd=Nkd8Nmd4Omd00g_M
Omeog@0FOmd4Omh3Omd2Omh2Omd>Omh00gonOmiogP02Omh2Ooh2Omh00goOOomooP0;OokoOoljOolI
Ooh2Ool9Ooh017omOmeooGom17oM00=og7_LNk/00W^k00]k^W^JMgQgEgMhKcMB<Ab50004011000D8
8084808880D48003220480@P00D480H400<48088800:440<@0a0340<HAB24888H@@P364346033402
44002`aQ3448@0Q12248811P464DXQBS46400`a00Q1P00<<H@a134000`a100@@PQ1Q340880<<@088
@006320<@0a0344<H@a00Q100Pa000H<H1B158<<HPa03603364030a032040000340@PAB0340<80a1
2448@08<@006364<HQ22360<H@aP0Pa100d8@PaR6:@<H@a02408@@b23608@0@P2208@00234033640
0`a1244<@@0224000`@P2448H@03240236022402220224001`a0360<H122588@PPa10088@@03344<
H@aQ0088@@<8@0064808@0Q02208@0A10PQ10PQ000@88@Q12448@@@8@003220480PP0048@@0000=c
W7NLMi`02GNL17NK00=gVWNKMi/00gNK00=gVWNKMi/02WNK00=gW7NKMi/01GNK0gNl00AgVgNlNiak
W0=k^`Ek_003Nk]k_7^l00Qk_003Nkek_7^m00=k_004Nkek_7^lNk`3Nkd00g^lNkek_@0>Nkd<Nmd8
Omd3Omh3Omd3Omh;Omd00goNOmeog@03Omd>Omh7Ooh5Omh00gooOoiooP09OokoOollOol5Ooh3Ool@
Ooh2Ool:Ooh00gomOoiogP02Omh3Omd00g_LNkak_002Nk/02W^KMgUgEg^HJ_I5ca14000400`P20PP
00<48@@P12001`@P00<48@@P120010@P10@00P@P0PPP00<<H0aQ34400PaQ0Q220`aQ00T<H0a0220<
@0aP364@HA1056400a220Q1R0Q1Q0Q2200X<H@a0320<811P584DPPaQ340<808<H@<<@@08240<@0a0
464<@@a0320<@08<@@04364@HA1046023400211P584Ha0aQ220<HA23488236802@aQ220400@0344<
H@Q01008800236400`a0364<H@0236401A22364<H@a124400Pa10`aQ01D8@0aQ4:<@PPaQ344<80a0
364@PQ2S488<H@a1244<@0Q1240880@P24400PQQ0PQ00PQQ10Q000L<@0QQ364<HA2248<<H@042203
24401`@P2208@0Q03408@0PP0088@0032448@0Q0008480032208@0Q000H8@0<8@@0000=cW7NLMi`0
1WNL3gNK0WNJ17^K0WNK00AgW7NKMi]gW0IgV`Ek^`03Mkak_7^L00=k^`=k_003Niak_7^k009k^a9k
_0=k_@Ek_003Nkek_7^m00Ek_@Ekg@03OmekgG_M00Ekg@Uog@EogP=og@=ogP9og@9ogPeog@=ogP03
OmeogWoN00QogPQooP9ogPeoo_moocioo`AooP=ooaaooP03OoeooWon009ogP9og@9kg@=k_00;Nk]k
VWMiNgQkMfJd?Hd40@00100<800422000`@P2208@002220512051002000212000`PP120400031002
12001@PP340<@0aP36400Q1Q00D@PPaQ360<@0aQ008<@00;320@HA1P364<@110564L`aRR5:8HX`03
46400`aP3408@00234000a10580DP@0246401`a0220<80a13408@0Q100<<@009344<@0PP320<@@Q1
364@PQ1Q008@H08<@006460DXABR360400aQ0QS40Q1R0QB300<<HPQ124400Pa10PPP0Pa000d8@0PP
1208@0aP488<HPaQ344880@0344<H00436402Q225:8<H@aQ220<@@aP5:4@PA1P0PQ000D<@0Q02408
@0a00088@006264@P`aQ2408@@QQ10Q000T8@@Q0240<@0aP368<@@PP12000PQ000D8@@Q0220480PP
00/8@0032208@0Q000<8@0D<@04<@@48@@0000=cW7NLMi`01GNL2gNK00=g^gNKMi/00WNK0WNJ17^K
00=gVgNLMi/00gNL1gNK17^k0WNl00Ak_7^kNk]k^`Mk_003Nk]k_7^l00Qk_003Nkek_7^l00Ek_0Ek
_@05NkakgG^lNkek_004Nkd00gnmNkekg@02Nmd00g^mOmeog@07Nmd9Omd7Omh017oMOmiogWoN0goM
00=ogWoMOmd02goM0goN00=ogGoNOmh027oN00=ooWoNOoh01Gon0WoN37onogoo@7oo00AooWooOomo
oaiooP0COoeooWoNOmiogGoNOmekgG^mNkak^g^lNkYkVGMHOiUgMfJd<B/00P0000<88@Q124400`PP
0P@P0PPP00<800@P12000`@P10@020@P0P@00`@P00<880Q034000Pa000D<H0aQ368<H@a000@<H@0;
340@HA1Q468HPaR2588HPQRT5:<DPP02464010aQ3448@@a10P`P00@@@1RQ464<H0D<@@03368<H@aQ
00<<@@04340<80a0344236407`a1364<HAB1460<8110460@PA22360880Q04:<Ha1BS468DY1cV5<D<
H@a1220480PP340@H@a0120400a0008<H0<<H@8<@@H<H@8<HP8<H@8<@@05340<HA1Q360<@0022200
2@Q0360@PA223648@@Q0264<X`0238802`QQ2448@0Q1364<P`aQ340480PP36000PaQ00<880Q13440
0PQ100<8@0PP22000P@P20Q000<8@@@P220010Q010a000<<H0aQ34000@Q100000g>LMiagW006Mi`?
Mi/4Ni/017^JNi]gVgNL37NK0g^k0WNl00Ik_7^kNk]k^g^lMk`5Nk`3Nk/8Nk`00g^mNkak_@05Nk`5
Nkd3Ok`00g^lNmek_@02Nkd3Okd2Nkd00g_MNkeo_@06Omd00g^lNmeog@08Omd7Omh017oMOmiogWoN
4GoM0goN0WoM2GoN00=ooWoNOmh017oN17on0WoN2GonogooA7oo77on00AogWonOoeooP=og@04Omik
gGoMNk`3Nk/01g^INgQkNGnIMeMNLRSY008000053248@@a12244800310000`@P1004000612021009
1204100010@P220<@0aP1@a000H880a0460@PPaP340246000aB26:<LX`0268<258<021AS588@HQ1Q
220400PQ2202320010a0360@HA1Q0PaQ00T<HPa1344<@@Q1360<@0aQ34400Pa000<<H12246800Pa1
0PaQ0Q1P00X<80a0460<H0Q0100880aQ468@H@8<H@04368<H@a136433402360021B1360<@0a0360<
HA1Q364434000`a1460@P@0236400`Q0364<HP023642344010aP364<H0a010Q000`@H1BR488<H0a1
340<H@b2360880@P244224000`aQ388<H00334000`aP364<H@02344010aQ464<H0a00PPP00<400PP
24000`Q000P880Q02408@0Q1120880a010Q00`a00`aP0@a100000g>LMiagW009Mi`2Mi/00gNLMkag
W005Mi`5Mi/2Ni/017^LMi]g_7NK0gNL00AgVgNLMiagW0=gV`Ak^`=g_0=k^`ik_004Nkek_7^lNk`3
Nkd5Nk`5Nkd3Ok`2Nkd00g_MNkekg@02Okd3Nkd00g_MNkeog@03Omd2Nmd2Nk`3Nmd7Omd3Omh00goM
OmiogP05Omh?Omd00goNOmeogP02Omh00goMOmiogP08Omh00gonOmiogP0;Omh6OokoOom8Ool3Ooh0
17ooOoiooWon17oo4Gon00=ooGonOmd00WoM00=ogW_MNmd00W^l00Uk^g^JNiUkN7nHNiUc=TX@7:L0
0P000`PQ00<880PQ224010PP1P@P0P@02@@P1@@000H480PP320@H11Q46024402344336400`a0220@
H00246424680111Q564DPQRS0QAR00<@P`aQ22000PPP00<@@@a046000Pa000<<H11Q48<00PaR00D<
H@a12208@0a000@<@@0A340<H1BT6:@<H@PP344<H@QQ360<80a0464HXQ1P2208@00246001A1Q3648
@0Q034000PPP00<<@1BR4:<00PaQ00<@P@aQ36400PaP10aQ00<<@11032000Q1P00T@P0aP240480Q0
264<HPQQ244010aQ00D8@@Q0220880Q000<<H0093408@@a0360<PPaP240880@P0088@003364<PPaQ
008<@003364@PQ22008<HP05468<HPaQ344<@003220010a0364<H@aQ0PQ100@8@0Q12408@@888003
2408@@Q00088@006220<@0aQ364<H11P0@a100000g>LMiagW00<Mi`00gNlMiagW006Mi`6Ni`017^K
Mkak^gNl0WNL00AgVgNLMiag_0mk^`ak_003Nkek_7^l00Uk_0=k_@03Nkao_7nl009o_003NkekgG_M
009k_@03Okek_G^m009k_@9kg@Aog@Mkg@eog@=ogP]og@03OmiogGoN00AogPAog@]ogP03OoiogWoN
00AogPUooP04OmiooWonOokoOom<Ool3Ooh7Ool<Ooh3Ood00gonOmeog@02Omd04g_MNkek_7^lNk]k
^G^HNgMoUWMiKaE1[Q14000400PQ120880PQ00L880D480031000000000P480D40003120880PP008<
@005360@@110460@@00334401@@P340@H11P34000P@000P<@1AQ584HXQAQ584DXa1Q0`a100@<@110
460@H0<@H@04340@HA1R360222001@a1340880PP34000PPP00@<@0aQ368<@@88@088@@0;240<@0aP
484DPQ1Q364<@11P440@H00336401PQ0220880aP5:4DXP8<H@05344<H@aP360@H00234001@aQ360@
H11P44000Q1P00TDXA1P360<H0a02408@@QQ34400PaQ00@<PPQR2648@084800;240<@0Q0220400PP
340<H0b1360<@002240030PP2408@0Q1240<@0aP488DXa233688@@8<@@04244880PP220224001PaP
488<H0Q0244<@@@8@@<8@00:2448@0Q0240880a1368@P@aP460134000003LiegWGNL00agW003Mkag
W7NL00IgW003NiagW7^L00=kW09kV`05Nk]g_7NLMiagV`04Mi`00gNlNk]k^`09Nk/00g^lNk]k_00;
Nk`00g^mNkak_003Nk`3Nkd3Nk`3Nkd017^lOkao_7nl17_M00Ak_G_MOkeo_@=k_@03NmekgW_N00=o
g@04NkekgG_MNkd3Nmd?Omd00goNOmeog@05Omd;Omh5OmdBOmh<OokoOom<Ool3Ooh7Ool01gonOomo
ogooOoioogon009oo`MooP9ogP9og@9kg@9k_00<Nk]k^W^IMgMkMgMiKaHmS0PS000400PQ2`PP00@4
80PP220880D48@H48003220400@000840003200880PP00<<@009360@H11Q468@@111344<@0aP008@
H0063408011P464@H1AQ0QR200<DHA1Q46800Pa10PaQ00X@HA1P460@HA1R464@@111340<H08<H@03
368@PP`P008400032408@@Q000@8@@88@003340<H@aQ00<<H@06368<@@PP464@@11Q1PaQ00D@HAB1
488<H@a0008<@@05120<@11P440@H00236401`aP460@H11P5:8DPA1Q008<H@0C360<H@aQ268<HPaQ
2648HPAR2448H@Q1240<H11P340800@022000Pa000<<H@aP34000`Q000X880Q02448@@Q0360@X`b2
3688H@<8@@032248@0Q000<8@003340<H0a00088@0D8@@042248@@aQ2643240010PP340<HA1Q0Q1P
0@a000000g>LMiagW003Mi`00gNKMiagW00AMi`3Ni`4Ni/01GNKNk]k^g^kMk`00gNL00=g_7^kNk/0
2g^k00=k_7^kNk`02G^l00=k_G^lNk`00g^l0g^m1g^l17nl0W^m0W_M00=k_GnmOkd00g^m0g_M00Ao
gG_MNkek_@IkgAMog@03OmiogGoN00IogPQogA1ogPioo_moodUoo`eooP=oo`03Ooioogon009oo`=o
oP9oo@05OmeogWoNOmiog@03Nmd03G^lNk]k^W^INiQgMW]hLeQ^mCU;228000@000`88005120880PP
22048@0312000`Q11204800412000`PP10048002120222053400211P464@HA11464@HPaP34024600
1A1Q584L`Qc358400QAQ00DDHQ1R468<@Pa0008<H@03360@H11Q00@@H@0<444<@0a0340<HA236<DD
XPPP100880Q00PQ110@P00H8@@a0360@H121364334402@`Q344<@0a0220<@A1Q588@PP0336402121
3688@@Q0340<H@a1220244002A1P364<H@aP460<H11Q488<H00534001`aP3648@@Q1264<HPQQ0088
@@06340@HABR460<@0`P10a01`Q00PPP00T480`P360@PPaQ2444@0Q124000`PP0PQ010a00PQ000L8
80Q0120480PP22448@0224000`QQ2408@003240010Q1360<H0a00@`P00000g>LMiagV`0GMi`3Mi/0
1G^LNi]gVg^KMk`00g^k00Eg_7NLMiagW7Nl00=k^`03Nkag_7^l00Ak_0=k^`ak_003Nkek_7^l00=k
_0=k_@Ek_0Qk_@=kg@04NkekgG^mNkd>Nmd?Omd2Omh00goMOmiogP02Omh00goMOmiogP07Omh3OmdD
Omh2Ooh01GooOmmoggoOOol01GonogooC7oo37on17oo00=ooWooOoh00goo17on17oN00EogG_MNmek
gG^l009k^`0;NiYgVWMhNgUcFF:C<@T80P0010088@0:220222400`Q122048003124<120010PQ2208
80PP0`a00PaQ0Q1Q010@HQc5468880a0560@H1AP8><Ti1RS568<8110464@HP<<HP<<H@8@H@04468@
H@aQ364246400a11340<H@0236823642344010a0344<@0PP0P@P00<8@0aQ360010aQ00@<@@a0320<
@08DP`05468<HQ1R488<HP0236401PaR388<P@aR3648@0<<H@05340@H0`P460<P@023642360010aQ
368<H0PP0Pa000D@H@aQ360<@0a10088@@08264<H@Q1220<@0aP488<H08<@003240<@0a0008<@003
2408@@Q000<8@@08240480@0220<H0QQ2608H@88@@03240880PP00888088@003244<@0Q000<8@004
22448@@Q12431203240212000`A12448@@022441240122000004LiagW7NKMi/6Mi`00gNKMiagW009
Mi`00g^LMiakW007Ni/00g^lNiak^`0:Nk/7Nk`3Nk/3Nk`00g^kNkak_002Nk`2Nkd?Nk`8Nkd01g_M
NkekgG_MNkekgGoM00=kg@=og@=kg@03NmiogG_M00=og@AogPAog@AogP03OmeogWoM00MogP03Omeo
gWoN00EogPEogA1ogP03OmmogWoN00=ooPAog`05OomooWooOomooP3oOom:Ool2Ooh3Ool:Ooh2Ool0
1GonOomoogooOoh00goo0Won00=ooGonOoh00WoN0goM0W_M00Ek_7^kNk]kVWNK009gVP06KeUJDBB4
100000@00PPQ2@PP00<88@@Q12001P@P0P@02@@P0`PP00L8@0a0364<H0Q0220<@@02368010aQ3448
81100Q1P00TDH1RQ6:8<@0@0200<@A1R46400PaR00<<H@aP36400PaR00@<@Pa1344<@@H<@08<H004
340<@@aQ364246400`a0344<@@0336401Q1Q4688@@@0340<H@8<@008440@HA1Q344<HQ1R4888H@88
@@05240<H@aQ368@HP03364246401A1P320@P12236800PaP0Pa000<8@0a034000Pa000DDPABS588<
H@a1008480031248@0Q1008880<<H0@<@088@0053408@0Q02408@@0324002PQ1220880a02648@0@P
100880Q010PP0Pa000<<H@a024400PQ00PPP00D480@Q12448@@P00H8@0848@<8@@48@048800000=c
W7NLMi`01gNL00=gVgNLMi`02GNL00EkW7NLNiakW7^K009gV`05MiakVg^LNiak_004Nk/3Ni/4Nk/4
Nk`00g^mNkak_002Nk`00g^kNkak_004Nk`01g^mNkak_7^lNkek_7^m00ek_0Ak_@=kg@03NkekgG_M
00Ikg@04OmiogG_MOmd2Nmd01G_NNmeogWoMNmh017oM0WoN00=ogGoNOmd00WoM1GoN00=ogGoNOmh0
1GoN00=ogGoNOmh01GoN1GoM57oN0Won00=oogoOOol00Woo0gon1goo0gonogooB7oo0gon0goo00Ao
oWooOomoo`=ooPIoo`=ooPAogP9og@9kg09k_008Nk]gVgMkMi]cVVmICQ0H@P8400888003224880PP
008880<480888@04220480@P1202124010@P12488@@Q2P@P0PPP00D8@@aQ368<HPaQ008@HP<<HP0?
244480PP364@HAAQ584DXQB146488@`P344<HQ1R008<HP0:364@HA1R468<HPa2344<@0a134033440
2@a0364<H@a0364@PQB3468@H@0246001`a0364<HAB25:<@PPaQ00888003340<H@aP00@<H@073408
@0aR368<P`aS36800`aQ00H<HQ224:<DXaB3488246425:803A22364<H0aP340880Q03408@0PP340<
H122008<HP04344880PP344336423402360010a0240<@0a01PQ000<8@@aQ36401@a00PQ000<40000
10000`Q01@a000@<H0Q13408@0@880H8@@@8@0888@<8@0488@000WNL00=gVgNLMi/01GNL0gNK2GNL
00=kW7NLNi`00W^K0WNK00=gW7^KNi`00W^L1W^k0W^K0g^k2W^l0W^k1W^l00=k_G^lNkd04G^l0g^m
0g_M00Ak_G_MNmek_@=kg@9og@9kg@05OmekgG_MNmekgP07Omd2Omh00goMOmiog@02Omd2Omh<Omd5
Omh8OmdCOmh:Ooh5Ool;Ooh;Ool6Ooh3Ool2OohAOol00gonOomoo`3oOolHOol2Ooh6Ool5Ooh6Ool2
Ooh4Omh3Omd2Nm`2Nk`027^kNi]gNg^KMiY[>46]304210000``Q2248800622000`@P22088@03220A
120222003@a1368@PQ225:<HY123468@H`aS3688@@a2008@HP0@568@PABS588DHQ1R444@H@a1368<
HA1Q460@PABS368234801111460<@0a00`a10Pa000D880`P360<HA1Q008@PP8@H006340@H11Q464<
H11P0Q1Q00D<@0a1360@H121008<H08@H003340<H@aR008<HP0>364@PQBR464<HA1R6:@HXa22468@
PQB25:8@P@8<H@8<H08<@0888006240<@0aP360<H@aP10a10PaQ0Q220PaP00L8@0Q1340880@P240<
@00236000`a02408@@02244324000`a0364<H0032203120010PP240<@0aP0Pa000L<H11Q464<@0Q0
2248800224400`aP2448@@0224400`aQ2408@002240212032401220000YgW0=gV`9gW003MkagW7NL
00agW004Ni]kW7^LNk`5Nk/017NlNiak_7^L1W^l00Ek_G^lNkak_7^m009k_003Nk]k_7^l00Ak_0Ek
_@03Nkak_G^l00Yk_0Ak_@03Nmek_G_M009kg@03NkekgG_M009kg@03NmikgG_N00=kg@04NmikgG_M
Nmd:Omd00goNOmeogP05Omh00goMOmiogP02Omh00goMOmiog@02Omd;Omh00goMOmiogP0DOmh3Ooh0
0goNOoiooP02Ooh3Ool00gonOomooP02Ool2Ooh017oMOkao_7oL0Wnl00Aog7nkOk]o^`Iog006Nk]o
^goLOm]o^g^J0Wnj0Wnk0gnl1WoL00=ofgnkOk/00WoL011kVW^INiYk^WnkOmao^g^jOk]og7^kNi]o
^goLOmeo_09k^`=o^`03Nk]o^g^k009k^`9kVP9o_09k_004Omak_7^lOmd2Omh00goMNkak_003Nk`0
1GoMNmekgGoMNmd00goM00IogWoMOmeooWoNOmd2Omh2Nmd00goNNmek_@02Nk`017_MOomkgW^m1WoN
00=o_GoMOmd00WoN00AooWoNOmiogP9kgP=ogP9kgP03OmikgW_N009oo`9ogP9ooP9ogP03OomkgW^m
00IogP04OomogW_NOmjZOol3Ooh5Ool5Ooh00gooOoioo`02Ool3Ooh017oNOmeogWoN0WoM0W_M00Ik
g7^lNkak^g]jLeX2MiX01f;f=D/40000100<8@PQ00@8800312048@PP00@48003124880@P00X48084
8@@480888005344@PaS45:@@P`0248801Q1R58<<HPaR120<HP<@HP07464DXaRR7:<DP@a046400`aR
00/@HA10488<P`aR220@@AB2464@@111008<@007440@H0a0344880a036000Q2110aQ00<@H0aP3600
0a1Q00dHXQ1R364<@11Q364@HA10360<HA1Q488@HP04364010b2464<@0a00PaQ00<<HPaQ364010aQ
00@<@0aP3608808<@003364<H0a000@<H0888003340<HA22008@PP08364<H0aP340<H@aR468<H08<
@003360<H@aQ0088@@031448@@Q10088@006344<H@aQ2208@0A10`Q10PQ000@<@1215:<<H@@<@003
244880Q1008<H@H8@@<8@088@@04264<H@Q02401220000IgW004Mi]gW7NLMi`3Mk/017NlMiag_7Nl
1GNL1WNl00Ak_7NlNi]kW0Mk^`Mk_003Ni]k_7^l00Ek_@Yk_0Ik_@]k_003Nkeo_G^m00=k_@]kg@Ak
gPIog@03OmiogGoM00Eog@AogP03OmeogWoN00MogPEogAeogP03OmmogWoN00QooP=oo`9ooP=oo`08
OoiogG^JNgUoVGniOkYoV@9kV@0=NiQkMW]fNiEkUW]eNgIoUgnHNiIkMg]fNiL00WnH00Io^GnHNiMk
V7nIOkT2OkX2OkT2OkP00gnHNiMkV004OkX6Ok/3OkX2Ok/4Nk/017oLOmeogGoK0g^k00Iog7omOoeo
oGoMOm`2Nk`01W_LOmeooGomOmakg09k_0=og@03NmeogGon00aooP03OmikgWoN009ooP9ogP03Ooio
ogoo00Ioo`06OmiooWoNNmiogWon2Woo1G_N00AooW_NNmikgP9oo`9ogP9oo`AkgP=kg@=kgP9g_@04
Miag_GNmMkd8Nmh017_MNmikgW_N0g_n0goo00=kgW_nOol00Won00=kgW_MNmd00g_M0gon00=kgW_n
Noh00W_n0g_N00=kgG_NOoh00W_N00YkoWonOoikgW_nOomkoW_NOoioo`=ooP07OomooW_NNmiooW_N
Nmd00W_N0W_M00MkgW_MNmak_7_LOmeoo@02Om`2Omd00g_LOmaoo@03Ood00goLOmeog@03Omd4Om`0
0g_KOmaoo@02Ood2Om`2Omd01G_LOmaog7oLOmd00gol00=ooGolOo`00Wol0gom00EogGomOoeooGol
00Ioo@=ooP03OoeooWoo01aooaEooP=og@0COmiogGoMNmekg7^lNkek_7^kNgQgFG^JLgQBDB371000
00@022000PPQ10PP00@48@PP120880l48005124480@P1004800322001Pa1368<H@aQ344@H@8@P@0;
588<H@a1220<HA2248<@HQB35:<HX`026<802PaP468@Ha1S3448@11P464<PPaR0`a10Pa000<<@@aQ
46000Q1P0Pa000`<@@a0340@H122340000PP364@H110460346403ARR5:<@H@`P460<HA1P340@HA22
6:<DPa1R00D<H@0:464<@0PP1248@@aR364@HQ1Q360334000`aP340<@0033403360248401@aP2200
00a058400Q2100<<H@a022000Pa000<8@@PP24400Pa000L<H121464<H@Q12408@@0524001PQ12408
@0Q024488@88@@06220<@0a0480@P@aP10Q000L8@@a0340<@0aP3408@00322000`PQ2408@0022440
0`Q02448@0022401220000AgW003Mi]gW7NL009gW0=g_006Mk]g_7NLMkagW7Nl1GNL27Nl00=k_7^k
Nk/01G^k1G^l0W^L00=k_7^LNk`01G^m1g^l00=k_G^lNkd027^m1G^l0g^m00=k_7^mNkd00W^m00=o
_G^mNmd02W_M17_N2GoM00=ogWoMOmd00WoM47oN0goM77oN0WoO2Won0goo0gon0goo00EogGnlOk]o
^goJ009of`04Omaoo7oKOkP3OkL00gnhOkUo^@04OkT00gnjOm]of`04Om/00gnjOmYof`03Om/5OmX2
Om`00gomOoiooP05Ooh4Ood017onOomooWon17oo00=ogGooOol01Woo00=ooWooOol01Goo0gon37oo
00=ooWooOol0QWoo1Won0Wom00Aog7oMOmeog@9og0=oo004OmaofgoLOk/2Om`017oKOkYo^Wni0Wnj
00=o^GnjOod01GoK00Eog7niNiUo^7nj009o^@Ao^003OkMkUG]d00=kM@0@NiIo^7nhOiMkUgnHOkUk
Ug]fNiMo^7oKOkYgMgMiOmdMOol2Ooh3Ool7Ooh2Ool6Ooh6Omd2Nmd037^mNkak_7^JNgUoVG^KKcM6
4ARX000400D88@04220480@Q124222442209120312400`@P12448@02120322000`Q1368<H@023642
46403121464<H@PP340@HA1R6:<DXa23588DX`8Li0065:8<HQ1R468@H@a00Q1Q00@<HPa12208808<
@@0<340<@A1Q584@H110220<@0Q0220<@11P0PaQ0Q1R00D@PQ1Q320@H0aP008@H@09588@HA1Q340<
H0aQ460@H@aQ00<@HP03368<H@a1008<@0<<H@8<HP@<H@0;464@@11Q340<H122368<HA1Q468<H002
34000`aP364@PP0236001P@P360DXA1P464<H0@<@0<<@@05364<H1226<@@HP0234001A1P2408@0PP
24000Pa000@8@@Q02448@@888@03244<@@`P008<@003360<H@aP00<8@0052448@0Q0340@H0023400
0`Q022088002220010Q0344@H@a01@Q00@PQ0005Mi`2Mi/00gNLMk]g_002Mk`00gNkMi]g^`02Mk/6
Mi`8Mk`00g^lNk]k^`07Nk/2Nk`3Ni`2Nk`017^kNkak_G^m3G^l1g^m1G^l0g^m00=o_7^mOkd017^m
17_M0W^m1G_M00EogG_NNmikgW_M00Qog@03OmiogGoM009og@IogP03OmeogWoN00MogPEog@EogP=o
gA5ogP03OmmogWoN009ogPAooP9ogP]ooP04Omeo_7njOkX2OkT017oJOo]ongni0Wnh1Gng0gnh00Mo
]gnhOkQofWokOmYo^@02OkX00gniOkYo^P02OkT02WnhOmUofGoJOkUo^WoJOoaooGoL1Gom00=og7oK
Om/00WoL0gom0WoL00=ogGoLOm`00WoM00=og7omOod00Wom2Gon00=ooGoMOod00Won0Woo0gon0gom
17on0goo0gonQWoo00AooWooOomoo`9ooP03OomooWon009ooP9oo`05OoiooGomOoeooP03Ood2Ooh0
0gomOmaoo002Ood02WonOomoogooOoeofgolOoeog7oK17oJ0goI0gnh1WoI00=ofWniOkT017ni00Eo
^7]hMcMgNGom01Uoo`05OoioogooOomooP03Ool7Ooh2Ool6Ooh5Omd017oLNmak_G^l0W^k00UkVW]g
NgMcNV/FAQ4@I`0010000PPQ0`PP0P@P0`@Q0P@P00<880@P12002P@P00<48@@P12001@@P0PPP00<8
@@aR36400PaP00<@HA2146400Q1Q00d<@0`P344@HABR468<H@Q0364@XQC2488@P@0646401@aR2204
00PP34400Pa000D<HA1Q580@H0a0008<80<<@007484@PQ1R464@HQ224840111P0Q1Q00L<H@a1344<
@0aQ464@HP0346400`aQ344<@002340222002Pa0364<H@aQ360880a0364<H0a00`aP00<<@0Q03400
0PaP00<<@0PP22000Pa000L<H0aQ364@PAB1460<H006340020aQ368<H@aQ2448H@aQ244234001A1P
3408@0PP24000Pa000L8@@Q0244480PQ244<@@0334000`aP3408@00324000`@01208@00224033402
2402220010Q03408@0a00`Q000<8@@Q024000@Q10009Mi`5Mk`017NLMkag_7Nl1WNL0WNl00=gW7Nl
Mk`00WNl0g^l0W^L0W^l0g^k0W^l0W^L2W^l00=k_G^lNk`00g^l00Ak_G^lNkak_0Mk_@Ek_0=k_@03
Okak_G^m009k_@03Okek_G_M009kg@=k_@Qkg@Yog@03OmiogGoM00Aog@9ogPAog@QogP03OmeogWoN
01mogP=ooP03OmiooWoN00=ooP03OmiooWon00EooP03OmiogGnK009oV005OiMo^7niOkUo^003OkL0
2GnFOiEoUGnEOiAo]GnfOkMoUP02OiD017nFOkEo]gng1gni0gnh17ni00Ao^7niOkUo^@9o^P9o^@Io
^005OkUo^WniOiQo^@02OkX017nIOkYo^WoK0goL0WoK1WoL0WoM0goL00=ofgoLOm/00goL00=o^gnj
Om/01goL00=ogGomOoh00WonCgoo1Gon00=ogWoMOod01Gom0WoM1Gom17on0goo0gon27oo2Gon1Gom
00Aoo7oLOm]og0Aoo0Aog0=of`03OmaofgoK00Eof`03OoaooGoL00Aof`03OoeofgoK00=ofPEo^P03
OmYofGoI00Aof@03OmQofGoI00Aof@=o^P9o^@08OkMo^7ngOiUgF7<fOmaooR1oo`=ooP04OomooWon
Ooh2Ool3Ooh00goNOmeog@06Omd03W_MNkek_7^lNi]kVW]GNgQcNVKe>Jl89@0110042248124010@P
12448@@Q20@P0P@Q1@@P00L88@@P220880Q0344<@00336000a1P364@H@0246402Pa0464@HA1Q3644
80@0220<HA210a2200@DXQ1Q464@HPH<HP<<H@0=360@H11P340<8110460<@0PP464<HPaQ46400Q22
0a1Q00<@H0a036400a1Q00/880@P120@PQc4464<@11Q3648@0PP008<@@03340<H@aQ008<H@06344<
@0a03408@0aP0PaQ0PaP00<8@0@P22000`a000D8@@aQ240880a000@<H@03464<H@aQ008<H@03360<
@0a000<<@@07244480A12608@@@P34400PaQ0`Q01`Q100<<@@aQ46001@a000<<H@Q124000P@P00@8
@0Q1364<H08<@0032448@0PP008880H8@088@@4<@048@@003gNL00=g_7NLMi`017NL27Nl27^l0g^k
3W^l1W^m17^l00=k_G^lNkd017^m1G^l0g^m00Ao_7^mNkek_@=o_@03NkekgG^m00Akg@=og@=kgA]o
g@EogP03OmeogWoN00EogP03OmeogWoN01QogP03OoiogWoN00eooP0>OmiogGnJNgIkEG]DOgIoUWme
OiIoUGnDOiEoU0=oT`9oU0=oU@04OiAoUGneOkD2OkH00gnhOkUo^@0LOkT00gnhOiUoV@02OkX01Gnk
OkYoVWnjOk/01GoK00=og7oKOm`037oL1GoK00=ofWniOkX00Wnj00=ofgoLOmd00Wom2WonA7oo1Gon
00=ooGoMOmd00goL0goK0Wnj00EkVGnjOm]ofWnj00=of`03OmaogGoM009og@=og0Eog@Aog003Nk]o
fgoL00=of`03OmYo^Wnj009o^P9o^@Qo^09o^@AoV003NiQkUW^G00IoUP03OiMoUWnF009oUP9kUP06
OiMoUWnFOiIoUgnF1Gng4Gnf00Uo]GndOkAo]7nGNeMgEgolOoh07goo3gon00=ooGoMOmd017oM00Ak
gG^mNkak^`9kV`0;NgQo^GNKI_@eC@@4004880`Q22088@03220010@Q12048@@P1P@Q10@P00<400@P
120010@P00<880@P22001@PP0`a000@8@0aP360@H08@H@8@HP8@H@03468<H@Q100840009220<H11P
464<HAB27<@DHA1Q00@<HP8@PP8<H00<320<@0aP464<H@a0320<@0aP340880a00PaQ00H@H121484@
PA1P340234402Pa0484@H0aP22088@a15:8DXa1Q0Pa00Pa10PQ100X<@@aQ468@HPaR3448@@@P220<
@@8<HP8<H@07464<@0@P120880aP36400`a000H<H0a0340<H@aP3643464336400`a03608@0023400
1`Q0220480Q13608@@@Q00D8@@H8@08<@08<H@03460<@0a000@<@003244<@0a00088@003360<HA1P
008<@0888003224880PP00D8@088@@48@04<@04<@@003gNL00=g_7NLMk`00WNl0gNL0WNl0gNM00=g
_7^lNk`017^l0WNm00Ek_7^kNk]k^g^l009k_@03Nkak_G^l00=k_@Mk_0Ek_@=k_0Mk_@Ek_0=k_@03
Okak_G^m00Uo_@=o_003NmeogG_M009kgA]og@EogP03OmeogWoN00EogP03OmeogWoN01YogPmooP08
Omeo^gnHOiMoUWmeOiIoU@9oUP03OkEo]WnE009oT`07OiAo]WnfOkIo]gnfOiH00Wne00Eo]WngOkMo
^7ng00Mo^@9o^PEo^@Ao^PEo^@03OkYo^Gni00Eo^@03OkYofgoK009og003Om]o^goK00Mof`03Omao
fgoL00Uog0Eof`EofP04OkYk^GoLOm`2Ood9Ooi4Ool4Ooh01GomOoiooGomOmd00goL0WoK00Moo7oK
OkUo^GoJOkYo^@04OmX00goKOmaog004Om`00goKOmaog003Om`8Om/2OmX017oIOmYofWoJ1Wnh1Gng
0gnh0Wni0Wnh0Wng2Wnf0gnE17nf1gng00=o]WngOkH00Wnf00=o]GnEOkH00Wnf00=oUGneOkH00Wnf
17nE00Io]WnDOiMg=W^JOodSOol<Ooh2Ood5Omd03g_MNkek_7^kNi]gVgnlOkUgVfJc;>T00P01340<
@@0522031207124312022206120222001`@P220880@P22088@a100D<H@03460@PA2200D@HP05488D
Pa1S46<<HP023642220010aQ6:<DPQ1Q0`aR0`aQ00<<@0PP22000`aP0PaQ00<<@@a036001@aQ00@@
HA21388@H@8<@006364<HPaR368<H@aP0Pa100H<HA214:<@PQ1Q34043680111S368<H@aQ0Q2210aR
00`@HPaR488DPA1P340880`P360@PA2236433403364010aR464@HAB10Q1Q00<<H@a134000PaP00P@
H0`P320880a1340@H@Q10P@Q0`Q10PQQ00<8@@Q024400PQ100D<@0aQ364<PPaQ008<@006344<@0a0
2408@@a010aQ00<<P@aP34000`PP0`Q10`Q01@Q10@Q00@Q100000g>LMiagW00;Mi`00gNKMiagW002
Mk`00gNLMkag_002Mk`017^lMkegWGNM0gNl17^l0WNm00=k_G^lNk`00W^l0W^m0g^l0g^m2G^l0W^m
17^l1G^m00=k_7^mNk`01g^l0gnl0W^m0Wnm00=k_GnmOkd00W^m0gnl0g_M00=ogG_MOmd00WoM0g_N
6goM1WoN0goM47oN00=ooWoNOoh02GoN37on00MoogonOmeo^WnhOiMoUP04OiL00gngOkIo]P0=OkH2
OkL00gnhOkMo^@03OkT00gnjOkUo^P02Ok/4OkX00goJOm]of`05OkX3OkT2OkX3OkT00gnhOkUof@02
OmX=Om/;Om`6Om/2OmX01WoKOmYofgoKOmaoo0Aoo@QooRMoo`03Ooioogoo01Eoo`9ooP04OomooWon
Ooh5Ood3Omd00goKOmaog004Om`00goKOmYof`05OmX2Om/3Om`5Om/00goLOmeog002Om`6Om/4OmX2
OkX6OkP5OkL2OkP5OkT2OkP6OkLEOkH3OkD5OkH2OkD7OiD01GnCOiMc=g^jOod087oo3gon0Wom17oM
0WoL00=kg7^lNk`00WNK00Ek_7^JJcQJ<21U00800003340<80PP00888003100480PP00<880041208
80@P1202124:12000`@02204800322000`@Q224<@@023682488246401@aP488HXa1R36800Q1R00@D
HQRS6:@@P`8@H`0548<<HPa1220<@003464010aR3648@0aP0Q1Q00<<H@a034000Q1P00<@H@aQ3640
0PaQ00<DPQ2246400Q1Q1@aQ0Q1P0`aQ0`a10PaQ00@<@11Q364@HP8@H@09368@HQ23468<HPaQ488<
H@aP008@P@0;5:<DY123368@PQBR580<@11P340<H00246000`aQ360<H@0336405@aR364<@@a1460D
P11P320480PP340@H0aP460<@0@P240<@0aP3648@@0212001PQ02448@@@P2408@@88@0<8@@07344<
HA23488@H0a034400Pa00PQ000<<@0Q034000`a000<<H0a024000`PP0`Q010PP00@88@Q1244<@048
@@0000=cW7NLMi`037NL0WNl0gNM00=gW7NlMk`00W^l00=g_GNMMid00gNl0gNm00Ak_7NmMkek_@=k
_0ek_@06Nkak_G^mNkek_7^m1G^l4G^m00=o_7^mNkd00g^m0Wnm00Ak_GnmOkakg@Ek_@9kg@AkgP=o
gP]og@05OmiogGoMOmeogP05Omd017oNOmeogGoM1goN00=ogGoNOmh057oN0WoO00=oogonOoh00Won
00=ogWonOoh027on00YoogonOoiooGnkOkYoVGnHOkQoUPYo]`06OkIo]gngOkMo^7ng17ni00Ao^WoI
OkYo^@Qof`9o^`Uof`05OmYo^WoJOm]o^P03Ok/00gnjOm]ofP0>Om/00goLOm]of`07Om`2Omd2Om`2
Om/7Om`00goMOoeoo@02Ood:OohUOol00gonOomoo`0JOol3Ooh2Ood3Omd4Om`;Om/3OmX4Om/017oL
Om]ofgoK1GoL00=ofgoLOm/01GoK0goJ00=ofgoJOmX00WoI27nh00=o]gnhOkP01Gni0Wnh1Wng0gnf
00=o]gnfOkH00gnf00=o]gnfOkH01Gnf0Wng0Wnf0Wne2Gnf00YoUGnFOiIoUWnEOi=oTWnGLcQog@9o
oR5oo`iooP03OmiogGoM009og@03Omakg7_L009k^`07Mi]cO7NKLiYW64W`52800P0000<<80PP2240
0`PQ10PP0P@Q00<880@P12003@@P10PP00<88@Q134800PaR00H@Ha23488@HA1P36025:<236824680
2QAR58<DY123468<HPaS348<@@`P0Q110Pa100@<HPaQ364<H@@@H@04364@HA1Q4642344010aQ368@
PaB20Q1R00<<H@Q036400PaQ0PaP00D@H0aQ468<HPa200H<H@@@H@@<HP03364<H0aQ00<<H@04368@
PQ2348824680211Q460@H11P464<HPaQ240236023643368010PP340@HA1Q0Q1P0`a000H88110460@
H0aP2442340236000`Q12208800236003@Q1364<H@Q12408@@Q02448@0a0364@Pa22008<@088@003
3408@0Q000@8@08<@004360<@0a02403220224000`Q122088@0224423681340134400003LiagW7NL
00igW0=gW@9g_0Ek_0=g_@03Nkag_GNm01Uk_@]k_0]k_@03Okek_Gnl00=k_@9o_@Mog@9o_@04Nkeo
_G^mOmd3Nmh9Omh6Omd00goNOmeog@02Omh;OmdDOmh4Ooh017oNOoiogWoN0WoO00=oogonOoh01gon
1Goo17on00Ioo7nkOkYoVGnGOkL3OkH2OkL7OkP017ngOkQo^7ni0Wnj0WoK00=ofWoKOmX00goK1WoL
00=ofgoLOm`02GoL0goK00=og7oKOm/00Wnk00=ofgoLOm`02WoL17oK1goL1goM00=og7oKOm`017oL
0goM0Wom27on8goo00=ooWoMNi/00WMk00=og7onOol00Woo0gon4goo17on0Wom00AogGoLOmaog0Mo
f`03OmYofGoI00Aof@QofPEof`Aog003Ooeoo7oK00Aof`MofP9of@9o^09o]`9o^09o^@05OkQo]gng
OkMo^004OkT2OkP6OkLPOkH037neOiIoUWnFOiEo/gn`NgAc=goMOomooR5oo`iooP=ogP9og@9og09k
^`08NkYgVgMlNkagVf/j?Hh800800004320880PP120622021242220>12000`PP12048002220010aR
468<HPaR0Q1R00P<H11Q340@HABS464<@0a10Q1R00PDHAB2488@P@aQ34888Pa21@a10Pa200L<@@PP
220<HA1Q444@H@0336400`aP34088@0234401PaQ464<H@aR240<H@8<HP05364<H0aP360<H@023440
0`a2364<H@0<36400``P360<@002344020PP340@HA1R464<H@Q0340346000`aP340<@00234001120
360@H@aP0PaQ00L<@@a0580DXARR464<H@0234001P`P340<@11P488<H0<<@004360<@0Q034023600
10aQ244<@0aQ1`Q00PQ100<<80PP22000PPP0`Q00`Q10PQ010a000<8@0PP24000PQ000<8@@PP2240
0PQ10PaQ0@a00@PQ000017>LMiagW7NM3GNL0gNM00=g_7^lNk`00W^l27Nm6G^m2g^l3G^m00Ek_7^m
Nkek_Gnm00Uog@=o_@03NkekgG_N009kgPYogP03OmeogWoM00=ogP04OmeogWoMOmd2Omh7OmdGOmh4
Ooh3Omh2Oml00gooOoiooP02Omh5Ooh3Ool00gonOomooP02Ooh01gomOmao_7]iNeQoVGnH00=o]`04
OkQo]gnhOkP5OkT00gnhOkUo^@03OkX7Om/8Om`5Omd6Om`3Om/8Om`3Omd>Om`7Omd017omOmeogGoM
17oL00=ogGoLOmd00goM1Gon0Woo00=ooWooOoh027oo00=ooWoMOmd00WoN1Gon2Goo0goN1Goo00Mo
oW^kLaMZU7<HNiYoo@06Ooh:Ool3Ooh3Omd017omOoioogon0goo00=ooWomOmd00WoL2GoK00=o^WoJ
OmT017oI00EofWoIOmYofWoK00MofP04Om]og7oLOm/3OmX2Om/3OmX00goIOmYofP04OmT00gnhOkUo
^002OkP3OkT2OkP3OkL00gnhOkUo^P02OkT8OkL=OkH5OkL3OkH5OkL3OkH017nEOkIo]WnE0gnF00Io
TgncOk5kM6lgOmdTOol3Ooh3Ool7Ooh2Omh4Omd2Nk`037^kNkYgVgMkNiYgVVLI>Dd4000010088088
@@8880D88@848@03244880@P00<48003220480@P00L4800:220480@010088@Q148<@HQB346823644
46401Pa0000880aQ564DPP8@HP07464<@0@0244<H`aR26400PQ100D8@PaR368<HQ1R00@@H@06468<
HA1Q364<H0a10P@P00<8@0aQ36400PaR00<<HA2248<00PaQ00X<HPb2488<HPa0220<@@aR364<@@P<
H@8<HP05340<811Q364@H@02220010`P364<HA1Q0PaR00L<HA1P3608@0a0360<@00236401AB1588@
HA1P36400Pa100P<@0aQ5:8DPPaQ344<H@aP10a00PaP0`a000H<H0a0340<@0aP4842488236400`a0
2408@00424001@@Q244880Q022000`Q01@Q110Q000@<@0Q02408@0888088@08880@8@@4880488@00
00=cW7NLMi`03WNL0gNM1GNl0WNM1WNm6G^m3g^l2G^m00=k_7^mNk`00W^m00Ao_GoMNmeo_@Qog@04
Nmek_G_MNmh5Omh3Omd3Omh@Omd2Omh00goMOmiogP0EOmh3Ooh4Omh2Oml00gooOmiogP04Omh6Ooh2
Ool3Ooh027oMOmao_G<HL]EflgnGOiH4OkL00gnhOkUo^@04OkT3OkP2OkT017njOm]ofgoJ1WoK1WoL
27oM0goL00=ofgoLOm/027oL0goM37oL00=ooGoMOmd01GoM00=og7oMOm`00WoM1goL0goM27on2Goo
011ooWNKLeUc>6lHLcQgNG^kNiYgVWNKMiak_7NLLiagW0=oo`06MiaZn6[FKcQgVg_M0gon00=ogWnM
L_T00VkG00mkVgoKOmek_7NJNkakg7NKMgYgVg_MOoikgWNlMiX00WNK00UgVW^jNkYgNG<fLcEcEgNJ
Ood01Goo00AooWoMOmaog09of`03OmYofgoJ009ofP05Om]o^WnjOkUofP04OmT2OmX00goIOkUo^@0B
OmX7OmT:OkP5OkL01GnhOkUo^GniOkP00gnf0Wng3Wnf1gng0gnf0WnF0Wng00Eo^7nfOkIo]WnE009o
]P0:OiEoUWnFOkEo/gn`OjikDG=HNmdZOol7Ooh00goNOmeog@03Omd03W^lNk]k^g^iNiYgNWMiMgQN
]CE;200000`P220224001@PP22488@PQ24400PPQ0P@Q4P@P0`PP00D8@A1Q464@HPaQ008<HP0@3648
@0a0364<@0PP120<@1B17:<@H@a1340@@0PP364236802@a12448@@a2364@HQ1Q444@H@026:<0111Q
364<H11P0PaP00L880@P340<@0a1364@H@0336401a23364<@@PQ340DXQBS00<<@@04320<@0a03605
36443442320010a0344<@0a00PPP00@<@0aQ364<H08<H@03460<@0a000<<@006364<H1BQ5:8@HA1P
0Pa000D<@@aQ3408@0a0008<H@03340<@@a100`<@005460@PA22364<@003240322001`Q02448@@Q1
2208@0PP0088@003340@PQ210088@@032248@0Q000H8@0D88088@0032448@0PP0088800000=cW7NL
Mi`03WNL0gNM1GNl0WNM1WNm6W^m2G^l17^m00=k_7^mNkd02W^m00=kgG^mOmd00W_M00=k_GoMOmd0
1WoM0W_M0W_N17oN00AkgWoNOmiog@EogP03OmeogWoN00MogP03OmeogWoM00AogAiogP03OmmogWoo
009oo`AogPAooPIoo`=ooP07OkegFGKeMaEkEGnGOkT00Wnh00Eo^GoJOmUo^Gnh00Eo^@03OkQo^Gni
009o^P05Om]ofWoKOm]og003Om/8Om`8Omd<Om`5Omd9Om`6Omd00gomOmeoo@03Ood3Omd3Om`5Omd0
0gomOoiooP0@Ool01G_MMgYgFGMjNiX00W^k00=kVgoMOmd00WoN00Ak_GNLOkeogP9oo`05OmigW7Mk
Mi]kg@02Ool2Ooh02WoMOkegFg<HLcUgF7^IOmek^gnl0goM00=k^gMjOoh00Woo00ecNW=iOmaooGoL
Omeog7^JMeMc4g<DNk]ooP04Ool01GonOoeog7oKOm`01WoK17nj00=o^GnjOmT01GoI00Eo^7niOkUo
^WoI00=ofP=ofA1ofPMo^@03OkQo^Gnh00Ao^003OkUo^7ni00=o^@03OkQo]Wnf01=o]P=o]`9o^0=o
]P9oUP=o]`Eo]P9oU@=oUP06Oi=oTGn_Ne5gVGon8Woo1Gon0goo1Won0goN0WoM00MogW^mNkek_7^k
NkYgV@02NgT00gMhFW</j@02100010Q12408@0Q00`PQ0PQ10PPQ50@P10PP00<@@A1R46800`aR018<
H@aR3688HPaR344<HQB3588DH@a1100DHAR2464<H@aP4684368446401Pa0464HXa1R220<@0@<H@8<
@@03464@HQ1Q008@H@0:364<HPaR364<@0PP320@H@aQ344236401@`P220<@12248<01PaQ00T<H0a1
100400a0344<H0aQ34400PPP0PaQ0PaR00@<H@aP320<80@<@08<H0<<H@09344880a1364<H0aQ464@
@111008<@@04364<H123488734001P`P340<H0aQ3608@@@8@08880032408@@Q10088@@042248@0Q0
240224400`QQ2448@@02220524032442240334032403220120000003LiagW7NL00igW0=gW@9g_0=k
_09gW@03Mkek_7Nm00Ik_@03Mkek_G^m01Ak_@03Nkak_G^m00Qk_@03Nkak_G^l00]k_@9kg@=og@9k
g@Yog@03OmiogGoN01QogPMogAAogP03OoiogWoN00=ooP04OmiooWonOoh3Omh2Nkd00goNOoiooP0;
Ool027onOmio^gnIOgQoMgnFOgL2OgH017meOiMo]gnh1Wni0Wnh00Ao]gnhOkQo^@Mof`Qog0Yog@Eo
g003Om]og7oL00=og0=og@aog0Eog@03OmiooGom009oo@=og@=og0Eog@03OoeooWoo02]oo`06Ooio
gWoNNkeogGoN0Won47oo2gon00=ooGoLOm/01WoK17nj17ni00=o^7ngOkL00gng0Wnf0Wng00=o^7ni
OmT00WoI00=o^7oIOmT02goJ17oK0WoJ00Eo^WoJOmYofWnj009o^@Eo^005OkUo^7niOkUo^P02OkT0
0gngOkIo]P0DOkH01GngOkQo]gnfOkL00Wnf0Wne1Gnf17nE0gnF00EoU7nAOi1g;W^i02=oo`eooP9o
gPEog@05Nmek_G^lNk]k^@02NgP01WMiLeM:41QS00040088@0888@888003224880@P00h480042204
80@P12031003220232000a1R368<H`03368236400`aR268<@P0234400`aQ464@@@0220001aRQ6:<@
H`aP440HXQB2008<H@8@H@8<H@03464<@111008@HP03464880a000P<H@05440@H@aQ344880043400
2`a12208@0aQ360<@0PP340@H12236400`a00PaP00D@H0aP220400PP00<<H@0;360<@@a1364@H@aQ
368@PQ1P3208000334001@Q0340<H0aQ36000Pa000X<@@PP340@H0aP460<@0aQ468<@@8<H088@004
340<80PP240634000`Q02208@00424000`PP12088@0224400`A112448@02120424401`Q0220880PQ
2408@@Q000D88004244<@@a0244334032401220120000003LiagWGNL00QgW0=g_0=gW0=gW@03Mkak
_7^l009k_004MkegWGNmNk`hNkd017_MOmeogGoM0W_M27oM00AogWoMOmiogAeogP=ogAIogPQooP03
OmmogWoN00=ogP9ooP03OomooWoo00Qoo`0=OmiooWnlOkYoV7nhOkIoM7/cM_1g4W]EOiL00Wnh00Qo
^GnjOkUo^GnhOkUo^7ng0Wnh00=o^GoIOmX01goK1WoL1goM00Iog7oMOmeogGoLOmd6Om`6Omd;Om`5
Omd017oNOoiooWon17oM00Aog7oMOmaog@9oo@9og@9ooTaoo`=ooP05OoeogGoLOm]og006Om/2OmX0
17njOkUo^Gni0Wnh27ng1Gnh1GoI2GoJ1goK00MofWnkOkYo^WniOkQo]`04OkP017niOkQo^7nh0gni
0Wnh27nf00=o]GnEOiD00Wne0gnf17ng00=o]WngOkP00Wng00Io^7nfOkIoUGneOiD5OkD2OiD02GnD
OiIoUWnFOiAoTgnBMbek^@0QOol00gonOomoo`03Ool8Ooh3Omh5Omd2Nkd037^lNk]kVG]hNeMgNFlF
?Jh80P002008@@88@0@88@H880H4800322048@PP008880<48@@4800622088@a1344@HQ1S0`aR00X@
HQ1Q460<HA23468880P0340@H@8@HP0;5:<H`a23368<81AP580@H@a0364@H@023640211Q364@H@`P
340@HQbT464234001PaR48<<@0aQ468<HP<@H@04368<@@a13402364020`P344480@P244<H0a02202
3403344020a0360<H@b26<<DPPa0220536402PaR46<@Pa1Q468<H@aR464<@0a10``P0PaQ00`<H0aQ
360@HA10344<@110464@PQ1P34023442244010aP340880PP0P@P00@880Q12448@@8<@@053408@0Q0
240<@00224000`Q122488@0614400`@Q1444@@02144324401@PQ2448@@Q122400`PP00@8@@PP220<
H@8@PP03364<@0a000<8@04<@04<800000=g_7NLMi`01gNL1GNl00=gW7^LNi`00W^L1G^l00=g_7^l
Nk`02W^m0g^l7G^m00=k_7^mNkd02G^m0Wnm00=k_G_MOmd00WoM00=kgGoMOmd01goM0WoN0goM6goN
0goM47oN0goM17oN27on00=oogoNOmh00WoN1Won1goo015ooWoNOmeo_7nHOiMoUGncOg9oM7/cM_5g
4W/bOiEo]Wng00=o^@=o^0Ao]`03OmMofGoJ00Qof`iog003Omeog7oM009og004Om]og7oLOm`4Omd0
0gomOmeog@06Om`3Om/2Om`2Omd2Ood3Ooh00gomOmeog@02Omd2Om`00goKOmaog@03Omd017omOoio
oWonBWoo0Won0Wom00=ogGoLOm/00goK0goL17oK00=ofWoIOmT00Wnh0Wng00Ao]WngOkMo]P=o]`Eo
^003OkUofGoI00QofP]of`08Ok]o^WnhOkMo]WngOmQof@=o^09o]`03OkQo^Gni009o]`9o]P03OkAo
U7nE00Qo]@03OiEo]7nf00Ao]`03OkIo]gng00=o]`03OkIo]GnE009oU0UoU@9oU005Oi=o]GnBL`ek
U`0QOol2Ooh2Ool00gonOomooP07Ooh2Omh6Omd2Nkd04G^lNi]kNGMgOgMgF6[f=D`40P002208@@Q0
224880Q1240020PP0P@P00<400PP12000`PP20@P0PPP0`a100PDHQB4468<HQ1Q364@H1100a1Q00<<
80PP46400a1Q0QBS00T@PQ1Q320DP11P444880a034400Pa00a1P00H@@0a1468DPQ1R464246800`aR
364<H@024682464334400``Q2208@@02320334001@aP464<H@aP34000`PP0Pa100d@HA226<@DXa22
468@HA2258<@HPaQ464<H@0446801@aQ344<@0a1340010a100<<@0aP36000`aQ00L<@@a0440<H122
484<H@0234400`PP2408@005340234400`Q1344<@@0234442402220624401`A124448@A12488@@@P
00L8@009224880PP22088@Q0244<@@a0008@P@03360<80a000<8@04<@04<800000=g_7NLMi`01GNL
00=gVgNLMk`01GNl0W^L00Ek_7^mNkek_G^l009kW09k_1Mk_@03Nkak_G^m00Mk_@Ek_0Ek_@03Nkak
_G^m00Ak_@Io_@9og@=kg@04OmekgGoMOmh6Omd3Omh4Omd5Omh00goMOmiogP0BOmh00goMOmiogP0@
Omh3Omd4OmhBOoh9Ool2Omh027oMOkYoVGnGOiEo]WnDOgD2Og@2OiD017nfOkQo^7nh0gng0Wnh00Io
]gnhOkMo]goIOmX8Om/2Om`6Om/4Om`2Om/00goLOoaog002Om`3Om/2Om`01GoMOmaogGoLOmd01goL
17oK00=og7oMOmd00Wom0gon00=ooGoMOmd00WoM0WoL00=ofgoLOo`00Wol0Wom17onBGoo0Won0Wom
0WoM00=og7oKOm/017oL0WoK0goJ17oI17nh00=o]gnhOkP00Wnh17oI1WoJ0goK00=ofWoKOm/00WoJ
1GoK17oL00Eo_7nkOkUo^7nf009o]`Eo^006OkIo]gnhOkQo]gnh0Wnf00Ao]GnEOiIo]`Io]P9o]@04
OkAo]GnfOkL5OkH01GngOkIo]gnfOkD01gnE1GnF00MoUGnCOi=o]WnEL`ik^P0ROol00gonOomoo`02
Ool:Ooh4Omh2Omd03W_MNkek_7NKMgYkVGnGLcQR/bd:004000P02442344224400`a12208800;2200
10Q1220880PP1`@P0PPP00@<80a1344@H@8@HP03464<@@aQ008@H@04568@HA11340246403Q1R588D
XaBS468<HQ1R320HPAbS444<8110360244001AAP588@HA1034000Q1Q0Q1R00<DPQ1Q24000Q1R10aQ
00D<@0a1320480PP008<@007368<H@aQ360<HA1Q36400PaP00d<H@a0220<@@aQ464DPAS34848H121
6:<DXP025:<01A1R464<HA1R36800PaQ00D@H@aQ364<HQ1R008<HP8<@@03340<H@aQ008<H@03340<
HA11008<@0<<H@8<@@052448@0Q0240<H00236400a22468<H@033402244224000`Q134488@032245
244010Q0244<H@Q110Q00`PP0PQ01@Q10`Q000<<@0aP36000`a00PQ00Pa00@`P0002Mi/4Mi`00gNK
MiagV`03Mi`2Mk`017^KNiakW7^L17^l00=kW7NlNk`01G^l0W^m0g^l37^m5g^l00Eo_7^lNkak_G^l
00=k_@]kg@03OkeogGoM00iog@=ogPAog@03OmiogGoN00UogP9og@03OmiogGoN00=og@03OmiogGoN
00iogP=og@AogP03OoiooGoM00=ooP9ogPYooP]oo`08Ooio^gnJOiQoUWnfOkAo]@=o]09o]@04OmQo
]gngOkL2OmP02GoIOkUo^7oIOmQoegoIOmYon`02Om/3Oo`01GoKOoaoo7okOmX00gok00AofWokOoao
o09og0=on`03OoYofWnj009o^P9on`09OoaooGolOm]o^goLOoeoo7oM009og008Ooeoo7oKOm]ofWoK
Oo]oo0Ioo@AooP06OmeooGomOoaofgol0gom00AooWolOmaooP=oo`EooP04OomooWonOoi0Ool017on
OoeooGoL0goK00=ofWoKOmX00goK00UofWoIOmUo^7oIOmYonGokOmT00Wni00=o^7ngOmT00WoH00=o
^7oIOmT00WoI0goJ0WoK00MofWoKOmYofWoKOoaonP02OmT2OmX7Om/027nkOkYo^WoIOmEoegnfOkL3
OkP017ngOkIof7nh0Wng00=of7ngOkH00gnF00=o]gnfOkH017nf00=o]GndOk<00WnE00Ao]GndOkEo
]@Io]P=oU@EoU00<OiIoUGnDOiEoUWnfOi9o[gnAOiAg<GoK8Goo00AooWooOomooP9oo`IooP=oo@03
OmeogWoN00=ogP04OmekgG^mNk`2Ni/01G^IOiQc=ei`:<L00P0000<800Q024000PQ02PPP00<480PP
22000PPP2@@P00/400PP200400PP340@@11P444<@A1Q008@HP@@H@08344<@1B15:8HXa215:4@H088
8006200<811Q6:<@H@`P0a1P00X@@11P460@H110460@H@a0220<@@8@H@0:240<@0aQ360<H@a1360<
@0Q1344234000`aQ360<H00346002@a0460@PQ1Q360<@0aP340<H002460011B1464<H@aQ0Q2100<@
P0Q034001PaQ00@8@0aP364DPP8DX`04488<HPaR344234000`Q13408@00224033403344010aQ344<
@0PP0`a010aP1@a00PQ00P@P00@880`P22048@<8@@04224880PP22062408220324001`PP240<@0a0
360<@0Q1008880<8@04<@04880000WNK1WNL00AgVgNLMkag_@9g_004Ni]kW7^LNi`3Nk`017^LMkag
W7Nl1W^l4G^m1G^l0g^m3g^l1W^m37_M17oM00=kgGoMOmd02WoM17oN1goM37oN0WoM00AogWoMOmeo
g@mogP03OmekgGoM00AogP=ooPEogPaooPUoo`0DOoio_7MINgMkMGmeOiAoLWm^OfmoL7nBOi5oTgnB
OiAoUWngOkQo]`9oUP9oU`06OkMof7ohOmUo^7ni0Wnj17ni00Mo]gnhOkUofWnhOkMo]P02OkL00goK
Oo]o^@02OkP037oGOkUo^GnIOkUo^WoIOkYofWoKOk]o^@9o^P0<Om]o^WnjOkYofWoKOkUo]gnhOmUo
^GoJ0goK00Iog7oKOm]ofgnkOkT2OkX00gnkOkYo^P02OmX2OmT01GoHOkQo^GnkOmd00Wom1gon00=o
oGonOoh0;goo00=ooWooOol037oo00EooWomOoeoo7oL009of`03OmYo^Wnh00Eo^09o]`9o]P9o^006
OmQongokOmYo^7ng0gnf00Eo]gnhOmUofWoI009o^@08OkQo^WnjOm]ofWoKOmYof`9onP07OmMo]gnh
OmUo^7niOkX00goK00=o^WnkOk/00WoK00Ao^GnfOmQoe`9of@07OmYofGoHOmIof7oIOmP00Wnh00=o
]GnfOkL00Wnh00Ao]gnDOiAo]@=o]`03OiEo]Gnd009o]@9o]P9o]@03OkMo]Wnh009o]`03OiEoU7nD
009oU09oT`9oU@0<OiIo]GnfOi=o/gneOmAo/WnCNg9gEGoM9goo27on00=ooGoMOmh00goN00=ogG_M
Nkd00W^m00UkW7NKMiUkVG<gDRlHH`0010000PPP00@8@0PQ12448@88800424048@@P1202220>1200
2@PP100880P0220<@11Q364@H@0246800aB3588@HP0246401Q1R364<@0a0464@P`8@PP04584@H0a1
3403220236401Pa0364<HA22464@H08<@004440DH11Q464234401A1Q468<HPQ136400PaR00H<H@a0
360<H@Q03442364010aP464@HA1Q0Q1P00D@PABS588@H@aQ00<<@004360<HA1Q4642364348434643
36402@aR364<@0aP364<HQBT5:<@P`0336800`aQ340<@0053403344010`P344<H@aQ1@a000@<H@aP
364<H0@<@004364<H0Q1240222000``P3408@@02244924000`a0364<@00722000`Q0220880022202
340010aP240880PQ0`Q10PQ00@PP0002Mi/2Mi`017NlMiagW7NL0gNK00Ig_7NLMiagVgNLNi/2Ni`0
0gNlNkak_002Mk`00gNLMkak_005Nk`ANkd4Nk`3NkdANk`2Nmd2Nk`3Nkd2Nk`7Nmd2Okd@Omd3Omh8
Omd:Omh8Omd?Omh2Omd5Omh01GoMOmiogG^lOkh017oN37on1goo00eogGnlLaQg=W;dK_A^lfkBK]5b
lGK`Na5k<002N`l017/@M_5bdG/@0Wma00]oDG/AM]5fdGl^OfYoLG]cMa9c4gLd00=k<`=g<P9g400=
Mc1k;g/^NbioL7mcOe5fd7KAO`io;G/aM_800W;B01Ug4GL_Ne9kDG]BNe=k<G]ANe=g<GL?Mc9oTgnd
OkMoUW]CM^mk<7mcOiIo^7oIOmYo^P02OkT04g]gNeEkEG]eNe=kMW]eNeAoUWnfOkAoTgnBNe9bdG;b
McIoV7oI00Aof`03OmaofgoK009of`9og0Aog@9oo@07OoaofgniNkQk^GoKOm`01Wom17on0Wom00Mo
oWomOmeooGoMOmao_002Ni/2NiX017^kOmaogGom0gon00=ooGonOoh00gom00AooWoNOmeogP9ooP06
OomogG^LNi]og7oK17oJ00Eo^WniOkUo^7ng009o]P04OkEo]gngOiH2OkH01GneOiEoUGmaOdd00Wm?
00=oLGnDOi@00gnD00=oUGnfOkL00Wng00=o]WnhOkL017nh00=o^GnhOiH00WnE0WnC00Eo]GngOkIo
]gnh00Qo^@0=OkQoUWnGOiIoMWmeOiIo]7nDOi5oU7neOiH00WnE00=oU7nCOi<01WnE00IoUWnEOiEo
MGmAOfd2Ok@2Og42Ok800gndOiEoUP02OiH00gnCOiAoU004Oi@03WnEOg=oLGn@OhioJGn]Oo=oe7n?
OfmoLg^HOohUOol:Ooh00gomOmeog@04Omd3Nkd03W^LMi]gNWNIMiY_5DG<320000@0320880Q0124;
2203120322091202220010a0460@H0aP1Q1Q00@@H0`P340<H@<<@08<H@08368@HQ1Q464<H@a1320<
@@8<H@8<@@04340@HAB246433400111P464DPA1Q0a1R00X<H`aR348<HQ23464<@0aP364<H0<<H@03
360@H11P008@H0@@H@03460<H0a000<<@0@<H0<<H@D@H@@<H@8<H004364<HQ224682364334423402
240534001@Q0340<@@a124400PQ00Pa000H<H11R364<H@a0240434000`aP484<@00222001@a0460<
H@a124400`Q00PPP2@Q01@PP00<8@0PP22000PPP0`a00PQ00`PQ0`Q00@PQ0003Mi/3Mi`00gNKMiag
V`02Mi`00gNlMiegW@03Mi`2Mk`3Nk`00gNlMkeg_004Nk`2Mkd00gNlNkak_@0PNkd3Nk`7Nkd017^l
Nkek_G^m0W^l00=kgGoMNmd00g_M0W^m00=o_GoMOmd00WoM00=kgGoMOmd02GoM0goN00=ogGoNOmd0
17oM3goN1GoM47oN00=ooWoNOmh00goN00=kW7MkNk`00WoN3Gon2Woo00=o_7<HK_H00W<E021bm7;c
L_=blWLAMa9k4GKaL_5g4W/CL_9g4g]@Og5o<7/@J[5NCfZ?M_1k<W]ANeAkEW]fOeEkEGmENgIkEG/b
0W/a01=g4GLBObmo;gm>Ne1k46J@FPeRCVj`Ma=k4WLBL_9k<7mcOiAkL`02Ne<067/aM_=g4g]CMc5k
<GnDOi=oUGnCLa9RT6Z?Na1oE7nhOkUo^7njOkUoVGnHOgIoM@9oMP0>OgEoM7nEOiEoUWnBOg9oLfkc
ERiR/gLcNeIoV09o^@Ao^P05OmUof7nhOgMoMP02OkT03gnjOm]ofgoKOmYkUg<BKZmbcgLCOkUofgoI
OmYo^`02OkX2OmX2Om/00gniOkYofP02OmX2OkT02GnIMcEZ/V9bJ[9^/WMGOk]of`02Om`027oMOmao
g7oLOm]ofWoKOk/2Om/3Om`02WoMOoeog7<ELaIc=GMDOkQofGoJ0Wnh00Eo^GnjOkQo^7ne009oT`0=
OiAoUGngOiIo]WnEOiAoLFZaGTiRCVj`Ma800Wmd00IoUGnDOiAoU7nEOiL2OiH01GnEOiMo^GniOkP0
0Wng00mo^7nFMa5^dW;ANc1kM7nDOkIo]GnfOiMo^GnjOkT00Wnh01EoV7nGOiMoUgnEOg=oM7;cL_Ag
5G]BMc=flg]AOg5oUGnFOiEoTgnBOg400Wmc00IoUGmfNgIoUWnGOi@2Og<047K@JZm^dG/BM_=^dWK@
ObioKGm^Og=oTgnEOg9oLGmb17md00ioMGmcOg5oCW[_L/ifl7/@Nc=k4gLBMc9k^Gon9Goo2gon0WoN
17oM0g^m00akW7NKMi]k^WNJJ_@mJPP0000400a0220224401PQ0220480@P220480888003344880PP
00888004120880PP22091202220234000`aP364@H@0546401a1P464<H@aR464<@110008<H@05368@
HA1R468<HP05344010aR344<@@aP0`aQ00L@H@`P340@PQRS5:<@PP0336800a1R368<@P0236800`a0
344<H@03368236423403460246400a10340<@0033644340336401121488@PQ1R0Q1Q10aQ0Pa000<<
H@aR36800PaQ0Pa10PQ100@<@0Q12408@0<<@08<H@03368<H@a000@8@0L<@003244<@0a000@<@007
320<@0a1360@H0aP34400Pa01PQ000@8H0Q02448@0<88003120880PP00<48004240880PP22023400
0`Q02448@@04244122412401244000=gV`=gW003Mi]gW7NK00=gW004MkegWGNLMid3Mk`4Nk`00gNm
Nkak_00PNkd00g^lNkek_@05Nkd00g^lNkek_@03Nkd01WnmNkek_G^mOkak_09kg@9o_0=og@9kg@03
NkeogGoM01Aog@AogP03OmeogWoN00EogP03OmeogWoN00MogPUog@AogP03OoiogWoN00QogP9og@03
NkegW7^L009ogPYooPaoo`0SOoioognmLcQg=G/eOg=oTgmCNa=k<gmbOg=o<WLBL_=o<WnAOg=oDWla
N_1o4Gl?IViVKfjaL]5k4WnCOiIoUgmfNgIoMP02OiP05gnGNeEkDg/cOg9oM7maObmoCgm@OdebdF9a
IY5^dWLBOe1oDGmbOi=o/gnEOi@00WnE015oMW/fNeMoMWngOkIoTgmbOi5oT7]aMa5k4G/CNe=kUg^H
009oU`0=OgIkMgmgOiMo]WnHOeEkDGm`Oi9oTGnCOg800W]@00EkDG/BNe=kE7]g009oV00?OkQo^Wni
OiQo^GnhOmMo^GmfMc=oUgnhOmUofWnj00=oV00CMaAg4WKaNcAoUgniOmQofWnjOiUoVWnjOmUofWnI
NeEkMWnhOmL00Wng0WnF00IoMW/cL]=^e7LFNeP2Ok/017oKOmYoV7nj0goL00Qof7]DNgQo^goKOmao
^gnj0WoK00Yo^GLfMaIkEgnGOkMo^7niOkQoU`9oUP9o^005OiEoLG]?Oi=oU@02OiH047maOg1oT7m=
I[5J3F9_I]9kDWngOgEoUWnDOg5oTgnF0gnG01AoM7]eOiIoUgngOiEo]GnFOg=^df:cI[=^lg]BOi5o
]7neOkAoUGnG0WnH01EoUgnhOiEkM7meOiIo]7maNe5N/ejCJ_EZdV:AGW1^dG]^OiAkM7nDOi400Wmb
01UoU7nENgIkEGLDNe=kM7maOg=oM7[aIXiV/69_ENaEc69>L_1kCgn<Oi1o]7mcOg5oLP02Og<047]B
Nc9k<W]BNg9kDW/`KZiNB6I[HVaJ;5X;HXmZdW^j9goo2Won00=ogWoMOmd00WoM00Iog7^lNkek_G^L
Ni/2Mi/00g=hFW4Xi`02100010P03408@0Q10PQ00`@P2@PP00@480PP220880T48088808<@003460@
H@aQ00<@H@07440<@11P464@PQ2346400`a000<<HA1R46400Q1Q00@@HQ1Q440@@08<@@03368<@@PP
008<@003364@PQ1P00888005364@PA1Q484@PP0236400`aP364<@@0234400`aQ368<HP0436801`aQ
340<@0aP460D@110008<@007344<H@aQ460<H0a022000Pa000L<H0aQ364DXQ21340<H@0246423642
360020PP340<H@aR48<@HQ1Q364222000`Q12408800534001@aQ340<@0a024000`PP00<8@0a03400
2@a00`Q00PPP0Pa000<<H0a034000Pa010Q000L<H0a0340<H0a024048002100522000`@P2208@004
340324401P@Q2448@@PQ2208@048@@0000=cVWNKMi/017NK00=gW7NKMi`00WNL0WNM00=gW7NMMi`0
0WNl0g^l00=g_7^lNk`00W^l9g^m00=k_7^mNkd027^m0gnm0gnl0goM0gnm57oM1GoN00=ogGoNOmh0
1GoN00=ogGoNOmh01goN2GoM0WoN00AooWoNOmiogP9ooPUogP05OmeogWoNOmiooP03Ool00gonOomo
oP02Ooh017ooOoioogon2Woo035ooWooOmekNWLGMcIoEWmEMaAc5GLEOgIoUW/cL_9Zd7LBOeAoMW/c
M_5V[g;bN^m^[gK?M_1flG/BOg=oMW]DNe=k=7]ENgQkMgMEMgMg=W]DNcIgEgmDMa=c4gLCOe5fl@03
M_<06GLCOcAoDgmaOg1kD7]bOiEkDg]BOe5k=7MENgQkMg]eOgAkDWnDOkIkDgLbNc=g=7ME009kN006
NeEkE7LCMcAkN7nH0Wmf01ik4gKcNeEkMG]BNg=k<gLDNaAk<g/bOgEoMW]gNgQkMgmeOgMkEWLfOiQo
UgmcOgIoMg]gOiQoVGnGOiP2NgL03gnHOgQkEWmFNeMk57mgOiQoUGnHOiUkN7nIOiQoUP02OiT01g/C
OgEoUWnDOkMo^GnI009oU`9kE`05NeUkF7mhOiYo^P02Om`047]GNgQo^goLOoeo^WLBMcAo^WniOk]o
_7]gOgMog7ni0WnJ02=oN7mfOiMoUgniOkQkMW;bNc5oMGngNi9kLFKbMe=oTgoHOiAoCWLANe5oKgKb
M_AflWLBNeAoMGnEOiAoLG/`Oe1oUGnH009oM`07Ne=kMGnGOiQoUWmdOe800Wmd015g57/DNaAg5G/d
NgEoUGnDOiEoMG]gOgUoN7nFOkUkE7MC009kM@0=Og9oLG/cKaIg=GLCL^m^cfj`L]1oCgnBNg800W]d
02ekLg]aOg1oL7neNe=^m7/cNe5o/WneOg9blf:?K]5flFZbHW5ZT7KbOk5o[7n]Ofmk<G]AOg1oT7ng
OgEg5GLdNg9oT7nbOe5bceh8IRYZSVI]HR]N;6kBOmd09goo2Gon00=ogWoMOmd00goM00Eog7^lNkek
_G^L009kV`07Lia_F4iA8<P000@022001@Q030PP0`@P10PP1P@P0PQ000@<@110464<H@@@H@07440@
H1AQ6:<@H@b2364010a000L<HA1Q464@HA22588@@0024442344232000`a0360<H@0236400`PP120<
@00236402@aP368@PA22484@H0aP340<@@06368030aQ464@H0aQ240@H1QQ444<@0a1368<@@8<H@8<
@00A320880a05:<@P`aQ464DPA1P340@HA22468<H@aP3408800234001PaQ488@PQ1Q340<H@8<H006
340880PP340@H0a00PaP0Pa00`Q000<480Q024000`a000L<H0a0340<@0aQ360<@002240422083402
24000`Q1364<H@0234000`Q022080002100522000`Q0340<@00434000`Q02448@@0324400`@P2208
@00124400003MiYgNWNJ00AgVP9gV`EgW003Mi]gW7NL009gW004Mkak^gNlNk`3Mk`4Nk`=Nkd00g^l
Nkek_@04Nkd2Nk`>Nkd00g^lNkek_@08Nkd2Okd00goMOkao_003Ok`2Okd00g^mOkeog@0DOmd4Omh0
0goMOmiogP04Omh2Omd7Omh3Omd00g^lOmeogP05Omd5Omh5Omd4Omh4Ooh2Omh2Ooh3Ool6Ooh01Goo
OoiooWooOoh02Goo029ooWoNNi]^mV:dHY=R/VZbI[9RTF:BH[5V[fJ^HV]RSFJ@HXmZ[fZ>HVaVKVZ_
JZebZW[/M/iV/6ZbK]9blWKbMa=^m@9Zm@0OLaAgE7LCJ]ARTeibI[5b[fZ^IXmVT6Z`L]1bdFZaHW5V
TVZaL/ifkfk>J]5^df[BL_5kD7LAK]=be6kDK]800g;B00IblfkcMa5k<7;aJ]<2I]D05VkdL_Ablg<D
McEbm7;cMa=flg;DJ]EV]6kCMa=blf[CK]A^dfkBL_=g<W<C0W<D00eg4W;bK]9^dg;cLa=c4G<BL_5^
lg;cLaEc4`03L_<2La@017LdMcEc5G;d0WLe00Ec4W;bL_Ac57Ld009g=@0=LaAbm7;bMc9kMGMCLa=b
lW;cLa9k=WLfLcL00WLg01=kMg^HOiUkNGMILcIgEW]hNiQgNGMGLcEgEW^HMeIc=G<GMcMkV003OkX0
2G^INgMkMW]gMcAc4g<BLc=c4P02K_<06FkbMc1g<6k`Ka9c<VlCLa5bl6[?L_5k4GKbK]=k4G/?Ma9b
lVkaM^mg3Vk>L_5g<W<C009g=00=Mc=c=7<dMeAkE7]eMc=g=7/fNeEkDg]eNe@00W<E03Ig=7]CNeAc
4fkeLaEg=W]eNeIg=7<eNeEgE7LcNc=c56leNe9oDG/=O`ek3gLBMc=kDgnANe=g=V[eLaAoD7m/Oc1g
4fkbMa9oDGn@Og=oDflDL_Ao4WlbL_=^m7;cM_=oL7m:N`mg4W;bNa82Ofd047/BK]=Z/GKaObioJgn@
Oc1fkg;@N/mfcg;@L[1RCGLd:7oo2Gon1WoM00Eog7nlNkak_7^L009kNP04Mi]_EdiB7:P210001PQ1
240880PP240<@0@880<480`880D480888005240<@0a0360<H@0846401122468<H@aP0Pa000h880a0
464@PAc47>@HXQ1P464DPa11320880`P0Pa000H<H@aR364<@0PP3642360236400a215:8DXP024600
10a0344<H@aQ10aR00H<HA1Q464@H@aQ460244400`a1364<HP033446340010aP364@PQB1111Q0PaP
0Pa00PPP00<<@0aQ46400a1P00H<@1B05:8<H@`P220334023604340224001PQ1340<@0Q0340<H0<<
@08<H08<@0D880P<@088@003244<H@aP008<@005240880PP2208000222001@Q02208@0Q034000`Q0
00<<@0Q024001`Q10@Q00@Q100000gMjMgUgNP02MiX4Mi/5Mi`00gNKMiagW002Mk`3Nk`00gNlMiag
_004Nk`2Nkd00gNmNkek_@09Nkd2Nk`ENkd00g^lNkek_@08Nkd2Okd00g^mOkeo_@03Ok`017nmNkek
gG^m67oM00=ogWoMOmh05GoN0goM1GoN00=k_G^lNkd01WoN1Gon00AogWonOomooP=oo`03OmmogWoN
009ooP=oo`03Ooioogoo00]oo`0:Oke^meicGU5VLF9aGTmRLF:BGU04GTh2HTl2HTh09F9?IY1VTF:A
HVmRCei@GW1ZTFjaJ[5^dVkDI]EZmVKfI]ER]6:cHY=RLV9@GRmR;V9=HW1RLF:BJY5VTF9@IU1VCf9?
ITmRKf9`009RTP05G[=Z/VJcHY9VTP02J[<046ZbJY9RTV:BJ[=Ze6ZbIY5RTFZbJ[AV]6[DK_E_5Fke
0VkD00M^mFlEK_A^e6ZdJ[=^/`03J]<00fkCK[=^/P02K]<01fkdL_Ablg;cL_AbmFkE00=bm@9c5@0;
LaIc5FkeK_E^mVkeK]A^/W;eLcMc>002LaL01g;eK]9^/VkdLaI^m6kb009c5@=c5P9c=@08LaAc5G<E
McIc5G<FLcMc>@9cF@=c=`07MeUgFWMJLcUc5VlELcL00WMI01Ec>7=HLeMc=gMIMgUkN7^JNgUgF7MI
LeQc=W<FKaEZm6KDI]E[56KeI]@00V[C00YVdfKdI_E[5FKeI]=R/V:AH[9Z/P9Z/`0JK[5Z/6JbI[9Z
/VZ`K[1Z/F[CK_AZe6[CK_E^m6KEJ_I_5VlfKaIZm6[eLaI_5VkdLaEc=P9_5P9^m006LaE^mFlFKaM^
mF[D0Vke00A_5VlgJaIZm@9^m00;McAc5G<EMa9flG/cLcE_5F[dI]AVm@02J_D02V[DJ[5RT6:@I[5V
/V[BMaA^lf[d0W;d00eblgKdK_=Zm7;dK]=Z/VZaJ]1R/FJbI[5VT@02K[0046JbJY5ZKVZ?I[1V/F[d
Na9^/7;@M_9fd6Y>LY1RLG]h:Woo1gon0WoN1GoM00Yo_7^lNkekW7]jNgUgVf/F@Nl@I0840088@088
8003240<@0PP00<88003120880PP0088808480L880L480062208@0Q0340@HQ221A1Q0PaQ00D<HQ22
464@HA1P00<<@005444@PQBT5:@DX`0546401110344<@@a00`aQ00L<H0aQ464<HA1Q488@HP023640
1Q1R488@PPaR364<@@8<H@04368<H@aQ364246401QBS588<H0aP364<@0<<@@03244<@@a10088@08<
@004220@H0a03402364030aR464@@0PP340@H0aP340400PP320<H08@P@<@@003460<H@aQ00<<H@03
464<H@aQ008<H@05360@H11Q360<@00234401@a0360<HA2246400`a000<<H0aQ34000`PP00T<@0Q0
340<@0a1244<@@Q124000`PP00<8@0QQ36000Pa00PQ010PP00H8@0PP220880Q03402240010PP2408
@0a00`Q100<<H@aR24400PQ00@Q100000gMjMgUgNP02MiX8Mi/01WNLMi]gW7NLMkak^`Yk_2Ek_@03
Nkak_G^m00Mk_@Ao_@03Omeo_Gnl009o_003Okek_G_M00iog@=ogP]og@IogP03OmeogWoN00aogP9o
g@MogP9k_@=ogPQooP=oo`03Ooioogoo00=og`03OmiooWoo015oo`04Ooik_G^MNg`2NgX01W]iNgYk
FGLiNeUkNP9kFP04Ng]oNgmkOg/2Ne/00g]kNiakO002Mc/017]JNi]oVgnK0W^L0g^m00MkWGNLNiak
O7]JNcUkF@02OgX2Og/017]kOg]oNgnJ0WnK00EoW7nMOiao_7nm009k_0=o_@=k_@03Okao_Gnm00Ak
_@=k_0Ek_@9og@Ek_@=o_@=k_@=o_@04NkeogGoNOmd9Omh00gonOomogP06Omh3Ool3Omh017ooOmio
gWon0goo0goN0Woo00MooWoNOmiogWonOomooP05Omh2Ooh?Omh01GonOmiooWonOmh00goM00EkgG^m
Nkek_G_M00Ik_@=k_P9k_@0?Okek_G^LMiak_7nmNkagNg^MOkeo_7nmNiagNg^L00Qk_@Ak_004Nkek
_7^LMi`2Mi/2Ni/3Mg/03gMjMeYgNWMjLeUc>FlHJ_Mc5gMIMeQc>6lHKaM^mP02K_@026lEJ_EReEje
G[ARe6KEH[@2GY800ejCFW5FL002FW42EU402eZBG[=N/ejCG[AReFKeI]ER]5jCFW<00UZC00ANTUjc
H[ANTP9JLP09HY9RTejCFY=FLejcI]AVdejC009J<@03FW=bmGoL02Yoo`MooP9ogPEog@0:Okak_7^m
NiakFGnHMi]VdcE;32<20002240<22000`@P22048007220812000`Q0340<H003488010aQ464@HA1Q
0PaQ00@8@0aQ484@P08@H003360@H111008<H@03344<H@a000<@H@06560@@0a1344<@0PP0PaQ00<@
PA2246800Q1P00@<H0a1344<H@@<HP8<H@03240<H@aQ008<H@08360@HA1Q5:8@PA1P340880<<@005
24088@a1344<@002360010a0220<H0a00Pa100<480@022000`a000<@H0aP46000`a000d<H11P460<
@0PP440@H0aP364<@0aQ464<H00234003@aP460@PA20240<@0PP244<@@a0220<@0aP008<@0D8@0<8
8004340<80`P3202220020Q02208@0Q02208@0Q1364236000`a02208800222000`@P220880052207
240224400`Q02448@002240124400003MiYgNWNJ009gVPYgV`9gW003Mkak^gNl00=g_0=g_@=k_2Ek
_@03Nkak_G^m00Mk_@Io_@=o_004Okek_G_MNmd=Omd3Omh;Omd6Omh00goMOmiogP0=Omh00goMNkek
_@08Omh01GonOmiogWonOol01Gon1goo00=oggooOol0o7oo00AogWonOomooPAogP04Nmek_7^lNk`2
Nkd01W^LNiYkVgnkNi]kNP9kV`08LeU_5V/GKcQ_FW=JLgUgV`Ik_09kW00@MkagW7NKMi]k^gNJMgYc
FG=HLgUgVgNLLg]_F7=iMi/2Mi`00g]kMiakg@0/Ool00gonOomooP02Ooh3Omh5Omd03WnlNk]k_7^K
NgYoVWMjHY0/a@@0000400PQ240322000`PQ2208800522021204220612022204120010Q0344<H@aQ
0PaR00/@HPaQ588DHPPP364DPa1R464@PQB100<@H@03364@H@aQ008<HP03344880a0008@H@09560@
@0a1344<@0a1340<H11Q008@HP03464@H11000D<@@8<HPH<H@03368<H@aQ008@H@05360@H0aP364<
@@05244010a1364@H@aQ0`a000X<H0aQ244480@0220<@11P364<H0H<@08<H003340800a0008@P@06
364@HAB2464<H0a00`aP00`@H0aP340880@0220<H0a0200880Q0340424000`Q12408800222023402
32042205240010aQ484<@0a00`PP0PPQ10@P0`Q00PPP0PQ000<8@@a034000PQ11@Q00@Q10005MiX5
Mi/2MiX00g^KMi]kV`02Ni/017NKNi]kVg^K0WNl0gNM0g^l3G^m00=k_7^mNkd03G^m00=k_7^mNkd0
1G^m0g^l1g^m0gnm00=k_GnmOkd01Gnl00=kgGoMOmd03GoM00=kgWoNOmd02goM1GoN17oM37oN00=k
_7^LNk`02WoN0Won0goo17onogooKGoo00=ooWooOoh00Won1goM00iog7nkOk]kVW]kNeUoVGMiIXhT
PP0010080@PQ2PPP0PQ000@88@PP220480D88003120880@P00<88004120880PP3442364010aR2448
8@aR0Q1Q00`@HPa1344<@@aQ464DXaB1564HPQB346823642468010aR464@HQ1Q0Q1P00D@@11Q468<
H@a1008<H@06444@@11Q464@H1110`a100@8@@@P220<@@@<H@03360@H@aQ008<H@@<@005364@PPaQ
3448@@0324000`Q1340<@00234001@PP360<H@aP24400`a000<@@11P24000`PP00@8@0a0340<H0<<
@009320@@11P364@HA21584@@0a000<<H003460<@0a000<<@0<<H0032408@@a100<8@0033408@0@P
0088@@8<@0<<800<3408@0Q0240880Q0220<@0Q0360<HA1P0Pa000H880PQ2448@@PQ220312022404
220010Q02448@0PP0PQ00PPP0PQ00@PP0@Q100000g>JMi]gV`0;Mi/3Ni/017NKNi]gVg^K0WNl17Nm
0g^m00=k_7^mNkd08G^m0g^l37^m1Wnm00=k_GnlOmd06GoM00=ogWoMOmh01goM00=ogWoMOmh02GoN
0WoM3GoN00AooWooOomoo`=oo_moofeoo`9ooP04OomooWonOoh7Omd02WoLOk]o^W^JNgYkF7]iLcQR
Kb1R0P@000<<8@PQ22400`PQ10@Q00D88@PP3408@@@Q00<480032208@@PP00888004100880@P1205
22000`PQ344<H@0334803PaR46<@HPaR344880a0364@HA22484DPAc44882364010Q0468HY1BT0Q1R
00@DPQ22464@H@<<H@06344<HA1Q464D@1AQ0PaQ0`a100D<H@a1224<@@aR00<<H@09368@PPaQ3648
@0Q13448@@QP008<H@03368<H0PP00888@04240880PP244434001PaP368@PQ22360<@08@H009360<
@0Q12448@0PP240<@11P008<@004320<@0a0460336001a1P340<80a0360<HA1P008@@003340@H11Q
00@<H@88@@032404@0Q0008<@003244<@@a1008<@004464<@0a0244424001`PP200<@0Q0340<H@a0
00<8@0<8@@032248@@A10088@@<8@003220480@P0088@@<8@00324448@PQ00888048@048@@0027NK
00=gVWNKMi`00WNL00EgVg^KNi]kVgNK009kV`05Nk]g_7NLMkak_002MkdSNkd7Nk`3Nkd00gnmNkek
_@03Nkd00gnmNkeo_@06Okd00goMOmaog00EOmd6Omh7Omd2Omh00goMOmiogP09Omh00goMOmiogP0;
Omh00gonOomoo`3oOomaOol6Ooh7Omd02WoLNk]o^W^JNgYkF7miK_I=kQA20P@000<<80PQ220010PQ
00<48@PQ12400P@Q00@880PQ220480<88006120880PP124480PP1@@P0PPP00@<8@a2464<HP8<@`04
46<<@`PQ244334400`aQ464@PP0246400a1R364@H@0236400a1R6:@@HP0246424680111Q340<@0aQ
10a00Q1000@DPAB2364<@08<@@05360<HPa1344<HP0636402`a1364<HPaQ244<H0Q0364@HPaP2400
0PQ10`PP00<8@0a036000PaP00<<HA1Q46400Q1P00D<@11P460<@0Q00088@@<8@0H<@004320@@11P
460236000``P220<@00236043400212148<<H@a02448H@QP2402244224022443344434000`Q12408
800522001@@P340<@0Q022000`Q00PQ10`PQ1@Q10PQ01PQ10PPQ00@4@@PQ240<@048@@0027NK00=g
VWNKMi`00gNL0WNK00=kVgNKMi/00W^k0WNl0W^l00=k_GNmNkd097^m1G^l2W^m00=kgG^mNmh00W^m
00Ao_GoMOmeog@9og1Eog@MogP=og@03OmiogGoM01]ogP03Ooioogoo0?moog=oo`03Ooioogon009o
oP03OmiogGoM00Aog@=k_00=Ni]gVW^INiYZeCe/204000@0320<8@a022001PPQ00<48@Q134000`PP
10PQ0PPP00<88@@Q12000`@P0PA000D88000320DHQ1R008@P`0946<<HPaR3688@@PP340@HA1R008@
H@04484@PQ1R46834643468010a1340@@1110Pa000<@H11Q46000P`P00<@@A1Q46000Q1Q00<<@0aP
36400`aQ0Pa100d<HPaQ364<H@aR344<H@a1364<HQ2248<<H@0234401@aQ468<HPa124400`PP00P<
@0aP364<H0aQ240<HA1Q0a1P00L@HA1P440<@0aP368<H@05340336001`a0440@@1B2464@H0a0008<
800:2208@0PP2208@0aR488<PPaQ220224401PQQ2448@@Q0364<HP@<@@03340@@0a0008<@0032448
@0@P00<880888@04240<@0`P2203240010a0360<@0Q00PPP00P8@0a0340<@0Q1344<H@a10`Q100<4
@@Q114400PA10PQ10@Q00@Q10004Mi/5MiX00gNKMiagW002Mi`2Mi/017^KMi]gVgNK0g^k0W^l0g^m
00Ak_7^mNkak_1Ik_@03Nkak_G^m00Mk_@9k_0=o_0ak_@03Nmik_G^m009o_@9og@9og1Iog@IogP=o
g@03OmiogGoM00=ogAEogPAooRQoo`03Ooioogoo01Qoo`03OoiogWon0?mooc5oo`=ooP03OmiogGoM
00=og@0?Omao^g^kNkakW7^JNkYgN6:C>D`80@@0228<80a000<88004120400@02243244010a02208
80PP0`PQ00<48@PP22001P@P00H8@0@P220400a04602464021B15:<@P@aQ468<H@a0460346402aB2
484@HPaR340@H11Q460<HA2346800Pa100D@@0a0220<@11P008DP@033208811Q00@@H@04364@H121
36043642368010aQ24088@a10Pa000@@H0aP360<H@@<@@06364<@@aQ3448@0PP0Pa000T@P122364<
H0a1240<811046000Q1Q00@@H0a0360@H0D<@088@006360DXQ21360<@0`P0Q1P00@DP11P340880<<
@08<@@074:<@XPaQ360880PQ14400PQ10PQ000L<H0aQ468<H@a1240<@002460236000`Q124048002
22000`Q02208800210022206240322001@a0360<@0PP24000Pa00PaQ0`Q100<8@0Q124400PQ10@Q0
0@a00@Q00004Mi/3MiX3Mi/8Mi`01GNKMiagW7NlNk/00g^l0W^m00=k_7^mNkd05g^m00=k_7^mNkd0
2G^m0W^l00=o_7^mNkd01W^m0Wnm0W^m0W^n00EkgGnmOkeo_7^m00Mog@03NmeogGoM00]og@03Omio
gGoN009ogP03OmeogWoN00MogP=ogAIogP9ooPAoo`03Ooioogoo01moo`03OoiogWoN00=ooQYoo`04
OoiofWoLOokoOol^Ool01WonOomooWonOmeogP9og@0;Omao_7nlOk]kVgNKMiYgW7=JFS</b@021000
10`R324<@@a00`Q110PQ0`Q110PP0PPQ2@@P0`PP00<<@0aQ36400QB200<DXQBS48800Q2200@@HPaQ
464@H@<@PP8@HP0:368<HA1Q468<H@aR46<@HQ11440246402`aQ464@HABS588<@0P0364@H@aR4680
0Q1Q00<@PABR48800`aQ00<@HQ2348<00`aQ00<<@@`P34000Q1P00D@H@a1344880a100<<HP04364<
@@a1344234001121364<H@aQ0PaR00<<HA1Q46400a1Q0`aQ10a00PQ000@8H0aQ364@P@8@H@03320@
H@aQ008@H@<<@00:364DP`a1244<P`aQ264<@@@P240524401@Q0364<H@aQ24400PQ00PaP00D<H@a1
3448@0PP00<8@003244880PP00<880H8@0888004320<H0aQ3402220010a1464<H@a11`Q10PQQ0@aP
0@a000000gNKMiYgVP04MiX6Mi/00gNLNiagW004Mi`2Mk`017^kMkakW7^L17^l17^m0W^l4G^m0W^l
2g^m0gnm3G^m0W_M4GoM0WoN0WoM27oN0goM1WoN00=ogGoNOmd00goM37oN00AooWoNOmiogP9ooP03
OmiooWon009ooP03OomooWon00=ooR]oo`9ooPAoo003Oo]oo7ok009on`9oo09on`9oo00>Ooeoo7oj
OoYoo7ojNmQg^GOlOmao^WnlOoeooPEooaEoo_mooa5oo`03OoiogGoN009og@05Omao_7nkNi]kV@02
MgT017NmKcU>4AaU0P@00P`Q00@88@a024088088@@<88@0322848@PQ00@88005240880@P12088003
12000`@022088002220224000`aQ368DPP026:801AB2488@PA2146000a1Q0a1R0`aR1A1R00X@HA11
460@@11Q488@PA1Q360<H@<@H@09364@HA1R468@HA1R488@H@aR00<<H@05344<HQ22488<HP023640
2@aP340@H11P340<@@PP120<@@0336800`aQ344<@@03340236400`a0344<H@0236401A1R464@HA1Q
46800PaR00<<H@a034000Pa000`@PPaP340880aP580DPA1Q440@H@aQ360234000`aQ360<H@023440
0`aQ368<H002100224001PPQ120480Q0244<H@<<@@032448@0Q000@8@08880H8@003224880PP00<8
80@8@0<<@003360<H@a00088800:340<H0Q0244880Q02448@0@P2442264324000003Mi]gVWNJ009g
VPAgV`05MiagVg^KNi]kW005Mi`2Mid00gNlNk]g_002Ni`5Nk`3Nkd3Nk`ZNkd3Nkh00g_MOmeog@0@
Omd3Omh00goMOmiogP05Omh5Omd5Omh5Omd>Omh4Ooh017ooOoiooWon0Woo00AoggonOoiooRUoo`0P
KgaNme9@=FTXi2C4:@LY1RTW<FXic3F[<FTeRSW;?L`iZcF:<FTeRcF/<H`]BBCV=JeSF7okOomgnf=j
=Jh]:@8aK00=<HXaJS5Z=J`i[3F;<FTeRSV[>J`iZcV/>J/00cF[00HiZcV/>J/i[3V[>J`3>J/00cg<
@Na23P02@Nd5@N`0248=@N`mk3g]@Rm6DDIaAU05BU000di?CU1:C`02BU001DH_BRm>LEJCE[<00eJA
00UF/U:BDY9BTUJeF]EF]5:BF[@00U[E1E[D00=NeF;eHaH00Uke00=NmUkeG_D00Uke00=W5fLhIeP0
0fLh00E[>6LhIcQW>6]I00=_NP03KgU_NW>K009g_006Lk]cVg>LNkeooGon17om00=oo7omOm`00goL
00=ongoLOm`00WoL0WoK00=ooGooOol01Woo00=ooWomOoh0WWoo00=ooWoMOmd00goM00ao_7nkNi]k
VW]iMeUg_F/IAM4DI0001002324010PQ340880Q00`Q100D<@@PQ22448@PQ00<88003340880PP0084
808880<48088800@2408H0a03408@0Q1368DXQc34888@0aQ464@H11Q468234400a1Q468@HP033682
46800a22468@HP0446424880111Q340<@11Q1a1R00D<H@aR368<HPaQ00<<HP06244<@@aR36<<HQ23
0PaR00`<H@aP340<@0a1240<@@aQ368<P`aR36443403364010a03648@@aQ111Q0Q1R0PaQ010<@0aP
340<@1BS6:<@@0P0340HXAS3484@H@a0364@H@8<@004364<H11Q464236802Pa1340800a0244<@@Q1
2248@0a10PaQ0Pa10`Q100@8@0Q122488@<880<8@@032408@@Q10088@@03224880PP00D8@08<@004
360<@0a02402220030Q13608@0@0240<@0Q1240<@0aQ3688@@88@048@@0000=gVgNJMiX00WNJ1GNK
00MkVg^JNiYkVg^LMiakW002Mi`2Mid00gNlNk]g_002Ni`5Nk`3Nkd3Nk`ENkd00g^lNkek_@0BNkd2
Nkh00g_NNmekg@0COmd:Omh5Omd2Omh7Omd>Omh2Ooh2Ool4Ooh017ooOmiogWoN1Goo00=ooWooOol0
87oo00Mk^eJC:BX89@01100800070003100222000`a02204000600002Pa1CV]ooGokKgT]:``1108@
A@a00PPP00<<80a034000Q1000<<@0`P34002Pa000@8@0a0340<@0@8@0@<@08@@0<<@0072408@@A0
1408@0Q134400PQ010a000<8@@a134400`a000@8@0a0364@H08<@003344<H@a100L<@@07364<H0aQ
344<HA2158800QB11aB200@@PQ21468@H@@@HP05348@HQ22488DP@0258835:<358<45:@011RT6:DH
aAS50QS40Qc400/PiBD69>DTiRD79@HU9RU89BPQ22DX008]B@<]B006;DLaJCF9>JY1jcg[0T7[00E1
bdG<=DaBCGo`09=oo`9ooP03Ooeog7oM009og@0<Okao^g^JNiYkNW]iLieVnSV>20<000P00PPQ00D<
80a0240<@0PP00D88@0322088@PQ00D88003120880PP008480@88005340<H0a03448@002348011B2
6:4DPA1Q0Pa100D@HA1R46<8@Pa1008@HP05464<H@a1340@H@02468346401@aQ464@HA1Q48400a1Q
1a1R0`aR1@aQ00@@@@a1220<@P<8HP05244<@@aQ360<@00536401Pb248<<HPaQ3408808<@006464<
H@aP344<@0Q00`a000H880aP488<H@a0220334002@aP364@H110340@H1RR7>@H``02464010a0460<
@0a10Q1Q0Q1P00H<H0a1344880`P3402364334402PaQ488<H@a03448@@Q02448@0PQ10PP00D88@Q1
244<@@Q000848003124880PP008880P8@08<@003240880PP0088@@032408@@Q000<<@006360@PA22
344880Q00@Q100000gNKMiYgVP02MiX5Mi/2MiX01G^JNi]kW7NLNi`00WNL0WNM00=g_7^kMk`00gNl
17^l0g^m0W^l5W^m00=k_7^mNkd047^m00Eo_G^mNkik_W_N00=kgA1og@]ogPIog@9ogPEog@iogPIo
oP=oo`9ooP03OmiooWoo00=oo`MooQ]oo`0:Jg]BM35Z88@D@10P44<@HaB36:@25:@011B3468<@@P0
0P@00`PP00<800@022000Pa100h<@0`P220<@A11200DP49?MiIFD33W500TQ1c50QbT00LHY1bT7<DL
aAc46:<LX`027<<27:<01ARS7<@HXac47<<00QbS00XL`aS36<<Ha1RS5:<HXaRT6:<HPP<HX`8LX`06
7<@H`aRS5<<Da1BT0QBS0QBT1ART00XDY1RT6:@HXabT7<@LXaRS7<@HY@8HY08DY08HY00358<HY1RT
00@HY0036<@HXaBS008HX`@HXP03684HXQRS008HX`0;5:<HXaR2584DHQB1564DPQB3588DH`0258<0
0aB2468@P`0258<24880111Q468@PQ220QB300<@P`aR36800Q1R111Q0QAQ1A1Q0PaQ00<@PaB34640
0Pa000l@HA22588@PA1P440@H1B16:4DP110300@0BB1Nfl0Tgoo0Won00AooGoLOmeog@9o_008Nk]k
Vg^KNiYoVW>LGYH/jP80000920088@PQ320<@0PP34088@PP00888@07244880PP220<@A1Q24000`PP
00<480PP220010@P0PPP00@8@0a0360<H@8<HP0<468DPQRR584@HQ11344@HQ2246<<@P`Q0a1R00/<
HA1Q444@HPaR468<HPaQ368<H@aR008@HP03464@PQ2200<@HP0458<@HQ1R464346803PaR364<H@aQ
220@HAAR444<80a23688HPQ22442344336402Q1R368<HPaR48<@X`aR364<@0P00Q1000D@H@aQ364<
HPaQ00888005340<H0aP360<PP05340236003PaQ464@@111464@PAC45:<@PPaQ340@@0a034424642
58800a22464<@@02220020aP364<@@Q1224<@ABT4682340010a12448@0Q10`Q000D8@@Q02408@0Q1
0088@004224480@Q124322000`PQ2208@00324001PPP240<@0a0364<@0<8@0032208@0Q100<<@007
344<HQ21364<@@a024000@QQ00000gNKMiYgVP02MiX5Mi/3MiX00gNKMiagW002Mi`01G^LMiegWGNl
Nk/00gNl17^l00Ak^g^lNkak_@9k_09k_@=k_0ek_@Mk_0Mk_@=o_@=k_@Ao_@03NkekgG_M00=kg@Io
g@9ogPIog@aogPmog@]ogP03OmeogWoN00MooP=ogP9ooP9oo`YooQYoo`08H_PTb@`2208HQQbT8<DT
i@8TiP09:@L]9bD78<DHY1RS568@HQ11008<800G344@@@a1344@HQRS7<@TiBdV;@HTi2C37<<Da2TU
7:84010P;@@]9RT69>HU1`02:@L00bD79>HU1P029@H012D59@HU1RD60bD70bD600<Y1RDV9@H00RD6
00<Q1RD69@H00RD712D600<Y1RD69@D012D600<U1bDW9@L022D70bTV00DY1RTV:BLY9bDZ008U2@04
9@PU:2D89@P4:@L012TW:BPY:2TX0RTW1RTV00@]9BdV:BHY9`8Y:0@Y9`03;BHY9bTW008Y9`04:BPY
:BTY:BP3:BT2:BP01BD69BLY9bTW9BL00RTX0RDW0bD700HU1RDW:BLY9bT69@D2:@D012T69@HPiB3V
0RD500@PiB3T8>@Pi0@Pi@039>@Thb3S008Ph`067<@P`abV20<LHF/@TWoo0Won00EooGolOmaog7oM
009o_00;Nk]kVg^KNgUo^W=kFU<TQ`00100@@00422001`Q0320<80`P2248@@Q000888004340<@A1Q
3443220010Q0220480@P0PPP00L480Q0220880Q0460@H@0246803A225:8HXQB2468@HA1R488DPQ23
468<@Q1R008<HP03364@HA1Q008@H`<@HP04340<@@aR364246400aBS484@H@064680111Q468@HPaR
0`aQ00T<H11Q468@H@a0364<HPa1244010a10PaQ0Q1R0`aQ00L<HPaQ364<@0PP460DPP0346400a1R
464@H@02464010aP220<H0aP0`a000@<H11P360<H08<H@05440@H@aQ364<HP02364234002A1P220<
@A22464<HA1R588@H@0334000a1Q3648@@02244334401PaP244<@@Q12408@@D<@0032208@0Q0008<
@0D8@0@88005240<@0a03408800334001PaP364<@0Q01208@0@<@008244<@@aQ3608@@@P240<H04<
H@0000=gVgNJMiX00WNJ00=gVgNJMi/01WNK17NL00EkW7NMMieg_7^k009g_0Ek_09kW004Nkak_G^l
Nk`2Nkd3Nk`=Nkd3Nk`3Nkd017^lNkek_G^m0W^n2G^m0gnm00=k_G_MNmd02WoM00=ogWoMOmd00WoM
3WoN3goM2GoN1Gon00EoogonOoiooWoo009ooP03OmiooWoo009oo`9ooP03OmiooWon00MooQUoo`08
OoiJ4Q`4300TR1cY7>HLaP@La@037:DHY1B3008HX`035:<DPaB300@DP`0C568@HQB3588HXac48@DU
1bD69@DTiBDV9>D@@@00220PiC5V;DD00Re70RT70RCV00@U1RD59@DTi@8U1P059@LY:2D78@HQ1`02
9@L00bDV9@HU1P039@H012D59@HU1R470RD712D600<U1BD69@H012D60bD70bT70bD70RTW00<Y9RT5
9@D00RDW00LQ:B3W:BTU:24Y9@PU1`02:@L00bT6:@LY9`03:BP3:BL00bDW:BLY9`03:BL00bT7:BPU
:@02:BT022TZ:BTY:2TX;BLY9bdW;BP6:BP01BdX;DP]:2TX:BL03BTX0RTW0RdW0RdV00D]9bTW:BLU
9bTW00PY9P8Y9`03;BL]9RdV008Y9P05:DLY:B37785Vl02BOol2Ooh3Omd3Om`2Nk`2Ni`02GMiOiYc
FUXb86@400P0440<@00232000`a0244<@00232001PPQ2408@0PP200<@0<8@@888@032208@@Q000@8
8088@00<220480a0464@PA2248<DXaRS5:8DPQ230Q1R00DDPQBS488@HQ1S008@HP8<@@8<HP8@H`8@
HP05464880a1368@H`0246800a22588@H@0546801122364@HA1R0`aR00L<H@aR368@Pa1R368<H@05
344234004`aP364<HPaR468@@0Q0344<H@Q1220<@11Q7>D<HPa0464<HA1Q008DPP0:464<H0aP3408
@0PP120<@0aP484246401Pa0344@@A1R46<<H@8@H@093648@@aQ460<80PP368@PPaQ00<@H@05364<
@Pa0364@P`0236801Pa12248@@Q13648H@@8@@03340<@@a000<<@088808@H00324448@Q10088@@06
2248@0PP240<@11Q1@a000@<H0a02408@@<8@08<@0063448@@Q1244<@@aP0`aQ0@aP0@a100000gNK
MiYgVP05MiX7Mi/3Mi`01G^LMiag_7NlNk/00W^K0W^l00Ag_7^LNiakV`9kW0ak_0Uk_@=k_0=k_@04
Nkak_G^mNmd2Nkh3Nkd00gnmNkek_@04Nkd2Okd01W^mNmeogG_MOmeo_@aog@IogP03OmeogWoN00Eo
gPmog@03OmiogGoN00IogPaooP=oo`9ooP=ogPIooP03OmiooWon01Ioo`0;OoioogooOoiN4aP6408<
8Q1T48<<HP0346<02Pa2468@HQB26:@HXaBS6:<HY1RS0aRT00/HXaB3588@HA11340@H1B26:<La1cT
008Li@0<7<D<@Q227<<U12e3:@<]9BT69@LTiRCU0bD500<TiB3U8>H00b3V00PTiRCW9>LU1bD68@HP
iRCV0bD500TU1RCV9@HU1RD79@HPiRD79@H012D500<U1RDV9BH00RD700<U1RD79@L00bD700HU1RdW
;BL]9RST9>D29@H03BD7:BLY:2DW8@LPibCW9@HY1RSU:>HY1RD700<Y1`8U1P8Y9`039@LU9bD7008P
iP089@PU2BTY9@TU2RD99BTU208Pi@039>HY9bdW00<]9`@Y9`8]9`04:BLY:2TX:BL5:BP01BDX9@PU
22D89BL00bTW0RTV00H]9bTW:BLY9RDW:BH39BH2:BH2:@H01RTV:BLY9bTW;BHYA`8Y9P06:DH]AbT5
9<9N[gomTGoo0Won0goM0WoL00Eo^gnlNkakW7]k009kVP03KcQB41a200880004440<@0a132033400
10`P324<@@a00`PP0`Q00`PP0P@P1@PP00H480Q02408@0aP464248801QB26<<LiAc4588DH`<DPP0E
584<@11Q468@PQ1R464<HPa2244480PP364@HQ1Q360@H@aR46<@HPaQ008@H@H@HP0358<@HQ1R00@<
HP03364<HPaQ008<H@03468@H@a100@<@@04340<80aP364236801PaQ344<@@a13408@@88@007488L
iQ1S220@H0a046000Q1Q00T@H0aP360<@0@0000400PP36000a1P00D@@0a1344<@@aR00<@H@0;360<
HPaQ460<@0a1364<H0Q0340<H@0234401Pa2344@PQ23488<H@8<@0042208@@Q11442244234453402
22001@`P460@H0a022401PQ02@a01PQ000@<@0a1344<@@<8@@8<@003364<H11P004<@00000=gVgNJ
MiX017NJ0gNK00=gVWNKMi/00WNK1GNL00=g_7NmMk`00W^L0gNl0g^L17^l00=k_G^lNk`00W^m00=k
_7^mNkd03G^m00=k_7^mNkd01W^m00=k_W^mNkd01g^m0Wnm00IogG_MNmekgG^mOkd=Omd3Omh00g_N
OmiogP0:Omh:Omd8Omh3Ooh00gooOoiooP03Ooh2Ool2Omh5Ool2Ooh5Omh8Ooh3Ool00gonOomoo`0@
Ool02GoNOomoogooEHlD1Q1458@HQ00558@258<00aBS6<@Ha@036:@47<D00aRU6:@HY00258<041B2
568@HQ11464DPQRT7<@PiB465:@@HQS47>@U12DT0RD500<TiQcV7<D01AcU1AcV123V00<Q1R3V8>D0
0bCU00@U1b3V7<DLa@<PiP078@HQ1bD68<DLaB358>D00b460R3V0R470R3V00TPibCW9>HTaB34:>DT
iR3V9>H00Qc500DPiB356:@LaB35008Pa0078:<PY22T8<DTiR357:@00R3600TLaAbU7<HLiQS67<HL
aac67<L00Qc800DDR1BX6<PDYaRW008LY`047:HPYRC79<H38>L01Ac66:DPaRCW8<D00b3600DPiR3W
9@LU1b4700LPi`049@HU9bDV9BH29@L012DW9@LU1R470bD60bTW00DY1RD6:BLY9bDW008Q1P079@HY
9RTU9>8HP4h/Oo/0TGoo0Won00=ogWoMOmd00WoM00Eog7^lNkakVgMk009kVP03JaM1SA00008800<<
@005320<H@aP340<H@0236800`a13408@00224000`Q122488@0822001@@P220880Q026000PaQ0a21
00DDPQBS7<@DPQB300<DPP0<564<811Q464DPQ23488<HQ1R48<DQ1230Q1R00L@PQ1R464@HQ1S468<
@@0246401A22468<HPaR46<00Q1R0Q1Q00<<HPaS36800PaQ00<8HPPP22000Q1Q00<DPQ1Q34400`a1
00@<@0`P460<H@8<@@05364<HQ1Q440<@00224401@00368DaQ2336400Pa00Q1P00<@H@aP32000Pa0
00D880`P240<H0aQ008@H@03460<@0a0008<@@03364@HA1Q008@HP8<HP06464<@0a0344<@0`P0`aQ
00D<@@a2344<H@aR008<H@06340400@P244<H@QQ0Pa10PQ10Pa000/<H@a0340880`P460DH11P3408
80@P00<48@D8@@03344<@0a000@<@003240880PP00<8@0033408@@Q000<8@@03344<H@aQ008@H@4<
H@0000=gVgNJMiX017NJ1gNK17NL00=kW7NLMi`00WNL00MkW7^lNkak^gNlNi]kW004Nk`017NlNkak
_7^l47^m1G^l3g^m0Wnm0goM00=kgGoMOmd02goM0WoN00=ogGoNOmh087oN0Won0Woo0Won0Woo00=o
oWoMNkd00WoN0goo0Won00IogWoOOmmoogonOmh9OohFOol01goOOomoogoNBD/D11B5008HY0DHY@04
6<DLiR3V8@H38@L01BD79BPQ1b3W7>H00Qc600PLiR3V8@HPiQc56:@DQ1RT0Qc400`Ha1cT6<@DXa1Q
588Ha1cS;DD]ARD58>D26<@01Ac57>@LiR3V8>D0123V00<Y1bTX:DP00bDW00DU9RD69>DU1RD7008Q
1`@U1`048@LU1bD79@L2:@L01BD6:BLYB2U8:BP00Re900<]JBe:;DX00Re:00LaBSE9=DTe:CDX<BPY
2002;BP2<BL2;@L2:>H01Rd6<BLe9c46<@L`i`<`iP0A;>H/aRc6<>Le1cD8=>Le1cCW<>H/YRR6;:L`
bC3Z=@/`j`02<>X023D;;:PTQbB79:HTabBU88D38:D022C5:>HTib367:DHYAc67<D27<H01AbV6<LH
YaRW6<L00QcW00DQ1bD79BHYB2e8008Y9`HU9`0A9@LPiR3U9BHY9bTV9BLQ1QcV9BHU9bU6:D@aHabP
?J]oo02AOol3Ooh03WoNOmeogGoMOkek_G^lNi]oVgniMiUNU3DZ100220000``P344<800232001Pa0
240880Q0244<@@<8@@0424088@PQ12072202120060@02208@0a0360<HA21584@P@a0344DPQB3468@
HAB16:<DHPa0464DHARS7>DDX`8@H@04368@HQB35882468246402A1R6<DDPa1R464DPAS458<@HP02
36804PaS364@H11Q46<<H`aR468<H@aR364<@0aQ464HXQ1R364<@@8<@007220<@11P360<@0PP3440
0Q1R014@@0a0220<@0Q0268DY@aR364<H0a0360<@0aP344<@0a1008<8009340<H1215:<@PQ1Q460<
@0a1008<H@05368<H@aQ364<HP0336400`a1340<@003340020aQ464<H@a1340<@@aQ3602340010`P
2208@1210PaQ00<<@@Q124000`a000<@H@a032000Pa000PDP11P340880@P224880@P0PQ100D<@0a1
344<@@a0008<@@8<@088@003224880PP00@8@0@8@@<<@04<H04<H@4<HP0000=gVgNJMiX017NJ27NK
0gNL00=kW7NLMi`00WNl00=gWGNlMk`00gNl2G^l4W^m1G^l47^m00=o_WoMOmd03GoM00=ogWoMOmh0
8WoN00=ooWooOol00goo00QooWoNNkek_G_MNmiogWoO0WoN17on17oo1Gon00AoogonOoiooQUoo`05
Oki12P`2104@@@0646<236<448<548@348<01aB458<@Pa1S48<DQ1BT00<DP`0B5:<DY1BT58<@@@a1
5:<La2E6:DD]ARTU8>DHY11R58@DYAcU0Qc500TLaQcV6<HHaQc67>LQ21cW8>L011cV00<Pib478BL0
0R4X0R4700@M9b489BPYB@8aJ@8aJP03;FX]BC5Z008eR`0J<H/aJcF;>J`iRcE:>DXmBT5ZAJa1ZSf;
?F/e:CU:@HY9beG[EL]9Ze6[EL]Mjf8=GLYIZP=IZ`0;HLaUkFG/KRibD79?LRe]jW8<KNaUc002JNh0
179AOY5nTWZC0W9c0ViB01AMcUF^EJi5Jd5:BFY5JTF;BJa9[D6<?Hdm[SF<=F`eS3V/=H`eRcF<0SF=
0SF<00<e[3W=>Nd00cg^00=23T8=APd00dH_0TH^00E63T7^?NdmcCg/00Lmk@06?N`ibSF9;BLi[Gol
TGoo0WoN00=ooWoNOmh00WoM00]o_G^mNiakVgnlNiYcN5Ic:<T400P000888007244<@10P440<@0`P
22000PQ01@Q100@48@@P120480@880032448@0PP00<880<8@003360@HAB100@DPP0B58<DPPa1584H
PQ1R344@HQB26:<Ha1B24648@0PP588HPQB20QB300<@HQ1Q46800QRT00L@HQAR588DXaB348<<H`02
48<01A22364<HQ1S36<00Q1R00P@H@aR368<HA1Q588H`aB30PaR00X<@A11344<HA1Q364@@0`P340<
H@8@H@05440<80a0344<@00534400`a0344<H@02364234001@`P340<H0aQ48800Q1Q00<<H0a03440
0PaQ00L<HPaQ368<HPaQ240<@@0236401@aP240480PP344010aQ00<<@@PP36400PaQ00@<H0aQ368@
P`8DX`8<H@03344<@0a0008<@003240<@0a0008<@08@H@03364<@@Q100<8@@88@003244<@0a000<<
@009240<@@a0364<@@Q1220480PP00@8@@04344<H@Q1240224413641264128<00003Mi]gVWNJ00Ag
VPUgV`9gW003NiagW7NL00EgW09k_003Nk]k_7^l00Mk_1Ak_@=k_0ek_@06Okek_GnmOkiogGnm17oM
0Wnm2WoM87oN00EooWooOomooWoo009ooP06Omik_G^lNkaogG_M1GoN17on0goN00=oggonOoh01gon
6Woo00I=C000000400P0100300000`@00000000=00001@@0000400@024400Q1R0Pa101H<HQ1R48<D
Pa11224<@1c48>DLi2TU=HH]AacU348000Q15:<HaAc46:@DP`8<@P03344@HQ24008@HP0C6:@LaAc5
6<DLiR479BLUB2DW8@LQ9R478>LPiRe8?La1jcF:<FT00S5901XaJSEZ=FXaJS5Y>HXmc47=?JdiK45[
CNmRdfKbFY9B<DgaCQ9ReG]hOm]ofW^KOi]og7ol7Woo0WnN021o_WoLOmikW7MkKaUVeeZgD[MBUEJD
F]=Fe4ibAS12<DZCD[=F/UkdE]=>LD8??Le1c3g;?JXiR3F7<FLeR3F70SF800@eRCV9=HTeR@8eRP@a
RP07<HTeQc5X7:@PaSF]Oo`0T7oo00=ooWoNOmh01GoM00Yo_7^lNiakNWnIMiYcEe8a88L800<<8005
220<80a0460@@00234001@Q02208@0Q022001P@P0`PP0P@P00D880@P100400PP0088@005220<@11Q
588HX`025:801ARS7<@DPQ2258400a1R00<DHQB258800QB2010@H@a1464DPQR26:<DXaBR588@H@`P
220<HA1Q588@PP8@HP8@P`0758<Ha122240@HQB346800a1Q00/<H@Q0344@HARS6<@@Pa1R368<HA11
00@<H@0@464<@110340@HA22464<@0PP340<H11Q344000@0220234000`a1360@H00534001@aQ464D
H@a044000Pa00PaQ00T@@11P484@PPaQ34488@PP24000`a000<800@034400PaQ0`a100`<HA21464<
H0a0364<HQ1R368@H@aR3642340232001@P0320<80a036400Q2200@<H@a1344<@@88@@04240880PP
2402340010PP1008@0Q10Pa000H<H@Q1240880@P2245244224032441364136<00003Mi]gVWNJ009g
VPagV`03MiakW7NL00=gW09gW@Ik_09kW09k_003Nkek_7^m02Ak_@05Okek_GnmNkeo_@02Nkd00gnn
Omeog@02Okd;OmdLOmh017ooOoiooWon17oo2goN00=ooWoNOoh00Won17oN00AoogonOoiooP=oo`=o
oP03OomooWoo01=oo`07OoioogooOomMm0P400000P@000P480@Q12048@@0000400010`0000L08@@Q
124000@Q2488@@02120222001`P0100400a1468@Pa1R00<DP`05568@HPPP100DPP037<@031c5:DLQ
1aBT468HXabT6<DDPaR358<88@8<800D7<DDY@a2424La1c58>DHaABT7>HU1RE9:DTUBB4X8@LPiac5
8<DY1`8]9`0G:>DTa2CU;BLeJ358:@L]B3EY<HXaJbe:>FTi1EI>HcMNmF<GH_MJUDidF_QW>002Mi/0
1GnlOk]o^gnlOoh01goo00=ogWooOol04goo01eo_goOOmiooWooMka[FV;hEYE:MD[HAWEJeUlFE]E:
LD8`=NlnLcW_AS1FdE:b@RlaRR3656<<8@@000L000@400L0000610000000000]BW_L67oo00IoggoN
NmiogWooNol4Nmh2Mkd017^mMkek_G_N0W^m00=g_G^mNkd00W^m00=g_GNLNkd00W_N0g^m00Ag_GNL
MiagW09g_@04Nkeg_GNmMkd9Mi`2Nkd00gNmMiacW003Mkd027NLMkeg_GNLLiagW7^mMkd2Mi`2Li`0
17NmLiacNg>L1GNm00IcW7=kMiagW7NlMi`2Lg/00gNKNiakW003Mi`01W>KLg]gW7NmMiacO0AgW09g
_@UgW004NkegW7NLOmh2Ool00gonOmiog@05Omd037oLNkakVg]iNgMgNV/E?Jh@A000320@@0<<@08@
H0@<@0<8@003220480@P008480D8808480@8800:320<@0a0220@HA22588HXQRS6:@26:<258824880
0aB348<@P`0358800aR2568DHP0258802Ac4588DXQRR688@H@`P340<@@0436804a1R488@PQBS6:<@
PPaP468DPQAQ464@PA1Q364880a1588DXa1R008<HP8<H@03368<H@aR008<HP06464<HA1P440@H122
0Q1Q00T<@@a0360<H@a1324<@0a134000P`P00<<HA1Q34001@a000@@@11P320<80<<@007460@811P
484@H@a034400`Q10`a000H880`P344<HA2348833442364234000`aQ368<HP043642340232001`@0
320<@0a0364<H0aQ008<@08<@@H8@@8<@0H8@@03368@P`aR0088@@032248@@Q10088@@032408@@Q1
00D8@@0000AgVgNJMiYgVPQgV`9gVP06Ni]gVg^KMi]kW7NL17Nl0g^l00=g_7^lNi`017^L0g^l9G^m
0gnm0WoM00=o_W^mNkd00WoM0Wnm2goM5GoN00=ogGoNOmh00goN1gon00=oogonOmh047oN17on1goo
0Won57oo17on0Woo00Ebna@:000000Q100@88@P48@P88@06340<80`P20088A1R0QB200hHXaRT5:<@
PaB2468880P0220HXaS458<8@A1R0Qc400THXbD6:BLLiQc56:DDY1B446800QB300<DQ0a258@00ac5
00THY1BT6<DPiB479@HQ1b3W7>L00R3600DLYBCV;BPeJCVZ008mZ`0I=HXeJC4X;DPaBC5Y;DXTiabS
<>8i0EiYG_=J]EJCFY9J]5JCDYAJ]FKgJaQkF7ngNiX00W=j0W^k00Ik_7^mNkekW7^mOml3Ool00g_N
Oomoo`0>Ool077_ONiegW7NJMiI[=fLFEW9FMEkFF]IBeUKFD[A>LDH^BRe1kT8A?U92DD8_CVi23CF:
8>H@I0PR1P0000<4000000002`000P@00P0000<aJGolOol03goo00=ooWNLNk`00Won00=kgWoNNmh0
0gNm0W_N00IggWNmMkeg_G^mMkd4Mid6Li`4Mi`2Mkd6Mi`00gNmMiacW004Li`7Mi`:Li`2Mi`7Li`2
Mi`017>LKg]_Nfmk0W=k0Vmk0W=k0W>K00=cNVmJLeX00g=k1G=j0g=k00=cFVmJKeX00VmJ0fmK0g=k
00=cFfmJKeX00W=k00I_NVmJKeYcNgNKMi`2Mg/017^lOoiooWoN1WoM00]o^g^kNi]kMgnGMiUZlSE;
104000P000<<@003360@PA1P00@<@0<8@004220480@P1006220212000`Q0340<@002340246024640
11B26:<Ha1B30aB200`DPA10468DPQ22368DPQbT6:8DPQRS6882588031B16:8DXAB16:8LXQAQ440<
@0PP244<@@88@004360@HA21464248801ABR6:<DPQ1Q58400Q1Q00H<HPPQ464DPQB346823440411Q
344<@0aQ368<Ha1R464<H11P440@H121584@H11Q0Q1000D<@0`P320<HA2300D<H@04344<80a03603
3403320346001A10420@H12146000Pa000<8@@a134001@a000<@HAB246400Pa100@<80a0340<@088
8003360DXa1R008<H@04464<H0a0344222000`@034088007240324401@Q02448@@Q134000Pa100<8
@@a024400PQ100L<@@Q1344<@@Q1344<@002244824012200009gV`EgVPEgV`9gVP04Ni]gVgNKMi/3
Mi`2Mk`3Nk`2Mk`5Ni`4Nk`TNkd4Okd2Omd01G_NNkek_GnmOmd00Wnm2goM2WoN00=ogGoNOmh027oN
00=ogGoNOmh00Won0goo00EooWooOomoogon019ogPIooQeoo`9ooP05OmeoogooNilHC00200022480
0`PR22488@071249224020`Q224<@0PQ348<HQBS5:@558<05Q23468<80a0464HaAd75:@@HaB46:@H
XaRT6:DHaQcW8BTQ21S658@@Q1230Q2400DDaAS58@HU1RDW008PiP8LiP0;6<DDYARU6<HPab3X8>LT
ic57=FTmc002AS003T7^>H/iRcV=>Jdmc3V/<D/Ta3TUBHMVREZbDU82DU403EIaFY9J/ejdG[EReVlh
NiQcNG=ILeYgW7NM009k_@03Okio_Goo00=oo`03Mkeoogoo00moo`08NkmgOGNLMi]gMflFI_EReP=R
m`0FG_MFeTjeAQ11kTh=ALe>DTYdBW=6LEJ?BPhaJRTX7<H400P1100<80a1460436400`a1340<@@05
34402@`P344@@11Q34480100@LYoo00@Ool00gNmLgYg_01DOol2Ooh<Ool2Omh3Ool6Oml3Omh2Ool0
17oOOmiogWoN0gon00MogW^LLe]k_GoMOoiogP05Omd2Nk`01W^KMgQoUg^JK_<a:@80008<80042208
@@a034453404240212000`@02208800522000`Q0340<@00234002PaQ460@HAAQ584DPQRS5:@@Pa1S
0Q2300@@PPP0344DP`8@HP06588LY1R2588PaAc40QB200XDPA22464<H1RQ8<@HPQ11340<H@8<HP@<
H@03340<HA1R008@PP0;5:<HXQB1584@HA1R3688@A1R464@PP0246803Q1Q468@HA1R464<HPQ1368@
H@aQ440<811P364246400`aP340@@00234001111364@PQ220PaR00@@HPaQ364@H@8@@004340<@@a1
444244000a1P584DP@0244001a1P464@H0aP340<@@`P00@<@006364@HA11340<80a00Pa10Pa00`PP
00<@H12246800Q1R00D@P`aP340<@@Q0008880042408H0aQ24452407244010Q0340<@@a10Pa000<8
@0Q134400`a100@<@0a1340<@@88@@033448@@Q100@8@0488@0000=cVgNKMiX01GNJ17NK0WNJ00=k
VgNKMi/00WNK0gNL17Nl0W^L0W^l0W^L1G^l4G^m0W^l1W^m00=k_7^mNkd01g^m0gnm00=k_GoMOmd0
0goM1Gnm3GoM17oN1WoM2GoN00=ogGoNOoh01Woo0Won00AogGoNOmiogA5ogPEooR=oo`03;>l00000
0088@P0322888@PQ00@48@0322448@@Q00/88@8<@@8<@P8@HP0>48<DPQB358<DPQ22588<@11Q348D
YCG<<HPHY08@H`08464<@@aS36<DYAS67<HHY08DY08@Q00;5:DU:2U79BHYARTV9@DPiAcV6<DLiP02
8>H06Ac67<LTj2dZ>Ja1bcf[>H/aJRTY9@PaBCV==Fhicd7]?LhiSC59?JU5jeY[CU1><eIB009B;`07
GY5N]6:eI]EVeVKfJcL00Vlh00I_>G=KMieg_WooOml2Omh<Ool00g>KOoioo`06Ool027NNLgegO7NK
MgQc=f/iJaP2IaL066;fG_MJeeKGBU=:3dW]@Le1kdXaAS96D5J>EU0i[CEY:@D@@@`Q344<H@a0460<
H@8<HP<<@004440<H@aQ3643344234001Q10240000`0APUoo11oo`03MiegNg_M07Uoo`05OoiogG=K
LeYog002Ooh5Omd2Nk`01W^KMgQoN7MHI[0XaP800008420<80Q0244<@0Q0100480<<@0072208@0a0
3408@0PP20000`PP0PQ00PPP00<400a0340010a000d@HARR6:8HPQB258<@P`Q236<<P`Q2240@PP02
5:<01A22588DHQAQ56800aB200T@PQ1Q340<@11P684LXQRR56400a1R0Q1Q00@<H0a0464<@@8<@006
468@PQB17<8DPAAQ0Q1R00H<HQ1R468@P@aQ3682468011AR468@HQ1R0PaR0Q1R00T<HPPP100<80a0
360@H11Q440011110`aQ0a1Q00H<H@aR464@HA1P340334403a1R464@@1AP584@@@`P200<@@aP364<
H0a0220<800234000a1P440@@00232000`a1340<@@03340236000`a0460@P@023642488010aP240<
@@a00PQ000D<H0Q04888@0PP00@8@0042208@0Q1340224400`Q0340<@003344234000`Q03448@@02
24401`a0244<@0a03448@@a10088@@88@0448048@048@@0000=cW7NKMiX047NK17NL0WNl00AgWGNL
MiakW0Ak_003Nkek_7^l009k_11k_@=k_0Ek_@03Nkak_G^m00Ik_@9o_@Ak_@03OkiogGoM009og@=o
_@iog@AogPAog@YogPAooPEoo`04OoiogWnmOkdEOmh017ooOmmoggon7Woo00=ooWooOol00Woo00A1
/`0000048P888P888@L48@<88@0422048@@Q1243224324401@a1348@HQ1R46<00aB301<DXaB3588D
PQAR3488@RU9?LPU1a1T348<@@Q134<@Q1BT6:HHY@0258@0212436<@PaBU6:DLiR3V7>H28>D03QcV
7<HLiQcV8@HY:2TY:B/aC3F=>JdmcC6<<DX2:@P04bD8<DTa:BeZ?O11kdH?@LhaJSg=ARm>CDi@DU9F
DU8`@JaJTEZc009R]@09I_MW5f/hLcQReEjdIaM_67NM009oo`04OmigO7MlOml7Ool00g>MOomoo`09
Ool07G_ONkikWGNKMeMg=gLiNi]kVW=kJcUW65kGE]IBLdh`BNi5cTh?DU5:<4Y?EVi:;cU/>FXTiA11
34400PaR00H@PQ1R364<@@QQ240234000`a1440@@00336402@aR364<@@aQ344000`0BPYoo@0@Ool0
0gNmMi]kg@1kOol01gMkKcMofgooOoiogGoL009og@0>Okak_7^lMi]gVW^IKcIB3QA2000400`P220<
@@<8@@8<@@H<@0033608@0PP008880032248@@Q10088@@0:224800PP320<H0a0220<811Q6:827<@0
0aB3348@P`0248<0312T5:D@Q1BT7<DDPQ2358<@@AAQ688DPP@@PP0:468@HAAQ684LXbD6588@HA1R
58<2464236802`a1444@@1B1488DHAB16:8DPAAR4440111R00P@PPaR468@HQ1Q6:<DPPaR0Q2300L<
HQ22468<HP@P100<@00222001110464@HA1Q0Q110Q1Q00P8@111568@H@a0468@Pa220Q1Q00H<HQ1Q
344<@@aR4682460246401@`0320@HA1Q36400PaR00<<H@`P34000PaQ00<@@11Q464010a10`a000@<
@@aR488<H0@<H@03360<@0a0008<@@06364<H121488@HPa00`Q000@<@0a1344<@08<@@03364@PPaQ
00<<@08<H@04344<@0Q0244222400`Q1340<@@0334400`Q12408@@042441224114800003LiagVgNJ
00AgV`QgW0AgV`03MiagVgNL009kW004MiagWGNLNid3Ni`5Nk`00g^kNkak_002Nk`=Nkd4Nk`4Nkd3
Nk`5Nkd3Okd5Nkd00gnmOmeog@0BOmd4Omh5Omd7Omh6Ooh3OolMOmh00goOOoiooP02OohIOol00gon
OomooP02Ooh2Ool015XF000000@R10PQ1P@Q00<88@@Q22000PPP1P@Q00P88@PP224<@@a2468@HaAS
0QB300@DXaRS58<DP`8DPP0D34888QB2<DHY:1B5468DHQB358@LaB469BTPiaR4568<HQ1S58@DP`8D
Q0056:DLaB3U9>DPi@037>H0:R3V9@LY:RT/>M4]KBe/9@TTabT9<D/]:Re;>HeFDE9_@PlmkdG_@Lde
JSV^BU5F/5JBDW9BDTG_ALaFCejbH[AReFLGJcQ[>FliG]IFLF;CIaMcO09oo`04OmicO7oONmlDOol0
7GoONkigNgMFLcMc>7=IMgU_>6KgG]IJ]UJeEY9BDDhaBS1BLUkDF]ABT5Z>@L`a:RCW568800a03640
0PaR00@<@Pa13448@@8<@004364<@@a14405364236801@aQ100<04X:OoX02Woo00=ooGooOol00goo
00=ogWNKNmd0Ngoo00]ogG=EOkQoogonOmaofgomOmao^gnl009kV`09Ok]kVFlFALd@8@00200@@0`P
00<<@@04244<@0aQ360534000`aP2208800222000`PQ2448@@02244422003`a0344<HA1Q584DPQc4
6:<DP`aR36<@Ha2358@@Q00248<021BT5:<@Pa1S344DHQB25:8248800aB2584@H@0246802QB26:<H
XQB2568DHAAR468@HA220Q1R00<@HA1P58000a1Q00<DPA1R46400PPP00X<@@aQ364@H@aQ344<HQ1R
488@HP@<HP04464@PPaR348434400`aP580@H@0546401`aQ444@HA11440@HA1R008@H@8<H@05464@
HPa2344<H@02460246401110444DPQB10PaQ00D<H11P340<@@aQ008@@08@H00;364<@@a1364<H0a0
2208@@a0344<@00334463402344336400`a02448@@043442340010PP100880Q00Pa000@<H0a03448
@0<<@00422088@Q13403344010a0360<@0a01@Q10@Q200000g>LMi]gVP02MgX2Mi/9Mi`01WNKMiag
VgNLMi]gW09kW004MiagWGNMNkd4Ni`01G^lNkek_7^lNk/017^l0g^m0g^l27^m0W^l1g^m00=k_7^m
Nkd00W^m17nm1G^m00=o_GoMOmd057oM1GoN0WoM1goN0Won1Goo00=ooWoNOkd05WoN0gon0WoN00Mo
ggooOoioggonOomooP0JOol00gonOmioo`02Ool01FJH400000@132400`PQ00D48@PQ22488@@Q00<8
8@P48@888@88808<@@04468@HaAS58<36:@458<01a1S348<82349BPDY112008DP`0A58@DY23V9BTU
1abT58<<@Q1S58@HY1R37:DHYAc58<DY1@029>D27>H081S67<DHYB4Z<O4UKBU=8<TXicE:?LdeS2e/
=Hdi[CW<?PlmkTG_AL`m[3F<?Nm23TY`E[=BLTh`DU5JTUkEH_H2IaP026/iLeUcVfmKKcQ_=W=FMkd2
Ool017oNMkikog_o5Goo00MgWGMjMeEc5fliJcUVm`02GY@03ejeF[EF]E:CF[ENef;gHaMW5ekfHcIV
cd6Z:<L@I00210000`a0344<@@0234432442340010aQ468<H@aQ0Pa00Pa10`aR00D880@03019jWok
00Uoo`03Nk][>7_M00Aoo`03OmigVg^m07]oo`0GOmac47McOoiogGMiNiYk^golOm]o^g^KNg]o^g^J
J_E1S0`P100<8110320<@@0324400`a0344<@@063402220010P022488@PQ0PQ10PPQ00X400PP2208
80a0364@HAB1688DX`8DP`0748<DPa1S468<@@a236<00Pb30Q2300L<HPa248<DPQRS5<@DP`024880
3A1Q340@HQ2248<DPQ1R564HHB3V7<D@HQ23008@HP8@PP03484@HA1Q00<@H@05344<HA1R368<@@02
46401111468@Pa230PaR0PaQ0`aR00DDPa22368<H@aR008<H@03464DPA1Q008@HP06444<@@aQ440<
@@aQ0Q1Q0Q111Pa10Pa200@<@@aQ464@HP8@H@04564HXa1Q364246400a1P364<@@0234000`aQ464<
H@03344236400`a0220<@0033405344234023442340010aQ344480Q10PaR1Pa10PQ100<88@PP2400
0Pa00P`P00@8@0a0320<@0D<@@88@@063448@@aP3408@@A10`Q10@Q200001gNLMi]gVW]jMgYgNgNK
00]gW004Mi]gW7NKMi`3Ni`00gNLNiakW005Ni`017^lNk]k^g^k17^l0g^m0W^l47^m00=k_7^mNk`0
1G^m0Wnm7WoM17oN00=ogGoNOmh00goN17on0goo00=ooWoNOmh00WoN00=ogGoNOmh057oN27on0WoN
00=oggooOol05goo0gon17oo00Ek>bP2000000a100@88@0312488@PQ00L88@H48@0<120880PP324<
@A1Q468DPaR37<@LaARU0QB40aB300P@HA106:8PiQRT468@@Q1R0`a100LHY34V7:@@H`Q234<DQ002
6:@01AR458@LaAc59>D00R3U0R3V01DU1bTX:DXa[37?:HlYKb4<;@PmRT7]@L`eRcE/>JdmcSg_CU1B
D4h`@Nh00Sg>01=23TY>H_9RmEkDFYAN]5jeH]IVmf/iKgYofWoMKcUW5W^BOkQk_002Ool00goMNmio
g`0FOol027NMLeYgEFlgJaQW6F;hI_L3I_H045[EBS96447`AS1:;eI`F[9N[fk^CN`a:11S10088@a0
10a10`Q130a000H@H@@P000@84X<Ood8Ool017nkFW=><WMi17oo00AkgGNKMiaooWUoo`04OoigMfZ_
K`l2Ood04UjdEW=kVWolOm]k^g^KMg]kNG^II[8iB@P0100<8110340<8@888@052208@0Q13408@003
34001@Q0220880`P22001PPQ00<4000010000P@P00T880a0460@PABS58@DY1BS48<00QB30a1R00@<
@Pa1368<@@<@HP0:48<DPQB2488@HPaQ464@HQB2468334401A1R464DHAB25:<00Q230a1R1A1Q0QAQ
00<@PA2246800a1R0a1Q111R0`aQ00H<HQ1R468<H@aP240234400`aR464DX@0246402Pa1340@@A11
364@@A10584DPQ1Q0P`P1Pa10`a200@@Q11R364@H@8DPP06464<HA1Q464@H0a00Q1Q00@DPQ22464<
H@@<@@@<@003360<@0a000<<@08<@@08460<@0a0320<@0a1340<@@88@@04364@HQ1Q340334423680
0`Q12248@@0324000`PP340880033404344224401@PQ124480Q0340010Q10@Q00@Q100000gNLMi]k
V`02NiX2Mi/00gNLMi]gV`03Mi/;Mi`4Ni`00g^KNiakW002Ni`5Nk`00g^LNkak_003Nkd3Nk`GNkd3
Okd:Omd3Omh3Omd2Omh<Omd3Omh00goMOmiogP03Omh01GonOomoogooOoh00goN00=ogGoNOmh057oN
00=ooWoNOmh01Gon0goo0Won8Woo00Eo^cB5000000PP00h88@H48@888003224<@@a1008@HP0358<H
PaRT008HY0035:@DQ1B4008DP`0?488<@@PP58<PiQRS448<@Pa1444HPbCU<DLPiQ1T00<DY@076:@H
YARV6:DLaAcV8>D00R3V00/LaB36:@HaJ3F/<J`][Bf_:K0Q;RT:008]B@0T=FTiJSV<?Le:<4YABU16
3cg=?Je1kT7_APm>;eJbHaEW5EkEFYAJLeZBI_IkVgomOkUoVg]lNgIkLGnhOkak_7^KNiak_G_N3Goo
00=gW7=LOmh017oo01akgg=LKc]cFW<gJaMRmfLIH_MReUjdH]IRmUJDAQ0mcSF<;FX]B2CU=DM:36J<
DPdiB@a210088@D<@@<8@@04340<@@a13445340020a1320<811Q120001A0CR`9Ool017^LBHa1K7<f
17oo00Ak_WNKMiaogWYoo`0;OkQbcFlAOoeoo6kC@HmJ]7oEOoek^`02Ni`01gmiMgQND2S6000400a2
008<H@8<@@88@@0=2408@@Q124488@a13408@0PP240<@0PP32400PPQ00D<@@Q124488@@Q00<48006
220<80a0484DaABT0QBS00LHaART58<@HQAR588@PP0258801Q1Q344@PQ1R48<@HP8<@@8@HP8@PP8D
PP03468DHQB200<DPP05568@HQ1R48<@PP02468646401AAQ464@PQB248800Q1R0Q2200@@HA1R468<
HP8@HP<<H@05344400Q0368<@P0222001`a1368DPQ1Q468@@@a0008@@@0:344@@A0P560@H@aQ340<
80a1364334401Q1Q364<@Q1S58@@HP8<HP05488<PQ21488@HP0346401A1R464DPPaR36401@a11@a0
1PaQ0`a0010@H0aQ364<H@a1244<@@Q1468@@A1Q444<@@aR468<HP8<@@88@@D8@08<@004484@PPa1
340234401`Q1344<8@a12448@0a100@8@@48@048@@0000=gW7MkMgX00W^J00=kVgNKMi/017NK00Ag
VWNKMi]gV`IgW0AkW0AkV`04NkakW7^LMk`4Ni`:Nk`>Nkd00gnmNkek_@05Nkd4Okd9Omd2Nkd00gnn
Omeog@06Omd3Omh7Omd2Omh4Omd027onOomoogooOoiogW^mOmdIOmh9OohVOol01Gon@@X000002000
3@PQ1P@Q00P88@PP220<80a1348@HA1R0QAR00@HPaRT6:@DQ08DY00958<@PQ214684011Q9@HLiQBT
008<@P07568HY2CV8>HLaARU6>H00RDX03DPiQRV6:HHQAc68@PY:2D78>DHYABU8<D]@bU6;FTYRc7>
9I0I3B3[7:HPabdX>H/i[47]ARe23Cg;=FX]:C4Y<FTeS35[=H`mcU9>H_1NdeZCDS1NTVKDJcMcNWMi
KcUVmf;CNe5kUW^J009kV`04MgYkW7^mOmh;Ool03FmlI]UZfG=JOmeogW^lJcYNf5[GH_Q[>Vlh009[
5`0DIaQVmUjdGY=FLE9ABPlm[35Z:@LHPP`P660TP466GT]=jc46200400L<@@04244<@0a034023445
340234401Pa03648@000641FK@Uoo`05Mge=[T5;I]Eoo003Ool017^mMg]kWGoONWoo01=ooGL_J_9o
nGomMaI1L4h?Oi9ooGoMNkakW7njMgMF3bB5100<800246801PaR344<@@a0240<@0@8@@03344<@0Q0
00<<@0888006240<80a0464<@@Q00PPQ00X480PP344<@A1Q6:<LiQB458<DXP8DX`086:<HPQB1584@
H1B1588HX`8DPP04468<HPaR4682488558801AR2588DPQB2584011B200@@HQ1Q340<@@L@H@@@PP<D
PP<@PP064688@@aQ364@H0a00Pa100L<@0PP220<@PQ1224<HP0546800a1Q468@H@0234404A10560@
HA1Q364<H0aQ3408@0a1340@H11Q468DP`aQ24000`aR00@8@0aQ484@PP8@H@05340@HQ1Q484<H002
344232000`a0344<@00222000`a0344<H@0236400a1Q364@H@033400111P488@PPaQ0Pa10Pa000@8
00`P564@H@8<@@06364@PPa12448@0Q10PPQ0PQ00Pa00`aP0Pa010a100<<80a034000`a10PQ10PQ0
0@Q100001WNLMi]gVg^KNiYkV`IgV`03MiYgVgNK009gV`EgW0AkW0AkV`03Niag_7Nl00Ag_09k_0Ek
_@Ek_1Ak_@04Nkik_G^mOkd9Omd01GnmNkek_GnnOmd00goN0goM1GoN1WoM00EogWoMOmeogGom00Ao
o`04OoiogGnmOmdJOmh9OohROol02GonOomoogooOoiMSP@100080002224010@R22488@@Q20PQ1@@Q
010880PQ224880a1348@HQ1Q564DHQR37:@LaQS65:D@Q0<@P`0:46<<@Pa17<DU:1c558<88@`P58<2
6<H01QB436<DYAcW6<HDY08HY@0A448HYB4Y;DPY1bD77<HPibD6:BHU:2E::H`]cRF`3:/HbP029@P0
12TY<F/i[Ch>0SW<00HiZbTX:>L]1cf/?Nh2>L`044G^CPeFL59aCS1JLF:bH[=VmF;FFW9F<UYdI[Ak
E7Mg0gMi00AcFWMkMiak_Paoo`05OmmgNW<iMe]_>P02J_T06FllLgek_G^JKcM[5V;EH]IReEjdFW5B
D4W_?LliSBe:8:H@8@`P520/XT5UHV]9jbC5008400<<@P@<@@<<@0D<@@<<@008344<H@aR3648@@00
761JK0Uoo`05NieEkdf<FTiom@03Ool017^nMeYgVgonNgoo01=kMf[eOkIonW]HCK1Ak7nBOoaog7^l
NiakVg<eCNhL@`P0444@H@03344010Q1340<@0a00Pa10PQ100D88@Q0344@HA1P008<@0042408@@Q1
34424642220020@P124880`P464@HQRS5:<258<011B258<DPaB30QB200PDP@aQ364@PQBR5:<DPQ22
0a2300<DXaRS58<00QB200DDPAB2588LiAc4008DPP03564DPQB3008DPP03564@@A1R008@H@03484D
XQB2008@P@8@PP06584@HA1R488DPAB20a2200<@HPaQ36400`a000H<@@a2368@HPaR348336800`aQ
344<HP0246801AB2468DHQB36:<00Q1Q0PaQ00<@H@aQ36000Pa100P<@11P440@H@aR464<HPaQ1@aR
00P@HQ1Q464@H@a0464DPPaQ1@a100D<HA1R364<@0a100<<H@0>368@HA22464@@0a0460@PQBS488<
H@a1364@H0<@@004564@H0`P3202344224401PPP120880PP2248@0L<@0<<@@07324<@@a0344<@0aQ
36800PQ10PQ00@Q1000017NKMgYgNWMj17NJ17NK0WNJ00AkVgNKMi]gV`9gW0IkW0EkV`03Niak_7^l
00Ik_0Ik_@Ak_1=k_@05Nkik_GnmOkek_@02Okd8Omd2Okd017oMOmiogWoN0goM0goN2WoM0Won0goo
00=ogW^mOmd017oM27oN00=ogGoNOmh03goN27on8Woo00=ooWooOol00Woo00AVE@P3000400888@03
12888@PQ00L88@L48@888@840004340@@A1Q4642568021R378@HYARV5:D@Q123368346<031A168<]
B3V76:<880`P568@H`aR248<@P8@HP0n368DHQRT46<<@QRV:FXaRBD79@PU1be8;DTU223Y6>TM2BE[
:HlHkBD;9>HTib3W;BTeRcW=>L`e[35Y:@PXicE9@NeFTEZ_BU1>D4h_BNi=kE9@EY5NdUjcG]AN]EIC
DS=JMF/ILcMcEgMGLeQgNGMjLeY[>VKjKeYog@9oo`03Ooioogoo00Qoo`0MNimR^e9fFYIZmg]JOk]g
V7meK_AVeEjeFW=FDEI>BNi:4D8A?O4i/2dZ200401A29:A1R6:=CPdTa`021003348434400`a0344<
@0033444340234401`aQ468@HPQ1000H@5j<00Yoo`04GU5=RE77Om43Ool017^nNg]ogGon?Woo0gon
0Woo0gon3goo2Won6goo01=ooW^IJ_Ig=gMGI]AAd4g8Kc5onGokNiYkNgMjK_91JQ0R100<80023400
10a1324880a00P`P00D<@0a13448@@Q000@880033408@0a000<8@0<880840005124400@0460@PP02
58801QB3588DPQB348<@PP8DPP07488@HPa0364DXABR6:<00Q23010@PQB2588@HQ1Q468@PAB0460D
PARR7:<HXQB2564DPP8HX`08488@HQ1Q468@HA22588DP@<@P@06584DXQBQ564@HQ220QB100H@PA22
588DXa223602340244001a226:@La1BT468<HA1Q00<<H@03348<HQ1Q008@HP05464HPQR3464<@002
36001AB26<@@PPaQ34400Q1P0Pa000X<HA1Q364@HQ23468<HPQ1224<@@<@H@<@HP03348<HA1R008<
@@03364@PQ1Q008<H005468<@0a0364<HP024880111Q444<@A1Q0Q2200D@H0`P220<8120008@H00;
564DP@a0320<@@a03448@0@P22088@0212000`PP240<@006340234401`Q1344<@@a0344<@0a100@8
@@4<@048@@0000EgVgMjMgYgNWNJ00=gV`05MiYgVgNKMi]gVP04Mi/5Mi`00g^KNiakW003Ni`017^K
NiakVg^L1g^l27^m17^l4W^m00Ek_W^mOkek_G^n009k_@03OkeogGoM00Eog@9o_@04OmeogWoNOmh3
Omd3Omh:Omd017onOomooWoN0WoM87oN27on9goo00M^na@Y000400Q122448P092247124322402PQ1
444@HAAR468DHQAQ68<HQ1R50QB5014@Q0aR344@HQ1S56<D@Q119@I1Z2T778D<010R20440@PQ008D
HP0?68@DPa1R68<LaAS56<HYB369<HXU:BDX9@PQ1acV008Li`067<LPib4:9@/Y:RdX0Rd700HaJCF;
=Lde[36;;DT2;BP03CEY?J]23Ti@CY9>LDi@CPi9ZeI>DY9F/U[D009N]005FW=NUF;iIcU[>002JcT0
36mKLg]cNg=kLiecFfKEG]AcVgooOmmc_@Moo`03Okio_GoO009oo`0LNiaVTeX`FY=[>GmgIW9RLeYC
EU9>3dh=CPi>DT8B?Q56Dd7=:8@D8QR59>I5bf:_BPlLb000120234800`aR344<@@02340234400`a0
344<@006340020a1364<H@aR220001a0H/h:Ool016kFCJeAR7MF0Woo00AogWMLNg]ogQ]oo`03Omik
gGoO00=oo`9ooP04Omik_G^lNmd4Ooh3Omd6Omh02G^mNkak_7oMOmik_GNLMi]k_002Omd2Nmd2Nkd2
Nk`02W^KNkaogGoNOmek_7^LNkeogG_M0g^m00AgW7NKOmeog@9k_007Mi]k^goMOmak^gNJNk/00WoL
00Ik^g^lOmek_7NKNk`3Omd017^lNi]kVWMj0g=j17NK00mgNW=iLgUcNGMiNk]o^G^ILaQJU5YBFS5A
cTF6G/l00Wok00ao^G^JMgUZdCD7200400`0340<@@a0464234001@`P340<@11R34400PQ110PP1PQ0
0`PP00P400001208@0aQ464@PQ210Pa100<DPQBS6<@00QBS0QB311B200XDXQS36>DDY12S488<H@a0
344@PP8DPP04584@@1AP584246800a23488DP@025:<23682468448801121488DPAB10QRR00XDHA1R
488HXaB1484@HQ2248<@HP8<@00:320@@A1058<DY1B3488@HQ1Q3604364236801`a1444@HAAQ588@
H0@0008<@009488DXa2258<@HA10460@PQ1R008@H@8@HP<<HP04240880aQ46823640111Q468@HPaR
0`aQ00<<@@PP340010aQ00<<@0a136400PaQ00@<@@`P344@HP<<H@09360880@0320@H0aP220<@11Q
008@@08<@005344<H@a13408@00224400`a12408@006340424400`a1340<@0023203244224012440
009gV`9gVP0:MgYgVgNKMi]gVWNKMiagVgNJMi/6Mi`5Ni/5Ni`00g^KNkak^`03Nk`;Nkd3Nk`6Nkd0
0g^lNkek_@0;Nkd00gnmNkek_@03Nkd4Okd4Omd2OkdBOmd4Om`00g_MOmeog@0AOmh00goMOmiogP0>
Omh8OohVOol01Gno::d000@032402@PQ1@@Q00@88@@Q22448@888@0W244<@@aQ468DHA1R220<81R2
7:@HYABU48D@P`a1364@HQ1S68<DH`P0300LY34Y7:L80P@1204000PQ464DPaRS58@@HaAR6:@LaBCU
008aJ006:BLU1bCW7<LHaR3V0R4602PLib3W9>PY22TY=HXm[47<>L/mc3F/;F/U:2e:=HXmRT6Z?JXe
JS59=H/mkD7^@La5ZUI;EY9BLTiACPmFDF:dI_MW66mJJcQW66<IKeacN`=gW09k_005Ni]_>F;GI]UW
6`05Ool017NoNiiV^WMm1Goo021o_7]lJcYR]UhcDO55d46]?Jdi[4H@AS4n44IAC[=>D3f<:@XY:S5[
BRmR[d6/58D000PQ344<HQ1R364<@1103@a000P<H0a134440000741VcGon2Goo00Yg64V?CFURTGoj
OmQ_5W<kOkeog@9ooP03OmikgW_N00Akg@9k_0=kg@=k_@=gW0Ek_@MgW0=k_008Ni]gVWNKNkak^gNk
NkYk^`9gVP=gV`04Mkak_7^lNk`5Mi/01gMjLgYcNW=jMiYkVgNJ009cNP=gNP03MiYkVg^k00MgV`03
MgYgNgMk009gNPAgV`0;Ni]k^g^kNiYgVGMhMgUgVG^JNk]gV`02MgX2MiX02g^JMiUcN7=HKeMcEflg
KaI[5flGKcL00g=H01I_>6lfJaE_5VleLeIkUg^JMcY9d3T=DM1AcDf7EVakngoiOkMoVGMiJ[0/a084
0008320<@@a1340@H0Q0340880D<@003240880PP00<880<8@00422088@PP240222002P@0240<H1B1
6:8DXQ21364DPQR20QRR00<L`aB258<01AB20QBR00@H`aC35:8@PP8@HP03464DPARQ008DP@0@460<
@11Q464<@@PQ340DPARR588<HPa1468@HA2258424880211Q364<@11P6<8HX@a03443468021B1468<
HPaR2448@0a0344232000`aQ468@HP034642460020aP460@HA1R3648@0a0444346401@aP340880aP
36400PaP00<<@11056000Q1Q0PaQ00h<HPa1220<H@aR364<@@aQ368<H@a0344<H@aP10a10`a00PQ0
0`a000@880a0364<H0@<@005364<@@Q1244<@@03340020Q1220880a0344@H0aP440232000`Q02208
80022408340424401@a0364<@@a022000PQ000@8@@Q02408@0488@000WNK0gNJ1GNK00=gW7NKMi/0
0WNK0WNL17^L17^K1G^L0W^l00=k^g^lNk`00W^l2W^m0W^l5g^m00=o_G^mNkd00W_M0g^m00=o_GoM
Omd00WoM0goN1GoM00EogWoMOmeogGoN00=og@05OmiogGoMOmeog002Ok`2OmdTOmh2Ool3OohYOol0
134_000400PP2@PQ0`@Q0`PQ10@Q00L8@PPQ100<@Q1S3448800210004aR38:<LY1BU46@<@PPQ344<
HQ2358<8@P@0000402T8:BPDYP@200<0000?340LaARS6:@DQ0a2444Ta46W<DH]9b3V6:@DQ1RU008L
i`8Q1`0;7<HPaRC6<F/]BRe9=HXmc3W==J/aJP029@L06S5Z=H]1bdG<@L/eJS5;;BTaBCV/CPe=k59?
CU5BLE8`EU1NLVKFJaQW66/iKcU[6F;hJe/2Lg/02WNKMkakgGoMNkagNgLiJYIVfG_o17oo00A_GFJI
I]YgWPQoo`0HOmm^n6KHEWE5lCg??Nln<Ch`>Pm2<4jcDY91l36?=HhicTibF[0a:@P3000880aQ0PaR
0`aQ10a00Pa10`aQ00/<H0a0340<H11P440<@0P0000H86;=00Yoo`09Mea9/DTZENaJ;UjAJ]Ao_7on
00AogPAoo`03Omik_G^l009gV`07Miak_G_MNkeogW_NNkd00W^n17^m00EogG_MNmeogW_M009k_@06
NkagVg^lOmeogWoM0g^l0W^k00Ik_7oMOmeogG^mNk`3Nkd00g^lOkeog@02Omd3Nk`00g^kNkak_002
Nk`017^mOmeogG^m0W^l00=k^g^lNk`00W^l00Ao_GnlNkak_09o_@03NkakVg^K009kV`04OkaogGoM
Omd4Om`00gnkOkao_002Ok`2Nk`00gnlNkak^`02Ni/3Nk/07GnlNkak_7^kNi]k^g^lOkak^g^JNk]o
^g^JNkYo_7oMM_MJ=4g@ENm5AdgYJeMof7^INgUgF5i>86800P@000X<@0a1344<8110340880Q03408
@0@8@@03240880PP00<880042408@@Q022432402220030a0460DPB437>DDXQ2258<HPQR37<@Ha08D
X`0358<DPQB3008DPP8@H@09488@Pa234:@@Pa22468DPQRR008DPP04564@@AAQ468246400aAQ6:8D
PP02488010aR468@PQBS0Q2200X@HPa12408@1217<<DP@`P1008@P8@HP03588@HPaR00D<HP8@HP05
488DPQB2464<@@03464020a0460@PQ22368@HQ1Q46824644364434001@aP464@H11P464010aR00@<
@0PP368@PP<<HP06348<@@a0320880@P0Pa100H<@0Q1340<@0aQ3604340236401A1R368<@@a03440
10aQ00<<80a134400`Q000@8@@a1364@H@8@H08<80<880032408@@a000H<@0083648H0Q1120000Q1
3448@@888@03244<@0Q100<8@04880001GNJ00=gNWNKMi/027NK00EkVgNLNiagVg^L00EkV`9kW09k
_0=k^`03Nkak_G^m00Ak_@03Nkak_G^m00=k_@=k_003Nkek_7^m011k_@05Okek_G^mNkeo_@02Nkd2
Nmd3Nkd5Omd2Okd017oNOmeogGoM0goN0goM0goN2WoM8goN;goo00M9/`00000800PP200880042240
0`@Q22488@021243224412401PPQ100400a134880084000=124@@Qc4<BHHY1BU46<88@Q1468@PaRS
36<00P0003/40DH?Lc11[AQ5100000P07<@]B2e77<DDQAR56:HPi3fR:@<HYA1T6:DTiac648@HaR48
8@LLib3W8<HHYART9@HaB35X;FTYBBe9<FXeRcf/?La1c4G<@La1l3gA=Hi1keJBGXiFCTh?CS1JTV;e
H]AR]6/G009_>@03JaQ_FG=J009cFP0<Niak_7oLOmao_7^lOkeogWooOkekWW_N1Goo0W^N1Woo01eo
oWnlMg]kNg]KKcYRnEkHF[MF]TYCATl]RTH^CW1JU4iD@Q8icdHaD[=J/2d9004000@0220<@0aQ00@<
@@03340<@@a100<<@@@<@0@@H00544040000741VkP0:Ool027^oDQA9KEX>FU1N]7]gOodUOol00gon
Oomoo`08Ooh2Omh2Ooh4Omh5Ooh6Omh2Ool4Ooh4Omh3Omd01WoNOmeogGoNOoiogP9og@03OmiogGoN
009ogP=og@04OoeooWonOmh3Ooh00goNOmeog@0=Ooh2Omd00goLOkao_002Omd3Ool04WnoEQ=9SCT6
@FMRlgniOmQkVG<ECNdD@0P0220@@0`P220<80<<@@04240<@0Q0340234401@Q1224880PP24001@PP
00D88@PP2208@0PP008<@00:460DP1RP7><Li1BS58@HPaB35:@25:<26:<011B348<DPQB20Q2200H@
HPaR368<Ha1R488258800a22468DPP0256801QB26:<DPQR25:8DP@8@P@8@PP07464@PQBR488@HQ22
48<00Q2200HDXQBS484<@0PP368246800a22468@HP0336803Q1R464@HQ226:8HXaRR564@H@aQ464@
H0a03602464246801QRS6<@@HPPP360<@08<H@0@360480Q0340@H1B1460@@0PP344<HA1R364<@0aQ
3682364236800`a2344<@@03344010aQ344<@0PP0Pa000D<H0Q0340<@0aP008<H@07344@HA1R364<
80PP24000`aP00@8@@a1344<@@8<@009364<H0a0364@H1AP340<80Q000<8800:240<@0a1344@H@a0
240<@0aQ360224402@@P2448@@Q022088@a13408@@03340132000003MiYgVgNK00AgV`03MiagVgNK
00MgV`=gW003NiakVg^K00AkV`=k_003Nk]k_7^l00Mk_@03Nkak_G^m00=k_@Ek_15k_@03Okek_Gnm
009k_@03Okek_G_M00=k_@03OkiogGoM00=og@=ogPUog@IogPAogBAogP9ooRaoo`08OoioogooHSH8
0000200<808880L88@848@<88@@48@84001<200DHabT7:<LaBT7:BPY9be8<DLaJ2TX9@LLaQRU7<HH
aAc47>LU2A1T8<QoogoiOohm:`@0200HQ358<JXaR2e8:BP]:2e9<HTaQRe79>HTibe9=H/eZcF;<H/e
cCW^=JdYBRT8:BPaJSV[?L`iRSF:>Je1kTH`CW=BLTX??J]5cEZCF_MJf5kgG_IRmUkADTm:3dh>G[<2
G]D03f;gJcU[66KgJaQ_FW=kMiYkW7^mOkeogGnlOmaooP02Ool017onOmmogW^L3Goo01ao_G=IJcYR
mfKhJc]_G6/kIaYNn5JeEY=>LE9_BS11kd7`BS=:<TYAE]ABLBd9104000P0344<@0d<@@03340<H11P
008@H006464<@P00000PH6/?2Woo00MkWdhDENm^lgmGMeMkV@0]Ool4Ooh5Ool4Ooh00gooOoiooP05
Ool2Ooh00gooOoiooP04Ool00gonOmiogP06Omh017onOomoogoo0WoN17on00=oogonOoh01gon00=o
ogonOoh01Won0WoM00=ooWomOoh00goM0Won00AogGoLOmeogPAoo`0AOeaAdCCWAFMVm7oHOoak^f[e
@H`<00P0344@H0`P3248@@043442340424400`PQ2448@00:220040Q0340<@11P560DP1BR6<@DY1RU
9>HHX`aQ5:<DPaRS0QB30Q2300X<HQ226:@DPP@P368@Ha1R48<@PP<@HP03588HPQB100<DPP05488D
XaS3588@H@0348801Q21488@HQ225:<DY08@X`034:@@Pa1R008@H@03368@HQ2200<@PP0348<@PQ1R
00<@H@056:<HXQS36:8DH@02464246003@a0364<HA1Q468DXaS46<D@HQ11360<HA1Q008<H0052408
80@P460HXP02464246834640111R464<H@aQ0`a100<<80a134400`a10PaQ0Pa10Pa000<<H0a03400
0PaP00<<HA1R46400PaQ0Pa100<880a136000PaQ0`aR0Pa110a000P<@@a0460<H0a12448@0a10PaQ
0Pa000H<@@a0340880Q034423642244226401PaQ244480PP2408@@8<@04@@04<800000=gVWNKMi/0
1GNK00=gW7NKMi/01WNK0gNL00AgVg^KNi]kVPIkV`03Nk]k_7^l00Uk_0Ak_@Ik_11k_@Mo_@07Nkeo
_G^mNkeo_WoMNmd017oM00=ogWoMOmd01goM1goN0goM2WoN1GoM5goN00=ooWooOol0:Woo00aooWoo
Oomg61P000080110320880PQ220<224312403`@0444PaC4V?HI>CEZa>JXTiAB358@LaB3T8<@LY004
58<011cV7<HLYRe/0goo00Ebn1@0000DHb3U008Q1P078>DTiBd59@DQ1BD69@L00RCV00`Y1Re7=FPa
J2e89BPYBB4X8>HTiRD6;DP2>JX0635X;DP]:2e8;DTaJSF:>HXiJSV;?JdicSg??Ni23TH_@NdiRSEZ
@La:3Dh_DU5:<@9><@9>400;EW9NeEkDG]ENeUjeH_Ic=gMfMgQgN@02LeT016mJJ]Q_5WoL0Won019k
_G^nNie_6VKII_YgNgonOomoggMkJ_MReejDEU=9lTXBCU@2E[H01UKFCW96<DH@@NleJ`8Y2@07>H]6
3Di@@Nh]:AbU42400PP000<<@0aQ344010a100@880a1344<@08<@@04364@H@aQ364246001Pa02200
0000981_<0Yoo`08Nii>55H?McAongnjMgIooS1oo`mooP03OomooWon011ooPQogP9ooPAogP9og@Ao
gP03OoiogWoM00Yog@03OmaogGoL00Eog@04OmaogGoNOmh4Ool02eif?BU9ZFlgOoQonWNJGY@a2P@0
20000Q1P00<<80a1344010a100<<@0Q024000PQ00`Q100<8@0PP220010PP00<8@0PP22000PPP0P`P
00<@H1AQ56400Q1R00@DPaRT:BLU1@HDPP09468<HQ2358<DXaBR464<HQ22008@HP8<@@03464@PAR1
008HX@07688DPQ1Q488DXQS35:<00Q2200<@PA2248800Q2200@DPQBS6<@DX`8@P`0346<@HQ1Q00<@
H@05468@PQ2248<@PP02464232001A1Q584HPQRR58400a1Q00X@H0`P460<HQ1R464@PA225:<@X`8@
HP0<364@H11P3408@0aP240<H120384@HQ1Q0Q1R00<@HA1R46400Q2200H<H@Q0220880`P36424643
34403PaQ368<@@a0240<@0Q0340@H11Q484DPQ22444634400`Q0344<H@03368030aQ340<@0aP3408
@0PP340<H1223448@@8<@08<H004340880Q1344234001PPP3408@0Q1340<@@8<H@03464<@@PQ0088
8004240<@0a0460134000003LiYgVgNK00MgW0MgV`=gW09gV`QkV`05Niak_7^lNkag_002Nk`00g^m
Nkak_002Nk`5Nkd2Nk`3Nkd00g^lNkek_@0?Nkd7Okd2Nkd01G^nNmikgW_MNmh00WoM0WoN1goM<7oN
0Won;goo00MoVRP0000401103208800<22404@Q12244@@@Q224801AR9>HY9CVYHaIBTc5Z46<88@P0
32000Q1000T400002208@@a234<@I0a314D00goo00UonScW000000a15:@@HA1132000PPP01l<@A1R
36888@P0224<HQB258<@PaS57@LDY@a222088@a25:<HXabS6:<LY2368>LQ1RCV8:@LXbC5:@PY:@02
;F/02S5Z<HXaJ2T89>PY235:>JdmcCg>0T7?01a1[Cf<BNmFLUZdG]ENeV;FI_I^mFleMgUkVg^mMi]_
>FlHJ]AooGooOmikgW^nMiecG6[iLe]og@9oo`05OmmcO5kFEU=B<@03CQ405DhaDWAB]DZE?S8n43F<
:@TPYaR578DLPbST>FTaBBdY=DPY1aA1200@@002344336400`a2368<@P0434400`aR48<@P`023680
0a1Q340<H@0200000bBPLe5oo`09Ool027noDSEB3fleOoiog7MEOmdaOol>Ooh2OolBOoh8Omh2Ooh2
Omh2Omd00goNOoiooP03Ooh00goNOmeog@04Omd00goNOmeog@0<Omd2Omh3Ool03gMmDSA5JTg[LeQo
fGoKKeUFMBCY100880a0464<HP0234400a1R344<@0023404240224400`Q022488003220524022202
32001A1P564@H11046400Q1R01PPiR3U588DPQB3588HPQBS5:@DPa1R58<@Pa225:8@PQ23468<H@Q0
220<@12258827<<01B3T588@@AB248800aB30Q220aBR00L@PQB25:8@XaBS48<<HP0224002A1R464@
HA1R368@HQ23488@P`0246400`a1340@H@0258400aB2584@P@0346401P`P464<HQ1R460DPP8@PP04
48<<H`aR364246000a1Q484@P@02364010b1388@PQAQ0Q1R00<@HA2248800Q2300<<HPQ124400PaR
00@@HQBT58<@HP@<HP0>344<@0a0340<H0a0460@HABR58<@HP`P220<@@@<H@07368<H@aQ368DY122
36400Pa000H<H@a0220480Q034032442344236400`a03448@@0234400`a0320<800534001A22468<
@@Q1240010a00A1P0@aQ00000gNJMi]gV`07Mi`<Mi/8Ni/00g^LNkak^`0;Nk`2Nkd3Nk`ENkd3Okd0
0goMOkeo_@02Okd00goMOkikgP03Nmh6Omh8OmdFOmh00goMOmiogP0COmh3Ooh_Ool01Goh><L00000
44000P`P0PPP2PPQ0PQ00188@@PQ224881Q1:<</i3V:E[E:DRD858DHY1c49@HHY11R368248<258@0
1Q1T34<40@01BTeokP9oo`08J[@80`00100HYAc558<DH`8HY0047<DU1B4V7<D248<36:@01Ac58@HU
1QcV6:D00QRT01dPaB3U8>DU1RD79>LPaB3W:BP]B3EY>HXiRcV/>JdiSCV]?Ni23dH?@O0aKC5<@M1B
=5IBCS9FUEjf009N]@0:H]MW66/iJcU_>GMHMgQkVW^jNk/2Nk`017^kNkagNWMj1Goo00=oggnnOol0
1Goo00=k_VlJI_P00V/H01Q[>6mIJcUS65kFCYE2=48B?NleK2dZ9@TPj2D7<DLiJC479:<a13U77:<<
00a0344436443444364010a1244<@@a10Pa000D8@000000TP7=A00Yoo`08NgeBEDh?KcEong^ILcEo
gC9oob9ooP]ogP03OmeogWoN00=ogP03OoeogGoM00Iog@03OmiogGoM00Aog@03OmaogGoM009og@03
OmiogGoM009ogP9oo`0>Ng]VmdW?AFUF;7=hOoUog6mJEUDPZ0@0320<@0<<@@03244<@0a0008<8004
2208@0PP2205240010PP340<@0a00`Q000T<@0Q0320880a0440@HAAQ584031B200DHXaBR564<HA22
00<DPP8@PP@@HP0:488DPQBR6:8La1BS588@H@a14682588248<01QBS5:8DXQBR488@HP8@PP8@P`06
468@PQ23488<H@a10PaR00H@HABR5:<@HQ1Q44434642584258801ARS588@H@`P46400Q1R00<@HAB1
46800Q2301H<H`aR464<H0Q0220DPAS3488@H11Q360DPAAQ468@PQ1Q240<@0aR488<PP@<HP05588D
PaRS58<@H@04344334034600211Q484<H@a0200880a1460436401Q1Q488@PQ22364<H0@8@088808<
@0032408@@Q100D<@@8<@005244<@@`P3208800234001@Q0340<@0a134000`Q010a00A1P0@aR0000
0gNJMgYgV`03Mi`017NKMiagW7NL1gNK0gNL0WNK0g^K00=gW7^KNk`00W^K00=kW7^lNk/02W^l0g^m
0g^l5G^m1gnm0WoM00=o_W_NNmh00W_N0goN00=ogGoNOmh01WoN0goM;7oN0Won;goo00AooE6=0000
008<80T88@0312488@PQ00888@<8@@0:224801QQ;:</XSf:DW@m[bC78<D27:D01B3W8@LM1acW6<D0
0QBT00LHYAc67:D<@PPQ661g]P02Ool037onAHh<01026<LLibD78>HLaAc68>HYB0<aR`08:@LTiRCV
:>HY1bU8;DPY:08U1`0@:@P]:35Y?Le1kCg]>J`iRcF<>J`mcCV/@Le:<4iABS42AQ005dX@CU9BLTiC
CS=B<eIDFYENU5jfI_Q_FVmjKg]cVg^lNkeo_GnlOi]k_7oMOoh00Woo00EooWoMOi]gVgoN00Eoo`03
NkicOGoo00Ioo`0:Omio_GnKNiacWG>LJeQNeU:ECW@2AS<03dHAAO11l47a@O0eSCf[BLa1JBB2:<@e
B1bT440@H@0236801A1R364<HPaR34400PaR00H<@@aQ364<@@PP224234400`aQ3448800200000bB0
Mi9oo`09Ool027^NDSEB<G<fOoakVW<dOod9Ool00gonOomoo`0[OolCOoh00goNOoiooP05Ooh00goN
OmeogP04Omh2Ooh01GoNOmmogWoNOmd01WoN57oM0WoN00=k_7oMOoh00Woo01Ik>UXaBJa1B5j>OiUo
o7^lKcU5l@a500080110344880a0240<@0`P340<80@880<8@08<@003360<@0Q000<8800=240<@0Q0
240<@11P464@HQRS7<<LiAS45:@011B300<DPQ1Q46400QB300DLiARR588DPQ2200<DPP0348<@PQ23
008@P`8@PP03388@PQBR008@X`045:<@PQ1R48<248801123368DXQS30QS40aBS11B300hDXaS45:8@
PPaR364<@@aQ488@Pa1R464<@@a00Q1Q00@DPAB2584@PP8@HP8@H@0C364@HQ23488DPAB28>HDP`a2
368@P@aP220<@1215<<DXQ1Q44000a1Q0Q1R00<<H@a0240010Q100@<H@aR488@H@8@HP04488HXa11
344234000`Q1344<@0023603464236423444364236000`aQ360<H00236023403240222000``P360<
H@02244234400`a0344<@@02344236401P`P2208@0a0240480888088@088@@042208@0a046423401
26800003MiYgNWNK00=gV`03MiYgVgNK00EgV`03MiYgVgNK00=gW003Ni]gVg^K009kV`03MiakVg^L
00Ek^`=k_09kW0Ek_0=k_@9k_09k_@Ak_19k_@Eo_@03Omeo_Gnm009og@AogP9og@QogPIog@9ogP03
OmeogWoN02=ogPAooRmoo`04FO<<1@002002324@224210003AaR;:<``d6[DU<aC2C668<DHaB46:DD
Y1BU008Ha@0:6:DDY1S47>HPiQbT448402e7Ooh2Ool047nI924401RW8<LLaR357<DLaR3W9@LY:35Y
<HTaJ2TW0bT700<YB2e7:BL00RT8010Y:Be9=H/mc47/@Ne1k3g]>J`e[3V/?Ja1c4G]ANi1k`=6400@
BS5><E9bEW9FDUICFWAN]F;FI_M[>G=kMi]gVGMiMgX2NiX00g^KOkaogP03Ool017oNOkec>FmI1Woo
00=k_V/lOml01goo01YooGoLOiaVnEZdF[0mc47@BU=:<T7bAO99lDhBBS9:4T8@ANm>3Tg[::<LI2S5
78<<811R1PaR00<<@@a236800Pa100<88@Q124400PQ10Pa10Pa20P0000<X`7oEOol02Goo00QgOTXE
EU=c=WoLNi]gEWol2Woo00AooW_MOmeooQmoo`03Ooioogoo00Uoo`9ooP9oo`EooP03OmiooWon009o
oP03OmiooWon00IooP04OmiogGoMOmd6Omh2Ooh3OmhKOmd2Omh00goMOoeoo`02Ool03G]JFS19RTF6
H]1ofGolNke_63f>108000@000X<@0@88004240<@0a0340422000`@01208800222002PQ0340<H1B2
468@PAc49BHPiABS0QB300DDPQB3588880aQ008DP`056<@La1R2588@HP03588548<02aBS6:<@PPQ0
484@PaBS5:@DPQ2258801a220aBR0QB20QB300DDPQRS5:8DPARS008@HP03364@HPaR008<H@04368<
@@a034424640111R464<@@a11A1Q0Q1R00P@HA1R588DPa1S464@P11Q0Q1R00L@PQBS488<H@a1468@
H@04468030aQ360480@P220480PP1208@0aP468<HP<<@@06340880a0364<@@PP0PaQ00<@PA224640
0PaQ0Pa10PaQ00<@HA1P36000Pa000<<80PP34000Pa000@880a0364<@0840004220<@0a034022442
340030a1364<HPaQ344<@0`P2208@0a0360<@0@8@004224880Q024043401368000IgV`03MiYgVgNL
00AgW003Mi]gVWNK00=gW003NiagW7NL00=gV`9gW003Mkak^g^l00Ek_09kW09k_0=k_@05Nkak_G^m
Nkek_003Nkd4Nk`CNkd2Okd3Omd3Okd2Omd3Omh2Omd5Omh@OmdPOmh4Ooh`Ool016JI40P000@04@PQ
00d88P00200PPcC3>@E9Zdha<B/PYAbT56<HQ0036:@35:D25:@06Qc67>HHYA1R100004Y^OoYoogoh
BFX@1Q1V9>PLiaS56:@TiR3W:BTY1cf/?L`aJBTX:@P2:BP01Re9;BPY:2D7;BTaJ`8aJP0?>J`mZcV[
>JXmk3W<>NdicC6;>J]1c3g>@Q1:;e9b009BDP9>DP0;DW9FLeYdGY=ZmF;FH]MW66LiKga_F@02LeT0
17MJMgUgNGNK0W^l00Ik_G^KLcUc>W<iLg/7Ool00g=lMiaooP05Ool077^mLeYW65jfEUIBDeI`BS11
cdG_APlmcdGaFWAN]F;hFYI><dhBCS1>3BS554<PPaQQ320<@@aR0`aQ0`aR00<<@PQ2344010a100<8
@Pa124400`a10P0000<]0WogOol02Goo00QgOTGDDS9_=g_LNkekVGon27oo00IooWooOomgVgMiOmd_
Ool:Ooh4Omh4Ooh4Omh00goMOmiogP02Omh3Ooh8Omh00goMOmiog@06Omd3Omh3Omd;Omh04WonOomo
ogooNcUN<4fZCJM[4golOm]k_F[F=@/00@00320<@08<@@@<@088@@063408@0PP220480Q10PaQ0PQ0
0PPP00<480PP22001@Q000<<@0aR46800Pa000HDXQRS6:<HY1R3568258<00aB2488DP`0258<011RR
7:<DPQ1Q0aB200L@HQ2358<DPaBS588@PP0246802A1Q468DPaBS588DXaB248<@PP02468348803Q21
488DXQB35:<DPa2358<DY1S55:<@PQ1Q468248801Q1R464<H@aR464@H0<@H@04488DPQ1Q46824640
1122588@HA1Q112200<@Pa1S46400Q210Q220Q1R00<@H@aQ24400PaQ1@aR0PaQ0PPP00D480@0360<
PPaQ0088@003344<H@aQ008<@@0:360<@@a1340<H@aR484@PPaP34023447364234000`Q0340<H002
34000``P340<@003340010aP3408@@Q00PQ100X<@0aR368<@Pa1244<@@`P364@PP8<H004240<@0Q0
220224000`a13648@@043401344000IgV`04MiYgVgNKMi/2Mi`2Mi/017^JMi]gW7NL0g^L0WNL00=g
Vg^KNi/00g^k2W^l0W^M00=k_G^lNk`00g^l00=k_G^lNk`01G^l1G^m0W^l37^m00Ao_GoMOmeog@=o
_@03OmeogWoN00QogPAog@9o_@eogAmogPAooP]oo`03Ommoogoo025oo`05LcdH2P000004000?2240
1@@Q224000P08:@00ST600U9bdW^<@TPYAbU68@LYQRT58802ABT01D<@P@0000@@7NEOomooW<i:>hL
J2C77>PLaQRU8<DPiR379>D]:3F[=FT00RTX00T]:2e9<FT]B2dX;DP]BC59;DX00S5:00<iJSf[@N/0
0T7/00dmbcf[>HXiRSf/>Ha:<EZAF[=JTe9ADU9BD@02FW8035icH[9ZlfKEH[IRf6LIJcYgNG=JMeYg
NP9gN@09MeUcFGMiMgYcFG^mOmmogWon00Qoo`05OmioogooOomk_@02Lg`06G=kLea_>f/KEWQJUUZC
DU9><Dh_CRe:3UZeLiaooGNoLiiNfE9ECO15c2RV54@LHaQR008<@@06348@H@aQ464<H@a10`Q11Pa1
00D<H@a1344<@0PP00800003;@=omgoo00Uoo`08Mgi:5EIBNeEooW^mNiUooPMoo`9k_006Ooioognl
MeQkVgon;goo0gon1Goo0Won0goN0Won00=ogWonOoh00goN00=ogGoNOmh00goN17on1WoN2GoM0goN
1GoM00=ogWoMOmd00WoM0WoN00=ogGomOoh00goo00YkF5X_BJQ=j7=fOoeongMjHW@XQ`840@03440<
@0a100H<@003244<@0Q100D88003224880PP00<88003240<@0Q000<8@003340<@@aQ00888003464H
XQRR00<HP`0358<HXaRS008DPP03488@HQ2300<DPP07488DPQR3588@H@a136800Q2200<<H@a03640
0a2200/@HQ22588DPQBR588@HPa1220<@A1Q00<@PP03588DPaBS008DY00?58@@Q12448@<HPaQ464<
@@aQ488DXaRS588@HA10008@H@8@PP<@HP@@H@08460@HA21588HXaS36:<@HP8@H@05364@PA22468@
H@024680311Q360@H0a0464@HPaR240<H@b23688808<@008484@PPaQ320880a0364@PP8<H@053408
@@`Q344@HP0248800a21360<@004344834001PaP340<@0PP340<@@H<@0<8@08<@00524488@Q13448
@@0334400`aQ360<@00334000`PP240<@00534012401340122000003LiYgVgNK00=gV`04MiYgVgNK
Mi/2Mi`017NKNi]kVWNK0WNL17^L00AkVgNKNi]kV`=k^`Ik_004Nkek_7^lNk`3Nkd=Nk`3Nkd01G^l
Nkek_G^mNk`027^m0Wnm2GoM17oN0goM0goN2goM00=ogWoMOmd00goM1GoN00=ogGoNOmh067oN17on
00=oogonOol00Woo17on00=ogWooOoh05Goo0WoN3Goo00Mo_bR;000400PQ32488P0=22403@@Q1040
00`Q;>Le1cU8BLY5[3488:@LYAc5008LaP066:@DQ11S368<Ha240Q2U00<@Y12U26<00`0000Q1jgoo
OomoodWD72DLR1C80ac600hPaRC68:@Y1Re9:DLY:2D89>HU1bTX;DP]9bdX0be:00LY22C59<D]1SV9
@La5k@02AL/01cf:<DTTic5;?Nm>;dia009><00=DU5FDUYBFU9RU6:AI]5VeEjEFWAN]VKgMeP00gMj
00=gFGMkNi`00WMJ00=kW7oMOol037oo01=ogW^lLgYc>G=kMi]kVgoONii_O6;HGYIJTeIbDU5>3Th;
BNaRm@04Ool02gNnEWI9l3f;:<LDA1aS668<@@PP44400a1Q20a100<<HPa134800`aQ00H<@@aP0000
034UOoP:Ool027NNDSEJDW]COoek_G^jOod7Ool027=jI[I_6WMlNg]c5W^KOmhfOol<Ooh00goNOoio
gP02Omh3Ooh00goNOoiooP03Ooh4Omh9Omd3Omh5Omd00goNOmeogP06Omh02GonOomoogooMcQF;TVY
DRagN002OoX027=IEO0H8@00100<@0Q03202340534400`aQ3448@00222001`Q0220880PP320<@0a1
00D8@0888008320@HA1R468DPQRR7<@LY08HP`0358<HPaRS008DX`03484<HAB3008DXP085:<DPa23
58<HY1R2420@@@8<H@04468@PQ2248<25:<00a2S48<@PP0258800aRS588@HP0234400a1R488@PP02
48804@aQ588Ha1S45:<DPQ1S36<@H`aR364@H@a1464@HQBS48800Q1Q00H@@11Q488HXQB248834685
46400a21588HX`025882468010Q0464@PQB30Q2200@DPQBS588@P@8@H00J364<HPaR3448@0b33688
80a0364DXQBS464@@@a1364@PQ2S368<@@PP120400a1468@PP@<H@@<@@03440<811000<<@006360<
HA1P460@@0a00Q1Q00L<H@a0344<@@Q0340<@@0236400`a0240<@00534400`PP340<H@0534000`Q0
244<@003340010aP480@P0a00@`P00000gMjMgUgNP04MiX5Mi/00g^KMi]gVP03Mi/2Mi`00g^KMi]k
V`05Ni/00g^kMkak_007Nk`2Nkd6Nk`6Nk/=Nk`3Nkd7Ok`2Nkd3Nmd;Omd2OkdBOmd2Omh4OmdMOmh7
Ooh00goNOoioo`0FOol017oNNkeg_G_N37oo00<mL00000000P`R00<88PPQ22401PPQ1P@Q01X40000
448`icD7?DM1R3E8:>LTaB357<DLiR487<D@H`a234<<@PQ236<@H`aS24<@Q0@Q0`0000]cUgolOomc
FbRX30HHZAS56:DHYQc6008DQ00D8<DU9bTV9@LPiR2U7:DPiRD7:BL]B35Y;FXY:BCV9:DPQ2C7;BTi
[091b`0;ALXmRS4Y;@T]BSF<?Ja1[4G=CNiFD002EU404eHaEQ5NCf[AJ_AVeEZDFYEReW<hMgUgVGMj
Mg]kNgMlMiak_WoN00Yoo`9ooP0FNkecNgMkMia_>5kEG[Ec=W^FMeQ[>FLHI]IR]5jCEW9><4W]BLY5
Z6KbOoX3Ool02goMH]Q5l3V<9<TDA21R764<@@Q034000a1Q00@@@0a1344<@0T<@@03340<H@aQ0080
0003<DMonGoo00Uoo`08Mie>55XaNe=og7^mNkYoo@Moo`09NiaBMDGdCSANUG<iOmaogGon01moo`Mo
oP03OomooWon00EooPIoo`AooP05OmiooWonOoiogP05Ooh4Omh2Ooh2Omh6Ooh00goNOmeog@0GOmd3
Omh4Ool03W<hEPa9bUZ@NiQofGniKcQ5[``0000400a024033402344010aR3448@@PQ0`PP00@8@0a0
2408808<8003460<H0a000@88005240880a0460@P@0258803b3S7<@HXaB26:@LaARS568HPb355888
81BR7>@DX`0258<25:@02AS46:8@@11R58<HXaBS6:<DX`0258<041S46<D@P`a1468DPQRR488@Ha1R
568HXaB1464@PA1R0QB20QRS00HDPPa0220<HA1Q368346400`aQ468<HP0246400``P340@H@034840
2a1Q468@HA1R588@PQ1R464@H0a048400Q220`aR00H<@A1R488DXaRR688446401A1P360<H@aR4680
0PaQ01LDXa22340<@11Q5:8DXa22464<@Q1R588@P`aQ220480a1220<80aQ368<H0a000D<@@8<@003
320<@0a0008<@08<H0<@H004464DPQB23642344524402@Q0340<@0a0360<H@aP3408@00234000`aQ
360<H002360010a02408@@a10PQ00Pa000<DP11P44000@`P00000gMjMgUgNP03Mi/017NJMi]gVgNL
17NK00=gVWNKMi/017NL00=gVg^KNk/01G^K00=g_7NMMkd01G^l17^m1g^l17^k3G^l1g^m00=o_7^m
Nkd01G_M2WoM0Wnm1goM1WoN17oM1GoN0goM7GoN00=ooWooOol00gon00=ogWoMOoh067oo00AogW^m
Nkeog`]oo`05EQ@40000228<@P022289224412402`@0000@8BRT>@@di3U7<DPTiRC58>H00aS60QRU
00/DYAB458@@Q1B458<DQ12448<<H`@000800008?LYonWooOomAd1A844HHY0@LaP0<6<DLaR479BHQ
1b356:@LY2T8=H/a[2eZ0S5Z01daJbT8:<HXibe9=H/i[3f[@La5k4G^@LdiRcE[?Le=kDEYFP]F;UY`
G]AN]5idFU=RTFlCLeMgF6lh009_>@09LeUgNgNKNkakVgMJLeakWG_N00aoo`0ROmek_G^mNkiogW_N
Mie_6FKgJaMVn6:gH[IVeFJcHY=JTeZBCRm>2dFXGXmgEWokOomoo7mIG[M>4T7>9>TD@b1R76434680
111Q468@H@aQ0Pa100<<@0a134401Pa10PQ200H8@@Q0000003E7OoT:Ool027NMCSANLg]DOoio_7Mh
Ooh7Ool2Omh017]nMgagW7oN0Won87oo1Gon00=oogonOoh01gon1goo1Won0goN17on0goN0goM0goN
1Gon0WoM00=ogWoMOmd00goM1GoN1GoM00=ogWoMOmd027oM0goo011kgf/HDLa5bEkDOmYofGnjJ_Lm
S@`0100880a0240<@0D<@@<8@@03240880Q000@8@005320<00a03408@00222006`a0344<@@a1360@
HAB25:<Ha1c36:<DPaRT6<DHiQBT544HPR356:<DXQBS6>DDXaB26:<La@025:@05aS46<DHaART5:<H
aAcV6:@@Pa225:<DaA2S244<@QB2584@PPa1464DPAB258400QAQ00dDHQB35:<DXQBS5:8@H@a1364@
PQ23488@H@02364236800`a1464@H@05464248802A1R464DPABS588@HA1P464@P@02488636800a23
6:8@H@0234024640111P364<H@aQ1Q1R00@<HQ1Q484@PP8@HP05344@HQ21488@HP02368234800`aR
364<@00334000`a1340<@00234000`aP340<@007340010aP364<H@aQ0Pa11PQ100D8@0a0340<@0aP
00T<H@03360<@0a00088@003344<H@aQ008<@003460<H0a0004<800000=gVGMiMgX00gNK0gNJ1GNK
00AgVWNKMi]gV`=gW003Mi]kVW^J00EkV`03MiagWGNM009g_0Ak_09k_@Qk_0Ak^`]k_003Nkek_7^m
009k_@07Okek_G^mNkeo_7nmNkd00W_M00=k_G_MNmd027oM00=og7nmOmd02GoM1GoN17oM1GoN00=o
gGoNOmd07GoN00=ooWooOol00Won00AogW^mNkaooQQoo`04OoiogW^mNkd8Ool01WoOOomoofJF5004
00<<@P0322888@PQ00T88@0?12400@00000<8C45?FDe1345;>D/i2BT44888A1200<LY@037<DHYART
008DQ00:6:@HXaBS588@P`a2104001PPLgL2Ool01WMl;@hH9AQR6<HPiP<TiP049@LY:2TW:BP3:@P0
:2dY;DT]JSF/?NdmcC6;<DXeBCEZ=H/mbcg<@Le5cDX>CRmFCe8_BS123dG^@HYF2eZ?I_=RmF:dGYAN
MF:dLcEgEWmhOiYkVWMIMeYgNgnm0Won00=ogW^nNkd037oo00AooWoMOmiog`Aoo`07OmmgOG<kKcaJ
^5jFI]@00V:c019N/ejAFW5B;dWZERaZlgogOo]odfJBDSA><dG_;@XH@b11764346800a22468@H@06
3405344334801PQ134800000?FQomPYoo`08NgeBE5jDNgIooGnkLeEooBioo`iooP9ogPaooPEogP9o
oP03OmiogGoM00Aog@EogP9ooP03OmiogGoM00Iog@IogPYog@9og003Omeog7nl00=oo`0:LiiReTVZ
BNQW5WomOoYo^fKE=B/2200434000`a124488@0322400`Q122088@02220224000`a0240<@0022200
20Q0220880PP3408@@a036434640611R588LXQRR568@HQBT7@LDY0a0588HXaB2488DXQRS588@H1RR
5:<DY1S56<@DY08DP`0A588DPa22468@PQB15:8HaART58<@HQB26:8@PPa1320DH0035842468021B2
5:<DXQ225:8DPQ22468548800aB3468<@@04464258802A1Q340@HA1Q468@HAB16<<DPP0246424880
0a21464<@002368246802@aR364<@0P01008811P464@H003364246800a24468@H@0246800`aQ464@
H@0446400a21488@PP02468010aR348<@@a10Pa000D880a0364@H@aQ008<@@05340<@@a034088002
34002PaP340<@110364<@0`P220<8@a110Q100<8@0Q124400`a00Pa100P<@0aQ488<H@a0364@PPaQ
0PaP0PQ000<8@@a034001@a00@PP00000gNJMgUgNP03Mi/3MiX4Mi/00g^KMiYgV`06Mi/01G^JNi]k
Vg^LNi/00WNK00AgW7NMMieg_09gW@03Mkek_7^m009k_AMk_003Nkek_7^m00Mk_@03Okek_G_M00Ak
g@9kgPMog@9o_@Yog@EogP03OmeogWoN02EogP=oo`9ooP04Omik_GoNOohIOol017onNmicO7_N2Woo
00Ig6B@0200@Ha12324=224200002Qb3@FQB;TG:AJ/mJSeY>BLa1RBS0QQR00PD@QR48<DTiQRT68@D
Q1RT0aB30a2300D88@P0000eJgon009oo`04ESHP0Aa36<H29>D29>H01BTW:DP]J2eY;BP00RTX00dY
:Be:;FXaRcW^>LdaS2e:;BPeJSF/>J/m[@02@Lh06DG`BS1:<4X`@S0n43g>ALiB;UZbI_=RmEjcFW=N
UF;EJ_A_5WLhNk]cFG<iMcUgFW^L009oo`9ogP03Okioogoo00aoo`03Omioogoo00Eoo`0NMg][>V;H
H[IVeF;fH]ENLEjAFW9B<4h>ETmZm7oiOoeoEEh_BM5:<dha;@PP@R0P644@HQ1S48<<HPaQ3@a100@<
@Pa12248@0800003@HQomgoo00Uoo`08Mga>=5IcMcIog7^lMgQooA]oo`03Ooioogoo00Moo`03Ooio
ogoo00Eoo`UooP=oo`9ooP=ogP03OoiogWoN00IogP03OmeogWoN00MogPQogAIogP=og@03OmiogGoM
00Iog@0BOmaogGooOomkgf/lEWA=be88KeMo^WomNiYNM2S8100880a10`a00`Q100D<@@PQ224<@@Q1
008<@@8<@005240<@0Q02408@@022403220010a0344<@@a10PQ000X8@@a1564HXQR2568881B38>HD
Y0<@PP0>368@HQBR6:8@@11P6:8DXaBT6:@DXaBT58<DHP<<@@0>340DPQR26:8DXac49@HLaAB2688@
HQ11440DH@8DP@08488@HQ1Q468DPQBR5:<DXP<DX`0548<DXaBS58<@PP0246800a11488DX`026:<0
2AB2488@HA1Q360@HA1R588HX@0358834880311R464<@11Q468DPQ1R3448@0a0464<@08@H@04444<
@11Q464346802Q1S468<@@aQ468<HQ1Q364<@11Q0Q1R00P@HA22488@PQ1R368@HQ110a1000D<@0aP
388@PQ1R00<@H@8<@008320<@0aQ364@PQB1440<808<@08<808<@@05244<@@a13448@@0222002`a1
340<@0a1244880a1364<@@a036000PaQ00D<PA213648@0Q100<8@004340<H0aP340132000003MgYg
NGMj00MgVPEkVPMgVP03Ni]gVgNK009kV`9gV`07MiagWGNMMkagWG^MNkd047^l1G^m27^l3G^m00=k
gGoMOmd01goM00=og7nlOkd02WoM00=ogWoMOmd0:WoN17on00=ooGnlNkh06Woo00IooWoMNiacG7NK
Ood9Ool01gnJ;20<00a2448800PP00/88@08120000@0BPagLFlbK_AVC`9RC`0;HTeF;UY>CPhe9QA1
68@TiR34568@@P0456<258<07A1S468@@@P0000<0flDOoAoognn<8DD0QbU:>@XiBSV:@H]9be7<DL]
B2dX;BL]:2T7:BT]Jc5[=H`00SF;01PaBRT7=FTiZcV:>H`i[dHc?O5244H?BS163d8@@O1>3eI@FY5R
dUjcFW9F;eibH]@2J_@027<gMgUgEg<hJ_MZmW]jOmd2Ool00goOMkekg`0=Ool00goOOmioo`04Ool0
6WoLNgU_>6/HI_MVeV;FGYAJLejcH]EJLe8`FU5Ve7MiOmYoMfIbDQ=FUUia<@LP@BA07642468010aR
364<@0PP3@a10`a00P0000<mIWoiOol02Goo00Qc>TWbGYAkMGoLNiakVgon5Woo2Gon0goo6Gon2WoN
1WoM1GoN3goM00=ogWonOoh017oN00=ooWoNOmh00goN47oM011ogWooOomoof/jDS=9ZE8WLgQofWoL
MeYF4B270008008<@0063448@0PP220<@@Q10PPQ1Pa01`Q00`PP00L<80PP244<@0a1368@HP035880
4AB3588DPQBT6<@Q1QBS5:8<@@Q258<La23V6:<HPARQ58800QB300HDXaB358<DPQAQ464234445880
0ac37<@HX`02584246400a10584DPP02588011AQ344<@@aQ0Q220QBR00<DPQ2248800aB200<@PPa1
34800a1R00<@HA1R4640111Q0Q1R00<HXaRQ58400aB200<@PQ1R36800`aQ00P<HQB1468<H@a0364D
PQB10a1Q00@@@@a0464@PP8@HP8@H@03344<@0PP0088@08<@@0734888@a0464DXaB246800a1Q0Q1P
00L<@0aP340<H11Q5:8@PP0246401A1P340<@0a046000a1Q00D@H0a0340<@@a0008<808<@0<<@@05
3408@0Q1244<@@0236401`aR344880@P2208@@a000D<H0<<@088@08<@08<H04@H04<@00000=cVWNJ
MiX01gNJ1g^J0W^K1WNK00EgW7NKMi]gVgNL009gW@05MkagWG^MNkekW00>Nk`8Nkd4Nk`<Nkd2Okd9
Omd017oNOkeo_Gnm2goM00=ogWoMOmd0:WoN00MooWooOoiooWomNkaogP0JOol01WonOmegW7=KLgYo
g@Uoo`07OmU51a01224<8@P032002PPQ01T<8@@000048U;DKi9[=EibITi^[gLdOkMofWMEIY55ZBB2
8:Da9ac46:@HQ1B468@HY@0258@04AR368@HPaQR444@@Q01?DMon7ooOo]Qk22744<TY2cU;@H00RdW
00T]B357;BPa:2dW;BPY22T9;DX00S5Z00<eJSV<>H`00SV:01liRcV:<BT]KCXC>O924DH?ARm23Sg>
?Nm:459AFY9N/UZCES1EkUjBH]EVeFKDLcMgF7MGJaMVmV[fMeYk_@04Ool00g_NOomoo`0BOol01Gnk
NeQc5VlGJaL00VKf01E[5f/HH_INmUZCES1B3eH?GY=cFGMhI[AJMEkGGW4i22QR:44H@A1146802`a1
00<<@Pa134400`a100<<@0aP34000P0000=1QgojOol02Goo00Qg>dWAH[Eo]WonNi]gVgon5goo27on
0Woo17on27oN1Won3WoN2WoM00=ogWonOmh017oN3WoM17oN17oM0goN3goM0WoN0goo00ek_fKiBO11
IeIZNiUonGnlKaQ9d11400040003344334000`PP22488@0222023400111Q3408@0Q10PQ00PQ100@8
@0Q1220880<<808<@@09464@PaB3588HPQRR6:<DXaRS008HY0097<DHaABR3688@QB38@HU9b3U00<H
X`04688@HA11468258801AB1688@HPaQ58800QAQ00/HXaR2464@HQB2568@HQ1Q440DPARR00<DPP04
344<HA1Q46425:8011BS588DPQ220a1R0Q2200DDPa22468@HPa1008<@003464DPAB200<@HP0E6:<H
XQB1588HXaB248<DPa2S48<<PPaR264<HA1R3688811Q6:<DPAAQ00<@HP8@H@0848<@HQ1R468<HPaQ
368<H@<<HP08364<@@a2348@HQBS58<@HP8@H@04344@HA1Q364334000`aQ488@PP0346400a1P440@
@00446400a1P360<@00234422206344224400`aR48<@Q002368234400`a23448@@0224400`aQ360<
H00934013601464136800003Mi]gVWNJ00MgVPMkVP04Ni]kW7NLNi/4Mi/01GNLMi]gVgNKMi`00g^L
00=g_7^lNi`00W^L37^l2G^m17^l2G^m27nm0goM0WoL00AogGnmOkeo_@9og@=o_@Yog@]ogP03Omeo
gWoN01aogPAooP03OoeogGon01]oo`06Omik_6liKcQog7on27oo00MonE5Z50840@`Q200<80062240
0`Q122488@02100300005DX>H/liZSe/EJYVB7L_OmEgMV[ACPa1R2BT8<H]22D77:DHYAbU7<DLaP04
6:D041bT68<HY1c676@T@6;?OoionGnI>DhH8aa1:<@]1BTW0be800L]BBdX;@PY22T9;BT]BP02<DT0
4cEZ>H/m[3f[@L/m[3V;<DXeKCga>M9:=59`ARm63SV;>Je644iB009JT`08GY=F<EG^GW9ReFKfJ_E_
=`9g=`06JaMZmg<jMeYkW7oO5goo01eogW]iMcI[5VlfJaI[5flhJcMVmV;fG_EJTe8`CO1B45YcF[AR
e6:DFWABM5IA;<LP@R11640<811100<<@@03340<@@a1008<@@03244<@@Q10088@@<<@@08340@@110
340000P0AJUoo0Yoo`08Maa=lejCOkAooG^lMgUooQQoo`QooPAogP03OoiogWoN00QogPEooPEogP9o
oPAogPmog@9ogQ5og@03NkagVg^k00Eog@9ogP]og@9ogP9og@03Omik_Woo009oo`05LeaNUDV]AHIN
[002OoT01W^KI[Hi;0@10008008<@@8<@005464<@0Q02244800222000`a0240<@00234001`Q02208
@0Q02448@0Q1008880@<@004464<HA1R468258800ac37<@HX`036:<01aBR5:<DXQBS468DPQcU008U
9P035:<<Ha1R00<DPP03468DPQB2008HPP0?588@PQB2588HXabT588<@@@P244@HA1R564@@1R1008L
``05588DPa23488DP`025:8011B2468@HQ1R0Q220Q1R00`DPQRR6<<HXaR2468@H@a0444@HARQ5882
4640111R5:<DPQ220a1R00<<HQ1R48<00Q220PaR0PaQ00D<@@aQ464DPQB1008@H@@@HP0338<@H`aR
008@HP03488<HQ1R008@H@04364@H0`P344346802123488@H@aQ344<@11P464434000aB15:<DPP03
46400a1P340@@00546400`aP340<@005344236401@a1244<@@a148800Q2300<<HPa2344010a100<<
HA1Q36000PPP00<<@@a034001Pa00@aQ0@aR00000gNKMiYgVP02MiX3Mi/3MiX00g^KNiYkVP03NiX3
Ni/5Mi/01GNLMi]gVgNKMi`00W^K00=kW7NlNi`03W^l00=k_G^lNk`00g^l0g^m0g^l00=k_G^lNkd0
2G^m0Wnm0goM00=o_GoMOmd00WoM0Won00EogGnmOkeo_GoM00=o_@]og@]ogP03OmeogWoN01]ogPEo
oP03OoeooWon01]oo`05Ooik_FlIJ]Ek^`09Ool01GokFJh@100020000P`P1`PQ00<8@PQ100000`00
01@402c4BL]1c3eZ@DM1IeX:J/aVlT7<:>@Ta2358>HQ1aS55:@DPa1S11AS01@DPaB458<DPa1T7>LX
aA`P;BMkfWojOomJDR0272@TYBd69BLY:2eZ0RU:00@Y:359;DPY:08]B@0W;BPXiRT6<BPiRSf[@La5
kT7]?Le1[3U[=He244YaBU563cf<?Li:DU9bF[AN/UjCGY9RLF:cI_MVmVlFLcIgEgMiMeQ_67MlNiao
_7oN01Moo`07OkekFG]HLcQ_=f/GI_L00fKf0UkE015N/UYADS5>4DXbE[EVmeYdDSA>DdX?::HD8R11
640<00a000P<@@03244<@@a100D<@@04340@@110320200000dg[Ooaoo`09Ool01g;kDSAR]GnhOoec
NWMj019oo`03Ooioogoo009oo`]ooP9ogP9ooPYogPAooPaogP]og@04OmiogGoMOmd3OmhAOmd2Ok`6
Omd5Omh6Omd3Omh2Omd00g^mNkioo`02Ool01G<jES1=ZTF5I^l00Woi00=oVVJD::L00P0000@880a1
344<@@8<@003360<HPa100888@03220<@0a000<<@0888@072448@0Q124088@Q024400Pa10Pa000P@
H@aR364<@A1R5:<Pi1cU0QRS11BS00<DXQBS58<00QRS00LLiASU4:<8HPQ1588DP`025:<031BT5:<D
PQB26:<@Pa22588PiARS58<8@@8<HP0B464@HQAQ584HXRCU7<<DPQB35:<DY1S55:8@Pa22588@HQ22
0Q2300P@PQ235:<DPQ21588HXa220a1Q00H@PAB2488@HPa146424682368040b336<4@A1R488DPQ23
488@H@aQ244<@A1Q584DPQB10a1Q00P<@A1R488@Y0aS344@HQ230QS400<@PQ1Q44400Q1P00D<H@a1
320<@0Q1008<HP03488<H@a0008<@0@<@@03440@HA1R00<@HP8@H@06460<HA1Q464@HQ1Q0Q2200/@
HPaQ344<@@aQ344<HAB238<<@@Q1008<@@@<HP<<@P@<@@@<@08@PP03364<@0a0008@@0<<@04<HP00
00=gVWMjMiX00WNJ0gNK1WNJ00=kVWNJMiX017NJ2GNK0g^K00=gVg^kNk/00g^k6W^l2W^m00Ao_Gnl
Okeo_@Aog@03OmiogGnm00=o_@9og@03OkeogGoM00]og@=ogP9og@AogP9ogAiogPAooP03OoeooWon
01aoo`04Nka_>6[ENiX5Ool02goNOomoogooOoiVUP`5000880`P32401`PQ01T8@@A100040358BN//
`QPP86@a:SU8@FTmJCUW?HPiJB23344@HabU7:@DQ1B3468<@@06224234809P`Q348HaRC588<DA4G/
OoQoogoK=@TD1B1U:>DU9bTX;F/YBBTY=J]63T7[=HTaJBe9;BP]9bd7<BPeJCV/@Na:3D7/?JY1bdG;
@Ld2?Lh05cg_@Nm1kdX?F[ARe5kCH_AVe6:cI[=Ve6KeJaI_=WMENgMkVG^JNi]kW7nlOkd00Woo0Won
57oo00Uo_WmjNgQgEgLgJaMRef;gH_H00V;e019NeEjcFW5BDDiCBQ=BMEIcEU=5ldidBPl/jAPT:6<H
@0`0440634400`Q1344<@@07344020a0460<80PP0004058ZOoh:Ool01fkkDQAR]WnHOoik_G^l00eo
oa=ooP=ogPaog@EogPMog@9ogP9og@03OmiogGoM02Yog@AogPIog@9ogP=og@03Nieoggoo009oo`05
JaYEkTVWAHA_<002OoT00gMHHW8XY@0200001Pa02448@0Q1224<@@8<@088@@88@08<@08<@@033208
80PQ00<8@0888003120880PP0088800;340@HA1R244880a26<@H`aBS5:8DPP0246400aB25:<DXP03
58801QBR588<@@PP340@PP8DPP045:8HXaRS6:<358802QB3588DHQB258<DPPa1468DPQB10QAR0aB2
00/HPQbS58<@PQBR6<@DXQ22588HXaB200@@HP<@PP05464<H@Q0340@H@0258400a22464<H@023402
240010a1364<H@aQ0PPP00L@HAB26<<Ha1222208@00236801QB25:8@PQ21364@H@<@HP095:<Da11S
340@HQBS5:8DPA1P00<<@00:460<H@aQ34488@@Q248<HPaQ3442340634401Pa0364<H@a1364@H@8@
H0<@H@05364@H@aQ360<H@0234402@a0364<@@a0588La@a2320<@00224400`a1340<@00634401`a0
240<@0a0360@H@aP008<@006320@H11P360880a00@aR00000gNJMgYgVP02MiX3Mi/7MiXDMi/4Nk/6
Nk`4Nkd9Nk`00g^kNkak_006Nk`7Nkd3Okd2Nkd00g_MOmeogP02Omh2Nkd2Okd4Omd2Okd9Omd5Omh2
Omd4Omh2OmdNOmh00goMOmiogP03Omd00gonOomoo`0JOol01G^lLcQ^mGMJOmd02Goo00MkOQQ;0008
00`Q22448@06224050@Q024882CVOkQon3D3840daSDY=DTiBCE8=HTeAb23348DHabV6:D2468258<0
0`aR348<@P02348010`R224<@QAS0P`R00dHYAcV6:DHHb21EXaoogoeJ]DPJA@19<HU:@03:BP04bCV
=J]23SW;=HXaRc5Z=HXeJcE9>DTeRTH>BPa5jd6Z@J]5k4G^008m[@0F?Le244HAAS9FM5JCFY5Ne6/f
KcMZm6KDI[AV/flfNgUoUgoKOoeog7nkOi`KOol077nMOi]oVW]iKcQRmelHF]EN]6;EH_ERe5JBDU5>
LdXbDW=N]59BBS5B]59b<BXHA2AR640<811110a10PQ100<8@PQ134401`a10PaQ00H<H0Q0000@@58Z
OoX:Ool01fklBO=N]W]gOoik_GoM00]oo`]ooP9ogPYooPAogP03OmeogWoN00=ogP9og@MogPYog@Eo
gPUog@03OmiogGoM01aog@9ogPeog@0BOkeoggooOomkgf/JEPm=Z4g4MiAonWoJMcMJ3Q@Q000400a0
1`Q100@8@0Q12248@@88@0H<@@88@0D8800900040110588Ha1BS58<<HQ23008DX`03588@PAB1008@
PP8DX`0858<DPQB2588@PQ11300DH0@DPP065:8DPQB2488@HQ220QB300TDHQ1R568DHQR268<LaB3T
58800Q1R014@PQ1R588HPQB3264DXQS45:88@ABS7>DHa1BS48<<HPQ100<@PP04364@HA1R46854880
0`aQ2408@00236402`a1364<H@aQ344<@110588HXaS348800PaQ0PaR00DHXaC2388@XQC3008DPP8@
PP0958<@Pa1R220<@0aR484@HA1P00@<@003364@H@aQ00@<HP05364<@@a0340<@@02364234823440
0`a0220<H@0236400a1P360<H00236400`aR364<@002220234403@a0364<HPaQ360<H@a1220<@0Q1
3448@@a0008<8004220<@@a1344224401@Q0340<@0aP34000PQ00Pa000DDPA1Q364<H@aP004<HP00
00=gVWMjMgX00WNJ0gNK2gNJ00=gVgNJMiX00g^K2GNK0W^K0g^k0W^L1W^l0W^m1g^l17^k1g^l1g^m
0gnm0W_M0WoM00=ooWoMNkd00W^m0Wnm0WoM0gnm00=ogGoLOmd027oM17oN0WoM0goN17oM6goN0goM
00IogWoMOmeog7^kOodLOol01G^kLcQ^eG<iOmd01Woo00QooWooOomoobd@000800`Q20PQ0P@Q0148
8ARR@JE>2332960m1CCU>BLiB3U7<DLa1RS544<DHaR4008HY08HP`0356<DHQAR00<@HP03448<8Pa1
008DHP0H58@HY23V8<DLPaQ19<Io]Wo[Oom1/b0U74@Xabd6:BLY1R2T;BLiRSEX;BLY:2dX0S4W01le
9cU7?HU5bdX;BN]1ZCf9>FXm[3f]>H`m[4H??Nlicd8@EW=JTUZAJaA_Ef[dGY9NLf:cLcIoVGnHOgQo
^P03Ood01WonOomoogooOmio_AAoo`03Okio>G/i009oN@04MgU[5ejeG[@2H[@04UjcGY=JTUZBDW9>
DE9`H]=J/EJaD]=FTC4Y84@P@AQ0300@@0@<@@88@@032488@@Q100P<@@8<H@0522000110ERQom`0:
Ool01flLBOAR]gnGOmegW7oM00Uoo`eooP9ogP=ooP04OmiooWonOoh3Omh01GoMOmiogWoNOmd00goN
1GoM1WoN2WoM1GoN=goM015o_7oOOomoog^oI_YAkdVWETYk]GojOk]c5Tg<300000P000<<@004244<
@0a02442240324401@Q0244<@A1R36400Pa100<8@@Q022000`PP00L480@010040110584H``026:<2
6:@36:<25:4011B258<Ha1BS1AB200D@H@`P584HXaBR008DPP0:468@PQ1Q340@HA21588DPaB248<2
46801AAR6:@YB24558800Q1R00D<H@a1464DHAB2008@H@095:8@PQ2258<HXacU7<DDXa2300@<HP8@
HP0=464@PQ22488DPQBS488@HA225:<@P@aP34000`aQ0Pa00Q1Q0Q2100dDPA22488@PQ23488@P@b1
5:8Li1c2564@H@0246803PaR364<@0a0364@HA1P360<@0PP320<@110340336401a1Q364<H@a12204
80PP00<<H@05348<@@aP220<@@033640111Q364<@@a11@a00`a100@<@0Q0120480<<@004100880Q1
3402344234000`PP344<H@0234001@Q12408@0Q034000PQ000<8@@a046000QBR00<@HQ1P46000@a1
00001G>KMi]gVgNKMiX01gNK1GNJ00AkVWNJMi]gV`=kV`UgV`03MiakVg^K00=k^`9kV`Ak_0Ek_A5k
_0Qk_@9o_@=og@03OoiogW^m009k_@03Nmek_GoM009og@Ao_@Yog@9ogP03OmeogWoN00AogP9og@Mo
gP03OmeogWoN01IogP07OoiogGoMOmak^goLOoh06Woo00IooWnkLcMZeFlHOmd:Ool01CUa000400P0
22000PPQ00<48@PQ22400PPQ0P@Q01@000@0100000@0888m1CcU>@Li:3TW<@H/iQbU44<D@QR47:@H
Q1R30QQS00<DHQA154400aAR01dD@Q11544D@QA3568LY1c478<<8A@R@HQongooKe/m:RA5504PQBCW
:>DTY2C4;@HXiB349>HY1bSU008/i@0;<>Da1C4U<B@Xi2C3888T`bd7;BPU20029>P012D:9B/eSCV/
0S5800Y5k5I_DTi:3TW_CNeF;Ei_I[5Zm09^m00CJ[9Z/flFOiYo^7]HK]I^eG/EOgEomgonOomoo7oK
Oo]onGngOkP01Goo00]ooWnkOiQkFFkfIYANDEi@GW1NLEX_009B;`0HDPi=kTg^CPi>;Th>BNi5kTi?
G]9J/D8^D]=>LC4Z96@X@Aa1320<@0a1364<@@a00PPQ00<8@PQ124402@a100H8@000000<85iXOo`:
Ool01g<mBO=R]WngOkagNg^l00]oo`]ooP9ogPQooPIogP03OmeogWoN00=ogP=og@EogPMog@04Omio
gGoMOmd5Omh;Omd5OmhWOmd03gnlOmmoogooMiiN^4g?@JYN/7ngOoYgVVkE@FX<000220000`a0240<
@002344324400`PQ2448@@03244010aR48<<HPa00PQ020PP00X<80a0464@PaBS464Pi2TW7<@HY08H
a0046<<DXQBR5:<258<258801A1Q568DPQ2258401AB200P@PPaQ244<@1B1588@PaB30a2301X48@aS
6<@DXQB2468<HA1Q344@HQB2468<@@aQ488DXaB3368DPQB35:<Ha1B2488@Pa221A1R00@@PQBS6<@D
X`8@PP045:<D`aBS4642468011B35:<@HQ110Q1Q00<DPA214880212200X@PaB2464@H11Q488DPa22
468<H@8@H@04364<@0aQ4642320334001Q1Q368@H@aR364<H08<H@03360<H@aR008<@@0=364@H@aQ
364<@@aQ368<H@aR364<@@Q122000PQ000@8@@a1344<@@8<@005220480a0340@@00222000`Q1364<
@@0334401@aR48<@P`aQ34001`Q00PQ100H<HA215:<@PQ1P4401320000AgV`=gVP03MgYgVgNK009g
V`AgVP=kVP9gV`AkV`03Mi]kVgNK00EgV`03MiakVg^K00=k^`9kV`Ak_0Ak_@Uk_0=k_@Ek_003Okak
_7^m00Ek_@=o_@Aog@Ek_@03Okao_G^m00Io_@aog@iogP9ogAMogP=ooP04Omeog7^kNk/6OohEOol0
1WomOkYc=f[EKaQog@Yoo`03CKH00000008<80888@0312488@PQ00<88@031240000000<0000B;:@l
iCcU>BLiBCU8=@P/iaAT304@8A1256<DHQ11424@@A0P2@`000T800`0440@HAAQ424001`0EV`00Woo
00QJU2S:50<801@Q764PPbBS0R2200<LHAaP76400QaQ01dPHBB1::8X`RRQ:88L@AaQ;@I1kDh=:@PH
I21T76@LQ22U8:@Ta2cT=DHmJ3U6<@H/iS46>DQ9Z5GW009Ab00lDJQEZEWZEN]J;5i^GU1A[4eYGTmo
3WmWM^efkWK_L/m^[fj^LZm^/7/@OkMofW^HMc=bm6KDGW1J;TfZBDM59dUYCHU9RE6YDJQ9J3U9=BPe
9cUY@Ni63cg<>J]63Uj^FVa:;4i@BPla2BAT844H80`Q448@Pa1Q0Pa000@8@0Q12488@@8<@@032448
80PP008<@@8<@007220<80@0000@85j9Ooh02Woo00Mc?4gbHYAoTgnkLeYk_00:Ool6Ooh2Ool3Ooh4
Omh6Ooh5Omh3Omd5Omh3Omd00goNOmeog@03Omh00goMOmiogP03Omd00goNOmeog@0?Omd7OmhVOmd0
0goLOkaooP02Ool02gMnG[M5[d6/I_AomgojMgYRLSD710000PP000@<80Q02408@0<880032248@@Q1
0088@@03224880Q000@8@0L88005320@@@a0320@H@0248<01AB19@@Y9Qc56:<00QB30aBR0QBS00TD
PaB2588HPQRS588@HAB156400Q1R00PDPQBS5:8@P`PQ344DPABR0QBS00@DPQ23468<HP8@H@0E584D
PQ1Q340@HA1R588DPaRU58<DPQS47>@DP`aR320@PQBS5:8@HA1R008@PP07468@PQ1R468<HA1Q5880
0Q2200DDPQBS6<<DXa22008@HP8@PP035:<@HQ1Q008@H@8DP@8@H@04468@PQ22488246801`a1364<
@@a0464DPQS3008DPP8@H@04340<H@aQ340232000`a0440@@0023400111P364<HA220PaP0`aQ00<<
HPa122000Q1Q00@@H0a0344@@0<<@@07340@H0aR244480PP24400PPP00/<@@a03608@0a0360@H0aP
460<80PP00<<H@8<@@06244<@A2248<<@@PP1PQ000T<@0Q1364<HA1Q364@H@aP34000@`P000017>K
Mi]gVgNK0WNJ0WMj17NK17NJ0g^J0WNK0g^L0g^K1WNK00=gW7^KNi/00g^k0W^K17^l00Ag_G^mNkek
_@Yk_09k_@Ek_003Okak_7^l00Ak_@Ao_@03Omeog7oM00Ek_@03Nmeo_Gnm009o_@03Nkeo_WoM00io
g@mogP03OmeogWoN01EogP=ooP04Ooeog7^kNk`6OohEOol01WomOkYgMf[fJ_Qk_@Yoo`09IYT@00@0
300@@0`Q22448P@Q00@88@<48@0A120001A2>>Hm1ScU?FQ1cD6;=BP/iaR4448DHR348<DTa0029:<0
2BbT9:<HHQ0P400@81A0520H@@0276802QQ1668TXbCT:><PPb12700Ta6^k0Woo011JTcD8708D01P2
54<TY2S5:<8/`bS3::@Xa2RS::8```8`h`0L<<8/XSD7BJYZlgonOm]Re4F;=<HXIBA4:8DPHBAP;:4d
hcSS<<4`XBbR;:<XY2BR::8XP2b0<:82<:<08Bb2;:4``BbR<:8dPCB0?<14h4CQ@>50hScR><8d`CS2
?>959456@DQ1AcdV>@Ddi3ST>>DdiC35;<D/a334<<D`a002=>D05CD6=>H/Y34X@Q1FLdh@?Le23ej?
ALXmICf9?H/`j21S744D80`Q348<HP03364324433443364234402@a0364@HA1Q220001APGZeoo00:
Ool01fkiCM5RLgnDOmacFg^m00Yooa1ooP04OmiooWonOoh7Omh2Omd5Omh3Omd2Omh2Omd6Omh00goM
OmiogP0AOmd6Omh8Omd00goNOmeog@0LOmd00goLOmeoo`02Ool03GMmF[Q1ST6]JcQonGomMi]NDbRV
000400PP008<@006344880@0220<@@PP0`Q100@48@PP2208@088@@04240880PP220224003`Q12408
80`Q468@H0aQ464DXaS58@HY9BT56:<@@00258802a215:<DXa2S58<@HAB26:@La23U6:<00aB100`@
HQB2588Ha1RS48<48@aQ5:8H`acT5:8458806AR2564DPAB2464<@11Q488HY1S55:@DPQ226<@Q1QRT
56<@@AB25:<DPQ1Q344<HQ22008@HP8@PP8@HP04464@HQ1Q46444882468236824880111P464@PQBR
0Q1Q00h<@@a0364@PQ1Q468@PPaQ240@H@`P464DXaB20Q1Q00X<@0PP460@H@aQ320800a1364@H@8@
@003320<@0aQ00<<HP0>364<HQ23488<HPPP200@HA11440<@0aQ444<H@8<@@03340<H@Q100888006
2408@@a1320<H0aQ0PaP00`<H@aP360@P@aP320480aQ488<H@a1220224400`aQ24488005244010Q0
2448@0a01PaQ0@aP0@a100000g>KMi]gVP03MiX2MgX8MiX2NiX017NJMi]gVgNK0W^L00=kVgNKNiX0
0W^K17NK00=gW7^KNi/00g^k0W^K00Mk_7^kNkak_7NmNkekW@04Nk`2Nk/<Nk`017nlNkak_7^l0gnl
00Uk_GnmOkeo_7oLOm]ogG^mNi`00W^m0gnm0W^m00=o_G^mOkh03goM3goN0goM5goN00EooWomOoeo
g7^l00IooQEoo`06OoeofW]fKaIZeg^K1goo00]ogWooOomoW2@00004010P32088@@Q00D88@0B1248
8@PP120001R2?@E11cd5BJUBD46[>BP/aRBT8:@a1T6Y0Th>03e5c4W]CPiB3Dg]AJe1[4h>EW5B;dG=
BLmB3e8`EU1JL5IaEU1>;e8_DPm9keZaOoYoogomOk]Vf4F?9:TTZ349BLaJ;6J?IY5NLV:BJ[=^m7<D
MeAg=G;bL]5bm7nIOo]oogonNkYc=f9D?Ddm2dg`LaEkDgLcMcIkEP03OiL05WMGJ]ARTW<FOgQoMGLE
K]EbmW]HOkYon7ogOmMoUgnHOiMoUWoEOo=oeGmf0WmG0WmF015oF7<hI]I_67]kOiYoVgnJOgYk>7Kf
MaMkFGmiNgYgFG<h009g>00DK_IVU5iCFW=RTdh@?J`a:346=BDa8cUY=DTXaRRT98<@8@P0220<@@H8
@@8<@004344<HA1Q3644340246001@PP000LH6K>Ooh02Woo00M^eTg@HY9oegonLeYogP0;Ool3Ooh2
Omh2Ooh3Omh2Ooh00goNOoiogP07Omh2Ooh2Omh2Omd5Omh7Omd017oNOmeogGoM0WoN0WoM00=ogWoM
Omd04GoM17oN27oM00=ogWoMOmd02WoM1GoL2GoM00Iog7oMOkao_7oLOmd2Ool01WonLcUFED6>ANm_
N`9oo005LeYF<QaV0008000434001@`P2408@@PP34000PQ100<88@@Q220020PP0PQ000@8@@PQ224<
@@<@H@08484DXaBT9BHYAAcT5:<DH@8DPP0;584DXaS5468<@A106:8Q1B347:@DP`0558802aB3588H
XaB2488DPQS38@@U0aBQ34000QB200`DXQRR584HPQRS588@PPaQ468@PQ234882344021225:8DXaB3
568DPQBS488234401`aR344<@1225:<DPPaQ008@H@05344<@11Q488@P@02464446801Q22464@H11Q
588DP@L@H@0<584@PQ1R340@H110464DPQB1460<@1100Q1Q00/DPA1Q344<8111464DPA10320<@A1Q
00L<HP03364<HPaR008<@08@@004360@HA1Q364234401`a02448@@a0244<@0Q1008<@0L<H005484@
H0a0340<H@0236001@a12404800012000PQ10P@P0PQ11@Q010a000<<@@a046000@aQ00000g>KMi]g
NP06MiX3Mi/7MiX3Mi/4Ni/00g^JMiYkV`04Mi/00gNLMi]g_002Mk`01G^LNi]kVg^lNk/017^l00=k
W7^lNk`00W^l0W^k3g^l0g^m00=o_7^mOk`00Wnl0WoL00Ak_7MkNkeo_@Qk_@=o_P=og@03OmiogGoM
00Mog@mogP=ogAMogP9ooP05OoeogG^lOoioo@04OohEOol01WomOmYkUVlEJ]MgN@Moo`05Omioogoo
Ok/`8@02000010`P22088@@Q1PPQ0PPP01480000788m9ScV?@E=k5jB@L/iJRcW9:DXa3DVALa63TG]
0099kP08BPmBD59bBS163dH@AU56<@8ml00=AQ1:<4H@APm5kCVZ>HY63DH?@La1ZeH_MiT017oo02eo
VfkFFPi9JDf/CNmB4DhbEW9NTeJCG]EW5ekDI]9^dFkcOiMomgomOoYofFKfEWHmKc27DQ9ZmflDKcMc
F7<gLcIkN7^HMgY_>6lGKcQcNG^IMeQc5g<hOi`00Woo0Won0Woo01]ooGonOoiooGoLOk]o_7nkOiYo
N7nJNgYcFGMjOk]ofgomOmaoVg]IM_Ic5W]jOkaogW^nLid00W^n01AgNg=KI[I=kcU9<>Ha1RcU:<@a
1CE6=FXaBbT8<>HXY1A3100800PP1@a100<8@@a0340010aQ00<<@@a034000`aQ00D80000641RcWok
00Yoo`07L]E=d6:COmMooW=JOmh02Woo1Gon0WoN00IooWoNOmiogGoNOmdEOmh00goMOmiogP05Omh0
0goMOmiogP05Omh00goMOmiogP05Omh3Omd2Omh6Omd3Omh9Omd00goNOmeog@0<Omd00goLOmeog@0=
Omd04GnlOmioogooOma[64Wb>F]>;WNlOm]kVflG@Jl<8`0032000Q1Q00<<@@a034400`a10Pa01@PQ
10PP00<<@0Q1240010Q100<480a158<00Q1Q00XDPABR58<LiB456<@DY1RT5:@DX`8DXP0958<@@@`Q
464La2DW6:<HPaAR00DDPP0448<@PQBR5:<258804aRS8@DU9ARR464<H1BR8>DHXQAQ588HXac4588@
HQ22588@P`aQ008<@@04468DPQB3488248<01122464@HQ1Q0Q1R00D@HA1R58<DPQ2200<@HP8@H@07
488DPAAQ584<H@aR46800Q2200H@PA22488@PQ214602464258801AAQ584@HPaR46800Q1Q00@@H11Q
464DP@8DH@<@H@085:8<H@a1344@@ARS588@H@8@HP04488@HPaR3482368236<010Q1368DY1230PaQ
0Q1Q00@<H0aQ364<H@8<@@092248@@a0244<@@Q1340<@@a0008<H004364@H@aQ3402360536400`a0
2408@00224000`Q13648@@04244020Q02448@@Q12408@@a024023401360136800003Li]gVgNJ00Ig
VP=gV`agVPEkVP9kV`AgV`9gW005Mkak_7^LNiak_00:Nk/2Ni/8Nk/6Nk`4Nkd2Ok`01g^lOk]ofgoL
Nk]gF7^L009o_@03Nkek_W^n00=k_P05NkeogGnnOkiogP0>Omd>Omh5Omd00goNOmeogP0@Omh02Gon
OmiogWoMOoeogG^lOmeoo@06OohDOol01WoJOkI_56kfMeIoo@Eoo`9ooP04OmmoogoG><L200000``P
22088@09224210003R2S@@HhiSSTDPaJL4h=>FTXibRS<><`i2d5:>H3:>D01BcV;@HXiB3556<00`PQ
0PQ20`PQ00d400PP344HPbC37:8PXB2T52@TYEY>OoYon`04Ool07W=JCO<PR0P352@H@ab48<@PaQb4
9:@e1U6XENQZlGnaOoIonW^GFW=5T33/70@H0bRV;>DTiRSW:>H/iP8]1P05:@HXiBSV:@LXi`02;@H0
0bcU;@Ha2002;@P2:>H00bd7<BL]1`02:>H01bd6;@La:3DX>DTiB3E8008e9`08=DPeAcE8=DLeB3DW
<BHa1`8a1P04<@L]1bdX;BT2;BX0534Z<B/a:SU:=BP`iC45<>Da1CD5>BHmJ3V;<D/]:3U8>>LDI0@0
2203344010a0344<@0a10Pa00`a100D<H@a1340<H0aQ008@H@05320001Q0H/eom@0:Ool01g;DCLmR
TgneOmegNgoM00Moo`UooPAogPEogA=ogP03OmeogWoN00EogP03OmeogWoN00EogP03OmeogWoM00Eo
gP=og@9ogPIog@03OmiogGoM02Qog@0DOkaooWooOomoV6KFAK0mJUZ?Ooaog7]kJ_DeC0@2000<80a0
460<H@@<@@<<@00K240880@P224<@@PP100880Q0360<@0Q02248@@Q0340880a158<DHAAP580DPQBS
5:@HXaBS008HX`045:<DXQBR4882344020PQ588Li1cU5:@DPQ1R58825:8011B2468<HQ220aB200D<
HAB16:8Q0aS3008DX`088>@U1ARS564DPQRS8>@DXP@DP`8@PP08588DXaB2588DPAB2464<@08@H@08
488@Pa22588HXaRT588@PP<@H@8@PP07484DPAB1584@H@aQ46800Q1Q00<@PA2246400Q1Q00<@H1AP
46400Q1R00@HXQRS48<@HPX@H@05468@HA1Q468<H@0234401Q2258<@HQ1R488DPP8@HP8<@P8<HP05
2688@PaR48<@PP024642340236002a1Q468<@0@P220<@@a0344<H@aR34400`a00`aQ0`a00PaP00D<
H@aR364<H@aP008<@0072408@@a0484@PPaQ36000PaQ00@<H0aQ2448@@<<@088@08<@048@@0000=c
VgNKMiX01WNJ0gNK1gNJ1GNK00=gVW^JNiX00W^K00=gVgNJMi/00gNK0WNL1WNl00=k_7^kNk/01W^k
0W^K1G^k27^l1W^m00UkgG^lOm]ofW^kMgYgNG^lNmd00W^m1G^n00Eo_WoMOkio_WoN00Uog@=ogP9o
gA1ogPEogAAogP9ooP04Omik_GoLOod6OohDOol01WomOkM_5FkFMeIoo0Uoo`06OoeES@00000<80PP
2@PQ00d40000200TXd46=<Hha5H<FW1>;CEY:<DXa002<><03bcT:<@Xa2S49<<TXb2T:>HTa1AS1000
00@00004000300003P@0000881R29<@TiBCS9:@P@QP0:615R6ldOod5Ool03V[i>B/L91a664DHIQbV
768H03e2CHIAaVlDOoP2Ool02gonG[EAcUW_@FdTJ1`1984Xa2d6:@D00RS300@T`bCT:>DTiP8Xi@08
:>@/i2C4:<@XaRSV:<DTa@<Ta0088<@Ta2C49<@XaBSU:>HXi@8X``8/i@0;:<<Xhbd5;@H]1BS3:<@/
iBST:<<Ta002:<@012S5:>D/iBS50Rc400Da1CeX@HU1RD680091I`0:@FI5bSV;<D/aBT69>BTDA0@0
320334400`a0344<@00234023443364234402@a0364@HA1Q200001Q0I^mon00:Ool01fjdCM1RTgnh
OmekW7oM00Qoo`YooPAogPEogA5ogP9og@IogP03OmeogWoN00EogP03OmeogWoN00EogP03OmeogWoN
009ogPIog@03OmiogGoM02Mog@03Nmek_7oN009oo`0<OkYR]4V^@DMVl7okOmYo^fkE;>P00@@00`a0
00H<H@aR368<H@a1340234400`Q124088003220224001@Q1340<H@aQ34400PQ100`<@0`P324<HAAQ
560HXAB25:<DPaB25:<26:<25:<25:8258800`a17<@Li0025:@00aBS48<@PP0648804Q23488DPQ1Q
484DXQRS5:<Ha2467>@HXaRR584DPQc47<<HXP@DP`08588DPaS46<@DXQRS6:8DPP8@H@@@PP06468D
PR3U688DHPaQ111R00D@PQBS7<<H`aB2008@PP03468@HA1Q008@PP075:8@HPa0440DPA1Q46800a22
00<@Pa2246400a1Q00<<@0PP3400111Q01D@PQB2464<@@PP3408@@aR468@HA1R464<HPaQ344<@Pa1
3648@@0012000a1Q00<@@0a034000PaP00<<H@a134400Pa10Pa000@<@A2248<@HP8<@0@<H@H<@0<<
H@03360<H@aQ008<H@05360@PA2S364<H0043642488236423403240124400003MgYgNGMj00IgVP=g
V`QgVP=gV`9gVP9kVP=kV`03NiYkVg^K009gV`04Mk]gVgNLMi`2Ni`2Mk`00g^lNk]k^`05Nk/3Ni/4
Nk/9Nk`3Nkd017nmNkek_Gnl0WoK00MofG^jMgYkVgnkNkeo_@02Nkd3Nkh2Okh017oMOkiogWnn2GoM
0goN0goM3goN1WoM4WoN00MooWoNOoiooWoMOmaog@08OohBOol01WomOkU_5F[ELaIog0Yoo`03IUL8
1@00008800P88@0M22040000300XXSd6=<Hm9eh/IZmB;3E7:<@/i343<><`i33U<@D`iBcT:<</iC4W
;@HLaQ13304<@P0246<00`a344<<@@0222003QB3:>H]9c4W<@D`i2c3;:8THB1S76@eJF/BOoP5Ool0
35YG::`H1aP5:8HXHcBPM/=ZbFJ>LcEooP9oo`09Ooac>GnjOo]ood6A:6H/XcD5008e9@04>DDiASU6
>DL2=DP2=BH03SE6>DLiAcE8>DXiBCDV>DLiJ3U8=DP]9c4W=DP2>FP01CU7?FPmJ3UX>DL00SU600Dm
Icf8>FLiJ3eX008iJ0DiA`03>BHiAcUW008mQ`03?DDi945V0095Z003AHQ5Z4FY0095Q`0:AJTm[35;
?F]9bd5954<400`03403344334000a1P464<H@0534402@a0364@H11Q100001aPJa5on00:Ool01fZd
CO1R]GoKOmegNWoM00Moo`YooPEogPEog@MogP9og@QogP=og@EogP=og@EogPAog@=ogPAog@03Omio
gGoM02Qog@=og0Aog@0:NkegVgoNOomooWmiI[A=[DETJ`d2OoP01W]iJY8TQ@01100@H@<<@003364<
HPaQ00@<@@@880L8@00@340<@@`P240<80P0220<HAAP440DPABR588@HQB25:<36:<01QBR5:<Ha1BR
6:8L``8Pi0074:8DXac55:<DPQ2246400Q2200@DP@a0468@PP<DXP036:<DXaBS008DX`095:8DPQBQ
588DPaS37<<DPAB2008DP`8DPP035:<Ha1c4008La0067>@Ha1B2468<HA1R0a2200@DPQB1584DPPD@
HP07488DXaS36:<DPQ2248400a1Q00<@HQ2248400Q1Q00L<@11P464@HQ22588@PP02468246401Q11
340880PP320<@08<H@0>484DPQ21340<HA1Q364<@@Q1240<@11Q360<H@<<@@05340@H0a0220<@002
46401@a0220<@0a046000PaP00H<@@PP340@H11Q3643344234001A10364<H@aQ34400`a000<<H0a0
34400`aQ00<<H0a024000`a000H@P0aP364<@0aP2642260336001PaQ360<@0a01208@048HP0000=g
NWMiMgX01WNJ0gNK2GNJ1GNK00EkVW^KNi]kVg^J009kV`04Mi]g^gNkMk/2Mi`2Ni`2Mk`00g^lNk]k
_002Ni`2Nk`3Ni/5Nk`00g^kNkak_008Nk`02W^mOkek_G^mOkao^goKOmUk^g^K0W^l27^m00=o_WoM
Okh00Wnn00=k_GnnOmd00WoM0Wnn00=ogWoMOmh00WoN0goM4GoN00=ogGoNOmh057oN0Won00AoogoM
Okaog@QooQ9oo`06Ooeo^flGK]Mbmgnl1Woo00UoggoNOomoofkk40T000@022002@PQ00l40000400d
a3d6<<E5RVI^K_5>3345;<@/`c3T;>@0134500T`i345<@Da1RcV7<H@A0`044800a1S0Q1R00P<@@PP
58<U22dW=DLiAcD50S4500L/i2BS964L02B0DNQg^P05Ool027LlDDlXIa`3:4LdY7oFOo`2J_001Woj
OomooFZCEO1og09oo`05<Dl/YcCT=@@i9@02>DD2>DH00cU7>DPiB003>DL01CUX>DPiBCUZ>DT00SU8
00<iAcU8=DP00SE800<eAcUX>FP00ceX00<iJCUX?HP00ceW00DmJ469?FPmJ3UX00<iA`0@=DPe9ce7
AJU5bSf7?HPiASeW@HQ9bTgZBLY5ZDVXBLT2BNX02D7[=DQ1RU8<@DXHI0@030088004344234004A1Q
368<@@aQ368<H@a1340<H@aP464<H0P0000PX6/BOo/02Woo00MVUE8BIaMog7^kKcMog@06Ool4Ooh0
17oNOoiooWon27oN1GoM4GoN00=ogGoNOmd01GoN0goM17oN17oM0goN00=ogGoNOmd0;goM00=og7oM
Omd00WoM019k_GoNOomoogonNaYV]Df[CJAcCgogOoUc=eH?424400PQ464236402@a02408H@aR48<<
HPa124488@0222092404320010`0320<H1AP0QB100HDPQ1R344@HQB26:836:<25:<02QRR588DXQS4
7>DDXQBS6<DDXaB20Q2200<DPQBR58400Pa000`@PaB25:<HXaS45:<HXaBR588@PQ215:825:<011RS
6<8DXQB20aB311B200<DXQS46<@00QB200<DPaBS5:<00Q2200P@HQB26:8LXaB2488DHP`P0Pa100D@
HQ235:<@PQ1Q008@PP06464@PQ1Q468<HA1Q0PaQ0a1Q00L@HQB2588@PQ1Q340@@@0246400a1R464@
H@0246402121488@PQ22464<H0aQ388348802A1R464@HA1Q364<@0a1464<H@034400111Q560@H0aP
0`a000@<H0aQ364<H@888004360<HPaQ364234401`a0344<@@a1364<HPaQ008<@@04364<H0a03442
36401A2S48<<H@a022000P`P00@@H0aQ3648@0@8H@07240<H0aP364<@0PP32000PQ00@QR00000gMj
MgUgN@04MgX00gNJMgYgNP0;MiX01WNKMiagW7NLMi]gVP=gV`=kV`03Mi]k^gNk009gV`08MiakW7^L
Mkak^g^KNk]g_0Ak_003Nk]k_7^l009k_003Nkek_7^l009k_003Nk]k_7^l00Ek_003Okak_7nm009k
_@06Nkak^g^kNkUgEg^K0g^l00Ao_7^mNkek_@Eo_@05Nkeo_W^mNkeo_P03Omd2Okh00goNOmeog@05
OmdXOmh2Ooh01GooOmek^goLOod02Gon47oo00IooWnlLeU^n6kGOkd6Ool2Omh2Ool01G]n84/000@0
22002@PQ00h400P0640m13d6<<I5ZfZbI]59jbcS::</i33T0c4500Te1345<>@`i344;@H/iB363280
0PP000D@@Q11324@@@a1008<8005220LaBdV<BHe9@03=@D2=BD01cCR;:4THB229<EFKWod00Eoo`0B
IYP`k@`6;6IZC7ngHXQ1QEj<Li]F<bc764@iRfl?GYDTZbbV0SD300Di93DU>DHiASeV008mA`0:>DLm
B3eX@FLmJ3e8>DPiBCUY?FT3?FP03CU7=DHiISE7>FTmRD67@FLmJ3UW?FM1QdF70091R091R@91J003
?FPiAcU7008iA`0;>BLmADFVAHM5Yd68@FQ5R4FYCN]EjP02DLT2ENT034gYDPY:2TG9@LYB34E998D8
00`0220<8@<<@@<<@0<8@@05240<@0a0340<H@0246401PaQ100001b0LeAoo0Yoo`07IYEB4VliOm]k
VV/EOmd01Goo1Won00AogWomOmeog@=ogP04OmeogWoNOmh5OmdAOmhTOmd3OmhQOmd3Om`3Omd3Ool0
3GoOMaaJ<DEYDNAoT7ofOkUc5TF>200000a1008<@003360@HPaQ00H8@@888@03220<@0Q00088@088
8088@088808<800:324<8110460DP1bR7><LiABS468258802AB1588HXQRS588<@AB1588DXP035:<0
0aRS5:8DPP0258836:<00aB1464@HP0348826:8031BR588DPQ1R240<@1B1588HXac36:4@P@8@PP07
58<@PaBR5:<DPPa036400QBR00`@PQ1Q464DPQS35:8@PPaQ484PhbD66:<246401`PP100800PP244<
@A1R008@PP05588@PQ22488@HP0246401PaP340<H@aQ468@H@8@PP8@H@08460@HA1Q464<HA1R488D
PP8@P@03488@P@aR00@<H@04484@PQ22488346401`aQ340480a0464@@0`P008@@006580<H0aQ364<
H0PP0PaP00L@HA1R344880aP344<H@0334401Pa0344<@@a1364<HP8<H@03468<HA1Q008<@08<H@8<
HP08364<H0Q0340<811P488<H@H8@0051208@0QP340880023401360136800008MgYgNGMiMgYgNGMj
MgUgVP9gNP]gVP04Mi]gW7NLMi`<Mi/5Mi`2Ni/00g^kNkak_003Nk`00g^kNkak_002Nk`2Nkd;Nk`0
0gnkOkak_@03Nkd01G^kNkYgN7MHNk/017^l0W^m0Wnm0WoM00=o_W^mNkd00g^m00Ao_WoMOmeog@9o
_P03OmiogGoM00MogBAogP9og`9ooP05OmiogG^jOmaoo@09Ooh@Ool01WonOmacFV[hJ_IkVPIoo`09
OoiogWooOomogc3]000400P000D88@848@888P0A12480222?@@i1CD7BNiV/fKCAN/`i2c3<>D/hc44
=@De9@02=@D02c3U;>@a1C57<BDTaA12304D@QAR44400aAS00DD@@P0100HY2d4008a1@09<BDe9CDU
=B@i9CD4;></`RAP008P@003BJYgW7oo00Aoo`0HOgm=TSB5=<Di1c44:>@]12T68:@D0@`27:A:358a
<@/XHcCS=BDi9SDV>DLmB3eW0T5W0SeW0T5W01A1R3eY?HU1RSf:@HY1RD68@HTmRCU8=DL]1SE8?HU1
R457@FTeB4690dF801I1J46:AHY5J468?FPiB3E7>DLe9SD4>@A5IT5VAHQ5J4EY?DI5ZTgZFPYEb@9E
jP0<DNYB2eH;CP]62dX^DRi9JRAT200<00`P10a10Pa010Q10Pa000/<80a0464@HQ1Q36440000785g
Mgom00Yoo`07IYA9lF/iOo]k^FmFOmd01Woo1Gon1goN00AogGoNOmiogPEogA5ogPUog@9ogPIog@Eo
gPMog@03OmiogGoM00Eog@EogQiog@=og004Omeog7_MOoh2Ool02WnnJaY=[D5VETYodWohOm]ZmST[
0P@000@8@0a0340<@08<H@062448@0PP1208@@a10PPQ00<8@@a0220010PP0`Q000D8@@a1340<@@`P
008@H005560DPAcT7>@DX`0258<0211Q584HXQRR5:8DPQAR464358801Q215:8DXQBR468DPP8DP`DD
PP05488DPQB2588HPP0258802Q1Q468@HPQ1464DPQR37:<DPPQ00Q220Q2301XDXQBS588<@0a1488D
XQB2488<@A2258<DPQ1R368@PQcT9@HDPQ1P464@HPaQ348<HQ1R0Pa10Q220QB20Q2200P@HQ22464@
H11Q488DXa220a1Q0a1R0a1Q0Q2200D@HA21484@PA22008<H@06240480aQ364@PQBS0Q2200<@H@aQ
34400Pa100P<@0Q0240<@0`P344@811P0Q220PaQ00P<@@aQ440@@11R364480a00`a10PaQ0`a10PaQ
00<<HPaQ36800PaR00<<H@`P34001@aQ10a000D<H0b2364<@@Q100@8@088H0062648@@a1344<@0aP
0@aR00000gNIMgUgN@05MgT3MgX:MiX017NKMiagW7NL3GNK17NL0W^K00=gVgNLNk`00WNl00Ak_7^k
Nk]k^`ek_09k^`9o^`08Nk]k_7^lNk]k^7^IMgUkVP9k^`=k_0=k_@06OkeogGoMOkiogW^m0Wnm17oM
00=o_GoMOmd037oM2GoN00=ogGoNOmh01GoN0goM4GoN00IooWoNOmeo_7oLOod;Ooh?Ool01WoMMg]_
66lGNiYogPIoo`05OmioogooOom=T00200000`@032088@022242220040PQ12488P00100PPT45?@@m
B5I@H[=Re4G/=@@a13DU0S4400/e1C45=@De1S3V<>De9d6Z@JPa1BS5008/Y00;:<@Ta2357:D@HQAR
66<<8Ac5=BDe1002=@D2>BD033TT>BDe1343>B@e0bRQ::DPIRcXFW9oo0Eoo`0@HYE=/56>?BP`aBcT
;@HX`RB362<XaEh]K_I=cc35<><2<>D01SDV>DLiAce7?BI1A`A1I`06?FLiAcU7?HU1RTFZ0T6800Tm
J3DU;<@XXbc4=BDmJ468?DL00SU800Li9ce8@FQ1RD5Y>DLmA`02@FL053TU=@D`i2cS<><``c3T>@Dm
9Se5?BHe1CTUAJUEjUGYDLUEjUX:ERX3DP/01Dh;ETmNCdV;:8@00PP000<<80a034400Pa100<<@0a1
34400`Q100P<@0Q0320<80a0364@H@aQ0P0000<LXgNHOol02Woo00MRLdW`JcQonW^hLeAog@06Ool2
Omh3Ooh2Omh2Omd2Omh<Omd00goNOmeogP0<Omh9Omd2Omh8Omd4Omh>Omd3Omh8Omd00goLOmeog@05
Omd00goLOmeog@04Omd2Om`00goMOmaog003Omd5Om`00goKNk]ooP02Ool03WnnI]Q=[4FXH_9omGoi
NkYR]C3Y000400aQ3402320434001@aQ3448@@Q122400PQ10PQ01PPP00@8@0a1340<808<@005460@
@11P560HX@025:8031B2468@HARR7>@Pi1S35:<DPQ1Q364@H@<DPP046:8DXaB2588446402A1R588D
PQ22468<@11Q588DXP0358802A1R464<@A11588HPQAQ340@P@03488011B25:8DPA1Q0PaQ00<DXQc5
58800Q1R0Q2200T@HQ225:8H`QRR484<@11Q5:<00a1R00@DPa1R464@H@8@PP8DPP08488@HA1Q464@
H1B15<<DX`8@PP05588@HQ1Q464<H@02464248800a21464@P002480248401`a02208811P464DXQS3
008@PP04364880@0244434002`PP120400`P340<HA21364<@@a034401@aQ0Pa00PPP0PaQ00<<@@a0
34400PaQ00<<HPa1344010a10Pa00PaQ00@<@0@P120<@@8<@005364<HPa11208800234000`Q0340<
H00236001@aQ344<@@Q034000@a100000gNIMgUgNP02MgT01WMjMgUgNGMjMiYgNP=gV`MgVP03Mi]g
W7NL00mgV`=gW003Mi]gW7NL00Ag_004Nkak^g^kNk/?Nk`00g^kNkak_003Nk`01G^IMcIgN7NKNk/0
17^l0g^m17nm00=k_GnmOkd01GoM00=o_GoMOmd02WoM:GoN17oM1Gon0goo00=ooWooOol03goo00Io
gG^MJaU[6G^JOmh6Ool02GoNOoioogooJUD40000100<8@0522402PPP12448@00200PPccS?@A5RUYa
0V;C00=5kC3T=BH00STW00<e9cU7>DL00SU701TiB3e8?FQ5bdWZ>HTiB3TX=@Le1S3V;@La9c4X;>DP
aAR4:<@mACTU>BHiAd57@BHmAP02?DL02SU7?DLmJ3U8=BTi:C35::A1JG=k1Woo00mg>5F;><Dm:3eZ
?FL/aRR6=>Ac2WoJK]A1RSeY>BP00SU900`mJCf9@HU1RDV:BHU9R4fYCJY5RDF[BL`2CL/01TW;CL]A
bTg;BJY5J@91B00>@FQ9Zdg:AJ]1JTF;BJa5Zd6:ALa=k4W]AJ]5RP95R@03?BHi9STW008i9`04>BHi
9d5Y@HX2AJ/0146:BJYEjeX/0eY>0eY=00YF;4h=EVmVKTf[96<800`0320<@0@<@@03364<@@a100@8
@@8<@@08364<HPaR368400008<=gV0Yoo`08OmeRLU8?KcQonW^iKcIog@Eoo`03OmmogWoN00AogP03
OmeogWoN00MogP03OmeogWoM009ogA5ogPMog@EogPMog@EogPeog@03OmiogGoM01Yog@9og09og@03
OmaogGoL00Aog00CNkaoogooOomkO5jGCJ]9j6/eOoUong=iFW@XZ@@0200<HA1Q36000a1000DDH@a0
344<H@a100<8@@03344<H@a10088@0032448@0PP00<8800=340<80a0320@@11P340DPARQ5:8@HABR
5:@00QBS00DLiB467@HHY1BS00<DPP8DH@06584HXaBT5:<DPQ1Q0`a100h@HQB25:8@PPQ1120DPQc4
6:8DPQR2588HPAR20QB200<HPQQQ56400QB100<@PA225880112200X@HQ225:8DPa1R364@HQ2248<@
HP8@H@05588DXQ1Q340@H@02488246801123488@HA1Q0Q2200@DPQRS488@H@8<@@03440@PQC3008D
XP8@PP04464<@11Q364246402AB35:<DPQ22484@HA1P484DPP0346400aAQ6:<@HP0246800`aR364<
HP02364334000``P344<@P03344336432202364020aR488@PPaQ340480PQ36433683348334401`a0
344<@@a1340<H@aP008<H@03320<@0a100@<H@06340<80PP344@PPaQ10aP00D<@0a13448@@Q00048
@@0000=gVGMiMgT01WMi00=gNWNJMi/00WNK1gNJ2GNK00=gW7NKMi`00gNK27^K00Ak^g^LNiak_0]k
^`ek_005Nk]kVWMhLcEkV@02Nk/4Nk`5Nkd2Okd4Ok`AOmd3Omh00goMOmiogP0;Omh2OmdFOmh4Omd5
Ooh3Ool00gonOomoo`0?Ool01WoMNia[6F/HJaIog@Ioo`09OoiogGooOomfn10000080@`Q00<88@<8
80052248@@00320XPP02><8094VZGY1[55jbANd`i3U6>DPi9cDV>DLmJ45W@FPmB457@FQ5bTG8?FPm
JDF:?DPi:3TW>BHiASUW=BH]1BC4:<<iACe5?DLmJ091I`0??FPmJCeY?FY1Rd6:?HTmJD5W?BL/a2c6
=BYBDgNK00Eoo`0>J[HdQ2QR<<Dm9SD786D/X7/SOoMkM5H<AJe5c@95c006ANa9kDg]CNeAk5X;0Uh[
00=J35H<FRd00V9`0V9_00aVT6J?IY1VT6JAHTmN3F9>IY5Z/FJBIW82HU401f9bHY5RTF:AGW5RL5i?
009N;P0:GTiNCei>FTmF3EG]FPeJ;Ui?GW02GTl01f9aHY9RTUibGY5RLEi`009JL00:EU1B;di?IZi=
ZbR3200<00`P340734401@a02208@@a136401@aR00@88000:@=k^@Yoo`08OmaVL5H_KcIon7^HJaMo
g@Ioo`iogPMog@UogP03OmeogWoN00EogPMog@QogPQog@03OmiogGoM01Qog@03OmaogGoL00=og0Yo
g@=og003Omeog7oL00Iog00@OoeoogomNeUJDdV8BLE_MgoiOo]cF58a86L400P03444340020PP320<
@0Q12408@@PP2403244010Q0340<@0Q10`Q000<880@P22000`a000P@H11Q564DPQc27<<HXaBR0QS4
00<DXaB25:@00QBT0QB300LDXaBR588DPQQQ588DP`03588258<02a1R488@PQBR488<HPaQ6:8LiAcT
5:800QB200<HXQc36:800QR20QR100<HXQB146400aB100L@HQ1Q464DPAS36:8DH@0234401A2258<D
Pa1R34000PPP00<8@11Q4840111Q00HDPAS3488<@11Q58435:82488246800a11468@PP0248400a1Q
3648@002340;46400aB1488@H@0246403A1R464<@@a2368@PQBS488<H@aP364<@0PP008<@@03440<
@@a100@<@@D<H@03360<H@a100@<@@8<HP8<@P<<@@<<@005240400@P240<H00248401`aP344<@@a1
364@PQ1Q00<<@0073448@@a1244<HA2246000Pa000@8@0PP244<H@4<HP0000=gVGMiMgT01WMj0WNJ
0gNK00AgVWNKMi]gV`=gVPYgV`=gW09gV`]kV`03Nkak^g^k00Uk^`=k_003Nk]k_7^l00Ek_007Ok]k
_7^KMeQc=g]iNk/017^l00=k_G^lNkd01G^m00=o_GnlOk`00gnl3WoM1GoN00=ogGoNOmh02goN0WoM
5WoN0WoM00=k_7oMOod00gon17oo00=ooWooOol03goo00IogW^mKa]Vn6;gNkd6Ool027onOmeoogoo
Og/X00001045224222004@Q1344400`P<<@m13cTBJ]NT6ldG]=5cCTV=BHiB3U7>BL00Se700U1Id5X
@FLm9DF9BN]5Z468@FT00TF:00A1RT5Y?DPmI`95ZP07=FT]1bC4>DM1RD68AJT00TFZ0111RD6:@HY1
ZdF[@J]1RT6YAJQ5ZD5X>>EAB4e9DNmgN0Aoo`0<Ome=:C1TB@I^T6Id=@`XPfk6OoMc<Eja0Tg]00=F
3U8>DPh00U8>00EF;UI>EReB;EI?00=JC`06FW5NTUYaFW5NLF:A0V:c00MVe6:CGU5ND69aIY5RLP02
GU8016:DH[AR/f:c0V:C00ANTUiaGW5JL@ANL@9ND00EFU1NLF:cH[=R/Ei`GW5R/fJdI]EV]6:CHY9V
e6KCFW5><59aI[1AkC2T00880003220<@0a100X<@@0:364<HPaR36888@`P100002TTOo/:Ool027om
IW1J;flgOoMkVF/hOmh6Ool@Omh5OmdCOmh5Omd9Omh5Omd00goNOmeog@0EOmd3Omh4Omd3Om`;Omd5
Om`01goMOmaog7oLOmek_7oM009ooP0=Omeg>58BAFM=i6mFOoUk^g=G@Jd<8`0020000P`P1`a00PQ0
0PQ100H8@0PP2208@@a0244224000`a02408@00434402@a0564DHAB25:8LXRCT6:<DX`025:@02aB2
464DY12T48<@HQBS9@LPiABS58800QR20QB200HDXaRT6<DDPaAR48825:8358801ABR588DPQB258<0
0QBS00DH`aBR588DPQB1008L``@DP@07464@HQB2584HXQS36:800QAR00X@HQB258<DP`a1220400P0
340@H@8@PP8@H@04588HXaB3488246802Q1Q5:4DXQ2248<@PQB3588@@@a10Q1Q0Q2100D@HPaR468@
HPaR008@H@06340@HA1R468@HA1R0a1Q01L<PQ1Q464@PQ1R344880aR48<@PQB3468880aP464<@0PP
440@@A10464<@0P000<<@@8<H003364<H0aQ008<H08<@0@<@@06364<HQ1Q440@@Pa10`a000H8@@Q0
220880a04602364010a1220<@@a10PaQ00D<@0aP364<@@Q1008<@@03340<H@aP00<<@003364<HPaQ
004<HP000gMi0gMj2GNJ0gNK1WNJ1gNK0gNL0WNK0W^K0W^J2g^K2g^k1W^l0Wnk00MofW^kNiYg=gMj
Nkak^`04Nk`00g^mNkak_@02Nkd017nmNkeo_Gnm1Wnl5WoM1goN00=ogGoNOmh00goM5GoN0WoM00=k
_7oMOo`00Won00AoogonOomooP9oo`03Ooioogoo00ioo`06Ooik_VlkJ_YZn7^M1Goo0Won00EogGoo
Oomo^cB7008000033248@@PQ00<88@06220480`P000<03C40T4500M=bej>Ja5J/Sf/=BHi9P03>DL0
2Se7?DI1QdFZAHPmATFZERe=jTF80dF914F:00Q9bTW[AJ/iJC4W=DQ1RDFZ0TW:00A5ZTFYAHU5R@=1
R@0;@JU1Z4FWAJQ9Z4E7FL]V]Df]ADIc<`04Ool00fiaCDeoo`02Ool035ij;>UEYg;;K^aJJe8;DN]=
k58=EPeB3@9F;P03ETiJCeY?00=JL007GY5R/f:cGYAJLUIAFU000Uia00eJDEiBGU5NLFJdI]=RTf9c
HYAV]6[EJ_EVe002H[@2H[<3I]@00f:cGY9NL@03GW0055Y`GW5JL5i^FTeNLEjCH[AReFKFHYAV]6:c
I]9N/dh>BPmRL57^;8@220000`PP340<@@0234400``P244<@@03344236401PaP344<@@a2324<0080
0003:@=oo7oo00Uoo`07OoaVCUH=JaIo]7]hLg/01Woo00=ooWoNOmh03WoN1GoM2WoN00=ogGoNOmh0
0goN2WoM1goN37oM00=og7oMOmd03GoM17oN0goM17oL27oM0WoL00=ogGoLOm`01WoM00Aog7oMNkeo
g@9ooP0>Oma_64f_AFIB9W>GOkQkV7<d>BT80P00220<@08<80@<@003460<H0a00088@08<@0052408
8@@P22088@022405340234401@a0464DHA1R48800QRQ00@HXQB358<DP`8DPP8DXP07488@@ABS:BLU
1QBS68<00QR211B200D@Pa1R344@PQB200<DXP04588@PPaQ3642588011B1588DPQ1R0aB100<HXQc3
6:800QB100D@HAAR588DPQB100<DPP08468@HaAR588DXaRT464400<<@0@@H@03468DPa2200<@PP09
468<@1B15:8DPa23488@HAAQ00H@H@8@HP0<244@HQ2S5:8@PQ1Q444@HQB2584@HA110Q1Q00<<HQ21
46401PaQ0Q1Q00L<@0PP460DPQ1P340@H00244000a1R44040004340546000`aP460<@00234002@a1
364<H@aQ464@80`Q344<@0023442340020PP2408@0aP340<H@a13402220010Q1220<811P0PaQ00@4
80Q1344<@0<8@0<<@04<H04<H@4<HP0000=gVGMiMgT00WMj2WNJ00=gVgNLMi`03GNK0gNL17NK00=k
Vg^JNiX02W^K1W^k0g^l0g^k1G^l0gnk00Ak^g]jMeQkV`9k_003Nkek_7^m009k_@03Nkak_G^m00=k
_@9o_@Mo_0aog@=ogP=og@03OmiogGoM00MogP9ogAQogP06OoiogWoNNkeogGom17on0goo0gon3goo
00MooW^mKe]_6V/HMiaogP05Ool01WonOoeoogooOoe5KP80000322488PPQ00<88@0?220480@0000D
@3SU?@E19U7;HXiVkeJ@?H`e9ce700<iA`0<?DM1IdF8@HU1ZTW[GTaNCDVZAFM5RDFZ14F[00a5ZTW;
BLY5bd6Z>FXe:Cf:AL]AjeH;DN/2AJX00dF9AHQ5R@02@HT02d68@JQ1ZDF9BHUEk6;DHTi90dU6J_D0
0goo00=oVGJAOmh00Woo00UVoSe==@EEZ68YCP]9jdg[CN`00Th=00=B3EH^ERl00UI?011JD5Y`EW1F
LEYaGY9FLU8aDS1B3eH_FU5NLV:dI[ERU0=NLP06GW=RUF:EH[EV]FKD0VJd0V:d00QRe6KDI]EVeF;D
H[9NTEia0Ui`01AR/V:cGW5NKeH^ES5JTejdH]IRe5jdFW=R]5jcFW=9kDh_GRm=[Bb50PP000<880`P
34400Pa000<<80Q134400Pa10PaR0PaQ0`a100H<8110200002DTOod:Ool01golHRiF3FlgOmUkVW=I
00Ioo`03OoiogWoN01aogP=og@EogPMog@QogREog@=og0Mog@03Omao_7nl00Yog@=ogP0>OomooWnl
J_M9[T55HZaonGogOkU^d33510400@8<@003440<@0a000@<@006364<@0a0340<80a010a100<8@0a0
24001@a000L8@@PQ364@PABR588<H@026:801ARS5:<HQ1R37<@00QB200XPaAB2220DPb466<<@HAAR
68<HPP8DX`03588@PA1R00<@HP09488DPQ22488<HQ1R364<@@aQ00<DPP8@H@05488DPQB2588HX`02
58800aB1588DPP0358801a1R464@HQ2358<DPQBR008H``04464<@@aQ3603364446803a1Q488@PQ22
468@@AB1588DPa23464<@11Q468@H@0246802Pa1340880PP464DXQ2S5:8DXa210Q1R00@DPaRR588D
HP8@HP05388<HPaR468@H@0336803`aQ340<@0`P340@H1RS4648811P464<@A22464<80033400111P
464@HA1P0`aP00H@H0`P320@@11Q48825880111Q440<@@a11@a00PQ000D8@@aP364<@@a000@<H@8@
@005464<H@Q1364<HP02340224001PQ12408@0a0364<H04<@@0000=gVGMiMgT00WMi0gMj1gNJ0gNK
0WNL1WNK1GNJ1GNK0g^K00AkVW^KNi]kV`EkW0AkV`Ek^`=k_0=k^`=k_0Ak^`05NkYkVgMiMeMk^P02
Nk`5Nkd3Nk`3Nkd8Ok`00goLOkeo_@04Okd6Omd3Omh8Omd6Omh2OmdDOmh4Ooh2Omh01GoMOmaoo7om
Ooh00Woo0Won00=oogonOoh03goo0Won00IkgG=lKaU_67MjOmd5Ool3Ooh2Ool01EhD008000P02280
10PQ00D880@Q100001QR008m1P0;ADQEbfJ_J`mJScf<>DPmAcU7?DLmJ002@FL03dFX@JY1RSeVFRQ>
2dF9?@A9R4W;BJ]=ZdV[AJY9ZP04AJX02D6/>F/iJDFZCN]AjTWZBJU5Z@04AHP03D68@HU1R46ZAHU9
R5WZHXaZZeW9=>Q59f:a00Moo`0>EY`Xbc37AHY5bTG[BNY=jTg[CPa>3E8]DRiF;`9FD00<FU1FCeI?
ERmB<5IAEW=N]V/HMeUo_7on17oo00EogWnLOiag>f;G009FD`03GWANLUiA009NL@03GY9R/f:b009N
TP9NT003FVmNLEi`00ANL00AFTmB3dg_FU9ReFmIOmUgNVliH[IFDeHaCNi><5X`BJd`YP0220000`PP
320<800734000`Q1340<@@02344020a0344<80`P100002U5Ood:Ool027olGPeF3VlhOoek^g=HOmh5
Ool00gonOmiogP0:Omh5Omd9Omh7Omd5Omh4Omd00gnmOmeog@05OmhXOmd00goLOmeog@05Omd3Om`3
Ok`8Omd00goLOmeogP02Ool04GonOi]Zmdf^BFEZkWoiOoQkN6Z^968000@Q364<@11P32000`a01@Q0
0``P0Pa100D<H@Q0220<@0Q0008<@0<8@088@@0I468DXQC35:8DPQBR6:<HXQBS6:@LXaRS5:<HXac4
688801116<@Pi1RR588HPQRR5:<00aBR0QB200L@PQB2488@H@a1244<HP0448800aBR6:<DPP024642
22001a1Q588DPQBR588DXA22008DPP05688DPQ11200@H@025:802QB25:8H`aRR584@HA21480<H0aQ
111R00H<H@a0240@PA2258<246801Q23488@PQ1Q360@H@8@PP8@HP0C368@HQB29@DYAacU484DPA21
584@HAB38@LU1QRS588DHA1Q48800Q2300<@HQ1Q36400`a100@<80PP220<@08@H007480@H11P464<
HQ1R46400`a00Q1P00<@P11P46001Pa000D@H120460DP11P008@@@04340<H11P360534000`aP340<
H@0234000`aP240@H002460234000`a1340<@00534052401340134400003LgYgNGMi009gN@IgNPAg
VP05Mg]gO7NLMi]gW002Mi/2Mi`4Mi/00gNJNiYgVP05Mi/2Ni/00g^JNi]kV`02Ni/6Ni`4Ni/017^l
Nk]k^g^k0g^l0g^k0g^l00Uo_7^lOk]k^g^jMgUgFW^JNk/00W^l17^m17^l0g^m1gnl00=ogGoLOkd0
1Gnm00=o_WoMOmd00goM0goN00=ogGoNOmh00goN0WoM1goN0WoM5GoN0Won0WoN00AogGnlOoeooP=o
o`9ooQAoo`06NmicNflHKaIc=WoL1Goo00=ooWoNOol00Woo00AV^@@6000400@88@88@P0?14400000
664m1D47AFQN2f[aKc1FKcU[>BLi9SU7008mA`91I`0<@HQ1ZT6:?DE>2DX<>BHhhdV:ALa=bTfZ0dVZ
00U5ZTVZBJY5bdh>?H/a:45YAJX00TW900=9ZDFYAHP00dF800M5RD69@HU1ZT5XBHQEb@02HV`01Dg<
>BTdYD46KaD00goo00YoggooOolaMaP6;<He:46ZALa9k09=j`04CNaB3E8^DRh2DRl01e8aDS1=kTW;
CLUVdgok011oo`0=OkeoVgLDGW5B3eH`GY=N]5ZBFW9JLEI@FW000UYa00aF;UH/GTiJCUY?FRiAkdf^
EPi_=WokOo`2Ool027MHI]EEkTg=BPmN<4f];:D220000``P3408@0033406344524401Pa110000000
;FMooPYoo`07OmeR3EH?JcQog7^KMi/01goo37oN1GoM2GoN1goM2GoN00Ek_7nlOmeogWoM00=ogPeo
g@03OmiogGoM02Aog@=o_0Aog@06OkeogGoMOmao_G^m0Woo011ogWmHI[E=[DeSK`mofWnjLeMRCQQ1
00048@aP440@H0<<@0H8@08<8004460<H@Q126452402220224001@Q1240@HABS4:<00QBS00LDPaB2
484DPQB38<@U10036:<01aR2320@@1RS:BHHXaBS00<DXP8DX`046:<DXaB258825:82488011BQ5:8D
PQB20QBS0QS400@DXQ1Q344<@@8<@005464DPQ1Q488DXP0358826:801AAQ464DPQS45:<00QB200TD
XaBR488@HQ1Q488@Pa2246800`aR0`aQ00<@PA2248<00QBS00@@Pa22488@HP@@PP0:468<HQ235:<L
iB46;FXY9aAQ584246401@a0368HaB466<@00QAQ01@@H@b2488DXa1R340880a0344<@0PP340<@@a0
360@HAB16:<HXQB20PaS00P<@@`P320<@11Q484@P12110aQ00<<@11046000a2100<@HA1044000Pa0
00D<H121488<HA1P00<<H003464DPQ22008<H@07360<@0a0364@H@a122001@a000@@H@aQ340<@0<<
H04<H@4<@04<@@0000=cNGMiMgT00WMi00AgNWMiMgUgN@=gNP=gVP03Mg]gO7NL00MgV`03Ni]kVW^K
00EkVP05MiYkVWNjNiYgVP02NiX4Ni/5Ni`4Ni/00g^lNk]kV`02Nk/2Ni/3Nk/5Nk`01gnkNk]k^WMh
MgYkW7^k009k_0Ak_@Uk_0Uo_0Ao_@03OmiogGoM00Mog@EogP9og@AogP9og@04OmiogGoMOmdDOmh2
Ooh01GoNOmeo_7^kOmd00Won0Woo0Won57oo00IogG=jJaMVmVkdOkX6Ool027oOOmioogooLed<2000
1007224210003R22?<=59df9IV]^kfl>DRheBSCU>BHiAce6?DL2@FL03dF8AL]5RDF7EPYF;3e8?@I5
ZdW]CL]1RT5YAHY9ZP03AJX02DVZBLa1RSe9>BQ5R4gYCN]5Z@03AHP04DF7AHQ5R469@HY1ZTF9AHMA
aeH;DL]1JCT7>@TXQdDUOk001Goo00LeEaP5748a:46;ALe9k@02CN`034W]CNaB3Dh<CL]=c4g^@Ji:
46/FOoUooQAoo`0;Omag>6/HH]EJU5IaES5B3e7^DPmFC`02FTl02UX/GTeNCEY?EPiAkdg?EN]o/gol
0goo00Qong<gFPe=bU8^HTm=cC2T0PP000D880Q0344<@0Q100D<@005244<@@Q124488@0334401@PP
100002e6Ooh02Woo00Mo_5h=EPm[>GolMgUgNP07Ool00gonOmiogP04Omh:Omd9Omh5Omd;Omh00gnm
Omeog@0AOmd2OmhSOmd2Om`3Omd4Om`4Omd00goLOkeogP02Ool03gnlNcMNLDf[CH=c<GoJNkY_=dW^
424000@P460@@003340010Q0220880PP0`Q000X<@10P584DX`aQ2448@0PP240480@880043408@0aP
464248401A224:<@Q1BT5:800QBS00HHXRTT8><HXQR258826:826:<01ARR588@H1BQ5:800QBS00/H
`aRT5:<DXaRS5:@DPQ206<4DXABR00<DX`086:<Ha1BS588@HQB2584DPP8<H@LDPP06568DPQB26<<L
a1BR0QB20a2200D@H@Q0244<HPaQ00<<HP0;464<H@aQ384@PA22364D`aSU4:<@HP0236403A1Q588D
Xa1R344<HQBS6<<HXQB2468<HAAQ00<DP@0=564@H@aR488DPa22468@H@aQ464<HQ1Q22000Pa000H<
H@aR364<@0aQ368346403aB27<8La11S368<H@PP320<@11P484DPA1Q364<@002364020a0440DP121
464<H@aP4402340020a1340@PA22360<@0aP340336043642344010aQ344<@@a10PPP00@<@@a0340@
H08<H004340<H0aP3602464144400003LgUgNGMi00IgN@IgNP03Mg]gO7NL00MgV`03NiYkVg^K00Ik
VP04Ni]gVgNKMi/ANi/00g^lNk]k^`02Ni/00g^kNkak_007Nk`00g^jMgQkV`0@Nk`8Ok`7Okd3Omd2
Okd4Omd5Omh2Omd4Omh3Omd00goNOmeogP0COmh3Ooh01GoNOmeogG^kOmd00Won5goo00MooWoMNi][
5f[fKaEo_007Ool01goOOomoogoo76/000@000H88@<4000O<:8la4DYDHYZKF[@J^m>3SDZ<<Di9SU7
>DHmAce8@FI5Qd68?FM5QdgZAJTi9d5XGReN/Ui]ERe1RceY@HX01DF[00M5ZT5Y?DQ1J4g[CPe5Z@02
AFP2AHP2AHT03T5X@HU1ZTF9BHQ=b4W:@FPm1SdW?DY11e53La85Ool04EII::TL@bS6?HY1c4W/DNaF
3Dg^BJe5[DW=AFQ=ZV:BNgT01Goo00Uog7]HLcMVmfKFI]E_5gMINi/00W^m00=ogWooOol02Goo019o
fgLfJ_INTeH_ES1JDEibFW5NCeh^GTeJCeX_DQ1AceX<Oi<4Ool027omLcMVTEX?FU1VKdg<<<@22000
0`@P2408@@0234400`a0344<@002340334401Pa2344<@@a1464880800003;DIooGoo00Uoo`08OieN
3UX`KcUooG^kKeUooPIoo`03OmmogWoN00UogPQog@IogPEog@]ogP=og@EogP]og@=ogRQog@03Omao
_7nl009og0=og@03Omao_7oN009oo`0AOkec65X?BHYJ2GmcOoQo^f/G?H`80000244@H0`P3408@@02
2402220424023200111P488<HPa10`a00`Q001d<@0PP220<@11Q488DPAR2588@Y0b35:<H`aBT5:<H
Xb3T9>@HXaRR7<@Ha1BR6:<DXaB3464DPABQ00HDX`037>HU9aS5008DXP037<<DXQBS008HX`8Ha00=
6:@DXaB25:8PiB467>D8@@QR6<DLaARS58800a2200P<@0Q158<H`aRS588@PQB20a2200L@HPaR468@
HQ22468<H@02368011225:<@PQ21112200h@Pa1R3448811Q484Da11R340<@Q237<@DXa1R0Pa01AAQ
00LDPQ2348<@PPb238<@P`02464030aR364<@0aP364DPa23468@H@aQ368<H@8@H@03488H`aBR008<
H@04464<80a034033602364434001a10460@HA1Q360<H@a1008<H@04344<H0aP3645340236043640
0`a1364<H@03364236801`a1244<@@aQ2448@0QP008<H003364@PQ1Q004@@@0000=cNGMiMgT01WMi
0gMj0WMi0WMj0WMk17NK0WMj00=gVW^JNiX00W^J00=gVW^JNiX00g^J0gNJ0W^K0W^J3G^K00=k_7^k
Nk/00W^K00=k^g^lNk`00W^l00=k_G^lNk`00W^l00=k^W^INk/02G^l00=k_G^lNkd017^l27nl00=k
_GnmOkd017nm2WoM0goN17oM7GoN0Won00EogWoMOmeo^goL00=ooP9oo`AooPmoo`09OoiooGoMNk]c
EflFJaMgW7on00Yoo`04=C0000@0204422405PPP100400P0;8<licSXBHYN2VJ?HXi=kS4:<<Ha1CTV
>BDmAceX?FM5QdFX0Se500a5R45X=>A1REj@KeMgV6/FFU91RceZ@J/6AJ/03SeY?DQ5ZdX=ALU1Ice8
@FU1J4FZAHQ1R46Y@JX4AJT074F8AFPmBD69HRUblW/bOoYoogokOoYoVVJgBHhPIBc6?FU5c57/EN]=
bdF<?Fi5dEYeKcUongon0Woo00Ioo7nGJaMJU58bCQ42CQ00158@ES5FDEIb0UYc00QJTejdI_Ic=gMh
MiUk^WoL0Wom1Woo011ong<gH[EJDEX`FU1F3EX^GTiNL5Y@FU5AkeX]Mc=onP9oo`09OmekMflEHW5F
45Y@IXmAkC33008800032208@0Q000<<@004240<80a1340734401PaQ12000000=FQoo@Yoo`07OkiN
3eYAMeQoo7^kLgT01Woo2goN00=ogGoNOmd04WoM2GoN1goM0WoN5GoM0goL87oM00Eog7nlOkao_7nm
009o_003Ok]oVgon009oo`0:OmmZn57>@DURSgoCOoQk^Ujd<B/200001@aR460<80@P22001@Q000<8
@@a024400PPP00<<@0a124000`Q000<<@0PP34000Pa00PPP00<<@0aP36400Q2200DDPQBT48<@HARR
008HX`8DPP8HX`066<<La1S47<@Ha1BS0aB200HDXQRS5:8@PQ1R58<35:<01ABR6:<HY1BR58800QBR
00/H`aBR5:<DXaB3588H`bD5:BHU1aS5008DQ0046:@L`aB1364246401`PP368@PQBS58<DPQ2200HD
PP8DX`06588@HQ1Q464<HA220Q2100@@XABR5:8DPP<@PP0>364<@@a0584H`aRR584@PQ235:8HXaB2
464@H08@H@0?440@H1B15848@0Q1368@PA22468<HA1Q488<H@a0008@H004464<HA1Q588236400`a0
360@H00236003@aQ464@HA10320<@0aP364@H@aQ240480Q000@<@08@H@8<H@04360<@0aQ36823640
10a0220480Q01`a00Pa100T<H@aP340<@0aQ468<HPaQ34400PQ100@<@@Q13408@0@<H04@H@4@@000
00=cNWMiMgT017Mi1gMj00=gNGMjMgX00WMk1GNK0WNJ17^J0WNJ1W^J00=gVWNKMi/03W^K00=k_7^k
Nk/00W^K00=k^g^lNk`01g^l00=k^W^kNk/02G^l17^m17^l1Gnl17^m0Wnm3GoM17oN00=ogGoNOmh0
7GoN00=ooWoNOmh00WoM00Ao^goLOoiooQIoo`=ooP05NkagVVlhH_Q_F`08Ool017oNOomoodgB0P00
00H800`P2448@0PQ220210001A@P=<=1BCT9CJ/00V9=01iRKdG=<@X/aSD7=BHe9CU8>DXmJT6;?FXi
:3e8@FXmBCTXAJaFLWNjOoakg6/GEPm5[3f/?H]1RdG<ALd2AL`02TF[?FTmRT7<AL]1RCU7?FU1J4VZ
0dFZ00A5ZdFZ@HY1J08mA`0A@FU1RTFZIVYkDg/_Onioo7oGOhajlG<GFS4XQBQR?FPmZ`03CLX00eX^
J_IoVP04Ool01gonKaMF;Tg:DNe>3e8`00=B<@03ES5JDUib009NT`9RT`0<H[EVeF;EI]E_5VkeI_AR
e6KDLaEgEWnk1Goo00Qon7/CI[9J3UX`ERmJD5Ya0Uia00mEkUi>Ka=oeWonOomkVg;dK_ANLDg?FS1Z
T5H?=>D00PP000<480Q024400Pa00`aQ00P<@@a0340<@0a1324<@@a20PaR00D88000000iR7ok00Yo
o`07OieN<5iAMeQofW^kNkd01Goo00AoggoNOmiog`YogPQog@IogP03OmeogWoN00]ogPEog@07Omio
gGoMOmeogWoMOmh00goM00=ogWoMOmd00goM00=ogWoMOmd01WoM00=og7oMOm`07WoM00=kgGoMOmd0
0WoL17nl00=o^gnKOmd00Woo00Ykgf;GBJe1JVKCOmEofWMhDU4Tb@800004364<H0aQ364234000`Q0
2448@@0224402`a0344<@@a1340<@@PP000480A1340010`P0PPP00<<H121488011220QB200<HPQbS
6:<00QRS00LDPa1R58<DXaBT5:<DP`0458825:8358801QB3488DPaBS488@H@8DX`03488@HQBS008H
X`8DX`0<588DHARS6:<LiAS558<DHQ1R5:8HXQB1111Q00L@PQ23488@PPaR48<HX`04588248825880
111R464@HA1Q0Q2201@<PQ2R5:8H`R3T4888@11Q3648@0PP580DXQ22588DPaBS5:8DPQ1R111Q00D@
H11Q6:<@H@a0008<@@D<H@03368@HA1Q008@H@8@@@05464<H@aQ364<@@02340010aQ460<H@aQ0Q1Q
00L<@0PP364DXQ22364<@00222000`a0360<H@0236400a1Q364<H@02364010a1364<H@a10Pa000<<
@@a034001`a000@<@@aQ364<H@8<@003344<H@aQ00D8@@88@005340<H0aP364<H00134400003LgYg
NGMi00=gN@QgNP=gN@03MgYgNgMk009gV`AgVPEkVP03MiYkVW^J00AkVP03MiYgVgNL009kW0AkV`03
NiYkVg^K00IkV`9k^`9kV`9k^`Mk_005Nk]k^G]gNkYk_002Nkd6Nk`3Nkd00g^lOk]k_002Nk`5Ok`2
Nkd3OkdDOmdNOmh4Omd00goLOk]og002OohFOol02GonOomooGoLMgY[5f;iKcaog`06Ool01GoOOmio
ogooJYD00P0002@800`P220880`P220000@0=BE=k4g<ELaN;VJAK_=V/E8>?F`e2C48<BP]1C4Y<DX]
:cE]>HheSCV^@M0iSCV<BQ1FU6miOoX2Oo`016;ECNm5kT7=0TG=00A5kDW]ANe5k@=5c003AL]5Zd6:
0091RP03AHY5Zd6[00A5b`0H@J/mRT6:AJ]1ZdG:GRIZYW<9N`YolgoeOoMom7nEEP``aRbR?FQ9jejc
KcMoegom0goo015ooVliFYE>4U8@CNeB3EH^EW1NTEYbFU9F<EYBGY=RU6:e009ZmP0BK_EZeFJdI]AZ
mF/FKcI[5F[eH]=R/ejcG[ANeFLGNgAonWon0Woo00aonf/GES9Al57>EPmJ;UY@FRmRKg<COm42Ool0
2WoLKaE^lfJCEQ5NTfZaFRldiPP00P@000D8@0Q1340@@0a000<<@@03340@@110008<@005344<@PaR
48<<H@0210000cfXOo]oo`09Ool01gnMGPmNLG<gOiQgN7^l00Eoo`=ooP]ogPEog@UogP=og@eogPUo
g@04OmiogGoNOmh?Omd00goLOmeog00SOmd01gnlOmao_7oLOkao^goM009oo`0ANkmRedV]BJa[5Goe
OkUcMe8a78H400`Q444@H0a0460<H00234042442344236401`a12448@0@P100480Q0008<@088808<
8008460DXQSS6<<DXQB2464DP@8DPP0;688HXacU7<@HY11358@<@@@P244<HP035882584458800aBS
58<DP`0258800a1Q468DPP0258<011S46:<DXaRS0QRR00<DPQ1Q58800QBR00dDPQ1Q344DXR3S7<8D
PA21584@PA1Q364<HP0248<00aB3588HP@0258801Q22464@PQ22464<@08DH@0?588@PQ23484DPABQ
8><Pi1BR4888@0a0220<@11P00<@P@8@PP05484@HA1Q464@H00446400a22468@HP02368020aP3408
80a0364<HQ1Q460246400a11340<H00336403Pa0240<@A1Q460<H0aQ488HX`a0220<HAB146024642
3402360011215:8DPQ1Q0PaQ00P<H0a0344<@@PP120<@0aP0PaQ00<<H0a034001@a01@a100@<80a0
2448@08880<8@@07240480PP240<@0Q034000@`P00000g=jMgUgN@03MgT9MgX00gNJMgUgNP02MgX2
Mi/017NJMgYgVWNJ17^J0gNJ0WNK00EkVg^JNiYgVWNK009gW09kW09kV`=kVP03NiakVg^K00=kV`03
Nkak^g^l009k_09k^`Mk_005Nk]oV7]FNiYk_003Nkd5Nk`2Nkd2Nk`00gnlNkak_002Nk`4Ok`2Nkd4
Okd6Omd2Okh00goNOmeog@08OmdNOmh02GoMOoeogGoMOmao^goMOmiooP0HOol01gonOmagNVLGHaU[
?7_N00Ioo`09OmmogWooOomk>100000400`P00<8800E10000233H]9gE6kfHWAZ]7MHOgQkMg]iJ[EI
cce/<@T]2CV=AQ5:MDIE009:MP0>@UE6=D8B@O1>DeZeH_I_N7omOoicNdhABQ15k`=5kP06BNi=kEH=
EPe5c46Z0dG;0T6[00E1c4G<ALa5cDG^00963P0<APm:3dG]ANe5c4G;ENQN96J7KZeo]Won0Woo00Mo
oEi@?DU1AeXZLeIoo@05Ool047]iI]EJDUYBGWAJLeibH[AVe6KeI_AReF:eI[IVeV/G0Vlh00=[5f/H
MaL00W;f0V[f00i[5flGJaM[5V[eI]EReF:dFY=NLEY?GY9g=7ok0goo01eoO6JfEO5=[UXaFU5NCfI`
LaAo/WokOoioUG<EJ_ARTeHBGY=^dUH_=<D800@01208@0@P340@H@a000@<@@8@@0<@@@8<@@06464<
@0@01011b7om2Woo00MkO5W^GW5gEgniMiYgW006Ool2Ooh00gooOmiogP08Omh5Omd9Omh3Omd6Omh2
Omd5Omh9Omd00goNOmeog@0`Omd3Om`4Omd00goLOkaog002Ok`2Ool047onMe]NUDW=CNecEgogOm]g
F4G_44@40110464@@0`P0Pa000P<@@aR368<H@a1364@HPaQ0Pa100@@HPaR344<@@88@@D<@009320<
@11P484Hi1S46:8DPQ1P00<DPP07344DPQS49BHHY11146400QB200P<@A225:8HXaRR684HXABR0aB2
0QBS0aB200L@HQB38@HHaAB35:<HX`025:<01QRS6:8DXaRS688DXP8DPP09440@HARR9@DHXPaP584D
PQ21008@H@07364@PaB35:8U11R156400QB20QBS00@@PQ1Q464DH@8DPP8DP`05588@PA1Q7<<HX`02
58801aRS5:<@HA1P480@PA1Q00<DPP04488@HA1Q3642464010a0364<HPaQ0`aR00/@PQ1Q440@@0`P
460@HAB2464@H0a0008<8004340<H@aQ364236800`aQ340<H00236001@aQ484<H@Q036400a1Q0PaP
00@<HA1Q488@P@8@PP03464<H@a0008<H@<<@@04244<@0aQ360236400`aP340<@005340234422200
0`a1340<@@02220020PQ2448@@Q1360<H@aP2443240122400003LgUgNGMi00=gN@AgNP9gN@IgNP03
MgUgNWNJ00EgVP=kVPAgVP9gV`05Ni]kVW^JMiYgV`02Mi`017^LMiakVgNK0W^J0W^K17^L00=kVg^l
Nk/00g^l0g^k00=k_7^kNk/00g^l00Ek^WnHNeIkVW^l00=k_@ik_0Io_0Mo_@=og@9o_P03OmiogGoM
00]og@]ogP03OmeogWoM00eogPAog@9og004OkeogGonOohGOol01gonOmakVf[gJ_U_>g^n00Ioo`9o
gP9oo`04OkTX00000002220030PQ22000000BPQoeGoGJ[9RMW<IOiYon`9oo00JOme^n4G@<DdmlUKi
Ig]SOEmLEaYBf5;ID[MB]TjfD[IF]UkEH_I_NW>KI_M><TW_BPm>3`=>3P05DPeF;E8=BN`mR@02ALX0
14G;AJ]1Zd6[0TG<00I5kDX?BPm63TX?BPh3CPd01Tg/DLUAYe62FLUk5P=oo`06KeY9cDg;GTe_=7of
0goo00UooW<iG[MJMF:EI]EVeVKEH[D00V:d00QVe6KeI_EReFKEI]I[5flh0W=I00E_>F/HKaM^mflG
009[5`03J_MVmV[f009ZmP0:J_EVmFKeH]ER/ejCEU9JLFleOod3Ool06GnoH[QAldgAGU9NCUi`I[9_
5G]CMeE_56JaI[9NTdg?EU1blUX^>>H<00P02208@0Q1008<@0D<@@8@@0D<@006320800@01011Ygol
2Woo00MkO5F/FU1kN7oIMiYk_@06Ool2Ooh00gooOmmog`02Omh;Omd9Omi:Omd6Om`017oMOmaogGoL
0Wnl015o_GoLOomoogolKaQJDdFZDRegNGniNkYZmCE:208000`P008@@004340<80a1340224443400
2`Q12248@@a0364<@0Q03408@@aP34000PaP0Pa00Q1P00HDXABR6:8HXQR1560358800`PP348HX`05
6:8051BS48<@PQS38>DL`aR06:4HXQBR584DPQRS5:<@PAB1488DPaBS6:@25:<03QBR588@PQB25:8D
XARR6:4DXARR588@H@a0464258801121360@H11Q0Q2100T@PPaR58<DXaB17<4LX1RR5:800QB20Q22
00<@HQ1Q46400Q220Q1Q00@@HPa1240<H@8DPP03488HXQS200<@P08@H@04588DXQRS58<246801Pa0
100@HA1Q3448@@<<HP03484@HA1Q008@H00<360@H11Q484@HA1P340800`P340@H@aP0PaQ00<@PPaQ
34000PaP00L<@0aP460<H11P360@H@0236000`a0360<H00636401Pa0344<@@Q1360<H@8<@0042408
@@a03402360010a0320<@0a00`aP0`a00Pa100H<@0PP220880Q0344224000`aP364<H00324412401
22400003LgUgNGMi009gN@EgNP9gN@03MgYgVWNJ00=gVP9gNPegVP9gV`04Ni]kVW^JMiX2Mi/4Mi`0
17NKNi]kVg^K0gNL0g^L00=k_7^kNk`00W^l1G^k17^l00Ek^W^HNeIkVW^l00=k_@ik_0Io_0Qo_@9o
g@9o_P03OmiogGoM00=og@9o_@IogAeogPAog@04NkaogGomOohGOol01gonOmakVW<hJaQ[6W^m00Io
o`06OmioggooOomonCd90P0000<400PP22000P@000P004XZOoUVcUX=FU=VmgNJ0Wom0Woo00YJUCF>
?O1BnEnMHkiKODlJC_Y:f0=>f00;D]UK6V<iG_INeU[FF[EBDTG>BNm>3`02BPl3CRl0158^CPe>3DG;
0T6900=5bdG<AL`00TG<00U5kE8>BPm63TW^BPm:3Th>CRh00U8]00iAjSe6A@AERGmlOomo_eIE:>X]
:E8^JaE_Egoi0Wol00]_Ef:dGYANU6JfI]I[5f/HI_MVmVKF009Ve@9Vm@0<I_IVeVKgJ_I[5fliLeUc
>6liKaQ_5f/G16/H00YZmf[fJ_IZmVKeI_IRmV;EH]IRe@9NTP03I_IogGoo009oo`0HOkmR]eHCEO1N
LV:dHY5NTEj?HY1R/FKCI[9NLdV`ES5^dEX?>>H<00P0220<@0Q010Q110a11@a000<@@1AP42000P@0
00=5igokOol02Goo00MkNe6[FU1kN7nhKcIk_@05Ool3Ooh00gooOmmog`02Omh3Omd3Omh5Omd8Omh:
Omd5OmhmOmd7Om`3Omd04WnmOmeogGonOomo^F[EDNi1AeY=NiQo^WNJHY8XYP@1200@@0<<@088@@03
2408@@Q1008<@004244<@@Q12204244224000`QQ240<@003340346000aB15:4HX@026:801aR2468D
PQBR588@HAB1008HXP0=6<8Pi1c45:8@H`a05:8Ha1bS684HXABR58800QB10QBR0QB200`@PQ23364<
@A228@HLa1AQ220@HABR5:4258802aBR588DPPa1488DPQ23488@H@a046400QBR00T@PA22368@PaBT
5:8HX1bQ6:800aB200@@PQ1R464@H@8@HP@<H@06344<HA22588@PQB20Q2100L@HA1P484@P@a0488D
XP0448801@a0220@HARS48800Q1R00H@HA1R468@HA1P360746402a1P440@@11P688@H@aP368@P`aQ
34400PaQ00<<H11P46000Q2200P@H@Q0360@HA10360<@0aP0PaQ00P@H@aQ340<@0a158<@X`aQ0`a1
10aQ00<<@0aP46000Pa000@<@@aQ364<H@8<@@07368@PQ22364<@@a022000Pa100H<@0aQ460<H@aP
36422441240122400003LgUgNGMi00=gN@AgNP9gN@03MgYgVWNJ00=gVP9gNPigVPAkVP03MiYgVgNJ
009gV`9gW005Mi]kVg^KNi]gW003Ni`017^KNk]k^g^k0g^l1g^k0W^l00EkVW^GMgMkVg^m009k_003
Nkek_7^l00]k_0Mo_0Yo_@Eog@9o_@03Omeo_Gnm00Qog@UogP=og@=ogP03OmeogWoN00QogPAog@04
Omik_GoMOod2OohGOol01WoLNiYgF6[gJ_Qk_0Ioo`06OmioggooOomooDf_0P0010PP01H80000@JER
dUX;@BEAZejdKeQo^W>IHaQ>4SU/=Je>UFNKHieSW5<JC_Y:n@9>f09>f@0<D]UFn6MIGcUJn5JfCS95
cT7=BPm>3TX?0TX_00a>;Th>DRmB;E8/BNe1ZSe6?FQ1Zd7;AL`3ANd3ANh02TG_BPm>3Th=ETeB;E7Z
AFM=RV[F0goo01TdQ`@0;>UJCg=HJaI[>6LFEY=BDUYBFW=NU6KEI_E[5V[fI_IVeF;EI]E[5VlgJaIV
mP02I]H2I_H00f[gJaM_5`02KcP01FlGJ_IZmf[fI_H00VKF16KE0fKf00MReV;EH]IFLeIBFYAk_003
Ool02W]nH[QF<UibJ_IZm6:bGY9RTUjA0V:b00UJU4GAES5VKU7]=>D800@020000PPP0PQ00PQ120a1
0Pa000H@80`010080587OoT:Ool027]jELaF;g^GOmQcEgNKOoh3Ool01WonOmiogWoNOmmoo`=ogP=o
g@=ogPEog@QogPYog@EogS=og@9og0=og@=og09og@Qog0=o_@0AOkaogGooOoioE5i`AHY1IV:]OkUo
nG^JHW8TI@@1348@H@023402220224401PQ0340<@0a1364<@@<8@@092408@@@P2208@@aQ240480@0
008<@005460@P11P484DP@026:404ARR68<DPaB25:<LiABS464DPAR08<4L`QBR464<@A1Q58400QB2
00DHPAB1484<H11P00<DP@8@P@08488DPQB2464DPQBR5:<DPP8<H@09588DXQBS58<DPQB1464<@QB3
008DXP07488@HQ22584L`acT5:<00a2200HHa1BR6:4L`abS5:8258800aB1464@H@04464248825880
0a23488DPP034880111Q340<@11Q0Q2100@@HA21488@P@<DP@8@PP036<<DXa1R008@H008360<@@aQ
464@PQ1Q360@H0<<H0<@H@09584L`ac25:4<@0aQ368<H@a100<<@00:464DPA21364<H11Q364@HA1P
3402360010a0464@PPaQ0`a000@<H0aR364<@@8<@0<8@0H<@003344<H@aQ00<<@@04364DXaBS4683
34002@a1364<H0aQ460<H0a012088002240122000003LgUgNGMi00AgN@AgNP=gVa=gVPAkVP03Ni]g
VWNK00=gV`03MiagVgNK00=kV`06MiagVgNKNi]g_7^k0W^K0g^l1g^k00Ik_7^LNi]kV7^JNi/BNk`2
Ok`3Nkd00gnlOkeo_@08Okd5Omd3Okd00goNOkeog@07OmdLOmh2Omd017oNOkeogGom0Won5goo00Io
oGnkLcM^mVkhNk`6Ool02GoNOmmoogooOoiJ=@01000<8003220060P0000LXTF7@B@l`UVZG[=[5W=i
H]E><D6<;<I1cU;gIi]SW5]JEaYBnTkiC]Q>f@9>n@0;E_UFn5liFcUJeeIdBO59cDh>BPm>3`03BRl0
34h^CPm>3dh^DRe>3DW:>@De1cEY@J]5k0963@06ANe1cD7=?Li5kTX?0U8_00IFD59BFS19JE8@Oml3
Ool01d11500/a69ZJ_AReEJC009FLP03EW=NU6:e00=Re@04I]EReFKEH]D2I]D016KDI_EVmVKf0VKF
00IVeFKfI_IZmf/GJ_L3J_H01F[gJ_IZeVKEI[D00VKE0fKf0V;E00QRe6:eG]EJU4h@CS5NeGom0goo
00QkOVJFHYIZmflGJaQVmfKF0V:d00QN/eZEBO9><V9_DNd`a0P00P@00PPQ00@880Q12448@@L<@@09
244<@@a132080000401FB7ok00Yoo`07NgYAc5Y@OkQonW^jNi/00goo4WoN0goM2GoN1goM1goN00Ao
gGoNOmiogRmog@9og0Aog@9og0=og@=og0=og@03Omao_GoM009o_00DOoioogooOgUNDDF:AJMVl7oi
Oo]gNEX@748000@1220<H@aP340880@8@@043408@0aQ36422442340030a1244880PP240<@0aQ360<
@0`P460DP@8@P@03584H`QS4008HX`0?468DPacV7@LHiABS584DH2336<<DPQ1R464DPQB1008DPP08
6:8L`aBR484@@0aP584HXP<DXP<DPP0:5:8DPQ225:8DY1cU7<@DPQBT48<256806Q10464DPQS2488<
@A1R588@PQRS8@HDXa22468@PQB26:8L`RD57<@DPQR27<<DP@a0464246801AAQ5:8HXaBS6:@00QBT
00<DXaB248800Q2200<<HA1Q46400QBR00<@PA2258800QB100P@PAB15:8DXaS55:<@Pa1R0a1Q00X<
HQ1R488@PPb2384@H@aP220<@0@@H@06484DXQ21220400PP0Pa100H@H@`P220<811P360236400a1Q
488@H@02364246000a10464@HP02364234400`a02448@@0234400`Q12408@@0234400`aP364<@002
34001`a1360<H@aQ344880a100<<H@8<@004360<HPaQ3402360234032401340124400003LgUgNGMi
00IgN@03MgYgNgMk009gV`03MiYgNWNJ01IgVPMgV`IkV`mk^`06NkakW7^KNkUkVW^K0g^l00=k^g^l
Nk`03W^l0g^m00Ao_7nmOkek_@9o_@03Okao_Gnm009o_@Qog@03Omio_GoM00Mog@EogPAog@AogP03
OmeogWoM009og@]ogP04OmeogWoMOm`2Ood017onOomooWoo0Won0goo0Won37oo00QooWomOk]c=f[f
K_IgNWon1Woo01mogWooOomoof/K00L000@0220400P0100000`0=<8lhd44FL]VmFlgJaQFM47><BX]
1di@DaISNV=lFe]G>P02D_T014khC]UBnE;i0UKi00UG6E/IE]IBLdW`CNiB3Th?CS400dX_01E>;Th?
CPm>3U8/ERa=jSeY;<La1d6:DN]B2dh<ANdm[3f]@Nm5kdX`DU400UIB00EFE57bCJmB47mk00=oo`07
F@@H03D3NdYc=6;FFYD00UZD00=NU5jdG[<00f:d00=Re6KDH]@00V:d00YR/f;CH]AN/eYbGY=R]6;D
H]EVe@EVeP03I]EVmVKe009VeP9Ve@06I]ARe6;DH]AR]6:c0ejc00IN/UjCDS9JTfKfOod3Ool047]M
K_]g>g<iJcY[6FKGI]EReF;DG[I:4eIBIY1F3CC40P`000H880@122488@Q1340834402@Q1344<@Pa1
1000010PCPUon@0:Ool01g]iDLaNTG^GOmYk^WoM009oo`=ooP03OmiooWoN00EogP03OmeogWoN00Eo
gPEog@03OmiogGoM01=og@=ogRmog@9og0Aog@9og0Qog@06Okaog7oLOmao_7nk0Woo00aooWmjGU51
JTgXKe5onGoLJaI1[@P0000210000`a0460<H00234000`Q02208@00;2402224224002@a0440<@110
584HXQB2584HXP025:801AB258<DPaBS4:<00QBS00DDXQAQ588Ha1BR008DPP8HPP0:564DPQRR7>@H
`aBQ588@HQ226:825:801AB26:8DPQB25:800QB200<DXQS47<@00Qc400XDXaB3468<@A10584HXQRQ
480@H@8@PP<DPP03488<HQ1R008@PP0@584HXAc3584@PAB2688DP@PP320DHQ22584H`QRR58824682
58800a22588@PP0346402a226:<Ha1S35:8DPQ21584@H1BQ6:<00aB300H@Pa1R340<@11R36825:<2
48801`aQ464<H@a0344<@0aP008@H@8<H@05360<H@a0340<@@0246000`aP364<H@02360434001`aP
460@H11Q460@@0a1008<H@@<@@@8@@88@00=244<@@a1364<H11P320<@0a13648@@a134000PPP00<<
@0Q134400`Q000D<H11Q344<@0Q0008<@0@8@048@@0000=cNGMiMgT01WMi00=gNWMkMg/00WNK00=g
NWNKMiX00gNJ00=gNWNJMiX017NJ00AgVgNJMiYgVP=gV`EgVPMgV`EkV`9k^`9kV`03Mkak^g^k00=k
^`04Nkak^g^kNk/3Nk`01G^LNi]kVG^JNi/037^l0g^m1G^l27^m00Ao_GnlOkeo_@9k_@03OkiogGoM
00Eog@03OkeogWoM00Mog@EogP=og@UogP03OmeogWoN00]ogP9og@03OmaooGon009ooP03OomooWon
00Aoo`03Ooioogoo00Yoo`9ooP06OmagNFlGK_Ec=goM1Goo00=ooWoOOml00Woo00=g_a1<00000PP0
0PPP01@800@0520dPT44ABMN36;eKeMVmU9C<F`Y2C4YCW5G=f=jHiaSO5/k0Tki00E>f4kIC_QBnEKi
00=G6@09F_MBM4hABLe=kTh?CQ1:44X`009:;`9>3P0BDNeB3EHZFTY=k3D7:88mB4F9DN]5c4G;BLa5
kTH@CU9BLe9b0UIB00ENU6lHES51K5jD00=oo`07HJdX@dU4Olaon6KFEW<015ZD0Ujd00=NTeYbGY80
0V:c00mNTf:dH[=Re5jeDU9=l58@EU9N]5kEH]EN]6:eI]H00fKE00EVmVKEI]IVeF;F00ARe@03H[AR
/ejc009N/`9NT`05G[=JU5IBDU9Zm`04Ool01GoOMiagFVliJaT00fKE00YVdekDDS1JLFZaEPdd```0
200<80@<@@03340<@@a1008<@@0=348<@@a1244<@A1S48<<HP@0000<@4h[Oo`02Woo00MkO57^GY9k
N7^jMiYkg@05Ool2Ooh2Omh5Omd7Omh00goMOmiogP05Omh017oMOmiogWoN1goM0goN1GoM0goN?WoM
0Wnm00Eo_7oLOm]kVWnm009oo`0?Omic6E7`?F]>2G=cNm]gVV:e=B/40000320@HA21008@H@03340<
80`P0088@0032448@0Q000D8@0@8@@032248@0Q0008<8007440<H11Q464DPQB15:400QBR00L@PPaR
488@Pa225:8DX`025:802QB25:<DXa1R340DHAR26:<HXQBR0QB200<DXQBS4:<00a2S00@DXQBS6:8H
XP8DPP07464DPQS37>@H`aBR58800QB30Q1R00D@HAB19@DL`QB100@DPP8@H@03468<HQ22008@PP05
484@H0a0340@H@035840311Q344DHQB25:8H`QB1344<80a1568@PP8@P`08488@HQ1Q464@PQS35:<D
XP8DX`05588@PQB1584DXP0258801QB3468@HPPP2008808<HP03484@PQ22008@H@88@004464HXQ22
3642340010aP364<PQ1R0PaQ0Q1Q0Q2200D<HPaQ360<@0Q000<<@004364@H@aQ460234000`PP2448
@@02244010a12448@@a00Q2200@8H@Q1344<@@8<H@06460<80a1244<@@Q10Pa100H<80a0464<@@@0
120424000`Q1340<@0023404240122000003LgUgNGMi00IgN@IgNP05Mi]gVWNJMiYgNP0;MiX3Mi/5
MiX7Mi/4Ni/2NiX3Ni/00g^LNk]k^`07Nk/4Nk`01G^KNiUgNGNJNkd02g^l0g^m1g^l1g^m00=o_7nm
Okd00W^m00Ao_WoMOmeo_@Qog@03Okeog7oM00Eog@9ogPAog@MogP03OmeogWoM00eogP03Omek^goL
009oo@QooP05OomooWooOomooP09Ool2Ooh01WoLMgYc=g<ELcIo_@9oo`AooP9og`=oo`0K9<h000@0
220<80PP320401A1=<A11TUYGTe[57=FIaI><C5;:@TeJU:@EcQSVfNLHiaG>Tki009>f00<B]QBn5;i
EaUG>U/kEaUFedjDCS55[DW^0Th?00I9kTX?BPe9k4g/BNX2BLX03e7XGVUJBSUW984THSCU=BHiJ4W[
ETmFD59@EW=FT`02EW801UjCKaMoVF[eAHe=[@=oo`09IU<lZE63OlUomf/GFW=FM5ZE009JU09NU00=
FW9NTV:bH[=NTUYbGW9R/fKDH_MFMEICEU800UYb00=JLejDG[@00VKE00=Ve6KEI]D00VKE00EVmVKE
I]EVeF;E00=R]0=R/`9NT`=N/`04FW=B4UHaH]H5Ool027^lLeY[66JdJ_EVmFKdH_<2H[000fj_EN/`
X@0220000`PP3408@00234400`a0344<@@0534402@aR348<HPaR36488000561BC@0;Ool01g]MDLiN
LG^HOkYcVG_L00Eoo`04OoiogWoNOmh:Omd>Omh7Omd00goNOmeog@16Omd2Okd01GnlOm]o^W^JOkd0
0Woo019oWF/ICJhmJe9=NkIong=jH[D/j@@0200@@1RP584DPQ1Q460234000`a13408@@0=24001@@P
100880a036400a1Q00/DPABR5:8DXPaR2208@AB25:<HXaBS00<DXP0958<@HQ1Q568HPQRS7<DLa1B3
008@HP03588HY1BS008@P`8DP`046<@La1R1584258801AAP7<8HXQBR58800QAR00PDPQB358<DXR3T
9BDL`Q1P0QB100@DPQRS6:<DPP8@PP05468@HA21488@H@0222000a1Q584DPP0258802AB36:@La1S3
7<8DP@a0320<@@0646801A22584@PQ2236400a220Q1R00<@HAB158400QB100H@HPa0220<@0aP3646
46401a1R368<HQ1Q6<8H`a1R008@H@03360@P121008<H@<@H@07468@PQ223608@0a0240010a000D@
HA22464@H@aQ00H<@@88@@04240<H0aQ3602340010a1340480PP0`a100<8@@@P22000Pa100D<@1B2
3688@PPP00D8@0D<@088@08<@00000=cNGMiMgT01WMi1WMj00=gVgNJMiX00gMj1GNJ0WMj0gNJ0gNK
0gNJ3GNK00=kVg^JNiX00g^K0g^k0W^K00=kW7^kNk`01W^l0g^K00=k_G^lNk`01g^l00=k_G^lNkd0
0W^m0g^l2W^m00Ao_GnlOkeo_@9k_@03OkiogG^m00Qog@9o_@eogAEogP9ooP04Omek^WoLOod5Ooh0
17ooOoiooWoo1Won2Woo00IogGMjKaIc5W<EOk`2Ool01WonOomoogonOomog`=oo`04>G8000001002
22006`P0100HHSCV?BU=Zf9_KcIcEFKeCQ4eBbdY=H]B/eLiGgYOO5]KDaU>fDjhB]M:f4kHD_QC6@02
Fe/01U/jD]M6ED7aAM11[`91[P0G?HdmS46:@JU1R4FWALU9jTh:CNM9aTV6>BHdi3cRDLA[4gneOmQV
mUjDFY=FLP02FY<01UYbKaIonG]iAFY=[0=oo`07OaY9KTUVLbmk^VKgH[D00UZD01UN]5kEH]IReV;E
I]EVmF/fI_AR/ejDH[ARe5kFFYENU5jCGYANTeZdG[EReFKFJ_IZm@02JaH01V/GKcM_>6[fJ]EZeP=V
e@0>I]ARe6:dGY=JLUYcGY=N]5jCEU9B44V<DQ5c>@Eoo`0<Omic6F:eJ_IVmVKeKcQVdfJbK[1Ek3C2
0PP000D880`P2408@0Q100<<@0<<@@8<@PD<HP04120001B1EW0;Ool01gLLDLmFDG^JOm]cNG_M00Eo
o`04OoiogWoNOmh3Omd5Omh00goMOmiogP0?Omh5Omd017oNOmeogGoM1GoN@7oM0Wnm00=og7oMOm`0
0WoM0Woo00ikWF[hCJi1K5kCOoQongNJES4Tb@00220@H1201A1Q0`a000<8@0PQ22000PPP1PQ00PQ1
00H<@0a1344<@@a03683468031BR6:8DXQRR688DPPa0588Ha121464DPP8DX`0358<DPQB200<HX`08
8@HU1QB2444@HA215:8HX`8DP`06464DPQc47:<DHAB10QB200DDPARR5:8DPQAR00@DP`0<5:<HiB46
7>DDXPa0440DHARR7<@TiAB20a2200T<@@aP468@H@PP344DPQRR58400aB200/DXaBT6<@HXQAQ444<
81AQ488@HPaR008@HP<@PP<@HP<@PP<<HP03468DPAB1008@H@07320<8@a0364@PQBQ46000a1Q00H@
HQ2248<@Pa22484248801A1R464@HA1Q48400PaP00@@H11Q464<H@8<@0043608@@a0240434000`aP
468@P@02468248<010aR344<@@aQ0PQ10PPP10a010aQ00@<@@Q0244<H0@<H@8@PP03368<@@Q1008<
@003360<H@Q100D8@0<<H04<800000=cNGMiMgT02WMi1GMj1WMi17Mj2GNJ0gNK00AgVWNKMi]gV`=k
V`=gV`04Ni]kVW^JNiX7Ni/017^lNk]k^g^k0g^l00=k^g^lNk`05W^l27^m00=o_GnlOkd00gnm0WoM
00=kgGoMNmd00W_M17oM0Wnm3WoM57oN0Won00AogGoKOmaoo@9ooP9oo`04OoioogonOoh2Om`00gMi
MiUog004Ooh8Ool01WonNi]_5W<DL_Ao_09oo`04OoioogooOoh5Ool01UGh000000@032088088000B
88@e1cTYCLeVT6lDLeEN/Tg_=DT]:CF;C[9C>5<HC_Q>ed[G0dZg00Y>edZgC]MBnE]KHg]K>e;hAU@i
S`91S`0<AM59lThBDS9FDEZAI_=[4fldKcEc=G]f0WnF00EoUGndOo5omgon00=oo`0;H[EJTeIbEW1B
D59?G[5ZlVJa?DIF<004Ool04UieBDUJ;6:cH]IN]EZdFY=N/ejdG[EReVKFJ_EgF7^ILeIR/P=R]00<
G[EN]6:dH[=R]6:cG[=R]6KFI_IZmVlF0Vlg0f/F00=ZmFKEI]D00fKE00MZmVKfGY=F<5HaFW9JL@02
FW801UIAES1F4DgAEU=gF@Eoo`0;MgaVeV:dG[AW5gNLLeURTVI_EN`d`P0220000`PP3208@0043400
1110464<H@a110a20PaR00D<H`@P000@H5jc00]oo`07M_aAceYBNiUofgNJNmd01Goo00AooWoNOmio
gPIog@03OmiogGoM00EogP=og@UogPYog@9ogPIog@03OmaogGoM00aog@9ogPIog@Aog1]og@=og0Io
_003NmeogGoM00=oo`0<OiiR]dV=?Fa[=WogOoYkVDW>66H000`P0a1P00@<H@a0340<@08@@0033408
80PP00@88003240<@0PP00@8@0<<@08<H@8@PP0448<DPac47<<36:<00aRR588DPP0358800aBS5:@D
X`0258<01aR26:<LiARS688DPQAQ008@H@03484DPQB2008DPP<HXP05584@H11Q588DP@0358801A1R
588DPaB35:<00aB200HDXQBS588@H@a14642584051bQ584@H@aQ344<HA1Q488<H@PP468L`b3S684D
HA1Q588DXQB2488246801A1Q460HPARR48800PaQ00<@HQ1Q46800PaQ00P<@A1R6:<HiA222208@@aR
0Q1R0a1Q00H<@0Q0364@PAS26:424603464346801122484DPQ21111Q00P@PA1P340@H11Q460<@0Q0
0`a00P@P0`a000H<80aP360<H0aQ4682368234801Pa1364<H@a02208@08<@003320<@11Q008<H@03
468DPQ1Q00@<H0@<H@8<@@8<@003320<@0a0008<@007244880@P340@H12146000@`P00000g=iMgUg
N@08MgT7MgX017MiMgYgNWMj0gMi00=gVWMjMgX02GNJ0gNK00EgVW^KNi]kVg^J009kV`9gV`03Mk]k
Vg^J00=kVPIkV`04Nkak^g^kNk/7Nk`00g^kNkak_00BNk`8Nkd00gnmOkao_@03Okd3Omd5Nmd6Omd0
0goNOmeog@0:OmdDOmh2Ooh4Omd017omOoioogoo0Won00UogGomOmakVVZDK]5ofGomOmd00Won2Goo
00Eo^g<fLaIc5W^m00Eoo`04OoioogoOOoh2Ool01FJk2000000032000`P0018TXcCW=@U=cV:AKaAc
DejA@Jha:Be:?Nm:/d[gA]I:eTJE@YH2A[H01TZFAYE6MDZfB]Q?6@9G>P0?D]M24DhbKcMoUGoHOmUo
nWokOoaongoiOoIonWom00]oo`0<OoiVmU9BCU5>;dh;DT]RdF:_BHHiAEJC17oo01=c?DU[?BI=Zf:e
G]IJ/eZCF[=N]5jeG[AV]FKDJaAgNFlFG[=NU002H[@00f:eH[AR]002H[@01VJcH[=Ve6KeJ_I[5`9[
5P9ZmP04I_IZmVKeI_H2J_H01V/GKcM_=flhKaMZmP9VeP0;J_I[5flgJaMZmV[gJ_QVeVkENgYog@03
Ool037^lJ]ER]EZCIaMoogMjIY=R;Tg<<<@8008400033408@0a0008<@0<<H@8<@P07368<@Pa1348<
HPQR36<00P0000<<@5jbOol02Woo00Mk75G_FU1gF7oLNkakgP05Ool2Ooh2Omh3Omd01WoNOmeogGoM
Omiog@MogP03OmeogWoN00EogPaog@9ogQEog@03OmiogGoM009og@05OmaogGoMOmeog00MOmd00goL
Omeo_002Ok`3Okd017^mNkik_GoN0goo00agOEYeAF`mRfmHOoUoo7MH@Hd80P003202460246402`aQ
340<@0`P340@@0a0320880`P22001@a00`Q00`a000T<H@aP488HXaB258<La1c36:8011RS00<DPa1Q
68800QRR00XDXQRS6:@HXaR27<@Q1QRS584DHP8@H@03468DPQB2008DPP04688PiARR58425:<03A1Q
564DPQBR588DXQBS58<DPQBS6:8HPQAQ008DPP8@P`<DPP0@5:8H`aB1464<@A1R488@Pa224688@@Q0
488Q1B3T684258802QRS58<DPQ23488@HPa1564LXQRS0QB200X@PQ1R468@HAB1484<@11R6<<DY08@
HP03344<HQ1R00<@HP0;464<H@a1464DXAcS5:4@H0a0360@H@02368446800a22464@H@0234001`aP
364@H@PP460@HA1P00<<H006460<H0aQ364@PPaQ0PPP00<<H0aQ36400PaQ0PaR0`a200D@H`aR344<
@@a0008<H008340@H1B2468<HQ1R488<H@<<H08<@088808<@@8<H@05360<@0a0340<H00336401@a1
320@H1B146000A1000000g=iMgUgN@08MgT7MgX017MiMgYgNWMj17Mi0WMj2GNJ0gNK00AgVWNKNi]k
V`9kVP05Ni]gVgNKMi]kV`06NiX4Ni/00g^lNk]kV`03Nk/<Nk`00g^kNkak_00;Nk`00g^mOkek_@05
Nkd00gnmOkao_@02Okd4Omd2Nmd2Nmh6Omd4Omh<OmdBOmh02GonOoeooGoMOkaogGomOoioo`04Ooh2
Ood01WoMJ[QZTWnfOoeogP=ooPMoo`06Ooio^g<fMaIc5g^L17oo0Won00=oogoOOol00Woo01YgGA`1
000000`P200400P0<<<i1cTZDNiV/G<CKa1FCSV;<BP]BCh@B[A6eTJe@WA2UDJE0TIe00]:UDYeAWE6
UDJfA[M:eTkFE]E>DFmH009oo@03Ooioogoo009oo`AooP03Ooaoogoo00Eoo`06Ooeon7oeOkIVmEIa
0U8a00Q>3U88Lg9g]flbCJHmIUZc17oo00]gGdE<=BMAkEZDG]EJ/UYbDU5FDEYb009NT`06HY9Zm6[f
H]AJLeYd15jd00MR]6:cH[=V/VJaJ_A_5P04KcL01FKfH]EVeVlGMcH00g/f00ik=gmhOkUofgniOgQo
FGmiOkUo^WoJOkYo^7mG0WLG00Ag6G]lOiao_@=oo`0=MaEReUjDI_MooW]jIY9VD57==>D<00P03200
10a000<<H0a034000Pa10P`Q0Pa10PaQ00H<@@PQ00000110G[8;Ool01gKkDNiJCg]hOkagW7_N00Ao
o`9ooP=ogPUog@MogP03OmeogWoN00EogPaog@9ogPIog@03OmaogGoL01Mog@03OmaogGoM01Uog@03
Omao_7nl00Ao_00ANkeo_G^nNiio_GonOomooW=JFUA1JdW<KeQonW^lK_Hi:P02000010P0220<@0aQ
0Q1Q00X@@0`P320<80a0464<@0PP320880D<@004240880PP240334001a1Q484HXQB1588DPARQ00<H
XP037<<HXaB3008DPP8HX@085:4HXacU6:<DHARS8>HHX`HDPP09364@HA1Q6:<TiAbS5:8DXaRS00<H
XP056<<DXQBR588DXP03588011B1688DPQB20Q1R018@PQB25:8Lhb3U6:<@HA1R488DPQBS6<<DPa1S
468DXQcT7<<2684258802a2258<@Pa22468<@QAQ7<8HXQB358800Q2200H<HA1P6:4HXAB146424880
111R368<HQ230QB3111R00D@PQ216<8H`QB0008<@00;360@HA1R348<@AB27<DDPa1Q460<H0023402
3602340546000a10580@P00348801A1R344<@0aP48800PaQ0Q1Q1`a100<<@0aP36000Pa000DDP1BR
588<H@a100T<@08<@@<<H@8<@@04340<H0aP3642344010a0460@H11P0@a000000g=iMgUgN@02MgT4
LgX00gMjMgUgNP09MgX00gNKMgUgN@02MgT00gMjMiYgVP08MiX6Mi/017^KNiYkVW^K0gNK00=kVg^J
NiX00W^J1W^K00=k_7^kNk/00g^k2g^l0W^k0W^l00=k^g^lNk`01W^l0g^m00=o_G^mNkd01g^m0gnm
0goM0g_M00=kgWoMOmd01GoM17oN2WoM5GoN00IooGoMNkaog7omOoh3Ool00gonOmiooP02Ool017<i
K]=o^Woo17on1goo00IooWnlMeUc>7<HMe`5Ool00gonOomoo`03Ool017nn:6H000000PP001@40100
><8m1Ce;EPmZlg<eKa9B;3V<<DX]K3haB]E6eSjE@WA6Ld9c0dIC00a:MDId@UA6M4JeB[A6Te:AFY5o
oGooOo/2Oo`07gokOoYongojOoQomWoiOoQonGoHOmMof7oiOmEkUG<eH[5=jD5UAHQ1RdG?BLiF<6:_
OoQoo7MeDNM1REId00Aoo`0DH_a1KSf:BNeFTUJAEViJL5jBH[AVeF[eJ_IZmF/EJaIVeEYbFY=NT`EN
/`06H[AV/f[CLcIoMgnG0g]g0WMG00QkN7]iNgMkN7mhNeMoMgnj0WoK00=o^WnkOk/00Wnk00Eofgnk
Ok]o^G]i009kF@05NgYkVg]kNg]o_@02Ool02WoLKaMJU6KhNiec>FIbIU1AcC340PP00Pa000H8@@a0
340<@0a1364434401Pa2368<HPa1220400800003541RdWoo00Yoo`07Ma]AkV:aOkYkVgNmNmh017oo
0gon0WoN2GoM3goN9GoM00=ogWoMOmd08WoM00Eog7nmOkeo_Gnl00Ao_@0?NkikWGnmOmeooWnjJaQB
4D58ETegVWokNiaRTbbV00800009200880`P344@H@aP440<8110008<@08<H08<@006240<@0a0340<
80a00`PP0PQ000h<@110464DPQR26:<DPQ106:8TiAbR7:<HXaRT11BS00lHXaBR5:<HiB45688HXaB3
568@HQB25:<DXQBS48800Q1Q00/@PQB27<@HXQRS8>DU1Qc46:<H`aBT008DX`04468@PQB248825880
11RR588DPQ230Q1R00D@PQB25:8DXQB2008@HP8@PP075:@LiQS548<DPaRS6<@00QRR00LHPQB2488@
PQ1R368@HP0234402a226:8DXQ1R588HXa22220@PAc158400Q2200<@HPaQ24000PaR0Q230a1R0Q22
0QBS00dDXQB1464<811P364<@0aR468@HA2248<@PP02464010aQ220880aP0PaQ00P@@A10464@H@aP
440<81AP0Q1Q0Q1R00<<HPaQ36400PaP00@<HA22488<HP8<@@06364<HPa1220400PP0Pa00PPP00@@
HA22464<@08<@@@<@0<<H0<<H@06220<@@aQ368<H@aP0Pa000L<H@aR364<HA1Q460@@00134000003
LgUgNGMi009gN@04LgYcNg=kMg/6MgX00gMiMgYgNP09MgX=MiX2Mi/5NiX00gNJNi]kV`02NiX2Ni/0
0g^JNi]kV`05Ni/6Nk/3Nk`5Nk/2Nk`2Nk/00g^lNk]k^`03Nk/4Nk`4Nkd017nmNkek_G^m0Wnm00Ao
gGnmNkek_@=o_09o_@9og@=kgAIog@iogP=og@9ogP=og@04Nkaog7omOoh8Ool017]iL_=kF7om0Won
00=oogonOoh01goo00Iog7]jLaQbn7<kOmh4Ool2Ooh2Omh2Ool01Gon?B`0000020000P@001<H@3S0
@>=1JUX_J]=c=VlBDR`iRcE[=Lln<E<EA_M2Ud9dAW92DP02?O0054HABS52<D9BAW=2TdJCBY9>L4X/
IaAomgoZOk5cDf[bH[1NT5Y`EW03EW402Dh`BPi9kDG<ANa:34X=BN]5ZP02AHT03D58@DU5Jdg>ES1R
dG^fNmQ_;e77<@Q1/6LM00=oo`0;G[a5KcDWALeNT5J?H]1R/FlFMgQoV002OgP01GnHOoAo^F/GEW40
0UjB00=NTEjbG[800UjB01QNTf:cJ]=cEW]hOiEkMWmfOiMo^GoJOmUofWniOiUoN7]fOgAkMW]gNgQo
N7^IOiT2NiT03GnJOkYkVWnJNiYkNG]HNgUkNW]IL_IkFWnl009oo`0;MgUN]F;HMg]ZmVIaIReAbcCR
30080002340010Q0340<@0a00PaQ00@<@@a2348<HP8<@P8<@@06364880@0100PX6Kc2goo00Mk?5H>
H]9kV7^kNkakgP03Ool2Ooh017oNOoiooWoN2GoM1GoNDgoM0Wnl0gnm00=og7nmOkd00gnm011k_Gnm
OmiogGnhJ_I=[DEVGXek^WoKNkaRLbAS0004008<808<@@8<@003460@811000H<@005240<@0aQ340<
8005220010Q0320<81100QB200LHY1RS584HXQbS6:8HX`026:@02QS45:@DXaB3468DPaRS7>DL`aR2
0QB200X<@A11588H`acT6:<@Pa1Q484DXP8DPP086:8HXac47<@Ha1RS5:<DY08DX`8<HP8@HP8DPP06
6:4DPAB36:@@Pa1S0Q1R00<@PQB258400QAQ0Q1R00<8@@aR48<00QB300@HXac47<@HX`8DPP8@HP05
464<@@Q0340@H@0358825:8258802QBR584L`AB1364<@@Q0364@HA1R0Q1Q00<<HA1Q46401A1Q0Q1P
00D<@11Q444<HQ1R008DP`8@HP<@H@0:3408@0@P240<H@aR464DPQ1Q344234005@`P200@H1B24648
@0aR48<@PPaQ360<@0aQ488@H@aQ344<HA1Q488<@00232000``Q2208800222000`a0364<H@053403
36002`aQ360<H@aQ36888@PP344<HA2136000PPP0Pa000<@H0aP36000Pa00@a100000g=iMgUgN@02
LgX2Lg/3Mg/4MgX00gMiMgYgNP04MgX00gNKMiYgVP0AMiX00gNKNiYkVP09NiX8Ni/2Nk/2Nk`3Nk/3
Nk`2Nk/00g^lNk]k_006Nk`4Nk/3Nk`:Nkd3Okd3Nkd00gnmOkaog@0MOmd>Omh2Omd2Omh5Omd00gom
OoiooP06Ool01gonOkUV/f:DI[A^mg^K009ooPQoo`06OmekVg<IK_Q_6Wnm17oo00AogWonOmiogP=o
o`0eEK800P00220000@0664h`43QBJYNCV[CMgU_5E8^>J/eS2f>?U9>mT[g?[I6]DIc?S4icSF=>Je1
cCW>?Q16LT9cAW=:TTY`BTiBCEZ=DRI9aTW7BNQ=j4WYALU9jdX^BRm5kCf/>HXmR`02AL`00dG;DPeJ
K`02H[803V:CIW9RCfJ@LcI[5EZbFY5JT5Y:AFTTYc3[FYP3Ool08F;M>@`TY3f;FXiW4f/CLeIgN7nk
OmYongolOoeomgnjJaMFU5IbG[=N/UZbFY5NTV:cGW9RTfKCLeIo^GnGOgIkMP02OiL027niOoYoo7oJ
OkUoV7mgOgH2NgL3NgP00g]gNiQoV002OiT05gnjNiYk^g^INeMk=G/gNeQkFG/iNiYooWooOma[66KG
LcYZmV9bHRiAZcSR30000P`P00<<@0Q0340010a100D@HA1R48@@P`aR008<@P8@P`05488<@0`P;>5_
<`0;Ool01gLIDNiR/gNINk]_FG_N00Aoo`9ooP=ogPMog@MogU9og@9o_@03Okao_Gnm00Eog@=o_@9o
o`0>Ooioff[gBJi5IVK_Oo]oo7MkES8H8@@0124<808<@@07368@H@aQ460<80a036000Q1P00L<H0a0
340<H11R368<H002340422002@Q0220<H11Q340DPAc46:<DP@0458826:<02QS45:<DXPaQ220DPQS4
7>DDXQBS0aB200HDHAB26:<PiAS45:<25:802A2S488<@1B27<<HXPaQ344DP`035:<00a22368@P`02
5:<258801QRR588DPa2346<<HP8@HP03584DHAB1008@H@0=468DPPaR3448@@a258<LaABS6:<DPa22
46800Q1Q00<<@0a146800a2200X@HAB25:8DPQB1464@PQBQ7<4DP@8DPP0958<@PQ1R468@H@a0220<
@11Q008<H@8@H@05360<@0`P340@H@0246802PaQ464@HQBS588DHA1P464@HPaR10aQ00T@HARS464<
@11P340880a036000PaQ00D<HPQ1368@HPaQ008<H003464<H@aQ008<@004344<@0a03406344010aQ
464<H@aQ10a000@<@@a0340<@0@<H@08268<@@a1464@PQBR488@H@<<@0<<H04<H@4<@@4<@@0000Qc
NGMiMgUgNG=ILgYgNW=k0WMk0WMj17Mi17Mj5gNJ27^J00=kVg^JNiX017^K1G^k0W^K0g^k0g^l0W^k
2G^l17^k0g^l4G^m0Wnl0goL00=ogGoLOkd067oM3GoN1goM0WoL00AogGonOoiooPIoo`07OkUZTTga
ES=VUWMjOod02Goo00MogG^lLcUc6VlINgYooP02Ool6Omh2Ool00f9g10L000031000;Ab2><10`56X
HVe_5G^KKcIB3CV;;DXaSCG_@U52]4Jd?W8nDSha=Llel4ICAS4iccG_?U0nDD:DA[=:TDH_@N`iRSE8
>HPmZDG;BN]:34h;APe1bcEY=FXm[002@L`01T6]ALeB<6;CKcEcF09kF00=OeUoMgobOoMg=U8>AJi=
kdF:@BT`jEHDLah00goo00]J_2RZ;<HiJTh<DTeN[f;cH]9Rdflf009cE`0CLeIgMg<gH[ABDDh`GY9N
TEjaGY1NL5X^FPiJ<5iaKcEgV7^FMeH00W<E00]o57nAOi1oLWmdOgIoUWnhOkMoV7]f009kM`0LNeIk
MWnHOkMoV7nGNiQo^GnjOgMoE7meOiMoMgLFMaMg=WMfOoeooWMhLcMg=f[EHY=R3df9=<4230023200
10Q02448@@a00`a100@<H@a2344<@@8<@P8@H@05460<@0P0;>1gD`0;Ool01gKeDNeR/goMMiY_5WoM
00Aoo`9ooP=ogPUog@03OmiogGoM03mog@9o_@Mog@9o_@03OmaogGoM00Mog@9o_@Ao_0Iog@0@Omio
ogooOoioVVJeBHe9IF/@OoYoo6lh@Jl<00@0224334400a1R360<@00232001@@0220@H12146000Pa0
00<8@0a134400`a000h8@0a0340<@0`P440@HARR584DPQBR5:<DHARR0aBS00<HXQRS6:<00QRQ00/8
80aQ5:8La1cU6:<DPQR26:8HPAB1008DH@04588DXaBS58825:802121340@HAbR6:4@@0PQ58<65:<3
5:801ABS588DPQB346<00Q1R00l@PQB2584DPAAQ320<@AB3588@HPaR46<<HaB358800QB300<@HPa1
34001A1Q0Q2200hDPQBR5:8HXQB1464<@11Q584H`ABQ588DXQB2111R111Q00/<@0aQ468@PQ21584@
HA1P360@H@aQ00D@H@05564@HA1Q464@HP02364446434603340010aP340<@@PQ0PPP0PaQ00<@H@aP
46400PaQ0`a101D<@0PP200<8111468@HA11344@HA1R368@H@a0460@@11Q468<@0@032000PaP0`a1
0PaQ00D@HAB25:8@PQ1Q008<H005340<H0a0360<H@023440009cNP05LeUcFW=jLgYgNP03Lg/2Mg/2
MgX00gMiMgYgNP04MgX017NKMiYgVWNJ0gNK3gNJ1W^J0W^K00AgVg^KNiYkVP=kV`Ek^`9k_0=k^a1k
_003Nk]k_7^l009k_11k_@=o_@06OkaogGnmOmeog7nm1goM00=ogWoMOmd03WoM47oN17oM00=og7nk
Omd00gon1Woo00IooG;dK]Ig>GnmOmd:Ool02GoMNkec>W<iLcQkNWoLOomog`05Omh3Ool00f/L20T0
000310006BBS?>550UW8J[1cEW^kJ_E1[2SW9>PYBRf<<Lhf449A?S4nDSXb=WEWggooIg/nE3XA008j
<@0X>U8nDSX?<JdaJSEZ<BPe9cEX>FTiRCg;?JXeJBT6:>Ha:35Z=FXeBSE;?HeJDV/GLgQcF7<gMeMo
fWonOoYkVUH=?DY1S3f]BH/m1UWZOeH4Ool01U9L;</e:3U9@La23@963P0>BPe9k4g[CN]=jU8:ETaJ
T4h>>Ha1cTX`DU163P91Z`0AAJ/mJCeZDNaNKV/CKa=ZdVZaJY1^dGK@L]1b/FkCK_EoE`02OgL017nG
OiEkEGLE0WLF00ek=G]DNgIkM7meNiEo^WnGM_EV/fZdLaIg>002McL02f/GKeQongomLaQbmVZdGW=R
<4f[=:800P`000H<80a02448@@Q0244534401A11344<@@a134000Q1P00@88000:81gD@]oo`07NaQE
kUjcOomk^g<gOmd017oo00=ooWoNOmh00WoN1goM0goN0goM0goN=7oM0goL17oM0Wnm1goM0gnm2GoM
0Wnm00Eo_7nmOkeo_Gnl00Ao_@03OmekgWoo009oo`0>LcUF<D5:CJIcM7ojOmaVmcD/200400a0588@
HP8<@@073408@@PP220<80a036002Pa000<8@@Q024400Pa000@@@1AQ7:8Pi08DPP<DX`096:<Ha1cU
7<<HXaB26:<La1S4008DX`046:<DY1RT6:<26:801AbR9>@HXAAP5:800QBS00XDPQ1Q488DP@a0320L
`B31440DH@8DX`036>DLiQS5008DY08DP`045:8DXaRT5:@258<03A1S48<DPaBS5:8DPQ1Q200<@ABS
6<@DXa22008@H`0=58<DXa2S58<@H@aQ464@PABR684DHA1Q48800aB20QBR00LDPQ1Q464HPQB16:4@
XP02364248801QB258<@HQ1Q6:<DX`<@H@03468@PQ21008@H@08484@HA1Q464<H@a0360<H@8@H@03
484@PQ2200<@H@066:<LXaAQ440@H0aP0a1P00@<H11Q440@H@8<H@03464<H0a0008<H@04488DPaB3
468236401A1Q344@@11068400QAQ01D@@0`P444DPQ23364@@11P464@@111340400aQ588<H0@P244<
@0a136400Q1Q00<DPQ1Q36401@aP0`a00@a1000017=jLeYcFW=J0W=j00AgNW=kLg]cN`9gN`9gNP03
MgUgNWMk00=gN`=gNP9gVP=gV`mgVPIkVP9kV`03Mi]kVg^K00AkV`Yk^aEk_0mk_@Ao_@06Okao_Gnm
Okeog7nm67oM3goN0goM0WoL00=ofg^jOmd00gon1goo00=kVGnjOol037oo00QooWnlMeYc5g<gMgUo
g7oo1WoN0goo00=ogaa/00000`@001/TXccS@>9IafJ^MeEo^VkD>DTLHaR558DHaR4X=Ldn3Sh`=Q0f
<SZGIkikof>L=WHf<S8a<Q400SH@00Ha[BDY9>PY1bd7;BP2=DP04CV9=HX]9bC69<DXaBT6:BP]22SY
:<TiSEIBJcQ[F6mHNkP00Wok00AoeW=GFRm1J@8/aP05>D/e:T5XLc9om`04Ool0259l=@de9cE9=FXi
ZcV:=HX2>HX2>HT06CEX>FQ5jT7;=DPTiBT7<FXeJ2dW:@H]1Rd7<BPeBCV9BNaF:eY;FTaRKVJ?IZmV
T6I_009RCP05HY1VTF[CLcIgN002OgH01gmFLaI_5W<EMcEoEGmc009oM00DLcM_5VJBFNmJ46:CJ_E_
5F[fH[ABD7oFOoek>6[EHY9RU6YbDL`/X`880004320<@0Q12444240234423402344334001A1Q1000
02B0Ng002goo00Mfme7^G[AogW^JMgQog@02Ool3Ooh<Omh00goMOmiog@02Omd3OmhcOmd4Om`5Omd0
0goLOkeo_@05Omd01GnmOkao_7nmOm`01goM0Wnm00Eo_7nmOkeo_GoL00=o_@9k_00FNkioogooOmm[
6Tg?AFUF2WnFOo]k^UZD;>/000P0440@HA22364880`Q344222401@a1464@H0a022000PQ01@a00PQ0
0Pa00``P00@@@1R0684HX`HDX`086:<L`aRS468DPaB25:<DXP8DPP0358<DHQ1Q008HXP0:8<<U1Ac2
580DPAcU58<@HQ1Q584258002QAP680P`11P584DXQc46>DDY1BS0QBT00<DPaB26:800aB200<DPaRT
58<00QB30QB200THPQB1340DPQcU7>HDXaBR48800aB300/HY1B3568@HQB26:8Lhac2560@HA22008D
PP04584@HQ1Q568248800aAR584DP@025:802QB1464<@11Q588@HQ1Q588DXaB20a1Q0Q2200<@PA1P
4840111Q0Pa000`@HA1P460@HA21588DXa21464DHAR1680246001@a0580@H11P34000a1000<<H11P
46000Q1Q00D<H@Q0340<HA1Q00@<H@0=444@@110680@H1AP440<80a0464@HPa134000Q1Q00P@H0`P
320<H@aR588@H@a10PPP00T<@0aP464@HA1P340<H@aP46000PaP00@880a0340<H04<@@0000=_NW=J
LeX00g=j00AgNW=kLg]cN`=gN`03MgYgNGMj00EgN`9gNP9gVP03Mi]gNgNK009gV`egVP9gV`04Ni]k
VW^JNi/5Mi/00g^kNi]kV`0;Nk/;Nk`00g^mNkak_@07Nk`>Nkd5Okd00gnlOkeo_@02Okd8Omd3Omh7
Omd00goNOmeog@03OmdAOmh3Omd017oLOm]o^goM17on1goo0Won37oo00QooWoMMgY_5W<fMgUogGoo
1GoN0WoO0goo02He<000000000@09:<hhcc2FLQNSWMFOkU^lSe8648<@b376:L8A@aS9DXekcH>;Nh^
4CJE>YDfUS8c:Q8YlBXA;O0]cRE:;DXY:BdY0S590SEY020aJRe9=FTeBBS49:@XiBD7;BTTb2CY>F]N
/VmHNkEooGonOoagEflFJ[=N3Tf:<>L`j2AT;>MRdWobOo]kUWon0Woo00ABO34^=BPeB@<iRP05>HTe
JCV9>HTeJ003<BL08CE89<DLPaR46:@L`ac47:<LPb34;DPeRSV/>HXiJCV9@L]>359>EViJKeI>EReA
jdF:BHYEjf9`J_=_=7=FLcE^m002J[<06f[dLeMoMgmgLeI_=V[CHTiIkEG/HW9ZeG<fJ_EJD4G;LeQo
oWnjL_EVTfJdJY5=[2bT200<0002320224422402340534402@a0320<@0a046040000;:1oT`0;Ool0
1fkFDNmN]7nkMgUgEWoK009oo`03OmiooWon00iogP=og@=ogPEog@=ogQmog@9o_@Uog@05OmaogGoL
Omeog00=Omd00gnmOkao_@09Omd2Okd01GnlOkeo_GoMOk`00gnm00=ogGnmOmd00Woo011kWVKiCLi9
RUi=OiIoo7=iCS8PZP00220@H0aQ48<<HP8<@@8<@P082448@0a1360<80a0240<@08<@@8<@0<8@08<
@00;440800P0320DPARR6:<Ha1RT5:8DX`02488011BS6:<DXQ1R1AB200<DHA1Q58800QRR0QRS0QBR
00dDPQ1Q468DHPa1564DPQR1664@@1B18>@Ha0025:<26<@35:<25:@011216:8DPQAQ0Q1R00`DPaRT
6<DDY1B27<@PiAB2464HXb3U5:425:800aB258<DP`0358<02QAR588DPQBR6<<L`QR1584<HA210QB2
0QAR00`@HA225:8H`QB1460DXR3U588DH@a0444246802A1Q488Da1B2488@HA22588@P`0248824642
468446400a1P360@H@0248401122464@H11P0QAP00H<@11P360@H12146034403460246402Q22464<
H@P0100880a0468<HPaQ0Q1100P@@1AP460DHA10320<@@aQ0Pa100H@@A1Q364@H@aP220536402Pa0
220<H0aR364@H0a0220<@0aP0a1P0Pa00@aP0A1P0@aQ00000fmjLgYcNP03LgX00gMjLg]cN`04Lg/0
17=jMgUgNWNK17Mk1GMj0WMk0WNK3GNJ0WNK00AkVg^JNiYkVP9kV`03Mi]kVg^K00QkV`=k^`9k^P04
Ok]o_7_MOk`8Nk`5Nkd5Nk`00g^mOkeo_@05Okd00g^mOkak_@08Okd00gnlOkeog@02Okd7Omd4Omh=
OmdAOmh3Omd3Om`2Omd00gomOoiooP0DOol02WonOoeogGMjLaEZmG=GOkaoogoN0Won0WoN0WoO0goo
01Y9/P00000000P0::<ha43SGLQV[gMEOkMg<TF9628DI1RU36D00A0T>LiS>6niE]<n<C7`0S8B0S8A
00D]l2F=9F`YJbe9008aB@0U<FXaJC5Y=FPeBBCW8:@eB46[?HTa9bd7;@PXiRcX;@Y9k6mFOoQoo7oi
OkI[5UjCI[=Z]6JCDJ]1BBbW;@MJ/WokOoQoUUICOgX00Woo00AN_3T]=BPeJ@<iR@0G=FTiRSV:>HTe
J3V9>FTeBC598:DDHaB48<DPiAS458<HXb2S:>@eIcV[>H`mZ`02>FT023fZ?La1bcg;@L/mZcfZ?HT2
>FT00cf[BN]FBP02FT`01UX]GRmNL6:AJ_=_=@9cE@0DKaAVdV9^GRaN35i`J]=_56[cETm1RF;DOoao
nWKeI[EZeFj?DJ/da@880007340<@@PQ2248@0a022000`a00Pa100@<@0aP320<@08@H004100002c0
Ok@;Ool01f[FEPmRe7^HNgQgE7oK009oo`mogPmog@03OmiogGoM01aog@=o_@Iog@Eog003Omeog7oL
00eog@03Omao_7nl009og0Mog@9o_@9o_09og007Okao_GnmOmeog7^lOmd00Woo00mgO6:gCJe5IfJ`
OkEofg=HAO0@A@00200@H11Q48800PaQ00P<HPa2344<@@Q02448@0a00PQ000<<@0a136400Pa00`Q0
0Pa00P`P00D<@11Q588La1S3008DX`0<588DXaBT48<DPQS46:@DPQAQ568DPQB10Q1Q0QB200`HXQRS
6:8DPQBR588@HAB2464<@11Q5843588258<25:8258801ABS6:@HXaBR6:800QB200LDPARQ584DPAB2
568DPP0458<01ac37<@DPQ1Q584HXAB0008DX@06464DPaR26:<DXaB30aB200PDPARQ684HPAB1364@
PA2211B200HHXQS26:4DP1AQ484358402A1Q46<DY1B3468DPaRT6:<DPP0248800aB2488@PP024642
468348800a1R360@H00346402Q21464<H@a0460@HA1P340880a00a1P00<@@11P46400a1P0Q1Q00@D
XQ21364<H@8<@@03340<@@a100<<@006440DH11Q444<@@`Q0`a100D<HA1Q588DPQ1Q008<@0D<H@8<
@006360<H@aQ364<@0PP0Pa00Q1P00D<H0a0340<@11P004<H@0000=_NW=jLgX01W=j17=k00AgNgMi
MgYgNPEgN`04MgYgVgMjMi/3Mg/00gNKMiYgVP0;MiX2Mi/00g^KNiYkVP02NiX00g^KMi]kV`08Ni/5
Nk/01W^iOkUo^goMOkek_@Mk_0Mk_@=k_003Nkeo_Gnm009o_@9o_003Okek_Gnl009k_@Mo_@03Okao
_Gnm00Yog@aogPAogA9ogP9og@9og004OkakW7oMOod2OohDOol02GonOoeogG^JLaEVmV/FNk]oo`02
Ooh4Omh01WoOOmioogooIUL400800016520/Y3cVBDMN26J_NgIof7mcAJXH@abV8>H@I@`4=BQk^Goo
OoMonDic9Fh]dRgb;O0USB4Z9@Pi[4G_?H`eBS5:<F/aJSF;=FTa22S6;>LiBdG=@J`]BRT9:<Ha1dUX
I]AonGolOomonWnEMaEZmV[DK]A^meid@BX/Q3TXH]9ongooNoeFD3d:M_42Ool01UjJ>B/e9cEY>HTe
RP@iRP8iR@0F>HXiRCf:;BLY1QB39<HPiRCU7<@DPQAR9<</hcEV>JXiRcV[>H/iJCEY?J/2@L`02CV:
=FPeJCEY=DTaB3E9=FTiR@02?HX01T6/ALa5cDW<CNaFCP9JKP0<G[1RdEi_DNaEk5Y>GXmNSEjbBP`]
B5Ia0Wom00Ik=V:dJ]E^/56Z<88210023202224010Q0320<811P0Pa00`a100T<@0a1340<H11P1000
02S1Om@02goo00MZeU7^J_EoV7^INgEoo@02Ool?Omh?Omd00goNOmeog@0MOmd00gnmOmeog@06Omd5
Om`00goMOmaog@0<Omd5Om`7Omd2Okd2Ok`00goLOmeo_004Okd047^lOoioogooMe]NUDF;AFMZlWod
OkYc5Sf=10<000PP0PaP0`aQ00<<@@Q134401@Q100<8@0Q134000`a100<<@0Q0240010a000D<HA1Q
468@PQRS008DX`03588HXQBT008DY0076:<La1S56:@DPQAR48<00QB100<HXac46<@00Qc400LHXaBS
5:<HXaR2588@HP03588031R26:@Da1S55:@<HPa1468@PaB35:<DXP<DPP03564DXQRR00<DPP06568D
PQB348<DPaRT0QB20Q1Q00d@PAB1460DPAB2364DPabS6:@DXac56:<DPP03564021AP684DPA1Q484D
PQ22588258<2588558401aB2584@HQ1R5:@HY1B300L@PPD@HP04488DPaBS48824640111P464@HA1Q
0a2110aQ00d@PPaQ320880a0360@H0aP488DPQ1P464DPP026:8011B2468<H@aQ10a100<<HA1Q4640
0Q1Q00L<H@a1344880a1468<HP023640111Q468@HA1P0Q1Q10aQ00T@H@aQ364<HQ22464@@0a04400
1`a00A1P0@a0000016mjLgYcNG=i1GMi00EcNW=kLg]cNgMk00=gN@AgNPQgN`03MgYgVWNJ00]gVP9g
V`03Ni]kVW^J00=kVP]kV`0;NiYk^W^jNkYk^G^GOmYooW^mNi]k^`08Nk`5Nkd3Nk`00g^mOkek_@0B
Ok`2Om`3Omd00goLOmeog@04Omd;Omh5OmdBOmh01goMOmaofgoLNkaogGom009ooQAoo`9ooP08Omao
^WLfG[A_=WoLOomooPEogP0HOmmogWooOomfna00000401QQ<:@lj4UYIRU^dGnFOoUkLT5X76@HQAbS
68@PbGMG0Wom01mokGoH@O4Lj`aY7@/YBcF^>LhmkTX`CU55kSV<=F`aJcV:=FXaB2cV<@PiBc4;?Hda
:BSY;@Y5[VKDOkMooP02Ool00goiOiIk=@02M_H04gKdK]EZU5GA;:ThiVKAOoUooGooF[H/jC3WFL9o
igolFU@`iS4V008iR@0I=HXiRSV:>HXiRCV8>HTiRSV9>HPa9RT56:@LYB3U9>@La1R3588TXbd3>FHi
R3V9=FT00SV:00<mZSV[>HX01CV:0SV900@iJCEY=DPeJ@@eB@08=FXiJSV:>HXmZT7/AN]5b`91Z`0?
ANa>3EI=BPdeJB34DW5ooWolNcIR]6:BJVi=RBb10088008<80032248@@Q000H<@08<@@8<@007320<
@0a010000343OmH02goo00MV]E7]JaEo^G]hNg9on`02Ool9OmhSOmd00goLOmeog@0HOmd017oLOkao
_7oL4WoM0goL0Wnl00=og7oMOmd00WoM00Ao_GnlOkaog0=o_0Ao_@0AOmeooWooOoakF6:DAFU9ZVld
OoAoV6[D<@X00@00340@@00434001@PP120880a134000`Q00PQ11@a00`Q010a000D@H11R488DXaBR
008DX`036:<DXaBT00@DY00758<DHQ2348<DPQR17<<00RD500`PiART5:<HXac48<@LXaB2464DPQBS
58<258802ABT5:<DQ11T58@@HPa2244<@@0358800aAQ584DPP0258800aBS6:@DP`02588358<25883
48802AAR464@HPaQ468DHQR2588@H@0258800aB1340<@00246402aB1484@PQ21488DXQBS58<@HPa1
46801AB200PHXQR1564@HQ226:8DPQ1R0Q1Q00@<HA1Q464@H@@@HP8@PP8DPP03464<@0PP008@H08@
H@04484@HA1Q4642460248801@aQ320<@0aP46000`aP00<@H@aP4640111Q0Q1P00D@H@a0220<@A1R
008@PP046:<DXaB13642344334001@a1340<@@a036400a1P00<@H@a034000PaQ0a1Q00L<HA1Q464<
H@a0440<@002320222000`a0360@H00134000003KgYcNW=i00IgN@9cNP9cN`04Mg]gNGMiMgT4MgX4
Mg/01GNKMg]gNgMkMgX03GNJ0WNK00=kVg^JNiX01G^J2G^K00]kVW^jNkYk^g^jOkUog7onNkagNG^k
00Qk_0Ak_@Ak_0Ak_@03Nkao_7nl00Uo_0=k_09kg@9og@03OmaogGnl009o_09og0Aog@=ogP03Omeo
gWoN00AogPIogA5ogP9og@9og0=og@9ooQAoo`9ooP07Ooeo^WMHG[Ec=golOol01WoN00IoggoNOomo
ogmm80020000;QQQ=>Hdb4f/ITablWnGOoYg<ST5628DIAbU549JTWooOoeoogogBL/DAAAW66HPQCUZ
BS1644XaCU5:DTH??J`eS35[=FXa:2SU;@LeBBdY;@Ta1dEYERi[5Wom17oo00AofW]cNc=g5@9fm@0F
M]=ZLV8`A>EE[GmiOoeoogonFY<]2BRU>BQ9A7nCMgMF3c3U=DPeRCV9=HX6>HX053V9>FTeIbdV:>DL
YAR47<DTa1c46:@La2CT;BDmYcF7>HTeRSF;>HX2>J/6>HX3?HX2>HX00cV;>HXeJP03=FX01cEY>FXm
RSfZ@L]1bSEX008]1P8eJ@0B<DHaBBSW78=FCgomOoUc56:BGY9VD4f[=:8<010P320<8@PQ0PQ100<8
@0Q134000`a00Pa100<<H@aR36400PaR00@48000<@Aom`]oo`07J[IF<6lFOoegEg<@OoX00Woo0Won
2GoN8GoM00=og7oMOmd09WoM00=og7oMOmd01goM0goL0WoM0WoL00=ogGnmOk`01Wnl019ogGnmOkeo
gGoNOomofg/gFU95R58:LgIof7nkI[@/b001100244000`a0320<@002340010PP320<@0a00PQ000<8
@@a034000Pa10Pa01PQ000`<@0PP340@HQ237>DHXaB27<@Ha12336825:@25:<02aB3468<@Q23588H
PARR6<@LiABS46400QB200LDXaRS8:<HPPaQ484DPP024882588030a1220<HQB35:@DP`a1364DPQBS
6:8DP@@DPP8DX`065:8DPaB3488@Ha230aB2018@PQB2568DPQ22464<@1AQ688DH@PP340@HA213608
80aP484348800`aQ488DX`0248<0111R464@HA211QB200<DHQ1R46800QB200D@H@a03448@0aQ00<@
H@06468@HA1R468DPQ1R0Q1Q0Pa00Q1P00@@HA21464<H@8@H@8@H004464<@@PP20023600111Q360<
@0a00PaQ00T<@0aP460<H11P440@H@a132000PPP00/<HQBT5:@DXaS4468<80a1364@H@a0008<8004
340<H@aQ36423600111P464@HA1R1a1Q0PaQ00<<H0a034000`a00`aP0A1Q0@a1000016mjLgYcNG=i
1gMi00=cNWMkMgX00WMi1GMj27Mk00=gNWNJMiX037NJ27^J0g^K0W^k1G^K00]kVW^jNkYk^W^JOkUo
fWonNkakN7^j00=k_0=k^`Ak_09k_@9k_003Nk]k_7^l009k_@03Okeo_7nl00ao_003NkakgG_M009o
_09og0Eo_09o_@Qog@03OmiogGoM00QogA5ogP03Omeog7oL00=og@9ooQAoo`09OoioogomOmYgFEID
K_Eongon009ogP03OmeogWoN009ogP05OmeoogooOkl`R00200006QaQ?@Pi2dg>HReZ/7nGOoa^lC33
624LIAb6BNaomGooOoMoleH_74880A1U56<PPceXBPl2BQ0064haBU563Sf:>FTeJRSW9:DXiC4W<@La
:CU/EU5cN7ohOoaooWooOoeoVW<EJ]A^d`9blP07K]9V/f:BIY=Z]G<gOoT00Woo00i_Nd7B:>XPQc49
=BHiJ58<EVm5k3U7=FPeRSV90SV:00<eRSV:>HX00cV9010eJ3EW;BLXiAbT9<DY1RST7<@HPac59>D]
9CV6=FLiR@<iRP@iZPHiRP8mRPPiRP0K?J/mZSfZ?JTmR3E7;@DTa2CU:@HaAbT866DLHEY/OoYon6kc
HY9ZeFIaDL``PPP0300<80PP00<88@032408@@a000@<@08<@@08364<HPaS46<88@00;@=om`]oo`07
K]IJD7LeOoekNG<?OmP00Woo00=ooWoNOmh017oN0goM00=ogWoMOmd0AGoM17oL00=ogGoLOmd01WoM
0WoL0WoM00=og7oMOm`01gnl0Wnk0Wnl0Wnm01AogWooNgQVeDg>@FMFBGNHOmUkVV9d98H40@PQ460@
@0a0220<@0aP1@a000@<80PP220<@0<<@@<<@0032448@0Q00088@088800I360<HQ236<@L`aRR9@@T
iAB4364DXQS4588@PQ1R58<@Ha23364@@AB25:8DPQ1Q36400`a1010@@AQQ6:4L`aRS5:8HXaS4588@
H@a1588DXQC45:@DX`8DP`<DPP06688HPAB2464<@11Q0QBR00<DXaB258801AB200dHa1B2568@HQ22
584@HAB26:8DPQ11340@H@0448425:801122464<HA1Q11220Q1Q00DDXARR6:4DPA22008@H@<@HP08
568@HQ1Q344880a0464@HP<@H@03340<HA1Q008@H@04344<@11Q588546400a1P464@H@0346000`a0
200880024602484436402@a1460@H121460@@0a032088002340020a1464@HAB2468<H@P022023400
10`P220400a00`aQ10aP00<@H11Q4640111Q00<<H@aP22000PaP1@a000@8@0aP360@H@4<HP0000=_
NW=jLgT00W=i1WMi0W=j00=gNWMiMgT00gMi0WMj27Mk00=gNWNJMiX01GNJ00=gVgNJMiX01GNJ17^J
3W^K00Yk^g^jNk]kVg^jOm]ooGnkNgQkV`=k_0=k^`Mk_003Nk]k_7^l00Ek_0Ao_09o^`Mo_09k_003
Nkeo_Gnm00=o_@05Omeo_GnmOkao_@0DOmd>Omh017oMOmiogGoM0WoL0goM00=ooGonOoh04goo0Won
00MoogokMg]FEG<HOoioo`08Omh2Ool04WonAHl00000:84hicT[BLmND6kCOkYooVJ`;:<P8211<BQo
n@9oo`0JOn]VSbR6500LIABU68@PPSUXANi:44h`CU9>TdH??H/eBRSX9<LTYBS6=BQ=bV:cLeQoo@=o
o`08OmYgE5Y_DReJLFkBK_AZd`9Z/P04L_9k4goHOo`3Ool02VKE?FX]22cW;BT]BC58<FTaJ3VZ0SV:
00HeJCF:>JXiZcV:=HX2>HX2>HT043UY=FPeJ2dW9<DLPb36:BHY11bS68<DPaRT:@HaIcF81CV:00<i
ZcVZ>J/023V:0cV900<iRSV;>H/00SV:0Sf[0Sf901LmR3U7;@DXiBdW9>HPYAb762D805i`Oomon6kc
HY5Zm6ZABJ/THP@0200400PP00<88@03220<@@a100H<@@8<H@06368<H@@0000]0goh2goo00MRUe7_
KaEo^g]iMc5on`03Ool7Omh2Omd00goNOmeogP02Omi4Omd017oLOmeog7oM0goL1WoM0WoL17oM1Wnl
00Mog7nlOkao_7oLOkao_@02Ool037]HI[E9[Ce6GZakfWoKKaM5d1A3200<808@@004340<80a13642
34000`aQ488<H0023202340434400`aQ340<@00534002``P464@HQ235:<H`b3T8><Pa1AR58800QBR
0aB20QB30aB201lDXQB2464@HA1R364<@0PP440D@1R29@DL`aB26:<Ha1B2464DPaS47>DM1Qd77>DH
`aRT5:8DPaB2688HXP0258801Q10444DPQRS7>DLa08DPP03568@HA2200<DPP0H464<@1B2584HXQRS
7<<HXQAQ344DPQS48@HU1R466<@DXa22364<@122588@PQB20Q2200@DHABR5:<DXP8DP@8DPP04568D
HAAQ58424882468246401a1R464@HA1Q440<@0aQ008@H@0:468@HA1Q588HXaBR484@HA1P34024640
1aR2460@H@aQ344@@11P008@H@8DX`09488<H@aQ344<@11Q5:<@PA1000<<@004344@@0a044424640
1Pa0220880a1468@H@8<@@03340<@@aQ00<<H@03340<H0aQ008@H@D@H003364<H0aQ008<H0D<@004
360<H@aQ364136800003KgYcNW=i00EcN@AgN@03MgQgNGMi00EgN@=gNPIgN`9gNPIgVP03Mi]gVWNJ
00IgVP=kVP03Ni]kW7^L009kV`AkVPAkV`=k^`9k_007Nk]k_7oLOkUgEW^JMk`00W^l1W^k00=k^W^k
Nk/00W^k1G^l1Wnl0Wnk0gnl0g^l00=og7nlOk`00g^m1Gnm5goM1goN00=ogGoNOmh03WoM00=ooGon
Ooh04Woo00MooWooOomofG<GFYMkO002Ool8Omh2Ool04GohFOD00P00<80hiCD:CO1NDG<fOkYk^eY>
;<<P@2RQHZh00Woo00]oo7MC<<DD1QaV8<@PiQbT8:8iIdh_009BD@04F[9BDD7==@T29:P01RBY<B]5
SV:dNiUonP=oo`06OoicVfmHLeQo^WoI0Wok01=ofgnJOiQongonOomooWolOoU[5TW_<D/a:Bd8=DPi
JCEY=FPaJ002;DL01be8;DTeJSF:>JTiZSV:008eR@@iR@0E=FTiRBdW8<DHHQc58>DTi1bS68<DPaRT
:BLaJ3F:>JXiRSF;=HXiZSV[008iZP03>HXiZSV:00<iRP@iR@@iRP<mRP04>HXmZSf9?HT2>FP053EY
:@HTaR377:P<1AQ5CNioo7ngIXeRKF[BK[59RbR4100800PP3203220010`P344<@@a10Pa000<<80a0
36000Q1Q00H<H0a0000003E4OoH:Ool027oOFWI=cVKCNgQkNGLbOo`3Ool5Omh6Omd00goNOmeog@0l
Omd00goLOmeog@04Omd9Om`5Omd2Om`3Omd00goLOkao_008Ok`00gnkOmaog@02Ool047nKI]I=[TEV
I^eonWoKJ_HiKPP0100<01AP464<H@a10PaQ00T<@0Q0460DXQB1340<8@a1340010a100<@HPa02200
1Pa000D@HA225:8DXac3008HX`04588@HAB16:8258800a21488DPP02488011BR6:8HXQB10QB200<@
PPa148800QB200DDHAR26:<HXA1Q00@DPP0=5:8Ha1S45:<@Xa216<8L`aB2344DPaR36:<00QB30QB2
00PHXQS37<<HXAAQ444DHAB10QB200<@PQB158400aB100THXQbR7<8PhQB0564DPQRS6<@00R4600<L
iABR5:800a2200@HXQ1R468@PP<@HP03364@HAB100@DP@03564@HAB1008DPP05464@HQ1R464@PP02
46401aAP460@HA1Q484DXQBS00<@H@<@P@8@H@04340@H11Q4642460010aP340<@11P1A1Q0PaQ00D<
@@PP340<HA1P008<@008440<H0aQ344<@0aP464@H08<@007344@HA1Q588DP`aQ344010aQ0Pa000<<
H0aQ46400a1P0Q1Q00L@H0a0460<H0aQ360@H002340434413401364136800003KgYcNW=i009cN@=c
NP03LgUgNGMi00YgN@AgNPEgN`9gV`EgVP03Mi]gVWNJ00MgVP9kVP03Ni]gVg^L009kV`=kVPIkV`9k
^`0;Nkak^g^kNkaog7niMeQgNgNlNkakV`05Nk/017^lNk]k^g^k2G^l1Gnl00=o^gnlOk`01Gnl00=o
_G^mNkd00g^m0Wnm6WoM1WoN0WoM00=ogWoMOmd00WoN2goM0Won4goo0Won00IkVEicI]Mk_WooOoh8
Omh04gonOomooVJH00D002aP?<@e2Tg`H[AgF7^JKeUB3RB2::91A7oe009oo`0FOoQAbA`086HLaac6
7>LPaR2S>FMB;e9@E[=><Cf=::PTABRW<@U=cV;ENk/4Ool017omNkIkfgom37oo00UonFKcCL/iJc4Y
<DXeJcV;=HX00cEY00PeJ35X<FTaJC5Z<FTeRCF:0SV:0Sg<01DmbcV9>HXiZSV[>JX]BBC568<PaB3V
9>@PiAc56:@TiC5Y=JTic3F[>J`013V[0SVZ00DeZSF[>J/iZcV:008iR@LiRP8mRP0;>HXiRcf[?HXm
RDG;>HX]BRSW<BU9kP02EW@035IBGY=_>6KCDLQN:fkBK[1=[2R41008008<8003340<80a100L<@@@@
H@06460<H000000iA7oe2Woo00QkWUYfEO1^m7nkNgYgF7om0goo00AoggoNOmiogPMog@EogSUog@9o
g003Omeog7oM009og004Okaog7oMOmd5Om`=Omd:Ok`04WnkOmeoogooOi]NU4g<DJA_;goiOkYV]34<
1008010P460@H@<<@@88@@06120<H1BS488@H@a11@a000<@@11Q34000Pa00Pa10Pa000`<HA1R6<@P
iB467<@HXa1R488HXaB26:835:801aBS588@PQ237<@LXaRR008HPP04588HXaRS5:826:<258800aBR
6:8DXP0558825:82588021BR6:8DXQB2340@HARS588358<26:<01ARR5:8DPQB158800QRR0QBR00<H
XaS35:800QB201P@PQ21588DPAc2564@HA23468DXacT6>DDY1BS5:8DPQ2358<DXQ22344@HQB24683
48800a1Q460@H@02464256401AB2488@HQ1R46401A2200T@HQ1Q464DPQBR6<<@PQ1P3600111Q00<@
PQ1Q46400PaQ0a1Q00@<H0a0340<@0@@H@@<H@05344<H0aP3408800234000a1Q364<H@033640111Q
320<@0a10PaQ00@<HQ23364<@08<H@03464<HA1Q00D<H@04464@PQ1Q464246000a1Q364<H@033600
1`a1340<HA23488@@@a1004<HP0000E_NW=jLgUcNGMi00=cNPmgN@=gNP06Mi]gNgMkMg]gNWNK47NJ
0W^J17^K0g^J2G^K0W^k00Qk_7oLOkUkNGMkMieg_7^K1W^k00=k^W^kNk/01G^l00Ik^g^lNkak_7nl
Ok/2Ok`2Ok/3Ok`2Nk`2Ok`00g^mNkak_@04Nkd2OkdKOmd00goNOmeog@08Omd2Omh6Omd01GoLOkao
gGoMOoh04goo00EooWnkK_IJU7<i009oo`YogP9oo`0WMc/<1`00<40lhcTZDS5_5W]jNiUVmTF/::8/
`EhROnIoogolI[4/abB4:<DTib376:HPab2S=BI:359=DW4m[21V30DTR4F^JaMofgok009oo`05Ooio
oF[hFY=oe`09Ool077omOoUoVW=HLcMVmE8_>F/a2SE:=FTeJSV:=HTeJC5X>JXmbcF9<FTeRSV[>JXe
RSEY<FTeRSV/0Sg;00]1bd7/?L/eZSF:;DPXiB2T9<DU1RCU008Pi@048<@Y1C69?N`2?Nd01CV[>J`m
c47]?L`00cW;00dmc3g;?J/mbcf[>HTeRCV9?J/iRSF:>HXiZP02?J/02cV:=HXiJSV:AL]9kCV:9>LL
adh`Om`00Woo00ioo7nkJ_IF3TUWFNQ^/6Y=BJ/XP`@0200<80a00PPP00<<8@`P32000Pa100<<HA1Q
46400a1Q00L@H0aP34048000>B=ol`0:Ool027noGYMNDgLEOmekO7MjOoh4Ool2Omh:Omd3OmhiOmd5
Om`00goMOmaog002Om`3Omd00goLOmeog00@Omd6Ok`047nkNiUog7ooOmec>5X_CLYAhg^@OoQo^5i@
9<X000P00Q1000<<@0a134400PQ10Pa000<<H0aQ36400Pa000H<H11P320<80a0440434003PaQ344<
811P464@PaS47>@Ha1BS58<@HaRT7<<2588258401A225:8DPQB35:<00aRS00XDPQRS6:@HXQB26:8H
PQRR5:<HX`8H``045:<DPQB258825:8458800a22588DPP0858800aRQ6:8HXP04588021c38<@La1c4
5:8DPA21468248800`aQ340@H@0246403PaQ48<<HQB27<<HXaB3588DPA1Q468@PQBS488346801A1Q
488HXaRS46800Q1Q00@@HQ22588DP@8@H@09444@HA1Q488DXQ22484@HA1R00<@H@07460DPA1Q3408
@0aP46400a210Q1Q00@<HA1Q464DP@8@H@8<H@03240880aP008@H08<@0<<H@8<H006240480@0340@
H0aP0PaQ00@@HPaQ460<808<@004344<H@aR3683364020aR464@H11Q588@P@aQ340222000`a1460@
H@02460236401a1Q460@H0`P340<H1B1008<H@8<@@4<@P0000=_NW=jLgT02G=j0WMj1gMi2WMj00=g
VgNJMiX00gNJ0gMj27NJ0W^J17^K0g^J2G^K00ak^g^lNkaog7oJNiYcFgNMMiakW7^kNk`7Nk/<Nk`0
0gnlNkak_003Ok`00g^lNkek_@08Nkd3Okd:Omd3Om`<Omd2Omh:Omd3Omh7Omd2Ok`00goLOoiooP0@
Ool027onOkebmVkgMgYogGooOoh9Omh09gonOomoognn82X003A0?<=1JUYBJ_EgF7MGGY4mJRbQ=@9Z
Z7o^Oomo^STW74<PQ2T69>HPaQS67:DLPc4VBNaJKSg=;@PP8RcXH[EooP05Ool01F/HBFY5JVlfOo`0
0Woo01U_FeIdDPiNT5kCFY1FL57/@FTmJ5G[FRaF;d6/=BTa:BdX<BL]B2e7;BP]9bTW;BL]A`03<DL2
<DP2;BL01Be8<DP]BBe8;DT00be800H]JBe89@HTaAR48<D28>D01acU7<DHY2CU:BPaJC6:00<aJP0:
=J/ic3FZ<FXeZcV/=J/eRSF9>HX2>JX04cV[>HXeRSEY>HXi[3g<>L`iZcF9=FXiRSUY>HQ5bcUY78<P
b6]I00Aoo`0=OoigFDf]>BQN2FZ@ITi5RbAR100800PP32000PPP00D88@`P320<@0a1008<H@8@H@8@
H007360<H@aQ120003e4Oo002Woo00QogeigGU9g5GonMgagVgon17oo0Won1GoN0goM27oN6GoM0WoN
00=ogGoNOmd06GoM17oL77oM01Eog7nlOkao_7nmOkao^golOoio^V[fENe=ZUY9Ok9onG^HCPlHR000
22000Q101@a10Pa000P<80Q0440@@11Q368<H0`P0`a000<<80a012000Pa000<<@@aQ46800Q1R00<D
PQRR6:<00QBS00`@PaRS7<<DXPa1320@H1225:8DPQ225:<36:<01aBS7>@Ha1BS688HPARR008HY0<D
X`0458<DPQB258825:83588011BR5:<DXaR21AB200<DPaAR58800QR100@DPA22468@H@HDPP07464<
@A1Q48<DPa2358800Q2200L@HQ2248<@HQBR7<<DXP0246801QB2344@HQ23588@P`8@PP05464@HQ22
48<DPP0246801Q1Q488DPQB2488@H@<<@08DP@04588@PQ1Q44024682364246002A1Q2208@0aQ484D
PARR588@HP023440311R464@HA1P440@HA22588@PQ1Q360<@0<<@@H<H@04368<H@aQ360236401A1Q
484@H0a036000PaQ0`aR00l@H@aR48<DPa1R464<H0aQ464<H@`P220<@@aQ46000PaP0Q1Q00H@PQ1Q
460@H0P04402464010aQ368<HPaQ0@a20005LgT3LgX017MjLg]cNg=k0WMj1gMi2gMj0WNJ0WMj00Ig
NGMjMgYgNWNJMgT4MiX00g^JMiYkVP02NiX00gNJNiYkVP07NiX7Ni/02W^kOk]ofW^kLeagW7NKNkak
^g^l27^k17^l0W^k00=o_7^lNk`01G^l0Wnl00=o^g^lNkd01G^m00=k_7^mOkd00Wnm00=k_GnmOkd0
2GoM00=og7oMOmd037oM0WoN2goM0WoN0goM1GoN00IogGnmOmeogGoNOoh9Ool3Ooh02GoMNkagVg<I
KaUkNgooOoioo`07Omh017oOOmiogWoN0Woo01Io_cC]300`83R0BJYNLFkeMeIg=5i_@HX`X4E1L^]o
kGomH[@T@APQ8:@Ta08Ti@0R9>HTaBCU<BM9jdh]<DLXaTF:LcIongomOo]oo7oJIaI:4Bc;@@UZm7oj
OoMJeC5_44L40QA37:8Pa1R2420@8AQQ88428:4021R2668DHQR36:@La1c56<@56:@02Qc49>DTi23U
8<DLaB358>HPiAc50QRU0Qc500@PiB3V8>DHaP8DQ0057<DLiR3U7>DHa0026:@011c58>DPiBCU0R3U
00<Q1BD58>D00b3U0RD500<Y1BT6:BL01RdV0RdW12e700P]9c4V=DHiIc448:<a:g>J1Goo00ac5cdZ
;<IIjVkBKY1=[2R3100800PP32033402320234002A1P464@HA1Q360880aP3648@@0200000d5UOo1o
o`09Ool027nnFWMJ<GLDOmak_7NKOoh5Ool6Ooh00goNOmeog@09Omh=Omd00goNOmeogP06Omh00goM
OmiogP03OmhJOmd4Om`<Omd00goLOmeog@04Omd2Om`2Omd3Ok`2Om`01GnkOkao_7nlOkd00Wnl011o
oGolOkMZm5G;AFQR[GncOoUgMT6]46D000a0440<@0@<@@P<@0D8@0@88003340<H0aQ00<@H@04340@
@1B26:<25:<26:<01b3S7<<@@0P0340@PABQ008DXP0<488DXac48>@La1c2584DPac47<<HXaB30Q1R
00TDPa1R344DPQBR588<@1B25:800Qc400<HY1BS588021B20aR100hDP@PP120<@AAQ584DPQAR348<
HQB35:@DPa220Q230Q220aB20Q221AB201D@PPa048<DXaB2364@PQB2584@H@a1468@HAAQ464@PAB2
7<<DXQ2136400Pa000<@HAB14840111Q0Pa100<@HA1P46400Pa000<<@@aQ46400Q210QRR00@@PQ1R
468@HP8@H@07460<@11P460DXABR46400Pa000<<@@a034000PaQ00<<H0aQ36400PaQ00@<PQ21360@
H08<@003360@H11P00<@H@<<HP@<H@D<H00<364<@0PP364@HA1P2208011Q5:8HXa210Q1P00D<@11P
460@H0aP00<<H@4<HP001G=i00AcNWMiLgYgNPEcN`03LgYgNWMi009gN@AgNP03Mi]gNWMj009gVPEg
NP04Mi]gNWNJMgT2MgX01GNKMgUkNG^JMi/02GNJ0W^J0g^K0g^J1g^K00Mk^gnkOoaog7NLMg]gW007
Nk`3Nk/5Nk`2Nk/=Nk`7Nkd00gnlOkeo_@02Nkd00gnmOmeog@04Omd2OkdAOmd00goNOmeog@07Omd4
Omh3Omd6Omh3Omd017nmNkaogGon17oo00=ooW^lOmd00WoM00Mk^gNKMi]kVg^LOkeogP03Ooh7Omh0
17oOOmiogWoN0Woo00=oge5b50000S0P039=REjBKaMkNGLeGW0mBBbPEJ9oKWoXOoeAlB0P864TXbST
9>@Xi2SU;>La1cU8?J/mRRBS?FURSWoIOoYo^GMhGY15ZdEY;:DliFZ`Oo=koD7?:<LLQ`P210088@a1
220400PP0Pa100D8@0a03448@@`Q008<@@04468@PQ23468334801Pa1220880a1468<H@8<@@04468D
Q1BT48@248<011245:@DY1B30Q2300DDY1c67>HLiQcU008Ha@8HY0037<DPaB3500@La0047<<HXaR3
7:<27<<37:<00abT8<<LX`0278<28:<00abS8<@Pa0028>@02R3U9>DPa2SU=DLiAbcV=FY[=Gog0goo
00UooFJC:8HXQ5WZL_E^/U7^<:@00PP00P`P10PP00D<80a0340<@0a1008<H@05360<H@aP22040002
00000dW7OoEoo`09Ool027^nI[MVU7LeLeUcNg=iOoh5Ool2Ooh00goNOoiooP02Ooh00goNOmeogP08
Omh5Omd00goNOmeog@05OmdAOmh7Omd00goNOmeog@0@Omd00goLOmeog003Om`8Omd00goLOmeog@04
Omd2Om`3Omd01WnlNkao_7oLOk]og0Eo_00=Omaoo7^HJ_EEbT5WH]5o]WojLcLiS@PS22400Pa000<<
@@aQ36400`a10Pa000<<80a034000`Q10`Q000<8@@Q024400PPP00@<@0aP364<H@8@H@8DH@0H6:8H
XaBS58<@PQB19@8P`QAQ320DPABR6<<Ha1BS4:<DXaRS5:<HXaRR440@HQB30QRS0QAR00`@HPaQ464D
PQS3588DH0a0588DPaRS6:@4588021RS5:8DPQBR7<@HXaB24402684021B1240880`P684LXQR25643
58<01ABT6<@DY1B358800Q1R00@DHQAQ588@P@88@00:464DPQRS5:<@PPa0468@PaB3588248802QB2
464@HA22588@HQ1Q488DPQBR0QB20Q2200hDPQBS5:8DPPa0460DPA22468@HA1R444@H@aR0PaQ00X<
H0a0460@PAB16:8Ha1BT48<@PP<@HP<@H@07484<H@aP340<@@PP340010aQ018<H1215:<DXaC45:<@
PPaP220<@0aP460@@0a0468DXa2336823443364536002PaQ464@H@aQ488DXQ1P200<HABR111Q1@aP
0`aQ0@a20005LgT017=jMgUgNGMj0W=k00EcNW=kLg]cNWMj00=gN@9cNP9gNPAgVPIgNP03Mi]gNWMj
009gN@9gVP9kN@agVP04NiYkVg^KNi/3NiX00g^KNiYkV`02Ni/02g^JNkYk^WnjOoaooWnlNgYgVg^l
Nk/01G^l0g^k1G^l0W^k2W^l00=o_7^lNk`01G^m00Ek_7^mOkao_7nm00Ak_@9o_@=og@9o_@04Omao
_7nlOk`IOmd2Omh5Omd4Omh8Omd01gomOmigW7=IMeUk_7oL00=og@9ogP03OoiogWoN009ogP9ooPUo
gP06OmmoogooOomREa`00RaP0315JEjCJ_IgFFJbDNhXQBbQFN9oRgoXOmXiSbBT984X`bST9>DTa22T
:@Li[46/>DXXabBSFRYc<WNCI_9JD4EX<@Le22cX@FMZlGo`OnMVm2C<88PTZ2CX68@DQ1B36<D28>D0
1ac56:<DPaRT7<DLiB3U008Pa@<La@086:@DQ1B458@HY1B4468<HP8@HP09348@HQ1S5:@LiB3V7<DH
Y1RU00@Ha@037<@HY1RT00@HY0068>DTiB3U8>HPiBCU0RCV00<PiB3V9>D00RCU0R3U00<PaAc47:@0
11bT00dPa2C48:@LY2349>DTi23U8>@PiAbS8<DTaP02=DP012dV?JYR[Go`0goo00aoN5F/96@/aEh[
L_A^TTg=:8@400P0320522000`a0320<8005340020aP340<@@@0000404gYOoT:Ool027oNK]U^eGMF
Lia[>g=HOod5Ool9Ooh01WoNOoiooWonOmiooP=ogPeog@=ogP03OmeogWoN00=ogP03OmeogWoM00Eo
gQQog@03OmaogGoL00Iog0Mog@03OmaogGoM00Aog@9og09og@9o_09k_003NmaofgoK00=o^`0BOkao
_GoLOoYg=fJcDJU=jV/DOmIoVFKf<D`00@@0460@@0aP0PaQ0`a100<<@0`P32000Pa000<8@@a02400
10Q000T<@0a1240880a0364<@0`P56000QB100dHPARR5:<DXQ1Q444HP2T28:4DHQAQ5:8H``027>@0
0aS45:<DX`025:<011BT588@HA110aB200/DXaB358<DXaRS5:<DXQBQ584@H1AR00<DPP8<@@03468D
PQB200<DPP056:8HXaB2340HP@0258402122340881R18<<LXQB258<35:<00aS46<DDX`0248801a1R
464@@1B15:4DPA21008DP@<DPP03464@PQ2300@@PP03468@HA22008DXP<@PP8@H@05488DXQRR6:<H
``026:<05QB2488DPAB25:<@HQ1Q348@@A1Q364@H@aP340880a0460DXARR588@PQ230Q2200H<H@aR
468@HQB2488246402@aP364@HA22368<H@a1244<H00248425:82364010aP340<@@aQ0`a000@<HA21
488@H@<<@@08340<H@aP360@H0aP464@PP8@H@03468DPaB2008@H@07364@HA1Q464@P@aP340010aP
0PaQ0Q1Q0002LgT017=HLgUcNG=j0WMi00=gNW=kLgX01G=j0gMi0W=j1GMj00=gNGMjMgX017Mj00Ag
VgNJMiYgNP=gVP9kN@=gVP=gV`MgVP=kV`=kVP03Ni]kVW^K00AkV`08Nk]o^goKOoeofg^ILeUkV`9k
_004Nk]k_7^lNk`3Nk/ANk`00gnlNkak_004Nk`00g^mNkak_@09Nkd5Omd01GoLOkao_7nlOm`067oM
00=ogWoMOmd017oM1WoN0goM00YogWoMOmaoo7ooOmiVLFlGOkaoo@9og@QogP9ooPYogP0jNmioogoo
J_U5:TUZCJaF3ejCI]AZmEi_>DP/icTTFP5oSgo[LeD];236;@@/i2C48>DLY1b38>Likd7<<>HPI2S3
I]1on7neJaEAkSd7?@Thid5[G[9onGooOoMEjbBX98LeBc5;;BLaBCEZ<FXaJ3F9=FP2;BL02S5X>HXi
bcV[>HXeJCF:>HXmZcV:0SEY00HeJSV[=HXeRSV[>HX2=FT02CV[@L`mcCf[>J`iRcF;=H`eR`02>J`0
4cV[;DTaBC59;DLY9be8<DT]BBe8=HXaJRe8<DPaJC5Z<FTaRSEZ008aJ003<FTeJS5Y008]:006<DP]
:2dW;BL]1RT50Rd600l]9RdW;BLY9RT5:@LY1RT7;@Ha9c58>J]1k6:]OoH00goo00]_64eY;:Ha1V9Z
K]9ZLdV<84<400P0008880888@888003340<80`P00@<@08@H007360<H@a0000804h:Oo/02Woo00Qk
_F[GH]EcF7?NJe]gMgom1goo0Won00=ogWonOoh00Won00AogWoMOmeog@EogPMog@04OmiogGoMOmd5
Omh00goMOmiogP03Omh00goMOmiog@02Omd3Omh4Omd00goNOmeog@0AOmd00goLOmeog@04Omd3Om`<
Omd2Om`00goKOk]k^`02Nk/01G^KNkakg7_KOm/00gnk011o_7^mOmeo^FkfGU1AbE8;LeIof7MGFU<P
Z000100@H08<@003344<H@aQ008<@0<<80H<@088@00F2208@0Q1488<@0Q0244<@110584HXQB2688H
XaS45:8@PAAQ7:8a8bCS58435:802aB26:8LXb3U5:<@Pa225:@HY1R368800QB200<DXaRS6:@00QBS
00DHa1S55:<DXaBR00@DPP03468<@@aQ008@HP8@PP03468@HAB200<DPP03584HXQB2008DPP0:364D
XRD66:<HPQRT5:<DXQB258<35:<2488256401QB16<<H`aRS5:8HXPDDPP0558<DPQ1R468@PP025:<2
5:8011B1488@PPb20Q1R0Q2200HDXQB2588DPQRS588248800aBS488@PP024682464336403a1P440@
HARR7<<HXQB1340<HPb348<<HPPQ220<@0023640111R464@H@aQ0Q1Q00/@PQ1Q340<@0aP460@HA21
3648@0PP0088@004340<HAB236423402364010aP460@H@aP0Pa00Q1Q00`@H1226:@DY1B2468@HA22
464<@0PP3643464010aQ340<@@a00Pa10`aQ0A1Q0A1R000017=hLeQcF7=H0W=i00IcFGMiMgYcNW=i
LgXAMgT6MgX00gNJMgYgN@03MiX017]iMiYgVWNJ0gNK1WNJ2g^J0g^K00ak^g^jOkYo^WoiOkUgFGMH
NgYg_7^kNi/6Nk/BNk`5Ok`6Nk`4Ok`2Nkd00g_MOmeog@03Omd3Om`QOmd3Omh3Omd4Omh02GoMOomo
og^LK]AkNWonOoeog@09Omh2Ooh01WoNOoiogWonOmiog@EogP0cOoioogmlK_URMFJEJ]I_>7MiLeMV
lTh=EPmRK6ZWM`]c2EH;:>XTiRdT:>@La23U6:DHQ237<F/]9bBS9:DmJFKAOoQonGomJaQ5CC4;@HmB
Lg>kOoeon7NF=BHPI2AS9<DXiRT600DPiP078@HU1bD69@LQ1RD7;BL00S570S4W00<aB3E7=DL00SE7
01<]9bTW<DPaBC4X;BPaB3VZ?JXiRSEZ;DTaBC5Y;BPY9c58=FTaB@029BT03SW=BRm:;d7]<DTY:BE9
9@DY1C4W<DLaB35Y=FT2<FT00cF9>HTeR@02<FT02cF9>HXiJC58<DTeBCE8=BPa9S4W<DP00c5Y01Te
JCF9=HXeRSVZ?JXiRSF9@JYF2WMcOoEongojHYDe1bB3=BEZZ7;cJUA5K2QT10080007220332053400
1a1P464<@000321F:Wol00Uoo`09OoikVfkDI[=c=g?MLi]gM7on00Aoo`QooP03OomogWoM00Aog@03
OoeogWoN009ooPIog@05OoiogGoMOmiooP04Omh3Ooh2Omd00gonOmiog@06Omd00gonOmeog@0?Omd2
Ood2Omd3Om`00goMOmaog@02Ooh00gomOmeog002Om`00gonOmeog@04Omd2Ooh3Omd037oLOmUkUg^I
NkYkUg<ELeUk^gokOoao^`9k^P0BNkak_GonOgMZe5iADJQF1gMfOoMkVEHb86D000`Q460<80PP0Pa1
00H<H@a0340880a03207340010Q0120880Q00Pa00PQ000/<@11P684H`aRR688HXacU7<@HXQR200@H
XP036<<DXQ22008<H@035:8HXaRS008DY00D5:DDY1RS7<<LY1BS58<DXaS45:<DPQ2248<@PQ1Q340@
PQB26<@HX`8DPP8DP`8@PP0448<@PPaQ488458802QR2588DPQRS6<@Pi23U6:<DPaB40QBR0aB20a22
0QB200@DHAAR488DPP8DXPHDPP0:5:<@PQ1Q468@PQB2488DXQS35:4248802@aR464@HA11340@HAB2
584DHP0246800a1Q468@H@0248401aBS48<@HPaQ464<H0aQ008@H@08564HXQc37<8DP@PP368@P`8<
HP072488@@aQ364<@0PP3400111Q0Q1P0Pa000@<H11P360<H0<<H@0;344<@0aP360@HA22360<@0PP
320<H002460232004@a0220880aP364@HQ22468@HAB1460@@0PP344<HPaP46000PaQ00<<@@PP3400
0Pa100@<@0aP360@H04@H@0000=cNG=HLeP017=i1G=j00=cNG=jMgT03WMi17Mj00=gVgMjMi/00WMj
1gNJ0gNK1GNJ37^J1G^K00Qo^WniOoaoo7nILaIgNgNL1g^k5G^l0gnl00Ek_G^lNkao_7^m00Ao_004
NkakgG_MNmd?Omd00goNOmeog@0AOmd3Omh3Omd3Omh2Omd5Omh2Ool01GnmKcQkVgoMOol00WoM2WoN
00=ooWoNOmh00goN00=ogGoNOmh00WoN17oo00EkFVJfIYAc>7^k009ofP0?MgQ_F7^kMeEVR6ZYGRI5
Zbd89>HY12348<DTiRD6008Q200>8>HPaB2R?FQAk5j@MgUoo7ooOoeZmT7ABWAWNP9oo`08NiQF2bRS
::<D@Q12444<@08<@@<8800334488@a000<<@@03440<@0`P008<808<@@8<@005444@HQ1Q344@@@02
34402A1R344880PP224<@@aR468<@@0232404PP0104M24I@JiUc^GNjIaIR/cW=8DX@I0a2468DPaRS
6:@DQ0<HY0036:<La1c500LLa@047:@LXabT8<D28>D28>H00b3U8@HU1P027>H04R3V:@D]1Bd4<BE:
2gNFOkAV[ce[724H0C45JZUc4fHcBF//Q088000734488@PQ2248@0PP24001@a00`a100L<HA113200
010PEPYonP0:Ool01gnkMaEZ/VlgLka[FGMg00Aoo`9ooP03OomooWon00AooP=ogQEog@03OmiooWon
00=og@03Omioogoo00=og@04OmiogGoNOmhCOmd3Om`<Omd2Om`;Omd07WoLOmeofWMDK_Ac=G]fL_E_
5W^JOoaog7^jOkYk^W^kNiaogGnGK]AJ;dUUFTYk^GoiNiYB41@Q1008008<@004360<@@Q134433403
2202240434000`Q03408@00224000`Q12408@@0234001QB15:<DXQR26:<Ha08HX`8HXP8DXP036<<H
a1BR008DX`0648<@PQ1Q588HXaS50QBT00HLa1RS6:<DPQ1R5:<25:@0211R244@PQBR488880a158<2
5:<01QBT6:@DXaB258<DX`<DP`HDPP03340DPQRS008DX`086:<DXQB358<DXaRR588@HPD@PP05588@
HPa1344@H@025:8011B2344DPQc40QB200<@P`aQ46400a220Q2100XDXaBR488<HP@P464DHA1P440H
P@8DPP8DH@<@H@03484<PA22008@PP055:<@PQ10464<H@0246401`a0464DPQcU5:8<HA1R00<<HP08
2488HQ22588@H@`P444<H@8@H@05484@H11P360<H@02340010aP460<H11Q10aQ00@<@@a0360<H08<
@004320@H0aP46023206340010a1468@HA1Q0Q1000<@@A1Q364010aQ10a100D<H@a0360<H11P004@
HP0000AcFG=HLeQcF0UcN@=cNP=gN@05LgUgNGMiMgUgN005MgT4MgX00gNKMgYgV`06MgX<MiX8NiX8
Ni/02G^JNiUofgooOm]gF6lHMi]kVP05Nk/7Nk`00g^kNkak_00;Nk`01G^mOkao_7nlNk`01Gnl00Ek
_7nlOkao_7^m00=kg@03NkaogGoM00=og@03Okek_Gnm00iog@03OmaogGoM011og@03OmiogGoM00=o
gP08OmeoogooNka_67MkOmeoo@Aog@UogP=ooP=ogP03OmeogWoN00=ogP9oo`0COoi_5dg=ELaV/Vlf
OiQo^FmEH]5_4flAHXYVRf8Y@HTa1Rd5:@@00RCU01XY1RCV9>HU1bD89<L/i4WZH[1RTVKDNgUooGok
OoYcW7>lOoioogolFThe:346;:8D@@`10PP01@PP1P@000<<80a032000`@000H880`P320<80a03205
22031002000010@0220880@00P0000<893h?MmH00Woo00Yoo7omNma[FCG`46D40@@0348<@0D880<<
@@<88007320<@111464@@@`P44400QB20a1R01LDPa2336848@00100@HBT39>8LP22Q;BHeIc4V888H
8A@1:<=N:G;AJU=9Jbb20088000334488@PQ0088@@88@0D<@00:344@@A11440<@0P0000@85H9OoT9
Ool02gonOk]flfZaLaAkMgLeLaEkNg^lOm`00WoM0g^m0WoM17^l00EkW7^lNkao_7nk00=k^`03Okak
_7^l00Qk_0=k^`03Okak_7^l009k^`9kV`Mk^`03NiYk^g^k00=k_003Ni]kW7^K009kV`03Nk]kVgNJ
009gVP05Ni]k^g^kNi]gV@03NiT00gNIMiQgV@03MiT01W^INiYk^gNJMgUgV@=gN@04MiUkVW^JNiX2
MiT00g^JNiUkVP04NiX01GMgMeEg=7<eLaH00W<f00MgEWMgNiMo^7oJOkUo^P02Ok/02WnGJ]AJ3Df5
FTao^GoHLcI1S0P00P@000D<@0aQ584@PPa100@<@003240880PP0088@0L<@088@0031208@0a10088
8008464HXQRR6:4HXaBS6:<DXP8DPP04488DXQBR5:<35:802AB3468@HQB26:<Q1ABT5:<DXP025880
0a1R5:<DY0025:D01PPQ220Ha2DV6<@@PP8@H@03488DPQB2008DPP035:8DPaB3008DP`DDPP0;584D
HAAQ588DXQB2464DHARR5:8DP`035880111R240<@A1R0PaQ0Q1R00T@H@a0488DXQB1340<@AB27<80
0QB101@@HPaQ464@HA21584@H11Q488DPA1Q244<@AB1588DHA1P7:4HXQB20QAQ00D@HA1P484DP121
008<H@03468DXaRR00D@H@888003364@HQ1Q008@H@08488@H@a0224<HQBS6:<@HP8<H@<@H@<@H0<<
@003360@H11P00@@H004340400@P344236002@Q0220<@0aP488@H0a03208800236023442220010aQ
464@H0a0111Q10aQ0Pa10PaQ0`a00@`P0A1P0A1Q000016mILeQcF6mI0W=I00=cF7=iLgT017=i0g=j
00AcNG=jLgYcNP9cN@03MgUgN7Mh00AgN@9gNPEgN`9gV`9gN@03MgYgVWNJ00agVPIkVPIkV`0@Mi]k
Vg^KNi]kVWnkOomooW^kLcQc=g^JMk]k^g^lNi/FNk`00g^mOkao_003Ok`4Nk`2Ok`2Okd5Nmd2Nkd9
Omd00g_MOmeog@0IOmd3Omh2Omd3Omh01GonOomogG=IMg/00WoN00=ogGoNOmh04GoN00=ogGoNOmd0
17oN01MoogolGY@TZ3d[FQ1ZmGMgLgUFLE8_DPaNJf9ZIX]N:cU7;>D/i2ST9>DTaR3V008TiP0I;BPU
22C7;>E5jekCGW=RLFKCMeMof7omOoiooGonNmeN/d6[<@P`iRc4548@@Pa1468011B30Q1R10a100@@
HQB3488<@@8<8003324<@A1R008@HP07444<@@PQ344<@Pa124000Pa001D<80PP220880a1444<8@P0
204LbDibLkQkoWOkJgUWNFnlHcLn4A2810400Pa300<<@@`Q34800Pa20a1R0Pa200@@@Pa2444@@@8@
HP05444DHQR36:@HX`0258<02QAR468DY12424840000200PiB2S0QAQ00`LXR3R8>@PY1aR76</i5h[
K]5ZDDf:<:8220000`a02448@@0224432402340244002Q11440@@11034888000421J:7oh2Woo00io
_7LDK]9^lVkeJ]=V]6KELaMk^g^mNmekgWoN0goM0W_M00Ak_7^mNkek_AAk_003Okak_7^k009k^`9o
_09k^`05Mi]k^g^lNk]k_004Nk/4Nk`017^kNi]kVg^K0W^k17^K0W^k1G^J00=gVW^JNiX00g^J00=k
Vg^JMiX00W^J00=gVGMiNiT01g^J00=kVG^JNiX00g^K025kVW^INgUgN7MGMgQgMflGI_Ic5G^FOmYo
^WnIOkYo^g/gJ[AJ3EFWJ]5ofgniH[<e2@P0300<8110364@PPaQ34400Pa000<<H0aQ364010a110a0
0PaP0`aQ00l8@0PP244<HA1Q564HPQc36:8HXaBS6<<Ha1BS48800aBS01XDXQB25:8DXaB2468@HARS
7<DPi1RS5:8HXaBR364@HQBS6<@HaA1R100DHRD69BHLiABR0QB200@<HA11564HPP8HX`8DY00358<D
PQB200DDPP0;540HXQcT6<<DPQ1Q564HXQB2484@PP0258801Q22468<HA1R488@P`8@PP09464@@1B1
588DPA1Q468DPaRR008DPP03364<@11Q008@PP03588@HA1Q008@P@8@H@07468DPQB2484DXAc15840
1A1Q00H@PAB1464@H@a04684488011BS484@H@aR0PQ00PaQ00L<@0aQ488@HA11244<HP025:<23680
2`a1364DPPaQ460<@11P340@H0aQ46400Q1P0Pa000P<H11Q364480PP344<H@aP0`aQ00@<@@aQ360<
H08<@08<H005340<H@aQ364<@@043642464236433682344010aQ368@H@a00P`P0A1P0@aQ00000fmi
LeQcF002LeT<LgT3LgX9MgT00gMjMg]gN`04Mg/2Mi/2MgX>MiX6NiX<Ni/2Ok/2Ool01WoLJaEgEW]i
NiYkV`9kW0Ik_0=k^`]k_003Okak_7nl00Yo_09o_@Ek_@9o_@Aog@=og1iog@=ogP=og@9ooP04Omek
W7MkNidCOmh:Omd067onOomomeGb52Lm;eYDLcQoV6/GCQ99kdf[GR]ZZfZ:CLT``Rc4:>@Xa1B358@P
aP8XiP08:>D/ib1T:891ZE9AES5NL@9V/P0FG[5Ndf;DF[=J/E8^=F/XabBV:<HPPaQS568DHaR37:@H
Y1B3468DHQB258<27:@27<@011c56:@DPaAS0Pa200L@HQAR588DPaAR32488@0220001PPP340<@@a0
344<@P<@HP0B58<HY1R458@LYRe9@N]23SFZ9@HY:3F[>JXU2Pa634@<@aAT0a1S00<@Q1R46<@011RT
00DLa1RT68@DPaR300<LY0066:<LY1c57<@LY1RS0QRT01DDPa2446<@@Qc49@D]92SS9<<Ta2T4:@DX
i2S59:@a1V9]L_9^KE6Z<<800PP00PPP00<8@@Q024000PQ00`a00Q1000X<@110440@@@aR344001@P
GTUomPYoo`0;OmekMfkBJ]9^m6[DI]ER]WLINi]oo`04Omh7Omd4Ok`01W^lOkao_7nkOkak_1Ao_0Mk
_0Ik^`03Nkak^g^l00Mk_0Ik^`=k_0Ek^`07NkYk^g^jNkYo^WnkNkX017^k17^j1W^k0W^K0W^J00Ik
VGMhLcQReF:BNe<2OmX03W^GOkQkVFlGHW9Ac5X]NgIo^g^IFU4XY`P0420244033604340010aP464<
H0a00`a100D8@0a0440@H0a0008<H00G3408@0Q1344<HA22588HPQRR6:<DPaBR6<<LiAS55:<DY1S4
6:<DXaB3588DXP025:<011RR6:<PiARS0QRR00hHXaBR5:8DPQBR6:8HXaRT6:<La2D58><@H1BQ11B2
00@HPQRS7<@HX`@DP`DDPP06584@@1R17<<LhaBQ2QB20a2200H@PaBS5:<DPQ1Q5:43588358<35880
0aB1488@HP0246400a1R464@H@035842588258402QBQ7<4DH11Q460DHA1Q588DXaB21A1Q00H<@A1Q
488La1S34642364030a1340<@0aQ360@HA1P444<H@aR468<HP8<H@0;464<H@aQ364<H0a0460<@11P
5:8DP@02460232001110364<HPaQ0`a100<<HA2236400`aQ00@@H@aP340<80<@H006360@H@aQ3448
@@aQ1A1Q00<<H@a134400`a110a000<<80a044000@a100000fmiLeQcF002LeT<LgT3LgX4MgT3MgP2
MgT00gMjMg]gN`04Mg/4Mi/=MiX8NiX8Ni/01W^LNi]k_7^lOk]oo@9oo`04OmekN7LfNgX2Ni/00g^L
Nkak_004Nk`017^kNkak^g^l0g^k1g^l3Gnl0gnm0g^m0gnm00Ao_7oMOmeog@9o_003OmaogGoM01ao
g@05OmiogGoMOmeogP02Ool017oMNi]gNg^l67oN035ogGoNOmiogWoMOmaooWooOoUA[aPX?G5RUWMi
OoMZmTg`BLaJ2f8XKZUVJTF8700TQ2SV9:<HHaAS78@XaRT7;<DXPbQ2;64mIdX`CRiNTF[bGXm9bTWZ
CPXmRRd7;<D/i`02;@P01RSW88<HPaR3568@@@<DHP8@@@8DHP04688Pa2C48<@278<00b2T9<DPY002
68<01Qb388<LPaAR668HH`8DP`0556<@HQ1R588HY0028<D01B349<@TY2BT8:@00R3600HLXaR1560D
@1105402664011AS56DHIAb50QbU00<LYR3W8>L00R3U00hTi2CU9>@Pa2CT:@LXiRSU9<@TXb2S9>@X
iB340QbS0b3401PPiBD69>LPaR2T9>@Y9RdU;@HXiBd6;BHY1RC58:@TaS47GRebdFj>DLX`XPP03202
220010Q12408@@Q10`a100@<@0a1340<@08@@0073648HP@P000D@6J;OoT02goo00=kV6JbI[<00VKD
00EVeVKgL_IkVWon00AogPIog@Qo_003Ok]k_7^l00=k_09o_003Nkak_G^l00Ek_0Ao_0Yk_0Ek^`Qk
_003Okak_7^l00ik^`9kV`Ek^PEk^`=k^PEk^`EkV`0ENiYgNGMiL_IVTWLENmaongoJOmUc>F:eEPiA
k6[dOkMo^g=GCS4PQP@000<@@003340<H0a000<<@004220400Q13602364246800`a1340@@0044400
1Pa02408@0a0464DX`8HXP03588HXaRS008HX`08488DXaBT5:@DXaB26:<La08DX`036<DU1b3U008H
X`046:8HXa1Q58845:8051BS6:<La23U8>@Ti1bR440DPQBS6:<DPQAR688L`ac4688DPQB348865880
1AAR564DPQBR6<<00QB20QB10QRR00<DXQB258800QB200@@PQ2348<@P`8DX`8DP`045:8HXaRS6:@4
58<00aS45:8@PP026<<00aAQ340@HP0248800a21564@H@0258801A1Q220DPARP58000aAQ0QB200XD
XaB3564@H@aQ464@@@a1464@P@<@PP<<H@03340@H@aR008@H@8<@003464@HQ1Q008<H@8<@08<H@D<
H08@H00:440@H1B1464<@A1Q588@X`aQ344234000`aP364<HP0336800a1Q364<H00446003Q1Q468@
H`aS368@HQ1Q460@HAR2464<@0PP340336400`a1340<@004340132000003KgUcF7=H00=cF09cN@9g
F003MgUcNG=i00EcN@=gN@03LgUgNGMH009gF09gN003MgUgNWMj00EgN`9gV`9gNP9gN@04MgYgVWMj
MgX8MiX=NiX6Ni/02W^lOkaooWonOomk^g<GLaQkNW^K1G^l2G^k27^l37nl00=o_GnlNkd017^m0Wnm
2Wnl00=og7oMOmd067oM00=ogWonOoh00Won00AogGNLNiao_@=ogAMogP0`OmeogWoNOmeog7oKOoao
ognhDB`H:4WDI]McEgoGI]==cUG[HRQV97;6ITQ1J2A274<Taab456<PQ2c6:<DTY33U>@LdiSSTAHUJ
;VJ_J_9c<f[bGW1F:f:;CPe5cTF/0T6<00TmRSE9=BLi9ce7>BPe1S47=@L00SDW00hiB3UX>FPmRCfZ
?HU1ZdG/ANe1cD7^BPm>;dX>0TG=0TW]00A9kTh?CPm:3`=5kP05ANe63TH>ANi9kP02BNd2ANd0447=
>F/eJSf;ANa5jd7;?J`mRcf<?Ja1cD7>ALi1cSf]0SV<0Sf/00XmZcfZ?JXmZSf:?JXiRSf:=DPe:0<a
9`0C<BHa9c4W;@HY1BSU:>@XiBSV9<HTaBSU<BDaAbd59<<Xa2cU;>@00RS400T/aRRV=DQN;6Z?JTa9
R2R110000P`P00@880Q02408@088@@042248@@a1344234001110360<H0aR0P0000<D@5Y9OoL02goo
00Uo^FkCGY=RTf:BI]AZeF[dNgH00Wom1GoM0Wnm2Gnl00Ek^gnjOk]o^g^k00Ao_1Ak_0Ak^`03NkYk
^g^j00Ek^`9k_0]k^`EkV`Ek^`03Ni]kVW^J009kVPAkV`03NiYk^W^j00Ak^`IkV`07NiYofgnkMcMV
]6[gOkX00Woj00eoeg<hFWEF45j@NgQomg^kLcQ5l1A4100<800<340236000`a024088003320010a0
440@@0aP0Pa000/<811P460HPARR6:<HY1c46<@HXaBR008DPP03464@HQB200DDX`0;6<<La1RS584L
`QRS58<DPQB1484@PP025:8041RS8>DY9RT47:8HXQB2468@Pa1Q444@@1AQ6:8HXaRR0QB200<@HQB2
588011B20QAR00PDPQB3588DPARQ580HXARR0QBR00@DPQBS5:8DP@<@PP8@P`<DP`8DPP8HX`0458<D
PQB358<258801ABR6:8DPAB158800Q2200<@HAB146401A1Q00DDH1RP584DPAAQ008@H@8@PP07468@
HA1R468@H@a124400a1Q00@<@0@P240<H@8<@004460@HA1Q3602340346402PaQ220880a0364<@0Q0
460@H@aQ0PaP00/@@0a0340<@111344@HAc36<@@PPa00088808<@006344<HA1Q48<@HPaQ0Pa100T<
@11Q464@Pa1R348<@`aS4680111Q0Q1P00D<@0a1364<H@a100P<@00000=_NG=HLeP017=H00AcNGMH
MeQgN@9cN@04LgYcNG=jLgT4MgT3LgT2MeP00gMhMgUgN@06MgX3Mi/2MgX2MgT017MjMiYgNWMj2GNJ
37^J1g^K00Yk^g^lOmaoogoMMiYc5W<hMg]gV`9kV`=k^`=kV`Ek^`Uk_0Eo_0=k_@03Nkao_7nl00Uk
_@]o_1Eog@03OmaogGoM009og@07OoioogooOmeo_7^KNk`01GoM00AogWoMOmeogA=ogP04OmeogWoN
Omh2Omd067omOomoNDBU82I=lfKGLeUgF5iaCHa=REgXHNIbZEfWAH/i:SU;>F/mJSU:>BTmB@91JP0?
AHY=c57^CL]9RDg;GTeZlV[aI[5NL6JaJ]9V/eYA009B<0=FD@07DPi=c4g/EPiFCeI@FU400UYa00IF
D5IAFW9JTejcG[82G[<08V:dJ_E[5f[dJ]=ZlflDLa=^lfkBL_Ag=gLiLcQc66KGI]EVmVLFI_ER]5jd
GY=RTfKEJ]ENU59BEW9RU6:dI[=V/V[D0V[f0VKF00e[5f[fI]ENU5YcGY=RU6JbHY9VTVZbHY9NTP02
H[<02UjBEW5BD58`EU1FCeI`GW1FD58_0U8^00eB3Tg]BNa=kTW^AJa1ZTG<@JXmBCTW?FQ1R@02@HX0
33TY=@U1Zf9]J]9ZKTUX964400`0200<8088@0<8@@888@8<@@03320<@0a0008<H@0624448000541J
Jgoj2goo00UooGnGMa=V/eiaGY=VeFkdNgP00Wom00AogGnlOkao_@=k_@=k_0Ak_@03NmeogG^m00=k
^`03Nkak^g^l009k_0=kV`03Nkak^g^l009k_0=k^`AkV`03Nkak^g^k00Ik^`03NkYk^g^K009kV`06
NkakVg^kNk]k_7^k0g^K0g^k0W^l00=kVg^JNiX00g^J17^K00=kW7^kNi/00g^J27^K00Ak_7^kNkak
V`AkVP9kV`0FOmao^g^KLcQR]EjDKaQo^G^iMgEVmUjEI]IgEgoJOkUkVflg>H`88P00200334033605
340010aP340<@0Q00PPP0`a000<@811044000Pa000X@@0`P440@H1R16:8HXaS46:<HY08HX`8DPP@D
X`055:8DXa22488DP`036:<00ac46:<DX`0258802a1Q364DPaB26:<PiBTW9>DLXQAR46800Q230QB2
00<DHAB16:800QRR00@Li1S4588@HP<DXP8DPP03564@HAAR00<DPP056:4HP1RQ7>@HX`0258800aRS
6:8DP@0448800a23488DX`0558800a22468@PP035884584358803122464<@0PP464DPA1Q460DH1RQ
588@P`8@HP05488@P@aR468DH@02464010a1220<@0aR111Q00H<@0aQ464<H@aP3642464246800a1Q
564@H@0446400`aQ368<H@033642360234002`aQ460@H0a0464DXQC4464@@0`P220010a000<@HA23
36800Pa10`aQ00D@H11R468@@@PP008<HP@<H@03488<H@a1008<@003468@PPaQ00@<@04<H04@@04<
@00000=_NG=HLeP00g=H0W=i0gMH17=i00=cNW=iLgT01W=i0WMH00=gN7MiMgT01WMi0gMj17Mi00Ag
NWNJMgYgNPYgVPakVP9kV`=kVP03Ni]kVW^K009k^`09OoeooW^jJ_IZmgMINgUkVG^j009kVPEkV`Ek
^`9k_003Nk]k_7^l009k^`=k_09o_0Ak_003Okak_7^l00Ik_0eo_09og@04OkeogGoMOkd>Omd017nl
NkaogGom0Woo00IooGoLNi]gNg^KOk`=Omd@Omh00goMOmiogP02Omh05WonOomooglj?68/YeXcJ]IZ
mf9cDLi5B4dVCBEEI67VGL]1KD5/@F]9cDg<0TW<00i=k4g<CL]=bdg/CLY5R45VAFI1ISU6>BDe9STW
0SU800Pi:3U9?DTiB3E8>DPmJDF90TVY00i5RDF:AJY5ZdG<BLa5bceZ=DTiJCf:?HTmRSf;0Sf:00=1
c4W]AL`00TW[00i9jTh<CPe>3U8`CS1B<4X?@Jhm[Cg=@Lhm[3F;0SE:00DiBcf<?H`mS3e[008mR`8m
S009?Ja5cDG^@JdmS46]BNm>;dX?0095cP03BNm><58_00=>3P9>3@05CPi>;dh^DRmFD002DRl2ETl0
0eY`HW1NK`03GVl2GW005UI@ERmB;eY?GTmF3Tg]GTiV/FZ_GVmF3dG?@Ji9kVK?KcEZ/TVZ98<800PP
0P`P00<880Q0244010PQ00D<80`Q344@@0a000<<@@05220001QPI]1oo@0<Ool02GolOkQbm5YcGY=R
]6keNgMk^`02Om/3Ok`00g^mNkak_002Nk`2Ni`2Nkd01W^lMi]kW7NLMi]k_09k^`03Ni]gVgMj00Ag
VP05Ni]k^g^kNk]kV`02Nk/2NiX00g]jNiYkVP02Ni/7Nk/2Ni/02GMjMgUkVg^KNiYgNG^JNi]kVP02
MgX01G^KNiYkVW^JNi/00WMj00AgVW^JMiYgN@9kVP04NgUgFGMIMgX4NiX00g]jMgUkNP06Ni/01WNK
MgYgVgNJNgUkN09kVP9gVP0FMgYgNG=IJaQVeUZDG[AW5WMgLcMW5flhMgQofWoKOmUkVV[E;@P40@@0
2003340336001Pa0344<@@a1340<H08<@003220480Q000H<@00>320<@110320@@11Q684HXAc37>@H
XaB258<HY0<DP`8DXP086:<DXQBR468<@@a0564DPP8HX`04584HXQRT5882488258<011BS6<<PiART
0QB20Q2300@DPaB25:<HXP<HX`037<<Li1c3008DPP8HXP055:8DPAB1564@H@0234002aB1684HPAB0
6:4HXQB1340DPABR7<800QB100L@PQ21468<HA1R488@P@0258400a1Q364@PP0258800a1Q488@P@02
58401AAQ584HXQS36:<00QB200<@H@aP46400Q1Q014@H1AP580DPPaS368@Pa22484<HA1Q684DH11P
464@HQ1Q008@HP03464DPA1Q00<@P@<@H@03584@HA1Q00D@H@03460<H@aQ008<H@08344<HA1Q364<
H11P340<H@H@H@04588@HA1P440334001P`P344<HA23368<80840008220<@0a0360<@0`P340<@@88
8003364<HPaQ00<<@@043408@0Q1240834000003KgUcF7=H009cF0YcN@EcNP04LgUgNGMiLgT2MeP0
0gMiLgYcNP09MgX00gMiMgYgN@02MgX00gNKMgYgNP0;MiX@NiX01W^KNiYkVW^jNk]kg09ooP05Nkag
NW<FLcMgN@02NiX00g^kNkakV`03Ni/7Nk/3Nk`2Nk/CNk`:Ok`8Okd@Omd3Ool01WoMMgQ_=GMIOmeo
_@iogAEogP0JOoioogooN_Ll@4D7J]MV/eX`CHe9J5F5FJ5A@5h1KZQg54f^;<P/acD8>BLmAce6?DPe
1P@`i@09<>@/XRA0:40`H2QP940TH210008L8007844PHR21768PHb2376400aQR01@DHAAR68<HPaAR
788LPb2S788HHAaQ8:8HHPPP420D@A0P200@81Q00Q@P00hHHAb388<PQ1aS88<H@Q0Q32488A11324@
@QA30Q@Q00hH8AQR644@8AQ2768D@QA1768LPaA1400H@R230ab300`HHab38:@PPb1R888PHQaP764P
PR2388829:<01B2S9:<Ta2cU<@H00SD600<diST6>BD00cU70Se801E1JE8>FReJ;F:`KcIcEVKeES5>
44G`DPmVdg=iJ]59c2C51008811032000PQ000L8@@Q022488@`Q320<8@0234402A10444@HA112000
01APH]5oo@0=Ool02WonNk]c5VJdI[E^mGNJNk]g^W^k0W^l00=gVWNKNk`00WMk00Mk_7^mNkek_GNL
Le]cFP02Lg/00gNKMiagNP02MgX02G^KMi]gNWMiLeQcFWMkMgYgV`02MiX2MgT4MgX00gMHMgQgN@02
LeP00gMjLgUcF@02LgX00gMiMgYgNP03LeT2LeP2LeT01G=iLgYcFG=jLgT00W=H0g=I0g=H00=cFG=i
LgT00g=H00AcFG=HLeQcF0=gN@04LeQc>7=HLeX2LeT01g<iLeUcFG=HLcM_=flE009^m@06KaE_=Vlf
KaI_5f[g0fKg00a[5VlgMgQgVgNLMkag^g^jOiUgNEiB9:H2100010P0220<@0aP0Pa000@<H0a0344<
@@8<H@8<H0D<@004240<@0a0320234002`Q0340<80`P440HXR3T9BHU9abT56400aB20aB300/DXQBS
6<<DXaB2464DPQRS688DPARS00<DX`03588@HQ22008DPP<DX`04468<@@aQ468248<00aB35:<DX`03
5:<02acT6>@DXa22688TiAbS588HXQR158400aB200<DPA1Q58400aB100LDHA0P564DXQRR584@PP02
484246400`aQ464DPP0258802122588DPQB25:<HXaB24842464246800a22588DPP034880111Q364@
PPb10Q1Q00@DPA22368<HP8@P`084888@A1Q7:<DH11P464<H@@@H@06584@PQB2588DXQ220a1Q00@D
PARR584@P@@@H@04488<HPaQ244222000`aQ488@X`02364236001121464@HA1P111Q00D@H0a0340<
@11Q00@<HP03200880Q0008<H006340<H0aP340480Q10PaP00L8@0aQ360<@@@P344<HP0234422402
34023602340134400003KeUcF7=H00McF0EcN@EcNPAcN@=gN@9cNPEgN`9gNPEgN@9gNP03Mi]gNWMj
00igVPekVP0@Ni]kVW^JNiYk^g^lNk]og7oMNk]kVW]jMgYgEgMiNiT2NiX2Ni/@Nk/CNk`7Ok`00g^m
Nkak_@02Nkd2Okd2Ok`9Omd017_MOmeogWon0goo00IogGMjLeUkVgnkOm`AOmd7Omh00goMOmiogP05
Omh00goMOmiog@03Omd0<GomOom^ecPP@>ERLV9`ENi9Beh]OdmoAg[ROf9ok7olGQDP0a0088D`iC45
=@8`Xb1S548DHQR3544@810Q96@i:fY_JXU9bD6Y@HTiAc47;>L]1c4W<BPTabC64404000000D80009
444HPb2S9<@XiBC49<<LP``P00800003300@00`000`<0003400<0100008<00<@0003500@01@000@D
0004400D01004003500940035003400330001A00300<00`050000Q0001TH81Q1888T`RC49:<XY2c6
@HYB35i=I_1[4flCH[9J<4g`ALmAkf:AJ_A^cdV:9<D88003320224001`Q1340<@@`Q224<80`Q008<
@@09440@@A1144480000441Rd7ol00moo`05Ooio_G^LNiak_002Omd6Nmd017^mNiak_7oM0WoN00=k
gW^mOmh017_N00=k_G^lNk`017oM00=o_G^LNi`00WoM00=kgG^lOk`00goL00Mk_7^KOkao_7^kNi]k
^`02Nk`017^mNiagVg^l0Wnl0gnm00ekW7NLNkak_G^kMi]k^gnlNk]gVg^kNkak^`03Ni/2Nk/03gnk
OkakVg^JNk]k_7^KMgYkVgnlOk]k^g^KMgYkV`02Nk`01G^LMi]gNg=jMi/00W^k00Ek^WNIMgQgN7NI
009gVP04MgYgNgMkMg/2Ni/3Nk`027NlNkak^W^FOiQcF5H@86@210001P`0200@H1BS464<H0<<@08<
H@08468<H0Q0340<H11P22080088800?320@@1103448@@@P220400a15:8LiB469BLHXa1000HDPP04
5:8DXaBR5:<258800aRS8<@Pa0026:@01aBS588DPQAQ464DPAB2008@PP8DXP07588<@@Q0468DPQ23
58<01ABS010H`aSU5:<@HAB2688DPQB16:4DPAB2584H`Qc4588@H@8DPP056:4DPQAQ560DP@026:80
2AB1464@HA21464@PQB26:8H``0258801122588DPQ1R0aB20QB100<<@0PP34400Q1R0Q1Q00H@HQ1Q
464@PAB2488246400aB1488DP`0248801`b23648@0aQ464@H11Q008<@08@H008484@HAB2588DPAAQ
584DPP<@H@04460L`ARR484446401122468<H@PQ0Pa100L<H@a0340<H0aQ360<@003460234002@aP
340<@0a0360<@110460<H@0236800`aQ320<@0023602484236000`PP2008800536001`a0344<@0a0
360<@0PP008<@08<H003460<H0aQ004<HP0000=_FG=HLeP027=H17=i2G=j00=cNGMiMgT00W=j1gMk
0WMj0gMi0WMj00=gVgMjMgX00gNJ0gNK27NJ3G^J1G^K00=k_7^kNk/00W^l00IogG^lNkakVWNJMgT2
MgP017MiNi]k_7^l0g^K2G^k27^l00=k_G^lNk`02g^l1Wnl2G^m00=ogGoLOmd00WoM00Ek_G^lNkao
gGoN00Aoo`05OoikVgMHMgUo_002Omd00gonOmeog@05Omd5Omh5Omd;Omh3Omd00goNOmeog@04Omd0
3WonOomnmS00:4=AcVI_DL]AcG]DOnIoR7K[On<2Ool067;h70080114:>H]1cD4768@8@`Q68@HY1AR
300<82B3BNecEV[aGY1FKTX=@Ldm[08mZ`09=HTaJCEZ8>L@@@00100880a00088800H464HY1c58<DX
iBC59>DTi1bT78<H02R4CFUAIU5WCDMERUF[CFU9BDe8BDQ59dU80TeY00=1:44WBBL00dDW0T4X00<m
:4DX@@L01ccU00<m1ScU=<D00SBS00PdY3C4<<@`Y334<<H`aBbU0S3500H/HbaR:88XPRB39:@2;<H0
82B486<PQ22586@H0P@0300PXbD59@@U1BSU8:<XY3DWAL]BD6:`JcA_4Ei`CNi=cTg^AH]1RTh=DPdm
B1b42002220322432442224010`Q344<@@a1111100D80000641RdGoj01Eoo`9ooR1oo`03OoiogWon
00=oo`9ogPAoo`9ooP]oo`03Ooioogoo009ooPIoo`04OoioogooOol=Ooh00goNOoiooP02Ooh00goN
OoiooP03Ooh01GooOoiooGomOoh00goo00IooGoMOmeogWomOoh2Omd027^lNk]kVWMFOiMcF46^4242
10001A10464DXQS346400Pa00PaP014<H@a1344<H@a1340<H11P340<80P0420@@11P564<@0A1008<
HP0;244@PaBS5<DDY1RT6:<DHAB35:<HX`026:@258835:<03Q1R368HXbT6:BHPiQc56:@DPQ11464@
HQB256825:<26:8458801AB3588DPQBS5:800QBS00HDY1BS5:<DPPa0444258835:8011AQ584HXQRS
0QB200@@HQB2588DPP8DH@04588DXQB2488346401@aQ240@PQRR7<<011B200PDPA10464@HAB1564D
PA1Q0Pa00a1R111Q00@<@0aQ464<@@8@H@04488DPaBS4882368010Q1364<H@aQ1Q1Q0Q2200@DXaRR
564DPPD@H@03584DXQ1Q00<@H@036:8HaA1R008<@0<<H@07360<@0PP360@H11046000`aP00`<@0aQ
3608H@aQ340<8110460@H@aQ36823642488336401Q22460<80`P200@H08<H005364<H0aP360<@003
240020Q1364<H@aQ360@H0aP340136800003KgUcF7=H00UcF0=cN@McNP03MgUcNWMi00AgN@03LgYg
NgMk00EgN`03MgYgNGMi00=gN@AgNP9gVP=gV`QgVPekVP03Ni]kW7^L009kW003Ni]kW7^k00=k^`0>
Nkaog7omOmeofg^kNkYgNG=HKcQcF7MjNiYkV`Uk^`Ek_003Nk]k_7^l00mk_0Mo_007NkakgG_MOkak
_7^LMi`00g^l00EkgG^mNkeogWon00Aoo`07Ooik_GMkMgYkVgnmOm`02WoM27oN0WoM1goN1goM00=o
gWoMOmd00WoN0WoM0Woo00aoEcQ18099[FI^DNYF;GnCOnMoRV9]Olh2Ool07gnG<8L001`5;<LXiabT
44480A1268<HYAAR420@8BBRALQBKdX>@LXmQBC18:8]9C4U<DHeJ2e7=HP]AaR30088008<@00:344<
@0a0588HPQ10320LHaQR400250000cU/Ommoo`0GOol017oNOoioogom0Wnl00=o_GoLOm`00WoL0Wnl
00Aog7nlOmao_09oV`9oW005OieoO7mlOg]oV`02Oi`2Ni`00g^MNiaoW003Okh01Eig=@dP8aa08<<0
0QbR01DLPB22888Ta2C3<@DmR4G[BNU1J3D6<<@e1STX<>HXXSD3=>DHH`@0000010PQ00<8@@a03400
0`a010a100P@@A1Q468800008:1[4gojEgoo00=ooWooOol04Woo0Won27oo17on0Woo17on00EooGoM
OmeogG_M00=k_008NiYkNG]EOkM[5SU;2004008<@@06464<H@aP460<80a00PaP00L<H@a1340<@0aQ
464<H@0234002Q10320<@110460DH@a0260<HABS0QBR00@DY1S56<DDX`<DPP8HX`0458<DPQB258<2
6:@011BT5:<DXaBS0QRS00`DY1RT58<DXaRS58<@H`aR468@HAB26:42588258401122588DPQB211BR
00DDXa22364<@@aQ00<DPP8DXP075:<DXQB2468@HAB25:800QB10QAQ00<@HAAQ4640111Q014@HPaQ
344<@0aQ584DXa1R344@HAB1580@@0a0464DHA1R008@H@03468DPQAQ008@HP07588HXQB2464800PP
34400a1Q0Q1R00@<HA21388<HP@<H@03488@PA1Q008<H@04340<@A1Q468258401A1Q340880a04640
0Q2100X@H@a0440@@11P6:8La11R220<H08<H@8<@003460<H0a000<<@008360<@0a0340<H@aP2204
808<8007440@H11Q488<PPaQ34000PaP00T@P@aQ468@HQ21440<@0PP46000`aP0Pa000@<H0Q01208
8088@0@<@003460<H0a0004<@@0000=_NG=HLeP02W=H00=cNG=jLgX01W=j00=gNW=jMgT017Mi00=c
NW=kMg/01GMk0gMj0gMi0WMj00=gVgNJMi/017NK1gNJ0WMj00=gVg^JNiX02G^J00AkVg^LMiakW0=g
_007Nk]kVg^KNi]k^gnmOoh017oo00AooWoKNiYcF09_5`03LcQgNG^K00=kV`ik_003Nkek_7^l00Mk
_0Ak_@03NkaogGoM00=k_09k_@Ak_003NmeogWoN009ogP03Ooioogoo00=oo`9ogP04Ni]gNg^LOkd=
Omd@Omh4Omd00goNOmeogP04Omh017oMOmiogGoM0Woo00eo^42T604mK6I`GTmNLGobOnMcDSd3MZQo
o002Ool02FIB70<<02AU7:H@HPa222888@0256<02Q11420@@BBQBNM>;SE;<@H/h@P00P0000XLXRT5
<DLaAcF8<FPLY0P0320@H@8DPP0<444<@A11520PP2d5<BD]1b0Q000D06/J?Woo00ERVA`0600<81@P
008@8004664HPaA2220210002@P0300400@0544/`RS586<XP`02;:<0122S300000@Q0PQ10PPQ1@`P
1@a10PaR00D400008:1_E7om05Eooa5ooP03OomooWon00iooP03OoeooWom00Aoo@04OoiogGoMOmd3
Nmd2Nk`2Ni/01g]hOgIkVF;E;@X400P0008<@08<H@05368@HA10340<H00236402`aP344<@0a0344<
H@a1340@H0aP44000Pa000`@H0aQ240<H1BR6<8Ha1BS48<LiQc4588246401aB25:<DPQAR588DPaRT
008La@056<<HXa21464DPP025:<258<031BT7>HHiQBT58<@HAB26:4DXQB2584DH08DP@03464@H121
008DP@046:8DXa1R488258<258802aRT58<DXQBS7>DM1QRS464<@12268800QB10Q1Q0QB10Pa000@<
H1215:<DXP8@H@0=588DXQ22364<HQB2584DH110464DPAB25:800QB200dDPaBS588@HPa1588L`aS3
584<@11Q58<HX`0346424680112248<@HQ1Q0Pa000@<H0b2364<H@8<@003240880a1008@HP0558<@
H@`P2008@00246404A1P464@@0a0320@@1AP568<@0PP464DXaB2440<@0aP464010a000H<H@aP2404
80Q0340222002`a0460@H11P464DXQ22364880@P36400Q1Q00@<HQ1Q460@H08<@003360<@0a0008<
@08<H0033408@@Q000D<@004320@H0aQ340134400003KeUcF7=H00]cF004MeQcNG=ILeX3LgX8MgT2
LgX2MgX5Mg/2MgX3MgT2MgX00gNKMiYgV`02Mi/00gMjMi]gVP06MiX2MgX00gNKNiYkVP09NiX00g^K
NiakW003Ni/01WNKNi]kVg^KNiYkV`Ak_003OkaooWoo009oo`05Ooik_7^lNi]cF002KaL00g<hMgUk
^`02Nk/BNk`2Ok`2Nk`3Ni`00g^lNmakg@02Nk`017NLMkakgWoN0Won2Woo00UooWoNMiegW7^LOkeo
_7oMOm`03WoM1goN00=ogGoNOmd017oN17oM00EogWoMOmeogGoN00Iog@9oo`0=OmI=1P`0>B]RCeY@
G[=on7o/GVPTPegPOnH00Woo02mo]EF]928H11AT6:@HYA1S320@@AAR540<01A0:<5FJF;B=HleJbd4
9<Ha;2CX8<DY9cVY>JPmZSF78<<<010P588HXabT668H@B1UDNagDgojOoMooF9E>8DPQgNo03ioo`0:
OglL0A@076@iSDibF]91kbdZ64<22003000210003A0P=@<iBBb6968TQ2BT9>@HQ0PR1288@@PQ00<8
8006320880PP320<@@a00Pa10Pa200H<H`P0000PX7=dOo]COol2Ooh00goNNkeooP0OOoh6Ood5Omd0
47oLNmakg7^kNkakW7^KNiUoN7=FFY<Tb@@0200<81100Q1P10a00PaP10aQ00@<@0a1344<@@L<@00;
220480aP580Y8bD47<@<HAB36:<DPP0234404AB2584@HAAR588HXaRT6:<DPQc37<@HXaBR588DPaB2
58<00Q230QB3018DXaRT6:@DXQRR584DPQR26<8La1B2220<@1B1464@H1RR6:@258<00aB2488DPP03
58802QB35:<La1S46<8DH@aR488@HQB10QB200@HXARR584@H@8<@0036:8Q1AcT00DDPP8DX`0:588D
HAAQ440DHARS6:8@PAB2488246801a1Q344<@QB27<8HXQRQ008@H@0@564DPAAQ4648@0@0220@HABS
6:8@H@a0100<H1223602220234001`aQ468@HQ1R7<@HXQ1Q008<H@03464<HA1Q008@H004440<80PP
3203340011215:8DPA101Pa000@<HA22360<@088@0043408@0PP3403460246401PaQ360<@0PP364@
H@8<H@<@H003360<@0a000@<@003360<H@a1008<@@043408@@Q1240222000``P340<H00136400003
KeUcF7=H00]cF003MeQcNG=i009cN@03LgYgNGMi00MgN@9cNP9gNP=gN`AgNP03MgUgNWMi009gNP9g
V`EgN`9gV`=gVPAgNP05Mi]kVW^JNiYkV`02Mi/3NiX8Ni/3Mi/7Ni/017^lOkaogGom1Goo00Yo_7^K
MgUc=g<fKcMcEg=IMgUkV`=k^`9k_0=k_@Mk_005Nkeog7^kNi]k^`05Omd00goNOoioo`0=Ool027on
Omek_7^lNiak_7oMOmhBOmd3Omh5Omd00goNOmeogP02Omh3Omd00goNOmeog@03Omd00goNOmeog@04
Omd03goNOomoneF_408`aeX:ETiJTW_JNg51QbAQ>>1ok`03Ool01gocHPdLAQ1T=J]2;c4W008@8@0N
320@00P0420a06/:Kg<e[bT9<D]g>7omH_HY:RU:<H/iZcEW<DDP``P0440HXQbS;>Da1bRTBJaoVGok
17oo00=VDTW?Ool0?Woo00AkGcRT@BEZe0Aoo`04LgU5cR1V100230003QA2200<02C3CNI5ZSCW;68T
Q2SU=DHY:@a300042244220010`P340<@0a110a200D80000981cEWoj04moo`9ooP9oobAooP03Ooeo
gGom009oo@Mog@0<Nmak_7^kNkakVg^JOkYoVflgBQ4HQ`000P`P0a1P00@@8110320<@0H<H004340<
@@a134453402320212001PaP580]A3558<<DPP8@@@03464<HAB2008DPP8@H@076:<Y9ac4588HPQbS
7<@00QRS00<DXaB35:8021B300TDXaRR588DPQRS7<@M1Qc446400aB20QBR00<DXaB346800Q2211B2
00<DPaBS5:<00QBR00@DPQ1S48<@PP<DPP0:5:<HY1B2464@PQB26<@Q1QcU6:@458825:<01AB2464@
@11Q56400QB200DDXQB2488DP@PP00880005464DPQRR6<<DPP0546405aB2464880P0340DPR3U564@
@0`0460<H0aQ368@HPaR344<HQRT368@HQB348800Q1R00<@PQB248800Q1Q0Q1P00@<H@aP360<@088
8004364@PQ1P320634000`a1364<H@0234000`aQ488<H@0236000a1P464@H0024642364222001PaQ
484<H@Q0340DH@8@H08<H@@<@003364<@0Q100@8@@07344<@0PP340<@@aP46000@aR00000fmILeQc
F00;LeP00gMHLgUcN@03LgT3MgT00g=iMgUgN@07MgT3MgX7MgT3MgX7Mg/00gNKMiYgVP04MgX2MiX3
NiX2Mi/017^KNiYkVW^J0g^K0W^J3W^K0WNK00AkW7^lOmeogP9ooP=oo`06OoiogGnlOkak^gMi0W=H
00IgVWNIMeQcF7MIMgX2Ni/6Nk`017_MOmeogWon3goo0Won00EogW_NNkek_7NL009k_1Uog@9ogQMo
g@0kOmiogGoMOmioogomIWHD1S35L^U_<f:cH]A5k2S3820T05hWOoaoogomOoMo^BT=5:HeRDH^=FLD
HPP0204400`0420X`7nXMdhi[@Q346Mc=Go`CRhPjQRV7:DU1RT48>DHX``P560HXRdU=H/a:cD8KaEo
o005Ool00gmiLcMoo`0nOol00goOCJeZm006Ool04gMl=Bd800`0304@8P`0420]15H5AHHhiS22;:<T
XTG5:DT@H`0000H88@88808<@00;360<H@aQ364<@A11200001aPKeIonP16Ool00gonOomoo`04OolY
Ooh00goNOmeoo@03Ood5Omd2Om`03W_MNkak^g^kNiYkVGnjOka_>D7?46@400PP320346000``P220<
800234000`aP340<@002340010PP340<@1102Pa000P@H1RP6:4HXAB1464<@@aR0QB200<HXQB25880
0QB200@HXQRS688HPP8DPP03584DPQB2008DPP@DP`0548<@HPaQ488@P`0358801QRR8>@Q1QS4588@
P`8DP`<DXP05588@PQ22488@P@0958801@Q2268DPQRS6:800Q1Q00@@HQ1Q468DPP<DXP035:<DPQB2
008DPP04344@HA225842440256403a22588DXaB2484@H@PP000881216<<DXQ1Q468@PP0246401`aQ
464HXQRS464<@0aQ00<@H@04460@@11P36424642468020aR364<H@a1464<H@a02403360236400a10
340@@0033602220010a1364<H@aP0`a000H@@0a0340<80PP32023640111Q364<H@aP0PaQ00L@HA1P
464@HA1P344<800222001PaP464@HA1Q340@H@8@H08880@<@003364<@0PP00848004244<@@aQ3642
34000``P360@H00146400003KeUcF7=H00]cF003MeQcNG=i009cN@03LgYcNG=i00=cN@QgN@=gNP=c
NP03MgYgNGMj00AgNPMgN`03Mi]gVWNJ00AgNPEgVP9gV`04Ni]kVW^JNiX3Ni/017^JNi]kVg^K0g^J
27^K17^l00QkVg^JNiYk^gnkOm]ooGon1Woo00Aog7^lNk]k^`EkV`03Nkao_7oM009ogA1oo`03Ooio
gGoM00=og@03NkakVg^l009k_003NkeogGoM01Qog@03OmiogGoM00]og@07OmiogGoMOmeogWoMOmh0
1GoM17oN0Woo01M_6aPX=@MoT7olI]@mZbBT520L00`0721NSGoiOomomWoo<M4I:RU8;DPY9R35008H
Y@0858<HPaR2781^k6Ja=F`48P80000A10000000000@HbSU:@DQ1B3U7:<DHAR27<DQ2BT:DNaof@06
Ool00g_NJcQgN`0KOol00gonOmaoo`0POol00gNNGYEgW007Ool04d7@200400P144<<8@P07:8mI3e5
<:</PRb3;84iABDX34<000PQ00D<@@03324<@0a0008<@0<<H@07348@@@P0000LPWNIOoh0AGoo0gon
0goo:Won0WoN1Gon00=ogWoMOmd017oM00Ak_G^lNkYk^`9kV@08NgQgVV;D?H`<8`@Q220<80<@H004
340<@@a046024402464234000`aP460@H@02440334022402340010PP460@H1BQ0QBR00XHXQB2588D
Y1BS6:<La1BS588@PP<DPP8@H@8DPP8@H@03568DPQB200<DP`065:@DQ12346<@HPaR0Q1R00@DPQRR
6:<H``<@PP8DP`8DXP036:<DXaBS00<@PP03588DPAB200<DPP8DXP0758<8HPAR488La1RR56400QB2
0Q1Q0Q2200`DPQB348<@HQ1Q468<HA116:<DPQB1440244401A1R488@PQBS58800Q1Q00H<HQ1R488D
PQRS584246400a22588@PP02488248400a22468@H@03464011AQ464@H0aQ0a1Q0Q1R00<<HQ1R4640
0`a000D8@0a0340<@@PP008<@003440@H0a000<<H004364<HPaR3682364434002@aP340880a0364@
PQB2464<H@0246400`aQ464@H00246400`aQ440@@0033644464010aQ464@H0a00PPP00@8@0Q1360<
H@8<@@032408@@a100<<H@05360<@11Q484@H00146400003KeUcF7=H00ecF0=cN@03LgYcNG=i009c
N@]gN@05LgYgNW=jLgYgNP04MgT3MgX6Mg/00gNKMiYgVP0:MiX;NiX2Ni/3NiX2Ni/2NiX<Ni/00gNI
NiYkVP02Nk`00goMOoiooP02Ood01GoMOoeooGonOmd00Wnm0WoM0Won1goo00EooWoMOmeogG^l009k
^`04Nkak^g^KNi/2Nk/4Nk`3Ok`00goLOmeog@0gOmd06gonOomoog=L9:/`Y7L9OkQRTC3V88@TaAa0
300401a0GVIolGo[Oo/n52f]<J`e[3V[<DTY1`02:>H022SU9<<PXS4W=DXTj237100400003Q1T9>D]
B3V/@NdiJ22S564@@0@0224HQ6/EOoh7Ool06G^JFYARegniOnmjlUYBAJm=lUjDMaEoM7oEOoQoegoH
OoUoo7omOoaofgoLOmio^Woj00Aoo`04Oo]kLWnINkd9Ool01GonOomooWooOoh00gom00UooWomOomo
ogolOk]gNg<GNgT01Goo00=_6V;iNkl01goo00ANUAP00008008@@P0=200<822R=>@/Xb22968XPR2S
58<88@P032000`PQ0P`Q00<<@@a034000Pa000T<H@a0364<@A1020000236Nm`0=goo00=ooWooOol0
2Woo8gon0WoN37on0goN00EooGonOoiooWoN00Eog@07OmaogG^mNkak^W^iNiL00W]g00EcNF:A;>L0
00PQ008<@08@H003344<@0a000@@@0D<@0<@H0@<@00A240880PP340@H1AQ484DPQBS8>DY9Qc35:8D
PaBT8>@Pa@0258<02aB2488@H111440DPQBS6<@HXQB256400QB200PDY1BS58<DXaS558@@P`a20Pa1
00D@HQB2588DPAB2008DXP055:4@PAB25:8HX`026<@25:8248800a21584DPP025:8258801aBR5:<D
XQ2S4:8DXQRR00PDPP<@H@03468@PQB200<DPP0<584@H@a0344@HAB25:8DXa22340@PA220Q210QB1
00@@P@aP464@PP8DPP036:8DXQ2100@@H@03364@HA1Q00<@H@05364@@110584@PP025:<01122464@
H@aQ0Q1Q00D@H0a13408@11000<@H006464<H0aP340<HA1R0PaR00@<@@PP220<808<@003360<@11P
008@H@04484DP@aP2442464020aQ340<@11P464<@@a046034640111P440@H11P0Q1Q00<@H0a03400
0`a000L<H0aQ364<HA225:<<HP023642360010a0584DXAAP0A1000000fmILeQcF00:LeP3LeT017=H
LeUcNG=j17=i2GMi1W=j00AgNWMiMgUgN@AgNP=gN`=gNP03Mi]gVWNJ00MgVP9gNP05Mi]gVWNJMiYk
V`0=NiX00g^KNiYkVP09Ni/3Nk`00g^KNiYkV`05Nk`00g^kNkak_005Nk`00g^mOkeog@05Omd01WoL
NkakVg^kNkak^`=kV`Qk_0Mo_005OmaogGoMOmeo_@0/Omd3Omh00goMOmiog@02Omh2Ooh2Ool0;7^N
<>`L05G8JaANCcCV<@LY1bS4444H@@`0761>2V/<E[0]KBE/<Jdn448?>J`a:3E8=FTaJBTV8<@TiC59
:>LTaB348>LPjAc88>PaJc6:;F/]JS6<:>L254401A12100002dYOod027oo01Yoo5ic@C0i:U56;20`
A7/EM^iEQSR4A@EN25I:DRMFBUZ=FXiJKEI_EW1JLEi`ENUJBgMh0goo00Eo^WMgMeQ_>6mJ00Moo`0I
NeMV/V9_K_=_5FkbJ]5VT6:@J_Ag=W]EKaENKeX]GTiJ2e6WDJQRL6keK]ARDEYcMid027oo00Io_3D8
00000111344232001aQQ::</`bRT::<TPQb200880003300<80PQ00@88@03324<@@a0008<@009364@
H@aR464<80@0000PiW_n03Aoo`03Ooioogoo00eoob]ooP03OmiooGon00=ooP9ogPEooP03OmiogGoM
00=og@0?Omao_7^mNkak^g^JNiUkMgngMeQV/2B30008811Q008<H@04360<@0a03403440234001``P
220<@0a0364@HA1P00P<@08DH@8@H@0>5:<PiBe87>@DPPPQ364U1234588DPaRS6<<HP@8@@00?58<H
Y23U8>@HPQB2468DPQBT364DPaS45:@@PaB300<@P`08364<@11Q584HPQB25:8DX@8@H@03488DXQBS
00<DPP8@PP07464DPAB2588DXQRR6:<00QB200@@Pa2S4:8@XP8DXP04588DPaRS5:<35:8011AR468@
HQ220aBS0QB200dDPAB2588@PQ1R588Ha1S5488<HA2248<@PP0346400aB1488@PP0246802QRR7<@D
Xa21460<@11Q488DXa220a1Q00P<@0aQ464@HARS7>HLiABS111R00<@PA1Q46400`aQ0Q1Q00<DH1bR
6:800`aQ00H<@@Q0344<HPaQ344334001@aQ588@HPa146000Q1Q00`@H0aP220<H1BR464<H0aQ58<<
H@PP340246402QAQ464DH0a0460@HA215:8DPQ1P10a000<<HA2348<00`aR00<@PPaR36400`aQ00<@
HA2146000A0P00000fmHLeQcF00:LeP017=ILeQcFG=H0g=i0WMH00=gNG=iMgT027Mi00=gNW=jLgX0
1gMi17Mj0WMk00=gNWMiMgX00WMj0gNJ00=gNWNJMiX00gNJ0WMj00=gVgNJMiX017NJ2G^J0g^K0W^J
0W^K00=kW7^KNi/01G^K00Ak_7^KNi]kV`Qk^`]k_09k^`EkV`9k_0Eo_005Nmeo_7nlOkak_009Ok`0
0gnmOmeo_@02Okd00gnlOmeo_@0XOmd3Omh00goMOmiog@04Omh03WonOomogdD^700mAfKDFRm1JS46
:@HXi22S8882668268@05aB46:DLib489BTY:C59>HU1Zd7<?L`i[3EZ<FTiRd7<?La1kCg<>J/eRS59
:BL00b3V00PHaQ13100@@Bd:64HD8UIA2Woo00IVf22/;@d/Z3cZDI42Ool0>7Ld>BiAS4gZCRe>:dX:
CPYFK5Z<ETeFCU9?FVeF;4h;DR]JSUZ@FXmRSVk`K_=JLDh`H[AcN7MgLeIgNGNINiQ^lUX[GTYV[VlA
La5^lFkbK_=c5G<fNeI^leX=I[1oegojOkUV/Ui@HW9EkE6ZEW49Ool03gonGS4<0`00200<@1AR448H
HbB2=<<XXS2R;:8HHP022005320222403P`Q340<@0a0460@@0aP364@H0a0100002D6Noh^Ool3Ooh0
0gooOoiooP05Ooh6Ool`Ooh2Ood4Ooh2Omh01GonOmeogGonOmh01WoM011og7nlOkak_7^kNiYo^gnG
OmIcEUX=740800a0560<@08<@@P<@007440<H@a0320<@A1R46001Pa0028@H11Q688DPA1R368DPQRS
8>@Pha22224<H2D17<8DHQAQ588HXQc1560@@1B26:<Pi23S688DHQ11588DXaRT6:<DY0<DX`8DXP0=
58<DPQ1R488DPQBR588DPABQ484@PQAQ46001a1Q0Q210QB200`HXQBR588@PPaQ488D`QST5:8@PPaQ
58826:825:800aBQ588DPP0258801ARS588@PQB35:<00aB200lDPaB2588H`acU5:8@HA224:<@PPa1
468DPQRR58802Q1Q00<@PA1Q46400a1Q00@<H@a0464@H@8@PP05468<HQ1Q468@H@02460446401`aQ
460@H11Q684@H@aP00D<H@04368@HA1Q464246800`aQ464<H@02340236002a1P360<H@aP580@H1B2
5:<@PPaQ36001A1Q0Q1P0Q1Q00HDXQS3588@H0aP340222000`Q0364<H@063640111Q364<@11P0Q10
0A0P00000fmILeQcF00:LeP01g=ILeQgF7=HKeUcFG=i009gF007MgUcNG=iLgYcFGMiMgP017Mi0g=j
1gMi17Mj0WMk00=gVgNJMiX00gMj00AgVgNJMgUgN@=gVP05MgUgNWNKMi]gVP03Mi/017NJMi]gVg^K
1G^J00=gVW^KMi/01G^K0gNL0W^K0W^k1G^K00=k_7^kNk/027^k37^l0g^k1G^l0Wnl0g^l37nl1Wnm
00AogGnmOmeog2Aog@MogP03OmeogWoN009ogP0HOmeoogooEM4P03d6HY=VTT6/:>LPaB338<DPYAbT
9>HQ1ac66:@HQAbT8<HY1bdW0Rd7010a9cV:?J`i[3g=?Ne1kTH?AQ16<48??Nhi[2e89>HTi@8La@08
7<HDQ@`R78<eK3f>;@MVl`Yoo`06JcX<:PPW::XH0Cf>0Woo00Ec_RS/848a1RTV008Y9@8]9@04:@H]
B2e9:BP29@H01B3T6<<DH11042000Q@P00DPXRC47:<HHAA0008H@003780P`Rd600<iR@06?HTmZTG;
BPe:;TX>0TX=00E>3Dh>ALi>3Gom009oo`06LeU><T7@AK0`aFKb2Woo011c>A05100<0111464<@AQR
988h`Sc3=:8TPQaQ3008008<8003220<80`P00888@03244<@@a000<@@007444<HA1034040000:BL0
;goo2gon0goo00AooWooOomoobYooP03OmiooWon00]ooP03OoeooWoM00Mog@07Omao_7^kNkak^g^K
NiX00WnH00U_=DG;520@81QQ564@@0`P344020a000@@@11Q444@@08<@08<@@8<@0032208@0aP008@
H@03584DPQBS008DX`8HX`0<8<<DXPaR5:8U11bS464881105:4L`aRR0Q1Q00hHPQbS8<8LXQ11200D
HQB35:<HY1BT48@LaQc50QBS00@DPaBS6:<DX`8DXP0:588@PABR6:<DPA1P560DHAB1468246424882
48404A225:8DXQBS588@PQ1R588Ha1d56<@<PPQ0464HXAc46:<00QB100hDPQRS588DPQ1Q488DPaBS
6<@DXQB2468@PQB211BR00PDPQ225:@@PQ1Q468@PQ210a1Q1A1R0Q1Q0a2100T@HA1R464<H@aR364@
HA1R46400Q1R00D<@A1R464DHA1000@@H@03368<H@aQ008@H08@H@0;340@HPaQ364<@1S57@LDY11R
364<HP0336401Pa0320<80a0360@H@8<H0<<H@07360<HQ1R464@H1B25:800a2200L@P@b1364<H@a0
364@H@0236001@aQ360880@P34000`aQ0Pa010aQ0a100AAP0A0P000016mILeQcF7<h1W=H00=_FG=H
LeP00W=H00EcEgMGLeUcFG=i00=gF0=cN@03LeUgNGMh009gN09gN@9cNP03MgYgNGMi00UgN@9gNP04
Mi]gVWNJMgT2MgX00gNKMiYgN@05MgT017MjMiYgVWNJ0gNK00AgVWNKMi]kV`=kVP06MiYkVWNJNi]g
VgNJ0g^J00AkVg^kMi]gV`EkV`03Nk]kVg^K009kV`]k^`Ik_003Nk]k_7^l009k_0Ek^`03Nkao_7^l
00Ak_0=o_003Nkao_7nl00Ao_0=og@9o_003OkeogGnm00Ao_@03Okaog7oM029og@EogP03OmeogWoM
009og@9ogP0NOmeoogooHS4T03C4GW9Zm4W_;@TTaRT59@HPaRC5:@HUBBTX9@PPaR359<D]1Rd59<DX
aBBT9<<XiBT60R3U00DY:35[:BTU:BDX008U1`@Ti@0:7>HLiaB5;BU><5HaBLeF2VldOoX8Ool00gom
H]L42003000010P08>HY:@013@0000<400`P0000400000<8811032001@@000l880a034080000220m
aEkaDVhHPPPR34D000P0Kbl02Woo011ZeQ@6100@@111464<@AQ1984h`SBS<:8TPAaQ320<008<80<8
80<88@04244<@110440534400`@0000]AP0^OolBOoh00gooOoiooP0NOoh3Omd5Ooh00goMOmiogP03
Omh4Ooh00gomOoiooP03Ooh00gomOmeog@05Omd2Om`047oKOk]k^g^lNi]gVgMjOgQgN6Kc@HX<010P
564@HA1020a00PaP00<@@0`P34000Pa000D<@@@P1008@0a1008<@004460@PAB15842588021RQ6:8D
Y1RS7<<DXaB358826:8011AQ240DXABR0Qc30QRR00DHXabR7<8HXQ1Q008<@007468DPaBT5:@DYAc7
5:D011BS00`H`Qc46<<DXQB2464DPQBR584@H1AQ584558801Q22584@H@aP464DP@8DXP<DPP095:8@
XaBS5:8<@A1Q8><U1Ac3008DP@04588HXQ223442240224400`aQ464@H@02340011B15:<DPQ220QB2
00<HXaBS48800a1Q00D<H0Q0340<H11Q008@HP04368<HA1Q464348424880211Q364<HPaQ464@PQ1Q
344234802QB3464@H11P464DXQRQ464<@Pa10Q1P00<DP1B236400Pa000D<@@`P320<HQ1R008@H@<<
H@06340<H0a0340880a010aP00/8@0aQ364<@0PP320<@11P584@H@aP00D<H@053608@0Q0220<@003
36001`a0360<H0aP364<@@`P00D<H@<@@04@H04@@00000A_FFmHKeQc>09cF003KeUcF7=H009cF004
KeUcF7=HLeP2LeL00gMHLeUcN@02LgT01W=HLgUcNG=iLeUgN@9gN003MeQcNW=j00=cNPYgN@UgNP03
Mi]gVWNJ00MgNP9gVP=gV`04MiYgVgNKNi/4NiX017NJMi]gVgNK0WNJ0W^J00=kVgNKMi/01W^k0W^K
0g^l2g^k0W^l00=k^g^lNk`01W^l0g^k0g^l00=o_7^lNk`01W^l00=k_G^lNk`017^l00=kgGoMOk`0
0Wnl00=o_GnlOkd00gnm00=ogGoLOmd08goM1goN00=ogGoNOmh00goN0Woo00]^]2P0;6=JDF[cDS4a
:bSW<BLY1bCW008U1`0A:DT]JBTX9>HLY1AR68@TaB3566<H@QaR88<PXQR366@DI@0244H00a1U36@D
Q0027<D03ARU6:@PaAS54:DU:EYbKaIRe6:cKaEkDg^G00Uoo`05BQ40000020040007000610030000
2@P0520`i10P100000P02208000510000`P022040002000010A17:<@@0P04`0000=>:gooOol027oo
011VU0@2100DHA11440@HQQ1:84d`C33;:8/Xab1420<00@<80888@<8@@03344<8110008<@@07368@
H@a010000357Ooh0;7oo4gon00=oogonOoh097on1WoN00=ogGoNOmh00Won00=ogWonOoh00WoN2WoM
00=og7_LNk`00g^l00]kW7MkMeYkNGMiHY8e:@P0320@@11Q00<<808<@008468<H@a0340@HQ22460<
808<@006360<@0PP344<H@aR0PaQ00@@HAB16:<Ha08DX`8HXP085:<LiAcT5:8<@@a0588HX`8DXP03
6<<Ha1S3008HX`0=7<@U1R347:<DXQRS7>DDXaB258<DXaRU7>L00QS500@DPaB26:<HX`8HXP066:<L
a1B2468@PQBR0QB100H@PAB1584DPQRS5:<258801AB1460DH11068401QB200hDXQB2588@HQ228@DU
9aRR588HXQc45:8@H@aQ0Q2300<@PPaR34000Pa000H@@11P584@PQ214682464011B1488@HA1R0Q1Q
00/<H0a03408@0a0468@Ha23488@H@aQ008@P@04584DPQ224682368436400`a0120<HP0236423600
2a1Q588HXa1R224<80a0460HXQB234000Q1Q00L<HA1Q468<@@a0460<H00236400a1Q440<H0063402
360010aQ468<HA100P`P00D<@11P360<H11P00<<H@04360480aP6:<334000a1Q364<H002240020aQ
360<H@Q0340DPa2S3642464010aQ440@@11P0A1Q00001FmIKeQ_F7<hLeL00W=H0fmI00=cF6mILeP0
1G=H00=gF7=iLgT017=i00=cNW=ILeT00gMi0g=j3gMi0WMj0WMk00EgNWMiMgUgNWNJ00EgNP05Mi]g
VWNJMiYgNP02Mi/2MiX3NiX017NJNiYkVWNJ0gNK1G^K0gNK27^K3G^k00=k_7^kNk/00W^l0g^k2G^l
00Mo_7^lNkek_7nlNkao_002Nk`00g^mNkak_002Nk`8Ok`01GoLOmeogGnlOm`0:goM27oN0Woo00Yo
ES0P925B3f[bGW8iK2S5<@H]9`8Y1`08:BPYB35X;DTXiQR4444@@P8@@`0M328<0AQ1::</`RB366I>
VT8G;I4Lb1b5468DPaAR588DPaAS48<HY4H_LgUcEf:aJ_EoMG^HNiYogP07Ool017=i88D000000``P
00<880P022000`a10Pa010`P00P880P0200<@AR28<<LY0`Q0PP000D<00`P440@@0a0008<800<440D
@A11340<80aQ7<<Pi@`R224880a10`PP00@400PP220400<0008400888005100002e5OoUom`07Ool0
4Gom@F`40@@0564<80a0444HHRR1><4`XS2T<<@LPQ0P300010`P00<88@`Q22400PQ100<880`P4400
1A1Q00@80000>FIoo2aoob1ooP=oo@mooP=oo@04OmeooGonOoh6Omh3Omd5Ooh00goNOmeog@0;Omd0
0g_LOkak_002Nk`03G^LMiagFg]jLeQFD2C5200@@11Q440<@@PP008<8003340<@@a100@<@@@<@00;
460<H0a1344<H@aR344<@11Q564HXP0358804ARS7<<Pi1cU6<<DPPa0220DPQc46:<DXQB25:8H`acT
7<<00aRS00HHXQBR7<@U1BCT6:<25:<02ABR5:<DXacV58<DPARR6<@DX`0658801aBR584DPAB1464@
PA2200@DPP0@5:4DPAAP584HPARR588<HA1Q468@PA1R2448@12158825:8258801ABR7>DLa1BS5880
11220Q1Q00<@PAAP56000Q1Q00<<H@a034000Pa00Q1Q00D<HA1R588DXQ2200<@HP<@P`054688@11Q
464DP@026:801122468<HPaR0`aQ00D<@0PP100<H@aP008<H@07340<H@aR368<@PQ222400PPP00<<
H0aQ46400Q1Q00H<HA1Q348<@Pa04602320010a0360<@11P1`a00PaP00<@H11Q46001@a00Q1P00<@
HA2246400PaQ0PaP0PaQ00P<H1215:8<H0Q0220<@0aP0`aQ00<@HQBS48800Q1Q00@<HA1P340@H04@
H@0000A[FFmHKeQ_F09cF0I_F@03LeU_FG=H009cF@icN@EcNP04MgUcNW=jMgX9MgT2MgX2Mg/01WMj
MgUgNGMjMiYgN@=gNP9gV`9gVP04MgUgNW]jMi/3MiX01W^KMiYgVWNJNiYkV`YgV`03MiakVg^k00Mk
V`Ik^`=k_003Nk]k_7^k00Mk_0Ek^`=k_003Nk]k_7^l00Ak_003Okak_7^l00Ek_0Ao_0=k_@9o_0=o
g31og@EogP9oo`0;OkE4XR03ALiZd5jB?F/L82BU9>LPaP027<H08Qc5;DLaJBT678<@HQ1S68<DI10R
400THSeXAFLda35:HgecgfMm@O0XYBcV9<HLPQQQ448<@Q134451k6mgKc=_5Gmg0goo00=o_G^MOkh0
0goo00Akg5JC9<L00084008<8005340<@@a1344@H@0234400a11320@@00244023202220010PQ368<
@11R0PP001@<01A0440<80P0340@@@PP320D@10P444@@0a1584DP`Q1120<@@a20PPP0Pa200H<@@Q1
364<@@aR468346401Q1R200000@0BPeon`Moo`0@GW@D0@00100@@@`P440<81QR984h`C2Q::</aQR3
4442200322001PPQ320<80PQ220<@0<@@@8@H@06564D@@P0200mJ7ok47oo00=ooWooOol03goo00=o
oWooOoh01goo8Won00=ooGonOoh03Gon00MooGoMOmeooWomOoiog@07Omh00goMOoiooP05Ooh<Omd0
0goLNmak_002Nk`03g^KNiagW7]kNi]_>4G_66@801AP564@H@a0220<800334000`a1340<@0043400
0`a1340<H00536403A1P320@H11Q584HPAc36:<DH@`P588Da1S3008DPP0:464DXaRS5:<<H@Q0584H
`b465:<358802A1Q220DHAbS8<<Pi1RS488DPP0458<00aBS6:8HX`025:<00`aQ464DPP0358801QRR
584@PAB26:<DX`8DPP<DXP08588DPAR1684La1B2464DPP8@H@8<H@05368@PQ22488@HP0246401ABS
6<@Ha1S458<01A220a210Q1Q00@<HA1Q360@H0D@H@0A468DXac47>DHaABS488@Pa2T38<<HPaQ460<
@1B17><HP@024642348010aR484<H0a00PPP00<<H12048400Q1R00T<H@aR3688@@Q2348<HPa12200
0`aP00<<H@aR36400Pa100H<@110300@@0a0344236001Pa0344<H@aQ340<80<<H003464<H@a000@<
@007320@HA1P6:8DPQ1Q36400Pa000L<H0aQ364<HPb14:<<H@03340011214:8<H@aQ0PaR0Q1Q0PaQ
0PaP0A1P0@aQ00000fmHKcQ_>004LeP027=IKeU_FG=HKeUcFG=iLeP2LeT3LgT2LgP2LeP00g=iLgYc
N@06LgT3LgX3LgT00g=jMgUgN@09MgT3MgX3MgT00gMjMgUgN@03MgX00gNJMgYgNP02MgT00g]iMiYg
VP06MiX00g^JMiYgVP04MiX5Mi/00gNLNi]kV`0:Ni/3Nk/00g^lNiag_002Nk/00g^jNk]k^`02Ni`0
0g^lNk]k_006Nk/017^lNk]k^g^k27^l00=o_7^lNk`00g^l0gnl00=o_G^mNkd00Wnl0gnk17nl1WoM
00=o_GoMOmd077oM00=og7oMOmd02GoM031ooWooOoIA1QP4>D]Z[V:a?J/PQAaV9<LPY1b366<LPRCT
;BHeARST88<e:3f;=F`Tb2B5>BQN;FZ:GNQF:f<FMk]JeDg_=@P/ic3W::<TY2SV7:L80P`0=B=JJg=B
OkL4Ool027miENla2cE;=FXY2AbU104200000`@0340<@00234001`Q0364<H@aQ440@HAAQ008HH@8H
H005760HHAQQ544DH@0366400aaQ760LH004760366001A@P640LHAaQ640011A000l@@1A0540D@1A1
664DHAA1564@HA11464@HQ1Q44400Q1001`880@0000002D7CXmkeGojOoUk^FKE>Hh@A@@000080111
344<@0P0544XPCBP<84XPbBU424800D0000310000000008000<400L00003<@IofGoo00ioo`IooPeo
o`EooPEoob9ooP=oo@AooP03OmiooWon00EooP=ogP=og@9oo@03OmeogWoN00AogP03OmeooWom00Eo
oPQog@Eog00>Nmak^g^jNkYkVg^LMg]o_7nLKcTm[Q13200@H08@H@03364@@11000<<@003360<@0a0
00D<@004364<@0a0340336002A1P320<@11Q588HPAc26:8DXP02468011BT6:8HXQB20aBR0aBS014D
XQc37>D@PP`P464DXaB2464@@AB16:8HXaBS488@H@a000DDPP036:<DXQBR008DPP0>468@H1B1584H
P1R1584H`b3U6:<DPQAQ584@P@LDPP8DP@03484@PQ2200<@PP<@HP04564DHQ22468348801a1Q488@
PQ22464@PA22008@P@8@H@06460@P1B0484@H@aQ0Q1Q0Q2200lDXQB3468<@A226:<Ha1BT46<@HA1P
340@HA216:400Q1Q00D<@@a2368@P@aP00@<@008460@HA1Q464@PA1R368<H@<<HP<<H@05360<80a0
340<H00334001@PP320@H0aP36800PaP0Pa000<<H@aP360010aP0Pa000D880@P240<@0Q000888006
440DP11P360880a00PaP0`a000@<H122364<@08<H08DX@07584<@0PP364@HA1P36400PaP0@PP0@aP
0@a100001FmHKcQ_>6mIKeP00W=H0fmI00=cFFmIKeT00VmI00=_FW=JLeX00W=I00EcF7=iLgUcFG=H
00QcN@AcNP03Lg]cNW=j009cNP03LgUgNGMi00IgN@YgNPEgVP03MgYgNGMi00=gVP9gV`UgVPMgV`03
Ni]gVW^J00akV`Qk^`=k_0ek^`Mk_003Okak_7^l00=k_0=o_0=k_@]o_003OkeogGoM009o_BIog@=o
gP0aOmeog7ooOoYEKP`4<@UZ[V[dEU19kdhBCO1=cDg>DLe=c4g[DPi1[2SW:<E9c6kaKeUFE3f^FS1c
5Fk>GTaND6/FKcM[>58_CJeEkdUZBHUVT7]eMeXmC@`0:8A9bflBOoX017oo00=VUBaU60801P0000@4
00PQ244<@@8<@00;344<H@aQ460<@1AQ784X`bST::8/XP02::801BS3::</`bbS88800R210RBR00@X
`bRR884PP@8XXP8PP003884PHR1Q008PH00?880XXS33<>@``bR2984XPBB1:88XXbcT788D@A11008@
HP@@@@0:20000000000401AP8>8PX1aP200310003@P0344<@PaQ220801Q2;:8dX321:8<PPa0Q01D0
0003?DMofWoo025oo`EooPEooaeooP=ogPUooP9ogPEooPIogP=og@UogP03OmeogWoM00Yog@Iog09k
_0=k^`09MiacW7nKNiaVeSV<32<800a000@@H@03440<@11000D@H004360<@0a0220334000`PP340<
H00236001PaQ340@HQB26:8H``8DX`8DP`045:<HXQRR588248836:<02aBS7<@La1BS344881AR5:@Q
1QS458800QRS00THY1BT58<@PQB2468@@@a044400aB2010<HA2258<@HQAQ688DPAAP684DXABR6:@D
Pa1Q440DP@8@P@06588DXQBS5:8DPQB30QB21Q220Q1R00DDHQRS468@HA1R00<@PP0;464@HQB25:8@
PA22388<HA21588@P@0246401120484@PA1Q0PaQ01D@PQB2488@HPaQ344<HA2358<DY11R440@H110
340@HABR488@HPaR22000`aQ0PPP00D@H@aQ360@H@aQ008@PP05368<H@aR368<H`0248<00a2248<@
HP0232000`PP340<H@02360010aQ360@H0aQ0PaR00D<H0a0364@HA2200L<H@0;340<H@aQ364<@0aQ
344<@11Q364<@@0336401Q1Q440@H@`P340<@@8<@08<H@03464@P1R1008<@0H<H@4<H04<@04<@@00
00=_F6lhKcP01FmI0g=H00E_FG=IKeUcFW=I009cFP9cF@IcF003MeQcNG=i00IcN@McNP]gN@=gNP04
Mi]gNWMjMi/6MgX4MiX017NIMiYgVgNK2GNJ0gNK00=kVgNKMi/047^K00=kVW^jNk/03W^k00=k_7^k
NkX00W^j0W^k1g^l00=o_7^lNk`00g^l4Wnl0WoM0WoL1WoM00=og7oMOmd05GoM00=og7oMOmd01GoM
0goN02IogGoLOomoo68d30D`b6Z=KcE_=VlGLcU_>FkgJ[EV]FkdMgIcNEHc>DXXaE7[OkEk^V:dDNeN
DG<EL^mZT6:BH[A_>7^KMeQ_>7<j0W<h00YomGonOom^nQ`260<i25X9Ja=om`9on`08J_LiKAP41044
0000100880L<@@@<@007460@@1A0760/`BBQ::400c3200Dd`bc3<<</`RbR008TP@03::8/XBB1008T
P@0B:84XXC2Q;:0TP220988PHBB1980/XCSS?><hi3d3?><dXSS20ScS00Lm133T8<@HPaAR468@H@03
444234400``P20040007000040@0220@@Pa2444<H@P0444PXc33<84/PBAS<:<``S3R0bcS01<Xi2SS
:<<X`bC3:></i2RT;>HmRdX_FViB;dg`BM11LDF<H]9oo00FOol00gonOomoo`08OolXOoh3Omh9Ooh6
Omh3Ooh:Omh017oMOmiogWoN4GoM0goL00mofg^lNk]k^W^iNk]gVgMiNgUgFEic;@T88@`P46000Pa0
0Q1P00@<@110440DH0H@H08<@08<8003220<80a0008<H08@H005344@HQB26:@HX`025:<00aB3588D
PP026:803AB2464DXbD68>@HXaRT6:<DXaB2464DPaRS00@HY0068>HLaAB358<DXaBR0QBS00@DPaB2
464<H@8@HP05368@PQB2588HP@03588258401PQQ48<@P`a1340DP@<DXP036:8Ha1BS00<DPPL@PP8@
HP8DHP03468@H@aQ008DP@03564@@11Q008DP@04484@HPaQ3684464246001QBR6:8@PQ1Q340DPP8H
X`04488@PA1Q468248803A1R464@@11P464@H0Q0364@HQ22468<@0Q0008<@004240<80aP36434640
1122468<HA1Q0PaQ00T<@@aR468DPPaR364<@11046400PaP01@@H1B2484<H11P588@H`aR340880aP
464<H0PP340<H@a0240<H@aR20aQ0`aR00/<HA1R488@H@aP460800@0220<@0a1008<H@03464@H1B0
008@H006240<@@a134488@PP0Pa00@aQ00000fmHKcQ_>004KeT6LeP4LeT00g=JLeUcF@06LeP00gMH
LgUcN@06LgT7LgX;MgT4MgX3Mi/00gMjMiYgN@02MgT7MiX2Mi/4MiX2NgT3NiX3Ni/00g^JNi]kV`05
Ni/00g^JNi]kV`05Ni/2NiX00g^KNkYk^P0?Nk/01G^lNk]k^g^kNkX00W^k1G^l0W^m1W^l4gnl8GoM
00=og7oMOmd01GoM0goN02UogGomOoeooVJG50LXIFI[JaEVeGMjOm]o_7MIK_MZmg<GLeQg_EZDBJda
:Sf/JaEgVejCGRe^lg<DIViRCf9aHY9_5flhKcMkNWnlOeQkEgon009oo`0@Oi`/IA@1924e1CU7>DE5
YDF5?FTXaR2588@@@P`Q224:34401``P440@@110420LH2B0008XP0039:4XPBRQ008XX@05;:4``S2Q
;:4XP@059842:843;8000bR0984TP@0298404RR1::4/XBbQ<:4`XS2Q=<<hhcBR;:<diC458:<DHQ1R
444<@@<<@P<<@@03340880@000<40004240<HPaR348434403`P0564i1CST<:8XH2A1>>5Eif9]FTaN
CVI_HY1RK`02HVh01VI^KXeZKFjbMaIoo@Moo`03Ooioogoo01Qoo`=ooPIoobEooP9ogP04OoiogWoN
Omh7Ooh017oNOoiooWon47oN0goM00=ogWoMOmd03goM17oL0W^l0W^k00agVgMkMgQkN7<gEPlLI0@1
468DP11P4645440346001PaP460@H11P364<H0@<@003460DPQ22008@H@03344@HQB2008DPP0?6:8H
Xac46:<HPARR7<@@H@a05:8U1B457>DDY1BS008DPP035:<Ha1RS008HY00?6:<DXaRT7<DDPaB458<D
Xad69BLM1QB3468@HAB2008DX`0>240@PQB2688Pi1S458<<HQ2338<@Pa1R344<H@8@PP09588DXQS3
7>DHXa1Q2208@11R008@PP8DPP@@PP04564@HQ1Q464246801Q1Q564DPAB16:8DPP8@PP03364<HQ22
00<@H@0:460@HA21488@HPaQ220DPR3U6<<2484021B2488DPQB2468@HA10460346400`a1364@H@02
36801Q1Q468@HQ1Q588@PP8@H@<@HP03364@HA1Q008@H@8<8003344<H@aQ008<H@D@H@<<H@0;340<
@@a12448@0@P364@HA1P320@@00234001PaR468@Pa2258<@P`8<HP8<H@05368@PaBT48<DPP0258<0
0a22464@H00232001@a1340<@0a136400Q1Q00@@PA1Q364<H@8<HP<8804<804@H04<HP0000=_F6lg
KcP00Vlh00E_FG=HLeQcF6mH00=cF0McF@IcF003MeQcNG=i00=cN@9gF0=gN@9cNP03LeYcNW=j009c
N@MgN@9gN09gN@EgNPMgN@03MiUgVWNJ00QgVP9kN@03NiYgVW^J00=kV`AkVP03NiUkVW^J00=kVPIk
V`9kVP06Ni]kVW^jNk]g^WNK47^k0g^j00Ek^g^lNk]k^g^l00=k_@Ek_0Eo_003Nkao_7nl00io_003
OmaogGoM019og@03OmaogGoM00Iog@03OmaogGoM00Eog@=ogP0=Omeoo7olOomc6RA:805R:6[dJaQo
VWoJNiT00Wmj01=kFW/hOgYgW6lhGU9=/3U;FWA[>F;EGVi^kfZ_GRmRCeh^FRiZd`02KcL01GMHNeIg
5GLdNiH00goo019F4R1W<:L/Y3DW?BA5Q5H3DLLiABS2;<<HHP`1200<@@PQ32423485344030a0440@
@110420L@21P960XP221984XP@8XX@04;:4/X3C0:806984386001RB0<:0/X2R0860TP@8XP@05860/
PBbQ;:4XP@02<:402cBQ<:8/Xc34;<<LPAAR448@@@a144400Pa10`a02Pa1010<@111444<80@06855
QD55<:8/H2QP=<1J9FJ:K/UZRP=Z[@08KZi^cG;`Ma9c57<FNiUooQeoo`03Ooioogon00QooPAoob9o
oP9ogP=og@9ogPMooP9ogP9ooP9ogP9og@MogP9og@9ogP03OoeogGoM00]og@03OmiogGoN00Eog@Eo
g0=k_00@NkYkVgMjNgMoV7<FBLdH@P@058<DP1AP564@H11034023205460010a0460DPQ1Q10a00Q1P
014<H11P464@HAAR688@HA1P588HXb3T7:<HXR3T8@HDX`PP008HX@086:8@PAB25:8@PQ216:8HX`8H
Y0036:<DPaB3008DP`0D468<HQ1Q5:8HXb3U7>DDPa1R588DPARS7<DDXPaQ468HXR3T8>DDY0@@P`8@
HP0;488@H@aQ584DXQBQ488<H@a1464@HP02364248801AB1488@HQ215840112100P@PQ1R464DPABQ
9@@U1QRS111R0Q1Q00@@PA1Q360@H@88@006364<@A1Q6<8Pi1RR0Q1Q00h<@11Q464@PQ1R444<811Q
588@HA1R464<HA1Q0Q1R00H<HA1R488DPQBS588346401A1R464@H@a022000Q1Q00@<H@a0340<@0<<
H@03464<H11Q008@H@03364880@00088800:100880aQ364@HAB1460<@0aP36833640111R488<HQ1R
0PaR00@<H11P384DX`8@HP@@H@04484@H0a02203340010a1364@H@aQ0Q1Q00@@H0aP464@PP8<@@8<
@04@H04<H@0000=_F7<gLcP00Vlh1VmH0W=H1g=I0g=H00A_FG=ILeUcF0=cN@06LeUcNGMHMeQgNG=j
0W=i00AcFW=jLgYcNP9cN@EgN@=gNP03MgQgNGMi00EgNP9gN@04MgYgVWMiMgT3MiT6MiX00gMjMiYg
VP05MiX00gNKNi]kV`05NiX017NJNiYkVW^J2W^K00=kVW^jNk/05g^k00=k_7^kNk`02G^l0g^m0g^l
17nl0g^m00Ao_7^mNkeo_@9o_003OmaogGoM02Eog@=ogP0:OmeooGonOomoO32;901Maf[dLeT2Nk/0
0g^JNi]o_002Oid027nLOgUoN6JeEO0mBTV`H_H2JcH016[cIY5EcEG]0UX<00QVe6lgLeQgN7]eL_EZ
e7Le17oo00mZn5F/DJM5RF[eOiU^lVJ^ENTi933S78@80@P034402@a200`<@@a0440@@10P760PH2AP
984PPBB19:82:842;:400cBP<80`X002:8402bR2::8TPBAP:80``CD2=<4XPAa076000RB100DXPBAP
;80XXRbQ008`X@<`XP8XX`068:8H@1A1324<@@a20`a10`a01Pa10a1100X<@A11444@@@a0100PXdW7
AFP`X`8/@00@=:1=a6J9HVQRJV9;GRYN:F9:IV]Z[FJ_J_=VdgMGOm/MOol;Ooh3OolQOoh00goNOmeo
g@07Omd2Omh00gonOmiooP04Omh00gonOmiogP0:Omh4Omd00gomOmeog@0:Omd4Omh6Omd00goLOkao
_003Nk`02gNJMi]gNW]gOiQ_5DF]4248011S4680111Q00`<@0`P320<@0aP460<@11P360<HA224643
34001PPP320<@0aP460@H@8DH@8DPP0?584HXQRS7<<HXac38@DQ1QBT340HXaRR584DPQRS00DDX`08
6:<La2356:<DXaB2464<H@8@HP0:364@PQBR488<HA1Q588HPRD56<@358802QRR6<<Q1QBT48<DXb3V
6:<@PPa10Q2200@DPQBR5:8DX@8DXP03588@PQ2200<@PP055:8DPQ21584@P@025842488346802Q1Q
588Ha23U8>H@PPaQ468HXa1R0Q1Q0Q1R00<@PQ1Q34400a1R00HDPQS27<<DP@a0360546401Pa0440@
HAB26:<DY08@HP<<H@<@HPH@H@05468@HA1Q440@HP0248800a2346<<@@0236401a1Q364<H0aQ368<
HA1Q00<<H@09348<@@a0444@HAB2688DPQ1Q008<H@03368@PPaR00<<H@07368<@@PP244<H11P5:80
0Q1Q0P`P0Pa000/@H11Q360<@0`P360@HA10340<HA1Q00@<H@05440@H@a1344<@002364136013640
0003KeQ_=g<g00U_F004LeQcFFmILeT7LeP3LeT3LeP2LeT017=iMeQgF7MH0W=I0W=i0g=j2WMi00Ag
N7MiMgUgN@AgNPMgN@03MiUgV7NI00agVP04NiYkVg^KNi/4NiX5NiT00g^JNiUkVP02NiX027^jNi]k
Vg^JNi]kVW^jNiX5Nk/3NkX2Nk/2Ni/?Nk/?Nk`3Ok`3Nkd017nlNkek_Gnm1Wnl0goL8GoM1GoN00Uo
oWooOgi4cA`0CDAZdgMiOk/00W^J0W]j01]gNgMKMeYoMgogK_ENDTg@@FmN]7MfKaE^mF:CDLmAcEX;
GPaZe7=INgMgMgLeJ_EVeWLGOk/00goo00EooV[BEPQ=kWoO009oo`09OmU^ZcdT=@<PYA13200@@@a1
00<<@P03248<@@a1008<@P8<808@@003544LHB1P00<PH004984TPRR1::82;:401Bb1:84/PBbQ:840
0RR200X/XS33=B@mI4FYAHPd`bQQ964XP0<XP@06:80/XBbQ::4`XCBR0S2R00L/XRbS98<LHAA03248
8@0434400a10340<@00734444442440060`P200TiDg8AHT/PbQ0920dX4W6HVYRJ5i8GTUN:68XHRMV
JVZ/IZeRSej@KaEo^AeoobUooP9ogP=og@03OoeogGoM00Yog@9ogP9ooP04OmiooWonOoh9Omh00goM
OmiogP0AOmd00goNOmeog@08Omd037nlNkak_7^lNk]kVW^KMeYkF7MfI]=1J`8<000:324<@@a2344<
HA1Q488@H0a02202320010a0360<H0aP1Pa00a100a1P00@DHAB1588HXP@HX`076:8H`acU5:<@HAB3
6:@00QRS0Qc400DHXaBT58<DXaS4008L``087:<HXQB2564@PQ1R368<H@8@HP04488DPQB258455880
11R2684H`QS30QBS00XDPQBR5:4DPAB2488DPQBS6:<DX`<DXP8DPP04484DPA2258826:825840111P
580DPAB20Q220a1R00H@PQ23488@PQ1R48835887468348800a216:4DP@0=464346800a1Q468@H@02
46400a1R364<@00446401@a1440@H11P46800QBS00`<HPa2220<H@aR488DXQ1Q120880aQ46433643
344246401122588@HA1Q10aQ00P8@0a0360@H0aQ240480a20Q1P00<DPA1Q34000`PP0Pa000<8@0a0
36000Q1P00LDP0a0220<@11P360<@@0434001Pa1340<@11P360@H@4<@@0000=[F6lhKcP01fmH0g=H
00=cFFmILeT01g=H0g=I0g=H0W=I0g=i00=cF7=ILeT00W=i0g=j00=gNGMHMgP017Mi00=gNW=jLgX0
1GMi1GMj1GMi00=gVGNHMiT00gNJ0gNK1WNJ00AkVW^KNi]kV`EkVP06MiYgVGNINiUgVW^I0W^J1W^K
00=k^W^JNiX01G^K17^j00=k^g^KNi/02g^k5W^l0g^m00Ao_7^mNkeo_@=o_0=og@03Okao_Gnm029o
g@EogP09OomogeFB6014hV[COgQoVW]k009kNP0LNi]kNWMJMcUkEgoIOeQVeUYeAK5FDG]fNeMZeF:C
DNmJ3Uh/GPeV]7=HMeMkUgMEKaIZeW;fNiX4Ool00fliAJe5l004Ool01fZ;?BDe12cV44<8011Q00H<
@P06344@@A1R564@HA100Q1100HHHAaP860PPBB1:842:883::801BbR::8XXRRR;:400RbR00d/XbcU
>JU:2Uj?GTe1ASBR:64XP2R1984XXP03;:400c32=>8dXP03<:801RbR988PHAQQ344<@P<@HP03448<
@0a0008<@@03364<@@a100@<@@8@@@0L464@H110200402SUDPU5JBQS:44L82b0BLINJf:8GTQN:EXX
HTQR9VIYJX]Z[6:>GVmZlgnHOohLOolVOoh3OmhBOmd4Omh5Ooh<OmhJOmd03GnlNkak_7^kNkakVg^J
NgYgFWmiMgMRTSDY00<80003324<@@a2008<HP04364<H11Q588244002Pa0360<H@aP320800`P360<
H@aP0Q1000@@HAAQ460@H08DP@0M5:8H`aS46:<HXQ1P580HXARS468DPQRS5:<DPARR8>DHXaBS48<<
HQBS6<@DXaAQ664HPARR688DPP025:<45:845880111Q564DPQB20QR200<HXaBS5:<00QBS00<DXQB1
56000QB20QS40aBS00@DXQRS6:8DPP<@PP076<@Pa1RR5:8DPAAP58400a220a1R00T@Pa22468@HPaQ
468@PQR258400QB200D@HA1R344@HQB3008DX`07588@PQBR5:4@P@Q036401A1Q00HDHA1Q464@H@a0
464346800a22468<H@0336401@a0464DPAB258400Q1Q0Q1P0PaQ00H@PQ2134488@a1364236824840
0a2248<@H@03464010aQ344<@@a10`aQ0Q1Q0Pa10PaQ0PPP00L<@@aQ484<H@a1244<H@02460020aQ
464<@111344<HA1Q4842464234001@aP460<H0aQ46400QB200<@H@a034400`a100D<@110464<HA1Q
004<@@0000A[F6lhKcQ[F0U_F003LeQcFG=I00=cF004KeUcF7=HLeP3LeT00g=HLgUcF00;LeP2LgT0
17MiMeQgN7Mh0gMi00=gNW=jLgX01WMi00AgNWNJMiUgVPAgN@04MgQgV7NHMiT2MgT00gMjMi]gNP03
MgX2MgT017]iMiYgVWNJ1W^J00AkVGNJNiUgV@=kV@03MiYkVG^J00IkVP03NiUkVW^J00=kV`03NkYk
VW^i009kVP=kV`Yk^`04NkYk^g^kNk/3Nk`00g^kNkak_00BNk`5Ok`017oMOmaogGnl0Wnm8goM17oN
0Woo00IR=200A>5c5GnhOkX2NgX05g^INiYkNG]iMeMkMgoJOiYZmeYDAK55[GMENeM^mUicFPmN;Uh[
FPaV]6lgMeH00W^G00EgEV[FMcMkNGoN00=oo`04Nee5/3E>Le`2Ool02V[hENTe1344:>H@8P@0340<
@@a20`a100/<@Pa0340PiB3T564@@A1R444HHB20008XP@04984TPRR2:886::803BbR;:4/XBbQ<:8d
iDh<MdioTWl/BFDl`baP008/P004;84`XS32<:82;:82<:801cBQ<80`XC32::4LHAQQ00<@HP0358<D
Q112008<@0P<@@06444@@110460<@11P0P0000/]15H[BJXXI2@Q820/P4W6IZ]RR5Y8009NBP0:HTQR
9VI8JVUZZVZ_HVmbm7nGOoh6Ool3Ooh:Ool00goOOomoo`05OolMOoh00goNOoiooP04Ooh2OmhJOmd7
Omh2Omd8OmhJOmd03gnlNkak_7^kNi]kVG^HMgUkNgmiNgQJDBS62004000232005`PP320<@@a1360@
H0aP464DPQ1Q460<HA22360<80a1364@H@aQ460<811046000Q1000TDPABR6:<La23T7<<HXaRQ7:80
0R3S01DDXQB3568DPQR2584DHAB15:8DPQ1Q588DXaRS58<@HQ1Q584HXQRQ6:800QRS00DH`ac48>@L
a1RS00@DPP0@688HXQBR584DPQ1Q364@PQBS6<@DXQB1440DPQBR6:825:801QBS5:8DXQRR688DPP8@
PP034:8DXQRR008HXP03580DH11P008@H@06488@HQ1R588DXaB2111R00@@PQAQ564DH@8@H@8@HP0:
464DPA22588DXQc36<<DP@a0364346401PaQ464DPAB2468@H@8<@@04464@HQ1R4682464236402A1P
360<@0aP584L`QRR464<@@0246001PaP464@HA1Q360<@@D<H@03584@HA1Q008@H006360<H@aQ344<
@0`P0Pa000<<H11P464010a100D<@0a1364@PQB100<<@0<@H004340880`P460346402Qc37>@@PPa0
220<H@aP364@H@aQ0Q1Q00<@H11034400Pa10Q1Q00@<H11Q364@H04<@@0000A[F6lhKcU_F@U_F09c
F003LeUcF7=H00EcF0=cF@]cF0EcN@03MeQgN7Mh00AgN@=cNP=cN@07LgYgNWMjMgUcNGMiMgX00gMi
00=gNWMiMgP01GMi00=gVgMjMgX00WMj00=gVWMiNgT01WNJ17^J00=gVW^JMiX00gNJ00=gVgNJMiX0
2G^J0g^K0g^J0W^K4G^k67^l2Gnl0Wnm97oM0goN0Woo00I^]RP0@<9g=gogOm/2NgX07W^JOiakNW]j
NgUkNWnjOka[65HbBK4mS6[BNgQZe5ibFPiEbUh[HVi^lflEKcIkV7nhNgQg>7MHOkYog@=oo`0@Okm9
dBd;BM9Zmf:eFW55ZS3T=BDXiQ0R000800Q2348234403P`Q344<80aR6<DPiA1Q444@HQ11664PPBR1
::839:8012B2888XXRRR12bR0S2R00T/PBR2;:=9ZG/]OoUZKDDT>:400S2000@/P2b1;:8XXP8/XP0@
::8XPRbR=:4dP3BP=<4/`Qb1564@HQ1S68@U1ac6468234000`a1340<@@04344244424400711Q340@
H0@0000a95j=DNd/IRA1820/P4W7IZ]RZEiZGV]NK69;ITYVJVZ;KZaVSV9`MaAoUgon1Goo0Won4goo
5gon27oN1gon00=ogWoMOmd00WoN1WoM00AogWoMOmeog@=ogP03OmeogWoM00Iog@UogP04OmeogWoN
OmhNOmd01GnlNkak_7^kNi/00W^I00agNGmkNgUc=Th`88H800`0444DPQ1R364234401@a0464<HA1Q
46800Q1Q0PaQ00H<H0aQ364@HQB3364246001Q10340<@11P5:8H``8La08HX`0;7:8HXARR9@HU9AB3
368DPaRR684HXP026:<021BS58<@HARS8>DHXQB258<25:8011B25:8La1c40QBR00`DXaS46<@DXQB2
464DPQRR7:<Q1AcU6:8258801A1Q488DXaBT58800QB100DDPQRS5:8@PQ1Q008DXP075:<HXQB2468<
HA224:<00QBS00LHXaBR584@HA1R464@HP0648801A1R488DY1RT58800QAQ00@DPA1Q464@HP8@PP08
464@HQ1R468DPQBS584<808@H@0<484@HA1R488H`aBS488DPQB1464@HPaR1A1R00/<HPaQ360<H@PP
584Pi1B1364880`P008@H003464@HQ2100@<H@<@PP03484@HA1Q008<H08<H@04368@HA1044423403
46401Pa1340<@@a1364<HP<<H@<<@0<@H005340880PP340<H@0246400a214:8@H@02340010aQ464@
H@aQ10a00Q1Q0Pa000<@PQBR48800PaQ0A1P0@a100001V]HKcQ_>F]IKeQ_F@A_>005KeQcEg=GLeQ_
F003KeT2LcP>LeP3MeP2LgT2LeT00g=iMgUgN@03MgT01G=iMgUgNGMiLgT00gMi00=cNWMjMgX03gMi
0WNJ00IgNGNJMiYgVWMiNgT7MiX5NiX5MiX:NiX01W^INiYkVW^JNkUkVP9kVa9k^a1k_003Okak_7^l
00Ek_0Uo_09o_@04Okaog7nlOm`ROmd02goNOomooglF=20/PVJbOoIofGnjOiX00WnK01akNW]INeQk
NGnJOiakFUieDQ=5keY@L_EZ/EX=ENaEjeXZGVigEW<EKaEoMGoGOkYkNW]GOo]og@=oo`0@OmmJECD<
<Ba=cUXYER]9bce7>DLa9aAS100<80Q2348534402`a2368@HQ11344@HQAR564LH2AP:8400RB100DT
PR22888XPBbQ00H`XP09<88/PRQQ;819YUY>@DH`P2aP008`P005960PHBR2:84XXP03:8800bbR;:4`
X@02=:002Rc1788D@@a1568DPac56<D@HP`P1Pa01a1001/<@11P200003EVHZi=k2QV:48P@2b0AJIR
RfJYGVUNBUi<HTaVBfZ<JXeZS6I]HTmbm7nfOoh017oo00mooWoNOomoogomOmYoEgjcOU1nC7i]OVan
SGkbOkP017oo00AoggooOomooaIooP03OmiogGoM00=og@UooP06OmiogGoNOoiogWoM3GoN27oM37oN
7goM00=o_7^lNk`00W^k00agVW^IMgUkFGMIKaE1[QAT200@@111464258801`aQ344<80a0344@H110
008<@00A220<@0aP464DPQ23468<HA1P320@@0aP464DHAB15:8HX`026:@011RS6:4DH1RR0QBS00DD
Pa1S5:<HXARR00@HX`<DX`046:<DXaBS5:<25:8258426:855:801aRR6:<HXaBS6:<Pa23T008Ha00>
6:8DPQB2588@P`a2220DP1B16:<HY1B3588DX`8L``07688DPQB2588@PQB248<00QBS0QB200@@PQ1R
468<H@8@HP03488<HA1R008@HP03464@PA2200<@H@04564DPA21488246801A1Q584@H@a136400Q1R
00@@H@a0340@H@8DP@8@PP8DPP04464@H1B0464346801`a0220<@0a0364<H0aQ0088@006484HXQAQ
340880a00Q1P111Q00H<@0PP460<H121364346402@aP460<@0aQ488DP@aP344@@@05464234401111
440<H@aQ0`a100<<80PP4600111P00@@@0a0340<@08@H@04364@H11P46425880211Q364<H@aQ440<
HA1Q468446401122464<HA1P0@a1000016]HKcQ[>F]I0VmI0flh00Ac>6mHKeQcE`9_F0=_F@9c>0]c
F008MeQgEgMGMeMcF7MHLgUcF09cF@QcN@IgN@9cNP03MgYgNGMi00mgN@9gVP=gNP03MgUgVWNJ00Ig
VQ1kVP04Ni]kVW^JNiT3NiX00g^iNiYkV`04Ni/@Nk/?Nk`00gnlNkak_00:Nk`4Ok`01G^mOkeo_7oL
Omd00WoL17oM00=og7oMOmd06WoM00YogWooOomoVdRS729JDGniOkMoV09oN00COiYoVG]IMcIg=gnI
OmioO6khEU=:<TW>HU9RD4g=>DXmRdG<HXl00W]g00QV/6lDOoUooWmlOg]ogGon17oo00iR]cdZBJmF
<5H]DPaAk4F9>DPa1ab3200<80a21`a10`a200D<@@a2464@@AaQ008TH@0:888TPRR2988XXS2R<:4d
XC2R=:43=:8043B2<64XH2Q0<80`X320;60XH2b1<84XPBAP:84/XRB20RR100<THBR2<:800S2R00H`
XBbQ788D@@`P444346800a1Q320<@0023409440234004a1P100003f8I/m=cBA6968TH2Q0AHERRfJY
HVURJf9]IViVKFZ=009^c`05JXmRCfkdOkMooP06Ool03gonOminnGH?KFYd`G2PL81XH6AQH69PaFW_
N[9o^`03Ool017oNOoioogoo5Won1GoM1gon1WoN00=ogGoNOmh00WoN00=ooWoNOmh01WoN0goM00=o
gWoMOmd00goM3GoN7GoM00=kgG^lNkd00W^l0WNK00]gVW=jNeUkNV[D>F`88PP0340@H111008@H@03
364<@0`P008<808@@005460<@@a1344<H004364010PP460DHA100Q1Q00DDHAB1588@HQBT008HY00@
6:<@HABS5:<@PPaR46<DY1BR7<@Q1R3U7<@HXaRT5:@25:<25:@25:<00aB2584DP@026:801QBR6:8D
XQB1464DPP8HX`0:6<@La2346:<DXaB2688HXQBS588258<01ABS5:4DPQB26:<00QB200XL`b3T7<<H
PQQR564DPQB3588DP`@DPP8@HP03364<HQ1R00@@HP0548<@PQ1R468@H@02340246401a21588DPQ22
468@HAB1008@H@<<H@09344@HQ225:<DPA1Q364@HA1R008@H@03440DH11Q00H@HP8@H@04340<H@aQ
340346400`a0344<H@0346401a1P360<@0a0240<H0aQ00D@H@09364@H111344@HA1R48<@PQ1R008@
H@8<H@05368@HQ1R444@@00246401@aQ340<80a134000`aP111Q00<@H11046400`aQ00X<@11Q7:<D
PQ1Q344<HA1Q364@H@8@P`08488@HQ1Q364@PQ21464@H04<@@000V/h00A_>6liKcU_F@9_>@9_>09_
F003LeM_F6mH009_F005KeUc>7<hLcQ_F@08LeP2MeP00gMGLeMgE`07LeP2MeP017MiLgUcNG=i0gMi
00EcNGMiMgUgNG=i01EgN@=gNPAgN@EgVPIkVP03MiYkVW^J00QkVPEkV@9k^@9kVP=kV`Ik^`9kV`]k
^`9k_003Nk]k_7^l00Qk_005Okak_7^lNkak^`09Nk`8Ok`4Om`2Ok`00goLOkeo_@0IOmd2Okd04Gon
OomooU4[405=[W<eMgQg5W]EOe=kE7/DMaEc5WLEOcH00Wmj01I^meH`CS59kdg_AJhdj2b7=>Hi9Uh[
Ng=gEFkaKaAkNGMkLeYgFWmKOgYo^P=oo`03J_Pm:4VZ00=B;`05BNa1RSU8<>DLP`02200934423480
1`a1444@@A11764THB1R008TPP05:88/XRbR<:8dX@02><000cc0>:4hX@03=8401c21;64`H321<60/
@2aP008XH@0::84/PBbQ;84XPBAQ:64/PC2R=:42=:801SC2;:4PPQA03008008<@0@@@003340@@110
00P@@00L460<H1100008046WJ/m=cBA6:6<XH2@PAHERJfJ8GTQRBV9[HVaVKFZ_K]1^[fZ@IY5g57nD
Ooh5Ool04gonOc9j;fD=G0IP16`0L21`H710J09T0V00F01LQ6F[OXeo/gom009oo`04OoioogooOolB
Ooh00gomOmeog@06Omd017onOmeogWoN2WoM00=ogWoMOmh00WoN17on00=ogGoNOmd027oM0WoN00Ao
gGoNOmiog@EogPMog@Aog1Aog@0BNmek_7^lNkakVg^JMiYgNW>KLgYcFFJc;@T00@@0340@@0a00`aQ
00D@PA1R344880a0008@H0X<@08@@00?464DHAAQ584DPaB45:@LaB3V6:<DPQ2258<DPQBS00<DP`06
6:<PiBD69@DLa1RS0QRT00HHXaBS5:<DXaBR5882584021R26:8HXaRR5:8DXA1Q56826:846:<011B3
468DPQRQ0QBR0QB300<@PQB158400QB200H@PAB26:8HXQB25642344246800a22588DPP0234400a1Q
468@PP0346802123488@HQB25:<DPQ1R36423403464248401Q22588@HQ1Q580@H@8@HP0>3448@0aQ
488HXaS3484<H@PP320<@11R364<@08@H@04468<HA1R468=46402PaR464@HA1Q340880a0360<H@aP
0PaQ0a1Q0PaQ00<<H0a134400Pa200<<HAB258800PaQ00<8@0a036400`aQ00D@HAB2588@PPaQ008<
@@06364<@0a0340<H11P1A1Q00@<H0PP220<H@@@H@06364<H11P460@HA1R10aR00D<HA1Q588DPQ1Q
004@@00000I[F6lhKcQ[>FliJeT4KeT5KeP3KeT2KcP00g<hLeQcF004LeP3LeT017=HMeQcF7MH1g=H
00AcNGMHMeQgN@=cN@]gN@03LgUgNGMi00mgN@=gNP=gN@MgVPAkVP05MiYkVW^JNiYgVP04NiX3Ni/0
0g^JMiYkVP04NiX00g^KNiYkV`03Ni/01G^kNkYk^g^KNk/00W^K2g^k3W^l00=k_G^lNk`02G^l0g^m
00=k_7nlOk`01Wnl00Aog7nlOmao_09o_AYog@0:OkeogGooOomE/0P1<@UZ/W<gKaD2KaH0;g<FL_Ib
mV[EIY=^eW<HL_MVLeG_BLi5kc5;;>L/QBb3;40`PTF9HTeZdUi^FRiJD5ibHWARLf9BIU1ZdgnjOo]o
oUiD<>M5Je8@CPi>D58]@L`a1S359:@<00P032001Pa10Pa20`a10Q1R00lDHQaQ844THBR2;88/XRb2
964`PCRP=:0hX3bP?<400SbQ00HhPCB1=64dPSRR=842=6001C1P=88`PRaQ;8400SBR0S2100dhXSR1
;60dH3bQ>:4h`c2Q768D@@`0320<@00444000a11340<@00334401110340@@1100a110Q1Q01P400P0
?FEZ[DV9:4D`YBQQ;615QF9/IVUNB699GTYRBfI]IXi^dFZ_J[1RT7<DOkD2Ooh03gooOmmoogooOeQf
2g36I0=/0700M01l07b0O41l0002L0001f`0J01P@5bVIS5kFGon009oo`iooP9ogP=ooP03OmiogGoM
00Mog@04OmiooWoNOmh=Omd:Omh6Omd3Omh3Omd5OmhQOmd01G_MNkak_7^lNi/00W^J00IgNG>LKg]_
>EYC9:H200023402344010aQ368<H@aQ0Pa100H<@11P460@@0`P2207340222003A1Q564DHAR16:<H
Y1RU8>LLaAB258<DPQB300<DX`03488<@A1Q008HX`036:8HXaRS008Ha0035:@DXaB3008DXP03588D
HAR2008HXP0:6:<H`aRS6:8DPAB26:<HXPb15:<26:<00aB3588DPP0358801AB3588DPQ2236400Q22
0aB200@DXaBR368@HP8@P`0346<@HQB300<DPP086:<Ha1RT58<@HQ1S48<@PP8DP`035:<DPQ2200<@
HP04464@PQ224842464010aQ468@HQ210Q1Q00/@HQB2588@HQB26:<DXa22468@H@`P008@H@03468@
HA1Q00<@HP8@PPH@H@8DH@8@H@04340@HA2248<246400`aP340<@002364248800a1R488@PP024880
1A1R364<@0a136400`aR00T@HPaR364<HQ1R364<@0aQ46401Q1R0`aR00@<@@a0344<H@8@H@07468@
HA1Q464<H0@0368010aQ0PaR0Q1R00T@H@aR368<HQ1R488<PPaR36400a1Q0A11000016]HKcMc=flh
0fli00A_>6liJeU_F0M_F@03LcQ_>7<h00IcF0=cF@UcF09gE`04LeQgF7MHMgT3LgT3MgT5LgTJMgT6
MiX2NgT3NiX00gNJNiYkVP07NiX5Ni/4NiX6Ni/01W^JNkYk^G^jNi]k^`9kVa1k^`Qk_09k_@]k_0=k
_@io_09og@9og1Mog@9og09oo`07HWL<0bb6IVmc=VlBJ]<00V[E0fZe00UZ]VjfK[EZLEg^DHa9[Cf=
=BT00Rc6024`a2bS844PHRC4:@La9c4X:>LTaRd7>DTmJD5YAH]>3Ei`EW=1KCCY>DaBLeZbEY5N/EH<
>FPdiBRT300800PP34002@a1014@@A1R468DHQaR840dH3R1?:0lXCbR?:50`T31A>14hDT10094h`05
@<=0Xcb2>88lP`02@:<01T2R?84lP3bR@:<lX`8lXP0>?:50XT2R?:4lP3bQ@:50`DCR@<4h`2B25408
00@@@08<@004344<@0a0344236402A10340@@110444<@@a0364@@00210005ce3JXe=J2aU<8@/HBQ0
@FENC6J:HTUNBEhYGTYRC6I]J]1Z[VJ?GVm^m7neOoh017oo00aofGi?J@]/9f`5M01h07`0O45lhWa0
N002M0001g@PL21X960UE8]je7og009oo`YooPIogP04OoiogWoNOmh:Omd3Omh=Omd4Omh4Omd00goN
Omeog@05Omd3OmhYOmd03GnlNkak_7^kNi]kVG]iMgUgW7=jJaU:4AaT008400@<@08<@@@<@0<@H003
340880a0008<@08@@08<@0<8800<488HPQB16:8HPaRT6:DLaQB4588@HAB211BS00PDP`a1320@HARS
68<DHARR0QRS00PDXaB35:<DXaBR6:8DPAR20QRS0QRR00XDXaBR588DXac36:4@PA22588HXP8DPP03
688DPQB2008DPP06568@HQAS46<@PQB20QBR00LHXaBS58<DPaBS5:@DX`0348<02QB258<HPaRS7<@L
iQB3468@PaB30Q230aB200<@Pa2246800Q1R00@@HA21484<H0@@H@<@HP03464DPA2200<DPP08488D
PQB2464@@1AP584DPP8@PP<@HP8@PP04468@HA1Q340246400aB16:8@H@0346402QB26:@DXa1Q460<
80aP364@H@aQ0Q1Q0Q220QBS00<@PPaQ34400PaQ00L<HPaQ368<HPa1340<H@0346400`aP464<H002
3443364336803@aQ344<H@aQ464<HA1R588DPAAP460<H11Q00<@HP04364<HPaR3482368010a2340<
HA1Q1@aQ0@aP0A1P0A11000016/hKcQ_>6lh1Fli2FmI0Vlh00=c>6mIKeT017=H0g=I2G=H0WMG0WMH
17=i00=cNW=iLgT01g=i0WMi0W=j00=gNWMiMgT04GMi1GNJ00EgNGNJNgUkNG^J00=gVP03NiYkVG^I
00MkVP9kV`EkVPMkV`9kVP04NkYk^g^KNk/2Ni/ANk/3Nk`01G^kNkak_7^lNkd037^l0g^m1gnl00=k
_GnlOk`00gnl0goM0Wnl00=og7oMOmd05GoM00aog7ooOomc?2AY:4=R:GMFLaA^dfkDK]D2K]H2K]D0
86ZDJU9QkUf]GO1NDUh^?FY1[UYdEU8iBRSW7:DPYAbT7:<LY1R3668HHb249:DXaRC5:@PaBRdZ=BY1
JG=HOod3OoT027nKEPliBBc6320800PP340934405Q11368<@AAR768XHD21B@AAATTVB>A=1E4VDBEA
8e43DB=EAEE6DBI=1Td50Td600==1Dd4C>@00Td400=<i4d5C@D00Td500==14d5C@D00Td500U<i4d4
CBEAA55WCBH`PaA232000Q111Pa100@<H0aQ364<H@8<@003364<@@a2008<@@0K348@HPPP2011R6Z?
DJ`/IRQT:64P@3e6EReRJUi8FRQJ:Uh[HT]VK6J>JZiRKeY>K_=oSWol00Aoo`05O/m]RfQ5L01d0`02
N0001G`0O45m1GaPO0000WP000Md07@PL29/8ea6JNioJ`02Ool;Ooh2Omh01GonOmiogWonOmh02WoM
1GoN3GoM0goN0goM00=ogWoMOmh02WoN:7oM00Ao_7^lNkak^`9kV`03NiYkN7MH009cNP05IaPmSQ0R
320<@@05340234400``P220<@0033402464010aQ360<H11010a000L<@@Q05:<U1R3U688HP`036:@0
11R3588881B30QBS00lDY1S55:<DPaAR688LXabR560HPABR6:8DPQRS6:@00QBS00<HXaRR6:800QRS
00@DXaB2588DPP<DX`@DXP07588@HAR28<@LXQAP56400QB200<PaART58<00aB200DDXQRT6<DHaART
00<DX`035<@DY1B3008DPP05468DPQB36:@DX`0358805A22468@PaAR488<HPa1564DPA22484@HA21
6:8DXQB2464@@@a1468@PP02588358<258802a22368<@@`P560@HA2258<@PQ1R46400a1R00<@HA22
46402Q1Q00<DXa2246400Q1P0Q1Q00X@H0aP220<HA225:<@PQ2S368<H@H<HP073448@@a1344@H11Q
48800PaQ00@<@@Q1344<H@D<HPD<H@06368<HA1R468DHAB10Q1Q00@<HA1R488DX`<@HP<@H@033408
00aQ00<<H@04368<H@aQ360134400003JcQ_>6lh00A_>003JcU_>6li00E_>@=_F@9_>004LcQ_FFmI
KeT?LeP00g=GMeMgE`02LeP3LgT00g=jLgUcN@08LgT017MiLgYcNWMj67Mi00=kNGNJNgT00W]i00=g
VW]iNgT01G^J00=gVW^JNiX00W^J00=kVg^JNiX017^J1G^K0W^J00=kVG^JNiX01g^K4g^k37^l00Ak
^gnkNk]o^`9k_09o_004Nkao_7nlOk`2Nk`00g^mOkao_@08Ok`00goLOmeog@0=Omd00goLOmeog@03
Omd3Om`02WonOomoWcc^901V1GLeLaI^/fkD0fkE00ibmFjcJU1MZeeZFHaN4FkfL]1=Re7?J]QV]Cf=
0SE:01@aBC5:<FXeJcV;?Je1cCF;=BXXYAaS68HHIAQS:<E9bGodOoioogom0Woo00McFT6^<@P<00@0
200<@008344030a0460<@@a1544LHBQ0?6591DdVB@E=1@9A1008D@=<hdcRE@=E95D4D@EI9@9IA@03
EBEA154U009A0`04D@AE95D3EB@2GB@00eTTEBAE1@02E@D03ETUFDEIAF5UGJU=BCbU52888A11320<
@@a200@<@@<<H@05344@@110364<@@0234800`aS368<@P02100033DXDS11CB@V<6DX@BA0>BIFCEXZ
FRQJ2@9J2P09GRYRJfI/IVeRKUi=K_5oc7og00=oo`05OeMj;fS6K21`0002M002N00017`0OBElPGP0
0W0000Yd07@PM41/86A3H>AjcGonOomog@UooPQogPYog@05OmiogGoMOmeogP0=Omd00goNOoiog@05
Omd5Omh^Omd017nlNkak^g^k0W^J00]kNGMhLcQcNW=hG]HeC@P0300<@@a0008@@0<<@008344<H@aP
340@@0a0440<H@@@H@03460<@0a0008<H006364@HQB36:@DXaRR1QR200<DHAB25:<01aBS00HHXQRQ
560DPAB2584658801ARS6:8HPARR6:<00aB300LHY1BS48<@PQB15:4DXP0258802AB36:8LXAB0584D
PQRS7<@HX`0258800aAQ584DPP0258826:<01ABS5:8H`QBR58<00Q2200<@HPa134400aB200H@HQB2
58<@H@Q0364246804@aR364DH1bQ580@P@a0464DPQRR5:8@H@Q0320@HAB26:<00QB30Q1R00L@HA1R
468<HPQ0320@H00246400`aQ464@H@0246400`aQ340@H@02488346402a1P340@HA1Q460<811Q468@
HA1P36000PaQ00/@PQ20340<H@aR464@H121488<H@a000T<@@05364@H11Q364<HP02364010a1364<
H@aR10aQ00<@H@a0344010aQ00<<@11Q46400a1Q00H<HA225:<H`aBS36824640111P584<H0a010aQ
00@@PPaQ340<@04<@@0000=[>6lhKcP00V/h0Vlh00A[>FliJcU_>@A_>0=_F@9_>@03KcQ_FFmI009_
FA1cF004MeQcF7=ILeT2LgT00g=jLgUcN@03LgT017=jLgUcNG=i0WMi0W=j00=gNWMiMgX00WMj1gMi
0gMj2WMi00=kNGNJMiX00gMj0W]i00=kVWNJMiX017NJ0W^J00EkVg^JNiYkVW^K00=kVPEkV`=kVPIk
V`03Nk]kVg^K00]k^`Mk_003Nk]k_7^l00ak_003Nk]o_7^l00=k_0=o_0=k_0Ik_@03Okeo_7nl009o
_003OmaogGoM00eog@03Omao_Gnm00Mog@0ROomogd4?601MaG<eK_A^/fkDK]E^e6kdK]=ZL6G]FBIE
B5E:FM5kFWLBDFPi:SU;>F`Y:RT9;@TaBSEZ>Ja63diACW<2AS4033f^::DXiRCX8:D@8B2SBN]on7og
MkEon`9oo@06KcMB<2cX300400PP2Pa100/<@0PP320<01PP600hH4dVC@9@hTbS009<X@9<`P0=D<9@
`Dc1C<5E0eT3E>9@hUCSFBAM95TSF@@0153S019I0edTG@AI0eSTF@AHi533E>=I0eU4HJQAJCQS3044
0@a13203348234400`a2364<H@0234400a10344<@@02348234<03`aS4640000068=5bcE:84@`8C11
:40i958]GRYJ:@02ENX04eG[FRYRBVJ=HVeNK5XZJ[1o/gokOoeoogmhLW=];6Q0K01d0700009d0005
L01l07dVO:9l0P04M0001g@PL41X@6BPKXmooWoo00AooP9ogPAooP9ogPEooP03OmiogGoM00Yog@Eo
gP]og@03OmiogGoM00Eog@MogR9og@03OmaogGoM00Iog@9o_005Nkak^g^kNiUkVP02MgX037MIMg]c
NUZF:>X400P0220<@0aQ464<H@8<@004344@HQ224683440244424640611R464<H@aP364<H0aQ468D
PaRS58<DPQR27:8HPQRS588HXQRS6:8HXaB3488DP`<DX`045:@DXaBR5:8658804QAR444@HABS7:<H
PAR2444@@QAR6:<LaAB3240@PQB16:4DXP8HX`8DX`036:8HPAB1008DPP0358<DPQAR00<DH@@@H@08
564DPQBR6:8DPQ1R364@PP<DP`<DPP0C48<@PQ1R468<@11Q468@PQ1R464DHAbR584DH@a0464@PQBR
48800PaQ00P<@1B2:BLLaAB2488@HQ110Q1R00<@HA1R4680111Q0Q1R0Q2200<@HPaR48800a22111Q
00@@@11Q364@H@8<8005360@H@aQ364<H00236401Q1Q340@HA22588DH08@H@033608@0a100P<@@8<
H@04464<H@aR368246824643364346401@aQ344@HA1Q48800Q1Q0Q1R111Q00@@PQBS488<HP8<@006
460<HA22468<HA1Q1@aQ0Pa00@a100000f/hKcM_=`0>KcP2KcT01FlhLcQcF7=HLcP04G=H00AcFG=H
LeUcF@QcN@03LgYcNG=i00IgN@EgNPIgN@=gNPegN@=gNP=kN@EgVPMkVP03Ni]kVW^J00=kVP=kV`=k
VP=kV`9k^`EkV`=k^`9kV`Ek^`Ak_004Nkek_7^lNk/4Nk`00g^kNkak_004Nk`00g^kNkak_005Nk`5
Ok`3Nk`2Ok`017nmNkek_Gnm17nl0goL0Wnm2goM00=og7nmOkd017oM0gnm0Woo01i=LA`0AB9Zlg;c
K[9^]6kDK]=ZdfkBIW5MZeT5D@MEJeWaMcQk4DdU;8DdicE:;BXTaaaT76<XY2d5<DL2<FT02c5:;BP/
ibRU9:@LYAB4668LXdh;Ni800W=C00Uk/gokOkMk^6JA;>P<0@0022800Pa100H<@Pa1344<@@`Q3442
340432002Q@090199g9=MZeZ36W^KNi]kFW]0VW/00EUbVW;IN]Uc6G;009Uc00<JLeUc6W<KRibD6h?
ILeUkVX`KW1Z<6W^0VG=00]UcV6<HF]Q[6G[JRa^CW8/B@P@0@P1008<808<@`03348<8@a100D<@@03
440<@@a100<<@P0334<<HPa00080000L?LeZl46[>BPliS1R:211AEH/GTUF2EH:CNU=jU7ZFRYVSFZ<
GPQN1fIZOe=o[Wo5OZUec6R5I242J0005W00M01h07P0L01l07dWO<5l0GP2N01d07P0M21`@720I81Q
jgomOomooWoN0Won00=ogWonOoh00gon0WoN1Gon0WoN2goM1GoN2goM00=ogWoMOmd01GoM0WoN00=o
gGoNOmh00goN2goM00=og7oMOmd03GoM1GoL00=ogGoLOmd01WoM00Aog7nlOk]k^`9k^P0=NkUkVGNK
Mg]gO7>LKeY><QaV100<00`P44400Q1Q00<<HA1Q36400PaQ0Pa100@<@110440@@0<@H@<<H@8<H006
340880a0488HXQB20QR200XHXARR588DPQ1Q5:<H`aRT58<DHP8DPP045:8DPQB258<2588011BS58<D
PaB31AB20aRR00LDPPa1448DHQR25:<DP`02464258402QB26:<HY1c56<@HXQR2584DPQB10QB20Q1Q
00LDPQAQ464@H@a1444@H@0458801a23468DPaRT68<DHQAQ008DPP04464<@A1R364246400a22464@
H@02464031AQ584DHA1P464@PQ1Q340@HA1R584DPP8HXP05588@PPa1444DHP0258801122468<HA1Q
0`aQ00<@HQ2348801Q1R00<@HA1P46000Q1000@@H0aQ364@@08@H@@<H@07360<H@a0340@HABR5840
0a1P0`aP00<<H@a1340010a000@<H@a1344<HP8<H@08344<HA1Q460DP11P340<H@<@H005364<@A1Q
464@PP0346402122464@@0a0440@HA22468246400``P360<@00236400a1Q484@H@03364234013601
36800003JcQ_=flg00a_>0=_>@03KcQc>7<h009c>004LeQc>6mIKeT7LeP00g=GLeQcF002LeP3LeT0
0g=HLeUcF@08LgT00g=jLgUcN@03LgT:MgT017MjLgYcNWMi0gMj3GMi0gMj0gNJ0WMj00=gVgNJNiX0
0W^J0gNJ0gNK1G^J3W^K1G^k0W^K17^k0W^K0g^l0W^m00=k_7^kNk`00W^l00=k^g^lNk`01G^l00=k
^g^lNk`01G^l0gnl1G^l0Wnl00=o_G^mNkd00gnm0Wnl00=og7oMOm`00Wnm2goM00=og7nmOkd00WoM
0WoN0Wnn00Yo_GooOomVMBP0=<AVe7LeK[9Z/`9^e@0IK_Ag=G<gIU5I9UTWEDQMk7<DM^i=0Sc5DDQ^
mWMKGS<mBbb5848PHaaS78@DHaQT78@00R1T018HHab48:DHQAbUCRigDg<cLcEk^7onOmYon6Zc<@T@
8`001042344234803@a1348<@Q116:<Ha11Q320@@1AQ520d@7k=009omP08OoYoVWmhOgMoMWmeOgMo
M@9oEP0:OgMoEGmfOeAo57kCOY1ndGmFOeP2OgX00gmIOgQoN003OeL04WmjOeYo>GmJOgMoUGokOdm]
Ib010008811R68@DYA13320@@@D<@@05440<@@a1344<@P02324040aR46400001OomomGolBLm1BcB3
;015I5i<GTYB:dWZ0dG:00]B2ei^GPaAZU68HJUbKg8]LHA`PF@0009X000<I01/0700M01h07`0N01l
07e6O<5h8W020gP000I`070PL:1XP5f9NgX2Ooh00goMOoiooP0=Ooh2Omh7Omd7Omh017oMOmiogWoN
1GoM1WoN17oM1GoN00AogGoNOmiogPaog@03OmaogGoM00Qog@03OmiogGoM00Aog@=og003Omeog7oM
00Iog@9o_00>Ok]k^g^jNkYk^G^IMi]gW7=KLgaW647@44D400<@H@03468DPa1R00<<H@05344<@0a0
340@@003460246401PaQ344<H@aQ360<@088800E464DPAAQ688Pa1RQ584@HA225<@M1R457<D@HQ11
464HPQR1588@HQ1Q008DPP086:<DPQBS5:<DXQRS5:8DPP8HXP0<6:<LiAcU6:@DY1RT6:<DY1B3468D
HaB30QB200@@HAB358<DP`8DPP07688DPAB17<@Ha12258<00QB200@DHAB2688HPP@DPP0<488@HQ1R
6:<La1RS588@HAB2688DPQAR0Q1R00D@PQ2358<<H@a0008@H@04340@HA1Q4847464011AQ684HXQBR
0QB200@DHQ1R588@P@8@HP8<H@04368<H@aR3687468246401QAQ440@@0a0460@H@8@HP0<364@HQ1R
48<@Ha1R464<H0a0460@HA1R111P00D<@0`P340<HQ1R00<<@@0C340<@A1Q368<@0aR468<HQ1Q320<
@11Q584@H11Q360@H11046000`a000<@HA225:<00QBS00<@PQ1Q32000P`P00<@H@aQ46400Q1Q10a0
00<<@@aP36400a1Q00@<H@aR364<H04<HP0000=[=flGKcL01Flh00=c=flhKcL016lh00A[>FlhKcQ_
=`9c=`Ac>0=_F@IcF003LeMcF7=H009cF0=cF@QcF003MeQcNG=i00McN@=gN@03LgUgNGMi00=gN@03
MgYcNW=j019gN@EgVP=gNPQgVP]kVPMkV`9kVP9kV`Ak^`=kV`=k^`AkV`Ak_11k^`Ak_0=o_005Nkao
_7nlOkak_002Ok`00gnmNkeo_003Nkd00gnlOmaog002Ok`2Okd6Omd6Ok`2Okd2Omd4Okh0>GnmOomo
ogLG;00/QF:dMeA^/VkDK_E^mW/DOo1ofFjdHFQMJ5f5ITUg4gK=B>599FJCOmioog^MGS=9SCe;=:Lh
YS25<:HhYSbV?:DhIC1U:4<THb249895[6:@LcQ_=gMjMgaoVgMIGPle:QAU00440@02344534802Q11
7<<U1AbR320@@1AQ640lP7o]0Woo00=ooWooOol087oo00]omgX]:2@000`P568LaB3V58<<811100<<
@@03440<@110008@@0<<@00N360@HA1Q0008A7ooOnmoceg_AF/hY2`0BF9FBe8ZAJM5Z468>BHi94g8
IRaIRDCU?45@PV2PH41P06@00VP000AT06P0K01`00=d0008L01l07eVO>9h8G@0N01d009`000:M41d
X6RPGFM_5gojOoiooGoMOod2Ooh00goNOoiooP08Ooh2Omh6Omd3Omh7Omd2Omh7Omd2OmhKOmd00goL
Omeog@0?Omd3Om`00goMOmaog002Om`5Omd02GnlOkYk^G^iNiQkUg^IMgYcO002Mg`01V/H>Hh<@`P0
464<H@8<HPD<H@05344<@0a0440<800244000a1P440@@00234401`aQ340<@11P3408811P008DP@0>
688Pa1c26:8DPQbS9@DQ1BDV7>DDXPa0220<H@8DP@8DH@DDPP8DP@0D5:8HXQB2688DPQRS7<@Ha1RS
7<DPiAcU6:@DPa1R34<@HaB458<@HP8DP`0346<@HQ1Q008DP@047<<Q1AcT6:826:<00aR2588HPP03
6:82588248801Pa1364DPARS7<<DPP8DP`046:<HPQAR5642588011RR58<@HPa10Q1Q0aB11a1Q00<<
@1106:000QRR0aB200`HXacU7>@DPQ1R344<@PaR364<@@aQ368346800a1Q468@HP034640111P440<
H11P1Q1Q0PaR00<<HA1Q46400Q1Q00@<H@a0340@@0@@H008484@H@aQ344<HA23464<H@<<HP05468@
PQ1Q464@@005464020a0460@@1AP484@H@a046054640111P340<@0a10PaQ00D@HA1P460<H0a100<<
@003320<@0aP008@H@04364<@@aP460136800003JcM_=Vlg00E_>0=_=`A_>004JcQ_>6lhKcL2LcL4
LcP6KeT3LeP00g=GLeQcF003LeP2LeT8LeP00gMHLgUcN@0<LgT7LgX;MgT3MgX3MgT5MiX017MiMgYg
NWMj1gNJ17^J00=kVgNKNi/00g^J00=gVW^JNi/00W^K00AkVW^KNi]kV`9kVP=kV`Yk^`03NkakVg^K
00Ak_0Uk^`]k_003Okak_7^l00=k_003Okak_7^l00=k_@04Nkak_G^mNkd3Ok`5Okd;Ok`2Okd4Omd2
Omh02WnmOomoogmG>68PAE9CMcE^m6kf0Vke00ek=7mdOiU^/f6ZILaUjfY]NcAbcdcRCFQcFP03Ool0
7WLkGQ9A[DTZC>M4YTC8B:ILaUBUE<I8YcR5;28D02@Q<<EJCgNKLcM[5f;gJcYVeehA?FdDQ`02100@
@@8<@@@<@P0:444@HQBS568@@111320<03APOmLVOol027lg<6H400`P46<PiQcV4682444334401110
444@@A100Q1Q00<<HA1Q46400PaQ01/00001Ooeom6WU><Hhj3R3<015@dgYAHI1QceW=BDe132Q@@AA
JDS6?0100500J01`07@0L0000W@00V`000e`07@0M01d0700K01l07eXOB=l@7P1L01d0002M2001W10
L:1X`5e5J]=oe0UooP03OmiooWon00EooP=ogPEog@=ogPMog@9ogPMog@03OmiogGoM02iog@Mog0=o
g@9o_00BOk]k^W^jNiUkV7^IMgY_FG=jMgYZmSE/22<400PP344<H@aR0`aQ0PaR0PaQ00H<@110320D
@1105602440234000`a1320<800246002a1Q460DPAB1688HXbT58<@HPR339>@00QRS00/HaAS4468@
PaBS8>DLa1R2588DXaB300LDPP04564@HAB25:846:<01AS46:@DPa1R56801aB30Q230PaQ00@@PQBR
5:<DX`8DXP<HY0046:<HXQR25882584031B2488@HPQ0484LXaRS488DXaS46:<DPP8DHP8DPP<DHP8@
HP03588DPAB1008DP@@@H@0G468@H@a1464HXQB1464@PQAR588HXac57>DHXa1R3448@A1S58<@HQ1Q
468@PP02468246401A22468@HQ1Q4680111Q00<DXa2246400a110Q1Q0Q220Q1Q00@<H0a0340<@0<@
H006464<H0a0240880Q11PaR111R111Q00/@HPaQ340@H110588@Pa1R364@H0aP008<@003364<H0a0
008<@08<@@8@H@06460DH@a03408@@a00PPP00P<HA1Q464@H@aP464<@11P0@b200000f/fKcI_=`0>
KcL01VlhKcM_=flgKcQc=`Ac>005KcQc>7<hKcQc>003LeL017=HLeMcEg=G2G=H00AgEg=HLeQcF0ac
N@9gN@AgNPegN@=gNPUgN@=gNPAgVP=kN@AgVP9gV`05Ni]kVW^JNiYkV`05NiX3Ni/3NiX3Ni/5Nk/0
0g^KNk]k^`02Nk/3Ni/<Nk/@Nk`6Ok`01G^lOkao_7nlNk`00Wnl00=k_7nmOkd00Wnm00=k_GnlOk`0
2Wnl00Aog7oMOmeog@=og00HOmeooWooOmI<iA@4CO5c=7LfLaIbmGKcMa=g4FlDJY1UkF7>JS1^TGKc
JVe8hTV917oo01io_fIdBDUE:5SUC:E4QDQ5F4=PPfBSJ@IDiTAS>20`0435IY=oogolMcIc>G^NOgiZ
]d6^68P00@@04406344434803Q12328<00@0601b/GooOemo?7lfOeMo=WleOeH2OeP02GmIOgYoVgoM
Ooio_7nKOkaooP02Omd2Ooh4Omh5Ool2Oml4Ool01GZE=8H400`P36800Q1R00D@HA11364<H@a1008<
@0<<@@04464<HA11444234003A1Q000003f:FRXdXS1S><Dd@C0P@@59QdF6008m9@0:=<4T@2a0@650
@c`0=01405`0K005M0000g00K01/0003M0001WP0L01h07e5OB=l@09h009d0007M21`86QPI<1M0Uh[
Olh00Wom0goM0goN00=ogGoNOmh01GoN00AooWoNOmiogPIog@03OmiogGoM01Eog@9ogPEog@03Omao
gGoM00iog@03OmaogGoM009ogAQog003Okak_7nj009k^P0CNiUkV7]hMgQgF7=HKcIRTRT910840@PQ
240@H0aQ348<HPa032001Pa00Q1P00@@@0a0360<H@8<@@888007340<H11P460DP1R168800QRR0QRS
00@LXaRR6:<DHP8DPP8HX`096<@U1BD58<@HPQB25:<DXQB2008@@@0=588HXaRR588@@@a0588HXQB2
464HXQBT58<00Pa100@DHQB26:8DXP8DP`06588DPaB3588@HQ1Q0PQ000<<HAB258800QB200TDPaR2
7:<HXaB2440DP1B158800Q2200D<HA1Q588HXQBR00@DPP8DHPDDPP<@HP03584DPQR100@@H@8@HP8@
H@08564@HA1Q464@PQ1R564@HP<@PP03464<@11R008@HP04568DPQB258434640211R58<@PQ1R368<
HA1Q46854643340020aQ464@PA22484@HA1P34023202460346400`a0240<@@0336400`Q1348<HP03
46800`aR468@H@024600111Q468<HPa10Q1Q00D@H0a0340<H@aP00@<@003360<@0a0008<@008440<
HA1Q464@H0a02208@@8<@004440@HA1Q464346014401460136800003JcM_=flg00i_=`03KcQ_=flh
009_>0Qc>003LcMc>7=G00AcF09cE`03LeQcEg=H00EcF09gE`03MeQcF7=H00=cF0UcN@9gN@04MgYg
NgMiMgT2MeT00gMhMgUgN@08MgT3MgX9MgT3MgX4MiX00g^JNgUkN@04MiX3Mi/2MiX00g^KMi]kV`04
NiX5Ni/00g^JNi]kV`02Ni/4Nk/3Nk`00g^KNk]k^`0>Nk/3Nk`00g^kNkak_00:Nk`6Ok`017^lOkao
_7nl0W^l1g^m1gnl00=og7nlOk`00gnl0goM0gnl00eogGonOomonUV>50I1KFkbLcM^mWLENaEfm002
M_800g;BK[=ZLP02KY8017:cITm51DV/1Goo01iVETT9B<IDY5RSD49L@f@PI41`P7T2NB=`hFbPG:=M
17;dOomooGmeNiaooWooNia1d1RY004400a0344234800`a1348<@P033480411244<@@a0P100805VZ
Oga^^FYCKRmZ3VH=JPaZ2fG/0VGZ00YUbV7:HN]V3FX<HNaMk6H<KTi^L09bK`03KTiZ;Vi?009bL09^
TP0>L[Eb]W:fL[Mfmg/fOkik>ee[80<400P024488@8<@@8<H@03344<@0aQ008<H@<<HP04364@@A11
4682340200003BA1?>@m1cRT?:DlPcQ0?<4m1Cd4=<<`XRA0008L0008=0148400@01@06@0L01h00Ad
0004L01X0700L002M00027P0M01d07cYO>=hA7P1N002M0002G@PL41XH62PH@5IXgm`Ooioo@03Omd2
Omh3Omd2Omh00gonOmiogP02Ooh6Omh2Omd3Omh2Omd2Omh6Omd2OmhQOmd2Om`6Omd?Om`5Omd2Om`0
1GnlNk]k^W^kNkX00W^J00akNGMhOgMkN6lEERlLQP01104880a146433640111P320<@0a10`a00`aP
0Pa000<<H@aR36400Pa100<880a046000Q1P00THXAB1588DXQRR6:<DXaRS7<<00QRS01/DHAB258<D
XaS47<<HXaRR788DXa226<@DXa1P440D@AR26:8HPQ1Q588HY1RS588HXQRS5:@00aB300XDHQB25:8H
a1S56:@DPaAR468DP`8DH@8@H@0=584DXQBR588@HAB2688HXQc4568<@1R258800a2200<@HAB15880
0QB200T@PA22588DPQ1R588P`abS68<00QB300<@Pa2246800Q1Q0Q2200<@PA2248400Q1R00@@HA1P
464<@0D@H@06468@PQ22488@HQ110a1R00@DHARR6<@@PP<@H@04588@HPaR36423682364246400a1P
464@H@0536401Pb1488DXQ22464<H08@@0D@H@8@HPD<HP03344<HPaR008<HP8@HP05364<@0a0480@
PP023442464234000`PP240<H0033602588346402@aQ340<@111468@H0`P1008@@0236801A1R588@
H0aQ48000Q1P0A100A1P0@aQ00000f/gKcM_=`0;KcL00flfKcM_=`04KcL7KcP2LcP00g<gLeMcE`03
LeP7LeL5LeP3MeL5LeP4LgT2MeP00gMiLgUgN@05MgT017MIMgUgN7Mi0WMh5WMi00AkNGNJMiYgVP9k
N@03NiYgVWNJ00QgVP03Mi]gVWNJ00EkVP=kV`EkVPMkV`Ik^`9kV`ak^`04NkYk^g^lNk/9Nk`<Ok`4
Nk`3Nkd2Nk`3Ok`2Om`9Ok`2Om`2Ok`037oLOomoo68d50Pm:fk?LaEZeFkfMaEk5P=o=@08OaEfe6jc
L]AfeFX`CDQ=cPEoo`0;JUM8b426G@IP`f2TI8ET@Vb1M<1lhP02OB<03gdWL>aY9Wk^Oo]oo7nfOmio
ogonOk]9lQbY10840005344634802@a344<<80P0501EkGMlJ]UV]`02IY@01fZBIW9VLFJBJY5ZTVZA
009ZTP04JY=ZTVJCKY82K[<04fJdIYAZU6jcL[=bdg;EL]A^eFZeJ]E^eFkFJ]IVeG<GKcYRECRX0084
0004340<HPa2348234400a10340@@0024602364010a1348@HQ110Pa201D<8110100802b3>8Hlid3U
@>HlY3b2>84dPRQ0940X@2@P700X03`PA0000TP000AH06P0M01h00Ad0004L01T06`0L003M002L000
0g`YO45l0002N003M000270PK61TX6DQFH9g<7onOol2Omd2Omh4Omd5Omh2Ooh00goMOmiogP03Omh2
Omd3Omh2Omd2OmhIOmd01goLOmeogGoMOmaogGoL00Uog@03OmaogGoM00=ogA5og09og@Aog006Om]o
^g^kNkYk^g^K0W^J00]gVW]hNeMgEfkdBNd@H`00100<80aQ00<@H@05460DP0`P320<@00222000`a0
360<H003340010aQ488<H0aP0Pa001@@@11Q460<@1AQ684HXQBQ6:8HXaRR584HXQc46:8DHA11468@
HA1R0QRS00/HPQR1688DXQcT9@HPi1RR564D@AR2008HX`<DX`8HX`035:<HaABT00<DP`8DPP035:8D
XaBR008DPP8<@@03464DHAB1008DP@8HXP045:8DPAB168826:<00aB3564@HP0258800a22584@H@02
46400aB26:<DXP0458801aR18>8P`aB2468<@A1R00<@H@8<@@03464DP11Q008DH@07588LXaAQ200<
@11Q4840111Q1A1R00P@H@aQ364@HAB1488@H@a00Q1Q00DDPA1R468<@@aQ00D@H@03460<@0a0008@
H@<<H@07464<PA22488@HA1P44400Q1Q00<@PQ1Q46400a1Q0a1R00<@PQ1R46800PaQ00<<@@a23680
0PaQ00P<@110580DX`aR220@H1112Q1Q0QB200H@HQ1Q468@HPa12202440336401Q22464@HA1Q484@
H0<@@04@H04<H@0000=[>6/gJcL00V/g46lg16lh0W<h0Vlh00=c>7=GLeP017=H1G=G27=H0W=G0WMG
00=gF7=HLeP00g=H00AcNGMHMeQgN@=cN@03MeQcFGMi00EgN@9gF003MgQgNGMi00=gNQ1gN@05NgUg
VWNJMiYgV@0:MiX3Mi/3MiX4NiX3Ni/5NiX7Ni/01W^jNk]k^g^lNi]k_09kV`ak^`03NkYk^g^l00]k
_0Eo_003Nkao_7nl00=o_0Ak_0=k_@=k_0ao_00@OkeogGoMOkeo_7oMOoioo6[H94XdYfZ;K]=ZeFkE
LaH2K_L02g<hOgUoF7KgM]Ajlg[eHNm91df]Om/00goo01=ogf7DB8I4YeT8J@I/iW36M<QhagS6N:=h
XGbQO:Adk7EXMVaod005Ool01W]j?HhPY``R100<@@@<@P03368<@`a200<<@P0<34<@@``P200PH6l<
Oomk_G=jMgYkNgMI0Vkg00=cFG]INgX00WMj00AkVWnLOkeo_P9o_@0:Oi]kNW]INgYoVWnKOiakW7nL
Oid2Ne/027]JMcYkG7nKOkUooW<G<8H210000aAQ444<@P0334401110344@@A110Q1Q111R00l@H@aR
468<@@a0200<02b2A@M51T3S@>DlYCaS>6400RPP00L`82`P:00T02`0@0180002C00015`0K01`07P0
17@000A`06P0K01`00=d0007L01X07P3O01h07@0N00017@000QX86c0JD=IXflAOoioogon0WoN1GoM
1goN00=ogGoNOmd017oM27oN5WoM0WoN1GoM00=og7oMOm`047oM1WoL1goM00=og7oMOmd00WoM0goL
00AofgnkNk]k^`9k^P9kV`0>Mg]gNW^INeQcEf[C?J/88@00200<@0aQ464<H@8<@003460@@0`P00@<
@003364<H0a000D<@00?364<@0`P440<@0`P464DHAR26:8@H1RS7<@HXaB1008HXP04688DHAB358<2
58800aR26:<LX`0268801ARS8>DU1R3U8<@00QbS00HPa2D56:<DXQB25:826:<01QBS5:@DXaBT5:<D
P`<DPP8DXP055:<DPQB258<DPP0558402QB25:8HXaRS5:8DPQB3588DHQ1R0a2200DDPA22464@PQB1
008DPP0;488DPQ22444DPAc27<<@H@PP444@H@0246801A1Q468@HQ2258400aAQ00PHXb3U7:8@@1AQ
588HXa220Q1Q00<@HQ2248800a1R00T@PQ23488DHAB1464<@0P046000a1Q00@@HQ1Q464@HP8@H@09
460@HA1Q440<80aQ488<H@aP008@H@03388@PPaR008<@08@H@03468DPaB200L@H@06488DPQB2468@
H@aQ0`aR00L<H@a1440DPA2S3688800234000a1Q588@H@0246400`aP464@H@0246405`aP488@PQ23
58<<HPaQ100@H1AR464<@11Q468<H@aP464DPQAP420<@0aP46000A1100000f/hKcM_=P03JcL>KcL0
0g<gKcMc=`04LcL2LcP00flhLeM_F004LeP5LeL7LeP4LeL00gMGLeQcF003LeP2LgT3MeP3LgT2MgT3
MgP00gMiMgQgN003MgP4MgT00gMjMgUgN@0>MgT01G]iMiYgVWNJMiT00W^I2gNJ0WNI0g^I2W^J1g^K
00=k^G^JNi/00W^K00=k_7^KNk/01W^k0W^K17^k00=k^W^kNk/00g^k1G^l27nl00Ik_7nlOkao^g^l
Ok`9Nk`6Ok`00gnkNkao_004Ok`2Nkd3Okd02GoMOoiooGmK?<h/8VHVK_=Z]002K]D03V[FJ[IZUGKf
OaI^TfX^N_1b/UU]B>IERfk@Ood2Ool02GnMHG5@I5ASK<=e0g31M<=haP02N:D02WR3N65dHWQTM:UX
PfW:Oi1on7ok0Woo00Uo^eYA<BTPYPa232480@a234400Q1R00D<HPa2348<@@a2008<@`0844<<80P0
<<1ojWolOomoo09ooP04OmikW7nLOmh5Ooh7Ool2Ood00golOomoo`08Ool01golOoioogok?@P80P@0
00<@@@03344<@0aQ00<@@@03344@HA1R00<@HPD@H@0=440<@100;6591TT5A>90iD2U?6<hHR`09000
0RP000@/03@P>018009<0003D01P06`000=d009h0005M01`06@0K01`0002M002L0001W@0M4Qh0f`1
K01`00=d0008L01X06R0JB9IQ6[?Ooeoo`9ooPAog@=ogQ5og@=ogQMog@EogP9og@=og0eog@03Omao
gGoM00Iog0Mog@03OmaogGoM009og@=og003Om]o^gnk00=k^P09Ni]gVgMkMg]kNGMHLcMRTC4X0088
0008444@H11P464@HPa2344<808@@0<<@004360<H@aQ3607340322001Pa1588HXQR26:8DP@<HXP08
584HPQRR688DHARR7<@H``@HX`04688DHQAQ6:836:<02QbS9@DU1B3T6:<DPQ1Q340HXARS0QRT00@H
XaB2588DX`8DPP8DP@03588HXQB200<DPP05584DHAAQ584@H@0348801QB25:8DPQ22588HY08DPP0:
464<HA1Q468DPQ1R484@PQB136025842588011B1588@HPa10Q1Q00<@HQ2246400a22014DPQAQ564@
HAB16:<HXQB1588HXaR2484DHA1Q564HXaB2008@HP07488@HQ1R468DHAB146400PPP00T@H11Q464@
HA1R464HPQRR46401A1P0PaP0PaQ0a1Q00D<H@Q0220880a100D@H@09564@H@aQ464@H11Q588@PA1Q
008<H@<@H@07364<@0a1464@H11Q48800Q1Q00D<@0`P564HXaB2008@H@03340<H11Q00D@H@09468<
H@aQ364<H11P464<H@Q0008@H@09340880aP460DH0`P220@HAAP004@H@0000=[=flgKcL00f/g1Flg
0flh3Flg0Vlh16mH1G=H0W<h00=cEg=HLeP017=H0W<h0W=G0g=H0W=I0g=H2G=i00AgNGMhMeQcN@Mg
N@=gNQ1gN@05NgUgVWMiMiYgV@02NiT8MiX00gNKMiYgVP02MiX2MiT017^INiYkVW^K1g^J1g^K00=k
^G^JNiX00W^K00=k_7^kNk/01W^k0W^K17^k00=k^W^kNk/017^k0W^l00Ak^g^lOkao_19k_0=o_09k
_0Ao_003Ok]k_7nk00Ao_0=k_@9o_@08NkeooWonOiiA4BP0HJA^l`=^e00DJ[EZMFHBJQ9^4V6`JRmf
cg:BFBeA1eeXIR]olGooOoQk66E?G6=L009/@00OK61`H720M81dPGAPL61dHGAVN4E`@6CSD@AZ[flD
J]5ZmEicALdeBB3646<<8A1S58<DPQ22468<@@PQ344010a2014@@PP0300PP6;aLo]WMV;eG]EVmf/i
IaU[66/hKeUgVgNJ009gV`05MkagW7=JKcYcFP02Mi`2Mi/017MkMgacNg>L0g^m00Uo_G^mOmeo_G^l
Mk]oog=I;>L00PP100<@@@a144400Pa100D<HA1Q4448@0a000<<@@04464<H@aR468346403110344@
02aQB>A91DCSA@I0YD1T?44h808X008`0003>01004P0009<0003E01T070000=d0004N01d07@0L002
I0002FP0M01h07@0N01l8Ge:O@=h9@03L003M0001V`0J61Y8UEUHVaon`9oo`9ogP03OmeogWoM00=o
gQ5og@=ogPQog@03OmaogGoM00aog@03OmiogGoN01Qog@Eog0]og@04OmaogGoMOm`2Ok/01GnjNkYk
^W^kNiX00gMj00MgF7=HLcIJCbC5100<800646400`a1340<H00246423400111P364<H@aP1Pa000H@
H0aQ340<@1225:<27<@05QRS688DPAB25:8DPAc38<<HPQ10588DXaBR5:<HXb3U6:<DPQ10320@H1B2
0QRS00THXQRS6:<HXaB2584DPQBR6<<00ac400THXaAQ588DXaB35:<DPQB146400QB20QB100DDPQbR
584DPA1Q008@PP04468@PQ22488246803Q2258<DPQB2488@HQ22468DPQ22464@PQB14642564011B2
5:<Ha1B21Q1R00D@PQ1R488@PaB2008DH@@@HP<@PP04464@@11Q4642564011B26:<HXQB2111Q00<D
PA1Q4680111Q00<@PQAR46800Q1R0a1Q00<@H0aP36000`aP00@<HA1Q364@H@8<H@05340@HA1R6:8@
H@02340246401@aP240<H@aQ36000Q1Q00D<H@aP364@H@aQ00<@H@8@HP0;464@H0b25:<@HQ1Q460D
H1S36:8DH@0246400a22468@H@0246400`aQ340<H0023643464010aQ368<H@aQ0Q1Q00P<H@a1460D
P0aP240@PAB10A1Q000016/gKaI[5V/f0V/g0flg00=_>6/hJcL02flg00A_>6lgKcM_=`9_>0=_F0Ac
F005LeMc>7<hLeQcE`06LeP01g<hMeMcEg<gLeQcEg=H009cF@IcF09cN@MgF005LgUgNGMiMgMgN@02
MgP4MgT3MgP5MgT01GMhMgUgNGMiNgP01gMi00QgV7^HNiQkVGNIMgYgVWNK0gNJ00=gVgNJMiT017NI
17^I1W^J00=kVG^JNi/017^K00IkVW^iNkUk^G^JNkX5Ni/2Nk/00g^JNi]kV`02Ni/2Nk/2NkX00g^k
NkYk^`05Nk/7Nk`3Nk/5Nk`00g^kNkak_009Nk`3Ok`00g^lOk]o^`03Ok/4Ok`2Nkd0:7nmOmeog7on
OkiI/RP0DB9^/7;cL]9bdfYcIK1Ljec:H<YDZ5d4O^afeED^EBUIJEg;IW1Z/g:aJS1Y2EPPF01`HFa0
J41X86a0L61dP71P0W1001YdA7PSM21P`e5ZFNaN;F9]HW9A/3e:=BH]9aR4448HY2D69@DHa1BS58<@
@@`P340<HA1P0a100PP000@<@A2T468<@@8<@P09368<@Q1R468DHQB26:8La1bS008DH`0456@DHaAS
68@37<H04QRU7:HLaQRU7<DTibCV:>H]9c59;BPU1be::D`Tj@`R10088@8@@P8<@@08444@H11P460<
@11Q588DXP8DX`0658<@HPa1444@HA100Pa000X<02aPB>9914CSA@I4a4AS@44h808/008`0003=010
04@0009<0003E01T070000Id0005L01X0600K01d0002N0001W`0O49mIGdUO89l009d009h0009M01`
06aPKB5IQUX[NiMooGon00=og@05OmiogGoMOmeogP0:Omd3Om`4Omd3Omh7Omd2Om`COmd00goLOmeo
g@08Omd2Om`8Omd:Om`3Omd5Om`01GoMOkao_7nkNk/00W^j00ek^G^jNiUgVWMjMgQkF7MHMcEJ;RBT
100<@00256400aB2464<@0034402460020aQ460@H11P484@H0a0460434000a10580DP00246401AB2
6<@Li23U7<@00QRR0QB200`HXQc36:8HP@`P340DPQRR6<<L`QbR6:8358846:<3584031BS588DHABR
6:<H`acT8@DPiABS440DPP8@P`04488@HA114642588011B16:4HXQRQ0QB100`@HQ22588DPQ1R368@
HPaQ344@HA22584358801122468@PQ221Q1Q00LDPQBS6<<DXa22468<HP0346801A21364<@@a14640
0QAQ00<@H@a136400Pa10Q2200D@HQ10340<811P008@H@03484DPAB200@@H@0:588HPQAQ464DH11Q
564DPQAR46834643460236000`aQ360@H00248434640211P464DPQc38><DPA1Q340244000``P120<
800246000`aP340<@00336402@aP464@HARR5:<DPQ10464@HP0258800a1Q460DH@0258400aAQ464@
H@024680311Q488DPAB1464<H0PP340@H1B2484<H@<<HP05364@HA22364<@00646400005JcI_5V/F
JcI[=`06KcL00flhKcM_=`05KcL4JcP4KcP2KeT4KeP2KeT2LeP01G<hLeQcF7=HLeT00fmI00AcFG=H
LcQc>09cE`=cF09cF@05LeQcFG=ILeUcF003LgT00gMiMeQgF004MeP5LgTGMgT2MgX017MiMiUgVGNI
0WNJ00=gNWNJMiX02GNJ00AgVGNJNiYkV@IkVP04Ni]kVW^KNiX3Ni/5NiX2Ni/3Nk/2Ni/00g^kNi]k
VP03Nk/00g^KNk]k^`08Nk/00g^lNk]k_00KNk`00g^mNkak_003Ok/2Ok`3Nkd01WnlNkek_G^mOmek
_09oo`0oJUD/0432HTiflW;BM]A^Dff?H8=PQFB5H8=Xh7k8M[A=;EE<HNeE[E5/EDUMAFEZK@=L05P0
K69`HG1PM61d@7APM8=dHWAQM45h0G`RN41Y:EF]GRiVKG;_IViR;TEY?DL]:1bT7:DPaRD7:BLU9b3V
6:@DPa1R448<@Q11008@H@0444440000100W00000`PP36<<H`0334401Q11440@@11P588Li@8U9`04
8@LU:2476:@346803A12348880`0;65=94CSA>E91dS5A690@3PP008/0005<20`03P0@0140002C000
0e@0J01`0006M0001700J01X07000gP000Ml07`QO89lPWaRO25l0004N0001W00L61]85g7DNUcN09o
oP=og@05OmiogGoMOmeogP0>Omd00goLOmeog@0;Omd3Om`AOmd7Om`3Omd3Om`7Omd3Om`5Omd;Om`4
Nk`3Nk/2NkX2NiT02GMhMeMkEgMHLaA9cAaR100<@00246401`aQ340880a0444DHA1Q008@H00A440@
H11P5:8@H@a0360<@0aQ468@HA10560HPAAQ488DP`028>D011S45:8DPQBR0QB201XHXac36<<DPQAQ
58<L`b3S6:8HXA10340DXQc58@HPi2459@DL`aRS460HXQBS588@PQB20aBS00PH`aBR588DPQBR48<<
HQ1R0QB200@HXaBS5:<HX`8H``03584DPQB2008@PP0358<HXaB200@@PPDDPP035:<DXQAQ008@PP03
484@HA1Q008@H@03584DPQ2200<@PP<@HPH@H@8@HP03464@PQ1Q00@@HP065:<HXaAQ460<@11P0`aQ
00<@PA1Q46400Q1Q00@@HQ1Q464@@08@H@8DPP03564@HA1Q008@H@8@H003360<H@aQ00<<H@04460@
PA21488246401Q1P464@PQcT7><DPP8@H@0:460@@111100<@1AQ464<H@a0240336802@aQ464@HA1Q
488@HP`P464<H@02464234001A1Q468@HA1Q3400111Q00PDPQRR484@H@aQ464@@11Q112200@<PPaQ
364@H@<<H@05464<PA1Q464@H00144400004JcI_5FlEJaH6KcH9KcL2KcP2JcP4KcP2KcT4KcP3KeT2
LcP3LeP01G=ILcU_FFmILeT02g=H0g=I0W=H0W=i0gMi17MH00=cNGMHMeP00WMi17Mh17Mi00=gVGMi
MgP037Mi0gMj1WMi3GNJ00=kVg^JNiX027^J0g^I00=kVW^INiX017^K1G^k0g^K17^k0W^K17^k00=k
^W^kNk/017^k6W^l00=k_G^lNk`00W^l1Gnl0g^m0gnl0g^m0Woo01mfn300<69Ik7;@L[9fe79cKFaP
HV1TI69LPfTROXAbLDd^FHmV;eGaA@/d@dc5LLea8E`0H01/@G10L61dH002N60017B4N4=d@gPP0g`0
00m]:5W_GRiRSW<@L_5RBdg9?FPaAbcU78@LaR3V9>D00ac500DHQ11S448<@Q1100@<@@03320800P0
00D40008220<80a1588DP`a1100000@40003120400@000<00006100@@1S458@<8@@00P000P@00P00
0P@00PPP0`a100T@@@a1340@@11P564HXbD6;BH00RD701@Q1bD78>HHY1B346<@@Pa2324@831QC@=4
`dT7BBQ8iTB1A40h83000S@P00<`03P0@0000TP000I<05@0J01`07@0L002M002N00017@0J01`07@0
0g`000Ad0700M01d80=l8@9h009d009/0007KB1Madg7LgQooGonOmh057oM0WoL1goM00=og7oMOmd0
0WoM1GoL1goM8GoL17oM37oL00Ao_7^lNkak_09k^`0=NkUkVG^HNgMgMGLfMeMc=V[B?DT<0@@03400
0Q1P00<<H0a032000Pa000<@@11P46000Q1P00@DPA1P360<@0<<@@05340<H@aP340@H00246401`a1
468DPQBR588@PA1R008DPP0:688HXac46<@DPaR26:<L`ac26:4346401ABR6:<La23T7<<00RT500DL
XaB16:8HY1BS00@DPP8@H@8DPP075:8DPQ2246<@Pa2258800QRS00HDXQB25:<HXaRR588248<65884
48800aBR6:<DXP025840411Q488DPQ22464@PA1Q588L`aB2488@Pa22588@PQ1Q0Pa000@@HAB1584D
P@<@HP0;488DPQB2484DPA1Q468DXac3588@H@0246001A10460@PA2146400PaQ0Q1Q00@@H0`P220@
@0P@H@03460@@0a000<<H@05464@H11P460@P@0246401Pa0460@H11Q484HP@<@H@0;460@@0a0340@
H11Q584@PPaQ24088@0224400`a0460@@002444010a2340@H@aQ0Pa00PaQ0Q110Pa0111Q00<DHA21
6:800Q1Q00<<HPaQ4640111Q00<@PA2236400`aQ00D@H@aQ488DXa22008@H@4<@@0000=[=VlEKaD0
0f/F00=_5VlfKcH00flg00=_=VlgKcL016lg3Vlh16mI0g=H00=c>6liKcT00VmI17=H0g=I1G=H0g=I
0g=H0g=i00=cF7=iLgT00g=i0WMH0WMi0gMh00=gF7MiMgT01WMi00AgN7MiMgQgN0=gN@9gVP05MgYg
NGMjMgYgV`05MgT3MgX8MiX017^JMiYgVW^K2W^J0g^I00=kVW^INiX017^K37^k0g^K0g^k00=k^W^k
Nk/017^k77^l00Ak_G^lNkak_09o_0Ek_@=o_0=k_@0KNmmoogmIB88X95F/L]5fmG:dKS9]2VARI4=X
@Eb3JDIjQfX?CBaId6IAGUEE:cP0HBAjD7U5009P0004K21/@71PM802M603M6@04W@SO01h07P0J>AI
cEX^GXm_4W<dHXiAjceY>DTa1R239<DPa@<La@036:DDQ11S008<@Ph<@@05448@HAc448<<@P043440
10aQ344<@@a00`a100T@HA10460Q1bTX56<@@@`044400PaQ00<<@@a034401`a10a1001/DH1B18<@P
a23U7<@LiAcV8>DLY1RT58<@Ha1R46480100;658hTS3BBMAJdSVB89<P3`P=0000c@P00Lh04@0A018
04`0F01X0002M002N0000g`0O49l8@02L0001f`0N01l8G`QM01`06`0009`0003N21l@W`Q00Ad0009
L01/06d0GLQ=b6mHOo]oogoN00Qog@=ogPYog@03OmaogGoM00Eog@=og0Eog@=og0Eog@03OmaogGoL
00Qog003Omeog7oM01Eog0Aog@]og09o_0Ak_09kVP08NiUgMg]eNgIgN7<gIY4e1`840006440@HA1P
364@H0`P10a000D<@A1P560DH11P0088@0@<@@<<@006240<HA1Q3448@11R0QB200h@PQ1Q444DPQR2
7<@HXa23468DPQRS7<<H`aRS0QBS00DDXQ1Q588HXabS008L``038>@HXQB2008DPP8DP`@DPP05340@
HAB2588@P@0348801A2S5:@DPQ2258<01AB200<@HAB358801QB200<<HA2248800QB20Q220a2100X@
PQ1Q488@H@a0464La121464@HP8DPP8HX`04564@HA1Q584246401122588DPQB20QRR00@DXQB1468@
HP8@PP08468@HA1Q440D@1R18<<DP@8<H005364@H@aP220<@002464010aP464@HQ1R0a1Q00@@HQ1Q
344<@0@<H@8@H0@@H@03360@H11P00<@H@04340880a0460546401ARS5:@<HPaR34400PQ100@480a0
440@@08@@@<@H@04364@HA1Q364222001@a1464@HAB246800Q1Q00PDPQR2464@H@aR340<HAB20Q1Q
0Q1R00@<HQ22464@H@8<H@04468@PQ224682464134800003JaE_5F/E009[5@03JaI_5VlF00=_5P04
KaM_=VlfKcH8KcL7KcP00flgKcQ_>002KcP00fmILcQc>003LcP00flhKcU_F@02LcP017=GLeQcF7=I
0VmI17=H00AcN7=HLeUcF@QcF0AcN@AgF0=gN09gN@=cN@03MgUgN7Mg009gM`=gN0=gN@03MiYgVGMi
00=gN@03MgYgNGMi00=gN@=gNPQgVP06MgUgVG^HNiUkVWNJ1g^J00AkVG^HNiQkV09kV@04NiYkVG^J
NiX3Ni/:Nk/3Ni/00g^kNiYkVP04NkT3NkX2Nk/5Nk`3Nk/5Nk`00g^kNkak_00:Nk`00g^mNkak_002
Nk`017nlNkek_G^m17^l025o_7^mNkek_WoOOomoo5D/70AAJgKAMaIb]6WaJ@UTHVR4J69LYFf[NXUY
c54[GLmVLV:GEDa0@FE5OW5e@e`0I0000W1000Q`H7RPM81hH7B3M49d@G@00WP001E`06BQFHYN2f:?
Ka5_4f:_EPdeBC4X:<@H@A0Q56<HPaAS46<DHaAR44800Pa20Pa10`a00`a10P`Q1@a100L<@111368<
@Pa1340<@@0534000`a1340<@00244001Q1Q468@HA11320<008<80L<@0@<@@0?340@H11P560@H1AP
884PP1AQ544DHQaQ568<8@`P008@H@0<46040100<654`TS3CBQARdcWB654@3P00S0000T`82`P=20h
84@0B01<05`0J0000W@000Qh07`0O49l@WP0L01/07000W@00W0000M/06P0I01L05@0G01X0002K002
M0002G00I01T`5V8CJM[=WokOomooP0=Omd00goLOmeog@05Omd00goLOmeog@05Omd00goLOm]og002
Om`3Omd4Om`2Omd3Om`00goMOmaog00POm`2Omd8Om`01GoKOmaofgoLOk`00g^l0W^k00Yk^W^INiUk
MW]dNgIgNG=HGW0/i`840009460@HA1P360@H0a0360<H@a000<<8005560@H1R1340<H00234000`Q1
2408@00234006`aQ488@P@Q0244@PQB26:<DP@a0344DHQR26:<HPQB2460DHAR26:<La2CU6:<DXARQ
584DXP066:825:8458801Q1R588DPQ22464@PP<DP@8@H@<@PP08468@PaB2584DHAAR588DXP8DPP03
564DPAB200<DP@09364@HA22584<@@`P340@PAB2008@P@0:464<H@PP240@H121464<@0PP46444682
46400aB0460@H@0346401Q22584HXABQ588@PP@@HP8@H@06320@@1AP684DPA1Q0Q2100L@HA1P460@
H@a0220<@0034682584246400`a1464@H@0236401@Q0340<H0a036000a1Q00<<@11P46000a1Q00<8
80P034000Q1P00DHXQB2464<@0a100<<H@@<@003320@@11Q00D@H@06340<811P468<@Pa10Q1Q00LD
PA1Q344<@11Q588HXP0246400`aR364<H@03464336401aB1588@H@aQ344@HA21008@HP8@H@4@HP00
00=[5FlDKaD01F/F0VlF0VlG0Vlg00=_=VlgKcL01Vlg00=[>6lhKcP016lh00=_=fmHKcP00Vlh00A_
FFlhKcQ_>0=c>005KcU_FG<hLcQcE`02LeP3KeT6LeP2LeT017=HLgUcFFmI1g=H0g=i0gMH0WMi1W=i
00AgNGMhMgQgN0=gN@9gN003MgUgNWMj00EgNPEgN@=gNPYgVP03NiUkVW^J009kVP05Ni]gVWNJMiYk
V`02NiX3NiT00gNJNiYkVP03NiX3Ni/6Nk/00gNKNk]k^`02Nk/4Ni/00g^kNkYk^P03NkX4Nk/=Nk`0
0g^kNkak_00@Nk`3Nkd5Nk`2Nmd08G^mNkioogojGQ8L1dD8LZmfmG:DKO5TiVAQI6=XPeS6KNijKFF:
C@UIS6IbGYM=CDARIFInTg4SG01T07B1L61`P002O:407WR2M8E`86`0J01h07`0N01/`UUYGNYJ;Ei>
GW5JCe8>?H/a2224400D81QR644D@P`R228<8@P0324<@P<<@@8<@005344<@0a1468<HP033445348:
34400`a2344<@003444020a0320<80`P444@@111344534033442340246404Pa0200801PP;<55bTg[
@J/X`aa1328400P0340@H0P0400`H@98h`06CBQAS4T7A8=4@3@00R`000//82PP;20/0400B01<05`0
L01h07`0009l8@9l000BM01`06`0L01d0700K01`06`0J01T8500=01@0600J01/07@00W0000QT051P
BDMAYf/EOoQooGon3GoM00=og7oMOmd01GoM0goL2GoM00Aog7oMOmeog@Aog09og@Eog0=og@04Omao
gGoMOmd4Om`2Omd3Om`017oMOmaog7oL1WoM17oL00=ogGoLOmd027oL00Iofg^kOmakg7oLOk`4Nk`0
3W^kNkak^gNJNgUkMWMDMeMcNFlhEU0PY@@12203464536402@a1320@@0`P464DPQB1688@@0033402
240030a0220<H@b2488@PaB3588HXQc47<<DP@<DPP8HPP03564HPAB2008DP`046:<La1RS58826:82
5:826:<01QBS6:<H`aS46:<DH@8@@003464@PQB2008DPP03488DPQB1008DH@8DP@034608@122008@
HP0358<DPQAQ008DPP8DXP03588DPAB1008LX`8DPP0F464DPQB26:<DPQAR464DPQBR6:<DXa22464<
@@aQ464@PA1Q340<H11Q468258801A1R464@HAB14840111Q00H@HQB26:8DXQB248843683340010`P
460@HA1Q0QB20a1Q00HDPQBS488@HQ1Q444246801QR2564DHAAQ588@PP<@HP07368<H@aQ464<@0PP
36000a1Q00<@@11Q46400Q1Q00L@@@a0464@HARR468<@002220334400a10460@H@0246400a10464D
P`0258801a1Q368<@110464@HPaR00D@H@07320<@0aQ468DHA1Q46800PaR00<<H@aR46800a1Q00X<
HA1Q468<HPaQ340<HA1R48<@HP8<H@4<@P0000=[5FlDKa@00V/E0f/F0VlF0VlG0Vlg00=_=VlgKcL0
26lg1Flh1Flg0Vlh00E_>FlhLcQc=g<h00=_>003LcQ_>6lh009_>003LcQcF7=H01=cF09cN@EgN@03
LgUgNGMi00YgN@9gN0igNA1gVPUkVP=kV@IkVPQkV`Ek^`9kW003Nkak^g^k00IkV`03NkYk^g^k00=k
^`Mk_004Nk]k_7^kNk/;Nk`7Ok`3Nk`3Ok`2Nk`0:g^mNkak_GnmOoeomfZg=8Y0YG:;NaEfU6g`H<AP
HFB1I89LiVhANViQIdCXDFYVDF:hEFm8PfV7NWAXi5@0I01dP71PL81dH7aRO:5lYW11I01X07@0009h
000FL>AQIeV8DL`m9cT7CJUJD5H<?H`eBdF]GY9NeEI`=FdHAP`1300400`Q34833446340834400``Q
344<@@0;3444444534400`a0344<@00634000`a1460<@00234001@P0100@8TW]NiH00Wok00Aoo7nk
BQ4D9P88000I320@@0a0400`HDd3B>==B56;B>Q4QDA2>00d0300;20P82`P<20h0400D01T07PQO480
0W`Q0g`000Al8G@0J01/00I`0005K21/@6R1L61d@002M0002g00M01/06@0B4111Tf7JcEolWokOmd0
17oL0goM0goL0goM00=og7oMOmd01GoM0goL3GoM0goL0WoM1WoL0goM00Aog7oMOmeog@Qog0iog@03
OmaogGoL00=og0=of`9og003Om]og7oL009og09o_0Ak_09k^`0=NiYgVW]iNeIkDg]FLeQ[5TG>76<8
0@PQ46800Q1Q00/@PPaR364<H@aR344<@110320800a1008@H006340<80a0360<@0`P0Pa000L@HA22
5:8DXQRR6:<LX`036:<3588256801AAQ684HPQB346<00QB311BS00DHXQR2564DHAB2008DXP046<<D
XPa0464;588358403aB2488@HQ1R488@HQAQ588H`aB2484DPA10584HX`0358801AB35:8HXaRR6880
0QB200D@PQB25:8DPQ2200<@HP<@H@03340DPAB200<HXP035:<@Pa1P00@DP@09464<HA1Q568DPQ21
588@HA1R008<@@05368@HQ1R464<@00346400a21480@H004464746801Q1Q564@H1AQ464DPP8@HP<<
H@D@H@04364@HA1P440446401`aQ344<H@a0364<H0aQ008@H@8<@@8@@003464DPQ1P008@@0@@H@07
368<@A11464@PQ1Q46001Q1Q00d<HA1Q464@@@a0320<@0a1240<@0aQ460@H@02364010aR364<HA1Q
1PaQ0@a100000fLFJaE_5@02KaD5KaH3KaL016/GKcI_=flg0V/g1Vlg1Flh1Flg0Vlh00=_>FlhLcP0
0g<h00Q_>7<hLcQc>6lhLcQ_>7<h5W=H1g=i00=gF7MhMgP02WMi00=gN7MiMgT01GMi0gMj1GMi27NJ
0gNK1gNJ1G^K0W^J0W^I1G^J0W^K00=gVg^KNk/017^K1G^k0WNl00=k_7^kNk/00W^k17^K00=k^W^k
Nk/01W^k0g^l0g^k00Ak_7^kNk]k^`Yk_0Io_0Uk_09k_@0UOmiog7olLcXlbT1QKRQo5WJBKNiTiEaP
J<9PPUC7LU9fKEe6A>QERfIAI]QISdbSJFIjDfCUD01P06aPK85XHF@PM41lHWc6N4<00W0000mh07`0
O01`YEd4IPYJ;U5UJR]IbE7;EPe9cUidNi`017oo00QN3b@P20080111348<@@`Q0Pa11@a010a11@`Q
00<<@@Q134402@a10Q110a101Pa110a00`a100<<@0a144400Q1000D880@0000eBWom00Eoo`03Nmli
D0`00088000@320880`0=81=0TSTCDQAS4D9A<M4@c`P;00`82PP9202;40013@0@01D07000Wa200=l
8G`0O0000W`00Wa20g0000]/0700L01X0700N45li7f6O<=lHW@000=`0008J01P0520@>EJ;GMgOoUo
o0Qog@=og0]og@=og0eog@03OmaogGoM00=og@Eog0Mog@04OmaogGoMOmd4Om`6Omd00goLOmeog@02
Omd00g_MOmeog@0<Om`01G^lNmaog7oLOk`017^l0g^k00ikVWNJNgQkEW]CMcEc=VKF?F`@8@P036<<
@A1Q0QB20Q1R00H<HPaQ340<@11P340222000`Q0360<H00336001Q1P320<@11P464DX`8DPP076:<P
a1RS6:<HY1BT6:@00QB300L@HQ11660LPARS568<@@0358<00aBS5:8DPP026:802QAQ420@@1B1588@
PAB15:8HXac40aB200L@HAB258<@HQ1Q488DX`025:8011B25:8HXa220a1R00PDHAB26<<DXPa0460<
@11Q11B200@DXaBR6:8DXP@DPP8@PP0:468@HA1R468@PQB2488@HAAQ584258801Qc47>@HaA23340D
H08DP@096:<DPQ22468<@@PP464@PQ1R008@H@8@HP0358<@Pa1R008@H@8@HP07488@HA1Q320<@1AQ
46400Q1R0QB300D@PQ1R464@HAAQ008@H@03488@HQ1R008@HP08484DXQBS488@HA1R488@HP@@H@03
588HXa1R008<H@04468@H@aQ340236001@aQ344<HA1P56400aB200<DH@`P22000Q1Q00P@H0aQ340<
@120588@PQ1R111Q10aQ00L@HA1P564@@0a0344<HP0236400a1Q488@P`0246844644364146013440
0003IaI[5FlE00=_5@E_5P9_5`03JaM_=Vlf00Y_=`9_>004KcM_>6lhJcP3KcL3KcP01W<hKcQc>6lh
LcM_>0=c>005KcQc>6lhLcQ_F@03LeP016mILeQcF7=G4G=H17=i0WMH17Mh0gMi0WMh00=gNGMhMgP0
1gMi0gMj1gMi0WMj17NJ0gNK1gNJ00IgVg^KMi]gNWNKNiX4NiT4NiX2Ni/01GNKNi]kVg^KNiX00g^K
00AgVg^kNk]k^`9g_003Nkak^g^k009k^`AkV`03NkYk^g^j011k^`Yk_0Io_0Ik_006Okak_7^lNkeo
_GoM0Wom00QoW4C[<01Ya7[cN[9^3VT60Ub1025LPU37MYEjSV57A>QEJVI@HYIIS4R2IFIb4V3VD01P
872QL<1/Xfa0L21d@7PPO45lHGb1O89lHG`PJ69PX65SHVl00Woo00EonEX/CL]JLW=J00Aoo`07Ooao
]Cc40008011134400P`Q0Pa10`a000@<80a0340<@08<@@D<8@d<@@03340@@10P00@<@@03324<8110
008@@08<@0<<@@06340@@110340@H0PP0P0000=:3GonOol01Goo00AImaP01008008<800F400dP4S1
B>AAJ5F/A>U4b4AT=00X02`P:20P82Q0<20l04P0F01d8Ga2O244O0001GP0M01d07@0L0000V`01700
00i`87eUOVQmYW0PJ01T06P0H01H05@PC:1IbVlE0gol27oM1goL1goM0goL1GoM00=og7oMOmd01GoM
00=og7oMOmd00goM1goL0goM0goL17oM17oL17oM0goL0goM00=kgGoMOmd01Wnl1WoL00AkgG^mNkak
_09o^`03Nk]k_7^k009k^`06NkYkVWNJMgQkE7/b0WLe00URTcT[2008011S344@@A1Q36400Pa00PaP
0Pa000H@H0a0340<@0a1340236001a1P360<H0a0320@@1AP00<DPP036:<La1S400@DY08DP`8DPP04
664HPAB1588458<26:801QB16:4HXQRR688DP@8DPP045:8DXacU7>@26:<02QRR588@HA1Q568@H@a0
588Ha1BR0QB10aB20a1R00`DHAB16<<HXQ21464<HAB16:8DPQAP68826:800aR1588DPP0248800aB1
464@H@0246800`a1464@PP03588258404AB26:8HXaS35:8DPQB1560@@1B16:<La1S458<@HPaR4680
111Q0Q1R00HDPQB3468@H@a14442340246400`a0320@H00246400a1R488@HP0246804A1Q340@HA1Q
468@PQ1R368<@A106:4DXQRS5:<@H@aQ36800PaQ0Q1Q00dDXQRR464<HA1R488DXa1Q340<HA1Q460@
@00236402A1P564@HA1Q564HHA11220@H003464010aQ440DH11P1A1Q00P@H0aQ364<H@aP364@H1AP
0Q1000@@@@aQ364@H@8<H@8@HP<@H@8<@@@<H@4@H04<@00000=W5V/EJaD00V/E00M[5V/EJaE_5V/F
KaI_5`03KcL01FlfKcM[=flgKaL02Flg0Vlh16/h0Vlh00=[>6lhKcP016lh0g<h00=_>7<hKeT01fmI
00=cF7=GLeP03W=H00=gF7=iLgT00g=i00=gF7=HMeP00WMh17Mi0WMH00=gNGMhMgP01gMi0gMj00=g
NGMjMgP00gMi00=gNWNJMiX017NJ0gNK0WNJ00=gVGNJMgX01gNK00=gVW^INiT00W^I17^J1GNK0g^K
00Ak^g^JMkYg^P9gV`9g_003Nkak^g^k009k^`=kV`03Nk]k^W^k00=k^`9k_0Uk^`9k_003Nk]k_7^l
00Ek_003Nk]k_7^l00Ao_0Yk_0=k_@9o_@0:OomogeV?<01QA7JbN]9bCff8F:42F8805537N]MnlfEW
C>Q=BF7]HWAIS4B1IFI^4US6D01L072QM>5/`g20M402L0002WA0O:MmB7f;O@El@6aPH41I16[E0goo
00AZ/UH]KcQoo@Eoo`06OoAARP@1000801111Pa11@a00`a10``Q00<<@Pa134401@a100L<8@a1248<
8@a1468<@P02440234401@a2344@@A0P54400Q1000<<@0a134400Pa100T<@110340<@110100001@P
LgH01goo00AZfRa52004008<800G520dPDSSCBEIREF/A>Y4Yd12;00X02`P920H02@P<41484P0E01d
07PQO25l0002N003M002L0000f`0I01T0003J0001f@0K01h`Wg]N>5804`000980009C01<8520HJM^
m7oFOomooGoL00iog@03OmaogGoM00eog@03OmaogGoM00Eog@03OmaogGoM00Eog@Eog0=og@=og09o
g@04NmeogGoLOm`6Omd3Om`3Omd017_MOmeogGoL0Wnl0Wnm00=k_GnlOmd017oL00EkgG^mNkak_7nk
00Mk^`0<NiYgVWMhNeAo<gmEMcEJLRc8200<80aR0`a100@<H@a0340<H@<<@08<H08<@08<H@H@H@0>
440<01AP584DPQR2588DXaSU7@LQ9acV5:<DXP8DPP0568<LY1R2460HX`026:@02ARS58<DXaRS588H
XQBS6<@La@027<@25:<01aBT9DPU1ARR7<@PiAR2008@H@03340<@A1Q00@DPP0M584DPQ1Q488DPQRS
588@HAB26:8HXaB2488DXaS3588DPAQP6:8Pi1c46:8DPQ22468@PQB1564@HP02488246801Q225:<D
Xa23488DPP8DXP03588@PA22008HXP<DH@08688HY1RT6:@DPa1R464DH@<@H@D@HP0:488DHA10464@
@1B1488@HA104602464346801a1Q488@H@aQ340@@11Q008@HP8<@@04440DPA224642468236833640
211Q468@H@aQ244@HQBS6<@446401AB1340<H@aQ46000Q1Q00D@H1AQ688@H@PP00H@H@05460<HA1Q
340<800446400`aP340<H0023642464244001a11464@H@aQ340<@@aQ008<@@05364@HABR488@HP02
364246400003IaI[5FlE00E[5@05KaI[5V/FJaI_5P04KcH00f/GKcM_5`02KcL2KcH00flgJcM_=`04
KcL5KcP00flgKcQc=`03KcP016lgKcQ_=g<h0flh00A_FFmHKeQ_F0A_F@04LeQcEg=HLeL?LeP4LgT2
MeP00g=GMeQgN@02MgT01G=iMgQgF7MhMgT00WMh2GMi00EgNWMiMgUgMgMh009gN@EgVPAgNP09MiYg
NWNIMiQgVWMjMi]gNWMk009gV`=gVP03NiUkV7^H009kV@=kVP9kV`=gV`07Ni]gVgNKNi]kVG^jNiT0
0W^J00EkVg^kNk]k^g^K009k^`=kV`03NkYk^G^j00=k^`9k_004Nk]k^W^jNkX5Nk/2Nk`5Nk/6Nk`2
Ok`00g^lOkak_003Ok`2Nk`3Nk/3Nk`3Okd2Ool0<6IC>21I96i>NZifSfh9IBAHa523F@QjmWlCHDEA
1dd7HLYZU5V^><EMZ6XbC:M<05@0J81`hFcQL:1dP7A0K01X06`0M69l`WcRO:9l`6b0D<A=JWomOomo
^TeVI]=onPIoo`09OoQVDAP60008010P444<8@a200<<@@03440@80a0008<@08<@@07324<@Pa2324<
8Pa2324010a10``Q00P8@Pa2224<8@a1340@@@a10Pa200<<@A1032000a100Q1100@<@@a2344<@0<@
H00544000000@Naon@07Ool04GoOAFd<0P@032080100<8591556GJUES4D:A:I4@3P0;0000R@000TT
82P0>41884`0F01/07PQO2401G@00W0000=X05`0E00015@00TP000e<05@PC00h02`0<00d0421D>AV
;7/COoMoo002Ood>Omd4Om`=Omd017oLNmek_G^m17oM00=og7oMOmd01GoM2goL0WoM00AkgGoMOmao
g0Iog@=og0Eog@07OmaofgnlOmaogGnmNkd00W_M17oL00UogG_MOkak^gnkOkYk^g^jNk/00W^j00eg
VG^IMgUgN7]ENeAg=VkbCS0PQ@P0420@H@0534400`aQ464<H@023402460030aP340<@0a0460@HA21
588DPA1P4404008@H004584DPQB358<25:<00aS37>@HX`025:8558801ARR6:<L`aRS58<01AB200TD
PaBS6:<HY1B3588DY1cU8>@00QB200@HXaRR688DPP8DHP<@HP0;588DXQBR488@HPa06:4Pi1bR460D
P@04588021RR584DPQ11560HXAc36:<358801A1R360DPAB14880111R0Q2200<<HQ1R48800Q2200`@
PAB1584DPAB0584@HA1P584DPQB3488346801a1Q560@@11P464@P@aQ008<@@04364@HAB144024600
1A1Q488@HA1046001A1Q0Q2200L@HA10340<01AQ6:<HXP0246801A1Q468@HPaR34401@aQ0Pa10PaQ
0PaR00L<HARS6<@@PQ1Q468@H@0246001`a0360@H11Q460<@11P008@H@09364<@11Q464@PA1Q3408
80a1008<@003364@HA1P008@H08<@003360@HA1Q00<@H@07440<@0a1464@PQ1Q36400`a10a1P00@@
P0aP344@H08@H@0000=W5V[eJaD01V/E00=[5VlFKaH00flF0Vlg0flG00=_=f/gKcH03Vlg00=_>6lg
KcP016lh0Vlg00A_>6liKcQ_F@=_F0A_F@04LeQcEg=HLeLBLeP3LgT00g=hLgUcN@03LgT?MgT2MgX0
0gMiMgQgN002MgT01WMjMiYgVWNJMgYgVP=gN@04MiYgNWNIMiP2MiX2Mi/00gMkMi]gV`03MiX01G^I
NiQkV7^HNiT00g^J0W^K1gNK00=gVWNjNiX00W^J2W^K0g^j0g^k0W^l0g^k00=k^W^kNk/017^k00=k
_7^kNk`00g^k1G^l00=k^g^lNk`01G^l00=o_7^lNk`017^k00=k_7nlOk`00Wnm02=oggooL_M4PdS6
INafS7Z^MViYbf4WD<=I9g:cN]1M9E3WC>IQbVIbFO1=ZegYHS1@idP0E25THFbQK<9``WC4M61d86`0
009X000<N0=l@Gc2OD=mR63V;2<`I3B5904`XW=E27oo00io_S4=0008010Q4448@Pa2324<@P`Q424@
80`Q0`Q1018<@@`Q34888P`R324<@PPR324@8A12348<@@`Q34488@Q23482244234401Pa22488@PQ2
344<HP<@@@04448@@@a2348234401111464@@1100P0000=[EgokOol01goo00mZUQPW100@80`Q200`
PdTVEHUMZE6<A@Y8adb1=0000RP00R`000Hd8410B21D@6@PL002O243M003L0002FP0I01H0500G<1Y
R78;LJ]H@002C00025@0C01<@532D@EQk6kfOgT2Ood2Ooh00gomOmeog@0=Omd4Om`=Omd00goLNmek
_005Omd00goLOmeog@07Omd9Om`00goMNmekg@02Omd00goLOmeog@04Omd3Om`3Omd00g_MOkao_003
Om`00goMNkekg@02Nmd3Om`00goMNmek_002Ok`00gnkNk]k^`03Nk/047NjMiYgVWMiMgMg=G]FLcIZ
e47_56<401AP464@@@aQ0`a100@<HA1P464@H08@@08@H@8<H@8<H08@H@03364@H11P00<@H003464@
PA22008@PP0B484@H@a0364DXaS45:8DPQB3588HXaRT6<<Ha1RS5:<@HAAR0QB300@HXabT5:<8@@8D
P`0;588DHA215:<HXaB2444DHQRS9>DLX`0258824680112248<@XaBR0Q2200@<HARQ8>DHPP8@H@05
488DPQ22464DPP025840111Q564HXQc40aB20Q2200@DPQB1584@PP@@HP8@PP03364<@A1R008@PP03
468@PAB1008@P@073408811Q6:8DPQB346<00Q1R00T@PQ1Q560@@11Q484DPQBS48<00a1R111Q00<@
H11Q46401A1Q00/DPAS36<<DXQB1564DH10P564La1B200<@HP04488<HPaR368236400a1R368<H@04
36401`aR46<@Pa22468<H@a000P@H@8<H@04468@PQ2246844646364246401QB2464@HA10460@H@8@
HP<@H@8@HP06344<@PaR364<HPaQ0Pa100P@@11P464@H@aQ340@H11Q0A1100000fLFJ_E[5@07JaD0
1VlFJaI[5V/FKaI_5`9[5`=_5`03JaM_=Vlg009_=`03KcI_=flg00U_=`06KcQ[>6lhKcQ[>6lh0flg
0flh00=cEfmHKeP00VmH0VmI00A_F7=GLeMcE`mcF008LeMcF7=HLeQcNG=hLgMcF0AcN@06MgUgN7Mg
MgUgF7MG1WMh0gMi00=gNWNIMgT00gMh1GMi00=gN7MiMgT00WMi0WMj00MgVGNHMiUgVGNJMi]gNP04
MiX2NiT3NiP017^INgUgVW^J0W^K2GNK0W^J00=kVG^JNi/00W^K00=k^g^KNi/00g^K00=kVW^jNk/0
0W^k00EkVW^KNk]k^g^J00Ak^P9k^`03Ni]k^g^l009k^`9k^P=k^`9k_0=k^`Ek_004Nk]o^g^kNk`5
Nk/0<7nkNkao_GnMOmmoogmGC>L/IV6;NZafS7J?MW1]c5d3HHIbT7:?FDY8jTdYFJYRDEG_AHYRBVY`
HHY8YDAVE8ELY6C4L<AdigS3N65d8700J01/07P2O25m97f4K>DX00<00003;41oSgoo00Qoo`03CK84
00@0008<0005348@@P`Q324@8P03300234401@PP320@80`P20000``Q00<80@P020400PP100P<8A11
444<@@`P220<80a10Q110Pa20PPP00/800PP324@8@`1204<8A11324880`Q008@@@06200<00@0201_
=Wok27oo01Yfmb19100800`0200hPdT6DHYMZDe[B@Y8idQP=00`02`0:00`03`PA41@PEbPJ41d8GPQ
0W@00g0001E/0600E01@04aPHF9fkgnaOo5odWmCO[1jTGjaO]9o<gmCOkAofGolOoh00goo00=ooWoM
Omd03GoM1GoL2goM0goL00=ogGoLOmd017oM0goL1goM1GoL00AofgoLOmaog0Eog@04OmaogGoLOm`3
Omd3Om`3Ok`02W^lOkao_7^lOkaofgoMNkekgG^m2G^l0W^k00Ak^W^kNk]k^`=gVP0<MgUgEGLeMeIc
=fJf>Fd<8PP0560@HA110`a1111000<@H0a044000Q1P00D<H11Q464@H110008<@004460@HA1P4602
464011B1464@HA1Q0QB2111Q00DDPAB2588DPQS3008Ha0035:<DXQB200<DPP8DP`068>DHXa1R348@
HQBR0QRS0QBR00LDY1B4468DPQRR684DPP02468236802Q1R488@PQ22468@PQB1588DPA1Q112200@@
HQ1Q584DP@<DPP066:<DPQB2584@HQ221AB200HDPA1Q468@HA214882588348805121584@H@aQ2204
011Q584HXaB348<@HPa1488@HAAQ440@H11Q58454682464746024640311P584DXR3U8@HH`aB1564@
@111464<H@88@@06364@HA1R368<HA1Q0PaQ00@<@@PP220<H08<H@03340<@@aQ008<H@8880<@H@03
488@HQ1Q00<@HP03488@HQB2008La004588@HA1Q36434640111R364880aQ0Q1Q00P@H0aQ360@H11Q
468<HA1P111Q00<<H@a136400Pa10PaQ00<@@0a046000Q1Q00@<HA1Q460@H04@800000=W5V[fJaD0
1F/E00=[5V/EJaH016/F0VlF00I[5flGKaM_5flFKcH?KcL00flhJcQ[>002JcP016lhKcM_=flg0flh
00=_EfmHKeP01VmH2G=H0W=I2g=H00=cNG=hLgT017=i17Mi0WMH0gMi0gMh1WMi00EgMgMhMgQgNGMh
009gN@06MgYgNGMiMgUgNWMi0WMj00=gVWNHMiT00WNI00=gVWMjMiT00WNI0g^I0g^H00IkVG^JNiYk
VW^KMiX:Mi/017NJNiUkVW^J0W^K00=gW7^KNk`017^K00Ak^W^kNk]kV`9kVP05NkYk^g^kNk]k^P04
Nk/00g^KNk]k_002Nk`00g^kNi]k^`02Nk/3Nk`3Nk/5Nk`7Nk/3Nk`09W^mOkeo_WooOiYAKbQYFDYj
[7Z=LTibCg9@LTi^CFjAK[5VLV9CHU9VKfJCHW=NLVJBHY5R;V7]HHaI9eC5F:AXaG37M<Ilj7QTM282
K0001g00O01l@Gd7K:8`01@000800003=61od7oo00Qoo`03CI8000P0008800@<0@03300800P00088
0008300800P0200<00P0100800880@<40@0300040@P100<80004100800P0100210400`0010080@02
200310001@@1200800P0304010P000D<0000401ZdWoj00Qoo`0IL[HL1P00300000`0<414ideZFHYA
JdT:B<I8H3P0=00h04@PB698PDQQC85DP6A0K0000g0000YX06`0K01P05P0E41D`FX/MgQonPeoo`03
OoiooGoM015og@Mog003Omeog7oM00Iog@03OmaogGoL00Mog@04OmaogGoMOm`4Omd;Om`5Omd5Om`0
0g_MOmeog002Om`3Ok`3Nk`3Om`00gnlNkek_@02Nkd2Nk`00g^kNkak_003Nk`5Nk/047NKMiYgVWMj
MgUgMWLeMeI_=eYd;BX400P0564@HA110Pa100<<@1104440111000X@H110440@H121364@H110444@
@0<@H009560HPARR588DPAB26:<PiAc4008HX`04588@@1B15842588011BS6<@DXaBS0aB200dHY1c5
58<@HQc56<<DXa23488DXacU6>DHa0035:<00aB3588DPP03588458<01AB2488@PPaR48800QB200`<
HA1Q5:<DY1B348<@HQAQ688DPQAR4644588011B1468@PQBS1QB200D@HA1R584DPAB2008H``045:8@
PQ22488246401@PP244@HQ2258<00QB200L@PQ1Q464@HQ1Q440@H0024640111R588@HQ1R0Q1Q00<@
@A1046400a1Q00/@H1B2464@HA1P464DXQc47>DDXQ22008@HP8<H@<<HP03364880a0008@H@<<HP06
344880PP344<HA1Q0PaR1@aQ00<@HA2246800a1Q00<@HQ1Q46400Q2200<DPa2346800Q1R00@@H@aQ
360<H0<<@003364<HPaR008<H@03220<@@aP008<@007364@HA21464@H0aQ36800PaQ00d<H0a0340<
@A10340@H1B25:<@Pa1R464DH00142000004IaIZmF[dJaD3Ja@00f/EJaI[5@02JaD2JaH3KaH00f/F
KaM_5`02KaH3KcH7KcL00flfKcM_=`06KcL00flhKcM_=`06KcL00g<gKeQ_F003KeP00g=GKeQcF006
LeL3LeP2LeT4LeP00g=GLeQcF007LeP2MeP4MgT2MeT3MgP2MgT017MhMgMgMgMh1GMi00EgMgMhMgQg
NGMh00=gN@03MiQgNGMj00AgNP03MiYgV7NH00QgV003NiQkVG^I009kV003NiUkVWNJ009kVP04MiYg
VgNKMi/7Ni/00g^JNiUkVP02Ni/01G^kMiakVg^lNk/017^K00Ik^g^KNiYk^G^INkX7Nk/2Ni/5Nk/0
0g^KNk]k^`02Nk/00g^lNk]k^P02Nk/5Nk`2Nk/017njNk]k^g^k0g^l02mk_GnmOkek_GooOkYRERQ[
E@UfQgJ<LVmfL7I_MXmncgkaK[5Zdg]jMgY_5FkfI[ENDUiAHY1RK7<COeI^]67?G@YLaf2UK<A`YWBU
M6=d@G@PL01d07P0N41X84@0008/0004:01@`gm[Ooh7Ool017nLE@dL020011`000@H0200;20`00HX
0004900P02@0:002900012PQ;24T0B000Q`00R@000<P01`070001b0000TT0200;00`82P0:24T0B@0
:2000S0P00T/82P0;20X8200:00/06W6Onl01goo00Eomg7_=0DT0200008X0008@89924eZEHUAJTTZ
B<I8HP8h000F@018@5D4FB=D`U1PE41H06P0K01`06`0J01L05P0C01@PVFZMaAodWokOod5Ooh2Ool2
Ooh00gomOoiooP03Omd00goLOmeog@07Omd00goLOmeog@05Omd9Om`5Omd3Om`017oMOmaogGoL1GoM
00=og7oMOmd01GoM0WoL0goK27oL0g_L1WoL00AogGoLOmaog0=o_003Nmeog7oL009og0=o_09k_004
Nkek_7oLOm`5Nk`5Nk/03GNKMiYgVGNIMgIgEGLeMgIcEeid:>L000P0008@HP0;464<@0a0340@H11Q
460<@110340<H002340010aP460@H11P0a100a1P00dDH1RQ6<8HXQBR6:<La1cT6<@La1RS588DH@02
584558800a22468@HP024882464011B37>DQ1ABS0aB30aBS0aB20QBR0aB200DDXQBS588DPQB3008@
PP8@HP06488DPQ22488@Pa1R0a2200@DPQB1584DPP<@H@03588DPAB100<DPP045:<DPQ1Q46424680
2Q22584@PAB1464DPQRR8>8DPA1R0Q1Q00H@PQ1Q464@HA1R488358825:801121364<@A110Q1Q00<@
HQ1Q4680111Q00<@H0a034000Q1Q00@@H110464@HP@@H@8@PP03484@HQ1R008@HP03488@HPaQ008@
H@8<H@8@H@@<HP04364<@@aQ368536434643364346423400111P464@HA1Q0PQ10PaR0PaQ0PQ001@8
80a0344<HQ1R48<@H@@P220<@@a0320<H11Q5:4H`QRQ460<@@aR0PaQ00<@H0a034000`a000L@H1B2
468@HQ225:<DH@0144000003IaIZmF[e00A[5@M[5PA_5P=_5`9_5P9_=P04KcM_=VlgKcL6KcH4LcH<
KcL2LcL2KeP2KcP2KeP3LeP2LcP00g=GLeQcF007LeP00g=GLeQcF008LeP2MgT00g=jLgUcN@02MeP3
MgT027=iMgUgN7MgMgQgMgMHMgP<MgT6MgX00gNJMiQgV003MiP4MiT00gMhNiQkV@02NiT00g^HNgUk
N@02MiX00g^JMiYgV`02Mi/00gNJNiYkVP04Ni/01g^JNiUk^W^KNk]kVgNL00UkV`Ak^Pmk^`9k_004
Nk]k_7^lNk`3Nk/4Nk`017^kOk]o^gnj17^k0g^l0g^m00MogWokK_X/S4S6LTMj[P02LW0077:AMY5j
T7J@K[9_5goJNkaW5fKEHYANDUibFW5FCG<dOmQongMIKW9QBUbTH:AXY735M:QhjgR90gP000Yd0700
J09P0e@3E4A]A7k]Ok9oo0Eoo`03Ooen^4`X009@00980004A01804`0F242G2401f@QH25P8F0QG25P
8E`Q009P8@03G25H8EPQ00AD0003G25P8F0Q009L8@05F25@05PQG25H0002G2401EPQF01D060QJ480
0VA200=L8E@0G2400U`Q00]T8F0QH25P8EPQF01L04`0F81ndWme00Ioo`0IO_I/`e02G09TIEb2D85D
iEeYDF]EJUF;BBU<idR3A41484Q0B61E1EdTF<=@@4`0G0000V`000=`06P0H0000U@000=H`F8]OiP0
0goo00=ooGoLOm`00WoL0goM0WoL27oM00=og7oMOmd017oM0WoL1goM2WoL17oM00=og7oMOmd00goM
00=og7oMOmd00g_M27oM3GoL2G_L00AogGoLOm]og09o_0Akg@9og09o_0=k_004Nkekg7_LNk/5Nk`0
0g^jNk]k^`02Nk/2Mi/03gNJMgQgMWMEMeIgMWLhEQ4LH`@0344@HPaR364<@@02340236400`a1340<
@002360234003`aP464@H110460@@0a0360<HA1Q560DPARR5:8H``026:<35:<4588011AQ588DXQBR
0QB200<@PQ1R46800Q2200P<@@PP5:<PiB455:<DPaAR0QB200<DHQ1Q46400QB200@DXQc45:8DPP<D
X`0458<@PQ224684488258800a2248<@HP0234400a1R588DHP02488558800aB1588DPP0258825643
464348402aB1440@HAB17<8DPA1Q3408@11R48800Q1R00<@HA2258800QRS0QBS00@DXQ1R344@H@L@
HP8@H@0=364<@0`P340DPQ1Q560@H@aQ464<H@a036000Q1Q00TDPQ22464@HQ2248<@HQ1146400PaQ
00<<HQ1R46800Q1R00<@Pa2246800Q1R0PaR0`aQ0Q1Q00@<H@a02208@08<H@07464DPQ1Q340@H@aQ
34400Q1Q00L<@@a0340<H@aR364<H00234002Q1Q488@HQ1R488DXa23364<@0`P0Q1Q00LDPQc46:8@
@0a1368<H@0236001@a0320<@11Q36400Pa00Q1Q00<@HQB256400AA0000016LFJ_EZmF[e0f/E0f/F
0V/E00=_5F/FKaH016lF00=[5VlGKaH00flF0flf00=_=flfKcH01Flf0g<f0flg00=c=VlgKcL01flg
0g<g0Vlh1FmH0Vlh00=cEg=HLeP01G=H00=cEg=HLeL00W=G2W=H0W=I00=cNGMgMgL00gMi00=cNGMi
MgP00gMf00=gMgMhMgT00WMi0WMh00QgMgMiMgUgNGMhMgUgN7Mi1GMj00=gNGNHMiP01GNH00AgVGNH
MiQgV0AkV09kN0MgVP04NiUkVW^KNi/3MiX00g^JNiUkV@02NiX017^KMi]gVg^K0W^J00=k^W^KNi/0
0W^K00=k^W^iNiT00W^i0g^j2G^k00AkVW^KNi]k_0Qk^`9k_09k^`=o^P9k^`=k^P03Nk]k_7^l009k
_00XOmaooGML@=10Q6gWNXmfT79`LW5bTGZbN]=RLVlgOoUk^f/HI[ANLEiAFU5F;eH<J]1ol7oGOkEo
EW;DJO1LbEbTI:E`ag2SL89dHWQ1M202L0005V`0M45lXWSRM@=j1Gj8OfMomWojOoQomGmFOU9`Ze@2
G01P060QG01L8F0Q0V@Q00AX8Fa2L49`@P=/@P03L49/@Va200=X8@07I25P8F0QI25X8Fa2K2400Va2
00AX@V@QH25T8@=/@P05L49/@V`QK25`@P03K2400g12K49/8@05K242K4803F`QI01X05P0I65ibGjV
OfYobWm`O_1fEFR/009L000CI01/@G31J@5YIVFYDH]EJU5ZCBU<idS5B:9@`EdTF@=8P4Q0C2000T`0
00mP06P0J01T05P0E01@H65RNa1olWokOoeoogomOmd017oL0goM0goL1GoM0goL00AogGoLOmaog@Ao
g0Mog@Eog0Iof`04OmaogGoMOm`2Omd3Om`3Nm`01W_MOmeogGoLNmaog0Aog@03OkaofgoL00Iog0=o
f`9og0Ukg005Nmeog7oLOmao_002Om`2Nmd01W^mNkao_7nkOkak^`9k_003Nmak^g^k00Ik^`03NkYk
^g^j009kV`0BMi]gVWNIMiMgEWMEMeIcEF[D@Hh<00@0468@H@aQ464@H0a00PPP0`a000H<H@aP360<
H0a024023402360222005@aP464@HAAQ584HXB3S8>DL`aRQ6:8DXaB2344@HQB3588@HQBR5:<HXP03
588248801AB1588@@A1Q58800QRS00TDXaBR5:<DPQB3468<@A1156400QB20QBR00@DPQB358<@P`8@
PP<@HP0358<@PQ1R00<DXPD@HP@@H@05584@PABR6<@HX`0258400aAQ464@H@0356400a1Q584DP@02
58400aAQ340@H@0248400a22468@H@0246800a1Q468@H@02464448800aB2584@PP07468234484640
1aAQ584@PA1Q340880a0008@H@03584@PA2200<@HP08464@@A1Q364@H@Q0220<@08@H@8DPP04488@
HQ1Q3642468446404`a0220880aP464@PABR588@HQ1Q364<@@PP340<HA22464<@@aR008<H@05360@
H0`P460@P@0348800a1R488@H@02440234001a1P464@@@PP344@PQ1Q008@H08<@004320<@0aP4603
46400a22588DH00142000003I_EZmF[e00AZm@03JaE[5V/F00A[5PA_5P9[5P03JaM[5VlF009_5P05
KcM_=V/FKcI_=`03KcH3KcL00flfLcIc=P0<KcL01FlhLcMc=gMGLeP01VmH0Vlh00=cEg=HLeP00g=H
0W<h1G=G2W=H0W=I00=cNGMgLgP01W=i00=gN7MgMgL01gMi00=gN7MiMgT01GMi1GMj00AgNGNHMgUg
N@agV@9kV@AgVP05MgYgVWNJMiUgVP05Mi/00gNJNiUkV@02NiX017NJMi]gVg^K0g^J0g^K0W^k0g^I
00=kVW^jNk/02W^k00Ak^W^KNi]k_0=k^`03Nkak^g^k00mk^`9k_00;Nkek_7nlOomoWe6C@49QHgJ?
LY1bL002LY8087[cL_IJLg<hOo]o^V/GGU5F3UX_FU1F;UH<J]1oTWnfOiMo^7mgLaMZ<5c7F8APHVR3
K89`PgRXO65d06`0L002K0003W10N:9d`7D2NHQn:gj=O]9j;6TZI21T0600I003J0000f`0J01X0009
J0000f@0J01T0006I006J002I003J002K003J003K002L002K00016P0K01/06P00V`0035X06`0K01/
06P0G01P06PPK>9aAG4XJ65P05`0H01T06P0K01`P62RKHMf9eF:DFY=BTdYC@MA1eU7EBE@iDR1A414
8400A01805P0J01H05`0F41D`VY=MeQonGonOoeooP06Omd7Om`9Omd7Om`00goMOmaog@06Omd4Om`3
Om/3Om`2Omd6Om`4Nm`2Nk`00goLNmekg@03Nmd00goMOkaof`04Om`3Nm`5Om`8Nm`017_MNkeo_7nk
0gnl3W^l27^k00=k^W^KNi/00WNK00QgVWNHMeIgEW=FMeER]3T/0P@000H<@@aQ464@HQ1P44043400
0`a1360<H0023603364236001@QQ488@PPaQ46800Q2100@DH1AQ7:<HX`8HXP0;8>@HXaB3568DPQAR
468DPQBR6<@HX`04588011BR6:4DH1B10aB20QBS00@HXaS458<DP`@DPP03584DPQBS008DX`<DP`0;
588@PQ1R468@PaBS7>DHY1BR5:<Ha002588346801AB2464DHA1P58400QBR00@DXaRS684DP@8@@@04
340@@1AQ584258800aBR584@H00246401A21488@PA2246801A2200P@H@a1240<HQ2248<@PQ1R0PaQ
0PaR111R00@@PQ1R468@@@8@H@04588DXa1Q240358400aB24688@@02368010aQ468@HQ1Q0Q2200@@
HPPP468HPPL@H@03468@PQ1R00<@HP8@P`08488@HQ1Q464DPQ1Q340<@@8@H@086:<@H@aQ364<HPa1
240<@@8<H@0<368@HPa1364@HA226>@DP@@0460@HA220a1Q00<<HA1146400Q1Q00H@H0a0440@@000
2202364246000`a0360<H00546424882464144000003I_EZm6[e00EZm@03JaE[5V/F00E[5P06JaE[
5V/FJaI_5V/F0flF0Vlf1FlF00A_=VlgKcM_=`9_=P03LcI_=flg00M_=`03LcM_=flg009_>09_=`06
KcQ_F6mHLeM_F7=G0fmH00AcEfmHKeQ_F09cF0YcE`IcF0=cN@04LgQgMW=gLgP5LgT5MgT2MgP9MgT0
0gMhMgUgN@03MgT017NIMgUgN7Mi0WNJ00IgNWMiMgYgVGNHMiT3MiX01GMiMiYgVG^HNiT00g^J0WNJ
00AgVG^HMiUgVPAgV`03MiYkVG^I009kVP05Ni]gVg^KNiYkV@03NiX2Ni/2NkX017^iNiUk^G^j1G^k
00=kVg^kNk/00W^K0W^k00=kVW^KNk/01G^k00=k^W^kNk/01g^k1G^l00=k^g^jNk/00g^l02]og7on
OomRET1QHFAbCW:@LW1bTW:AM]9_5f:eNiYoo7oJKaIJ3U7<FTmJ;E8=EPeZdG]dNiMgEg]gOiEoEW/D
KW9MCEBVE6EPI6R2L:9hP7A0L01/0002I0002FP0K21`@6`PI01T86QUK8UTH`02H002I003J002K00;
J009I006J002I0000fP0I01X0003J00;K0000fP0K01/0006K0000f@0H01L0003E0000e`0H01X0003
K0004G00M21TPW67MV9ER55ZCDY=:4cVC>=<`db0A41483P0=0000SP000Tl04@0B01885S1IJIbdWnD
Oo`00Won00=og7oMOmd01GoM2WoL1WoM0goL00AogGoLOmaog@9og003Omeog7oM00AogAUog0=og@9k
g@03Omeo_7nk00=of`06Omakg7oLOmaofgnk0WoK00=og7_LNk/00g^k0goL00Ak_7nmOkao^`=o_003
Nk]k_7^k00Ek_0=k^`=k_0Mk^`9k^P0@NiYkVgNKMi]gNWMgLgMgEW=FMeIV]CD<100800a046024643
3403360236402Pa0360<H0aP464<H@a0360<@0aP0Q1Q00`<HAB1584DPA10340@HAB26:8H`aBS4684
58826:800aBR588DPP0258801aBR5:4HX1AP7<4PiARS008DP`035:<HXaBS008DP`8DPP<HXP<DPP03
464DPQB200<DPP8@HP8DP`<DPP046:@HXaB2588246800a22468@H@0256402ARR6<<DXQBR6:8HPAAQ
440<@00246401aAQ584DPARR6<<HXQB100<@H@8@P@<@H@@@PP05484@HQ1R368@HP0348801A1R344<
@@aR34400Q1Q00@DPQRS58<@HP@@H@<@P@046:8LXQbR464446802a1Q3648@0a0464DPQ1Q340DHARR
56401a1Q0Q1R00<@HA1R36800a1R0Q1Q00D@PQB2464@H@aQ00<@H@07360880aQ468<@@PP36000`aQ
00@<HPa1344<H@<@H@04340@HA1Q484236401`aP340<@@aQ488@H@aP008@H08<@08<@@D<@08<H@03
464@PA2200@@H@4@H04@@00000=VmF[dJ_D01V[e0f/F00A[5F/FJaI[5P=[5@A[5P9_5P04KaM_=Vlf
KcHCKcL2LcL016lgKcQ_>6lh0flg00Ac=fmGKeQ_F09_>0I_F003LeQcEg=G00]cE`04LeQcEg=HLeP2
LgT017=hLgMcN7=h1G=i17Mi1GMh17Mi00AgNW=jMgUgN0MgN@05MgQgNGMjMiYgN@02MgX00gMiMgQg
N@05MgT017NJMiUkVG^I1GNJ00=gV7NIMiX017NK00=gVWNIMiT00WNJ00IkVgNKMi]g^W^JMiX2NiX4
Ni/2NiX00g^jNk]k^`04Nk/00g^KNk]k^`04Ni/00g^JNk]k^`0>Nk/6Nk`017^kNkYk^g^k0W^l00mo
_7oNOom^f4ARGDUZ;W9]LVm^LViaN_A_5f;FNgT00Wol01]c=f8_ENaNL5i^ERiB3F[ANiIk^GMhMeMo
N7]hNgUoNWliKYAQBU1RE2=P@W22M65`@6`PJ0000V@000A/07@0M01X009T0003K01d07@P009d0003
K01X06`000=/00aX00QT00IX00=T0004H01T06P0J006K0000g00K01/0003K002J00:K005J0001700
M01d07P00W@000]XP7H:MVMEREEZDFY=:DS6B:90@400008l008h008`0006@01484RRCBAN:gNH0Won
00AoogomOmaog0Mog@Mog003Omeog7oL00Iog@=og0Eog@03OmaogGoL00Eog@Mog003Omeog7oL00ao
g005Om]o_7nlOmeog004Omd00goLOm]of`02Om/017oLNmaog7oL17oK00=k^g_LNk/00Wnk0WoK0WoL
00Ao_7^mOkao^`=o_09k_003Nk]k_7^l00Mk_0Uk^`04NkYk^G^JNi/2Mi/02gMjLgQcNGMHMeMcEEic
:<T400`046400a1010a000<<@@a036400PaQ1@aP0a1P00L@@0a0340@HQB1588DXP045:<26:<021B3
220DXac47:<HPQB25:825:<258803aRS7<DTiARR584Pi23V6:<DPaAS58<DXQB2464DP`025:<01ARR
7:<HXQRR58800Q1Q00DDPQc48>HLa1B300@DPP036:8HPQB200HDPP0?468@HA1Q564DPARR6<<DXQ22
588HPQAQ440DHQ22008DPP0B584HXaRS7:<HXQB2488@H@aP484DPA1P564@HA1R5:<H`aB20Q2200H@
Pa1R344@HQS35:<246800a2258<@HP02468011B37<@DPa110Q1Q00@<HA1Q364@PP8DPP057<@DPQ1Q
6:<Li@0248801a1R464@H@PP564LXaAQ008@H@06564HXa1R464<@@a01a1Q111R00L@PQ1Q364<HA22
5:<@PP0246401PQ0220<@1B2464<H@8@H0<<H@8<HP04468<HPa13602464010aQ488@PA210Q2200H@
HPa1340<HAB348<2464336401Pa0360<H@aQ3408808<H@035:<@PQ22008@HP8@H@4@H04@@00000AV
mF[dJ_AZm0EZm@=[5P04JaEZmV[fJaH6JaD01FlFJaI[5V/FKaH00Vlf00=_5flFKaH00VlF16lg0Vlf
00Ec=VlfKcM_=flf00U_=`03LcM_=g<g009c=`08KeQ_>6lhKcQc>7=GKeQ_E`=_F0QcE`05MeMcEg=G
LeMgE`03LeL017=HLgUcN7=h0g=H0W=i00=cF7=iLgT00W=h00EgN7MHMgQgNGMH009gE`AgN@9cNP03
MgUgN7Mi00EgN@9gN004MgUgN7MjMgT2MgX00gMiMgQgV@06MgT02gMhMgUgNGNINiUgVG^IMiQkUgNI
MiX00WNK0gNJ0gNI00AgVW^KMi]g^P=gVPIkVP03NiUkVW^I009k^PAk^`MkV`04NiYk^g^kNi/4Nk/3
NkX4Nk/2NkX00g^kNkak_003Nk`017^kNkYk^g^k0W^l01ik_GooOomo>Dc6@<MV3g:=KTmZDViaN_=_
5V:eMcMof7niKaIRCUh^GW1NKEX]CNaVdWnGOmQoUgMGNeL2NeP02W]hOkEoMglDKS5DZEA4H6A/Q720
0VaP00=X@F@0I0000VP00V@000MX06`0L01`07PQO25h8@02L00016`0J01/06`00VP00V@000=P06@0
J0001VP01F@026P00f@00VP03F`00VP01f`000=`06`0K0000W000f`01G@000]d873PKJIYiU69EH]=
RdD8@<E4Pd0P008d008/008X0007;01084SRFHEZJ7MfOo@00Wom0goM00=og7oMOmd01GoM1goL00=o
gGoLOm`00goL0goM37oL0goM5goL00=o^gnlOk`00WoL17oM00=og7oKOk/00Wnk00Aog7_LOm]of`Ao
^`=k^`9o^`9of`9og0=o_003Ok]o_7nl009o^`9k^`03Nkak^g^l00Ik_09k^`03Ok]k^g^j00=k^`9k
^P04NkUkVWNJMi/2MgX02gMiMiYgF7<fKaA>3aaT0008011Q44000Pa000<<H@a134400Pa100D<H@a1
220<@0aP008<H@8<H0<@H00=440<H@aQ488@PAB16:8LiAc46:<DXaRS6:800aB20Qc300LHPA1Q364@
PQBS5:@DX`0258<258826:<01QBS588DHQ1S58<DXP@DPP8HXP<HX`04688@HQB258826<@021RT58<D
PaB2468@PQBR688558801aB1588DPA1Q340DHAB1008HXP045:8<H@a15642444011B26:<H`aRS0QB2
00XDHQAQ6:8HPQRR584@HA1P580@H08@H@04468@PaBR488646802a2258<@HQAQ588HXaB2464<@@aQ
46400Q1R1A1Q00<@PQB248800a1R00<DPQBS48800Q1R0Q1Q00P@@11Q564DPA22464DHA1Q0Q1R00D<
@0PP364@HA1R00D@H@03444@HQ1Q008DPP054608811P460@P@0246400`aP364@H@03464246002@aP
364<H@aR468DPaB4368<H002464258800aB1364<H@023640211Q364<HA1Q588@PA1Q460436001`aQ
360<@@aQ368@PQBS008@PP@@HP8@H@0000=VmF[dJ_@00V[d16[e0V[f00=[5V/EJaH00f/F00I[5FlE
KaE_5F/FJaD3JaH5KaH4KaL01F/gKcM_=flfKaH00W<f3Vlg00Ec=W<gLcMcF7MG009c=`03LcQ_F6mH
00A_F09cF0=_F09cF003LcQcEgMG009cE`9cF09cE`McF003LgUcN7=i00AcN@04MgUgF7MhMgP2MeP5
MgT2LgX8MgT017MhMgMgNGMh1GMi00=gVGNJMgX02WMi0WNI00=kVG^HMiT01WNJ00=gVGNJMiX017NK
0WNJ00=gVgNJMiX017^J00=kVgNKMkX00WNj1GNK0W^K00=kVW^KNi/017^K0W^k0W^l0W^k0W^j1g^k
1W^l0g^k0W^l039k_G^nOomoW5U`<8YId7K?LW1^LW:BN_=_5V[fMcIoUgMGK_EN35X]GY1NKU7[DNaV
/G=EMiUZmF:BI]EZmVlGLcQoN7oJOkMoF7:eJHeTb6bVL<A/XFb1J65XH6Q1I01P06@016P000Q/0700
N25lHgb3O25d07000fP000ET05P0G01H860000UX00=T00QX00=T0003J01/06`000]/00AX00E/00I`
0003K01`07@000=d000>L01/0720J<1Q@fH9FN]Ibe6]@@Y0j4S5?24/008`008T0009:010X4e5HLQA
Yf;=NmUonGon009og0Yog@=og0Eog@04OmaogGoMOm`6Omd:Om`4OmdGOm`01goMOmaogGoLOmeo_G^m
00Ao_004Ok]og7^kNm`2Nk/4Ok/4Nk/3Ok/5Nk`017nkNkak_7^l0W^k2W^l17^k00Ak^W^kNk]k^`9k
^P04NiUkVWNJMiX3MgT026mILeU_5V[A@H/@@`@0200246400`aQ344<@@033442364234400`aQ360<
H@0336401A1Q460@H@aQ34400PaQ00l@HAB25:<LiB3U6<@DXaB3588DXaB3564HXB346:800aB200LD
PaBT5:@@H`aR344DH@0458801AAR48<DY1RT58<01AB200LHY1B2688DPa22468DP`025:<458<01Q23
5:<DXQBR588@PP<DPP04684HXQB2564246402a215:8DXQBQ5:8DPA21468DHQB258<00aB200H@HQ1Q
464HPR3U6:<25883484246400a22468<H@0246800a22468@HP0246803122468@@A10564@H@aP340<
@@aQ464<H@D@H@03368@HQ2300@@HP03484@PQ1R008@HP0:464<@111464@HQB1488DPQAQ58824680
1Q1Q468@HA1Q364@H@8@HP8@H@08440@HAAQ7<<@PQ1Q200@H08@H@<@HP@@H@8<H@04484@HPaQ3642
368446874646364020aR464<@0Q0364@HA1R3642464010aQ368<HPaR0Pb200<<HQ1R46800QB20AAQ
0A1R000016KeJ_AZm6[d1f[e16/E0V/F00M[5F/DKaA_5F/EKaI[5@08KaH4KaL2KcL4KcH>KcL01G<f
LcMc=flhKcL017<g1FmH0W=H00AcEflhLcQ_F@9cF09gE`9cE`03MeQcF7=G009cE`IcF0=cE`=gF003
LgUgF7MH00AgF003MgQgNGMi00agN@04MgQgMgMgMgL2MgP01GMiMiUgNGMiMgX01WMi0gMh00=gNG^I
NiT00W^I00=kV7NIMiX017NJ1WNI0gNJ00=kVGNJNiX01G^J00=kVgNKNi/03g^K0W^J00MkVg^lNkak
^g^jNk]k^P07Nk/6Nk`2Nk/01G^jNk]k^g^lNkd00Woo011R=S2_DI1b[W:aKY=b/GlBKaIg5W/fOgMc
>6[dGReEjP9NT00KEPaF;V:aI[1NTEH^DNeAcUh`I]A_=g]GOiMof7nFOe=jlfiaJJaTif2RH85TPFR1
J65T@6@0009P00=T000BJ01/0700M01l8GaSO49l8G00K01X05`0E01@05A1G01P06@03fP00V`016P0
3f`000=X06`0K00016`01g001g@000i`H7ESLRY^TFZbI[9Z/Uh@@De9C4e:A:L/02P00R@000XlPDE4
FLEV:5gWFPAVk7^gOoQoo0aog@=og0Eog@03OmaogGoM00Aog@9og003Omeog7oL00Uog0=ogA=og09o
g@=o_003OmaogGoM00Io_005OmaofgoKOk]k^`03Ok/01G^kOk]o^g^kNm`00W^k2gnk00Ak_7^kNk]k
_09k^`03Nkak^g^l00=k_0Qk^`=k^P0ANiUkVWNJMiUgV7MgMeMc>7=HMeQZdCD8108000a1468@H@03
44402`aQ440@H11Q460<@0aQ360@H11Q46001@a00PPP00L<80aP464DPQBS6:@H``026:<01QB3568@
HAB2684HX@8HXP<DPP085:<DY1BT58@DPaB2564DPP8DP@04588DPaB358@358<258802Q1Q58<HY1B3
588DPa22220@HQ220Q1R00PDPQRT58<DPaRT7<<HXQB20QB100LDPQR2684HXQB1588@PP0346401Q21
5:4L`ac26:4DPP8DP`0546<@HQ1R464@HP02464358801Q22468@HA1P360@H@8@PP/@HP04344<@11Q
488946401`aP464<HPaR244<HQ1R008@H@06580@HA1R58<@PQ1Q0Q1100<DHARS6:800Q1R00<DHA1Q
46400a1Q00DDPQBR464@H@aQ008<@@8@@@0<464@H1RQ464<@0`P460<H11R58<@PQ1R0Q1Q00@@H0aP
364<H@<@H@05344<@PaR468DP`0346400a1R464@H@03464334401110344<H@aR0Pa100<<HA1R4880
0Q1R0a1P00L@H@aQ364<H@a0364@H@0258814641584156800003I_EZm6[d00EZm@9Zm003J_E[5F[e
00A[5PE[5@05KaI[5FlFKaIc5P04KaH6KaL2LcLAKcL3LcL3KcL3LcL00flhKeQ_F004KeP00g=GKcQc
>003LeP2LeL6LeP017=GLeQcEg=G0g=H00AgF7MGMeMgE`9gF0=cN@9gF09gE`03MgQgNGMi00=gN@03
MgQgNGMi00IgN@04MgQgMWMfMgL2MgP;MgT3MgP2MgT5MiT3MiX00g^JNiUkV@02NiT00g^HNiUkV@02
NiT00g^JNiUgVP05NiX2Ni/00gNKNi]kVP03NiX5Ni/00g^JNi]kV`04Ni/027^JNi]k_7^lNk]k^W^k
NkX6Nk/3Nk`7Nk/3Nk`037^mOmiooF[I<<m5;VI<L[9^TW:aNa=c=`9c5P0EKaQoV7nDK]=AkUYbGY9N
LEY_GY5R/5i_CLa=ReG]FNeVTV/FMeMgMW]f009oV00<OiMo=W;EKS1Pieb3G65PHVR2J61P@E`00V@0
16P00V`000i`07@0N25h8G`QN25`06@0G25D@S`0D25P86@02fP066`00fP01F`01W0000Ad07P0M01d
009`000LM41dH7U4OTAoQGoeNiUgNGMIHU@i2dV:LRU=:2P0800/03bQBHMF;F9[HX]NAeh2J/io]Woh
Om`<Omd3Om`7Omd00goLOmeog@03Omd00goLOmeog008Om`7OmdAOm`00goMOkao_002Ok`017oLNmeo
g7^l0W^m0gnl00Uog7oKOmaog7oKOk]ofgoLNm`00g^k00=kg7^kNk/02Gnk2W^k1G^l00=k^g^lNk/0
17^k00Ak^W^INkYgV@=gVP08NiUkEgLfNeQcF7]iJ[0TQ08000@@HP<@@@03340@@0a000<<@004360@
H11Q46423642340222001Pa0460<H121588DP`<DX`076:<DXQR2564HPQRS6:800aB20aBR00PDXaBT
6:@HaART588@@1B10QBR00`DXaB3468DPaB26:<HY1RR464<@AB36:@258801A22368@HQB256400QAR
00<HXQBS58801QB200D@PQR28:<HPQB200<@PP03364@HAB2008DXP0=584HXQB2588DPa23368<HA1Q
488@H@a146400Q2200<@Pa1R46800a1Q0a2200<@PaB358800QAR00d@HA1R468@HA1R464@PQB16:<D
PA1Q468@PP0258401A1Q564<@0@P36400Q1Q00/@H11Q464@HA21560@@11Q588DHA1Q008@@@05564@
HQB2588DHP02588348801Q236<@HXa1R360<@08<H@D@H@043648@0aQ46423680111R368<H@aQ0PaP
0`a00a1P00@@HA1R344@@@8@HP@@H@04468DPQ1R364234401@a0464<@@a136400Q1Q1A1R00<@@A1P
3400111Q0Pa000D@H@aQ464@HAB1004@HP0000=W56[cJ_@00f[d0V[e0V[d16[e00=ZmV[eJ_D00f/E
00A[56/EJaE[5@M_5PA_5`03KaI_5flG00=_5`9_=`03JcM_=flg00I_=`04KcI_=flgKcL3LcL3KcL2
LcL00flgLcM_E`05KeP017=GKcQc>7=H1G=G0W<h0W<i00EcF7=GLeQcEg<h00=cF0EgE`04MeQcNG=i
LgT2MeP2MeL2MeP017MhMgUgNGMi0WMh00=gEgMiMgT00gMi0WMh1GMg0WMh00=gNGNIMgT00gMi00=g
N7MiMgT00WMh00UgMgMhMgQgNGNIMgUgN7NIMgT00WNJ0W^J0g^I0W^H1G^I00=gVG^INiT00g^J0W^K
00=gVg^KNiX017^J0W^K0g^J0g^K17^J0W^K0W^k00=k^W^kNkX00W^j17^k0g^l0g^k00Ak_7^kNk]k
^`9k_00<Nkek_7oLOo]c6ScaB@]V;6ZBK[9^T7Kb0Vlg02EZmV:eOiAoj7<CDM1JDeYAFU1NSfKAJ]1R
KeH>EPmJ3Eh>IY9ZmFlfMeMkMWMFMeMkEWnFOiEo=6jdIM1LjEbUI:=TXFAQG25P0003I004J002K000
2700M01h8Ga2O89hPFPPH002G0000f00I01X000:J00OK004L006M0007g00M21l07a0O61m@7iROnMo
k7oaIVmN4Egb?B]EQWYTCFLT03@0@>=EbF8YHVYRZUYXHVEE`6[^OmEonWoK00Qog@04OmaogGoMOmd5
Om`3Omd5Om`3Omd>Om`2Omd01WoLOmeogGoLOm]o^`9of`eog0=o_09k_004Nk]k_7^mNkd2Nk`00gnk
Om]of`05Om/00goLNmak^`02Nk/017_LNk]k^gnk0g^k17nk0g^k0Wnk1W^k1G^l1W^k17^j011gVGNJ
MgYgNGMGMeIkEGLgLeQc5F8]96<00001344<@P8<@@03340@@110008@@006340<80PP340<H11P111Q
00D<H0a0320<@11R008@H@09584DPQB36:@DXaB16:<PiAbS00<HPP03588DPAB1008HXP075:4DPAB2
58<DY1cV6:@00QB20QRS00`HXQBS58<@HQB2584HXQc46:<DPQ1Q468458800aB3488DP@0356401AB1
5:8DPQ1Q46800aB200HDPA1Q564HPQB258<258801A22464@HQ22588011B100HDPR3V564@HA1P5802
4840111Q468@HQ1R0PaR0PaQ0Q1Q0Q2100@@HA1R464@H@8DH@8@H@8<H@09464HXQS36:<DPAB0340@
HA21008HXP03584DHA1Q008@H@@@H0065:8@HA1P560@H1AQ0Q1Q0PPP00D<@A1Q468@HQ1Q008@HP03
464@HQ1R00<@HP8<H@<<@003464<H@aQ00<@H@@@HP08368<H@a1344<H@aP460<H08<@007220<@110
460<@0`P22000Pa100<<@0a134400Q1Q00H@HQ1Q464<@@aQ4402340010a1340<@11P0Q1Q00D@HQ22
368@HQ1Q00<<@005364@H@aQ464@H00234000`PP240@H00146400004IaEZm6[eJ_D3J_@;J_D7JaD0
1F/FKaI_=flfKaL00V/F0flG00=_5W<FKaH00flF26lg00Ac=WLfLcIc=PA_=`9c=`9_=`9_>003LcQc
=g<g00a_F003LeMcF7<g009c=`04LcQcF7=HLeL2LeP00g=GLeQcF@02LeP00g=GMeMgE`03LeT4LeP0
27MHMgQgN7MHMgUcNGMiMgX3MgP00gMHMgUgN@02MgT2MgP01GMgMgQgN7MgMgP01WMi00IgNWMhMgQg
N7NIMgT2MgP00gMiMgQgN@02MgT00gMhMgUgN@07MiX2NiT00g^HNiUkV@02NiT017NINiUgVG^I0W^J
0W^K00=gVg^KMiX01G^J00=gVW^JNiX01g^J00EkVg^JNi]kVg^k009k^P03NiYk^W^j00Ik^`03Nkak
^g^k00=k^`0@Nkak^g^kNkak_G^lOkYong]kCK90aUg/J[=Z/VjbMa<2KcL05fKeFW1c4gmBIY15JU7^
GW9NTEi_H]9_4f:AFU5F<5X?GRmRTF[CKaI_=gMFMgP00gMH00UkVWnJOgYk5ficHDaLa623H4800UP0
00AP06@0I01T009X009/000:L01/06`0L01h8Gb2O8=lXgPQL00>J00IK0000fP0K01/0002K0001700
K01`07001g@0021h07a1O:9lPGaPK:AehgnUOomoMEfXGFeE[Sd:FHQb9TeX=8959F7ZHVaRRUiZFTYJ
JeXXFPAZl7oEOoYofgoL37oM00Iog7oMOmeog7oMOm`=Omd=Om`00goMOmao_002Ok/2Om/8Om`017oK
Nk]ofgoL17nl0W^l00Ek^g^lNkek_G^l00=o_0Eo^`03Omak^g_L00Akg09k_0Mk^`03Nkak^g^k01Mk
^`0@MkYgVWNJMgYgNGMGMcIk=FlfLcIZe4g^744000@Q344346800a1Q444@@0024402460234005PaP
460@HAB2488@H@aQ340<80a1488DPaBS484DPQB37>DHXa216:<LiAS40aR20Q1Q0QRR00HHXaRR588D
PQ1R24425:<02AB26:<Ha1RT6:<HY1B3588DP`0258826:8011BS588DPQBR0aB20Q2200TDPAAQ564D
HAB15:8HXQB258400aB200<DPA1Q46400QB20QB301<DPQ1Q588DPQBS6:<LXQR2568DPaS57<DHHAAQ
440DP1B26:<@PP024680211Q368<HPa1240<HA21488246400a1R464DH@02564246801A1Q364@HQRS
5:800Q2100LDP@a0340@PABR584DH@034640211P3408@11Q484@Xa2146024642564010a0220@HQ23
0Q1R00<@H@a134400Q1R00<@HA1R46800Q1R00@@H@a1340@@@8@H@8@PP03484@HA1Q00<@H@03468@
HA11008<@@05368<HA1Q464@H00334000a1P464<H@02364020aR344880a1464<H@a03642464010a0
364@HA100`a000@@@11P460@H@8@HP0748<@PQ1R364@HA1R36800`aQ00<@H11Q36400Pa00A1P0@a1
000016KdJ_AZmF[e0V[d36[e1V/E00=_5F/EJaD016/E00=[5VlGJaL01VlF0V/F00=_=VlgKcL00flg
0flf0flg0g<f0W<g00E_=g<gKcQ_>7<h00=c=`]_F0McE`=cF006LeMcF7=HLeUcF7MH0WMG00IgF7MI
MeQcFGMHLgT2MeP3MgT3MeP2MgT3MgP6MgT01GMhMgMgN7MiMgP027Mi0WMh00=gMgMiMgT00gMi00=g
N7MiMgP00WMh0gMi1WNJ0W^I0W^H0W^I00Ak^GNINiUgV@9kV@9kVP04Ni]gVg^KNi/5NiX00gNJNiYk
VP08NiX00g^iNkYkVP03NiX017^jNi]kVg^K2W^k1W^l00]o^gnFOoMo^f9D@:=ERVkeK_Abm7Le009_
=`0>LcEZlUj@HY1NKeX]EPeJ;UY?HXmR/6kaI[1J;`9AkP05FU1RT6:BI_E[=`02LeL03gMHMeUgNW]j
Oi]o^WojOiQjmV7AF>UDI4`1D01H0004I0000f0PI01T0005K0001700O49lHga20g0000=/06P0J000
2FP06F`000AX06`0K01/00=`0003K01d07@000Ad009h000PO25lPWb2M41/06@0J81nQ7oeNaEA9eE:
DD/lj448CHYAbUW7HRIVIei9FTUJBUY;FVeF2UXYJa9oe7ojOmYog0Mog@03OmaogGoM00Eog@=og0Eo
g@=og0Eog@9og003Om]og7oM009og@Iog003Omeog7oL00Aof`Qog09of`03Ok]o_7nk009o_09o^`9k
^`=k_09o_09k_0Eo^`Ak^`Ek_0Ek^`=k_0Uk^`Yk^PIk^`03Mi]gVWNJ009gN@0?MgQg=WLfKcIc=Vke
@H`800@0124<HQ1R5:<DPa1R00@@@08@H003320<@0aP008@H08@H@05460<H11P340<@@0236424640
1Q2258<La1cS5:8DP`DDPP05568DHARR684HXP0358800a1R364@HP0<58800aAR588DPP03588258<0
0a23468@HP0446400aAQ588HPP026:<011R2588DHAB111B201@@PQ1R568DHQB26:8Ha1c46:<DPaAS
58@@PaB3568DHA1P584DXQRR0Q1R0Q1Q00L<H@aR368<HPaQ464@P@0258424682564011B2488@HA1R
111Q00H@PA1Q464@HA1R48825843464020aQ360<@@Q1468@PA22484246400`aQ464@H@0246400a22
6:@DP`024682344010aQ464@HA1Q0Q1R1a1Q00@@PQBR584@H0<@H@<@H003340<@@a2008<HP0;364@
HA1Q364<H0aQ464@PQ21460<H0043640111Q344<@0aQ0a1Q00L<H121460<H0a0344<H00246001a1Q
364<@@Q0360DPQ22008@H@09468<H@aQ344<H11Q488@HA1P008@H@0000AVmF[eJ_EZm@EZm0EZm@=Z
m0I[5@=_5P03KaEZmF[e009[5P=[5`03KaI_5flF00=_=P9_=`03KcI_=flg00=_=`9_=P9_=`03LcM_
=flg00I_=`9_>004LcQc=g<gLcL>KeP:LeP00g=ILeQgF003MeL2MeP00g=IMeQcN@03LgT00g=jLgUc
N@02MeP00gMiLgUgN@09MgT2MgP:MgT01WMhMiUgN7NIMgUgNP9gN@05MgQgNGMiMgUgN004MgT5MiX7
NiT00gNINiUgV@02NiT2NiX017^KMi]gVgNK0W^K0W^J00=gVWNKMiX017^J0g^K00AkVW^KNiYkV`Ek
VPAkV`ik^`0:Nkao^gnIOoYonfkEC<=ABf[gLcP2MeL2LcP05W<gKcMcF7]hJ_IJL5i?HY9NTF:@H[1Z
dFJaGTmAk57]FTmR/fKeI_M_>GMF0WMH0WMi01AkNg]jOk]ofgonOmioOGKHH@Y80D@0E01L0600I01P
84`PE21L86@00fP00f`00g000W@00W000fP00V@01VP06V`000=X06`0L0000W000g@000]h07@0N01h
07PPO45lPWaQM21/06@0009P0004KB1fT6h^B@L2C@L04ScX@@MEbUj@J_5RdEi/GT]NJeY<FT]JC58;
ER][4goFOo]of`9og0Iog@03OmaogGoL00Eog@Eog0=og@03OmaogGoM00=og@9og09o_003Om]o_7oL
00Mog0=og@Mog0=of`=og09of`04Ok]o_7nlOk`2Nk`3Nk/9Nk`3Ok/2Nk/00goLOk]o_002Ok`2Nk`4
Nk/4Nk`:Nk/017^jNk]k^g^k1G^j0g^k00Ak^W^kMkYgV`9gVP=gN@06MgQc=gMGMeIZe3TZ0P@000@<
HQ1R468@H@8@HP8@@00:320880a0460<80a0360<HA1P340436002`a0344<@0a0240<HA1Q588HPQc3
5:800QB20QAQ00DHXQBS5:8DXaRR00@DPP08364<@A22488<HA1R588DP@<DPP03564@@AB300LDPP03
5:8DPa23008@HP0;364<@A1R468@H@a0464DHAB2688DPP0256400aB1588DPP02588021BT6:<DHA1Q
488DPQBS5:8258800a1R448DP`026:@01AB2584DXAS348800Q1R00<<HA1Q46800`aR00@<HA1Q464@
H@<@HP08464DHAAR488DPQ22468<@@8@H@07484@HA1Q468@PQ235:800QAQ0Q1Q00L@PQ1R468<@@aQ
464@PP0236400a1Q364@H@0446401a23488@Pa1R344@HPaQ00<@H@8@HPD@H@0?564@HA1Q488DXQB1
464@PAB1560DHA1Q360<H@aR008@P`03468@H@aQ008<H@05340<HA22364<H0023643344336424643
36400a1Q364<H@0236801122460@@1100`PP0PaQ0a1Q00<<H@a036400Q1Q00D<H@aR364@@11P004@
HP0000=VmF[eJ_@01f[d16[e0f[d0f[e0V/E00=_5FlFKaD016[e0V[f16/F0VlF00A_5FleKaE_5P=_
=`03LcI_=Vlf009_=P03KaI_5flg00U_=`04KcQc=g<gLcH2LcL2KeP016lgLcMc=g<g0VmH0W=G00A_
F7=GKeQcE`9cF003KeQcF7=H009cF003KeQcF7=H00=cF09cE`9gE`9gF0AcF004LgUcNW=iLgT3MeP0
1G=iMgUgNGMiLgT00gMi00=cNGMiMgT00gMg2GMi00AgN7NIMgQgN@9gNP9gN@EgN006MiQgN7MhMgQk
N7^I0gNJ0W^I0WNI0g^H0gNI00IkV7^INiUgVW^KMi/4Ni/3NiX2MiX4NiX017NKNiYkVg^J0W^K0g^J
00=kVG^JNiX01W^K1G^k00Ak^W^kNkYkV`Ek^`0<OkYoo7ojOc=A1DT;IYE_5W]HMeM_>7Lg0WMF00ak
V7oINgU[5VJdHY=NTF:>H[1VdVkdJ]82HY42I]<016KfJaQgNWMh17Mi0W]j0W]k011oW7oMOiaoF7Kg
JJmDYT@2B01<05P0F41DHEQ0G21T00AX009P000:I01/06`0L01h8GaRO45d06`0J005I004J008K000
0g00K01/000;K00016P0K01/06`00W001G@000A`07@0O49l@P9l8@0FM21`06`0K01X0600G01Xh7Zd
KS1IB4dWDDU5:E58HY5kfgohJaART5i/GV/2GV`01ei]ETeJKV/DOmMoo7oK009og0Eog@9og004Om]o
g7oLOm`2Omd6Om`2Omd5Om`2Omd2Om`2Ok`00goKOk]of`07Om`3Omd4Om`2Om/7Ok/2Om/3Ok/017^k
Ok]o^gnk0W^k0Wnk0W^l00Eo_7nkOk]k^gnl00Uo^`9k_09k^`03Nkao_7^l00Ak_0Ik^`03NkYk^g^k
00=k^`03OkYk^W^j00Uk^P05MiUgVWNJMiYgV@02MgT01WMhLcQcEg]dHVl/b0840004368@HA1Q4642
364244001Pa0440@H11P340@@08@H005464@H11P3408800234001@aQ468@H@aQ34400Q1Q00<DPAB2
58800QB200L@HQB26:8H`ac36:@DX`0458<458800a22468DPP0258801aB16:<DPQ1Q468DPaBS008H
X`036:8DPQB2008DPP04488@HQ1R468346401AAQ440<@11Q56400QB100D@PA1R464@HQ22008DPP06
5:<DPQAQ464@PAB10Q210a1Q00@DPQc58>DHX`8DPP056:8HaAB3468<@@0646403PaP340@HA1Q364@
HQ11464DHA1R464HXQS3488246401`a0464@PAB1588@PQ2300<@PP8@P@8@PP8@HP8@H@07468<@@a0
464@PQ1Q36000Q1Q0Q1R00<@PQB246800a1Q00D@H111464DPa1R00@@H@0=460DPARS468@HA226:8D
PA21580@H11Q48400Q1Q00<@H0aQ46800PaQ00@<@0aP364<H@8<@00<364<H0aQ364@HPaR244880a1
460<H11Q0`aQ00<<H0a134400Pa100P<H11P460@@0aP3408@0a110aQ00<<@0aQ3640111Q0Pa00AAP
0AAR000016;eI_EVm6Kd1f[d0V[e00=[5F[eJ_D00V[e00MZm6[eJ_E[5V/EJaIZmP03J_D016lEJ_IZ
mV[f16/F00=_5VlEKaD00VlF0flg0VlG00=_=VlgKcH02Vlg16lh00M_=g<gLcMg=fmHLcM_=`02LcL0
0gMFLcMc=`05KeP00g=GKeQ_F004KeP:LeP2MeL2LeP<LgT017=jLgUcNG=i0g=j0gMi00=gF7MhMgT0
0gMi00=gNWMiMgT00gMi00IgNWMhMgUgNGMjMgT4MgP7MgT00g]iMiYgVP05MiX6MiT00g^IMiUgV@06
MiX00g^KNiYkVP04MiX3NiX3Ni/9NiX2Ni/3Nk/2Ni/5Nk/017^jNiYkVg^K17^k00ak_7oLOoaoTUV[
@>]J4FKDMgUgF7<gMcL2MeL07g^jNkUkVF/FI]ER]5jCFW1NT6/DNgQcEVlEKaI[5VlGKaQ[>7=jLgQc
NWMiMgYgNGMjNgYgNW]jMg]gNW]j009oV`0COeYbefV<D8940500D05DHea0F21P06P0I01P05`0D01P
06@0J0000V`000=d07aRO6800W000V`000AT0500H01T00AX009/0004J01/0700K002L00>K002J000
0f`0L01`0002M002L003M0001GPPO45l@WQ1L0001F`001UT0600L@1o5W[DHHUIR5fZGL]VKWnHOomo
nW=iHY9JCEi/FViNKEi_FViFKVleOmUof`02Om`6Omd6Om`2Omd=Om`2Omd2Ok`2Om`00goKOk]of`02
Ok/4Om/5Om`4Om/?Ok/017^lNk]k^g^k0Wnk0g^l0Wnl0W^l00=k^gnkOk/01Gnk1W^k17^l3W^k2g^j
0WNI0gNJ00=gVGMiMeP00W=H00m_=WMDFPhPIP@0320<HQ1Q444@H@aR464<@11036000Q1Q00<@H0a0
44000Q1000@@HAB1460@@08<8005340<H@aR468@PP0558802A22588DHQ1R5:<La1RT58<DPP0458<2
6:@3588246802Q22584DPQBR6:@DXQBS6<DHa1B30QB200<HXaBR5:800QB20aB30a2200@DPA1Q440@
H@<DH@06468DPQB2588DXQB2112200<@HQ2248800Q2200L@H@a0444DHARS6<DDX`02468011B25:8D
Xa220`a100<@HAAQ46400a1Q00<@HQ1Q46400Q1R0Q1Q00HDHQ1R468DXQC4488446402Q1R488@HQ1R
48<DXa22464DPQ210QB200<@PQ1Q46400Q1R00<<@A1146800Q2200<<@11Q58800QAR00<@HQ1Q4640
0a1Q00<DHA104640111R00H@HA1P464@HAB36:<246401Q1R464@PA215:<@PP8@H@03360<H@aQ00@<
H@8<H0D<@08<H@<<HP8<H@06360<H@aQ468@H@aQ0Pa00P`P00<<@0aQ46400Q1000D<H0aQ464@PPaR
008<H@03368@HA1Q008<H@<@H@03320@@1AP004DH@0000ARmFKeI_AZm0=Zl`aZm0AZm@9ZmP04J_E^
mFlEK_D2J_D2KaD00f/EKaI_5P02KaD;KaH016lgKcI_=Vlf1Flg1Vlh00Ac=flgKcM_>09_=`Mc=`=_
F004LeM_F6mHKeP2LeP7LeL017=HLeMcF7=H17MG00=cF7MHMeP01gMH0W=i00EcNW=iLgUcNG=j009g
NP=gN@03MeQgN7Mi00=gN@03MgYgNGMi00IgN@03MgQgNGMg009gM`9gN0UgN@04NgUgVWNJMiX2NgT0
0g^JMiYkV@04NiT4MiT=MiX8NiX7Ni/4Nk/2Ni/4Nk/00g^jNkUk^P03Nk/2NkX07G^kNkaoo7oaJW94
kE6_J]AkNG]hLcQgEgMhNgUkVW^IMgQ_=fKDGW9JLEI?GY5_=GMhOiIkMgMGLcP00VlG00=c>7=HMgP0
0WMi00EgNWNJNgUkVWNJ009kVP0@MgUgF7]GNeQoMgmhOeIbDEdWB4=00dP1D01H0600I004H002I003
J002K0002G00M01h8GQ1L21X05`0F01T0003J006K005L005K002L006K002L003M002L002M0001G`Q
O49l@WQ0M2001F`001AX06@0G01H07E1OeMo55UVEFIMb6I;L]1olGonOoecFEiaEPaJCEY_0Ui^00MJ
CUj?LcEof7oKOmeog006Omd2Om`2Om/00gnlOmaog00;Om`2Om/2Om`3Ok`7Ok/5Om/6Ok/3Om/00gnk
Om]of`03Om/8Ok/00g^lNk]k^`05Ok/017^lOkao_7^l0W^k0Wnk2G^k00Ao^W^kNkak_09k^`03NkYk
^g^k00Mk^`ik^P03NiUgVGNI009gV@0?MgUgV7MhMeMc>6lhLcMc4TV/52840110364@HA11008<@@05
220<80a0360@H@0246001110340<81100Q1P00<<H11P34000P`P00@<@0a1468@HP8DPP07568DPQB2
588DPAAQ58800QRT01XDXaB3468@HQB3488DPQB36:@HXaB2584@HPa1364@PA225:8Ha1S35:<H`aRT
588@@1B20QBR11B20PaR00H@HQ1Q584DP1104643564021AR588DPaB26:8H`aBQ48424682464011B1
5:<DPQ220Pa10Q1Q00`DPA22368<@A1R568@HPa1464DPQAQ4643564746400a1R464@HP0346800a1Q
488@PP03464030a1464@HA1R46<@PaB1360@HQB3584DH@<@H@@@HP03464@HQ1R00<@H@8@HP03464@
HQ1Q008<@0<@H@04444@HQ1R4682368010aQ460<80aP0a1Q00D<H@Q0340@HA21008@PP03364@H@aQ
008<@004360<H@aQ3607340336401a1Q468@HPaQ464<HA1Q008<H@07360<@0a0320880a036400a10
00D@H11Q5:8DPA22008@H@0;364<H11P360@H@aQ460@@@`P440DH00142000004H_EVmFKDJ_@3J]<0
0fKDJ_=Zm005J_@2J_D2J_@4J_D2J_H016kfK_E^mFke2FlE1VlF00=c5VlGKaH00VlG00A_=flfKcM_
=PI_=`9_>007LcMc>7<hLcM_=g<gLcP02W<g1FmH0g=H17=G0gMG0W=G0W=H00=cEgMGMeL00gMG00Ac
FGMIMeUgE`9gF003MgUgF7=i00=cN@04LgYcNG=jLgX3MgT00gMhMgUgN@04MgT00gMjMgUgN@07MgT0
0gMjMgQgN003MgP4MgT3MgX2MgT017]iMiYgVWNJ0WMi00=kNGNJNiT00g^I00=gV7NIMiT00WNI00=g
VWNIMiX02GNJ27^J1G^K00=kVW^KNi/02W^K17^j1G^k00Yk_7oLOoUc5dT^B@UVTWMiNgQcM`AgN@0G
NiUkMWLfI[=J<E8?CNiNLFKdKeQcN7>HLeQ_>6lgKaMc=gMHMgMkN7MiMiYkVP03MiX017]iNgYgNGMH
0WLg00]kEgnjOmUoVgKfIFY@HDP0C01D05P000EP00AT000;J01/06`0L01/07@0O89l`gR2J21X0002
H002J005K006L005K002L004K003L005M002N0001ga1O49lHG@PM01`06`0009X000MK01X06@0F01@
05@0LFAoEg[aFFI=AUVYGN]^lWo`Ooeoo7MHFW9F;5Y<FViNKEY=ERaR/7<eOmYoo003Om`5Omd2Om`0
0gnlOm]o_00=Om`2Om/4Ok`00goLOk]o_002Ok`00gnkOm]of`02Om/3Om`7Ok/3Ok`00gnkOm]of`03
Om/017nkOkak_7^l0gnk00=k_7^kNk/01Gnk17^l3G^k00Ao^W^kNkak_09k^`03NkYk^g^k00Mk^`Uk
^P=k^`Ak^P0@MiUgVWNIMiUgNGMhMeMc=f/gLeM^dD5Z308801114682364010a1364<H@a10PaQ0Q1Q
00@@H110440@@08@H004464<HA1Q3442320010a0344@HAAQ1QB200@DPAAQ588DP`8DX`0358<@PQ1Q
008DPP8DP`8DPP03488DPQB200<@PP0<240DPaRT7<<La1RS5:<DH@a0588DPaBR0aB200@@PQ1R468@
HP@@H@@DH@8DPP0358<DXaBR008HXP8DPP8DP@8DH@<DPP<@HP8@H@04468@PQB3588256400a1Q588D
PP0258801QB1564@H@aQ344@@@8@H@04584DHA1Q4643468010a0220@HA220a1Q00@@@@a1364<HP8@
PP04464<@11R6:<2564246401A1R58<@HQ1Q4680311Q00<@@11Q46800a1R00XDPaRT46<<@@aQ460<
H0PP340@H@8<H@8<HP8@HPD<HP03464<H@aQ00<<H@03360<@0a000@<H@04344<@0aQ364236803@aQ
464@HPaQ344<H@aP340<@@a0344@@0a0008@@08@H@05564L`aB1488<H@0246400`a0360<H@023640
1@aP364<80a046000A0P000016;eI_AVe6KC16KD2f[d00=ZmF[dJ_D016[e00=^mF[eK_D00f[e1flE
00A_5VlEKaE_5@9_5PE_5`03KcI_=flf00Q_=`A_>09c=`E_=`Mc=`=_F0=cF004KeQcEfmHLeL2MeL2
LeL2MeL2LeL00gMGMeIgE`03MeL2LeP6MeP027=HLgUcNG=iLgYcNG=jMgX3MgT4MgP<MgT2MgX00gNI
MgUgN002MgP4MgT3MgX8MgT2MiX3MgT8MiT;MiX2NiX017^INiYkVW^J1G^K1G^J2G^K00=kVW^iNkT0
0g^j0g^k00Yk_7nkOoag>Df>A<AEbg=GNgIcE`9gN09gN@0DNgMkEGmEJ]AJ<EH@DLiNDFKdKeQgN7Mg
LeMc=flfKaEc=WMFNiMkMP=kV@04NgUgNGMiMgT3MeL017MFMcMg=gMG0WnG00UoMGlDMViYATaR@01<
05P0G00016000f@01FP00V`000Ed07a2N49d06`000=T0003J01/06`0009/00M`00=/00=`00=/00=`
00Ed0008O01l@Wa2N45d8700K01`00A/000MJ01T05`0C00l04`PJFMo=W[>DDE51DU8CDQZT7o@Oo]o
o7]iH[ANCei[GVaNBei<FRaRSgMEOmYoo004Om`017nlOmeogGoM0goL00=ofgnlOm`017oL00=ofgoL
Om`01GoL0WoK00Eo^gnlOkaog7nl00=o^`06OkaofgoLOm]o^goK0goL1gnk00=o_7oLOk`01gnk00Ao
_7^lNkao^`Ek^`=o^`=k^`=k_0Ek^`=o^`=k^`03OkYk^W^j00=k^`=k^PQk^`Yk^P=k^`9k^P05NiUg
VGNIMiYgN@02MgP00gMGMeIg=`02KcH01VZa=@L<0P`0564@HP8@H@03460<@11P008<H@06368@HA1Q
464@@11P0Q1Q00D@H110340<@0a1008<80<@H@03564DPQB2008HPP066:8HXaB1440<@11Q1AB200<D
PaB258800QB200<DHA1Q58800aBR014DPPaR368DPQc36<<HXaBR588@HAB258<DPPa1588HPQB200<@
PP@@H@8DP@06588DPAB1468DPaBS0QBR00/DPQBR6:8DXQB1460@@11Q588HXaBR00<@PP8@HP03488D
PAB100<DH@04584DPQB15842688011AQ340<8@aQ0Q1Q00@DHAB1464@H@H@HP8@H@8@HP0;464@HQ1Q
488@PA1Q364<@1216:<DH@02440010a0468LaAS30a1Q0Q1P00<<@11P46000Q101Q1Q00XDPQB1568D
HQB36:@DY11R364@H@<<H@<@HPL<HP06344<H11Q464<H@aP1A1Q0PaQ00H<@@a0344<@0a136023640
10aR468@PPaQ0Pa000L<H@a0360@HAB2464<@0024403464248400`aQ360<H002360234400`aQ360<
H00246013601460134000005H_EVe6KDI]AVm@04I]@3I_D2J_D2J_@01f[DJ_AZm6[eJ_AZmF[d00AZ
m@03J_IZmF[e009Zm@M_5@9_5P04JaI_5VlFKaH2KaL3KcL00flfKcM_=`05KcL017<fKcI_=flg0flh
16lg16lh0g<h0g<g0VmH0fmI0VmH00=cEflhLcL017=G00Ic>7=HLeQcEgMGMeH3MeL017=GLeQgF7MI
0gMH00AgFG=ILeUcF09cN@03LgYcNG=j009cF@9gN@AgN003MgUcNGMi00YgN@03MgYgNGMi00=gN@Mg
NPQgN@03MgYgVWMi009gN@03MiYgVGNJ009gVP=gV@IgVP04MgYgVWNJMiX2Mi/017NJNiUkVG^I17^J
00=kVg^JNiX00g^J00=gVW^JNi/01g^K00AkVW^iNiYkVPEk^`0PNkao_7oLNi]NDDRREJ]cF7meLcIg
EGMFMgUgN7MfMeEkEF[eGU9IkeX?FU1Ve7=iNgQkUgMGLcM_=g<FLaMg=`9kM`03NiUkVWMi00=gN@05
MgQgEgMGMeMg=`02MeL2MeH02W]GOeMoN7mGNaM^3EBTB05<05@00e`000=P06@0I0000f@016P00V`0
00A`07@0N25d009`0003K01X06@000A/00I`00A/0004L01/06`0K003L005M0001gP0O45lPWb2M21/
06P000A/009X009L000JE21@HUcVGBMU[7mHM[0l`SRR?@M9:6I`Ok1ongolOkUVmEY=GTaJC5Y=EReF
;V:AMeIof`Iog09og@Aog003Om]og7oL00=og0=of`=og09o_09og004Om]o_7nlOm`2Ok`3Ok/00gnl
Ok]og002Om`00goKOmaog005Ok`00gnkOkao_00;Ok`2Nk`JNk/00gnjNkYk^P03Nk/3NkX<Nk/2NkX2
NiT2NkX017^kNkYk^g^j0W^I0WNI00mgVWNIMgQgNGMGMeIg=gMHKaIRD2c62048811Q3640111Q00@<
H0aQ364<H@L@H@08460@@0a1464<@@`P440@H@8DPP@HPP046:<La1RS68435645588041BR6:<HPaR2
588DHQ11588DXaBR5:<DXQ23468DPQRR0QBS00<Ha1BS48800Q1Q00@@PQB2588DXP<DP`065:<DPQ1Q
344@HAB11AB200HDPaBS6:<DPQ1Q58825:801AB1464@@11058800QRS00<DXaB258800QB200<@PQB1
58400QB200<@PQB156400QAQ00TDPARS564800a1368<H@a046000aB20Q2200PDPQB3588DPaB2468@
PQ1R0Q22010DPaB2484@H@aP364DPQB3564@@111340@HQBT6:@@HPH@H@05560@@11P464DPP034640
11R26:<DPQB20Q1R00@@PQ23468@H@8<H@05468@PQ1Q468<H@0336800`a2364@H@03368236400`Q0
360<H@02464248800aBS588@@003464246000a11468<HP0236801`aQ220<@0aQ464<HA1P008<H@8<
@008440@HA1Q464@PQ1Q340<H08<H@03340<H@aR00@<H@03344<H@aP004<@@0000=RmFKDI]@016KE
0VKe0VKE00AVmF[eJ_EZm09Ze09Ve003I_EZm6[d009Zm09Zm@=ZmP=Zm@U_5@04KaI_5FlFKaD5KaH3
KcH4KcL01FlfLcE_=G<fLcL01flg0flh00Ac=flhKcQ_>0=c=`9_F0=_F@A_>0Ac=`06LeMcF7<hLeQg
Eg=G0WMG00AgEW=GLeMcF0AgE`04MeQgFG=ILeT2LeP017MHLgUcNG=i17Mi17Mh00=gNG=iMgT04WMi
0gMj2GMi0WMj00=gVGMhMgT01WNJ0WNI00=gV7NIMiT027NJ00=gVgMjMiX01g^I00=kVW^INiX00g^J
00=gVW^JNiX01g^K00AkVW^iNiYk^P9kV`0ONiYkVg^kNk]kVgnmOme^m4d3FJek=WmdLcEkM7MEMgMg
EG]eNeEk=F/FI[ANLUX`GW5ZdflgOiMoV7mhMcL00VlG00=_67<gMeH00W]g17]h00YgNGMhMeMgEgLf
McMgEg]gNgIkEP=g=P0:OgEoMWmDMY=UC4Q5?05<05@0G003H004I002J002K0000fP0K01/0002K000
1GQ2O8=lHW00J00016`01W0000]/06P0K01/0700K01X06`0M25h8G0000=d00=h0005N21d0700K01X
0002K002J0008F00F01D04`0C41<X5e6IHMU[6HaOgY^;2`0=615B5E[J]=o/gokOoaofF/EFPYNBUH]
EPiB3Tg=GY9c=WoJOm]og002Om/8Om`00goKOk]of`04Om`2Om/00goLOkao_004Ok`3Ok/00goKOk]o
^`05Ok/01WnlOmao_7nkOkaog09o_0=k_003Ok]o_7nl00=k_004Omao_7nlOm`3Ok`3Nk`4Nk/00gnk
Nk]o^`0>Nk/<NkX>Nk/00g^jNkUk^@03NkT01G^jNk]k^W^jNkT00g^I00mgVGNHMgMgNGMGMcIc5W=G
J_IF42AT2008811P464010a10Q1P00@@HA1P460@@08@H004464DPQB24404340244001aAQ464DPQB2
584DPQB300<HX`056:8DPQB1564DP@02588031AQ584DPQRR7:<HPAAQ440@HAB26<@H``8DXP@DPP03
48<DPQB2008DPP035:8HXaB2008DPP095:8DPQB2588HXaB2464@HQ2200<DPP03584DPQB200LDPP07
488DPAAQ568DPAS26:800Qc400<DXQB258801QB200@@PAB1564DHP8DPP056:<DH@a0464@HP024640
0a22588DP@0246800a22468DHP02488258834880111R464<H1210a1Q00<@PAB246400Q1100<<@@Q1
34400Q1R1A1Q00@DXAR0560@H0P@H@06468@H@a0344@HQ220Q1Q00H<@0aQ364<H@aP340236423442
46433680111R464@H@aQ0PaP00<@PA2258800Q1Q00@@H11Q584DX@8@H008344<@0a0340<H@aP340<
H08@H@03360@H0a00088800;440<@11Q488@H@aP364@HA1P340<@P02364010aR464<H@aQ0Pa10PaQ
0@aR00000f;eI]EVe@02I]D7I_D01F[fI_EVe6[DI]@00fKe00EVm6[dJ_AZmFKe00=VmP9ZmP=Zm@9_
5@05KaI_5FkeJ_E[5P02KaH00flEKaI_5@02KaH016/FKaI_5VlF0Vlf16lg00A_5flfLcMc=PU_=`I_
>003KcMc=fmH009_F0=_F@=_>09_F0=c=`9cE`9cF003LeMcF7=G009gE`EcF0=gE`=cF@9cF003MeQc
NG=i00EcN@EgN@04LgUgNGMiMgP3MgT00g=iMgUgN@0:MgT3MgX037MiMgYgNWMiMiUgVWMjMiYgNWNJ
MgYgV@9gN@03MgYgVWNJ00=gVPEgV@EgVP9gNP04MiYgNWNKMiX5NiT00gNINiUkVP03NiT017^JMiYg
VgNK0W^J1g^K0g^J00=k^g^KNiX00W^K00akW7^lNkeog7/CEHQIcVkDOeEgEgmfOkP2OkT03GnFOgMg
Eg=HOgQgF6JdHW5R/F[eLcM_F6lF009^mP0>KaM_67LhNgQoVWnINiUkNG^IOiYkVG]FMcMg>09c>005
MeQkN7]HMeQgE`02NeL02gmfOgMoUgnJNaQ^<F4WC6980500G0000f000f@00fP00f`00V@00VP000=l
jgc6O6800f`000=X06`0K0001G000V`00VP000I`06`0J01/07aRO482M002N2401GaQN25`0700M000
0V`000=X06`0K0000VP000ML05P0D21@P5D4GHIR2`02L[802VY`NeUUc2@0=61=ReG@KaMoeGom0Won
00e[5eh>FPeB;UY?DPaB3EjbMeIk^goKOmaof`09Om`00goKOk]o^`05Om`00goKOmao_004Ok`00goL
Om]of`04Om/5Ok/017nlNkao_7nk0gnl0g^l00=o_7nkOk`00g^l0Wnl00=og7^lNm`01W^l57^k1G^j
0g^k17^j3g^k2G^j0W^i00=kVG^JMiT00WNI00egNGMhMeQg=g<gKaIVmd6^424400`P464@H0023202
34401A10464@HA1Q46000Q1000D@H1B25:<DPQ10008880<<@003460DHA2200<DPP0:464DPaRT6:<L
a1RS5:8DPQAQ58835:8258801aR27:<Y1AbS688@HAB2008DX`@DPP035:8DPPaR00PDPP8DXP07588D
PA22488DPA2246803AB200XHXQB2564@@1B27<@Li1c46:<DPP@@PP<DPP0558<DPQB2584@HP024882
58802AcU6:@DPQRS7<@Ha1BR588@PP0446800a1Q584DXP04588446800aB1464@H@0246401Q22464@
HA1Q368<@@8@H@09444<@0a0464<@11Q488DPA1P00X@H@04488<HQ1R468248804A21340880PP364<
HQ1Q364<@11Q468@PQ1Q3648@0aQ46400a1P00@<H11Q484@PPD@H@8@P@8@H@H<H@@@H@<@H003340@
@11P00<<H@09464<H0a0444@HA2346<<HQ1Q008@HP04464<@@a13442364136800003H_EVeFKE00EV
e@03I_EVeFKD00=Ve004I]=Zm6[dI]@4J_@00f[eJaE[5P02JaD01F/FI_EVmF[eKaH01V[e00=ZmV/F
JaD00f/E0VlE00E_5VlfKaI_5V/E009_5P9_5`05JcM_=flgKcM[=`06KcL00f/gKcM_=`02KcL4KcP0
16lgLcM_=flg0Vlh0fmH0flh0VmH00=c=flgLcL027=G00=c=g=HLeL00g=H00AgEg=GMeMgF@9cF@9c
F004LeMcF7=HLeP2LgT00gMhLgQgN002MgP2MgT01GMHMgUgN7MgLgP017=i0WMi0WMh1GMi00=gN7Mg
MgT00gMi0WMj00=gNGNHMiT00gMi00QgNWNIMgUgN7MiMgYgNGNI0WNJ2WNI00EgVWMjMgYgVWMj009g
VPEkV@EgV@03NiUgVWNJ009gV`03NiYkVG^J00=kVP=kV`=kVP03Ni]kVW^J00=kV`0TNkao_7njOg9R
L5H@JY=^m6lfOeMkN7]GMeQkF7mHMeQkNGoHOkYcF6JbHY1NCejBH[=RTEiAGW9V]6KEI_I[5flhNeMk
N7]g0WMG0W]g00IgF6/GI]EZmVlFLcL3KcL046lfLcMgEWMGOgIoV7nGOgMnlff:D<E08T@1D01D05`0
0V0016@00VP00V@000MP06@1J05hPgQRJ01/0003J005K0001700K01/06`016P000YT06P0M45d8F`0
L01l`gcSN:9/809X000VK01X860QI21T06@PH21L84`0B41DheeSILM^JGLBOeIbcgK`OeQUlA`0:01=
BDe<K_IomgolOoikgV:fENm9[E8_FVmRdfKcKcIgV09og09o^`03Om]og7oL00Eog006Om]o^gnkOk]o
fgnk0W^l00=o_7oKOm`017nl0gnk2WoK17nk0WoK00=o_7^lNk`00Wnl00=o^g^lNk/00W^l00=o_7oL
Nk`00W^l00Ek^g^lNk]k^g^l01=k^`=k^P04Nk]k^W^jNkX3Nk/4NkX5Nk/3NkX4Nk/5NkX3NkT3NkX2
NkT3NiT00gNIMgUgN002MgT02WMhNcMc=flgI_LmS0P0100<81101Pa000@<H@aP340<@0<@@003460@
HA1Q00<@H08@@003464@H1R1008DPP0<464DHAB358<La2CU8>@HXaB2688DHAR20aB200@HPQRR6:<H
X`<LX`036:<DXaB300XDPP03484@HA1Q00<@H@03584HXAB1008@H@03568@PQ2200TDPP0:488<@@aQ
584HXQc35:8@H@`P58426<<011BR588@PQ1R0Q2211B20Q1R00D@PQ1Q464DPA21008DP@05688DPQB2
588DXP026<<02QB2488@HA1Q468@HA1P580DPABR0QB200@DHQB2588DP@@@H@03460@HA1Q008@H@@@
HP8@H@04340@HA1Q340?464010aQ464@HQ1Q0Q2100D<HPa1240<H@aR008<H@0=464DPQ1Q360@H@aQ
464@H1AP440@H0a036000Q1Q00@<H@a1340<@@8@H@06364@HA1Q464@PQ1Q0Q1P0PaQ0Q1Q00<@PQ1Q
3600111P00L@@0a0340@H1BQ5:8<H@022202344010aQ464DXa1R0`a100<<@0aP46000@a100000ekE
H]ARe002H]D00f;DH[=Re002H]@01F;CH[=R/f:cH]<00VKD00QVeFKDI]AVdfKDI_EW5V/F0VKe00=[
=flgKcL00V/F0Vlf0V/F00A_=VlgJaIZmP9[5P03JaE[5V/F00=[5P03KaI_5FlF00A_5PQ_=`03KcQ_
=flg00M_=`03KcQ_=flh00=_>003JcU_>FmI00A_F@05JeQ_F6lhKcQ_=`03LcL01G=GKeQcEfmHLcL0
0W=G00=cF7=GLeP00W=H00=cEg=HLeL00W=H00=cFG=HLeP01G=H0W=i00AcN7MgMgMgN09gN@05MeQg
NG=hLgMcN005LgT00gMiMgQgN006MgT00gMhMgUgN@02MgT3MgX00gNHMiUgN@02MgT3MgX2MgT00gMj
MgUgVP03MiX00gNIMiYgV@06MiT027MiMgYgNWNJMgYgVWMjMiT3NiT3MiT017NJMiUgVWNI0WNJ00Ag
VgNJMiYkV@AkVP=kV`MkVP0;Ni]k^g^kNi]og7oHNgIc5VkfHW9F3`02FS0045i`GY9R/f9bH[AgFGoj
NmagVVlgI]=V/V[DJ]=V/fJd0fKD00AVeFKeI_I[5`9_F@0@JcM[5flhKeQ[>6KfH[=NLEY`GY1R/fKC
I]AVdfKdI_<2I]<03F[dK_E^mFkDK[=YkEDXB8A88D`PE21H@5a0009L809L0003H01T0600009L0003
F01P0600009P0003I01P06@000AT009X0005M65hPWB2M65`8@02J00016@PH41T06P00V0000]T86bQ
N@9/X5`PH01P8610H65HPeQR009H@@0RF41<HECTEBI9J68:IViVSVkCL_A^SfYZM_AIcRR3;:A0i4e7
HW1kMWOKKeQVmeYcDNmF<FKEMeQo^WniOkYk^goMOm`4Ok`00goLOm]og002Om`2Ok`5Ok/01GoLNkak
_7^kOm`017nl2gnk0goK1Gnk1G^l00Ek^g^lNkak_7^k00Qk_0ek^`03NkYk^g^k00Mk^`Ek^P=k^`Ak
^PAk^`=k^PEk^`Ik^P05NkUk^W^jNkYk^@05NiT2NgT2MgT01gMhMeMg=W<gKcIRmSU;00880004320@
@0a0340336400`a1364<H@03364234000`aP364@H@0246400aB2568@@00246402QRQ584DPQBR6:8H
XaB26:@TiQbT0QB200@HPQQQ688DXP8DPP<HPP096:8HXaRS6:<LXaRS5:<HY1BS00@DPP08688LXaB2
484DPAAQ588DHP8@H@8DP@065:4DXQB2564@HAB20aRR00<DPPa148800aB200L@HA1R488DXQS47<@D
X`0246400aB1588DPP024683488011235:<HXaBR0QB200@DPA1R488@H@<DP@05684DPAAR344DH@04
58800a1R464@HP0246801AAQ588DPQB158800Q1R0a1Q00@@HQ1Q468DP@8@H@@@HP09464@HQBT6<<D
H@a0464DXaB200<@H@03468@H@aQ008@H@03564DH11Q00H@H@8@PP09388@PPaR368<H@aR468DXQ1R
00L@H@03460HP1A0008@H0<<H08<H@03464<@11Q00@@H@05468DPQB1460<H00436401@aR464<HA1P
46400a1P0P`P018<@1BR6<@@Pa1S468<8@PP344@PQBT464@@0aQ340880a0460134400004G]AN/ejc
G[@2G[<05f;CG[=N/ejbH[9Rdf:cH]=ZmFKfH]ER]6[EKaI_5F;DH[=ReFKDH]AZmFlFKa@00V/E00=[
5VlfKeL00Vlg00=cEg=HLeP00W=H0Vlg00=c=flfJaH00f/F00=_5VlfKcH00VlE00E_5VlfKcI_=flf
00m_=`03LcM_>6lh009_>0=_>@04KcQ_>FliKeT4KeP5LcL8LeL3LeP00g=GLeQcF002LeP00g=ILeQc
F008LeP2MgL027MhMeQgF7MHMgQcN7=gLgP5LgT00gMhMgMgN006MgT00gMhMgUgN@02MgT2MgX017Mi
MgQgNGNI0WMi17Mj17Mi00EgNWNJMiYgVGNJ009gV@EgV003MgUgNWMj00AgNP03MgUgVWNJ00=gVP05
NiYgVW^IMiYkVP03MiX017^JMiYkVGNJ17^J00=kVg^JNiT01g^J01QkVG^JNiYkVWoKOmUomG]GES8m
:c3X?DY5ZDh>CNe9Ze7^GY5VlfKdJaAZm6[cJ]<4J]@01V[CI]AR/eYbGY=Re09R]003I]EVmV/E009V
m@0:H]ENTeYaGW5RTEY`ETmF;eY`GY42H[804EjBGW9FDEH`GW9RTFZbK[1ZCeeYB<M4I4b3D:9DXU22
D8400e2000=@PE1QC4400Ta200Q@HTa2C45<8D`PE41H85@P0e0P01=D85aPI:1TX621I:5TH5a0G61H
HUB4D4=@8T`1D05DHUBTF:=DY002C6808daSC:A@iE3UC<E<a4AP@654`TdVCFM=J56YDLYEje8=ENaE
b5h9ITi=RD58CJaVTV[BI]9W5FLGIcM[5flGLaMg=gnJOo`00Won00IogGnlNkaog7nlOk/3Ok`3Om/0
0gnlNkak_005Ok/027oLOm]o^goKOmaofgoLOm/FOk/01W^lNk]k_7nlNkao_09o^`03Nk]o^gnk00Ak
_0ik^`03NkYk^g^k00Mk^`Ek^P=k^`Ik^P=k^`9k^P9k^`04NkYk^g^kNk/8NkX2NkT5NiT01G]iNgQg
NGMhMgL00W<f0VlE00ANLS48200<008@@0<<@005360<H@a1468<H@0534405PaQ488<H@a0360<HA10
340@H11Q580DPAR27:8Ti2D56:<@HA11568DHAB20QR200/DPQBR6<<HXQB1560@HAB26:8DPQRR008H
X`<DXP04588@HA1Q58826:8011BR5:4HXAB10QB200<DPA2146400Q210Q1R00P<@11Q5:4HXQBQ6:8D
PQ1R112200`@HA225:<HXQBR5:<DXQB2564DPAB258<246801Q1Q584@PQB37>DHa08DPP8HXP035:8D
PQAQ00<DP@8DH@08464@@AAQ564DPQ1R464<H@8@H@06468@HA1Q464@PQ211A1Q00<<@A1Q58400QRR
111Q00L<H@a1344@HQBS6:<@HP0346400a22464@H@03468446401@a0464@HA1Q34000Q1Q00D@PA22
368<HQ22008@HP04364<HQ22588246403Q10460@HA1P360@HA1P7:4DH11P360@H110460646400`aQ
464@H@0246400aB0460@H@05364446401111440@H0a00PPP00D<@0aQ364<HPaS008<@`04344@HAC4
5882460010aP460@HA1P0@a100001EjaG[9N/f:dH]D00VKe00]VmVKgJaMZmV[eI]AVmFKfH]EN]5Yb
009JD008FVmFLEI`DRm:3TX?CPm:3`9:3P0>DTmBTUZcF[=JTUjcI_=VmFKdI_I_>7=ILgUgN@9cF006
LeM_=flgKcM_=W<g0VlF00A_5FlFKaI[5P=_=P=_=`03KcI_=flg00M_=`Ac=`=_>005KcU_>6lhKcQ_
F@04KeP5LcL016mHLeM_F6mH0W=H0W=G1g=H0W=I1G=H00IgEg=HLeQcF7=hLgL2LgP4LgT00g=hLgMc
N006LgT2MgP2MgT01gMhMgUgNGMiMgQgNGMh009gN@9gNP04MgUgN7MiMgT5MgX2MgT00gMjMiYgN@02
MgT01GNJMiUgVGNHMiT00WNH0gMh00=gNGMjMiX017NJ00=gVGMjMiX00WNJ0g^J00=kVGNJMiX00gNK
00=gVW^KMiT00gNJ00AkVW^KNi]kV`=kVPEkV`=kVP0=MkYg^g^kOmQcN6;EEQ1Al58`FY5N]5jcFTl0
0U7/00EJ;EX^DN]=be7]009B3P0>ERmF3U7]BL]9ZdW<ALa9bdF[AJY9kDh?CPi>3@9>3P05BLa5Zd69
AHQ5ZP02AJ/01dF/AJ]5ZdF[AJU1RT6[00=5Z`0<AH]9c4W<ALi9S3TX<68/03A1?6=0Q4C50TC400E4
aD36@:I0YT260094QP05@6E4QTB6A6A8I003A4801DASB8A4PdARB8<00TR400Y8I4R5C:E<adbWA8I<
YdRXB8M8QP94Q@0@A:E4YTBU@8E4YTC6A>M9:DD7>:DhY322<:8di3TU@FL2AFL03TF8BNeF;dg<CJQJ
36[CLeUo^gonOo]o^G^GNiT2NkX00gnJOkaog@03Ooh2Om`037nlOmao_7^lOk]o_7nkOkaofgoLOm]o
_0=k_004OkaofgoKOk/2Nk/2Ok/017oLNk]kg7^k1Wnk0g^k17^l2Gnk00Ik_7^kNkak_7^kNk`2Ok/0
17^kOk]k^g^k0g^l67^k17^j0g^k27^j1G^k0g^j0g^k0W^j00AkVW^jNkYk^P9k^@=kV@06NiYkVG^I
NgQkMgMg0WMF00IgEg<fLcI_54h@98D2300544002a1Q364<@0aQ464<@@`P344<HPaQ36000PaQ0Pa0
0Q1Q00d@H0a0464DP1B1688HXB3S:DLHY111568@H@02440011R17:8DPQB20QBR00TDXABR588DXQRR
5:8@HAB26:800QBR0QB200@@PAB2588DPP8DXP036<@H`QB200H@PP0;484DH@a0340@H1215:8Ha1BR
564@HP044880311R368@PaBS488<HA22588DHAB258<DPP8@HP0;568DPPa158<DXaBR588DXQS46:8@
PP0346401Q1R584LXQAQ340@H@8DH@8@H@04220<@11Q464246801A1Q360@HQ1Q46800Pa1111Q00XD
PAB2588DXaB2464@HPaR344@HP<@PP8@HP@@H@8@HP0548<@HPa1340<HP034640411R464<80a0464D
XaS45:<@Pa1R364@H@a1364@PQ210Q1Q00h<80a0364<H0aQ340DH233584@H0aQ460<@11P0Q1Q00<@
PA1Q46400PaQ111Q00<@PA1P46000Pa00Q1Q0PaQ00D@HA21464<@110008@H006340<80a0364<H0aQ
0`aR00H@@A1Q5:<DXa1P4642364246414680000HH]1N/6KeI]EVmF[fJ_ER]5jDFW9FDE8`CRm1kD6/
=FX]:2d7:@DTaAbS688HHAR20aR101THHQQQ664HXQc47:<La2D6<DPeJCV:@La9kTh=DRiFD5jBJ_A_
5WMGMgQcN7<gKcM_5`03KaH016lEKcE_5VlF0Vlf0Vlg00=_=W<eKcL00flg00A[=flgKcM_=PI_=`A_
>003KcU_>6mH00=_F003LeMc=W<g00=c=`04KeQcEfmGKeL=LeP02W=hLeQcEg=HMeMcEg=HMeQgN7=h
0g=g00=cN7=iLeP00W=H00=cMg=hLgT00W=i00AcF7=iLgUgM`9gN003MgUgN7Mh009gN@03MgQgNGMh
00AgN@9gN09gV003MgUgNWMj009gNP03MgQgNGMi00EgN@05MgQgNGNHMiQgN003MgL017MhMgUgNGMj
0gNJ00EgVGNHMiUgVGNJ00AkVP03NiUgVGNI00EgVP04MiUgVWNIMiX4NiX3NiT5NiX017^INiYkVG^k
0WNj00Eo^W^jNgMkEg]H009kN@06NiUoV7]HMcIc5flG0V/G00EVmV;EH[ER]6;E009R]007G[=N]5jd
G[AR]5jcFW800e9A00ABD59ADU5FL09JL@9B;`03CRm><58`00=><0=>;`9B;`0@DS1>3dG_BNm=ke8@
ERiR:eF9?<H`03P0A418H4b2C842C682D4800e@QD25D0@05F2002UA0E61@HE22D8=DPUB3D49@85@P
0Ua000=L@F11G4400U`Q01QL@Ea0F21H@5a0F45DHE10B21<@DR2?64h@3AQ<88i1DV8GT]V[flDKaEZ
mV/GIaL2JaL017<gOiEon7ok0gom0Wol1WoL00Ak_7nlOkao_09o^`9o_09k^`Qo^`03Nk]k_7nl00Eo
^`03Nk]o^g^k00Ak^`Eo^`=k^`04Nkak^g^kNk/7Ok/5Nk/00g^lNk]k_002Ok/017^kOkYk^g^k0g^l
27^k0g^j1G^k00=k^W^kNk/00g^k0W^j00=k^G^jNkX00W^j0W^k2G^j00Ak^G^jNkYk^`=k^P04Nk]k
^G^jNkX3NiX2NkX03G^iNiUk^G^iNiUkVW^IMiUgMgMfMeEgEWLf009gE`06KaIZdSf;54<800`P1A10
0Q1Q00<<H@aP46400Pa10PPP00<<811034000`a000H@HA1P464@HAAP6802584011R07:8PiARS0QR2
00<HXaB246000QbQ00`HPA1Q440DHARQ6:<HXQRQ6:8DPAB25:8258801ABR584DXQRR5:800aB200DD
XQRR5:8DPa2200<@HP03488DPQB1008DPP0:464@H0aP588LiAB2344@HA22588348801PaR48<@PQ1Q
488DXP<DPP0;68<DPQ1R464@HQ1Q344@HQB3488<@@035840211P344@HA1Q468DPQRR5842460=4640
10aQ344<@0a0111Q00<DPA1R46400a1Q00D@HPaR368DPa2200<<H@D@H@06364@H@aR344<@0aQ0a22
00<HXQRS46400Pa00Q1Q00P<HA1Q364<@0PP344<HA1Q0Q210Q1P00L<@0`P340<@0aP340@H0024640
111P484@H@a00Q1P00<DPA2148402Q1Q00D@H11Q464@H@aQ008@H@03480@HA1P008@@08<H004340<
@@a13402360246402Q10464@PQ1Q440@HA1R464@H11Q0A1R000045I_FW1Re5jdFW9:<3f]=F/]2B37
66DD8P`1420<80P00P000P@000@000P03208008000840003000400`000H8000E320D@AAR78<TaBd8
=FXm[DW^DRiFL6;CJaI_>6mILcM_=VlEKcIc=Vlg009_5P05KcI_=flGKaIc=P0>KcL2KcP00flgLcQ_
F005KeP016lhLcMc=g<g0W=G00=_Eg=GKeL02FmH1g=H00EcEgMGMeQgF7=G00=cF0=cM`07LeQcFG=H
LeQcN7=gLgP00W=i0g=H00EcNG=hLgQcN7=i00AgN@9gN003MgUgNWMi009gN@05MgQgMgNIMiQgN@04
MgX5MgT01gMjMgUgNGMhMgUgV7Mh00=gM`05MiQgN7MiMgUgVP02Mi/017NJMiUgV7NI0gNJ0g^K0gNI
1GNJ00]gVGNJMiYgVgNJNi]gVW^KMiYgVG^I00AkVP05Ni]kVW^JNiUg^P02NiX01G^IOk]o^gnkOm`0
0Wom00=ogGomOod017om0WoM00Io_7oMOoiooWoMOm`2Ok`02GoKOmaooGonOoeoogonOkakVP02Oi/0
17nkOkYkVWnj17nk00YkVWnkOmeo^g^JOk]og7nkNi]o_09o_@0<OiaogGooOoaoVfY?D<<l0400B01@
05`P0V000VP000=T06P0K00017000VP000UX86A0H41LH6B1K:5/HFa0J0000f`000A`07@0L01/009`
00A/009X000;I01H04`PB84lH42RDDEMj7<COkUon@02Oo`01gonOomoogonOmeooGon009oo@9og0Mk
^`03Nkao_7^l00Ao_004Ok]o_7nlOk`2Nk`7Ok/00g^lNkek_007Nk/2Nk`00g^kNkak^`02Nk/2Ok/=
Nk/00g^lNk]k^`04Nk/00g^lOkak_003Nk/00gnjNk]k^`03Nk`4Nk/017^jNk]k^g^k0g^j37^k47^j
00=k^g^iNkX02W^j0W^J00=k^G^jNkX00g^j00QkVW^INiUgVGMgMgQgEWLg0W<f00I_=FlDIXle:@`2
200232002111464DHA10444<HA1Q4443364234001``P440@@11Q364<@0aP008@H008464DHAB1588D
PA1P6:4HX`8HPP086:8Ha1S56<@L`QR1584@@08DH0076:4H`b337:8HXQ1P34400QB200TDPAB2488@
PQB26:8H`aB26:800QB200T<HA2348<@HQ1Q584DPQ2158400QRS00@DXaB2464<H@8@PP06468DPQB2
8>DDPa220Q1R00L@PQB1564DPQS58@HHX`03588011B3488@HQ1Q111R00L@PQB2584DPA10464@HP03
48800aB2484@H@0346401AAQ468@PQB25640111Q0Q1R0Q1Q00<<@0a146801Q1Q111R00H<H@aR488<
PPQR36434642344346402PaQ344<@0aR468@PABR484@HA1R1A1Q00D<H11Q364<@@aR008@PP0348<@
PQ1Q008@H@05460@80a0364<H00234002@aP460@HA1Q340@H11Q688DXP0248800a1Q440@H0034640
11RS5:<@PQAQ0Q1Q00@@HQ1Q464@H@8@P@05464@H0aP340<H0023404364346802A11344@@@`P440D
Pa1Q340<H00136800007<Jd][Be99<DLPa0Q10001@0000/8010Q540HHR2R8<<Ta2d6<BLaB3V9008m
ZP<mRP0;?JXmRCUX=DLa9RT69<@PY1b3548D8@02544254803Q12548HQ236;@LiRTW^DPiFD6KDKcIc
Mg=hLeL7KaH5KcH>KcL3JcP2KcP2KcL3LcL2LeL00fmGLeM_E`08KeP6LeP3LeL00g=HLeUcF002LeL2
LeP2LeL01G=gLeQcFGMHMgP00WMg0W=h17=i00EcN7MgLgQgN7=i00AgN@03MgMgN7Mi00AgN@9gN09g
V09gV@EgNPEgN@03MgQgMgMh00EgN09gV003MgQgV7NJ00=gNP03MiUgN7NI00=gVP9gV`04NiYkVG^I
NiT7MiX00gNIMiYgVP02MiX017^KMiYkVG^I0g^J0W^K1g^I00=kVW^INiX00W^K1W^k0Wnk00=o_7oL
Om`02goL0WoM0Wom1GoM0WoL00Aoo7okOoaoo0Yoo@AooP9oo`0;OoioeglhJO14YS@0A01@05`0I01X
0003K0001g00M25h8G@QK01X06`000=T0004J01/@G1QL442K2000f`0J01X0002K002L003M003L000
3F`0H01L04`0A694aDTVHNQ^cg^HOoMonWok009oo0=oo@9og@=og0Ak_0Ak^`Ek_0Ao_003Ok]o_7nl
00Ao^`03Nk]o^gnk00=o^`9o_004Nkak^g^lNk`4Nk/4Nk`00g^kOk]k^`02Nk/01GnkNk]k^g^kOk/0
0g^k0gnk00Ak^g^lNkak_0Ek^`=k_0Uk^`ek^PQk^a=k^P9k^@Yk^P03NkUkVG^i009k^PAkVP9kV@0D
MiUgN7MhMgMgEg<gKcI_=6lCIZhe:0P1324@@@a1468@HAR1440<@0@<@@05340@H11P440<80024402
34023602460011AP464@HA1Q0QB100DHPAB1688HXQRQ00DDP@04580@H1AP58026:401AbR8><LX@`P
22001A1R00H<HA1Q584DXQB2564258800a22368@P`0258801AAQ580DHA1R48800aB20Q2200<@HA22
58800QB20QRS00H@HQ1Q464DPAB0584258800aRS7<@L``02588248401A22464@HAB146800Q220QB2
00@DHQAQ564DPP8@PP8@P@03464@PA2100L@H@8@P@04464<H0a1364946401AAQ468@HQ1R56800Q1Q
00D@HQ22464<@11P008@H@<<@08<H@<@H@0@344<8@a1584@PQ21364<@@aP460DPA1Q440@HAB24642
36400a1R464<H@034642460010`P340<H0a00PPP00h<80a0440<@110560@HAB1588@PQ1Q460<8110
0a1Q00<DPaRS58800Q1Q00<@HQ1Q46400a1Q00<@PA2048400Q1Q00<@H11Q360010aQ00L<HQ1R468@
HP`Q1008000234433401344000035@`EKP000080000;200D81@P768XiSE:?Je5cdh?FU1NT@02H[40
0f:AI]=Zm002J_<01flELcIcEg<fLeMc=V[d00=ZdP0NJ_=ZdfJcGY9JLEH^CNe1[3U9<BPY1bC678<D
@100540HHR2T;@PiSDH@EY9W5VmHLgQc=G<fLeMcF6lg26lf56lg00=_>6mGKeL01FmG16mH17=H0g=G
1G=H00A_FG=ILeQcE`=cF009LeMcMg=gLeQcFG=HMeQgN7Mg009cN0EcN@=cN003LgUgNG=I009gN@03
MgMgN7Mh00AgN@9gN09gN@07MgYgNGMiMgUgNWMiMgX027Mi0WMh0gNH0WNI00=gNGMhMgT00WMj0WMi
00=gN7NIMiT00WNJ0WNK00AkVW^IMiYgVP=gV`AgVP03MiUgVWNK00=gV`03MiYkVW^J009kVP=kV`03
NiUgVG^I00AkV@9kVP03MiYkVW^K00=kV`03Nk]kVgNK00EkV`03NiagVgNK009gV`EkV`=gV`03Ni]k
VW^J009kV`06Mi]kVg^JNiUkVW^I0W^J1gNK0WNJ00=kVW^KNi/00g^K00ao^goMOoioogoMMaUYK4`P
B01H05`0J002K0001G00M01d0700K0000VP00f@000AX06`0J01T00EX0006I01P0600J01/07000g@0
0W0000U/06@0E01DP5DTCFQIjVlDOmT00Wol00AooG^kNk]k^P9k^`=k_0=k^`Ak_0Ak^`Ek_003Okak
_7nl00Ao_003Nkak^g^k00Eo^`03Nkao^gnl009k_003Nk]k_7^l00Ak^`Ak_003Ok]k^g^k009k^`9k
_003Nk]k_7^k00=k^`03OkYk^W^j009k^`9k_0Ek^`Ak_003Nk]k_7^k00Mk^`]k^P=k^`ak^P03NkUk
^W^j009k^P=k^`04NkYk^g^kNkX3NkT;NkX3NkT3NiX2NiT2MiT03WNHLgUgN7MGLcM_=W<dLa=RKRS5
204<8A1Q468346401Q22468@@@a1364<HP<<H@8<H0H<@005460@@11P464@PP0358801aB1564DPQc4
6:8HPAB100@DPP<DP@<HX@089>@L`QAQ58<@HQ22588@PP8<@@0:460DPAB2588DHAB26<DDXPaQ4682
58800aAQ584DH@02464011B1564DPQB31aB2010@HQ1Q464@HAB1580DHAB2468DPQS47<@Ha1B2584@
HP<@PP03468@HA2200<DPP0:464DPQRS8@HHXaB2484@PQ1Q4844464010a0440DPQB2112200<@HQ1Q
4640111Q00D@HQ1Q468@HAAQ00<DPP03564@HA1Q008@HP@@H@0>484@PQ1Q3408@0aQ464DPQ1Q3208
80a0464@P@H@H@05444@@1AP584@H@0246801122464@H@a00Q1Q0a1P0Pa000H<H0a0340<HA104442
46400aAQ464@H@034640111P440@@11Q0QB30a220a1Q0a2100L@HPaQ464DXQC3488@H@0236400a1Q
488@PP024648344010aQ344<@0a00@a1000041BY7>/LPS45>FM1ZTX<FTeR[V:?HY5Ze6lGJ_E_5W=G
0WMF0WMG00AcEg<gLcMc=`9cE`=c=`09LeMc=W<fLcIgEgMFMeMgF7<g009c=P0;LaAZdf:BGW1F;U8=
AN`eJBSV78@@0@0230001aA388Da:DG]GXm_<g=F00=cE`05KcMcEg<gKcI_5P04KcH2KcL00flfKcM_
=`08KcL00f/gKcM_=`03KcL00f/hKeM_E`04KeL3LeL01VmHLeMcF7=HKeQcF0AcE`AcF003KeUcF7=H
009cM`=cE`03LeQcEg=H00=gF007MgMcEg=GLgMcN7=iLeP00W=i00AcF7=hLgQcN@=gN@05MgMgMWMg
MgMgN003MgT017MhMgMgN7=h1GMi00=gN7MiMgT01GMi00AgN7MiMgQgN09gV0AgN003MgMgN7Mi009g
N@9gN09gV008MiUkVGNJMi]kVW^IMiYgV@AgVPAgV@EgVP03MiUgVWNJ00EkVP03NiUgVG^I009kV@06
NiQkVG^INiUgVW^I17^J0W^K00AgVg^KMiYkVP=kV`AgV`03Ni]gVW^K00AkV`0>Mi]gVWNJMiYgVg^K
Mi]kVWNJNiUkVW^INiYgVP=gV`EgVP07NiYkVG^JNi]gVW^JNi/00W^J00YkVgoLOo]ofgmGKQ9HQU00
E01X00A/00AX00MT00=P00=X009T009P0005I01X06`0K01`0003K0002VP0G81I0Uf3GNQRSWNGOoAo
nGoL0g^k00=k^W^kNk/01g^k0g^l1G^k17^l00=k^gnlOk`00Wnl0g^l0W^k1Gnk00Ik_7nlOkao_7^l
Nk/2Nk`00g^kOk]k^`02Nk/2Nk`2Ok/7Nk/2Nk`3Nk/3NkX6Nk/2NkX2Nk/3Nk`017^kNkak^g^k0g^j
0W^k1g^j0W^i0g^j0g^k27^j00Ek^G^jNkUkVG^i00Ek^P06NiYk^W^jNk]k^W^i0g^h0W^i0g^j00Ak
^G^jNkYk^PAkV@04NiQkVG^INiT2NiP2MiP03GNGLgQgN7=GMeM_=VlCJ]5B3AaR200<@AAQ008@H@06
364<@@aQ364@H@aQ0`a11@a000<@H0a034000`a000H@H1AP584DPQBS5:8358801AB46<@L`QR15840
0QB200HDXaB2584DPAB06:4268400ac37:8DP@0558802Q22468DHAB1588DPAAQ588Ha1BR0aB200DD
HQ1R444@HAB1008DPP03488DPQBR00DDPP04468@H@Q0240346401aAP564DHA1Q344@HAB2008HXP03
584@PQ2100D@H@035:8DPQ22008@HP03588HXaBR008DP@06488DPQ22484DPA1Q0a1R00HDPQS35:8@
HA1R488258800a21464@H@0246402Pa0464DPQAQ560DPAR2564@@@a00`aQ0Q1Q01<@HQ1Q588HXa21
2408@@aQ464DPA1P340800`P340<H11P464@P@03464234001QAP460@HA1P360<H@<<H08<@005360@
HA1Q464@H00346400a11344@H@074642460346401Q1R488@HQ1R464@HP8@H@05480DXQBR464<@002
46401a22468<H@aQ360@H0aP008@P@03460880P000<<@007344<H@aQ364<@@PP34000@a100001d7@
BLeNCUj@H[5ZlflD009_=@04KaE_5VlFLcL2KcL016/EKaE[5F[e0V[d0VKd00=ZmFKeI_D00VKd00AZ
mF/EKaE_5P=_5@06KaIc=flFLaIc=gLg0WMH0g<g01I_5FKeFW5>3T6/<BLPPQ@0300801Q19<DeJdX?
H]E[=g=HMgUgN7=HLcM_=`=_=P03KcM_5flf00Q_=`03KcI_=flg009_=`A_>004JcQ_EfmGKcL7LcL5
KeP7LeP01VmHKeU_F6mHLeQcN0=cE`9cF003LgQcF7=H009cF0=cM`9cF09cF@9cF003LgQcNG=i00=c
N@04LgQgMg=hLgP4MgT017MhMgMgN7Mh4GMi1WMh00=gMgMhMgP00WMh0gMi00IgVGNJMiYgNWNKMiX3
MiT5MiX00gNIMiYgV@02MiT3MiX2MiT6NiT3MiX00gNINiUkV@02NiX017^IMiYkVgNJ17^J00AkVgNK
Mi]gV`AkV`05Mi]gW7NKMk]gV`02MiX2Ni/2MiX01GNKMiYkVg^JNi/00WNK0gNJ00AkVgNJNi]gVP=g
V`AgVP03Ni]gVgNJ00UgV`0<OkaooWoNOg]fUFC4E01T06P0K01X06000V@00VP01f@000EX06@0I01X
06`000=X0006I01T85@QF01D06000f`00V@000QP`55TGLIB2EkBOoYomg^i2g^k1G^l1G^k1G^l00Eo
^gnlOkao_7nk009k^`=k_0Uk^`03Nkak^g^l009k^`03Ok]k^g^k009k_0Ak^`03Nkak^g^k00Ek^`03
Nkak^g^k00=k^PEk^`=k^P03Nk]k_7^l009k_0Ak^`Ek^P=k^`=k^P03Nk]k^W^j00=k^P=k^`=k^P03
Nk]k^W^j00Ak^P03NkUkVG^i009k^P04Nk]k^W^JNiX4NkX01G^iNkMkV7^HNkT01g^j1W^I00=gVG^I
MiP00WNH0WMh00=gUg=gLgL00W=H00M_=VlEI]=1Ra0P200<@00346400`aR464<H@02364010aR364<
H@aP0PaQ00<@H@aP46000a1P00H<H11P464@PAB05846588011B35:<HXQB10QAQ00@DPQBR588@P@8D
P@8HXP03688HPAB1008DPP04568DXQS35:8358803aB1568@HA1Q588@PQBR6:<HY1S45:<@PPa1464D
PP035:800aB3588DPP035884468030a1364@HA1Q560DHAR26:8DH@`P464@PP8DPP04488@HA1Q4882
4840111Q484DXQB20Q1R00L@PQ1R464@@A1Q468DPP0248803aB26:<DPa22588HXaBS468<@A1R588L
a1RS588@PP06464356400aR2564@H@0248800a1Q468@H@04464248801PQ148<DXa21584@H@8<@088
8004340<H11Q588246400`a0464@H@03464334002PaQ488@HQ10320<H11Q488<H0a00PaQ00<<H0a0
34000Q1Q00X@PQ1Q464<@11Q588@HA1P464@H08<H@03368@HQ1R008@H@0;468@HA205:8@P@aQ2408
80aP368@H@03340246001@aP364@H@a032000Pa00PaP10aQ0@a00@aP0@aR00000eZcG[9_5@04KaD2
JaD4J_@00fKdI]=Vd`04I]<2I]@6I_@7J_@01F[eJ_AZmF[dJ_D00flE00=_5W<fLeL00W=G015gMgMF
KcAV/Ei=BNde:2253044000054@Y247=GXm[57Mf00AcE`03KcM_5VlF00=_5`I_=`9_=P04JcIc=Vlg
KcL3JcP2KcP8KcL3LcL00fmHLeMcE`03LeL5LeP9LeL00g=HLeMcF004LeP3LeL2LeP2LeT00g=iLgMc
N005LgT00g=hLgMcN002LgT3MgT017MhMgMgMgMg17Mh1WMi00=gNWMiMgT00WMi00=gN7MiMgT00WMi
00=gN7MgMgL00gMg0WMh17Mi0gMj00EgVWNINiQgVGMi00AgV@03NiUgVGNI009gV@06MiQgVGNIMiYk
VGNI1G^H00=kVGNIMiX00WNJ17^J00AkVGNJMiYgVPEkVP03Mi]kVg^K00AkVP03Ni]gVgNK009gV`Ak
V`9gVP03Mi]gVWNJ009kVPIgVP9kVP04MiYgVgNJMiX5NiX8MiX4Mi/027^lOoiooWnFNYIP@eP0H007
I0001V00G01L05`0H41PH0=TH007H65T86@0I01P06@0I2000V0P00=L05P0G0000VP000]/06P0H01U
05VTGPAAifKeOoaong^j00Ik^`03NkYk^g^k009k^`=k_0Ak^`Ak_0=k^`=k_003Okao^gnk009o^`03
Nk]k_7^l009k_0Yk^`=o^Pak^`Yk^P03Nk]k^W^j00Ek^P04Nk]k_7^lNk`3Nk/7NkX3Nk/=NkX00g^k
NkYk^P05NkX00g^iNiUkV@02NkT00g^jNk]kVP06NkX00g^iNkQkV004NiT6NkX00g^iNiUkV@02NiT0
0gNINiUgV002MiP03gMhMgIgUWMfLeIc=flgJaE_=VJd>D/800@0440@H002220010a1340<H11P0Pa0
0Q1P00<<@0aP36000PaP111P00<<H11P46000QB10aBR00/DPQR25:8DXQB2364DHAQQ564<@A1R008D
PP03488<HA1Q00<DP@08564@HA1R444@HARR6<@DXP<DPP0B564<@@a1464@PA225:4@PQBS7<DHXa22
344@HAR16<<HXQB20Q1R0a1Q1A1R00dDPQ1R464@HAAP564HXQR2568@@@a0344@H@02488246400aB2
6:4DP@02484011B158<@HPa10Q1R018@H@a1340@HAB16:<DPa2258<HXa22464@HQ22464880a04642
58400aB2484@H@024640211R464<@1AQ7:<HXQAQ568248800aB2488@H@054643468248825:80111Q
440<@0aQ211Q00LDHAB2464@H@aQ360@H00236402a22464<H0a1360@H0aP340400PP34000PaP0Q1Q
00<DPA2246400a1Q0QAQ0a1P0PPP00<<H@Q024000a1Q00@@@11P584@H08<H006340<H0aQ460<H0a0
0Q1P00H<H11Q464@HA1P464236001Pa0360@H11P484@H@8<@04<HP0000=Je6;eI_D00f[e0VKe00=V
e6KCI]<01fKC00=Ve6KdI_@01fKd1F[d00QZmF[dJ_EZm6[eJ_AZmF[d0V[e00=Zm6[eJ_D00VlF00=_
=W=GMgP00WMi00IcNV/GG[A9kc4Y644310001QbU>JaB;f;eJaIcF09cE`06KcE_5FlFKcI_5Vlf1Flg
00I_=W<fLcMc=W<gKcL4JcP00flhKcM_=`09KcL8KeP3LeP6LeL00g=HLeMcE`02LeL5LeP3LeL2LeP2
LeT00g=iLgMcN006LgT2LgP3LgT3MgT00g=hMgQgM`04MgP01WMiMgQgNGMiMgYgN@9gNPUgN@03MgMg
N7Mg009gN09gV004MiUgNGMiMgT4MiX00gMjMgUgN@03MgP027MiMgQgMgMgMgQgNGNIMiP2MiT00gNJ
MiUgV003NiP017NINiUkVGNI0WNJ00=gVgNJNiX00g^J0WNJ00=gVgNJNiX00g^J00=gVg^KMiX017^J
00=kVgNKMi/02gNK00=gVW^KMiX01GNJ0W^J00AgVWNKMiYkV`akVP03MiYgVgNK00=gW005NiaooWol
Oi]];003F0000e`0H01T0003I0003V00G01H85R0F<1DhUSQG<5Y0fCSI81TH6A0I202H2000f00I01T
0002G00035P0I01X0600I21U85gWFNEB1f/eOoYo^P9k^PYk^`=k_0Ak^`Ak_003Nk]k_7^l00Ak_0Ik
^`9k_09k^`03Nkak^g^k01=k^`Ak^PEk^`04NkYk^g^kNk/5NkX3Nk/3Nk`7Nk/3NkX3Nk/=NkX01G^k
NkYk^g^jNk/00g^j00=kVG^iNkX017^j00=kVW^jNkX017^j00Ek^G^hNkUk^W^I009k^P9k^@9kV@=k
^PAkV@05MiUkVG^IMiQgN@02MgP02GMeMgIgEVlgJcMVmF[fFU8]2@02100010a0460<H0`P0`a00Q10
00DDHA10460@H110008<@0@<H0093408@0PP360@P1BQ7>DHa1BS008DPP8DXP07588@HAR2684HPQB2
48800QBS00<Da1BS48<00QBR00P@PPaQ344<@11P584DPQBR1aB21A2200TDPa23488@HPa1564HXQc4
6:800Q1Q00<@HQ1Q46800a1Q00H@HQ22588DPQ22588458401QB2568@H@a0344@H@@@HP04488DPAB1
584248400a22364@H@02564021B1588@PQ1R464@PQB258<2488021AQ464@H11Q468<H@Q046434842
46401a2258<DPa22464DHQRS008@H@8@HP03488@HA1Q008@H@03364@HQ22008@PP03364@HA22008D
X`03488@HA1Q008@PP8<H@H@H@05588@HA1Q3408800236401@aR364<H@aP34000PaQ0PaP00/<@0PP
320<@11Q588DXaBR588DPaB200D@H@03460@@11Q00888007340<H@aQ364@HQ1Q44000a1P0`aQ00D@
HAB2464<H0a000@@H08@H@06468<@@aP460<H11Q0Q1P00@@HA1R364<@04<H@0000=Ne6;CH]<00VKC
0fKD36KC0VKD16Kd00AZdf[dJ_=Zl`iZm0AZm@0=JaE_5VlfKcMcF7=IMeUcEg<fJ]9J;3V:66@00P00
00T@0R24>FYB36;BLeEcEWMFLcD00VlE00=_5VlfKcH00Vlf26lg00I_>6/hJcQ_>6/hKcP3KcL016lf
KcM_=flg17<g16lg00Ac=fmHLeMcF0QcE`03LeQ_F7=H00EcF0EcE`EcF004LgMcN7=iLgT2LeP2LgT3
LeP00g=hMgQcN@02LgT00g=hMgQgM`02MgL3MgP00gMgMgQgN@05MgT00gMhMgUgN@05MgT4MgL01GMh
MiQgUgNHMgP00WMi0WMj00=gVWMjMgT00WMh00AgMgMGMeMgM`9gMP=gM`03MgQgV7NH009gV@9gV0=k
V0AgV@AgVP9kVP9kV@9gVP03Mi]gVWNJ009kVP04NiUgVW^JMiX4NiX017^IMiYkVgNK0WNJ0gNK00=g
VWNKMi/00WNK00=kVgNJMiX01WNJ0W^I0gNJ00=kVWNJNiX017^J00=gVW^JNiX00g^J0WNK17NL00Ik
VWoiOm]fDE@0C003G0000f00I01T0002H00035PPF61DX5CPFB=I0EdRID=M8ecPH<1TX09PH005H41P
06@0I01P0002G002H00025P0G61Q@5WVCJIJBG]fOoT4NkX4Nk/017^jNk]k^g^k0W^l0W^k0g^j1G^k
00=k^W^kNk/00W^k0W^l37^k00=k_7^kNk/01g^k00=k^W^kNk/00W^k0W^j00=k^G^kNkX017^j1G^k
00=k^W^kNk/00W^k17^j3G^k0g^j0g^k17^j00=k^G^jNkX00g^j00Ak^G^jNkYk^`9k^P9k^`9k^P03
NiUk^W^i00Ak^@9kVP04Nk]k^W^kNk/2NkX017^iNkQk^G^i27^I0W^j17^I0WNI0WNH015gNGMhMgMg
MGMFMcE_=V/FKaIVe4ha9:L400P0440@H11000<<@003460@@110008@@0<@H003340<@@a100<<H0<<
@008440@H1BP9BHQ1QS45:8HPP8DXP08588@HAB2688DPQS46:<DXP<DX`085:8HXQB2588@PQ1R484D
P@HDPP07688HXaRS6:<DPQ2246800`aQ0a1R00@DHQB17:8L``8DPP03464@PQ22008DPP8@HP03484D
PAB1008DP@8DH@DDP@06564DPA21484@HPa10PPP00<<HA1Q46400aB100D@PAB1584DPA21008DP@0=
484@HA1Q468@HA1R364<@11Q564DPAB248800a1R0Q2200D@PA1Q464<HQ1Q00<@HP@@H@03364@HA1Q
008@H@<<H@05468@PQRR488@H@02340336400`aP464@H@02464336400`aP340<H0034642340010a1
364<H@aQ0Q1Q00<<H@a0340010a000<@@11P46400Q1Q00<DPQBR48800a1Q00D@H0PP340@HA1P008@
@004340<80PP360246400`aQ440<@002220020a0460<H@aP464DPQ1Q3602340446002a1Q48<<HPaP
460<H0aQ368<@Pa144400Q1Q0@aR00000f;DI]=Vd`04I]<3I]@9I]<4I]@3I_@00fKDJ_=Zl`02J_<:
J_@00f[eJ_AZm005J_D2JaD066[eJaIc=gMHLeQcEgMgLeI_=UjBANh/iP`0100<02B5>F]B;fKdKaAc
Eg<fKaE_5PA_=PY_=`03KcQ_=f/h009_>0A_=`04LcMcEg=GLeL3LcL01VlgLcMc>7<gKeQcE`A_F0ic
F004LgQcEg=GLeL5LeP017=hLgUcNG=i1g=H0W=h1G=i0W=h00EgMg=hLgUgNGMh00]gN@04MgQgNGMi
LgX4MgP00gMiMgQgN@02MgT01WMjMgUgNWMiMgYgN@AgN003MgMgEg=G00=gE`9gM`03MiUgNGNI00=g
V@=kV@03MiUgVWNJ00EgVP03MiUgVW^I00AgVP06Mi]gVWNJMiYkVWNJ0gNK00=gVW^JNiX00W^J0WNJ
00=gVgNJMi/00WNK0gNJ0gNK1WNJ00EgVGNJMiUgVG^I00EgVPYkVP03MiYgVgNK00=gV`06NiYkV7oH
Om]ndUaP0U0000AL0600H01T009P000:G21LH5RPD>=A0ddUDB=E95E5DBD2D@<01FDSG>=PXEa0H000
0f@000aP05`0G01L050PH>1UX5GXCJMRSgoBOoT2NiT01g^jNk]k^g^kNkak^g^j00ik^`05Ok]o^W^k
Nk]k_004Nk/01G^jNk]k^g^kNkX00g^k17^l0W^k00=k^W^kNk/00W^k00Ak_7^kNk]k^P=k^`Uk^Q]k
^`03NkYk^g^k00=k^`]k^P=k^`06NkYk^g^kNk]k^W^k0g^j17^I0W^J1g^j00Ak^G^INiUk^PEkV@=k
^PEkV@=gV@9gN@0=MgQgMgMeMeEg=G=GKcIc=f[DBNlLI0@032000Q1P0Q1000@<@110440@@0D@H003
464<HPaR008<H@05360<@0a0340@H00256001aBQ6<<DXaBT6<@HPQB2008@P`05388DXac45:8DX`02
58801AB3588DPQRR58400QB200DDXQB25:8HXaBR008DPP0:5:<DPaB25:<DXQS48@HHa1B248823400
211Q364@HQ1R584HPAbR7:<258800aB3588@PP0548801AB1588DPQB258400QAQ00@DPAB2588HP@8H
XP036<<HXaB200<@HP8@PP0;588DXAB1584DHA1Q488DPQ22484DP@044642468246401A1P464@PABR
48800Q1R00L@HABR4:<@PPaQ468<HP0546800a22484@P@04464336401PQ1368@HARR5:<@PP8<@006
364<H0a0340<HA1P1PaQ00L@HA22488@PA22464<@003364246801Q1Q364<@0PP340@H0<@@003584@
H@aQ00@@H@03364@HA1Q00<@H@05488@PA1Q340<@@02340010aP464@HA1Q0a1P00<<@0`P36000PaQ
0Q1Q00<@H0a034000Pa000@@H11Q460@H@8<HP0:364@H@aR368@PQ1R464<@110464146800003H]AV
dfKC00EVd`9Ve0IVd`03I_=Ve6KC00UVe0IZm003J_=Zm6[d00UZm0UZm@04JaE_5W<fMeL2MgL03g<d
J_1=k2cW4040010388DiJUY<KaAgMg=FKeM_=`02KaH00flfKcM_=`06KcL016lfKcM_=flf36lg0W<g
0Vlg00A_>7<gLcMc=`9cE`9_>003KeQcF7=H00AcE`03LgMcEg=G009cE`05LeQcEg=gLgMcE`05LgL0
0g=HLeMcF002MeP00g=GLeQcF005LgP02W=gLgQcEgMHMgUcNGMhLgQgMg=h1WMi00=gN7MiMgT00WMi
00EcNGMiMgQgMgMh00AgN@9gN0QgN@03MgQgNGMg009gM`=gN09gM`06MeMc=gMGMgMgUgMi0WMj3WNJ
0gNI00QgVW^JNiYkVWNJMiUgVW^J0WNJ0WNK00IgVW^IMiYkVWNJNiX3MiX00g^IMiUgVP02Ni/;MiX4
MiT01W^HMiUkVWNJNiYgVP=kVP03MiYkVW^J00MkVP0=MiYkVg^JNiUkUgnfOmQoDVh@E4A<0500H000
16@000IP86B0H>5I8e4SCB@3CDD024U5B@=8hDd2GB=HX5QPG202I0005600G01H85P0E01<@5e1IL5I
iU7;J_=ocgoFNiUk^G^jNk]k^W^kNk`3Nk/5NkX7Nk/2OkX017niNkYk^g^k1G^j00Ik^g^lNk]k^W^k
NkX2Nk/3Nk`6Nk/00g^lNk]k^`0ANkX00gnjNk]k^P0=Nk/00g^jNk]k^`02Nk/4NkX01G^kNkYk^g^l
Nk/037^j00=kVW^jNkX00g^k00=kVW^jNkX01G^j1G^i0W^j00AkVG^jNkYk^P9kV@03NkYkVG^I00=k
V@03MiUk^W^j00EkV@AgV@9gN00<LgMgMGLfLcI_=f/EKaI^ld6<328400`P11101Q1P00@@HA1P440<
@@<<H@06360<@0a0320@@11P0QAP00dHXA21364@HAAQ584DPQ2248<DXb3U9@DLa00258801`a1568D
PQB1588DHA1Q00<DPP045:8Ha1c46:8258802aBR588DPQB2488DPQBR6:8DPQB148400Q1Q00L@HQ1Q
584HPARR688DPP06488246801122584DPAB10QB20QB1018DPQ1Q560L`B3S7<8DPQR26:<DPQ22468@
PABR7<<L`QAP4642340010aQ488@PQ210Q1Q00H<@11Q464@HQB2564346000aB0484@P@0346400aB1
5:8@PP0246400`aR468@HP0246801Pa1360@H11P464@H08@H@03360<@0aQ008<HP04488DXQBR5842
46401PaQ3608@0a0364<H08<@08@H@<@HP07588DXaS35:<@HA1046001@aP00H@H@aQ340<@1104602
44024600111Q360@H@aQ0Pa000<@H11Q46401A1Q00@<H0a0340<@08<H005464DPAB1464<H@033402
46024640111P340880`P0Pa000<<H11Q46400PaQ00@<HPaQ364@HP@@H@4@H04<H04<HP0000=Re6KC
I]<01VKC00=Re6KCI]<01FKC2FKD00=VdfKDI_<016Kd00=Zm6KcJ_@00fKd0f[d2V[e00E^m6keJ_EZ
mF/E009_5@0AKcEcEWMhMiQcN6KEDPh/iPP0300@02cWCNiVdf/fKeEcN003KcH2KcL00f/gKcM_=`02
KcL3KcH@KcL3KcP00flgLcMc=`02LeL016lhLcQ_F6mH0W=H0W=G0VmH17=H1W=G17=g0W=H00AgF7=H
MeQcE`9cF0EcN006LgMcN7MgMgMgN7=i0g=h0WMh1GMi00=gN7MiMgT00gMi0W=i0W=h0W=i2gMi00Eg
NWMiMgUgN7NH00AgN007MgMgN7MhMgUgN7MgMgP00WNI00=gNWNJMiX037NJ0gNI00EgVW^JNiYkVW^K
00=gVPAgV`0=MiYgVGNJMiYgVgNJNi]gVW^JNiUgVGNJNi/00W^J1gNJ0WNK0gNJ0gNI2GNJ1G^J00=k
VgNKNi/017^J0W^I00UkV7niOmIo=fE:E21@05P0H0000f@000MP861PG>5A9E4TCDE=A002BDD024DU
A@@l`DSSB>A<Xe1RG202I0003V00G0180500F01<P55VHLAAI5H:MeEodWngNkT2NkX017^kNi]k^g^l
1G^k0g^j1g^k0gnj00=k^W^kNk/01G^j00Ak^g^lNk]k^PAk^`=k_09k^`03NkYk^g^k00=k_09k^`ek
^P=k^`Ek^P]k^`03NkYk^g^k009k^`9k^PEk^`03Nkak^g^j00Qk^P9k^`04NkYkVW^jNkX5Nk/7NkX2
NkT=NkX2NiT4NkX8MiT2MgT037MhMgMgMWMFLcM_=f/EKcIV/CU92004008@@003320@@11P00@@H0<@
H@8@H003364<@0aQ008<H@04360<@0a0460246403QAP580DXQBR488@HAB26:8DPQ1R5:<PiBT66:82
58801`a0588LY1B2464DPQBR00@DPP056:<DPPa1488DPP0248<3488031B25:<DXQBR588DXaRS468<
@A1R588DP@8HP@035888@0a100D@PP03468@PQB1008DXP@DPP05468DHAB18><L``02584258800a21
488@P@02484011B26:8DPAB10Q1Q00@@PQBR588@PPH@H@07488DHA1Q564@HAB148400Q1Q00<<@11Q
48400Q220a1Q1A1R00H@HA20464@HA1P560446401@aR468DXQRR4840111Q00<<H0aQ46400a1Q00h@
H11Q464@HA1R464@PABS6:8DXa1R440@H@aQ0`aP0`aQ1A1Q1A1P00P@H@aQ464<@110360@HA1R0Q1Q
0Pa000<<H@aP34000Pa00PaQ0Q2200<@HQ1Q34000Pa00Q1P00<DPA1Q46400Q100P`P00<<@11P3640
10aQ0PaR00<<HA1Q46400Q1Q0@a00@Q00@QR00000f;DH]=Vd`02H[<2I]<00fKBI]=Vd`08I]<6I]@3
I]<2I_<01fKCI]AVm6KdI_=ZlV[C009Zm09Vm0MZm008J_EZm6[dJ_AZmFkdK_EZm@=[5@04KaA[5Flf
KcH2LeL03GMgLc=ZkTg[:<D80000504eB59=Jc5_EG=G009[5@04KaI[5f/gKcH3KaH4KcH8KcL016lf
KcM_=f/g1Vlg00=c=flgLcL017<g0W=G00=_F7=GKeP01VmH0g=G0g=H0W=G0g=g0W=H00AcEgMGMeMg
M`AcM`03LeQcN7=H009cM`=gM`AcN003MgQgMgMh00IgN003LgQcNG=i00=cN@04LeMgMgMgLgT;MgT0
0gMjMgUgN@02MiP3MgP3MiP2MgP2MgL2MgP01GNHMiUgNWMjMiT00WNJ00=gVgNJMiX00WNJ0WNI0WNJ
00EgVGNHMiQgVGMi009gVPAkV@05MiYkVWNJNiYgVP03NiT02WNJNiYgVWNJNiUkV7NHMiUgVW^I0WNJ
00=kVWNJMiX00gNJ0WNK00=gVWNIMiT01WNI1WNJ0W^J0WNJ00AkVW^KMi]gV`9gVP=kVP0;MiYkVW^G
OmEo]G[cID]<8TP0D01L0002I0002F00G21HXE44CB9=@de4BDA5A002@@<01T3S@81<PE22F65L809T
0003H01H050P0098000:C<1AIe5VENMZlGncOmMk]g^INiX2Ni/6Nk/<NkX3OkX8NkX00g^kNkak^`05
NkX3Nk/00g^jNk]k^P02Nk/3Nk`2Nk/=NkX3Nk/5NkX;Nk/00g^jNk]k^`02Nk/2NkX4Nk/2Ni/6NkX4
NkT4NiX3NkX3Nk/00g^JNkYk^P05NkX01W^INkUk^W^jNkUk^P9kV@03NkYgVGNI009gV@9k^P=kV@=g
V@=kV@03MiUgV7NI009gV@9gN@0=MgQgMgMfLeMc=flgJaI_5Ui^;>@800`P56400Q100Q1P0Q1Q0Q1P
0Pa000@<H11P460<H0@<@08@H00D360@HA22588DH11P6<8H`aB2468DXQRR6<<DPQ1Q588HPQB2464@
HP8DPP046:<DPa1Q58426:802QBR588DPQB2364<@@aR364<@@aQ0a220aB200l@PQB2588@PA1R348@
HQAQ584HPAQQ584@HA225:800Q220a1R00@@HAB16:8HXP<DPP8DP@03564DPAB1008DP@06564DPA22
464<HA1P0a1Q0aB100H@PARR7<@H`aB248854644564946424686464256400a1P580@H00244001aAP
584@HA1Q468@PQ21008HXP03560DHA1P008@H0<@H@03484@HA1Q008@H@0<460<@0PP220@H1B24648
@0@0200<80a10PaQ00<<@@Q03400111Q00@DPQB1464@H08@@08@H007364<@@a0460<H0aQ48800Q1Q
00<<@0PP22000`a000L<H0aQ340<@11P464@H00234000a1P464@H0035842440010`P340<H11P0Q1Q
0`aQ0Pa000<<HA1Q46400Q1P0@a00@Q10@QS000015kDH]=Rdf;C0VKC0fKB16KC2fKD00AVdfKDI]AV
e09Vl`07I]AVm6KdI_=Zlf[CJ_@016Kd1V[d0V[e0V[d00=ZmF[dJ_@00V[e1f/E00m_5W=GMgQgN7=h
HY51S1a4000801RV@Q1S>6mGLeP00V/E00=[5V/gLcH00W<E0flF0Vlf2Flg00=_EflgKcL026lg00=c
=flgKcL00W<g00A_F7=GKeM_E`AcE`=_F0=cE`AcF0AcE`03LeQcEgMG009gE`03LeMcMg=g009cM`9c
F003LgQcMg=h009cN004LgMcN7=hLgP2LgT00gMgLeMgE`02MgL017MhMgUcNG=h1G=i0W=H00=gF7=i
LgT027Mi1GMj17Mi0gNH17Mi00AgN7MgMgUgV@=gVP03MiUgVWNJ00EgVPUgV@=gVP03NiUgVGNI00=g
V@9kV@=gV@=gVP03MiUkVGNH009gV@03MiYgVGNJ00MgVP9gV`=gVP=gV@agVPAgV`03Ni]kVW^J00=k
VP9gVP0MNiUo^GoJOiQg5fg=F65<0500G01T05`0F01HX4cSC@598dTTADE59443@><l`T10C41DH5aP
H21T0002H0002eP0C01004bQFDA=If9=KcEo]7oiOmT00W^i17^J0g^j0W^k00=k^W^kNk/01G^k0g^j
0gnj0g^j1G^k00Ak^W^kNk]k^`Ek^PIk^`05Nkak^g^lNk]k_004Nk/9NkX2Nk/00g^lNk]k^`04Nk/0
0g^jNk]k^`02NkX00g^kNkYk^`0:Nk/01G^jNk]k^g^jNiX00W^K00=k^g^jNkX00W^j0W^J0W^i00=k
VG^JNiX00g^J00=kVG^JNk/00W^k00=kVW^INkX00W^j0W^I0W^j0W^i0g^I0g^j37NI00=kVGNIMiT0
1GNI00mgNGMhMgQcEg=FKeQ_=f/FJaEVm58^7648811R56400Q1000H@H11Q484DPA1P440334043600
2A1Q340<@0a0464<HA1Q488DPP0256400aBR6:8DXP055:8011B2464DPQBR0QB300THPaB2588DPQ1Q
584HXQc45:800aB200<@HAB248800Pa100<@PQB2588011B20a2200H@H@aQ244@HQB2564268401aB1
588DXQBS48<@PQ1R008@H@05484DPAB1584DH@03584256401122484DPA1Q0a220Q2100D@HA22588@
PQ1Q008@PP055:<H`aBS588@PP06464258400aR2464@H@0346400aB15:8DP@094643564446402Q10
560HPQ1Q340@HQ22588HXQBQ0QAP00<@@11P46400Q1Q00T@PA22484<H@a0460@H@aQ46400PaQ00L<
@0Q02408@0PP340<@@0236400a1Q360<H0054643460244000aAQ464<@@02368236402Q1R488@PQ1R
364<@0a1364@HA1P10a00`aQ0Pa100<@HAR246400Q1Q00T@H0`P320<80aP364@H0aP36400Q1Q00<<
H@a034000a1Q0PaP0@a00@Q10@AR00000ekDH]=Rd`02I]<00f:cI]9VdP05I]<00fKDI]=Ve008I]@0
1VKCI]AVe6KCI]9Vd`9Ve09Vl`03J_9Zdf[d009Zm0=Vm0aZm09Zm@I[5@04KaE[5F/FKcP2LeP03WMG
J_IB4BS[00<000@2<DYJCF/DLeI_=G=GKcL4KaH01FlEKaIc5W<fKcH05flg00=c=fmGLcH00g=G00=c
=W<gLeL01W=G00AcF7=GLeMcM`AcE`03LeQcEgMG00=gEP03LgMcEg=G00IgM`03MgQcN7=g009cM`06
LgQcNG=iMeQgEgMf0gMg00AgN7MHMgQcN0=cE`06LgUgF7MHMgUcNG=h1gMi00=gN7MiMgT00gMj0WNJ
0WMi0gMh00MgNGNIMgUgN7MiMgQgN@03MgX00gNIMiQgV@05MiX00gNIMiQgV003MiP01WNIMiYgVGNI
NiUgV@9gVP03MgYgVWNI00=gV004NgUgVWNJMiX3MiT01GNHMgQgV7NINiT00WNI5GNJ0g^J17NJ0WNK
00=kVg^JMiX00WNJ1G^J00YkNG^IOkUofGnEOc9fLV3UC05400=@000MC61<hTd1BB=58dD4ABA1143S
?<=0H4PPF61PH60PG01H04`0@010@4c1HFIV:fJaKcIo]goHOkUo^P02NkX5NkT3NkX9Nk/7NkX00g^k
NkYk^`05Nk/:NkX3Nk/2Nk`6Nk/;NkX9Nk/2NkX5NkT3NkX6Nk/6NkX017^iNkYk^W^k17^j0W^J00Mk
^G^jNkYk^W^kNkYk^@02NiT2NiX2NkX00g^JNiUkV@02NiT01G^HNiUk^W^jNkT02W^I00AgVG^INiUk
V@EgV@=kV@EgV@0@MgUgN7MgLgMgMW=GLcM_5FlDJ_=9baA0200DPQB1460244001A1Q488@HA103400
0P`P1Pa00Q1001@<@0aP364@PA22584DHA1Q588HXQS37>@La1BR460DXABR5:4DXQB20QB300TDHQB2
58<DHQ1Q684HXQBR48800aB200P@HAB15:8@PPQ0484HXaBR1AB200<@PQ1Q46400a1R1AB100@DXQRS
6<<DXP8@PP<@P@04584@PA1Q440356400a1P464@HP0346400aB2484@P@0258400aBR7<@H``025880
2A22588DXQBR488<HA1P584@P@02488358800a22468@H@0446400aBR6<8H`P0246402Pa1468@HA1P
240@HAB2580DH1AQ0a1Q00T@H110464@HA1P340<@A1Q48400QB10QAP00<@@11Q46400Q1Q00hDPQBS
488@HA1P100<@AB3584<@0P0100880a00PaP0Q1P00<@HAB248400Q1Q0Q1P111Q00@@@11P440@@08@
H@<<HP04364@HAB24882468010aQ340<HA1R0a1Q0`a000<<@@aQ36400Pa100@<HA1Q464@H@8@H00:
320<@0a0360@PQ1P440@H11Q460234001@aP588DPQ1Q22000`a00@QR00000ekDH[=Rd`04I]<3H]<3
I]<00fKDI]=Ve008I]@01FKCI]AVe6KDI]<016KD0fKc0VKD1F[d0f[e1V[d1F[e1V/E16/F00M_=g=G
MiY_FEkg@LlH0P0200001bcYAQ1Rdg=HLeM_=f/E00=_5P05KaEc5G<ELaEc=P02KcHFKcL00g=GLcIc
=P03LcH5LcL2KeP2LeP7LeL00g=HLeMgE`03MeH00g=gLeMcE`02MgL3MeH017=GMgMcN7=g0W=h0g=i
00EgF7MgMgIgMgMG00=gF003MgQcN7Mg009cE`AcN@04MgUgN7MhMgP5MgT017MhMgUgNGMj0WNJ00Mg
NWNJMgUgVGMhMiQgN002MgT2MgP01GMiMgQgNGMiMgX00WMi00=gN7NIMiT00gNJ0WNI00EgV7NIMiQg
VGNH00]gV@04MiQgVGNINiX2MiX017MjMiUgV7NI0gNH0W^I00AgVWNIMiUgVA9gVPEkVP03MiYgVgNK
009gV`03Ni]gVWNK009gV`9gVP0/NiYkNG^INiYkVG]iOiYog7okOk]o=W8aH<=<04@0D01<PdS3C@55
8dDTA@=113d4?><l`dAPD61H@610G01H04`0D61@`TT5HLU^dVleMiYoo7omOk]kV@9kVPEk^@=k^Pak
^`Ek^PMk^`Ek^P=k^`03NkYk^g^k00]k^`]k^P]k^`Qk^PIk^`ik^P9kVP=k^P=k^`9kVP03NiUkVW^J
00=kVPMkV@03NkYkVG^I00EkV@05NkYkVG^INiUgV@03NiT<MiT00gNJMgUgN002LgL017=fKeMc=VlD
0VlE00=1R@`010000Q1Q00X@H110440@H@aQ460@@11Q460@@0<@H0<<@08@H005360<@0b1484@PP02
564021R2588DPQS48@DHa1B156045:8031B1588DPQB2688DPaAR340HPAbR588<H@8DPP05464@PQS3
7>DDXP0258400aB25:<DPP0358802AB3488@PQB1468@HA1R588HX`025:801AB2584DXQS458800Q22
00d@HA21484@PA22464DPAbR788DH11P464@HP0346400aBR484@P@0258426:8011B1484@HA210Q22
00HDPAB2568DPQB1588258<2588348800a1R464@H@0248800a215:8DP@02464020aQ468@HA1Q460@
HA216842564946401Pa1340<H121584DH0@@H@0C588DXaBS588@PQB2488@H@aQ488DPQ1Q340@H11Q
360@H11Q58800a1Q00@@PA1Q464<H@<@H@04484@HA1046024402364336801@Q0464@PQ2246800Q1Q
00D<HA1Q58<DXa2200@<H@8@H@06440<80PP364@H@aQ0a1P0`a000@<H0aQ464@H08@H@07460<@0aP
364@PA2236400`a00@aP0@QR000015kCH[9VdVJb0fKC0VKB0f;C00EVdfKDI]AVe6KC00EVe0=Vd`EV
e0EVd`04I_=VdfKCJ_@3I_@9J_@6J_D016/EJaA[56/D0V[d00A[5FlEJaE_509_5@06LeIgMgNGMgIJ
D2270P0000@TZ4G^H]=c=@9c=P04KcI_5VlEKaD2LaD01W<FKcI_=VlfKcM_=PE_=`03KcI_=flg00a_
=`03LcMc=W<f009cEP05LcIc=g<gLcMc=P02LcL2LeL00g=HLeMcE`05LeL00g=HLeMcE`03MeH01G=g
LeMcEgMFMeL00gMF0W=G00AcN7MgLgQcN09cN@9cF003LeMgEWMG009gE`9gF003MgQcN7=G009cE`05
LgQgN7MhMgUgN003MgL5MgP017MgMgQgNGMj17Mi00=gV7MgMgP01GMh0gMg00AgN7NIMgYgN@9gN09g
V0=gV@03MiYgVGNH00UgV09gN0AgV005NiQkVGNINgUgVP02MgX00gNIMiQgV002MiP017MhMiQgV7NI
0gNH00=gVGNJMgT00gMi0WNI0WMj0gNJ00AgVGNJMiYgVP=kVP9kV@9kVP06Mi]gNWMjMgYgVgNJ0gNK
0WNJ00=kNGMiNgP00W]i0W]j00akVWnJOkUoeWmeOa=b<UcY?2Dh0dC4B@42A@<2@@<04cd3?><l`d10
B01@H5APD21D86TQNT]UYEfXK]Aon7ogOmUofg^k00AkVP04NkUkVG^INiT2NkT3NkX00g^kNkYk^`04
Nk/00g^jNk]k^`02Nk/4NkX2Nk/00g^jNk]k^`02Nk/7NkX00g^kNkYk^`0;Nk/00g^jNkUk^P09NkX;
Nk/6NkX00g^iNiYkV`05Nk/5NkX00g^INiQk^@05NkT2NiX01G^kNkYk^W^iMiT00W^k0W^J0g^I0g^J
4g^I00AgVG^INiUkV@agV@0>MiQgN7MgMgIcMgMFKcI_=F[cKaAVdcU81008008@H@8@H004540DPAB2
464244054603340246001`a0364@PQ21360@HAAQ008DP@05588@PQB2488DP@0258801Q225:8DXQS3
6<@HXP8DPP09568@HQAP684LXQB248<@PQB3008@PP036:<Q1QcT008DP@03564DPQB200<DPP0;5:8D
PQAQ584DHQ1R464HXRDW8>DHXP0258401QBR6:<DXQ1R364@H@<DP@06488DPQR2584@HAAP111Q00@8
811Q6:8HXP<DP@055:4DPA1Q340@P002484646400a1R488@HP0346423643464011225:8@PA210a1Q
00@@PA1Q460@H0<@H@03684DHAAQ008@H@03364@PA2100@@H@8@H004464@PARQ460546400`aP464@
H@0346401Q22484@HA1Q564DP@8DXP09464@H11P340@@1B05:8@H@aQ00<@H@8@H08@H@08460@@A10
460<@0aQ58<@P`8<H@06360@HA22468<HA1Q0Q2200L@H@aQ364@H@aQ340<H0024640211P220400PP
460@HA1P440434023602460246400`aP364<H00236400`aR364<@@023401360136800007G]=R/VKB
I[9V/f:cI]800VKC00=RdfKCH]@01F;D00=Ve6;DH]@00VKD0fKC00EVe6KCI]=VdfKD00MVd`9Ve0AV
m003I_EZmF[e00UZm003I_EZmF[e009[5@03J_AZmF/E009[5@0FJ_A_56lEKaE_=W<gMgQcN7=jFY@a
:`P3000HACg?I]=cEg=FKcI[5FlEKaH2KcH2KaH2KcH>KcL5KcP7KcL8LcL3KeP00fmGLeMcE`02LeL3
LeP3LeL00gMGLeMcF002LeL3MeH00gMgLeMcF002LeP00g=gLeQcF005LeP017=GMgMcEgMH1g=H0W=h
0W=i00AcN7MgMgMgM`EgN003MgMgNGMi00AgNP05MgUgN7MhMgMgN002MgL00gMhMiQgN002MgL2MgP3
MgT01GNHMiUgVGNJMgX00gNJ17NI00=gV7MhMiP00gNI00=gV7MhMgP017NH0gNI0WMi00=gNWNJMgT0
1GNI00IgV7NIMiQgVGNHMiT3MgT00gNJMgYgVP02MgX7MiX017MjMiYgVW^I17NJ17Mj00=gVgNJMiX0
2GNJ00IgNW]jNgYkNW^KOm`2Ooh02WnnNaUQKCbX?:=50D43@@A10d4S0ScS018ha3a0B21<HDb3C6=@
P7Y4NaAVT6J>OmAoo7ojNiUkVg^kNiX3Ni/6NiX01G^iNkYk^W^kNkX01G^k00Ak^W^kNkak_09k^`03
NkYk^g^k00Qk^`Qk^Pak^`Ik^P03Nk]k^W^k009k^`03NkYk^g^k00Yk^`03Nkak^g^k00Ak^PIk^`03
NkYk^g^j00Ek^PAk^@03NiUkVW^K009kV`03Nk]k^G^j009g^P03NiYgVW^I009kV@=kVQ5kV@03MiUk
VGNI00=kV@IgV@04MiYgVGNIMiP2MgP01G>HMgMcMgMfMeH00W<f00Y_=F[BKaAFLRcW000<80aQ344<
H@8@H@04560HPQ10440446000a10340<@002340446001a1Q584@HA1Q588DXQB2008<@@04468DPQ22
5:825:<01QBR7>DQ1QcU5:<DPP8DHP05444HPAbR7<@DP`0448<020Q1588Ha1c4684HP11046465880
5AAQ584@HA1Q564DPQRR6:4LP1B0220DPQRR5:8@HPaQ488DPARR584<H@0348800`aR464@H@054640
11B16:8HXQB20aB100<@H0a058400Q210a1Q00@DPQ1Q464<@@8@HP03464@PQ1Q008@PP<@HPD@PP8@
H@03488DPA1Q008@H@0:460DH1B1584@H@PP364<PA22484646401`aQ484DXA1Q344<@11Q008<H@06
360<@0PP340<H11Q0Q220Q1Q00L@HQ225:<@PQ1Q460<@00244000aAQ488@H@0246401@aP340<@11P
36400`aP00<<HA1Q46400PaR00@@HPaR368<H@<@H@03468@H@aQ008<H@04340880PP24023640111P
464@HA110Pa000H@H121464<@0a1264234000`a1360@H00236400a1R364<H@0236400`aP364<H004
360136800003G]=R/V:b009V/P9VdP9R/`9Ve0MRe003I]AVeFKD00UVd`=Ve006I]=VdVKBI]9VdfKD
16Kd00AVmF[eJ_EZl`MZm0MZm@06JaEZm6[dJ_A[56lD0VlE0flF00agFGMhNiMZeCe]308001aUANiV
dg<dKaD2J_D00f/EKaI_5P02KaH4KcH5KcL00flfKcM_=`0;KcL00flfKcMc=`05KcL8LcL6LeL2LeP5
LeL00g=HLeMgE`02MeL00gMFLeMgEP03LeL3LgL4LeL00gMgMeIgM`02LeL3LeP2LeL2LgL2LeP017=i
MeQgMgMf0WMg17Mh00AgMgMfMgQgN@AgNP03MgUgN7Mh009gN0=gV09gN0AgM`04MgQgMgMgMgL4MgT3
MgX2MiX2MiT3MiP3MiT;MiP2MiT3MiX2MgX2MiT3MiP01GNIMiQgN7MhMgT017NJ17Mj17NJ0WMj00=g
NGNINiT05GNJ01IkNG]jNgYkNg^KOi]ooGolOkM^Tdd[@<A4hD43@@A10dDS?>8lhcC4?898H@9<H@09
A25@X7Z3OgI^m6:9OlMolgnk009kV`04NiYkVG^JNiX5Ni/2NiX3NkX3Nk/5NkX00g^kNkak^`02Nk/3
NkX4Nk/00g^jNk]k^`09NkX4Nk/00g^jNk]k^`02Nk/<NkX2Nk/3NkX8Nk/3Nk`2Nk/00g^JNkYk^P02
NkX01G^kNkYk^g^kNi/00W^k17^j0W^J0g^j0W^i00IkVW^KNi]kVg^JNkT=NiT2NiP?NiT00gNINiUk
V@03NiT00gNINiUgV@04MiT2MiP047MhMgMgMW=fMeEc=WLeLcE_57<DKaA:<AQU000<80aR0Pa100<@
@@a044000a1000T@H0a0320<8110460@@0`P44001A1P0Q210aB200<HPaB346<00Q1R00LDPQBS48<@
PQBR6<@DXP0248801QB2564DHAB1688HP@8DPP06488@PaB3488<@A1R0QB200PDPAB0320<@AB26:8H
PARR0Q1R00hDHAB0460@HAAQ584HPAbQ660DH0PP580L`QRR112200<DPA2136400Q1R00@@H@Q0220@
@0@@H@8DH@03584DPQB2008DP@05564@HA1P340<H00346403122588@HQ1Q364<@A1Q584DPQRR584@
P@8@H@0:468@H@aQ464@HPaQ340@HARR684246400a1P464@H00258400a1Q220@H@0248800a21480<
H00246402A1P360880a0580DPQ1Q440<80023400111P360<@0a010aQ00<@HA2148800Q2200<@H@`P
46000a1P00H@@0aP464@HA1P3602220346000`a0460<H003344236400`aR364<H@0246401A21488@
H@aQ34000PPP00<<HA1Q36400a1Q0a100Pa000d@H11Q460<80PP364<H0a1364@PQ1P3408@0033402
24001`a0360<H0aQ360<@0aP004<@@0000=Ne6;CH[800V:b0VKB16:c0VKD1f;D0VKD46KC00=Ve6Kd
I_@00VKd0VKe0V[d0f[e0f[d2F[e0V[d00A[5F/DJaA[5@A_5@0>K_Ec5GLeOkYc5e7>608001aTDPmV
dVlgKaIZmP9[5P03KaI[5VlF00A_=PU_=`9c=PM_=`9c=P04KcMc=flgKcL2KcP00flgLcM_>005LcL0
0g<fLeIcE`02LeL00fmGLeQcF002LeP3LeL3LeP2MeL3LeL017MGMeIgEWMg0g=g00=gMgMFMeL00WMG
00=gEW=GLeL00W=H00AgF7=HMgMcE`9cM`9cF004LgQgMgMgMgH2MgL4MgP2MgL00gMhMgUgNP03MgX0
17MiMgQgV7Mh0gMi0gNH0WMh17Mg0WMh00AgVGNJMgYgN@AgNP06MiYgVGNIMiQgVGNH0gNI2GNH17NI
0gNJ0WMj1WNI0WNH00EgN7MiMgUgVWMj00=gVP9gNP9gVP04MgYgVWMjMgX3MiT5MiX00g^IMiYgVP0>
MiX2MgX087MkNi]kVg^KOmaoegmkFHlla43R?>=10d44@B@lhcST<<@lY4B3B89<HC`0A61^17MgH[=N
BG]?OoIo^W^JNi/4NiX5Ni/2NiX017^iNkYk^W^k0W^j2W^k8g^j00=k^g^jNkX00W^j0W^k0g^j27^k
0g^l0W^k0W^J00=k^G^jNkX00W^j17^k0g^j00=k^G^JNiX01G^j00Ak^G^JNi]kV`9kVPMkV@05NiYk
VG^INiUkVP02NiT2NiP9NiT7MiT01g^INiYkVW^JNiUgVG^I00EgV@9gV00DMgQgMgMfLgMgEWLfMcAc
=6lDLcEZm3f^20<000a036888@`P340<@@<@@0@@H003464@H11P008@@0H@H004464@PAB26:<36880
2aB258@DHPaQ488@X`b34:8DXaB246400QB200XHPQ1Q564HXaR2464<@A22588DP`@DPP0>568DPQB2
488@HQB2584HPQc46:@DPQAR584DH@8@HP0:584HPB2R784HPA10584L`aRR5:834880211Q484@PQBR
588@HPa14446464011AQ584DPQB20QB100L@HA1P440@H@aQ340<H@02468548824682588258424640
0a1R464@H@0546400a22584@H@034642484648800a21464@H@0346401@aQ340<@11P48400Q1Q00<@
@0`P34000Q1Q0PaQ0Q1Q00D@PA22488@PQ2S008@PP03340<011P008@H003464@H11Q00@@H@03364<
@0aP008@H004440@H0a1340534403a1R488@HA1Q484@PQ1Q340@@A10340@HAB258<@HP0246402111
460DHA1Q220<HA1Q3402220020Q0484@H@a0364DPA1P3602364020a02208@0Q0364@PPaR36423401
34400004G]AR/f:bH[85I[83I[<00fKDH]ARd`05H]@2I]@<I]<016KBI]=VdfKC0VKD0VKd0V[d00=Z
mFKDJ_<00f[e1F[d1F[e1F[d16/D0V[d01=_5FkeKaEc5G<eNgM^m4G=300002bVEPeZm7=HJaM[5VlF
KaE[5@02KaH4KcH8KcL3KcH5KcL5LcH2KcL2KcP00g<gKcM_>005LcL2LcH5LeL00g=HKeQcF005LeP6
LeL2MeL00gMFLeMcM`02LgL00g=GMeIgEP03MeH00g=GLeQcF002LeP2MeL2LeL4LgL7MgL2MgH2MgL0
0gMhMgUgNP02MgX017MiMgQgMgNH1GMh00=gV7MhMgL01WMg00=gN7NIMgT00WMi17Mj0WNJ00=gVGNH
MiP03GNH00=gVGNHMiT00WMi17NI1GNH00AgVGNHMgQgM`9gN00;MgUgVWNJMgYgNGMhMgUgVGMiMgYg
VP02MgX00gMiMiUgV@02MiX017MiNiUgVGNH0WNI0WNJ00=gNGNJMiX017NJ0gMi17NJ00YgNWNKMg]g
NgNJOoYooFIb@>@l`P910`0C?@@lhcc3><@daCc4@:=8PTQ1>01086g3NeIZTEg4M`iomGokNiT017^J
00=kVG^JNiX00g^K0W^J0g^i17^j00=k^g^jNk/00g^k9W^j0g^k00=k^W^JNiX017^j00=k^g^jNk/0
2W^k0W^J1G^i0g^J00Ak^W^JNiYkVP9kV@03NkUk^W^j009k^P05NkUkV7^INi]kVP09NiT00g^JNiUk
V@04NiT2NiP00g^IMiUkV@04NiT00g^HNiUgV@04MiT4NiT00gNINiUkV@04MiT2MiP2MiT00gNHMgMg
M`02MgH047MEMcEg=7<DKcA_56KC=Fd00P00344@H`a1340@H0a10a1000D<H11P460@HAAQ008@H0<@
@003340<80`P008@H005360@HABR7<@LXP02684011B258<DPQ1Q0a220aB200H@PQB2588DHA1Q5642
58834884588021BR5:@DPaB3568@PaB24882584021B26:<DPQB2584DHA11468258401aR1688DPQ1Q
584HXQB100@@PP06464@PA1Q584HXaB20a1R111Q00<DHAB258800Q221a1Q00@@PA1R2448808@H@@@
HPT@H@03364@HA1Q00T@H@03488@PA1Q00H@PP<@H@03364@HA1Q00<@H@03364@HA1Q008@H003440<
H11Q008@H@0=460DPA21484<HA1Q468@P@aR4648811P34000Q1P00<DPA1Q46000Q1Q0`aQ0Pa000<<
H0a0340010a00Pa100<<@0aP36000PaP0a1Q00<<@11P46400Q1Q00XDP@a0340@@A10340@H1AP464<
H@8@H@04440<80`P340246000a1Q364@H@0246402@aQ360<H0a02448@0Q13608H@03340134800005
G[AR/f:bH[9R/@03I[84I[<00fKCH]ARe009H]@8I]@016KCI]AVdfKC0VKD0VKe00EZm6KdI]AVe6[d
009Vm09Vm@03I_IVmFKe009Zm@03J_AZmF[e009Zm@IZm003JaE[56/E00A[5@0?KaE^mFlFK_EgN7=i
KaDmRa00000/bE8AJaI[F6/G00A[5P9_5P03KcM_=Vlg00Q_=`03KcIc=W<f00E_=`E_=P9_=`9_>003
KeQ_>6lh009_>0Ec=`AcE`YcF09cE`=cF004LeMcF7=GMgL4LgL01g=GMgMgEWMFMeMcF7=G00=cF09g
E`=cE`AcM`MgM`06MgIgMgMfMgMgNG=j0WMj0WMi00AgMgMhMgQgN@=gN005MiQgN7MhMgQgN@05MgP4
MgT4MgX00gNJMgYgVP04MiT00gMhMiUgV@05MiT00gNHMiUgV@09MiT5MiP4MiT00gNJMgUgVP02MiX0
0gMjMgUgN@04MgT5MiX00gNIMgUgN@03MiT017NHMiUgVGMj0gMi0WNJ00AgNWNJMiYgN@AgVPEgV`9g
VP0JOo]oog<FB><l`TD4@@@m13cS><<d`c35><@lQ4B3B69004@PLL=flfX=D<1ZKGnGOoIofP9kVP9k
V`=kVP03Mi]kVg^K009kV`9kVP03NkUkVG^j009k^P=k^`=k^P03Nk]k^W^j00Mk^P=k^`=k^PEk^`03
NkYk^g^k00Ek^`Uk^P04Nk]k^W^jNkT2NiX8NkX5Nk/4NkX2NiX00g^iNiYkVP0;NiX2NkT3NiT01G^i
NiUkVW^KNiX02G^I00=kVW^INiX01g^I00=gVW^INiT00g^I00AkV7^IMiUgV@AgVP04MiUkVG^INiT3
MiX3MiT2MiP00gNIMiQgV002MgL03GMeLeIgEG<fLcA_57<eKaANL2d:004000a100<<H@05360@HA1Q
440@H0033603464246003Q10460<@0a0440@H0aP364@PQBR7<<Y1AbR688358801121468@HAB20QR1
00<@H11R58800aB200<@HQ2258800Q230QB30QBS00HDXQB25:<@PaB248<246801122584DPQB20Q22
00P@Pa22440<811Q584DPQB10QB200D@HAAQ584DP@aP008DP@06588@H11P484@PQBR0Q220Q1R00@@
PQB2588@H@<DPP8@PP<@HP<@H@03484HXQS300<@PP8@HP8@H@07564DPQ1R468@PQB24880111Q00D@
PAB2464@HA1100<@H@03584@HA1Q00<@H@03488DPQBS008@PP07468<@0a0220<HA1R464010aQ0Q1Q
0QB200<@H@@046400Q1Q00@@@121384<HP8<H@03344<H@aR008<HP05360@H11Q464@P@0446423642
468636400`a0344<H@0236402Pa1340<@0Q0340@H11Q360<@0aQ0Q1Q00T@H0a0200<@11Q364@HA10
46400Q1R00T@HA10440@@1AQ460<H11Q36800`aQ00<@HPaQ34000`Q10`QQ0`Q00@Q100000ejdH[9V
/P03I[8016JaI[9V/VJc0VJb0VKC16;D00IRdf;DH]ARe6KDH]@2I]D00fKDI]EVe005I]@2I]<016KD
I]=VdfKD0f[C16KD00EVeFKFI]IVeFKe009Zm@03J_AZmF[e009Zm@9Zm003K_A^mF[e00AZm09Zm@0;
KaE_5VlEK_E^mVlFLcMcEg^gI_<mRP020000133ZGY1[F6mH0f/F0flF00=_=VlFKcH01flf1flg0Vlf
00=c=VlfKcH00Vlf1Vlg0Vlh00Ac=g<fLcMc=PIc=`9cE`AcF0IcE`=cF0AcE`9cM`AcE`EgEP03LeMc
F7=G00AcE`AcM`EgM`04MgQgMgMhMgH2MgL00gMhMgMgN@03MgT00gMhMgMgM`04MgL01gMhMiQgV7Mh
MiQgNGNI00]gN@03MgQgNWMj00=gNP04MiUgNGMhMgT2MgX2MiX00gNIMgUgV002MiT3MiX2MiT8MiP0
0gMhMiUgV@03MgX2MiT00gMiMiUgV@02MgT3MgX00gMiMiYgVP03MiX2MiT5MiP2MiT>MiX3Mi/087^J
NiUkUg^FOmQoogLfB>=0hdDUA@E11CcS>><d`c2T=:@lQ41SA6948DQ0JH9bCFEWB41@i6kAOk5onW^j
NiX4Ni/00g^JNi]kV`04Ni/00g^JNkYk^P0CNkX3Nk/3NkX5Nk/00g^jNk]k^`04Nk/8NkX00g^iNkYk
^P0GNkX017^iNkYk^g^j0W^K00=kVW^iNkT00g^i00AkVW^jNiYk^@IkV@=kVP]kV@03NiQkVG^I00Ek
V@03MiUkVG^I009kV@9kV007NiUgVG^IMiUkVWNJNiX00W^I00EgVG^HNiUkVWNJ00AgV@=gV00@MgQg
MgMeMgEcEWMELcEg<g<DLcE_5EH_9:D000PR4642460434000a10460<H00246001Q10340<@0a0460@
@08<800:440@H11P464@HQB26<8DXARQ68825883584246401AAQ684DPAB258<00QB20QRS00<DPQ1Q
34400Q1R00<@HAAQ58800aB200@DXaBR588DPP<@HP0?584DPQ22344@HQ23488<@0a1464HPARR588D
PAB2008@HP03568@H@aP008DP@05588@HAB1484DPP02488246801QAQ584DPQ22468DPP8HX`03588@
PQ1R008@HP<@H@07580L`QS25:4DPA2246800a1Q00<DHAB156400QAQ111Q00@DHAB26:8DPP<@H@8@
H003564@HA1Q008@H@04364@HA22488258802122468@H@a1464<HPaQ4642364646402a1P340<@A1Q
460@H@a0240880a036401@aR0PaQ0PaP00@@H11Q464<H0H<H@03464<H0aQ008@H003440<@0a1008<
H@08344<@0aP240<@A10360<H@8<@08<H@08464<H@a0340@HA22464@@@<@H@8@@@06464DH11Q460<
H0a00`aQ00P@PQ1R364880Q0244<@@QQ0PaQ00<<H0a024000@Q1000015jdH[9R/F:a1FJb00YV/fJb
I]9VdV:cH]AReF;DI]AVd`IVe003I]EVe6KE00IVe0IVd`=Zd`AVe09Ve@9Vm@=Zm@03J_AZmF[e00IZ
m@05J_A^m6[dKaAZm003K_@2KaD03flFKaE_5V/FKcI_EWNiJ_8Xa`00100m[6MJJcM_5@02K_D016lE
KaI_5VlG2Flf2Flg0flf0W<f1Vlg0Vlh00=c=g<fLcL01g<g0W=G00AcF6mHLeQcF0AcE`EcF004LeMc
F7=HLeP2LgL00g=GMgMcE`02LeL01WMgMeIgEWMFMeMcE`=cF004LeMcF7=HLeP3LgL4MgL00g=hMgQg
N003MgL4MgP2MgT01GMhMgMgN7MhMgT00WMg00=gN7NHMgP00WMh0WMi00=gNWMiMgT01GMi0gMj00=g
NGMjMgX00gMj0WMi00AgV7MjMgYgV`=gVP04MiUgV7NIMiT5MiX2MiT2MgP4MiP01GMhMgUgNGMiMgX0
0WNJ17NI00=gNGMjMiX00WNJ00=gVGNJMiX00gNJ0WMj0WNI00EgV7NIMiUgVWNI00AgVP03Mi]gNWMj
00MgVP=gV`0UNiUkNG]gOgIoegolL_E8hd3TBBE59D4T>><dhc33;<@dXcb4@6=4HT0PB41I0FW9H@A<
8413GJQoLGoiOm]kVW^KMi]kVg^kNiX01g^K00=kVW^jNkX00W^j00=k^g^jNkX03G^j0g^k0g^j1G^k
00=k^W^kNk/01G^k1g^j00=k^G^jNkX00W^j00=k^G^jNkX05G^j0g^J00AkVg^JNiYk^@9kVP03Ni]k
VW^J00MkV@=kVP9k^@04NiUk^W^jNkX5NiT00g^HNiUkV@04NiT017NIMiYgVGNI1G^I0gNI00agVW^K
NiYkVGNIMiYgVG^INiYkVgNJMi/2MiT2MiP2MgP03WMgMgEgMW=gMcIg=GLcLcA_56[dBNdD@P@048<2
46401a1P464@H@aP340<H11P008<H0D<@006460@@0a0340@H1100Q1Q00<@PQBR6:800QBR00<DPQ1Q
58800QBR0QB100<@HAAP6:400QRS0QBS00/DY1BS588@PPaQ344@HQB2564DPA1R008@PP05588DXQBR
5:8DPP04468648802QAR464DHAB17<@HPQAQ588@PQB20Q220a2100@DPAB2584DPP8@PP053648@AAQ
564DP@0658800a22588@H@03464246000a1Q6:4DPP0246402Q1P464DPQB2564DPAbR564<@1100Q1Q
00D@@11P584@PQB1008@H@03564@HQ1Q008DH@07460@HA1Q468@PQ2S48<00a2200L@HA1R464<@@aQ
368DX`0246800`aQ464@H@0246401PaP364@H@aQ464@H0<@H@03364<@@aQ008<HP04364<HPaR3442
3642340010aQ464@PA220PaR00<<HA1Q36400Q1Q00H@HQ1Q464@H110464346801@a1340<H@aR3640
0Pa000L<H0aQ340<@0aQ484<HP043642368246401A1P364@HA1R48800Q1Q010<H@a0340<H0aQ464D
PPa0120<@0a1368<PQ2248<@PP8<@048@@0000AN/f:bH[9R/PMV/P04H[9V/VJcH[<3H]@00fKCI]AV
e005I]@01FKCI]AVe6KDI]<016KD1FKC00AZdf[BJ]9Vd`9Ve0=Vm@03I]AZdf[D009Zm@=Zm0EZm@IZ
m006J_=Zm6[cJ_AZmFlE0V[e0f/E00QcMW^eFW<@1P0042A:M6le0VlD00=^m6lEKaH00VlF00A_5flF
KaI_=P=_=@=_=PA_=`=_=P03KcM_=W<f00=c=@03KcI_=flg00I_=`Uc=`9cE`03KeM_F7=H00EcE`Ec
F003LeMcF7=G009cE`03LgMgMW=G00AcE`=gEP03MeMcF7=H00=cE`9cF0=cE`EgM`03LgMgMgMg00=g
M`04MgIgMgMgMgL2MgT00gMhMgMcN002MgP3MgL4MgP01WMiMiUgNGMiMgQgM`EgN@03MgYgNGNH009g
N@9gNP04MgUgVGMiMiP5MgX00gNJMiUgV002MgT2MiT3MiX2MiT00gNHMgQgN003MiP3MgP01WMiMgYg
VWNJMiUgV0=gN@06MiUgVWNJMiYgNGMj17NJ0WMj00=gNGNIMiP00WNI00AgVWNIMgUkN@9gVP=gNP=g
VP03MgUgVWNJ00AgVP9kN@0RNgQkMGoFOmY^ddSS?>=594DS@@<hhSC3<<</a3BR?88lPD1RA41485CR
HFQLhUA0@2EIAGm?OoMofg^INi]gVg^jNiX3NiT5Ni/2NiX3NkX00g^kNkYk^P0:NkX2NkT7NkX5Nk/3
NkX4Nk/6NkX017^kNkYk^G^i0W^j0g^i47^j00=k^G^INkT00W^j0g^J0W^K00EkVW^jNkYkVW^K00=k
VP03NkUkVG^I00EkV@Ak^@Ak^PAkV@03MiQkV7^H00EkV@04MiUgVWNIMiX5NiT3MiT3MiX2NiT3MiT0
17^INiYgVWNJ0gNI015gV7MhMgMgMWMEMgEcMgLfLcEc<fkbJ_9R/46Z3204012200H@H003360<@0a0
00@<@005320<@11P460@@00334001a10460@H121588DXQBS00@DXP8DX@076:4DPAB1464HXQcT7<<0
11B20QB10a2200<DPQAQ56400a1Q00@@H1B15:4DXP8@PPP@HP03584@PAB1008DP@0;488@HQ1Q464@
PQB1488@HQ1Q468@PP0548401Q22464<HA1P560DP0@DP@05564@HQ1Q464DH@024642340446423403
46402121584DPAB1464@@@a0440246401110560@HA1Q0Pa00a1R00H@HAAQ560@H11Q468348854640
1A1P340@HA1R58800Q1Q00D<HA1Q464@HA1P00<@H@07364@HA10464DPQRR58800Q1Q10aQ00L@H@a0
440<@0PP340@H002484236400`aR364<H@0346402122464@H11P440@H1B2468236443442340010Q0
340<@0a00`aP0Pa00`a100H<H@a0340@@111464336400a1Q364<@0023403360434001@aQ368@PQ22
36400Pa00@a100000ejcH[9R/P05H[82H[401FJbH[=V/fJcH[<00f;D00MR/fKDI]AVe6KCH]AVe002
I]<00fJcI]AVe003I]@2I]D00fKDI]=Vd`02I]<00f[CJ]9ZdP02J]<00fKDI_AVm002I]@00f[CJ]AZ
e@03I_D00fKdI_EZm@05J_D01V[dJ_E[5F/EJ_AZm@9Zm09Zm@03JaE[5V[e009Zm@04LeIgUf]iALl2
00001S6>GY5_57<EK_A_5@9_5P03KaM_5VlF009_5P03KaE_=Fle00=_=PA_=`04KcI_=flgKcL2KcH3
LcH5KcL<LcL017=GKeQcEfmG0VmH0W=H00=_F7=HLeP027=H2W=G00=gEg=GLeL027=H0W=G00=gMg=h
LgL01G=h0WMh0gMf0WMg0gMh00EcN7=iLgUgNGMh00=gN@=gN0egN@03MgQgNGMi00IgN@=gNP05MgUg
NWMjMgUgV004MgT2MiX00gNKMgYgVP02MiT2MgT00gNIMgUgM`02MgP01WMiMgYgVWNJMiUgV09gN@9g
V@=gVP=gNPEgVP03MgYgNGNI009gVP04Mi]gVWMiNgT2MiX4MgX017NJMgUgNGMi17NJ0WNK02=gNW]i
NgMoegoJL_E8i3RR@@A50d43><8/XS34::@dXcR2?84lHD10A21@`UTUG<5H@4@TGB=k<7ogOmYkVG^J
Mi]kVgNJ009kV@03NiYkVg^K00EkV`03NiYk^W^j00=k^P03NkUk^W^j00Ek^`Mk^P=k^`03NkYk^g^k
00Mk^`04NkYk^g^kNk/2NkX00g^JNkYk^P0ANkX5NkT3NkX5NkT7NiX00g^INiYkVP03NiX;NiT01G^j
NiUkVG^IMiT00g^I1GNI17^I00AgVGNJMiYgVPMgV@AgVP04NiUgVGNJMiT5MiX2MiT2MgT2MgL03gMf
MeEgMG=GLcIc=G<dJ_9_55jc>FX<00@0468DP@0246000`aP340<@00:3402440010PP344@@1100Q1Q
00<@PA2248800a2200<HXaS45:8011B200dDXQB2588@HAB27<DHPQAQ560DHA22588HX`0358801122
584DH1R10QB100DDPQ2248<DXa1R008@H@8DPP8DP@8@H@8DP@09484@PQBR488<HAAQ584DPQ1R00<@
H@<@P@8@PP0:48<DPQ1R688LXaAQ464DHAB168425640111R588DHAAQ111Q00X@HQ22468<@A1P564D
PAB2388@PP8DP@H@H@8DH00:464<@@PP220@HA11464DHQB2564446423642464356400a1Q340@H@02
4682464010a0460@HAAQ0a1P00P@H@aQ464<@11Q468LXaAR0Q1Q00`@HPaR364<H0aQ340@@11Q440<
@11P464236400`aR364<H@0236401A10464DPQ1R46400Q1P00H@HABS368480aP464534400`a0360<
@00334001@aP364<@0a034400PaQ00<<@@a044000Q1Q00<<HA1R36400Pa10Pa000@<H0Q12408@08<
H08<@003360<HPaQ008<H@4<H04<@04<@@0000=N/f:bH[800f:b00=R/F:bH[800V:b00IR/fJcI[=V
dV:cH]<3H]@00fKDI]=Vd`06I]<4I]@00fKEI]AVe002I]<2J]<01F[cJ]9ZdF[BJ_800VKc0VKd00AV
e6[CJ]AZe0=Vm@9Vm004J_AZmF[dJ_D3J_@4J_D3J_@2J_D00f/EJaI[5P02J_D03f[dMgQgUfk`<>P0
010TALeZlgMDJ_9Zm6/EKaE[5P04KaH2KcH016leKcI_=VlF0V/F00=_5flgKcH01flg00=c=VlgKcL0
0flg00Ac=W<gLcMc=`9_=`03LcM_=flg00=_=`McE`=_F09cF004KeMcF7=HLeP2LeL00g=gLeMcE`0>
LeL7LeP017MhLgQgMg=G0WMH0WMi00=gN7MgMgH017Mf0WMg0WMh1gMi1gMg00=gN7MiMgT01GMi00=g
N7MgMgT00WMi0gNH00=gNGNIMgX00gMi0WMj00=gNGNHMiP00WNH0WNI17Mj0gNJ0gMi0gMh00=gVGMj
MgX00WNI1GNH00=gVGNJMiX027Mj1gNJ1gMi2GNJ0WNK01mgNW^JNgQoegoJM_E0`SR2?>A0i3cT>>8d
`SC3<<@dXSRR?80lH410A41<X5SSG<1LH4A2D<5c3WohOo]kV@04NiX00g^HNiUkVP07Ni/00g^kNkYk
^P06NkX7Nk/00g^KNkYk^@02NkX3Nk/5NkX4Nk/2NkX00g^JNk]k^`03Nk/:NkX<NkT01G^INkUk^W^i
NiT01G^i00=kVG^iNkT00g^i6W^I1GNI1G^I0gNI00=kVGNIMiT017NI17NJ0gNI00=gV7NIMiX00gNJ
0WNI0WMi00=gMgMfMeH00WME00acEg<fLcEgEG<eKcIJTbd91008811R464246000`a0220880033402
3605340244003@a0344<@@a0464@HQB1488@HPa0364@PABR008HX`DDPP04464@HQB2488258801QAQ
464DPAB1588DXP8DPP0658<DXaB2460DP1B11QB20Q1R00<DXQRS48800a1Q0aB10Q211AB11a1Q00D@
HQB25:<DPQ1R00<DPP07464DHAB07:4HPAAR46801A1Q111R00T@PQB2588DPQAQ484DXQRR58401a1Q
00P@H1AP464<H@a0464DHQ1R1Q1Q00<<@0aP36400Pa00QAQ00<DHQ1R46400a1Q0PaQ0Pa000L@H11Q
464@H11Q340@H@0236400`a0464@H@0346834640111P360<@@a00a1100<@H11Q36000PaQ010@H@aQ
364<HA1P320@H11Q364<@11Q460@HA22364<H08@H08<@004360<H@a13402360334000`Q0340<@006
34002@a1588DP@aP364@HPa1220<8002340010Q0220480Q00Pa000D<80a0364<H@Q000<<H04<@@00
00AN/f:bH[9N/PAR/P9R/`06H[9R/f:cH[=R/V:c0V;C0f;D00=Vdf;CH]<01FKC16KD00=VeFKDI]@0
0VKC00MVdVKCI]=Zdf[BJ_=ZlP02I_<01VKdI_=Ve6KCJ]AVe0=Vm@=Vm0=Zm@9Zm005J_EZm6[eJaEZ
m@03J_@2J_D00f/EJ_IZmP02J_D03V[dKaEgMgMeGW0D8`009<MRe7MDK_=Zm6[eJaD2JaH2KaH7KcH<
KcL2LcH6KcL2LcL00flgLcMc=`02LcL3KeL2LeL2LcL00g=GKeM_E`04KeP017=HLeMcEg=H3W=G00=c
F7=GLeL017=G1W=H00EgMg=hLeMcF7MH00AgN0EgM`=gMP03MgMgN7Mi00IgN@EgM`9gN003MgUgNW=j
00IgN@04MgMgNGMiMgT3MiP00gMiMgYgNP06MgX2MgT3MiP2MiT00gMiMgYgNP04MiX2MgT01GMhMiQg
V7NIMgX00WMi00=gVGNHMiP00gNH0WNI00=gVWMjMgT00gMi0gMj1GNJ00=gVgMjMgX01GMi2WNJ17NK
00]kVgoJOoe^U3QQ=60li444?@@m0cST008di00@=:8hXcbS?654PTQPC:1@XEbPH818@TBPL/aon7og
OmP2NiP2NiT00g^HNiYkVP02NiX6Ni/6NkX00g^kNkYk^`07Nk/4NkX3Nk/5NkX5Nk/00g^jNk]k^`05
Nk/00g^jNiUk^P05NkX@NkT00g^INkUk^@03NkT3NiT3NkTINiT00gNINiUgV@04MiT017^IMiUgVW^J
0W^I00=kV7^IMiX00gNJ0gNI1GNJ0WNI00=gV7NIMiX00gNJ0WNI00IgNGMhMgMgMgMfMeD2MeH02g<f
LaA_=G<fKaI:<Qb70008811R36400Q1Q0`aQ0Pa01@aP00H<@0PP340@@0a04402340346400a1P484@
PP0246400aB1588DPP0358800aBR6:8DPP024646588268400aB25:8DXP025:<00a2S48<@P@025846
58801aB35:<@XQC4488<HA22008DP@8DPP04488DPAB1584258800aAQ464@H@064640111R588DPQB2
111R0QB100DHXQbR568<HA1100@@H@8@PP04468@PQ2248825882464011216:8DPA1Q0Q1R0Q1Q00D@
PQB1464@H@aQ008<HP04464La1R2564446400`a0464@H@0346401AAQ688@HQ1Q48400Q220Q1R00<<
H@a134000Q1Q00D@H11Q464@H@aQ008@HP08368@HQ1R468DHAB2488@H@8@H0`@H@03488@H@aQ008@
@005460@H@aQ364@H@0236401a1Q364<HA1P360<@111008<H@03464<H0a0008<H003364<@0a000@<
@08@@004460<@0PP36425:<246401@aQ344<@@a1340010a100@8@@a0320<H0@<H@4@H04<H04<HP00
00ANdV:aH[5N/PER/P03G[9R/V:b00AR/PARd`04I]=V/f:cH]<7I]<6I]@00fKBJ_9VdP02I]<3I]85
I_<00fKDI]=Ve003I_D2I_@01VKDI_AVm6KdJ_AZm@=Zm003I_EZm6[d00MZm@08J_IZmF[eJ_E_=G^F
J_<iJ@800005BS1c<flDJ_AZm@02JaD2KaH2KcH00fleKcI_=@02KaD5KcH8KcL00g<fKcIc=P02KcH3
KcL00flfKcM_=`02KcL2LcL5KeL2LcL00g=GKeM_F004KeP01FmGLeMcEg=GKeL00g=G0VmG0W=G00=_
Eg=GLeL01g=G00Ac=g=GLeMcE`EcF004MgMcF7=GLeP2MeP3MgP00gMgMeMgM`02MgL01GMfMeIgMWMf
MgL00W=h00MgN7MiMgUgNGMhMgMgN003MgL2MgP00gMiMgYcNP05MgT00gMhMgMgN002MgP3MiP00gMi
MgYgN@06MgT00gMhMgUgV003MiP017MhMgUgNGMi0WNI00=kVGNJMgT00WMh0WNH0WNI00EgNGMhMgMg
N7NH009gN005MiQgVGNIMiUgNP04MgT3MgX5MiX00gNKMgYgNP05MgT00g]iMiYgVP03MiX00gMiMiYg
VP03MiX037MjMg]gNGojOoiVDc10=6111454@DDm108hi006=<<hXCB2>88lHT220TAP00m<`EcQG:1<
PTc0L/]on7o_Om=o^7oHOmMo^7^GNiP00g^I0g^J0g^K00MkVW^iNkUk^G^JNkYk^`03NkX2NiX3Ni/0
17^kNkYk^W^i2G^j17^k00Mk^W^iNiYkVW^KNk]gV`02Nk/00g^jNiUk^P05NkX00g^iNiUkV@02NkT0
17^INkUk^W^i2G^I00Ak^G^jNkYk^@=kV@9k^@=kV@03NkUkV7^H01AkV@04MiUkVGNINkP3MiT02W^I
NiYgVWNJNiQgV7^HNiUkVWNJ0gNI0WNH17NI00EgVWNIMiUgV7NI00AgVP03MiQgN7Mh00=gM`0>MgEg
EGLfLcMc=G<DKa=_=VKf?Jl@IP00200@HP8@H@03460<H0aP008<@005360@H11Q460<@00246000`aP
340<@00234002`PP340<H0a0320DP1RR588<@11P58400QB200<@P@a0464011B200<DXQB258800aB2
00TDPAR1584HPQRR7<@Pi1c45:<00QB200<DPA2258800aB200XDPA22468DPQRS6<@@PQ1Q584HXP8D
P@8@H@8DP@045:4HXaB2564346401A1R464@HA1Q3640111R00DDPA1Q468@HQ1Q008DP@03588DHA1Q
00@@H@03588H`aRR008@P@04464@PQ22584234001A1R584@PA1Q36400Pa000<@HA2158400Q1Q00<<
HA1R46800Q1Q00<DPA1Q3440211Q0aB100<@PA1Q48000Q1Q0a1R00<@@@a046001Q1Q00/DPaB2468<
@Q11464DPQB1464@H0a0008@H003360@H11Q008@H@03364<HPaQ00<@H@04364<H0PP220234023640
2A1R364<@0a0344880`P460<H00234000`aQ468@H0033400111P588<H0PP10a000@@@11P580@H08<
H004364<PQ224882464436400`a12448@@0234401@`P340<H@aP24000Pa00@aP0@aR00000ejcG[9N
/P04G[83H[<7H[83H]<01f:cI[9V/f:dH]=R/fKB00AVd`AVe005H]AVdfKCJ_=Vl`04I]<00fKBI]=V
d`03I_<01FKDI]=VdfKDI]D026Ke0V/F16Ke26[e0f/F00i[5FleMeIcEV9<100002e;Ja9cEV[eJ_AZ
mF/F0VlF00A_5FlFKcI_=P=_5PE_=PE_=`04JcM[>6/hKcL2LcH00flfKcM_=`08KcL00fmGKeQ_E`02
KeL017=GLcMc=W=G0VmG1FmH00=cEfmHKeP02W=G00=cF6mHKeP00VmH00=cEfmHLcL017<g00=c>7=H
LeP027=H00IgF7MiMeQgNGMHLgT2LgP01WMgMeMgEgMgMgQgN@9gN0=cN003MgQgNGMi00=gN0AgN@03
LgYgNGMi00AgN@03MgQgNGMi00AgN@9gNPQgN@04MgYgNGMiMgP2MgT5MiX00gMjMiYgN@02MgT5MiT0
1WMhMgMgMgNHMgQgN@9gV@05MgUgNWMjMgYgN@06MgX00gNKMiYgV`02Mi/2MgX3MgT01GMjMgUgNWMj
Mi/00gMj0gNK0WNJ011kNGMjMgYkV7ogOoaVLcB1>:5114UV@DHi0cST?@Dh``8hPP8lPP0A@650@41P
C>EE9Ed4A89<`6Y3NkIo]G]fMeMkMgnfOmQo^002OkT017^iNiQkVG^K0W^k00=kVg^kNk/00g^i00Ik
VW^jNk]k^g^jNkT2NiX2Nk/00g^KNiak^`03NkT8NkX4Nk/4NiX00g^KNk]k^`02Nk/3NkX00g^kNkYk
^`03NiX3NiT017^iNiUk^W^j1g^I1G^i5g^I00AkVWNJMiUkV0IkV@04MiUkVGNIMiP4MiT2MiX01GNI
NiQkV7^HMiX017NI0gNH17NI00AgVWNIMiUgV09gV@9gVP04MiUgV7MhMgP3MgL03GMeMeIgEW=GLcI_
5F/CKcER]3V=32@000PP008@H@03344<@0a000<<H003340@H11P008@H@05460@HA1Q468@H@023400
20@P240<H11Q440HP2D68>D658800a1Q444DH@0258800aRR8>DHX`04588568800abS9>DHX`045882
488258801ARR4848@11Q56400QB200P@HQB17:<L`aR1464<@A1Q0QB100DDXABR588DHAAR00D@HP08
464@PQB2588@HA1R584@H@8@HP@@H@04564@HA1Q340246402AB26:<HXQB2564@HA1R488@H@034680
2A2258<@HPQ0368@HQ1Q488DP@0246401a1R364<@0Q0364DHA1Q008@HPD@H@04488DPQ2246444842
46401A1R464@HPa134000a1Q00L@HQ1Q464@HA1R464<@@02220020a0464@HA1Q460@@11P36024602
464436400a1P364<H@02364334402`aQ2448@0QQ364<8110360@H11Q46000PaP00P<HA1Q464@@0`P
340<H11P0Q1Q00<<H0a034000PaP0Q1P00DDHA1Q364<@0a100<<HP03364<@@a0008<@003364<HPaQ
00<<H@03340880QQ00<<H@4@@04<@04<@@0000=J/UjbG[801ejb0V:b0VKB00AR/V:aH[9R/P9Rd`03
H[9V/VJc009Ve008H[=VdfKCI]9VdfKBI[=Vd`9R/`03I]=VdVKB00IVd`04I]9VlfKdH]@2I_<2I]<0
2F[dI_EVmFKDI_A[5V/EJ_AZm@02JaD01F[eI_EVeFKeIaD01V/F01E[5F/FKcI[5V[eKaE_=G<fLeEg
MGMA:<H001b5HZicMflfJ_AZmF/FKaH00flE1FlF1Vlf26lg0flf2Vlg00=c=fmHKeP00VmG00=cEg<f
LcH00g=G0VmG0fmH0W=H0W=G0fmG1G=G00I_EfmHKeQ_F7=GKeP6LcL3LeL8LeP2MeL5MeP2MgT017MG
MgQgN7Mh0WMi0WMh0gMg1GMh00=gMgMhMgT047Mi0WMj00IgNGNIMgUgN7MiMiT2MgT01GMjMiUgNGNH
MgT00gNJ00=gNWMiMgT01WMi00IgNWNIMiQgV7MhMgL3MgP00gMiMiUgN@05MgT3MgX5MiX3Mi/3MiX5
MgT00gMjMi]k_002Ok/00gnlOmeog@02Om`037nkOkYkVWoHOoQooVkg=:8l`T43@B<m0`8`XP8`X`0M
<88dPDC1A<8lH300?454YDcUB:=0PDBPGL=Vbf[^I_1VdVKcJaA_=WMFNeIoUgnhOkUo^WnkNk]kV`02
Nk/2NkX017^iNkYk^W^j0g^k0W^j0g^k0W^K00=k^g^jNkX00W^j0g^k1g^j00Mk^g^jNiYkVW^iNiYk
V`02Nk/2NkX00g^INkYk^P02Ni/017^jNiYkVW^J0W^I0g^i00Ak^W^iNkYk^@=kV@=k^AYkV@03NiYk
VG^I00MkV@9kV0MgV@04NiUgVG^HMiP3NiP4MiP9MiT3MiP3MiT00gNHMgQgN003MgL03gMeMeIgE7MF
MaE_57MELcIV/cE/22<400a0464<H003340246001`aP340<8110460@HA1P00<<@08@@00>3408@0Q0
360@H1AP680PiB3V58<DPQRS588@PP<DPP08584DPQBR5:<H`aRQ460@H@<DPP0958<DPQB1584HPQRR
688DPQAR00@@PP8DPP045:8DP@a1340246400a11564DP@0268403aB1464<@AAQ6:8DPAB05:4DPQ1Q
468@PQAQ464@HP03464358800aAR564@@00246800a1Q360<H@0446424600211Q564DPQB2584DH@a0
364446800a1Q468@HP03468011B2584DHAAQ0a1Q00@@HPaQ364@HPP@H@03584@PA1Q008<@003560H
XAB100<@H@04488@HQ1R46834643468010a1464@HA110PPP00@<@0PP220<H08@H@0:340<H@aQ360@
H11Q584@H@aP3642460020a0464@H@aQ340<H@aR364224000`aQ340<800244002QB0460@H0a0464@
PQ1Q364<@@PP0Pa00Q1P0Q1Q1A1P00@@@11P364<H@8<@@8<@P03248<@@a0008<@006460<@0a1364<
H0Q00Pa000<<H0a136400PaQ0@aP0@a00@a100000eJBFY5NT@04G[82G[<00f:cH[9R/P02H[800f:a
I[5R/@02H[801V;CH[9V/fJcH[=Ve0EVd`=V/`9R/`QVd`04H]=VdfKcI_<2I_@04F[eI_=VdfKCI_E[
5FLEI_EVdf;CI_AZm6KdI]=Vm6LEI_D00V;D00EVmFLFI_EVmFLE00=Vm@9[5@9Zm00;J_=Zm6/CMgMg
MDH@000404G]KeQ_=P03J_D00flEKaI_5@02KaD4KaH4KcH;KcL00flfKcM_=P0:KcL00fmHKcQ_E`09
KeL2KeP3LeP2LeL3KeL5LeL3KeL00fmHLeMc=`05LcL00g=GLeQcF003LeP017MHLeMgMg=G0W=H00=g
F7MGMeP017MH00=gNGMHMeL017Mh00=gNGMhMgP00gMg1GMh00=gMgMhMgP047Mi0WMj1WMi00=gNWMi
MgX017Mi17Mj2GMi00=gVWNIMiT00gNH0WMh0WMi00=gNWMiMgT00gMi0gMj00=gNGNJMiX01WNK00Mg
VWMiNiYo^GnJOk]oo@02Ooh2Ool2Omh01WonOomoo7oLOm]ofP9on`05OoYoofJd;84T@002888051Q1
620D81Q098<hXSR0?84hHCA1;00X03QQB<E4a3aQA<1MXeHYFTX2ET`03EI=FViNSf:_I]9[57MhOkMo
^7nGNiUo^W^j009kVP=k^@03NiYk^W^l009k^`=k^P05Nk]kVg^KNi]k^`05NkX5Nk/6NkX2NiX00g^i
NiYkV`02Ni/01G^kNiYkVW^iNiX017^K0W^J00=kVG^iNkT00W^i0g^j0g^I0g^i00Ak^W^kNiYkVPMk
V@=kVP03NiUkV7^I00YkV@03NiYkVG^I00=kV@03MiUkVG^I00AkV0=gV@IkV@IgV0igV@9gVP04MiUg
V7NHMgP3MgL037MfMeIgEG<fLaE^lg<cKcENL34Y104<@P8@H@09340<H@a0340@H11Q360<HA1Q00<@
@004460<H1104402320020a0460@P121584HPAAP588258<458801ARS58<DPQB26:800aBS00XDXPa0
464DPQRS9@HLa1B2584@H@HDPP04488@HA1R584258801AB1468@HA1R56400Q1Q00PDPQB1588DP@a0
444DHAB11AB200@DXQB2568@H@8@HP8@H@0;584DPQRR588@HQ11244<HA21488@HP0546401AAQ464@
HA1R58400QAQ00<<H@Q13640111R00<@HA1R46800Q1Q00<@HQB156400a1Q00@@HQ1Q488DP`8@HP8@
H@03468@HA1R008@H@03584@PA1Q008<8003440HXQRS008@H@04364@PQ214883468258800a22468<
H@02464244401A1Q340<80a036001@aQ00L<H11P464DHA1P120<H@04464436402`aR364<@0a0360<
@0`P440@H1B046400Q1P00D@HA224888H@Q100888007344<H0a0340@H11Q48800Q1Q0Q1P00H<HA1Q
464<@0a12244344010a0360<H0a00Pa100H<H@aP360<H0a036423443340134400003EW5JLEY`00IJ
T@9NT@03G[5N/Ujb00IR/P0:I[9R/V:cH[=Vdf:cI]9R/VKBI]<3I[<00fKDH[=R/`03I]<016;CI]=V
dfKC0fKB00IVlV;BH]9N/UjaGY02FW000eZ@FY5JT003FY001EjAGY1JT5j@GY400UZA00MJTUZAFY5J
TEZbFY5JTP02FY400ejaGY5NT002GY002f:@H[1[57=GCU880@00<BUW5VleJaD00V[e00=^mFlEKaD0
1VlE0VlF0Vlf0flg00=_=VlgKcL016lg1Flf0Vlg00Y_=VlgKcM_=W<fKcI_=fmGLeM_E`=_=`9_E`03
KeQ_EfmG00A_E`04LeM_Eg=GKeL5LeL00fmGLeM_E`03LeL00fmGLeM_>007LcL4LeP2LeL01WMFLeMc
F7=HMeMgEP=gE`9gF003MgQgMgMG009gE`9gN003MeQgN7Mh00QgM`=gE`03MgMgN7Mi009gN@03MgQg
NGMi00egN@05MiQgN7MhMgUgN003MgT00gMhMgUgN@03MgX9MgT02WMjMgUgNGMhMiQgN7MgMgQgV7Mh
2GMi00=gN7MiMgT00WMj17NK00Ik^golOoioo7okOo`2Omd017^KMgYgNVli0VlH00][66lFKaE_57Mf
NkUongonOoaFD1@000<<0009200<0100640PHRb0>60dH310008X0008800`83aP@:8lPDSPFLAFB`9B
;00@ERUB:U89DPUF:EY;FVaNSV:`JaAcEW]gOkIk]gniNkX3NkT00g^INkYk^`02Nk/3NiX3Ni/2Nk/0
1W^jNk]k^W^jNiYkV`9k^`9kVPMk^@04NiUk^G^jNkX3Ni/2NiX00g^iNiYkV`03Ni/017^INiYkVG^i
1W^j0g^I17^i00=k^W^JNiX01g^I00=gVW^JNiT00W^H00=kUg^HNiP00W^I00MkV7^INiUkVGNINiUk
VP04NiT017^GMiUkV7NI17^H00=gUgNIMiT017^I0WNI0WNH0WMh0W]g00EgN7NHMiUgVGNH009gV@=g
V09gV@03MiQgVGNI00AgV@0@MiQgN7MhMgIgMGLfMcAc=FlDK_5^kfkbDPhTP`003442460010aQ464@
H1100Q1P00P<H0a0440@@11P464@H0a00a1000<<@11P46000QBQ00THXQR2588DHQB3468<@1AQ5840
1AB200lDXQBS5:<DXaBR584DPQBS7<DY9b3U688DHA1Q46800Q2200@@PAB1584@PP8@H@04564DPABR
58824682568458800aAR588DPP0256402aB1344@HQB25:8HXaBR588@HQ1Q44400Q1Q00X@HQB1584H
XQB2568@HA11440DP@<@H@06584@PAB2488@HQ1Q0Pa000L@HAAQ584@PQ1R344<HP0446800a1Q444<
@00446401AAQ468@PA1R56400Q1Q0a1R00<DPQRS56400a1Q00LHXAB2468@HPa1320<@00246423400
0a1Q584@H@03468358<01Q22468@HAB2468<H0@@H007360<H@aQ364@PAB246400Pa000D@@0a0240<
@@aP008@H0D@H@8<H@0;340<H0Q0340<80a0460DH110320@@00246001aB1464<H@a0344<H@aP008<
@003220<H0aP00@@H08@H@04460880PP244334400`a02208@003340020a1364<H@aP464<H0a03204
340124400003EY5JTEZA00AJT@9JL@03FY5NTEjb00=N/`9N/P9R/P04H]=R/V:bH[<2H[8016:cI]9V
dVKB0V:c0VKC00AVe6:cH[=R/`9Vd`03H]=VdfKC009Vd`AVdP05H]=JTE9>DPaB;@03DTh2DRd0159=
DTiBCEI_0U9>0e9?00aBLEIaFY9FLEJAFY5FLE9@DTiFCUI_FVl2ETh03eY?FVmNTF:cCU8L@`0088EN
mW=EJaEZmF[dK_E_5P07KaD2KaH01VlfLcI_=flGKcM_=PM_=`03KcI_=flg00M_=`04KcI_=g<gLeL2
KeL3KcL2KeL5KeP00fmGKeQ_E`02KeL00fmHKeM_E`05KeL3LeL3KeL00fmHKcQ_>004LcL00g<hLeQc
F003LeP00g=GMeMcE`03LeP02gMgMgUgF7MHMeMcF7MgLgQgMg=GMgL00WMi00AcNG=hLgQgN09gM`03
MgQgMgMg009gM`=gE`03MgMgN7Mi015gN@03MgYgNGMi00UgN@MgNP03MgUgNWMi00EgNP9gN@03MgQg
NGMi009gN@03MgYgNGMi00=gN@=gNP03MgUgNWMj009gNP05Mk]og7oMOoeoo`02Ood02GNKKcUVeEYA
CNi5cSE:9<LPY`028:H02b368:@TY2BS<>HeBD7^CW5>Tbd700000PP00P`000T@8A0P764PHBAQ;60`
@30P;0000R@000/`841P@84hHD30DLEFC5I;ETaFBUI;009FBP0<ERUB:E8XDPUB:UH[GY1W5FmGMgQk
UW^h0g^i0W^j0W^k1G^K0g^J1G^j0g^J0g^K0W^J1g^i17^J00Ak^g^jNiYk^@AkVP03Ni]kVG^J009k
VPAk^@=kV@03NkYkVG^j009kVP04NiUgVW^JMi/4NiX00gNJMiUkV@02MiX6NiT017NINiQkV7^H0W^I
00EgVG^IMiUgVG^J009kV@03MiUgV7NI009gV@03NiUgVG^I00=gV@9kV@03MiUkVGNJ009gV@=gV004
NgMkV7NHMiP5MiT00gNHMiUgV@05MiT017NHMiUgVG>I0g=i00]cMgMfMeEg=7<eLaA^lG<@K]19ba@P
0084000<440<80PP340@H110460<H110340@@0aQ0Q1Q00@<@A10440@@0@@H008480@PAB18<<HPQB2
688DPP8DH@03464@HQB200@DPP8DX`056<<HXaB1584HPP0258<00aR2568@@@0222001PaQ464<HAB2
7:8DPP8@PP06564DPQB2488@HAAR0aB200hHXaBS488<@1B27:@HPAB2584@@A1R588DXaBT0QB200H@
HQB2588@HQ1Q488258800aRR6:<@HP0246400a10464@HP0346400a215:<DX`02464021AQ464@H1AQ
6:<LiART488546800`a2320<@00246402AB1564DHA1R464@HQAR464@@@0246402Q1R464DPQB1464<
@11Q5:8DPQ220Q1R0Q110Q1Q0PaQ00H@HAB1464@HA1R568258<01QBT488@HQ1R488<H@<@H@8@H003
484DXQ22008<H@09388@P@aP340<H@a1340880a0008<H003460@HA1Q008@H@8<H@033448@@Q000<<
@08@H003440<80P0008@H009560HXQ1Q364@P`aR360<H@aP00<<H@07464@PQ1Q464@H11Q46000`aQ
10aR00H<H@a0340@@11Q488236801122364<H0PP10a00@Q00@Q1000015ZaEY9JTUZA0Ujb00=N/EjA
GY400UjA00UJTEYaEW5JTUjcGY9NTF:`H[400f:b0V:a00ER/VKBI]9VdV:b00ARd`06I]AR/fKDI]AR
/f;C0VKC00=Ve6KCI]800VKB00aRdUj?CN]5c4h=BPe:3U8^DTm>;U9?EVl3FXl035j@F[5N/EZbG]9N
/eIbDU9FLUjcH[9N/P9N/@05GY1JT5I_DTiFCP02DRh03E9@FW5><BcU000<0EJCLeE[56[eJ_A_5F/E
00=_5@04KaI_5FlEKaD4KaH01FlgKaM_5flfKcL01Vlf16lg0flf3Vlg00=_EfmHKeP00VmH17=G00=_
Eg=HLeL02g=G00Ac=flgKcM_=`=c=`03LeQcEg=H00IcF003LeMgMg=G00=cF09gF003MeMcEgMg00Eg
N005MeMgMgMgMgQgN@02MeP2MgL00g=gMgMgM`02MgL00gMfMgMgE`07MgT3MgP6MgT00gMjMgUgN@04
MgT2MgP2MgL00gMhMiQgN003MgT3MgX:MgT2MgP00gMiMiUgNP02MgX5MgT017MjNiYkNWMi0gMj00ak
^gomOoeoo7oLKeMVleI??J/TaAQ2324700000`P03008000500001001000000000``000L@81A1764L
HB1P:40/@002<2002BP0;00d83aP@60h@D3QENEJK002ERX2ETX015Y:ETYJBEY90eHY00YF:eH/ETiN
T6[cKcEgMWnfNkMk^@=k^P03NiYkVg^K009kV`03NiYk^G^i00=k^@03NiYk^W^J00=k^@04NiYkVg^K
Nk/5NkX4NiT3NkT3NiX00g^jNiUkV@02NiT2NiX2Ni/00g^JNiUkV@07NiT3NiX00g^INiYkVP03Ni/2
NiX3NiT00gNJNiYkVP0KNiT00gNINiUkV003NiT00gNJMiUgV@02MiP00g^HNgMkV002MiP00gNIMiQg
V007MiP00gNIMiQgV003MiP03WNIMgUcN7=hLeQcEg<fMcEc=G<DK_5g<VZ_@HT220002PPP320<80PP
320<@110460@HA1P0Q100Pa00`a10Pa0018@H0a0460@PAB0340DH1R16:8HXac36:8HPAAP464@HQ22
5:<258801A1Q588DXQRR5:800QB100X@HAB2588DPPa1240<@0Q0364@PP8DPP07584DPQBS588DHA1R
48800Q1Q00<DHAAR588011B200<@HQAR58400aB100PDPQ1R488DPQBS58<@PQB20QRS00<@PQ1R4680
0aB100HDXQAQ464@@0a0444336401aB1564DPQRS5:8DPQAQ008@H@8DH@8DPP04488@HQ1Q46434683
464258400a1Q468@HP03468346400a10340@H@044640111R588@PQB20Q1R0Q1Q00<@HQ1Q46401a1Q
00D@HQB3468@H@aQ008@HP<@H@06584@HA1P480@PA1Q0Pa000<<H12146400Q1Q00@<H@a1320880<@
H0@@H@03364@H@a10088@@8<@08<H005440<@0PP220<@00246000aB2464<H@033644360234000`aP
460@H@0246401A1P340<HAB348<00PaQ00H@PQ1Q364<@0`P460246401@aQ464@H11P22001@a00@a1
000025:@E[=Ne6;DH]=R/f:aGY83GY<3G[<2G[@025jcG[9R/V;CH]AR/f:bH[<3H[800fKBI]=Ve004
H]<00f:dH[=R/`03H[<3H]<02f;DI]=VdVKbH]=JKdF:?HY1c4G/@L`00cf[00/mc47;@La1k3g;>J/m
c48>@Pm23Sg>00Lm[00C>J`iZcEZ>HU1k4X^BPi63DH?DU5BD3DW000404H@Le=_56KdJ_@00V/E0flF
00A[5VlEKaI_5@A_5P9_5`03KcM_=Vlg00I_=PA_=`=_=Q1_=`=_F0E_E`05KeQcEg=GLeM_F005LeL7
LcL01G<fLeMcEg=HLeL01W=H00EcNGMgLeMcEgMH00=cF00ALgUgMgMhMgMgN7MgLgUgF7=GMeMgMgMf
MgMgF7=iLeQcN@02LgP017=gLgQcN7=h1GMg1GMi0gMh3gMi00AgMgNHMgQgV09gN0=gN@05MiYgNWMi
MgUgNP07MgT2MgP2MgT5MgX3MgT2MgX03G]jMgUgNW^INkaooGooMkeW>TXb=F/LP`P000H0000;1008
@QB47<LXaBRT?@HPHAaR34880@030003100320002@`0424H@Qa1844dPSB1=60`8002;0002S@P?40l
H3@P@>5EiUZ<FTYJ:UY:1UI:0UY:00YFBeX[ERYJBeY]H]5[=GMgOkIkU@9kU`9kV@07NiYkVg^KNi]k
^g^jNiX017^j0W^J00=k^G^JNiX017^K1G^j0g^I0g^i00AkVG^JNiYkVP9k^@03NiUk^W^I009kVP9k
V`03NiYkVG^I00MkV@=gVP03NiUkVW^J009kV`03Mi]kVgNJ00AkV@04NiYgVW^JMiX5NiT3MiT5NiT3
MiT2NiT00gNJNiYkV@05MiT3NiT2MiT01GNJMiUgVGNHMgT00WMh00AkMgNHMiQgV@9gV0EgN09gV004
MiUgV7MhMgP2MiP3MgT2LgP2LeL037<fKcE^m6kAMc9V/3e9200<011Q564@H08@@005460@H@aQ364@
H@0244000`a022088004340346002a21584@HA1Q588HXaS38>@TiARR44000Q1Q00D@PA22584DHAR2
00@DPP8DP@07588DPaB358<@Pa2246800Q2200<DXQB258800QB200D@PaB2564DPQ22008@H@05568D
HAAQ568@HP075883468248801123588@Pa1R0QB200@@Pa1R488DP@<DPP03564@HA1Q008@H@8@HP04
464DPA1Q488258801122468@HQ1R0Q1Q00HDHAB1488@HA1R4642344446801AB2584@PQ1Q3440211Q
00@DHAB1564DH@<DPP03488@HQ1R00<@HP<@PP03468DPQ1Q00@@H@<@HP8@H@0;344<H@aQ360DHAbS
688@HA1P464<H002220040a0464DPQB2488@HPaR340@@11P360@H11Q588@H@a00Q1Q00P<H@aR1448
@0a0360<H@a00P`P00<<@11P46400Q1Q0PaQ0Pa00`aP00<@@0a134000Pa000<@@11P44000PaP00D<
@0a1364<HQ1R00@<H@8<@003320@@11Q008@H@03460<H0a000<<@04<H@4<@04<@@0000a>;Dh^EU1>
<4X?ANi5kDX?@Lhm[DXAEU42DU001UIAFU5JLUjBH]=Re09N/`9R/`ER/P9N/P03G[=N/Ujc00AR/`AR
/P=Rd`0;H]9_56KeFU11ZcUY?JTmZ3V8=FLT``0256802QRS6<@Ha11R344880@0120880PQ0PPP00/8
8@Q122088@PP1008010P688aAT7:0095j`04@Ne1kU9@=BH200001T7<Lc1_<fKcJ_=Zm09[5@03KaE_
5VlE00Q_5@03KaI_=Vlf009_=`I_=P=_=`=_=P=_=`03LcMc=W<f00Ic=P04LcM_=flgKcL2LcL01FmH
LeM_EfmGKeP00W=G17<g17=G17<g00Ec=W<gLcMc=g<f00=cE`9gE`03LeMcF7=H009cF003LgQgMg=G
00=cE`=cF0AcE`=cF006LeMgMgMgMeIgEg=G1G=H00AcMg=hMgMgN0AgMP09MgMgN7MhMgQgNGMhMgMg
N7Mg00IgN0EgN@04MiUgNGMiMgT3MgL017MhMgMgN7Mh0WMi00=gNWMiMgT00WMi00=gN7MiMgT017Mi
0WMh00EgV7MhMgQgN7Mi009gNPIgN@09Ng]k^gomOoacVUZeAO4Tj`P300<0000A10088@a1464HPabT
6:@HYAbU7<HXa3D4>BDXa2347:DDQ@026:D00aB458<DP`02468234401PPP224800`0400L@08XH005
;40/02`0;20d@002>40014D2EPIJS5Y:0UY900QFBUY:ETYFBUY:FTUJBUY90eY:00iJ:UY<FTaNT6Kc
KcEkMGneOkIk^7^HNiUkVW^K0W^k0g^j00Ak^g^jNkYk^P9k^@9kVP=kV`Ek^P03NkUkVG^I00EkV@=k
VP=k^@9k^P05NiYk^W^KNi]kVP03NiT00g^iNiUkV@05NiT01WNINiUkVG^INiYkV`=gVPAkV@04NiYg
VWNJMiX5NiT3MiT4NiT01WNIMiQgVGNIMiQkV@9gVP0:NiUgVG^IMiUgUgNINiUkV7^IMiT2MiP2MiT0
1GNHMgQkN7MhNgL01GNH17Mh0gNH00MgVGNHMgQgN7MgMgQgN@03MgP04g=gMgIgEW<eKaE^lfkaMc5R
T2d8100<811P580@H110340@H11Q008<@@8<@004440<@0a0340236400`aP440@H002460446400aB2
5:8HX`028>@02AR1464<@A1R484DPQB1564DP@0358801Q1Q360DXAB2488@HP<@PPHDPP<@PP04468@
HAAQ5842564011AR588DPQB20QAQ00HDPAB2588DPQB148834642488031AR588@HQ1R340@PAB3468@
PQB1588@HP8@H@04564DPAAQ5645464358400a1R444<@002340246400aB1484@HP02464446824640
11B25:8DXa1Q0Pa000P@HA1P440DHAB16:8DPAB00QAP0QAQ0Q1Q0Q1R00T<@A1Q468<@@a0464DPQRR
58401A1Q0Q1R00H<@0a1364<80PP340246403AAQ464@HA1Q468<H@Q0220<@@aP464<HA1Q008@HP05
464<H@aP360@H00546400aB1460<H@0236401PaP464@PPa1320@@08@H006484@H0aP3408@0PP0PaP
0PaQ00@<@@a0344<H@H<@009440@H0a1340<811P464<H0a0008<H08<@005460@HA1P340<H0023400
10Q0340<H0a00@Q100001SV?>D/]1bT79<DPY08LP`0A7:DLYQbV78DLYBC6;@PeJcf/ANm>DEIcG[ER
mF;CH[=R/P06GY43G[8015jAGY9N/Ujc0Ujb011R/ejcH[=R/f;DI_AVlf;DFU55cCUZ?HU1Z3V8=DLH
P`800003220<H@Q1018000087<A5jTh<ANY1bd6/CU0eAP800005?HYc;VldI_=Zm003JaD01FlEKaM_
=VlFKaD00V/E0VlE00Ec5FlEKaI_=VlF00Q_=P=_=`=_=PM_=`03McIc=W<f00Y_=`03KcQ_EfmH009_
E`Ac=`03LeM_Eg=G009_E`04LcM_=flgKcL4LcL00fmHLeMc>002LeL00g=HLeUcF@03LeP3LeL5LeP5
LeL3LeP01G=gLeQcEgMgLeL017=H00EcNG=hLgUgMgMH00EgM`03MgUgN7Mi009gN004MgMgN7MhMgP@
MgT00gMhMgUgN002MgT00gMjMgUgNP0CMgT5MgX02G]jOk]o^WonMkeWFdXb;@TD8P0210001@P0348D
Q1RU6:H00QRU0QRT0aRU00PDPa1Q68<HPac57<@HY1AS11RT00<HYAS56<D00QBU01<@P`a2344<8A0P
400L@2AQ:40/82P0;20`83@0>4158UH6FXaJB`02FTT8ETX2FTX2FT/03UI;FTYJBej>I_=[=WMgNiEk
^7^GNiQkVG^JNi/5Nk/01G^jNiUkVG^jNiT00g^J00Ek^W^kNkYk^g^j00=kVP04NiUkVW^JNkX6NiX0
1G^INiYkVWNJNiT00W^J00Ek^W^JNiYkVG^j00MkV@03MiUgVWNJ009gV@03NiUkVWNJ00=gVP04MiUg
VWNJNi/4MiX5NiT3MiX017NIMiQgVG^I0gNH17NI00=gVWNIMiT00WNI00AgV7NINiQkV0=gV0=gV@05
MiQgNGMiMgUgN007MiP00gMgMgQgV004MiP01WMhMgMgMgMgMgQgM`9cN004LgMcEg<gLcD2Ka@01Vkb
La9BDR280008808@H@05460<H@a0340<H@0534001a1P468@PPaQ468@HA1000<@H006464@H11Q464@
PQB20QBR00DHXaB2588DPa2300<DPP035:8DPQB2008DPP05484DPABR5:<DXP0258<00a23588@P`04
588248800aB2488DPP0358801AR2568DHQRS7<<00QB100HDHAB2588@PQ1R464246801a11464@PAR1
464DHQ1S008@HP0;488@HQ1R488DPA22464<@11Q564DPP0258400aAQ464@H@0246400aB1564DH@02
46402`a1340880`P444@HAB25:8DPQ2258800Q2200PDPQ1R468@HQB2488@HA100Q1R00<@HAAQ5640
0aB200<DPA105640111Q0a223A1Q0Q1R00H@H@aR244<@0`P460248400a22464@H@024644368010aP
464@HA1Q1A1R00@<HA1Q464@H08@H@05488DPA1Q464DPP0446401a11464@HA1Q588H`aBR00<@H@8<
H@08464<H0aP364@HA22364@H@8@H08<H003460@@11Q008@@006320DH11Q460@@0aP0PaQ00@@H@a0
460@H0P<H04<H@0000HD[2c[768D@@`P2003100600002PPQ668PYBT8=D/i[DH?FU1NTF:a1eY`0UZA
00YJT5Y`EU1FL5ZAFY9JLEZCGYANT`9NTP0AGY5NTUYAANhiJSUX@JM5bT7:7:D000P1324<@A1R2444
000@00003aRTALU:2dGZAL]5k4X>=FP88@00;>A^k6mDI_=Zm003JaD00f[eKaI[5P02KaH00flEJaE_
5@04KaD2KaH9KcH00g<fKcI_=P04KcH2KcL00g<fKcI_=`0<KcL00g<gKcM_=`02KeL00g=GLcIc=P03
LcH3LeL6KcL3LcL00fmHLeMgE`02LeL00gMGLeUcF@03LeP7LeL00g=HLeMgE`02MeL5LeL01G=HMgMc
Eg=GLgL00W=G0WMH0WMi00AgMgMHMgQgN0AgN@03MgQgNGMg00AgM`03MgQgNGMi00=gN@04MgYgNGMi
MgP7MgT00gMhMgUgN@03MgT4MgP5MgT00gMjMgUgN@06MgT01GMhMgUgNWMjMi/00WMk011gNW^KNkYo
nGNKFYDY:a1656D@HQAS58<HY1c57>HHaP8HYP<LaP037<DPiBCV00<Pi@049>DPiB3U7<D27<@00abT
6:@HY0026:@25:@02QRT58<DPaB356<@@Q0Q620L@BA00RPP00P/82`0:00`04DSGRINZeY<0UY900AF
BUY9FTUJB@9JBP04ETYJBUY:FTX3FT/025Y8GVYNJf:_H]5W56mFMgH2NiH00g^HNiUkVP02Nk/2Ni/0
0g^jNkUkV@04NiT2NkT01G^jNiYkVW^JNkX00W^K00=kVW^INiX01G^K00MkVW^INiUkVG^JNiUgVP0A
NiT01G^JNiUkVG^INiX00WNJ0W^J00=kVGNJMiX01GNJ17NI00=kVGNJMiX01GNI00=kV7NHNiP02WNI
2WNH00=gVGMiMgT00gMh0WNH00=gVGNHMiP01GMh00=gV7MhMgP017Mg00UgMW=GMgMcF7<gLcIc=6ld
Ka<00Vkb00A5ca1V000880<<@@03364@HA1Q008@H0<<@0<@@0<@H08@@0<@H08@H@03564DPQB200<D
PP0558<DPQB258<DX`025:800aBS6:<DXP0258855:8358825:<248834684464011B1484DPQB20QAR
00<DPR3U8<@00QR10QAQ00`DHQ11344@HQB2568@@A1Q584L`A1P348346<246800aB1588@HP054640
11B15:8DPAAQ111Q0aAQ00@@HA1R468@HP@@H@0:488@PA21584@HAB1588DPA1Q468246403A22584<
H1227<@DPQ1Q584HXQB2484DHA1000@@H@03584@PQ2200`@H@03364<@@aQ008@HP06368<HA10440@
H11Q0aRR00X@PA1Q464<HQ1R368<HA1P360@H@8DPPD@HP8<H@P@H@09460<@0a1340@HAAQ464<H11P
00L@H@05584@PQ1Q360@H002464246001@a0360@HA2046001110111P00D@@0a0364@HA1000D<@08<
H0<<H@4<HP0000/];SD9;@H]B358=FTeBCE:=DT]:2SW008Y1`0C9>HLXaA1420800@0224LQRT8=DY5
cDi@H[9Vlf;CH[5NT5Y`FY400ejb00AN/ejbFY5JT@9JTP03FY=NTejC009NTP0=GY1NTEjABNha:CEZ
@L]5bdX<9<H40@@056800Q1R00H<HP`Q00040000100200000`0100000@0200400`@1100400020000
411R?HM5jTGZAL]>;TG/>J/<H`00985ZkFmFH_AVm6[d0V/E0VlE00E_5VlEKaE_5F/E00E_5@A_5Pe_
=P03LcEc=W<f00Ac=Pa_=`03LcMcEg<g009_E`08LeMc=W<fLcIcEW=GLcIc=`M_=`03LcM_F6mH00Ec
E`03LeUcF7=I009cF0AcE`AcF004LeMgEg=GMeL5LeL3LeP017=GLgMcEgMG0gMH00IgNGMgLgUgF7Mi
MgP3MgT017MhMiUgN7Mh0gMg1WMi00=gNWMiMgT00gMh1gMi00AgN7MiMgUgN@=gN0IgN@04MgYgNGMi
MgT3MgX5MgT03WMjMgUgNWMjOk]k^WonLgYB<RcY74<LQ1B46:D37<H00ac57>HPi`028@P00bD99BPY
:002:BL02RDW;FX]JR4X9DT]JBU8:BPU1b470R3V0Qc50QbU00dHYART58@HQ1B45:@DPa1R544@8211
;64X8002:00290001dDTIVMNZeI;FTYJBEY:00=JB@9FBPAJBP=JC00>FT]JBUHZET]NSf;BJaE[EgMF
MgEgUg^INiYk^`=kV`03NiYkVG^I009kV@9k^@=kV@9g^P04Mi]kVg^KNi/6NiX2Ni/017^jNiUkVG^I
0gNJ00=kVG^jNiT01W^I00=k^W^INkX00g^I00AkVW^INiYkV@9gVP=gV`03MiYkVgNJ009gVP03Mi]g
VWNJ009gVP=gV@05NiUkV7^INiUgVP03MiT2MiP2NiP00gNJMiUgVP0:MiT01GNHMiUgV7NIMiP00gNI
0gMi00=gVGNHMiP01GNH0gMg00EgN7NHMiQgVGMi00=gM`0BMgIgEW=GLeMc=W<eLcA_=FlDK_9V[cU/
108400`P340@@@a10PaQ00D<H11Q464@H@aQ00D@@08@H08@@003460@@11P008@H@8DPP08584DPQRS
488<HABR6:@DX`<DXP8DX`075:8DPQBR6<@La1S45:800a220Q1R00H@PQ2348<HY1BS58<258824642
58801aB1564DHQAQ468DPQR1008DP@05488@HQ1Q464@HP0258802122464@HQBR7<<DPA1S48<65880
1a1R464@HA22588@PQ21008DPP03564@HA1Q008@H@05564DPARR468@H@02468011BS488@PQ220Q1R
00@@HA21588DP@8DPP034688@@PP008@H@03484@PQ2200<@PP8DPP8@PP03464<811000@@H@8@HP8@
H@8@HP04368@H@aR4682464236400`aR344@H@0246801A1Q344@@@`P34000Q1Q00<@PQ1Q46400Q1Q
0Q1R0Q1Q00D@H11Q464@HAB200<@H@03468<HPaQ00<<H@04460@HA1Q464246002@a0364DPaAR464H
PQ1Q220<@0063602464248800`aQ360<@00234001@aP340<HA2248400Q1Q00`<@110340@H1B2584@
H0a0320@@0aQ46433202340248800`aQ368<HP0138<0000:?Li1kDi@FW1R[eY`GW1NTV:AH[42J_40
55jaEW1BCdW/AL/iJ2S4324000P144<XaCDX?JY>CUj?H/mN/6KCI_<3I_@2I_<05F;cH]9Rdf;DH_EV
mF;DH[AVdfKBI_=W54Y@<DXeJSU[?HU9jbTW32840002464246800`a10000000200000`@000000002
000200400`@11004800200004``P>FA9jTG:AJU9k4X=@L/LY000741R[V]GH_EVe6[dJaE[56/E00A_
5@03KaA_5FlE00A_5@9[5@E_5@03KcE_=VlF009_5PE_=P04KcE_=W<eLcD3KcH00g<fKcM_=`0=KcL0
0g<gLcIc=P02LeH5LcH016lfLcE_=Vlf0Vlg00Ac=g=GLeQcE`9c=`9cE`=cF09cE`07LeQ_F7=HLeM_
EfmHLeP00W=G00=gEg=GMeL02g=G0gMG0WMH00=cEg=hMgL00gMi0WMh00=gMgMhMgL017Mg0WMh1GMi
0WMh0gMg00=gN7MiMgT017Mi00=gN7MiMgT00WMi0WMh00EgNGMhMgQgNGMh009gN@=gN0EgN@0CLgQg
N7MhMgQgV7NIOmaofWnkKcU9lBBX42@LQ1bS8>DLiAc67>H0123V00<Q1bD89@L00RD6014TiR3V9>HP
iR367>HPiRD8:BPU1b3W7>HPiRTW;BLU1ac500<HY@<HY0<DP`0<688HHQQ1640P@BA0;00P01P0ADER
AUj:0UY:1EY900=JBUI:FTX00UY:00eJBeY<FTaJC5Y;FTaJBeH[DRYNKV;AIaA_EP02MgH00gNHNiUk
^P03Ni/00g^JNiUkV@07NiT2MiX00gNKNi]kV`04NiX00g^INiYkVP03NiX7NiT00g^jNkUkV@07NiT0
0gNINiUkV@05NiT2MiT5MiX3MiT3MiX6MiT017^HMiQgV7NH0WNI0gNH00=gVG^HMiT037NI1GNH00Ag
NGMhMgUgV@9gN@04MgQgMgMhMgP3MiP01GMhMgMgMgMgMgP00WNH00=gNGMhMgL00gMf0WMF00acEWME
LcE_=6lfJ_E^lfZ]=BX00@@03202440010a0460@H11P0`a000<@@0a034000Pa000<880`P4400111P
00h<@110464@PAB2584HXARS5:<DXQS47>HHY1BR0QB111B200HHXQRS6:8DXQB2464258801QB1468<
@@a1468DPP8@PP0@588HXaB2468DPQBR584DHA10320@H1B2584@HAAQ488246400a1R588DXP045880
0aB3588DPP0258801aRS588DPA1Q588@PQAR00@@H@04488@PA22488646402QB16:8DPQAQ464@@A10
580DPQ220Q1Q00<@HQB26:<00QB10Q1R00<<@@PP34000Q1Q00`<HA1R468@HQ22588HPQB24:<@HA11
344346401Q10340880aP464@HP<@H@04488@HQ1Q464236401PaR468@HQB36:<@H@<<@003320<@0a1
00<<H@8@H0@@H@<@H0<@H@8@@@03464<HA1Q008<H005460<H0aQ364@H@023640211Q468@HQ1Q588H
XaB13642360010a0220880a00Q1P00P@H@aQ364<H@aP440<@0PP0Pa000D<HA2S6:<DPQ1Q008<@00:
440@HAB1584@H0a0220<@0a134024400211Q340<@0aP464<H0a0368136<0000:AU1>TekdI_=Vd6KA
I_9Vlf[eJ_@2J]802FkcK_ARe5jcEW1>D46Z8:D@8`0200001P@0424LHbd5?J]>CP9BL@04FW5N/Eja
GY42FY401eYaFY5JTUZBG]EReF;D009Ve00?I_A_EVMFFcPe[Be9=F/mRT79<HX@P`@0460@HQ1S008@
HP0434888@@010040002004300005@@P000000P0>FA>2dWZAJY1c4X>AN`Ti@00421FKf]GI_EVe6[d
J_E[5002JaD3KaD00flDJaE_5@02JaD4KaD016lFKaE_5FlE0Vle00A_=VlFKaI_5Pe_=Q1_=`06LcMc
Eg<gLcMcEg<g16lg00=c=VlfKcH00Vlg0W=G00=cF7=GMcL00gMG00AcEfmHLeQcE`acF0ecE`05MeMg
F7MHMeQcF003LgT017MhMgUgN7Mi0WMg00=gN7MgMgL00gMh00EgMgMiMgUgNGMh00EgN@03MgQcNG=i
00MgN@=gN0IgN@03MgQcN7Mh00EgN@9cNP03MgUgN7Mh009gN00:NkUongoiOkaVedW?9:T@8Qb57>H2
8>D38>H00bD68>HLaP037<H01QRT468DPaS558@DH`<DHP0856<DQ1RT58<DQ1S57<HHaP8Ha@056<HL
iR3W7>HHY0027:@26:@021c56:@DPaR3568LHB11:202:00014EUHTMNREY90UY80UY91UY:0UI;00=J
JeY;FT/00UY;00eJBUY[GV]JBej?I_5[56lfLeMgUgNIMkYkV`03NiX01W^INiYkVWNjNiYgVP=kVP9g
VP04Mi]kVg^KNi/2NiX00gNIMiYkVP05NiX00gNJMiUgV@06MiT7NiT3MiT01G^INiYkVG^IMiT02gNJ
1WNI0WNH0gMh0WNH1GNI00EgV7NIMiUgVGNH00=gV@9gV09gN0=gV0=gV@9gN0EgN@04MgQgMgMgMgP3
MiT4MgT3MiP2MgT04GMhMgIgMg=FMeMcEg=FMeAc=FleJaIZmF[cIXh/aP@020400Q1000D@@A10440<
HA1Q00@@@08<H08<@003220<@11P00@@H@07460<@11P484DPQB16:800QB300X@PaRT6<DDPaB2688D
HARR588DXP@DPP03584@HA2200@DPP04468880Q0464348825880111R484DPQB10QAQ00<<@1114880
0a220a1R00@@PQB25:8HX`8HY0085:<DPa22468@PaB258<DPPH@HP<@H@8@PP03588@PQ2200D@H@<D
PP05564@8111320DH@0248802Q1Q468@HA225:<DXQB1464@HQ1Q0Pa000<<HA1Q46400a1R00HDPaRR
6:8@P@b2368246800aB3464@@00234000`a1364@H@0236400a1Q364<H@0336800a1R368<HP023680
21B37<@@HA11464@HQ1Q468236800`aQ340<H00234001111468@HQ1Q0aAQ00X@HA1P440<@11Q368@
H@aQ464@H0L<H@06368@HPaQ364@HQB20Q2200<@H@aP34000`a000D<H11Q364<H@aP00<@H005220<
@0aQ364<HP033642340010a1364@HA1P0PaP0Pa000H<@A10440@HA1R36053401344126800009CVi>
;F;BH[5NT5I`CRm5kCf[008mRP09>DPe9cD7;>H/iC4V;BHY0aR400H0000Q320P`bdT9@D]9c57=FPi
RCV:=FXiRcg<?J`i[3g=@Li5kTX?DU1JTEjAFY1RlU[C@Nha:C4Z>H]1jSW:7<@801AP00<@HP056:@L
iAc534848@0400001001000000000P@00P00010403USBP]>2d6[@Ja5kTG/8<<0010PDTi_Ef/EI_=Z
l`=Zm003JaA_56lD009_50=[5@03KaA_5FlE00I_5@04KcE_5FlEKaD5KaH2KcH016leKcI_=Vlf0g<e
0flf00=c=VlgKcL02Flg0W<g0g<f00=c=flgKcL00Vlg00=_=VlgKcH00Vlf00Y_=g<gLcMc=g=GLcMg
=WMGLeMcEPEcE`03LeQ_F7=H009cF004KeQcF7=HLeP=LeL01GMFLeMgEW=GMeL00gMH00=gNGMhMgL0
0WMh00=gF7MhMgP00WMi0gMh00IgMgMhMgQgNGMhMgL2MgT00gMjMgUgN@02MgT3MgP4MgT01GMhMgMg
MgMgMgP017Mi0gMh1WMi00AcNWMjMgUgM`9gN00:LgQgV7oINkUNU3U^72H80a137:@68>D03QRU58@D
Q11T48@DPaR458<DQ1B348<DQ1RT6:<458<248<03QB446<@HaB46:D@Q1237>DHa1RT7<DLY1RT6:D2
6:@03AR468<HPaR2768L@B00?<5=j6:8HZUNB5XX00=JB003FTUJBUY;00AJB`03FV]JJUYY00EJJ@0:
GVUJBeY<GVeVd6/CLcEgUGNGMiT4NiX017^INiYkVWNK17^K00YkVWNjMiYgVg^KMiYkVg^JNiUkVP9g
VP=kVP9kV@03MiYkVG^I00QkV@EkV004MiUkVG^INiT2NiX2NiT2MiT5MiX3MiT>MiP2MiT4MiP00gMh
MiQgV004MiP00gMhNgMgN004MiP3MiT3MiP4MiT01WMiMgQgMgMhMiUgNP9gN@03MgYgNGMi00=gN09g
N@03MgQgMW=g009cE`05McIc=GLdLcE_=@02JaD01fKBDPhLHP@0200@@11100<@@0<<@08@@004460<
@0aP3403364346401aB15:4@P0P0460@PAB100<DPP8DP`DDPP08584HXAB1588@HPa1240@H@@DPP04
5:<HXQBS58854682588011B1564DH11Q0QAQ00<DPQ2258801QB200<@HQB2588011B20Q222Q1R00<<
@A1Q46400a1Q00H@Pac5488<@11P464246800aB26:<DXP0246401@`P324<@@`P34400Q1R00D@HA11
468@PQB1008@H@03364@HA1P00@@H@08364@HQ1R5:<DPQ1Q484<H08<H@05468@HA1Q340<@@024640
1`aQ464<H@aR468<H@a1008<HP<@HPH@H@03440@HAB1008@H@03468@H@aQ008<@003320<@111008<
@006444@HA1Q444@HAAQ0a1P00H<H@aP360<H11P464336400`aP340<@@023643340246400a1R464@
H004340336000`aQ340@H00246000`a0364<HP043643344534000`aP340<@004340010aP460@H0aQ
10a10@a200002cf_>F`eBRT7:>HTaAbS668D@0`010000P0000<4000000000P0000H40000000400P0
100200000`P022040002100220001@`P344@@A1R58<00QRT01/LYB3V9@LY:2dY<FXeJSF:=FTaB2T7
:>H]:C5Y=JPaR2CU200@@A1R56<DHQB38>HU1aRU22400P0000<00@0000400P0000@4000010040080
000=9>=:;4h=AL]1[4H>AN`T``00321BCFmFJaD00VKc16[d00A[56[dJ_A[509[5@E_5@03JaA[5FlE
00=_5@03KaA_5FlE00I_5P03KcI_=Flf00=_=P9c=@9c=P9_=P=_=`=_=PI_=`04LcMc=W<gLcH3KcL7
KcH2KcL4LcL2LeL00g=HLeMcE`02KeL017=GKeM_F6mH0W=H00=_F7=HLeP01G=H1g=G0WMG0WMF00Ig
Mg=GLeQcEg=HMeL2MeP017MgMgIgMgMg0WMh0gMi0gMh0gMi00AgN7MiMgQgN0AgN@03MgQgNGMh009g
N005MgUgN7MiMgUgN003MgL00gMhMgUgN@02MgT3MgP4MgT00gMjLgYcNP02MgX03GMiMgYgNW>JNkYk
_6KD@JdTIa0176<HQ234008Pi@068@DLiQcV7<DHaARU0QRT00DHYAc57<DLiR3W008U1`079@H]:2TX
9@PU1bCW8>H00RCV00HLiQc568@DPaB45:D26<D00aBT6:@HY0056:@25:@02AB3688DHaA19411I5j=
IZQRI`03FTP015i8FTQJBEY:0UY;0eY<0UY;0UYZ0UYY0UY900UJJEY;FTYJBV:^J_5_=GMfMgD00WNI
0g^J00=kVGNJMiX01GNK0gNj1GNJ00=kVG^JNiT01G^J37^I17^H00=kVGNINiT01G^I0gNI1GNJ0gNI
00=kV7NHMiP017NH0gMh17NH1GNI00=gV7MhMgP00WNH00IgVGNHMgMkMg^HMgP4MiP3MiT3MiP01WNI
MgYgVWNIMgUgM`9gN005MiUgNWMiMgUgNP02MgT00gMhMgUgN@02MgT01WMhLgIcMg=FMeIgE@9g=009
KcE[56[dJ_AVdd6;544400P000<@H@05444@@0`P320<@@0244000a1P340<H0023642344236434640
1AB1484DPA1Q58400QB200X@PQAR588DPQAR588DPaBS5:8HXP8DPP<DX`8DPP@DXP<DPP04488DPQBS
588546401aB0564DHQR3568@HQ2100<DPP036:8DPaB200DDPP03488@Pa23008@HP0:368@HQ1R468@
HAAQ568DPQ1R344246402@aQ360@HA1R4:<@PPa0460@H@0246800a2248<@PP034646468346401a1R
488@PQ1R368<@11000@@H@03340@HA1Q00@@PP8<H@033688@11Q008@H@09444@HA1R588@H@a0368@
PQ1R00@<HP05468DHA1Q564@H@0236400a1Q440@H00246401AAQ444<80a036400PaP00/<@110340<
HA1R368<@@a0440@HQB1008@H@8<@004360@HA1Q4643364246400`aQ468@H@0234401a1Q564@HA1Q
364<@0PP008<@08<H004464<H@aQ3643460936401@a1340<@@aQ34000PaP0PaQ0Pa000<<@@aQ3600
0PaP00D<@@aQ48<@PPaQ004<HP0000<DZAC:00401@0000@801A0784PX@8TXP068:8PXb2S8<@Y1Re7
0S5700LaB2dW<BPeAcV7;BP<@`0600021005000210001@@Q248<@PaR58<00QR401<DQ1bU8>D]9BD6
7:<800@022488111568HXb346:<<@@0010000@040004100200003aB1AN]:34G<@La:3DG[8<<000P0
ETa_E6/DI]9Vl`06J_<01V[dJaA[56/DJaE_5@9Zm003KaE_56lE00A_5@06KaA_5FlEKaE_5W<F1FlE
1flf00=c=G<fLcH00flg0flf1Flg00=c=VlfKcH00Vlf0flg0flf00A[5FlfKcIc=P9_=P05KcMc=W<f
LcIc=`03LeL00fmGLeM_E`02KeL00fmHKeMcE`04LeL3LeP00fmHLeQcE`04LeL2LeP3MeL3MeH4LeL0
0g=HMeQgM`02MgL2MeL4MgP01GMgMgQgN7MiMgP00gMH00AcEg=hMgMgN@9gF@03MgQgMgMg009gM`03
MgUgN7Mh009gN0=gM`05LgQgMgMhMgUgN003MgL00g=hMgUgN@02MgT2LgX02gMiMgYgFWMjNkekgGol
JcQ5[Q`S20800QR300PPaB3U8>DPiB457>DHaAc50Qc600@PiRCV9@HY1P8Y1`8U1`0G:BPaJC59:BLU
1bTX;DTaBBdX9@LU:2T79@LPiacW7<HHaARU5:<HPQRS58<DPP036:<25:@02QBS6:8DPa12884m@Uj<
K^MNAeY715Y80UY90UY;00=JC5Y=FT`00UY:00=JBEYZFVT015YY00YJJUi9FTYNK6:_Ja9_EWMeMiMk
V@=kVP=kV@05MiYgVgNKMi]g^P03NkX3MiT5NiT5NiX5NiT00g^JNiQkV005NiT4NiP00gNHMiUgV@03
NiP2MiP:MiT5MiP017MhMgMgMgMg0WMh0gNH0WNI0gNH17Mh0WNH00EkUgMgNgMkMgMh00=gV0=gN0=g
V09gN003MgYgVWNI009gN007MiQgN7MiMgQgNGNIMgT00gMg00AgNGNIMgUcN0=cM`0?LeIcEgLeLcEc
=6leKa=VdV[dH[51RaA1300<@11000<<@@8<@08880L<@0073448@@PP344<H@aP34000Q1Q0QB10QB2
00<DPA1Q58802AB200<DXaS46:<00aB200@DXQB2588@PP<DPP<@PP@@H@08344<@1B0564DHQB2568@
@0@DP@05488@HA1Q564DP@025884468010aQ468@HQ1Q0Q1R00H@HA1R588DPA225682464234001@PP
468@Ha1R34000Q1Q00<@HPaQ48400Q1Q0Q1P00D@HA22468@HQ1Q008@HP05464@HPaQ364@H@024880
1Q1R344<@11P464@H08@@@03464DHA1Q008@H@8<H@05464<HPaQ464@HP0446401@aQ464<H11R48<0
0PaQ0PaR00@@HQ1Q460@H08<@@8<H@04344@@12148434642468030aQ360880a0460@HAB2468<H@a1
444@@0<@H0D@H@08360@HA1Q460@@11P464@PP8@H@04444@HQ224882364010a0220880a00`aP00<@
H0aQ360010aP00<<@0a134400Pa10`aQ0Pa100<<@0a134400Pa000@<H0aQ340<@08<H@03360@H0aP
00<<@@03364<HPaQ004<@P0000lDbQE_16@HQ2CV;DTiJSf[@Ja1kDX>CS1BD5ZAG[400Ujc00mN/V:c
I_=VlfKCH]ARmEkDF[=:;SF<7:H000@000000P@000<800@010000P@01`0000H88@a2324<@A1R6:@2
7<D01ac48>DHXaB358@@H`PP0088000:444@HAAR344400@1004000010004100050@1000000`P>HQ9
jTG[@La634G[8>D000P0CR]_<f/DI]9VdfKcJ_@2J_<3J_@5JaD2J_D9KaD017<EKaE_5VlF0VlE00=_
5VlEKaD026lf1Flg00=_=VlgKcL03Flg0flf00M_=flfKcIc=VlfLcIc=`03LcH2LcL4KeP3KeL016mH
KeMcEfmG0W<g00=cEfmHKeP00g=H1G=G0g=H1GMG0W=G0W=H0g=h00=cMg=hMgL00gMg00=gEgMHMgL0
0g=i0W=I00=gF7MhMgT00g=i00=cFGMHMeL017Mg1GMh0gMg00AcN7MhMgMgM`AgN0AgN@9gNP0?Lg]c
NW=kLgYgNgNmOomgVe8A::L<01QS6:@La1c500<Pi@058@DPiB3U8>HLiP038>H29>H01Ac67<DLaART
6:D00Qc600HHaAS67>HLaQS57<H37>H021c57>HYBBU96<DLYAbT7:<26:<36:@03QRS5:@DY1BT5:<D
Pa12464XhTGWGXQRR5iXFTP3FTT2FTX2FT`00eY=ETeJC@04FT/2FVX045Y:FVYJJUY/GVaJBei<GXiZ
lFldLcIgMW^iNiYkVG^J0g^I00EgVWNKMi]gVgNJ00YgV@04NiUkVW^INiX2MiX00gNIMiYgVP03NiX2
NiT01G^HMiQgVGNJMiT00g^I0WNH0gNI00AkV7NHMiQgV0MgV@IgV0YgN003MiQgVGNI00IgV003MgQg
V7NH00=gN0=gN@9gV09gM`03MgQgV7NH009gV005MgUgNWMjMgYgN@02MiP5MgP017MiMgMgMgMg0WMi
00AcNG=hLgMcM`=cE`9c=P07KcE_=6lCJ_9Zlej@>DT00Q0P00@<80a0344<@@8<H@03344<H@aQ00D<
@004220<@@aQ364234401`aQ464@H@a0464DPABR00@DPP0358<DPQB200LDPP04564DXac46:<25880
0aBR588@PP0348800a21488@PP04488346400a21464@HP0246802A10684DPA21488DPa22364@H@05
58800a1R444@H@0346800a1Q468@HP02468248800aB2564@H@0236000a1Q488@P`0646800a22464@
H@024642484246400aAQ588@P`0346824642488246801A1Q3608@0a036400Q1Q00@DHA1Q464@H@8<
@@8<HP05488@HQ1Q464@@004464336801@aQ340<@@aR46800Q1Q00D@PQ1R468@HPaQ008@H@095:4@
Xa22364DPQcU488<HPa0008<H0<<H@03464@@A1Q008<@004440@H11P364446403@aP340<H11P440<
@0aQ468<HPaQ344<HQ23008<HP04468<H@a0364246800a1Q360<H0023602364010a0360<H@aQ10a1
00D<HA1Q364<@@a0008<@@03464<@0a000<<@005364@HA22464<H0033442364224400007<JlacdH`
FW1NT6:aI]800VKC0VKD00=Rdf:bH]<00V;C011N/f;DJaE_=W=EJ_9N/U9?AL/eJ2cU56<800@00004
008000<80006324DPaRT7:<HPQQR0QAR00@@HPa122088088000<320<@A1R588HY1c59>HU1R3V58<@
HPa20`a100<480@000000`0000<4000000000P000P@00P0000L]1Th;BP]1bTW[AP/Y9`0200001T78
Kc=_56KBI]=Ve0AZm09^m005J_E[5F/EJaE_5@03J_D4KaD2KaH8KaD00flFKaE_5002KaD2KcD5KcH2
KcL017<fKcIc=Vlf0flg00=_=W<eKcH016lf2Flg00E_=W<fKcIc=W<g009c=P06LcM_=g<gKeQc=fmH
0VmG00A_EVmGKeM_E`=c=P03LcMcEg=G00AcE`9cM`IcE`AgE`=gEP9gM`03LeMgMg=g009cM`EgM`Ag
F004LeUgFGMiMgP2MgT3LgT00gMiMgQgM`0@MgL00gMhMgUgN@05MgT2LgX00g=kMg]gNP02MeT01g^K
Oom[5cDZ50@DHaR400<La0038>@LiB3T008U1@038>HLiQc5008La@047<@LaAc568@258<040a146<H
YQB448<DP`aR348@Q1B4588DY1RT5:@HYAS50ac500DLY2348<@HY1BT008HY0076:<DPaBT5:@DXaB3
46800Q1100H/h4h6HZYRREY8FTX2FT/00eI<ET]JC@02FTd01UY>FTeJC5Y<FT]JC0AJB`0>FVYJC5Y=
FTeNCF:=I^m[4g<dMgEgUWNHNiUkVP=kV@05MiYkVW^JNiYgVP05NiT00gNINiUkV@07NiT00gNJNiYg
VP03NiX00gNJNiYkV@03NiP01WNIMiYgVWNJMiUkV0AgV@AkV09gV@9gV09gV@MgV0YgN003MiQgVGNI
009gV@AgV0=gM`04MgQgV7NHMiT2MgT2MiP2MgP5MiP00gMiMgYgN@02MgT2MgP5MgL00gMhMgMgM`02
MgL037MhLgQcN7=gMgEcEg=FLeMg=G<dKcA_4`9_4P08J]5FD2cT100@80`P340<H@8@H@05468@PQ1R
364<H00434002@PP344<H@aP340<H11Q460@@@0246401QB1484DPQRR588@PP8DPP8DP@<DPP0<584H
PAB2588HXac47<<HPQAQ584DHAB10aB200@DPA2248<DX`8DPP@@HP09464@PQ22468@HAAP6:4HXQB2
008@PP8DPP8DP@06568@HQ1Q584HXaB2111R0a1Q0Q1R00dDHQ22588DHAB1464@H1B26:<@PQ1S468D
HP0446824640111P464@PA21111Q0Q1R0a1Q00@@PQB2588@PP<@H@0;360<@11P460@HA11464DHAB2
468<@@023680111R464@HA1P0a1Q00T@HQ1Q344<HPaQ3408@0aQ46800a1Q00<@HPaQ34400`a100<@
HABR5:<00Q2200PDPaRS58<<HPaQ344<H0a10PPP0a1Q00<<@0a144400Q1000<<H11Q46400Q1Q111P
00@<@0aQ364<H@<<@@03368@Pa23008<HP03468@HA1Q008@H@03484@HA1P00<<@003344<@11Q008<
H@04340<@@a134423642344734001@`P340<H11Q46000PaP0Pa00`aQ0@a10@a200001DiaDY=Re6:c
H[800V;C015Rm6;DH]AR]5ZBFW1NT6:`G[1NTF;DG[9>DCV;<BPTa@`P00@0000J320LPRT5<FL]91R3
300000@066A1[59aDTiFCe8_DRi>3TX>@L/mRSE8:@DT`QbR34400084000;200@HQBT6<DHY1BT48@<
H`aR2444800300000`@11000000800001b34CPU:2dW[BP]5jRTX00800005?JU[=6lCI]5Vd`02J_@0
0f[eJ_A^m003K_@4J_D7KaD00f/EJaI_5P06KaD3KaH3KaD3LcD5KcH9LcH00g<eLcIc=@03KcH8KcL0
1G<gLcI_=VlfLcH00W<g00EcEg<gKcMc=fmH009c=`E_=`9c=`9c=P03LcMcEfmH00IcE`9cF0AcE`Ag
E`EgEP03LeMgMg=g00=cM`9cN003LgUgF7Mi00=gF09gF@03LeUgNG=i00IcN@9cN0=gM`AcN0EgN0=c
N0QgN@0?LgYcNG=jMgYgFWMINgUo^G^mES<TI@`S58DHY1c5008La0088>@PiB3U8@DLiAcV7<HLa@8H
Y0056:<LY1bU7<DLaP028@L01ac67>HU1bD67<DTiRT7008PiP<La@0468@HY1c558@27:D26:@27:@2
6<D36:@35:<02QBT58@<8@`P540mQ5Y]GXUJ9eY:0UI;0UI<00=JC5I;FTd00UY=0UY;0UY<15Y;00iJ
BUY<FTeJCEH[GVaVcV/BKeEgUWMfMgQkVG^J1G^I1G^J0g^I00=gVG^INiT017^I00=kV7NIMiT00WNJ
00=kVg^JNiX00gNJ00AkVG^HNiQkV0EgVP05MiUkVGNINiUgV@02MiP5NiP00gNHMiUgV007MiP6MgP0
17MgMgQgN7Mh1gNH00=gVGMiMgP00WMg00AgN7NHMiQgV@9gN@UgV0EgN@03MgQgV7Mh00AgM`03MgQg
MgMh00EgM`0CLgMgMW=GLeIgEWLdLc=c4flCK_9_4f[aBPhPPP@0540@@11136800Q1Q0a1R00<@H@aQ
34000`a000@<@@aQ368<H08<@003460DHA1Q008@H@03584@PA1R00<DPP8@HP07568DHAB1588HPQB1
6:800aRS00PLXb346:8DPQR2564DHQ1R0Q220QB200@@PaC46<<DPP8@HPD@PP09468@HAB17:4L`aBS
368@PaB3008DPP05564<@0a0464@P@0258800aB3588DPP0546804A22588DPQB26:@DPQ1R464DPR3U
5:<@HQAR564DPQ1R34401A1Q00L@PAB1588DPQ1Q340@H@024680211Q468DHAB2488@HAAQ68824640
1QB2464<HA1P440@H@8DH@04568DPQ1R468546424682464246801@aQ340<@0aQ4680111Q00<<@0PP
34400PPP00H<HAB25<<@PQ1R368246801PaR364<H@aP364<H0@@H@<<H@04464@@A1R488246454600
10aP364<HA1Q0Q1R00<<@@aQ46800a1R00@<HPaQ464@P@8@PP0=588@H110340<H@a1340@HA22464<
@0PP34400PaQ00<<H0a134000Pa10`a00a1Q0PaQ10aP0Pa010aQ0@aR00000e[?FY5N/`02G[<03ejb
G[5JTEIaEU5FLUZBG[9RdF[_GZm:3CE7:<@H@@0400008@@0644XiCf:BPeFCVK>I^mZkTi><@H<0@00
548i:5I@K_5c<WMeLcE_56[cJ]9R[f:^GXiFKTH<<DLDP`PQ32480002100222002a1R46<@HQ1R3488
8@PP12048@@000000`@000@000@01004008000035659iTWY009:2`09ANTPi@00000iRF;aKa9VdFKC
009Zm006J_EZm6[dJ_A^m6[d1F[e0VlE00AZm6[eKaE_5@9[5@03KaI_5FlE00E_5@9_5PA_5@9_=@A_
=P04LcEc=VlfKcH3LcH3KcH00g<eKcI_=P02KaH2KcH7KcL2LcH4KcH01G<fKcM_=flgLcL026lg00=_
Eg<gLcL00g<f2g=G0W=F00=gMWMGMeL00gMG0gMF00=cEgMgLgL00W=g0g=G00=cNGMHMeP01WMH0WMi
1g=i00AcN7MgMgMgM`9cN003LgUgNGMi00=gN@04MgQcN7=hLgP6MgT3LgT00gMhLgUgN@02MeT027]g
OoI_>Ce^72<@@Qc67<D37<@01B3T8>DLiAcU7<@00Qc50QRU00DLa1bT8<DPaAc6008Ha`039@P]:2TW
008]9`049>H]1SE6<BH2:@L28>L01Ac57<@LaQRV6:D00QB300<HY1bT7:@011RT00@HPQRS6:@HY08D
Q008468@@0`P;@9>C5j9FRMJB@9FB`03FV]JBeY:00=JBP04FT]JBUY:FTX3FT/02eY:FVYJJEY;FTaJ
K5Y:GTUR[6[aKc@00WMf00=gMgNHNiT02W^I00AkV7^INiUgV@EkV@9kV0EgV@03NiUgVWNJ009gVP05
NiUkV7^HNiQkV@04MiX00gNIMiQgV@02MiT3MiP4NiP2MiT3MiP3MgP2MiP3MgP3MgL00g]gMgQkM`02
MgL4MgP2MiP00gNIMgUgN003MgL:MiP4MgP3MgT01GMhMgMgN7NHMgP02WMg01=gN7MgMgIcMW=GLeIc
=WLcLc=c4fkbJ]1ZlFka@HXDH``0560@@0034645364234002PaP340<@@a1364@PQ1P220<80a0111P
00DDHAB1464@HAAR008DPP03568DHAB100@DP@8DPP03688HXQRQ008LXP8DPP03468@HA1Q00<<H@0D
488DXaBS5:8@PQ1R488@HQ1Q484@PQ1R364@HAAQ7<4DXQB248<@PP<DPP03584@HAAQ008DPP08488D
PQB2588@HA22588@PP8@HP04488DPQB2568246823680111R484DPQ220Q1Q00<<@0a146400Q1Q00@D
H11Q464@P@<DP@@@H@8@HP8DH@<@H@03584HPAB100<@H@04344@HA1Q588346401AB26:8@HA1Q3400
1A1P0Q1Q00@<HA1Q464<@@<<H@@@H@05444<80`P344<H@0246401@b13648@0Q034400PaQ00<<H0a0
3600111Q00<@PQB246400PaQ00H@@@aQ364<HA1P464346000`a0460@H00746400`aQ464<H@023682
46401ARQ460@HA1P56000Q1P00H<H0aQ360@HA21460232000`a0364<H@02364010a0220880Q00Pa0
00@@@11Q464<H@8@H@03364<H11P008<@004360<@0aP460144400003F[1JTEZB00=JTP0<FY5JLEI`
FY5N/ekDFY9:D3V::>HH@@@00P0001P401PP:>HiS4H?FY9VeF/GJaI_5FleKcA_<V/eG[4mcB1U1008
02R5BNmRmFleLeH3Ka@03F/DKcEcEG=ELgQN/SV;;BT]1bT67<DDP`P000800003224<@PaR008@H`05
368<@@PQ224400020004100300001`P0?F99jDG[BRa:2abU00800006=DMJ[f/BJ_=Ve6Ke0V[d00EZ
mF/EKaE^m6[d009Zm@03J_IZmF[e00=Zm@=_5@A[5@9_5PA_5@A_5P9_5@03KcE_=Vlf00A_=P=c=PA_
=P9_5PM_=PE_=`05LcI_=flgKcM_=P08KcL3KcP4KcL00fmGKeQ_E`05LcH01W=GKeM_EfmGLeM_F0Ac
E`9cEP05MeIgEgMGMeMcE`02MeL01GMgLeMcEgMgLgP00W=H0W=G00AgF7=iLgUcN@=gF09gN003MeQg
NG=i00McN@04LgQgMg=hLgP4LgT3MgT5LgT5MgT3LgT017MiMgQcNGMi0WMI00MoN7ogHY@XZQ0158<H
a@047<@01R3U7>DLi1S458<HY08La@097:D@HQbS:<@Ti23V48D4@`a40088000L8<@aA23T200400PQ
220DPRCU:>LLaQB546<HY1c56:DDY1RT7:<HPaRT6:DDYART68<HY1S56:@35:<01aB2220LXT8:GXUN
B5Y900=FB`AJBP03FTUJBUY:00IJBP0?FVYJJEYZET]FK5YZFTUNJfK@JcA_EgMGMgQgVGNJ00EkV@03
MiUkVG^I00AkV@03MiUgVWNJ009gVP03NiUkV7^H00EgV@03MiYgVGNJ00=gVP06NiUkV7^HNiQkVGNI
0gNJ27NI00IgV7NIMiQgVGNHMiT3MiP3MgT4MiT2MgP2MgL00g]gMgQkM`05MgL01WMhMiQgV7NIMgUg
V@9gM`05MgQgV7NHMiQgN002MiP3MgT4MgP017MgMgUgNGMi1WMh0gMg1GMh01=gMgMhMgMgMW=fLeMc
=W<eMc=c=6lDK_9ZdFkbJ/diB0`Q220@H00346473643344236400a1Q460@H00546400aB26:8HPP06
588256803QB26:<DPQB1588HXQB1684DH1R07:4HXQB1568448801A1R368@PQB35:<00Q2200<DPQB1
58800a1Q0Pa100<@@A1P58400Q2200@DPQ22468@PPDDPP035:<DPQB200<DPP03488@Pa22008@HP05
488DPQ1R36488002368648801121220@@AAR0Q1Q00<DPA1R46800QB200h@PQ1Q468@HA1R464@PQAQ
688DHA1R568LXaR2111Q00L<@0`P440DPQ22464@@00746401Q1P340<@0a0344<H@8@H@04344<@0aR
4682488346401111320@H@aR10aQ00T@HPaR344880a0364<H0aQ36000PaQ00D@HA2248<@H@aQ008<
HP05364<@@a1364@H00346400a1P440@@0034640111P464DPQ22111Q0PaQ00D@HQ1Q6:8@H@a000@@
H003360<H@aQ008@H007440800`P320<H11Q48800`aQ00@<@@a0340<808@@004460DPQ2246423640
0`aP364<H@02364246014440000?FY5JLEZBFY9J/UjcG[9JTUZbFY5>D47<>FPTX`P000<00006644e
9dW[ETiV[fKB0V[e01=[5F[fI_EVeF;DI]AVm6KcJc=RdTX>:<T00@004091Jf9=I]1ZlP02Ja<2I_<0
2f[bKcA[5EjaAPhiS46[@L/iZS5656<00PP000/80@Q23488@Pa2468@PQ1R24448@000084008000<4
0080000>:>95adG[BRe62b3V000403EWFXmZl6[cI]EVm@UZm0MZm@03J_A_5FlE00E[5@A_5@I_5PE_
=@=_=P04LcM_=g<fKcL2KaH01FlEKaI_=VlEKcD01Vlf0flg00=c=VlgKcL02Vlg0V/h00E_>6lgKcM_
=flh009_E`AcE`03LeIcEg=G009_F003KeMcEg=G00AcE`=cEP03LeMc=g=G00=gE`=cE`04MgMcN7=H
LeP2LeL00gMHLgUgF008MeP3LgT2MeP2MgT2MgP017MgLgQcNG=i1GMi0g=i2WMi0WMh00=gMg=hMeP0
0WMH00MoVGnHFQ0LB10R6:<HY0057<@03QS47><Li1c45:<HXaS656@800a0;DA5aRdU3484000011R0
@J8]@PPP0`00010<835W=BL<8@00200Y1BD668<DHQR37:@HY1R358@DY0<DQ00<5:@HY1B3688HXQB2
444DPSV6FVUNJ5Y90UY;0eY:25Y91UYY0UYZ00YNJ5i9HX]Vd6/DKcMgEgMhNiUgVPAkV@07NiQkVG]i
NgUkV7^INiX00WNJ00=gVgNJMiX02WNI00AkVGNJMiYgVP9kV@AkV0IgV@=gV0=gV@UgV0=gN@04MgYg
VWNIMiT2MgT<MgL00gMhMiQgV004MgP4MiP00gMhMiQgV@02MgT5MgP<MgL5MgP3MgL047MfMeIcEW<e
McAg<g<dKaA^lflDLa=VS33U000400a0111Q0Q1100L<HA1Q464@H0`P344<H@0446002A10464@HA1R
568DPQRR7:<HXP0358800aR2588DPP02568258800aAR588DPP035843684011B2564DHA2211B20Q1R
00@@PQB2588DPP8DP@8DH@054648@0PP240<@00246400a22588DPP0258801A22588DPQ2258800Q1R
00H@HAB2688H`aRS5:834884464336402Q1Q484@PQ22464@PQBR588@HA1R0Q1Q00@<@11Q588@PPL@
HP8@H@03484DHQ1R008@H@07488@PA1Q344<H@aP36400Pa00a1Q00@<@0PP340@H08@H@03460@@110
008@@005444@HA1Q344@@@02464010aR468@HQ1R0a1Q00<@@A104600111Q10aQ00X@H@aQ360@H0a0
360<HA1Q364<H0@<H@05344<HA11344<@002464021B1464@H110460@HA1P340246001121588DPQ1Q
0Q1P00P<H@a1344@@A1Q468<@A110Q1Q00d@H0aP360<H11P340<80PP200<@0aP460@P@0236423600
0`Q0220<8002440011AP460<H0aQ0Pa110a000<<H11P46000A1100001EZAFW5JTeZCFY400Ujb00EJ
/diA?NlaBaQ200<00006520a:47^CU1NT6;A0V/E00A[5VKeH]AR]0AN/`0AG[9R/V;CI_A_=f;fDWDm
KQ@0000<0337BPmNSVKbI_5RdP03H[82H]801e9??Ha1RDGZBRi1bbC5008<8@0546<<H`aR368<@P04
34400`QR24848@02124010@0000400@00P0000hLXSfXAN]:34799@H0010Q>FM>CVK?I_=Ve6Kd2F[d
0f[e00=Zm6[eJ_D00V[e0VlE1F/E1FlE1FlF1Fle0Vlf16lg00A_5flFKaI_5@=_5P03KaEc5W<f009_
=P03KcM_=Vlg00=_=`9c=`M_=`03KcI_=flg00=_>004KcM_>6lhKeP2KeL5LeL2KeL2KeP00fmGLeM_
E`02KeL00g=GLeIcEP03MeH01W=GMeMgEg=HLeMcF09cE`04MgMcN7=HLeP2LeL017MgLgUgF7Mi0g=H
1G=i00=cN7=iMeP00gMh0gMg00=cN7=iMgT017Mi17=i17Mi0gMh0gMi0WMh00agMW=hMeQgN7MHOm]g
N5G@76P@@aRT7<D57<@09Qc57<@DPR33<DH]ARU858<000PP@P]BBDh9<BHLPbbU400001A1BNQ6:beT
8@DLa`PQ58=1k4FV66<00111BL@mIQ11100@@1c47:@268@00aRU5:@DQ00258@031B3688HPQR2564<
@111;B9FJEj:FV]JB`IJBP=JB@AJBP=JJP0>FVUJJUY[FV]NJUiYGX]Vd6/CKcMgEgMhMiUgVPAkV@05
NiQkNG]iNiUkV002NiT2MiX00gNKMiYgVP02MiX7MiT01GNJNiUgVWNJNiX00g^I00=kNG^HNiP01WNI
0WNH2WNI0gNH0WMi0gNJ0WNI0WMi0WMh00=kMgMgMgL01gMg00=gN7NHMiP02WNH1GMi1WMh0WMg00=g
MWMgMgL017Mg0WMh0gMi00]gN7MgMeIgMW=FLeMc=W<eMc=_=FlD009^l`08K_5NCBB2000400PP340@
@@8@H@<@@@07464@HQ1P3408@0aQ360010a000P<HA1Q464@HQB26:<U1Qc40QB20QR20QB200<DHQB2
5680111Q00D@HQB2588DPQBR008HXP07584DPQB2588Ha1S358800a1R0QB200DHXaB2588@HAAQ00<@
H@HDPP0358<DPQB2008DPP0448<@PQ1R4683464011B26:<Ha1B211220Q1R112200P@Pa2248<<HQ1R
484@PQ1Q0Q1R0`aQ00@@HA1R468@PP@@HP03464@HQ1R00@@H@05340<@A22488@HP0236801Q1R364<
HA1R464<H@8<@0@@H@06340@@110440@HA1R0aB200<HPQAQ46800Q1R00@@HA1R468<H@<@HP@@H@06
444<HA1Q468@H@aQ0a1Q0Q1P0PaQ00`@H@aP440@@11Q368<H@a0464@HQ1Q4403464010aP320<@110
0Q1P0Q100Q1P00L@HA1P364@HA10364<@@0244400a1R368@H@04464336400a1P440@@00234423642
464030aQ340<HA1P364<@0a1464@@11P360<H@<<@@D<@04<H@4@H@4@@@0000YJ/5I`EW9FTUZaEY1:
;SV:;@HHI0<0000898@mR4h]HZiVlV/CJ_AVd`=R/`IN/`03G[9R/V:b009R/`06H]AVmV;EH[=1[Q@4
0P0001`TQ4G:H/i_DfLDH]AR/f;CI]9VlEJ@@LdiADG8AP]5k2dV444<811246<@HPaR224400@P344<
H@8<HP0614848@@Q100000@00`00014@H3V7BN]:2d786:@00111>FE5jej<I_9Vm6[dJ_=Vdf[c00UZ
m0IZm@03J_A[5FlE00=[5@E_5@E_5P05KaE_5VlEKaE_5002KaD2KaH2JaH2JaD2KaD01VlFKaE_5VlF
LaIc=@9_=P03KcM_=Vlg00A_=`03LcIc=flg00A_=`03LcMc=Vlg00E_=`03LcM_=fmG009_=`04LcIc
Eg=GKeL3LeL5KeL5LeL017=FMeIcEg=G0WMG0g=H0g=G0W=g17=G00=cF7MgLeP017=H0g=i00AcN7=g
LgQgN0=gF003MgMgEgMg00=cN003MgQcNG=i00EcN@AgN@9gN0=gF09gN00<MgMgMW=hMeMgEW^GOoag
FDg?76L@@ac40Qc511c402TPa@P0000XheZaAP/eZS5Y7:<@@CE3@H1FJg=aHgAcDdga10<001b2E[1g
/FMeJeM5kb2W@LYVjSUX10<D@EHU@LLDP`@07:=1bc3V544@8AAS00@DP`055:<HPQR2688DH@023400
12T0DTQVbUY[15Y:00=JBeYZFTX00eY900=JBUY;FT/00UY;00AJBUYZFVUJJP9JJ`09FVUJAf::I]1[
4flgMeMgMg^H009kV@04NiYkVG^INiT6NiP00g^IMiYgVP02MiX:MiT00g^HNiUkV@03NiT2NgT2NiP5
MiP017NIMiQgV7NH17NI0WMj00=gVWNIMiT00gNH0WMh00EgNGNIMgUgVGMi009gV09gN0]gM`03MgQg
MgMg009gM`04MgQgV7NGMgL3MgP3MgT017=hMgQgN7Mh3GMg0WMh0WMi00=cNGMhMeH00gMF011cEg<f
LcEc=6lDK_=ZdVkbI/m=jaQ1000800`P444@@0<@@@03440<@0a1008@H@8@H003364<H0a000@<@008
460@HAAQ564LXbD67<@DP`8DPP056:8La1bT58<DPP03568346404A1R588DPQRR7><PhaR1568DHARR
8>DL`aB2488@Pa1R488011B200<DHQ1Q56400QAQ00DDPARR6<<HXQB2008@PP8DPP07488@HQ1R468@
PQB248800Q1Q00D@HQ22588@PQ1R00D@PP04464DPA1Q468248800a2346<@PP0546400`aQ464<H@03
468258834640111P360<@0aQ111Q00<@HQ2258<00Q231A1R00<@PQB246800a1Q111P0Q1000d@H11Q
468DHARS7<@L`a1R464<@121464@HP0236824680211Q468DPQ1Q320@@11Q4603360246400a1P360<
H@02464246001Q10464@PPaQ340<H@8@H@8@@004344<@0a0340244000a1P560@@0024400111P464@
H0aP0Pa000L<H0aQ364<H@a2344<H@044640111R464<H@aQ111Q20aQ0PaP0Q1Q00@@@0a0340<@0<<
@@H<@04<H04<H@0000QJZUZ=F[=J/dYA>LhY20`00P0000H@022U>Ha>DF;CJcH2JaD016KCH[9NTUjB
0f:c0ejc16:c02iR/V:cH[=R/f;EJaMW=f<iCS4Xb0P0000H@SV:DXmS=FLDIaERdfKCI_9J/Tg]=BE5
ad79@LXaJAbS300HQ1B45:<DPa1S368<@@PQ3448HPQS36@8@PA212848@840080000?100Y9dWYCP/m
Qa1R000DPSUUALYFBf;BJ_=Vlf[d00=Vm0UZm0EZm@Q[5@E_5@E_5P9_5@9_5P03KaE[5F/F00=[5@=_
5@A_5P9_=P04KcM_=VlgKcH=KcL2LcL7KcL4LcL00fmGLeM_E`0:KeL9LeL3LeP3LgL3LeP00g=GLgMc
M`08LeP2LgT017=hLgMcN7Mg0gMH0WMG00=gMg=hLgT03G=i00MgNGMhMeQgF7MhMgUgN002MgL02g=g
MeIgM7^FOm]cFDG?64L<@aRT6<D00ac5010DXaAR3008010P>HYBLE:AGa9W<5Jc:>L000@0DTeoo@9o
o`0GDW@00@000019k7>DOomkgEIC108Xa6/a@S040`00;@=:KSgZ?JU634h=?B@8000200001Q1S5:DD
YARU6:<DX`8DPP07688DPPa09<1>B6;<ET/00UY:00=JC5Y;FT`00UY;00=JBUYZFVX025Y;0UY/00aJ
JeY:FRQRRVJ_J_=[=gMGMgMgV7^INiP2NiT01G^JMiUgVWNINiT00g^H00=kVGNIMiX00WNJ2GNI0WNH
1G^I0WNI0g^H00AkVGNIMiQgV0QgV@9gN@=gVP9gV@9gN@03MiQgNGMi00=gN@AgV003MgQgV7Mg00Ig
M`=gN0AgM`05MgQgV7NHMiQgN003MgT2LgX2MgT2MgP=MgL2MgP02WMiLgUcNWMIMeMgEWMGLeIcEg<f
0W<e00U_5FkcJ]5_4VKB?FP<00@032000a1000D@HA11444@HA11008<@P03464@@A1Q00H<@003320<
@11Q008DH@0;588DPaBS5:<DXPaQ588La1RS6<DLa@025680111R584DHAAR0Q1R00dDPQR27<<Ti1R2
444<@11Q588HXQB2488@P`0246802a22588DXa22588@@0a0584HXARS58800QB10Q220QB200@@PQ1R
468DP`8DPP0358<DXQ2200<@PP<DP@@@PP@@HP0;364@HQ2248<@Ha23488@HA1R464<H@084680111Q
564@H@a00Q1Q00@<H@aP364@H@<@HP03588@Pa1R00X@HPD@H@03460@811000<@H@06584DPa1Q4688
@@a10Q1Q00<<H@aR36800a1R0a1Q00<<811046000Q1Q0PaP00H@HA1P460<HA1Q364346403A1P360<
H@aQ368@PQ1Q460<@0aP364@H@aQ008@H@0=564@HAAQ440<80a0460@HA1P364<H0aQ34400PaQ00`<
HPaQ340<@0aQ468DPQ1Q364<@0a13602464:364010aR364<H@aP10a00`a10PaQ0Pa000<<80a03400
0@aR00001Uk3DRUFCd7<=DTHI@800005004XidG[FVmZl@02I_<2H]<3GY<2GY82G[<016:cG[=N/ejc
26:c01iN/f:cIaA[4f/AFTm1JQ@0000<835WEXmW4UkAI_=VdVKcH]=B3CeW?FE1R47;?N`]0``068<D
Q1B36:<26:@02A233688@@PQ2448@PaR36<8@P0212404@@P000000006:=:1dh9=D@880009>A1b4G:
DPaR/6lBI_800VKC00=Ve6KdJ_@00V[d0f[e16[d0V[e26/E0VlF1flE16lF0VlE00=[5FlEJ_D00VlE
0VlD0flE0flF2Flf1Flg0flf00=_=flfKcL00Vlg00=c=VlgKcL02Flg00=c=fmHKcL00Vlg00Ac=g<f
LeM_EPIcE`03KeQcEg=G00=cE`03LeQcEg=G00=cM`=cF09cE`03LgMcF7=H00=cF0EcN@06LgQgMgMg
MeIgEgMH17Mg00=cN7=iLgT02W=i17Mi00=gN7MHMeP00gMh00agMgMfMgEgE7]fOm]gFD6>54H@@aB3
6<D27>D03AB3220<82BR>FTmcCg>@NmJeG>FOoM_Ubd:0080000A@LYS46=fHc<mbaAS300@834WANaB
L5Y??Fd00QPR?HHaJ`0300001e9_Mg55jC4U>FE1QPP000<00005224<@Q236:<HY00258<01aR35688
0231APIN[EY/009JBP9JB`03ET]JC5I;00UJB`=JC09JK007FTaJBEj9HXeVlf/fLcH00WMf00AgV7^H
NgUkV@AgVP03NiUkV7^H009kV0egV@03MiQkV7^H00=kV0=gV09kV0UgV0=gV@AgN@04MgYgVWNIMiT2
MgT2MgP8MiP017MhMgMgN7Mh3GMg17Mh0gMi0W=j00=gNGMhMgH03WMg00UgN7MgMeQgF7=IMeUgEgLg
LeL00W=F00ag=G<eLcE_5FkcK]5c4f[C=BL400P03203440246402110464@HPa2224<@Q1144063402
22001A10564DHAAQ44400aB200<@HAB258800aB20QAQ00LDPAR1584@HQ22568DH@0258801QR2588@
H@a1340@@@<DPP8@HP0<488DPQ22488@HQ1Q460@@1AP7<4HXQB30a2200<DPQBS58800a1Q0Q220QB2
00HHXQBR588@PQ1R4642584021B25:<@PQ22468<HQ1R5883488248<011B2468@HA1Q0PaQ0`aR0Q1R
111Q00<DH1104400111Q0Q1R00<@HA1R46801Q1R0a1Q00@<@@a0340<H@@@H@8@H003320<@11Q00D@
H@034688@@aR008@H@03368<@@aQ00D@H@03444@@0a0008@H00:584@H0a0460@HA1P484@HPaQ3403
4600111Q364@HA1Q0Q1P00@<@0PP340<H0H@H@05444<80`P440DH0025840111P360880a010aQ1Q1Q
0`a00Q1P0a1Q00P<H@PP220<H0aQ360480Q00PaP0`a000<<80a034000PaQ0Pa100H<H@a1340<@0PP
244136800004CRa1ZbcV40020000210P:@LmcE9aG[9W56KdI_<2G[4015jBG[=N/ejc0UjC0Ujc00=R
/ejcG[<01Ejc0f:c00AN/f:cH[9R/P9ZlP0HKcEV[dF:748000@0:BQ:D5kdIa9VlVKcI_AJCdG;>FI1
ZD7;APde91A1348@HaB40QB30QBS00D@Pa1R20040@PR00D8@P0814448000000803f4CRTa90800008
9@E5jTG[BNaNSVlCKaA_5@9Zd`9Vm0=Zm@03J_AZmF[d009Zm0IZm@A[5@=[5PE[5@9_5@=_5P=_5@05
J_E_5FlEJ_E[5@05KaD2KaH7KcH016leKcI_=Vlf0flg16lf1flg00=c=VlgKcL01Vlg0g<g0flg0g<g
0g<f0W<g00=_F7=GLeP01g=H0W=G0W=g0g=H0g=G1W=H17=i00AcN7=GMeMgE`9gF004LgUcN7=hLgL2
LgP;LgT6MgT0<gMhMeQgNG=iMgQgMgMfMgEkUWnkLePmK1Q646<DPaS59@DM1QB4200PY5jaOmIgoF<J
DWEF]UlEF/e6;b36300LHS57?LXibcVZ>H/eK35:=F/eBC4W<>DdiSD7::HTY2S25448000200002CfY
Ka0]9@00<BIF/DkE8@X<0@0200000`@0320@H@02588021B358@<@@P09>961eZ]FX/2FTX4ET/3FT`7
FT/3FT`03eY;FVeJKEY/GX]RSFKbJcE_=WMFMgIgN7^HNgUkV@03MiX00gNIMiYkV003NiP<MiT00gNH
NiQkV005NiP;MiP00gNIMiQgV@02MiT4MgT017MjMiYgVGMi0WMh00=gMgMhMgP00WMh1GNH00=gN7NH
MiP00WMi1gMh1GMg00AgN7MgMgQgN0=gN@9cNP03MgUgN7Mf00igM`05LgQgN7MgMgMcF004MeL03W=F
LcIc=G<eKcE_5FkdK_=c4eia;>L000`0340244002A1Q584@HA1Q588<HPPP000<@@02440334000`aP
340<@00232002A11564DHAAQ668LY23U688@H@0458800a1Q588DPP02584011B2364@HQB20QR211B2
0QAR00HDPQAQ564@HQ1Q5882488246400a22484DP@0258400aRR5:8@P`0648800a1R464@H@024883
58800aRS6<@DX`05588448801PQ2468DPa22468@H`8@HP05588DPa1R468<H@033683468246400a1R
464@HP05464546800aB2568@HP0246801QB2468@@0`P340<@@8@HP0C464@PQ1Q464<@0aQ464<H11P
464DPQ1Q340@HAAQ464<@A1R58801A1R111Q00@@HQ1Q464@H@<@H009440@HABR484DPQ1R364<@A1Q
008@H0@@H@04460<H@a034023640111Q364@H11P0a1Q0Q1100`@@1B0584@HA1P340880a0368<HA1R
3644464236400`a0320<@0024603464010aQ340<@11P0PaQ00L<H0Q0360@H110460<@002440011AP
464<H@a10PaQ0Pa10Pa00@Q10@QR00000aS97>X000020000322T@LQJKVK]H]1VlekCG[=N/UjaGY5N
TPENT`9N/`03H[9N/UjB00=N/`03H[=N/f:c009R/`0;G[=R/V:bH[9R/F[bI^mc3VZ]AJXL8P020000
4RBTDRiZkf;`JaAVlfKBDN`iASe5@JU5jcf6:<@<8@a346<DP`8DX`8HY0064688000000048@A20P@Q
00@8@@Q222448080000=9@9::3UT200002ST@LU1jdG]FRYZlF/CJ_@00VKC0VKd00=VmF[dJ_@00f[d
00AZe6[dJ_AZm0=Zm@9Zm005JaA[5F/EJaE_5@04JaD4KaD3JaD00flEJaE[5@04J_D00flFKaE_5@04
KaD016lFKcI_=Vlf0flF00=_=VleKcH00flf00=_=flfKcH01Flf00E_=flfKcI_=W<f011_=`03LcMc
=W=F009cEP9_=`05LcMcEg=GLeM_F003LeP00fmHLeQcF006LeL3LgL2LeP00g=hLeQcF004LeP00g=h
LeQcE`02MeL2MeP00g=HLgUcN003LgL2LgP9LgT9MgT00g=iMgUgN002MeH06G]fOkYc=ce[54DDHb2S
9>@aR36;58@403E:OmUonG>GBQ4Tb1QV:BXaRCF/>J`m[4G^009B;P04BPe9k4W<BL`2BLd05D6^@F`m
:D58DJQIj469=BPa1cUX>BH/hc55ANPHHP00>F]cDg_nFY<HH`0410003Q10688HPAB358@<@@P0;@=>
BF;/FX]JBEY:FT`3ET/3FT`7FT/2FT`00eY;FV]JB`02FV`02Ej:HXeVlF/eLeEgEGMeMiMkV002NgT0
1G^IMiYgVWNJMiT01G^H17NH1gNI0WNH1g^H4GNH00IgN7MiMiUgNGNIMgT7MgL3MgP4MgL00gMhMgUg
N005MgT2MgP;MgL01WMhMgUgNGMhMgMgMQ9gM`0BLeMgEg=GMeMc=g<fKcIc=6leKaA[56[dK_=^lDh`
88D400`00a1000<@H11Q46400a1Q00<<@@PP34400Q1000@<80a0340<H08<@003440@H11Q008DH@06
568DPQRS6:@DPQ1Q0QB20QB10QB200<DPAB258800aB200<HXb347:<00aB200<DHQB258800aB200P@
H@a0464@PQ1Q340@HA220Q210QB100<DXQ2248801A220a1R00P@PQB2588DPA1Q588HXaRR0aB20a1Q
1A2200HDPQB3588@HPQ236824883468010aR364<H@aQ0Pa1111Q1A1R0a1Q0a1R0QB20Q1R0a1Q00D@
HQ11340<80aQ008@H@03584DPQ2100h@H@03364@HA1Q00D@H@03360@H11Q00@@H@<@H004340@HABS
6:<346824642460248454642364030a1364<HA1Q440@HAB26:8@HQ11440DH08@H@06344<@0a1368@
PQB20Q1Q00H<H11P360@H0aQ340232000`a0460<H@04464236002A1P360<H@aQ488DPQ21360@H002
34002Q10580@H111440@HA22364<@@a00PQ00@a100002PbY4>X8@R2T>H]FLFK`Ia=VlV;A0UjA00AN
TUjbGY5N/P=NTP03GY=NTUjB00=N/`03G[9NTUjB009N/`03H[=N/ejc00AN/`9R/`9R/P0JI]9ZlFkc
IY1EkRaT000402ASANeNlfLAJaAZm5X/@HTi946YANY5b34V56<<@QB45:@DX`<DY0075:<<HP000004
8@@R22800PPQ0`Q100h880@07<=22SUU200402T3@LXmbSfZDN]NSV;C0fKC0VKd00=VmF[eJ]@01F[d
1V[e00AZm6/DJaE[509[5@03JaI_=V/F00=[5@03JaI_5F/E009Zm0=[5@08JaIZmF[eKaE_5VlEKaI_
5@]_5P03KaE_5VlF00Y_=P06KcM_=VlfKcIc=Vlf1Vlg00=_EflgKcL01flg00Ec=g<fLcIcEW<f00=c
=`AcE`04LeQ_F6mHKeP5LeP3KeP=LeP017=GMeMgEgMH0g=H00AcN7=gLgQcN0YcN@04LgYgNGMiMgP4
MgT2LgT2LgX06G=iMeQcEg]gOiYc=SU:52<DHbST9<91je:d9>P0022TEW1_;dh<;>HTPc48?Ja>;U:B
009FTP0NF[=N]5YbFW5NLEi`I]=oNGnkOmioWGMILcQg=fkcHW1AkTW_EW5>LDH>@N`iJ21S52@a:4i@
E]E1[0`0100000/LPBT57:<DHQB4468802SQDTQNc5Y[009JB@04FT]FBeI;ET/3FT`6FT/01UY:FTaJ
C5Y;FVYJBP9JK009GX]R[FKaJaAcEGMFMgEgUgNH00=kV@06MiUgVWNJMiYgVG^H1WNH0WNI0WNJ1WNI
00=gV7NINiT00g^I0gNH1GNI1WNH0gMh0WNH1GMi00=gN7MgMgL00WMg0gMh00=gMgMhMgL00gMg00=g
N7MiMgT01WMi00AgN7MgMgQgM`EgN0=gM`04MgQgNGMiMgP6MgL2MgP00g=hMgMgM`06MgL2LgL00gMg
LeMcE`02LeL03g<gLcIc=W<eKcE[56[dJ_9ZdFZ_BNhDH`P0320@@@0246400a1P364@H@02464011B2
464@@A110Q1Q10a000D<H11P460@HABS008HX`8DP`8DPP0;58<DXaB3588DPAB25:8DXaBR688HXP02
58801aB37<@La1R2464DPQ2200<DPP036:<H`aB3008@HPD@PP04468@PA21484258801Q23488@PaBS
48<@PP<@HP03588@PQ1R008@HP8@H@05588DXQBS588@HP0234002A1R464DPAAR588HPaB258<DPP02
46<00a2358<DHP0246401a1R5:<HXa22464<@0a100@@H@05444@HA1R464@HP034640111R48<@PQ22
0Q1R00<<HA1R46400Q1R00`@HA1R468@HQ1Q468@PQB26:8DHA1Q440;464336400`a0460DH@044640
0a1P464@HP0246402aAQ464@@0`P460@HAB1464@HQ1Q4680111Q00<@PQ1Q46400Q1Q00T@HQ22464<
@@a0360@H11046400QRS00@@HPa1440DH0<@H@07468<HPaQ368DPQ1Q36400PaP1@aQ00<<@@a03600
0`aQ00P<H0aQ364<@0aP460@PPaR10aQ00D<H0a0340<@120008@H@04440@HAB33682344234013440
00084:dM;S6;CTmR[FK@I_9R/@eNT@03GY9N/UjC009NTP03H[5N/V:B00=RTP=R/`=N/`0KH[=R/V:b
H[9V/f[CLaAZ/e7]:8H000@09:E>CfL>H_9Vm5j?DN/iAT68@JU5bCEX9<H<@AB2008DX`<DQ0047<DD
Y@a300420002124222404@Q0244400@0488]JBD4000402T4@N/mZSV8AL]JCEjcH]@016KC00=Ve6[d
J_@026[d0f[e00=Zm6/DJa@00V/D00=_56/DJa@00f[d16[e0V[d00A[56/EJaEZmP9Zm@03JaE_5VlF
009_5P04KcI_5V/EKaD5KaH00flEKaI_5@04KaD2KaH7KcH00g<fKcI_=P04KcH?KcL017<gLcIcEVlf
0g<f00=c=g=GLeL00W=G00=_EfmHLeL01G=G0g<g0W<h0g=H00=cEg=HLgP01G=H0W=G00=gMg=HLeP0
0g=H00=cMg=HLeP02W=i00AcNWMiMgQgM`9gN09gN@04LgUgNG=IMgT2LeT07g=HNiQo^fke=BPLHaR3
9><iIW=?KeLa:`@0644Y:3F9>J]9k57/ERiBCeZBG]ARe5kfI_M[>7=JNi]ogGok00Yoo`0>Nki_FVLH
H_IJT4X`?J`a:Bd9=DTmRSEZ;>H400@0000;680aRAc4320@@11Q320TX58UGZYJJP02FTT00eY:FT]J
B`0;FT/00eY:FT]JBP02FVT035YZFV]NK5j<I]5ZlVleLcIgMGMfMgQgV0EgV@YgV003MiUgVWNJ00Ag
VP9gV@03NiQkVG^I009gVP09MiUgV7NHMiQgVG^IMiUkVGNI00EgV09kM`03MgMgN7NH00=gV005MgQg
V7NHMiQgN007MgL01WMhMgMgMgMfMgMgN0QgN@05MgQgMWMfMgIgN004MgT6MgP7MgL2MgP00g=hMgMg
M`05MgL3LgL00gMgLeMcE`03LeL03G<fLcEc=G<eKaA[56[bK_5Zcd6<44@<010P008@@@07464@H11P
464DPARR58800a1Q00<DPQ1P440010a000T@H110564@PQRS8>HDP`aQ58800aB30QB200P@HAB2588D
PQBR588HXQBR0QB21AB10QAQ00@@@AAR6:<L``8DPP@@PP0348<@HQ1R008@P@0;584DPQ1R364@HQ22
588@PQ1Q468@PP0258844682464246801122584DPQ1R1A1Q00<DPQ2258800Q2300DDHQB248<@PQ1R
008<@004584DXQS35:<3468021B3588@HA1Q440@@A1Q58424642460246400`a1464@H@044640111R
58<DPaB20Q2200TDP@aP464DPARQ560@H11046001a1Q00<@H11Q46400Q1Q00<<H@a034000Q1P00@@
H@aP460<H08@H@04564@HA1Q4642340246401A1P464<@0a046000Q1Q00<@@@aQ36400Q1Q00d@H0a0
364<H@aP340<@@a0460<@11Q468DPP0246801Q1Q580@HA1R364@H@8<H@0=468<H@aQ364@HA1P340<
@@aP364@PPaQ34000PaP0a1P00D<H0a0340<H11P008<H@063448@0Q0244480PP0Pa000L@H11Q460@
@11Q48<<@P0234423401344000099C51lV;DI_AVlF;AGY1NL5j@009NT@03FY5NTEjA00ENT@9NTP9N
/P9N/`03GY9R/F:b00ERTP9R/`9N/`0<G[AR/f:cH[9R/fKBI]=Zm7<gK_AJDc390P00010Xidi?GcEN
lVKaFR]1RCeY?HU1bCfY;@H@@Q1R58@DX`8DP`056:<PiQSV48@8@P0300000`@Q22488@0224420000
3P@P58<DH@00200Y1CfZ?L]1Zd7;DPeN/fKdH]<3I]<2I]@4I_@5J_@3J_D2J_@2Ja@016[dJ_=Zlf[c
2F[d0f/E2F/F0flF16lE00=[5FlFKaD00VlE00=_5VlEKaD03Vlf2flg00=_=VlgKcL01Flg00Ac=Vlg
KcM_=`9c=`=cE`9_E`03KeQcEg=G00Mc=`9c>0=cF003LeMcF7=H00=cN@9cF003LeMcF7=H00EcF003
LgMcF7=H00YcN@04LgYcNGMhMgL2MgP00gMiLgUcN@02MgT07gMIMgUcFG=INiYogF[g>DTTYBCW9>EB
L7]eG[8a2BQQ=DQ23UJ@F]=FTEZAGY=N/f;DIaI_Eg=jMiak_GoN011oo`0=Mi][=5jbBS0i[CV<ALaF
3Dh=@JXY21AT30400P@000XiQDZb9BP400P0444@@2RPDR=RR09JBP03FTUJBUY;00IJB`=JC0EJB`0>
FVYJJEYZFVYJK5Y;GXeVd6[bKcEcEWMeMgIgV09gV@=gVP03MiUgV7NH009gV003MiUgV7NH00=gV09g
V@EgVP03MiUkVG^H009kV@9gVP03MiUgV7NI009gV@9gVP07MgUgVWNIMiUgV7NIMiP00W]g0WMg2GNH
00=gN7MgMgL017Mg00=gN7MgMgP00WMg00=gN7MiMgT01WMi00IgN7MgMgMgMgMiLgT3MgT5MgP2MgL0
0gMhMgMgN002MgP4LgP9MgL017=hMgMcEg=g0VmH011cEg<fLcEc=FleKaAZlf[aK_5ZcSU9328<8@`P
420@@@8@H@03460@@11Q00<@H@8@H08@H@03440<@0a0008<@003440<@11Q00<@PP07468@PQB25:<D
Pa2258800aB30aB20QBR00PHXaB3588@HAB26:8DPQR10QAQ00h@@0a15:8HXQbR588@Xa2358<DXa23
368@HQ220QB20Q2200T@H@a1468@HQ1Q340@HQB256801A1R00<<HA1R468011B2112200<@PA1Q4680
0Q2200<@Pa2246800a1R00d<HPa1340@HA2248<DXaB3488@HA1R588@HP044640111P464<@0a01Q1Q
00DDHA1Q464@HQB3008DX`0458<@PQ2248434642564:46400a1P464@H@0536400a21464@H@033642
46400aAQ464@H@0;464011AR464@H@aR0Q1Q00D@H0PP220<@0aQ008<@@06364@H@aQ344<HA1Q0Q1R
00D@Pa22468@HPaR008<H@03220<@@aQ00<<H@06460<H0aQ3408@@aR10aQ00<DPA1P46000`a000D<
H110340<@@a0008<H0D<@08<@@09340@@11P368<@@`P344<HA1P004<@@0000HildXcH_ARm6:aGY02
GW02GY09GY43GY801UjbGY=NTUjBH[5N/P9NTP9RTP03H[9R/f:c009N/`03G[AN/f:c009R/P9R/@06
H[9VdG<dK_EF3bR70P0000lXiEJaKc=[4F:<AL`iBCf9ALU5jSEW6:D8@Q1S5:8011RS00@HaART36<4
0@80008400<48@0924848@@0224800@0440Y1CV80091c005@J]:3UZAH_=Rd`04I]<00fKDI_AVl`02
I_@2J_@00fKdJ_AZm003J_D00f[dJa=Zl`02J_@7J_<6J_@00f/DKaA[5@06JaH4JaD00f[eK_A^m@02
J_D3JaD5KaD4KcD<KcH7KcL5KcH7KcL4LcL00g<fKeM_E`02KeP016mGLeMcEg=G0g<g00Ac=W<gLcMc
=`9_F09cF003LeMcF7=H00AcN004LeQcMg=gLgL3LeP01G=hLeQcMg=GLgL00W=h17=i0W=I0W=i0WMi
00MgN7MgMgMgMgMhMgUcN@03MgT047MHLgUcNWnkOomVmceZ9<<PaAb6ALeBCT6[>HY5k5I^0UkA00YJ
dV;CH]=J/eJCG[=J/e9@BPm1cP8m[@0<@LlmccgAAQABMekIH_Y_G6mJKeUcNGNI0W^J01A_=f[dI]9N
lEKdDY563dG_DPiNCFZ`FY563T7=>FXPY0`0CRUS=T7/0P@000T<8110<>1F@V:XETYJBUY9FTX01eY;
0eY<15Y;00mJJeYYFVUJJEYZFVaFBej=H/mZlV/fLeIgMGMfMiP00WNI0gNJ1gNH00AgN7NHMiQgV0Ag
V@=gVP03MiUkVG^H009kV@9gVP05MiUgV7NIMiQgV@04MgT2MiT3MiP01W]gMgMgMgMhMiQgN0AgM`=g
N0UgM`06MgQgMgMgMgMgNGMh0WMi00QgNWMiMgUgNGMhMgMcN7Mg0WMi00=cNGMiMgT017Mh00=gMgMG
MeL017Mg00EgN7=hLgQgN7=h00UgM`0CLgQcEg=GLgIcMg=GLcIg=G<eLcA_56lCJ_5^l6[^IX`a1@`1
20000P`P00<@@11146400a1P00@<H0a0340<@08@H08@@008200<80a0360@H110460@PPDDPP045:<D
PQ225882488358825:82584258800aB16:8DPP026:802AAQ584DHAB25:8L`QR158<DY00448<011B2
488@HA1Q0Q2200<@PA1Q46400PaQ00<<@@a046400Q1Q00<@HQ1Q46400Q1Q00<<HA1R46800QB20QB3
00<DXQBS58800a2100H@H@a0340@HA1R464346801@a2344@HA1Q36400Q1R00<@PQB256801a1Q00T@
@0`P340@@0a0440DHAR256401A1Q00<@HQ1Q46800Q1R00<<HAB156403A1Q00@@@11Q464@H@8<H@8@
H@07488@H@aQ464<HA1Q36800a1Q00H@HQ1Q464@HABR4842460446400a1R464@H@0236400`aP364<
H00234000`a1364<H@0336401PaR224<@11Q488@HPD<HPP<H@0:464<H0aP220<@@aR3608@0aQ3602
460334000`aP460@@003340336000a1P360<@00334002A10460@H0aP340880a1364@H00144400007
:E=2=Ek@G]5NT5j?GW000Uj@00ANTEZAFY5NT@9JT@03FY9NTUjB00QNTP03G[5NTUjC009N/`04GY=R
Tf:bH[<2G[<2G[@00ejcG[9N/P03H[404f:AI]9[5FkcDQ0XI`00200aBEZ@JcARcTh==DPeAd6ZBNa1
ZBT6008<@P0958<HY1RS68<HXaBT6<DDY@a200@000D48@888@0@1204011P8>DaB3f[?L/mc3g=CTmN
dF;dH]=Ve6[eI_D2I_@00fKcI_AVm002I_@00f[eJ_AZm@02J_D016[dJ_EZm6[c0f[d16[c16[d0V/D
00A[5F[dJaE[5@I[5PA[5@04J_E^mFkdK_D5JaD3KaD2KaH@KcH>KcL3LcL4KcL3LcL5KeL017=GKeM_
Eg=G1W<g00=cEg=HLeP00W=G1g=H0g=g3W=H0W=I0g=i0W=h0gMg00EcN7=iLgUcNG=j00=cN@0HLgYk
VW^mFW@e:BS4544H@BC3?HU5c59@E[9J/EJbCW5>DDH`?NhaJbD86:@<@@@04`0000T80@`05:E2TdZ@
EXiB;Dg]ANd00TX>00Q23DX_CTlaB2T3=JM6D2dX0P0000P801AP<@1NI6K9ETaFBeY:1UY;00=FC5Y<
FT`00UY<1EY;00iJJeYZFV]JBeY]ETaNK6K?I_9[=W=GMgEgUgNH0WNI0gNJ1WNI0gMi27NI0WMi00=g
VGNHMiT00gMi00AgVGNHMiQgV0=gN@04MgQgNGNIMiT3MiP01GMhMgMgMgMhMiP00gMh00=gNGMhMgT0
17Mi0gMg00EgNGMhMgQgN7Mi00=gN0MgN@9gN003MgMcN7Mh00EgN0=gM`04LgQgMg=HMeP2MgP7LgP7
MgL04gMhMgMcN7MgLeMcMW=gLeMc=WLeLcAg4g<CK_=^lW<BI/m>3B1R00880003440<8110008@@007
464@H0aQ364<@0Q036000Q1P0a1000L<811P464@H0`P440DHP02588011RR5:8DPQ1R0Q2200<DPQB3
588011B200XDPaB2588DHQAQ584DPQRS6<@HXP<DPP0658<DPR3T564DHQ22112300<DPaB248800QB2
1A2200<<HPaQ36400Q1R00L@HA1R344<@A1Q468<HP0246801AB258<HY1BT58<00a2200L@PA22488@
PPaQ464@PP0346801a1Q440@HQ11464<HA1Q008@HP03488@HQ1Q00H@H@03444@HA1Q008@H@0:544D
HART588@@11Q468@H@a0320434400a1Q584DH@0846400a1R464@H@0246400a10564@H@0346401a1R
488<PPaR364<@0`P00<@HP0558<@HQ1R464@HP025:<00a21464@H@02464246801122464<H@aQ0PaR
0`aQ00<<@@a0364010aQ00<<HPa144400a1R00H<HPa1220<@@aR4682368336400`aP364<H@023643
3443364010aP460@H11Q0Q1000@<@11Q440@H0<<H@05360<H@aP360<@003320346001Pa0344<@0a1
364@H04@H@0000@LlcVaI^iN[P9NSP03GXmNT5j@00INT@ENTPAN/@=NT@=NTP06HY9NTejCHY9R/Ujc
0ejd025N/f:cG[9R/6:aH[1R/F:bH[5c<F[ABLdT8`00200a1eI@I^iN[T7;=BLiJSfZALTeJ1RU348@
HQRT6:<HPaRS6:@00QS500<@PP0000000`0001@480@Q220480PP224880@0220HPbCV<BM1ZT6[>H]6
3Uj`H_=Re6;C0fKD00=Vm6[dI_@00fKd16KD0VKd00=Ve6[dJ_@00V[d00=Zlf[dJ_<00V[c16[d00IZ
lf/CJaA_56[dJaD3J_D5JaD3J_D2K_D016lEJaE_5VlF0flE0flF1Flf0Vle0flf0flF1Flf1Vlg0Vlf
16lg0g<g1Flg0g<g00=_Eg=GKeL00W=G0g<f00=c=g<fLcL017<g1G=G00=cF7=GLeL01G=g00=cEg=g
LgL00W=g0g=G0g=H00=cEg=HLeP00W=i1G=H0W=g0gMg00=cN7=iLgT00WMi01IgNWMhMgMgEWniMg]N
M3DX9:@LHR2T>J]:;eI`EY1>D4X_@NdeJBCU46<401X0000A005>mG?FHe5RjcDV9>PaS3V[>HU1bDh]
@LTaABe67>L<8P0200002`P0780i@5I4HZYJKEI<FTeJC5Y;FTX00eY;0eY<1eY;0UYZ00mJJeY/FVeN
KEi/I/mVlf/fKeMgMGNGMiQgVG^IMiT03gNJ00EgVGNHMiQgN7Mg00EgN0=gM`04MgQgV7NHMiT2MgT2
MgL3MgP00gNHMgQgN003MgP00gNHMgQgN008MgT3MgP>MgT00gMhMgMgM`04MgL00gMfMgMgM`04MgL0
0g=hMgMgF002MeP017MiLgUgN7Mh2GMg00QcMgMgMgMgMgMhMgMgMWMe0W=F0g<e00Yc56lCK_=ZdFlB
H[0mJA00000800D@@005444@H@aQ364<@@02220446001Q10320@H11Q460<808@H@04588DPARR5842
464236400a1R488DPP025883568358800a1Q444DHP0858801QRQ564<80a0364@PP<@HP04588DPaB3
588546824882468248800aB2568@HP0246801`aQ488HXaRS588DPa23008@HP0>464@PQ21488@PA22
588@PQ1R564DHQ1Q564@H@<@@0<@H@8<@0<@H@05340@HA1Q564@H@02468346401@`P464@HQ1R3400
0Q1R00X@H@a0340<@@a0320<@A1Q584DH@@@H@8DH@03464<80a100D@H@8<@@04464@HPaQ34423680
1`aQ368<@0a0220<@11Q008DPP8@H@8@PP04464@H1104444460010aP460@H@aQ0PaR10aQ0Pa00Q1P
00<@H@aQ36400a1Q00L<H@a1344<@Pa1364<HP0246801@aR364<H@aQ36000PQ000<8@@a136400PaQ
0Pa000<<H@aP46000Q1P00@@@0PP340<@08@@005360<H@aQ360<H@0236001@a0220880PP36000Q1P
00H<@0a1344<@@aP46014440000;48`];5Y]H/iRbei/GVmJL5ZAFY9JT@04GY45GY84G[400ejAHY5N
T@02HY42HY8015jCHY=RTV:c0ejc00AN]5jcG[9N/P=R/@0FH[9RTV:aI]5_5FJ@BLhP8P00728iRUI_
I_9JCCU6?FXmZTGZ@JX]1Q1258@66:@00aS57>H@Y00248<01@`Q0004000012000PPP0PQ1018480@0
100@@BC5<BDeAcV9@L]BC6;bH_=Rdf;DI]EVmFKdI]<9I]@016KcI_AVm6Kd2F[d00=ZmF[cJ_@00flD
00EZm6[eJ_EZmF[f00UZm@03KaE[5F/F009[5P=_5@A_5PQ_=P04KaI_5FlEKaH6KcH5KcL00flfLcI_
=P02KcL3LcL3KcL5LcL01FlgKeM_EfmGLeL017<f00=c=g<fLcL01G<g0W=G17=H0W=G0g=g0g=G0g=g
00=cEgMGMeL017MG2W=H00EcN7MgMgMgMg=h009cN@0EMeQcFGMhMeMkEg]EOiQkNV:d?FX]1c59ARmN
mEkcDY923SF;:BLHaA1R00L000888@07344@HQ1R568DHaRT8>H00RD702PQ1ac56:DDY123468<HPPQ
0004000044=K5g?eLo]RlT6:AQ12<RTY:>@iID6Y>HLeQc5V9BDDHP@00008033Q?D1>15I[ETaFCEI<
ET]JBPAJB`=JC0QJB`0=FVYJJeY/FVeNKEi/I/mVlf/eLeMgMGMgMiP00gNI17NJ00=gVGNJMiX01gNJ
00AgNWNIMiUgV@IgN0AgM`04MgQgV7NHMiT2MgT2MgP00gNHMgQgN008MiP9MgT3MgP?MgT2MgP4MgL4
MgH3MgL2LgP5LgT00gMhMgMgEP02MeH2MgH5MgL00g=gLgQgM`02LeL01GMgMeIgEWLfLcH00W<e00]_
=FlDK_=Vd6[bGY4i:0P01008011000<<@@P<H@@@H08@@005460@HA1P464DH@0258401aB26:8DP@a0
368DPaBS00<DPP03568@HQ1R00<@HP0748<DHP`P220<@1B258<00QB20QAR0QB200PDPAAQ444<@0Q0
364@PQAR0aB300<DQ1B348800a1R0PaR00<@HQ2248800Q220QB200HDHQB24684811R58<2568011B2
4648@11R0Q220Q210QB100@@PA22588DH@8@H@8@PP03564@@11Q00T@H@08584DPQB2468DPQB3488@
HPD@H@8@HP0=488@HQ1R568DXa1R464<@@a0564HPQ1134000Q1Q00HDPQAQ464<80Q136864680111Q
468<H@a00PQ000<<H@aR46800PaR00P880a0464@H@aQ340<HA1R0Q1Q00<@@0a034000a100Pa000@@
H11Q368<H@8<HP04364@HA11460346405Pa0364@HQ11464<@Pa1320@H@aR464@HQB3468<H@aR464D
PQ1Q344<80a00`aR018<@@aQ364@@0a0460@HA1P340880aP460@@11P360<@0aQ3603364234000`a1
364<H00236000`aQ344<@@02464146013400000<36TPad6VFXa_2f:;GVmJL5ZAFY9JTEjB1ejA1Eja
0ejA00MRTEjAGY5RTEjBHY9NTP02G[<01ejbGY=N/ejcH[=N/V:a009R/P9R/`0?HY9R/FKAKa9V/4F[
6004021RAL]N/6l=@LTaB3V:0095jP07>FLHY11T68<LXaRS7:<00aRT00DHYAS4:BLYB1R300@000<4
8003240480PQ0084000>200@@34U@JXiR4H;F/mW4VKCH[=N/f:cI]=VdPUVd`04J_=Zdf[cI_@=J_@2
Ka@016[dJ_EZmF[e0V[f1F[e00e^m6[eJ_E[5V/EJaIZmV[eKaIc=g=GMeQcE`03LeP017MGLeM_=Vlf
16lE00=_56lEKcH01Vlf16lg00A_=VleKcIc=P=_=P04LcIc=g<gKcL2LcL00g<fLcMc=`02KcL017<g
LeM_Eg=G1W<f0W<g0W<f0W<g0W=G0g=H3W=G1GMG0W=G2G=H0gMg00=cN7=iLgT00WMH0WMG015gEW/e
OiMoVVKDCJ]1[4X_H]9F/di?>H/Y1aB43284000000840003220<@0a1008<@@09348<HQ1R46<DHaB3
6:@PiRe7008aJ@059BPQ9b477>HHY00258<246807Q0Q200<8C67DVYBT47_>H]Ne5[g9>PPPBd1=D@e
Qc68>JPeYcET9<<<810P>B4mPTX7DV]FC5I=ETaFB`EJB`=JC0IJB`9JK00:FVYJJeY[FVaJBeiZI/iV
lFleLeL2MgH017MhMiQgV7NI0gNJ0gNI27NJ0WNI0WMh2gMg17Mh00=gV7MhMgP00gMh27NH00=gNGMj
MgT01WMi1GMh3WMi00=gN7MgMgL00WMg00AgMWMFMgIgMPEgM`9cE`=cN003MgQgMgMF00AgEP04MgMg
MWMgMgL2LgL00g=HMgMcE`03LeL04FmGLcIc=W<eKcI_5VlEKa=ZdFlCGW4e:@P0300<@11034000Pa1
20aQ0Q1P00@@HAB2460@@08@H003580LXQRQ008DP@09688DPQB2468DPQBS6<@H`aBS00@@HP0<344<
811Q468@H@a1444DHAB25:<DPaAR0Q1R0aAR00DDHA1Q464@HQ2200<DPP0458<HY1RT6:<248800`aQ
368<HP0236401A21488@PaBS58800QAR0Q1R0PaQ0Q1R00@DHA1R468@H@8@PP<@P@<DP@8@H@0:468@
HA11468@HAAQ560DHAB26882468346401110464DPARR0QAQ00@DHQRS6:<DPP@@HP04344@HA1R4682
48826:<01aB2468@HQ1R464@HQ1Q008<@@04468@HAAQ464546802aBS6:<@Pa226<<La122464<@0aQ
46800QBS0PaR00@@H@a0340@@08<@0@<H@8@@003340@@10P00<<8004440@H122464236400`aR364@
H@0246400a1P364<@00236401`a1464<@Pa2320@H11Q008@PP08468@HA1Q464@PQ1R364<@08<@@0A
368<H`aR344@HQRT364<811P484@HA10464@PAB0440@H00236000`aQ464@H@0636400a22468<@@06
34013200000:34LHQRdUBR]Zj6K=FVmNT5jAFY42FY8AGY42HY400ejBG[9N/P04G[800ejcGY=NTP04
G[83G[<05f:cHY9Zm6LEH[4mRa@0000TYE9AHZmFKcF8>HTmZDG;@LX]1aAT448LXabT7:<00QbT0QRT
00DLa2D6:DLLa11100<000<480052204811R6:@DP@0200002@a1:@DaIcW9DXiVkf;bG[9NT`02H[<:
I]<00f[bJ]=Zl`06J_@00f[eJ_AZm007J_@5J_D2J_H3J_D026[fJ_EZmF[eKcIcEgMiMiX4NiX01GMh
MeQkNW^JMgT00WMH00EkNGMiMgQgEg<f009_=P03KcE_=Vlf00E_=PA_=`07LeMcEW=GLeM_EflgKeL0
0W=G00=gEg<gLcL01Vlg00Ac=g=GKeM_E`=c=`=c=P9c=`9_=`03KcQ_F6mH00=cF004LeMc=g=GLeL7
LeP6LeL3MeL8LeP017=iLeQcF7=H0W=h1G=i0W=H00egEg/eOgIoVVKeERm>3UYaFY96<2e968@<8P02
200010PQ348800`P0Pa100H@HQ1S368<HA1Q468248<04QBT5:DLiacV9BL]J2f:9DPM1aS55:DDY1B3
56<@H`a210080084000E200<Hb59?PdeZab3864Ta2C2;DE6CSh<@Re23CV:9<<H@3U2ALIF:EI[009F
C003ET]JC5Y;009JB`EJC09JK0AJB`03FVYJBeYZ009JJ`0:FVaJJei;IZmVlF/dKeMgEWMfMgP2MiT4
MiX3MiT8MiX2MiT00gMiMgQgM`0=MgL00gMhMiQgV008MiP4MgT00gMjMgUgN@06MgT00gMgMgQgN00:
MgT3LgX4MgT2LgP3MgL2MeH00gMfMgMgM`03MgL2LeL3LgP00gMgLeMgEP02MeH5MgL4LgL6LeL01WMF
LcI_=VlgJaE[509ZlP05K_AFDBcX300<800244400a1Q468@@@043445364346400aAP440@H0024640
21R19>@HXAR1584DPQRS5:<258804Q22584DPQ1R564DPQB3568@@@a1564HXQB2564DPR3U6:<DPP8D
HP<@HP8DH@04684HXaB24882588258<01QRS588@HQ2358<@P`@@HP06488@HQ23488DPQ1Q0Q1R00<@
PQB248800a1R11220a1Q018@PAB1584DPQ22584DXQB2468<@@aQ464DHAB1488@PA22568246400a10
460@H@024642564011QQ8<@HPQAR2A1R00@@PaB258<DP`@@HP8<HP0448<DXaB34682464446800a22
58<@P`0348<00aBT6:<@H@0346401Ac46:<<HQ226:<00Q1Q0Q100Pa000@<@@aQ364<H@8<@00:320@
8111364@@A1P588@PPaQ340236400a1Q488@H@0246400`aQ468<HP023640211Q364<@@a0440@HAB1
488346401`aR364<H@a0220<@0a100D<HP0:46<<HPaQ364@PQ1Q460<@0aP460244001Pa0360<HA1Q
488@HP@<H@0748<DXa22340800PP32000`a00@`P000030Q556DDPcU5FVQRZej`H[1NT5Z@GY5JT@=N
T@04GY1NTEjAGY0>GY46G[400ejBGY=NT`05G[<025jdGYANTf;DI_=[4Ej?=DL200003BS6DTeRd4X/
>JTiRSf9AN/aJQbW56<HPaRT00<LY00:6:@LY1bT8<@La23U7<@<@@001002120020@Q1204811Q;DLi
QQS4100200002ab3<DA1jV;;H]1NdeZBGY9R/V:aH[800VKC00=VdVKCI]<00fKC00AZlV[CJ_=Vm0QZ
m003JaEZm6[d00IZm@9Zm003J_EZmV[f00AZmP9_5P0;MeMgN7MhLgQgEg=GJaER/Ui`HY5RT002HY40
1EibHY9V/f[dKcD00W<e0W<f00=cEW=GLeL00W=G0WMG0gMh00EgNG=HMgQkN7]g009kN09cN008MgQk
N7]iMgQ_F6/hKcQ_=`9c=`05KcMc=W<fLcIcE`06LcL00g<fLcM_=`02KcL00f/hKcQ_F002LeP4LcL0
0g=GLeQcF005LeP00g=GLeQcE`06LeL3LeP00g=GLeQcF002LeP3LgT00gMHLeQgF005LgT2LeT047MH
McEoMW^JKcIJLDh`CU11k2TX46<40000204800PQ20a10Q1P01D@HQ225:<HYAc59BLeRSg<BRi23SV[
:BLLiacV6<DHYA1S36<<@`PQ1000100001<H`c6W9DHP`aa1524PHDX9G_=>CCEW>HY1cC4W::0mQ4XZ
FVYJR`02ET/5FT/3FT`2FT/3FV/2FTX045YZFVUJJUYZFV]JJUY[GV]JBV:]I]1[4flfLeIgMWMh0WNI
17NJ00=gVGNHMiT01WNJ0WMi00AgN7NHMgQgN0mgM`AgN0EgV003MgQgNGMi00MgN@9gN0=gM`9gN0Yg
N@=cNPAgN@9cN0=gM`9gEP9gM`03LgMgMgMg009cE`04MgMcF7=gLgL2LeL4MgL01GMhMgMgMg=gMgL0
0W=G00=cMg=fLgL00g=G00=_EflgKcH00Vlf00Y[5F/CI_5ZlV[B@LdLQ@@0320@@0<@H@03444<@@a1
008<@@04360<@@aQ364234424642460246401`a0440L`1RP6:4HPARR008La007588@HA1Q584HXQB2
58400QB200PHXQB2568DHAbQ688DPAAQ11B200<DHQ1R56400QAQ00HDH2328>@LXQAQ58445880111Q
348@HQ1R0a2200D@HPaR244<HQ1R008@PP07464@PA1Q468@PQ214880111Q00<@HQ1Q4640111Q00DD
PA1R360DPARR008HX`0<468@HAAQ564DPA21584@HA10464@@11P0Q1Q00/@H11Q340<@11Q584DH@a0
224@HA1R008DPP06468<HQ1R468DPaR20Q1R0Q1Q0Q1R00H<HQ1R48<HXaBS4682464246800`aR344<
H@03468010aR46<@Ha1R1Q1Q00H@PAR26:8DHA1Q460244001PPP344<HA1Q364@@0<<@004460<H@aQ
3642464010aQ3408@0aP0Q1P00<@HA2148800PaQ0Pa100@<H@a0340<@08@@009460DPA1Q464@@A1Q
468<@@`P00888003340<@@a100<<@@8<@P8<@@04340<H11P3602344734000`aP364<H@0236401@aP
220<@11R34000PPP0P`P0Pa00@a100002PQ436@80B21ANIFKEj<HZmNT5Y`15ZA00ANT5jAGY5NT@AN
T0ENT@=NTP=NT@AN/@=N/PUN/`07G[AN/ejbH]9RlUJ>9>L00P0000la:UJCEY4iZSV9?FQ1Zc6;:>TD
Ha1R6:DHY1bT8<D00QbU0QbT00@P`bD5:BL@HP80000;100480@Q1448@@aR9@Hiad9<9DH880020000
3Q12<DQ:;F;bH]9J/UjBHY9R/V:cI]9VdfKBI]<2I]@2I]<01V[CI_AVm6KdJ_AZm@EZm0=Zm@UZm006
J_EZmV[fJ_E_5W=G0WMh00]kVGMhKeQVmE9A?Ld]:B36544@80`0008D800B768TaBd8>FTmZTg]ETeJ
Kei^I[5_57<eLeIgMgMhNgQgN7]i0W^J019kNGMhMeM_5F[bJ]9ZlVKBI_9Vlf[dI_E_=g=iLgYcFFmH
LeL2KcL01G<gLcIc=VmGKcL01G<g00Mc=W<gLcM_=f/gKcMcE`02LeP017<hLcMc=g<g0W=G2W=H0W=G
4G=H00=gF7=iLgT00g=i019cFG=jLeUg=gnGMiY[=ejbDVli[2CU448<0@P022488PPP224934404`aQ
468@HQ236:DQ22U9=HXmZe9@@NdeJRdY:@PPiacW6<HDYA24008<H`03244000000080000F<FMF/5lb
BR`e9RR4:85B;E:@>HLa9CU7@HXiJCU6@JM>C5IZEV]FBeI[ET/4FT/3FT`2FT/2FV`00eY[FTYJBP04
FVX2FV/035Y/FV]JBf:=I]1[4fleLcIcEWMgMiUgV09gV@9gVP04MiUgV7NIMiT5MiX00gNIMgUgN003
MiP00gMhMgMgM`0@MgL4MiP;MgT2MgP3MgL2MgP00gMiLgYcNP02MgT01GMhMgUgNGMiLgT00g=j17Mi
00=cNG=hMgL017Mg17=g00=cN7=HLeP00W=H1G=g0W=h0g=i0W=h00=gMg=GLeL00W=g0W=G16mG00]_
=f/fJcI[5F/DJa=Zm6:@>F`<8`00008<8004468@HA1Q364734401PPP344<H@aQ464@H08DPP04464@
@1A068036:401aRR6:<DXQB2468DHARQ008HXP0:588@PQB25:8@PQ1R564HXQB158824640111R588D
HAB11AAQ00HLXR3T684@@1AQ4883588358<4488258801A23468@PQ2246800a220Q1R0a2200L@HQ1Q
468@HQ1Q488@P`0248802A1R568DHA1R488DPQB16:<@PP02464358400aBR588@H@03464021B2464@
H0a0464@HQ1Q468246400`a1464@HP0348800`a1468@HP05468246401A1R368<HQ1R4880111R0PaR
0`aQ0PQ00PaR0a1R00<<HA1Q4640111Q00LDHAR1464@HAB2464@@00234000`aQ464<H@0234000a1Q
368<H@0336403@a0364@H@aQ368<HA1Q364<H0aQ368@P`aR008<@0<<H@<<H006464DPA1Q344@@11P
0Pa10PaQ00<<@@a034400`a100@<@Pa1344<@@888003440@H0aQ008<H@03464<@0a0008<@0<<H003
340<H@aQ00@<@08<@@<<80<<@04<@@0000T8@`Q4004D@3E1CR]VbF:<GY000eY`00ANT5Y_GVmNK`QN
T0UNT@9N/@05GY5N/EjaG[5NTP02GY<2G[<3H[<2G[<05UjCG[AN/f;DH]1cCdi@8:H00001=BYB;TX=
?HXiJCF:=H`aJQbU448DQ1RT1AbT00DPa1bT9@DU1a1R00800084800:1248@@Q1344<@2TV@RU:B367
46<200001PP1;@I:;V;aH_ARm@=R/`04I]=VdVKBI]<2I]@2I]<016[CI]=Vm6Kd0V[d0V[D1V[d00=Z
df[cJ_<016[c00=Zm6[eJ_D00V[f00Y_=gMiNiQgMg<dIZm=k3E8768400H0000?10000000000401PP
880X`c45>FQ1bdg/ER]NKF[A009ZlP0NI[1VdFJaGVmJCEi>FTiJ;5H<EP]F:eH:DPU9jDh:DP]B35H_
FW5Vdf/ELeIcN7MgKeQc=flgLeI_=W<f1G<g1G<f00=c=g=GKeP01g=G00AcF7=GLeMcE`ecF005LeMc
F7=GLeMgM`0=LeP03WMHLgUgFGLgOiMgVf/fFVe1bBST56<<8@P022423247344222400``Q32088004
10002`P0444LPRCU<DPTiQR432880@@110000`PQ00<<@@`P10000`0001P403fYJe5c]7oCI]0mRbRS
;@HeRC559<8P`bdW<DLiId6XCRaNRUIZET]FJeI;FT/2FTX4FT/2FTX01EY;FV]JJeYZFTX00UYZ00EJ
JeYZFVYJBUY[009NJ`09HXeV[f[bJcA_=W=GMeIgMgNG009gV0=gV@=gV0EgV@04MiQgN7MhMiP2MgPB
MgL2MgP3MiP00gMiMgQgN@06MgT4MgP5MgL01gMiLgYcNWMiMgQgMg=h009gN@UcN@03LgQgMgMg00=g
M`IcM`9cF003LgQcMg=g00=cM`9cF09cN@04LeQcN7=hMgL8LeL01VmGKcM_=VlfJaI[5@9Zl`06J_AN
L35;004401100P`P00<<@A10344010a100D<@0a1220880a0008<H@03360@H11Q00<@H@03564HPAR1
00<HX@8DPP05468@HAAP6:0DP@025:801AB3588DP@aP34400QAQ00/DHQAQ444@@A1R564DH1R0440D
HAR2008DH@8@H@8<@003364@PQ2200@DPP0458<DPQ1Q58424880111R588DY1221a1R00<DPa234880
0a1Q00T@HQ1Q464@HPaR468@PQc46:<00Q1R00<DHARQ46400Pa00Q1P00@DPA1Q588HX`L@H@03340<
H11Q00@@H@03588HXaB200<@PP8@HP043448@@a1468546400a1R464@HP034643468020aR364<HA1R
464<@0aQ368246800a1Q340@H002464010a0464DPQB11A1Q00/@@11P460<@0`P220<8110464@PaB2
008@H@8<H@8@H@8<H@8<H004364<@@PP220234401`a0464@PPaQ340<H0a000<@H0<<@004460<H@aQ
344334053442364010a1220<81100Q1P00<<H@a0340010a00`aP00@<@0Q0340<@0888006340<@@a1
344<@0`P0`a00@a100002PQ326@40@`07:8mZ6:<IZaNSeZA0eY`00UNL5j@GW1NL5j?GY1NTEj@GY40
0ej@3UjA00=NTUjCG[<00ejc00ER/f:BHY9RTV:C00=N/`0BJaE[<V/fBNhD8P00200i:58_@JTiJCEZ
>J`eRRT758<<8AR41AbT00DPa1c48>DLiA1Q0080000=1208@0@Q1248@@a1000@HCG8@PQ2CSF;68D0
0P0000`802T8AS1NmVLEI_ER/f;CI]AVdfKBI]<2I]@2I]<2I]@2I_@3I]@3J_D4J_@2J_<3J_@3J_D0
2V/ELeMgNG^kNiUgNFKdEW4iS1QS100001/H@2T6?Ja:3Th]FY1JSeI?BNhmRc46884H8100620LHBSV
=FTiRSf[?JTmRSV9=FT]9bCT88800QQ000@L@22R:>Da9`8eA`0=?JU9jTX;BNY9bDF8BJQ=k5H^H[9V
mFlgKgT00W=h00Ic=flfKcIc=g<fLcL5LcH2LcL2LeL00fmHLeMcE`05LeL017=HLeMcEg=G6G=H00=g
F7=HLeP017=I00icFWLiMcMkN7MiH]=5k3DU544@8@P0224<8Pa20Pa100<8@PQ134400Pa100<<80@0
00002@0000H@02dV;BDPa0`0100900002RTWDXlmkQRU8<E23emFKgAW=47/0S4V00<]12CR7<800Qc4
00XY1bdV>HM:;5YZGXYFBeI[FTYJB`9JBPiJB`0?FVYJBeY;FT]NBeY;GXeR/6KbJaA_=WMFMgEgMgMf
009gV0=gV@=gV0EgV@EgV003MgQgMgMg00egM`AgN0=gN@03MiQgNGMi00EgN@IgN0EgM`08MgUcNW=j
MgUgN7MgMgQgN@QcN@03LgYcNG=i00AcN0McM`9cF005LgQcMg=gLgMcN003LeP3LgT2LgP2LeP6LeL0
0g<fKcM_=P02KcH02V/EJ_AVdfKBI]AFDBTZ00840@a00`a100<<H@a134401@a10`a000<<@A1R4680
111Q0QAQ0aB100<DXQB258800Q1R00DDPQAP6:0H`aBR008DPP0B488DPA1Q340@@AAQ668DH@a1464@
HQAQ684LP110688La1AR0QAQ00<@H0a14880112200DDPQS46:<DPa22008DPP08488@HQ1Q58<DXa22
468@H@88@008464@HQB26:<Ha1RS564@H@8@HP06464@PQ1R344<HQ1R0QB300L@Pa1R444HPQAQ444<
8002464011AQ468@HQ1R111Q00@DPQ22464@HP@@H@0;440@HAB25:<DPQB3488@HQ1Q468<HP034685
464246800a1Q340<@003468246<00`aR468@HP0246801Q1Q368@HQ22468<H@<@H@06440@H@aQ464@
HPaR0Q1Q00@@H0a0460@H08<H@8@@004464HXaS4588546801A1Q364@H@a046000PaQ00H<@@Q0220<
@1114402344334000``P340<@00434000`a1364<@@0334400`Q1220<H@03368236401PaP460@@11P
464<@@<<@004360<H@aP360246000a1Q368<H@05364234401@`P340<@0a046000@a100003@Q224<<
@`P0300/hTh9HXaVdEjbFW1JKeY`00=NK`03GW1NT5j?009NT09NT@03GY1NTEjA00eNT@=NTPAN/`03
HY5RTV:b009RTP9NT`0GGY5VlfKaH//m[@`4000<0CU8@JLiR3F:>J/mbSEY9>DDHQ1S7:@LXabT68<L
X`037<@01R3V588400P0240<@084000;224<@@@0000Li47W?NU5jcfZ;@L<8P0200002Qb6@LiRdF<E
JaEVe6;CH]9VdFKB1FKC0fKD16KC0VKD0VKd0V[d00=Zlf[dJ_@00V[e00]ZmV/FKcQgNGNIMiMcE6k_
EN/`i@`000<00007760iA57YJ/ac<G]eNiL00Wnh00]kV7]gNgMg=FkcIY1RKUH;?JX]1QQS008@8008
664LP1aP540@80`0320@@0<HH00G540HHB2Q:<@/hcD4?HMNK6:`G[1FCTW:AHY9Zdg;ERiVdfmGMgM_
F6lgKcIc=@03LcH017<gKcMc=W<g0g<f0W=G00=_F7=GLeL01G=G00=cF7=GLeL017=G17=H1G=G00Ac
F7=GLeMcE`UcF09gE`03LeQcFG=J009cFP0:Le]g>GLgOgMgN6:`?FPPH@`02002324434401PQ22244
00aQ368480L0000@220DHaQT:@M:;WNjOoi_NDiB>HdTb1bV46@40`02004300006eJ>OoEkeCV]54<D
RBV==JTaIbdU<DHeAcEV;D@U1AS49>DXiRT5>HM5jUY:FXYFBeIZFVUJBP02FTT00eYZFVaJK00?FT/0
2eY:ERUNK6:`I]9[4g<dMeEgMGMfNiL00gNH0WMh1WNH0WMh17NH00=gN7MgMgL03WMg0WMh0gMi00=g
NWMiMiL00WMg17Mi00=gN7MgMgL02GMg00QcN7MiMgUgNG=hMgMcN7Mh0g=i00=gN7=hLgP00W=i00Ac
NW=iLgUgN0=cN0QcM`9cE`AgM`03LeMcF7=H00=cF004MgMcF7=HLeP2LeL017MFLgIcEW=G0W<f00Ec
=FleKaA[56[c009Zd`05I_E:3b2W10840@0234000a10364@@00334402PaQ344<@@a1444@@0a03208
80a00a1Q00T@H11Q564DHA1Q468@PQB258<00Q1R00D@@AAP7<4L`aBS008DPP06464DPA1R588HXaB2
0aAR0QB200HDHQAQ680DH1bR7<@258801QB1564DHAB2488@H@8@P@03588@PQ22008@PP@@HP05464@
HQ1R344<@00546401AAQ584DXQB146400Pa100<<@11Q5840211R00<<8@a14640111Q00D<@@Q1244<
HA1Q008@HP04464@HQB3588446401111320<@1110Q1Q00@@HQ1Q468@H@<@HP8@H@03344<@11Q00P@
H@04368@HQ1S46<23680311R364@HA1Q468@H@aQ464@PQ1Q364@@@8@@005460<H0a0340<H0024600
0aB0684@H00244001A1P464@HA1Q48800Q1R00<@H@aQ46400Q1Q00@@H120340<@0D<@@8<@0<88003
344<@0a100@<@@D<@0D<@@H<H@04344<@11P34024606340436001A1Q364<H@aQ36800`aQ00<<@@`Q
22000Pa00A1P0A1Q0@a1000030Q234<@@`P0100D@CDUFTiVcV;bFVmNK`9NL003GVmJL5i`00YNT0YN
T@04G[9NTEjAGY82HY800ejBG[=R/`02HY805f:AHY9RTV:CGY=RTUjBI]=ZlUkE?H`80000428a9cF;
<FTmbd7[?N`aAR2T56<00abT00<HPabT7<@00Qc401@PiARS444880Q1320000P0424@@000100<@34T
ALU5jTH=@Ndi[AR50P0000PH@Sf]F_ES4fLDG[9RdVKA0fKC00=VdVKCI]<00fKD00=VdfKDI]<01VKD
00iVmF[dJ_EZmFlFLcMcF7MhMiYcNF/iDU<iS1a10`0000TH034WCPeVlG=COiMo^7nHNgL01GMF02eg
Mg]hNiUkVG]hMgQcEVKdFTm=bdFZ>HTiJ3U8>FU5RTg]EW1N/F;CG[5RdejbFY1F:cf8=@@/XCU6EP]_
=GNIKcAVdF:?FRaAk57:DPeNTF[dKeM_=W=FKc@00Vlf00=_Eg<gLcH01G<f0W=G00A_F7=GLeMcE`Ec
F0=cE`=gE`AcF0EcE`9cF09cE`03LeQcEg=H00EcF004MeQgEgMGLeP3LeT02G=iLeYcFGLgOiQkNF9^
<>D@8@02200030a2344<@@Q1248<@@@Q000400@Q2688@@840009224DPbCV;@PeBT7=DU=Nn6nK00Eo
o`08MiiJ]TXA?JheSBe;8>PHH`84000G>JYcLfLe<DPTYD7a:F`HXR33:BD]B35Z=HTaIbUX7>DLa2SS
;@<eID77FTYJJ`02EV/00eY:FVYJJ@02FVX9FT/00eYZFT]JB`03FV`045Y;ET]JBUY:GVaNSfKAJa=c
EG=FMgEgMW^GMiQgN7NH0WMh1WNH1WMh4GMg0WMh0WMi0WMj00EgNGNHMgUgMgMh00=gN@=gN0=gM`=g
N0=gM`9gN004MgUcNG=hMgL2LgP4LgT2LgP00g=iLgYcNP02LgT4LgP8LgL2LeL3MgL2LeL3LeP00gMH
LeQcF003LeP2LeL017=fKeMcEg=G0W<f00ec=FleKaA_56[bI]9VdFKD@Jd@I0@1200<@00232000`a1
464<@@0234400`aQ444<@@0234401@aQ464<@0`P34000Q1Q00/DPQ21464@HA21464<@0aQ488@Pa1R
008<@@03584HXAB200LDPP036:@Ha1RT008DPP086:<DPaB2464@H11Q588@P`8@PP0:584<81B18>DH
XQB1464@PQ21488234400a1R488@PP05468346400a22464@HP0246402A1R488DPA22468@PQB2488@
H@02468248<0111R344@HQ1R0PaR00@@HQ1Q464@H@8@HP05368@HQ1Q340<H@0246800`aQ468@HP04
464232002111564@@11Q344<@0a146434682464546800`aR464@H@0346401122468@HQ1R0`aR1@aQ
00H<H0a0364@HQ2246824400111Q460400a00a1Q00<@H11Q46400a100Q1Q00<@PA1Q34000Q1Q00@<
HA1Q464@H@8@H008464<HA1R468@Pa1R488@HP<<@@8<H@05340<@@a1344<@0033444340434400`a0
364<H@0236400`a1340<H00236000a1P360<@00634001PaQ488<H@aQ464<H@<<HP07488<H@a13448
80a136400Q1Q0A1R000030PQ324<@@P0000801b4@JYNS5k@G[1JK`9JD003FVmJL5i_00=JK`03GVmN
T5j@00QNT09NL@=NT@9N/@03GY5NTUjA00=NTP9N/P03H[5RTEjA00ARTP0AHY=R/fJcJ_EW4ei]>DX<
0P00204]1c57=HQ62d7Z?JPY1@0268@47:@27<@0123T9@HLa11R0Pa100H40000200<@@`P20021000
21bS=FE5b479ANY1bSV:68D2000021A3?LeRcekcH_ARdf;BH]<?I]<03VKDI_AVmF[fJaM_5g<gMgQg
Mg=EG]55kBT9108300002Qa0>DIN:fl?Ng=kM7]eMgIcEW<e1VlD00A_5G<eLcEc=P9gE`9kM`0:MeEc
EG=EMeIc=FlEK_E^mW=GNiT4OkX05g^jNiQkUf/CDP`iB346@HYRSg=DOkMk]gNFI]9J;Tf[BH]Ak5i^
I]5[4W=DMe@00VmE00A_=VlgKcMc=`Ac=P9c=`IcE`9cF003KeQcEg=G00EcE`=cF0EcE`=cF0EcE`Ec
F09cE`AcF009LeMcF7MINeMoV7MHEN/X@0`000880003348<@@PQ008880840080000>244HaB46;DPa
Rcg=BS1BLeZdH_I[>G=kLieooPEoo`05I_QBDdX@?LdiZ`02?JX06SeW=@LPaa259@HTi@P088<m[BTY
:@M>;e:A;H`YBbe9>JXeRB3T420@@22Q=D91YEI9FX/2EV/01eY[FVUJJEYYFTUJBUYZ00IJB`03FTYJ
JEY[00=JJ`03FT]JK5Y[009NJP09GXeRSfKAJ_9_=6lfMeEgMGMf00EgN003MgMgN7Mh00AgN1IgM`9g
N0EgN@9gN003MgMgN7Mg00EgN09gM`04MgQgNGMiMgT5MgL00g=hLgUcN003MgL01g=hLgUcNG=iLgQc
Mg=h00AcN@9cN0YcM`9cE`9gEP=cE`03LeQgMg=H00AcF09cE`03MeIcEWMF00=cE`03LcIc=G<d009_
500=J_AZlV[@I/mJTcU/204400PP440<80PP32000Pa00Pa10`aQ0Pa100<<@11P46000a1Q00P@@11Q
464@PA1Q484@HA210a220Q1R1aB20QB30QB200@HPQB2588DPP8DH@03488DPA1R00<@HP0B464DPAB1
584<@1R18><DPA1Q564@PAB1488<HPa1468DPQ1R0Q1Q111R00<@HA2146401A1Q00<@PQB258800QRS
00@DPQ22584@H@8@HP06488DPaB248<@HPaR1A1Q0a1R0Q220a1Q00@@HQ1Q468<@P<@HP03464<@11Q
00@@H@03444<@A11008@H@03564@HA1Q008@H@04468@PQ1R368446401a1P560@H@a1364@HPaR008<
H@05340<H@aP364<H00234000`aQ340<H@0234401A10444@@0a046400QB200DDHA1Q320<811000<<
@004360@H11Q46434602464346000`aQ464@H@0236824880111R364<@@a10PaQ00@<H0Q1220880<<
@003440<@@a100<<@003344<@0a0008<@08<H@03360<@0a000P<@003240<@0a000D<@08<H@@<HP@<
@@<<H@4@H@4<H@0000@88@`P34488@84000634<]9Ti=G_9NceY_0UYa15Y`0UYa00AJL5YaFW1JT@MN
T003GW5NTEjB00ENT@MNTP05GY5NTUjAGY9RTP02HY42GY8056:BGY9ZmF[dDU<a;0`1324HHRT6;FTi
bSg[?LTaAbC556<HXabU7:@27<D062359@DY9aS53688@@PP000<@QB448<<@Pa1200000PP8<@mYTGY
@JU:2dX^>NdPiP800007648mcUKfG_ARmEZbG[<00f;C00=Ve6KCI]<00fKC00=Ve6KCI]@00VKD00aV
df[eKaIc=g=HMi]gNVliG[E>DSV/56<300001A@0;@I5kF:aKeD00WMf00AgEG=ELcA_4`9^l`03K_A_
56lD00=_5@03KaA_5FlE009_5@08KaA_5FleLeIgEgMgMgQkN@=gN@04MeQcEg=GLeL2LeP3MgP05WNI
JcEFKcf::8<e:EY?MgIofWNgMiM[56:ADNe9QdfXDPYVd6/dLgIcMfmF0Vlf0Vlg00Ac=g<fLcIc=P9c
=`IcE`03LeQ_F6mH00McE`03LeQ_F7=H00=cF09cE`AcF09cE`=cF004LeMcF7=HMeP2MeL04W=GLeQc
F7=HLeMcF7MGNgMoV7MIBJ`<00P0100800PP34488@840080000K444LaBe8?Ni6D4jCD[AJeElFJgUW
FEliGaUJnE[GF[INmV]IIcIBTSV/:>LTYB2U9>HPiRTW008aA`05=FTeRc5Z9>@DHP0232002a11320T
`e:AHePf41dY;FXaJ2CV7:@00P@000D@83D0AJEJBEZ:009FJ`AFJP03FTYJBeY;00EJB`9JBP05FVUJ
JeYZFV]JBP02FVX02UY[GV]JJUi/HXiV/6KbJaA_=W<f0WMf0WMh00=gNGMgMgL01GMg00=gNGMhMgP0
17Mh00=gMgMhMgP04WMh0gMi0WMh00=gMgMhMgP01GMh00=gMgMiMgT00WMi00=gN7MgMgL00gMg0g=h
00=gMg=hLgP017=i00=cN7=gLgP00W=i00AcN7=iLgQcN09gM`QcM`9cE`03MeMgEW=G009cM`QcF09g
E`9cEP03LeMc=W<f009c=@09Lc=_56[dJaE_56[AK_9J/c4[00840004344@HA103402320234023442
36401@aR364<@@aP36400PaR00@@HQ1Q340@H08@H@8@P@03464@HQ1R008DPP0558<DPQB26:8HX`02
588458<55880111R564DPAB10Q2200/@HA11460DPQB1484@PQBR588@HA10008@H@06588@P`aR468@
HA1R0Q1Q00H@PQB3588DPQB35883464010aQ464@HA1Q0aB200DHXQB2488@PQB200<@HP06588DXa22
48<DPa1R111Q0Q1R11220Q1Q00DDPQ1R464@@1AQ008@P`04468@HA1Q46426:<0111R464<HA110a1Q
00DDPA1Q464<H@aR008@HP8<HP8@HP04364<@11Q56034640111R488@HQ1P0Pa000H<H0aQ364@PPaR
364234000`a1364<@@02340246400a22464@H@0246400a1R464@H@0346401121464@HPaQ0Q1P00D@
HA1P220<@11Q008<H@03464<HPaR00<<H@8<HP09364<@@aQ464<H@a2344<@0a1008<@08<H@@<@@05
340<@@a0340<@@0236400`aR360<@00334001@a1364<HPaR36400Pa10`a000@<@@a0340<H@<<HP04
364<@@a13444364134013440000?224880`P24888@PR204LY3fYE[1VkUj_GY9JLEY`009JK`03FW1J
LEYa00=JL@03FY5NT5j@00MNT0INT@07G[5NTEjBGY5NTUjAG[4015jA00=RTEjAGY400UjB0UjC00mR
/f[eH]IB<S4[9:LXYQQS7:@]B3VZANXmbS568<@00QR300lLY1c57<DPa2CU8@HHY0a1240400006:D]
BAc622800PP000/40000588mQD79?JU5bDX[@P/mabD50080000744E6<E[AG_AJ/ejbH[800f;C16KC
00mVlfKdI]=Ve6[eKaIcEg=HMgQcEg<fI[=B3cE:66@0100000HLH46WHVUc37MANiH2MgH00g<eKaAZ
m002J_@2K_<00fkdKaA_5003KaD2Ka@3KaD00flDKaE_5@04KaD5KcH016lEKcA_=Fle0flf01UcF7=h
NiQ_=UY>;>LLASD9FTacMW^gMiMcMV[cI[9J;Tg9DNYF:fJ_Ja9_EFmFKcIcEP04LcH017<gLcIc=W<f
0W=G00=c=W=GLeL00W=G00=_EfmHLeL01W=G0VmG00=cF7=GLeL017=G17=H3G=G00QcF6mHLeQgEg]h
OkQ_5cT;0P0000<80@`P44400Pa101P400a16:@eJ47[BPeBTEJcEY9>LDYABU1>L4ib@PlaS2e/:D/P
j1RV58D@I0a2324322402PQ1348<@Q1R58<HY1c49@DaASEV0S4V00/PaAB1340@@2dT>J`LiRDW=J/]
AaB40084000=000402BPALENRF:ZEV]FBeY[EVYJJEY:FVX01EY;00AJBUYZFVUNB0MJJ@0<FVYJBEY9
GVYNS6J_I_9[56lfMeEgMGMf0WMh00=gNGMhMgL017Mg00AgN7MiMgQgN0=gN@03MgQgMgMh00AgN@ag
N15gM`9gN09gN@03MgQgMgMg00MgM`9cN0AcN@06LgQcMfmhLgUcN7=g0g=h00EgMg=gLgMcMgMg00Mc
E`03MeIcEg=G009cM`AcF003LgQgN7=H00AcE`9cEP9c=P9c=@0;La=_56keJ_E_56[ALa=N/bd80004
000444000``P340@@003340436401A1R364<@@aR34800PaQ0Pa100L@HA21580@PA1Q344@H@025882
58<011B26:<LiARS0aB30aB200<DHQ1Q46800Q1R00d@PQB2584@HAB1460<8110464@PQ21464@HP02
46401A1R464@HA1Q48<00Q1R0Q1Q00<<HA1Q58800Qc400`DXaB3488@H@aQ344@HQ1Q440@HAAQ5883
58400a1Q444@HP0246801Pa1584@PQ22464@HPD@H@07468@PQ22488DPQBR48800a1Q00L@H1AP6:4L
`aB3464DH@02464258800a1R464@H@0546401@a0464<H@aQ34400PaR00h@HPaR368<@Pa1360@H11Q
584HXQRS488@H@aP0Pa000<<H11Q464010aQ00H<@@aQ364@@A1Q468246400a1R464<@00246455640
0a21464<@0023403460646401`a0464<HA1P320880a100888003340@HA1Q008<H@03344<@0a1008<
@@8<H@8<@@P<@088@@8<@0888004320<@@a1244234433402344422001@Q1364<H@aQ34400`aQ00@<
@@aQ344<H@4<HP0000<<@@PP22400`Q200T40@`P9<A635j]GZmJ/UIaFW000UY_00=JL5YaFW400eYa
00=JTEj@GY000ej@00=NTEj@GY402EjA00ENTUjAGY5NTEja00=NT@04GY9RTF:AGY42GY82GY<04V:B
H]AReUjfFYA:3cDY78@<@QbT<DLmbTY=@NT]122S564LY08La@0J7<@PiABT48<<HPPP00088BTXAP`a
JA12000800PP100802CU=HTiR3V7?JQ6348<=NdTaP80000968Hmke/FG]5NSf:aH]9VdfKd00=Ve00>
I_A[5FlfLcIcEgMgLeQcEflhG[E6435:66<800<0000;500a:4h>I]9c<g^FNiEgMG<dKa=Zl`04J_@4
Ka@5KaD2Ka@2KaD00flDKaE_5@08KaD:KcH06W=GMgMgN6lDDNh/b2@Q>DUNSgMeNmUcMgMhLeMZmF:a
EP]AbEGYGXmVlg=fMgM_EVlfLcH5LcL2KeL00g=GLcIcE`03LeL00fmGKeQ_F005LeP3KeL00g=HLeMc
N002LeL00fmGLeQcF003LeP5LeL5LeP00g=GLeQcF002LeP08G=GMgMoV7niFU4TI``040<LQAAS100@
@@a16:@aJD7/BTm:;dY@@Nhi[2e99@LPaQc57<@HaART58@@H`aS3688@P0222400`a1348<H`0246<2
48<010aS364@HQ1R0Pa000T@@1B37<DU:2e8;DLaIRSR68400P@000HPiRDV7>@LiA1R100200002ab1
ALMNRVK;EVeFC5I;EVYJJEY[FTX01EY;0UYZ00=JJEi8FVT015YY0UYZ00aJBeY:FT]JBUi;IZiVdF/C
KcEgEGMeMgH2MgP00gMiMgMgM`05MgL017MiMgQgN7Mh0WMi00=gN7MgMgP01GMi2gMh4GMg00AgN7Mi
MgUgN0YgM`03LgQcMg=h009cN004LgUcN7=hKgP2LgP00g=gLgQcN003LgP2LgL017MgLeMcEgMg1G=G
0W=g1g=H00=cEg=HLeL00g=G0WLf0W<f0W<e00]c56lDKaAZmF[DJ]5^lE9B9<P000P0008@H@<@@003
444@HA1P008@@004340<@@a13402344010Q1344<HA1Q0a1R0Q1Q00d@H121584@@0a0464DPQRT5:<D
PQB36:<DPP0358<358801AAR464DHQRS5:<00QB200<@PQ2148400Q1Q00<@HQ1Q48800Q1R00H@H@aQ
468@PQB25643468346424684588248800a1Q468<H@0246800a1Q564DH@02588011RR588DPQAQ0a1R
00@<@A1R488DHP<@HPD@H@8@PP8DPP8DX`0948<@HA1P340DH1c26:8@HQ1Q008@H006464@HQ1Q364<
@0a12A1Q00@@PQ1R468@HP@<HP03364@HA1Q00D@H@05364@H0aP360@H@03360010a0440@@11P311Q
0QAQ00DLXQAQ464@H110008@H@<@H0D@H@07468<@0PP364@H@`P34000PaQ00`<@@a0444@H@aR348<
@@a0344<H@aR3643344246423400211Q340<@0@P2408@@aP364334001@aQ468<HPaQ34400Pa000<<
H@aR36800PaR0Pa100H8@@aQ2648@@Q0244336400`a1364<H0013480000?344<80PQ244<@@a23208
0112<BE>C5j^G]5JT5Y`009JK`03FW1JLEYa00AJL@INT003GXmNT5jA00UNT@9NT005HY1NT5j@GY5R
/@06GY42GY804V:BHY=R]6:cH[9VdD6/:>PHHa11:<@eIcgYCTXiQbcU688HX`8Pa@0>7:@HY1BT3688
@P00100HY3VZBRdmbac5000400880007100@HBe6?JPiIcEX=HP00T8<00/mbBC7000001bVBU5S3V;>
I_5RdF;C009Vm09_=P0:LeMgMgMhMgI[4VJ^DP`mRBBT100400002aaP>DAF2FZ[K_5gEGMFMgMc=FlD
Ja@01V[d1FlD0Vkd0f[d1VlD2VlE0VlF16lf0flF01]_=VmFKeEgMVlfDLd/QB13?FU_<GNHNkUcMg]h
LeMZlV:@DN]Abe8=HY5[4g=fMgI_EW=FKcH00Vlg0W<f00A_=g=GLcIc=PEcE`03KeM_F6mH00=_F005
KeMcEg=GLeM_E`03LeL2KeL4LeP00fmHLeMcE`03LeL5LeP00g=gLeQcF002LeP08W<gMgIkVGMgDNlT
R337?DTmK2BV200<81AR8>DiZ478>HPaB2C57<DDY0aR12440@@Q2248@@a2468@Pa1S468@HaB40QB3
00<DY1RU5:@00aBT00<DXaB358<00Q1R0Pa101L880PQ348DY23U<FLmZ2dV7<D<HP@P340L`C5W8>D<
80@0000<03ETGXYRbeI/009FB`05EVYJJEYYFVUJBP03FT/015Y:FVUJJEYY0Ui815YY015JJUY;FT]J
BEY;FTUNBF:/I]1[4VldMcEgEGMfMgMgUgMh00MgM`03MgUgN7Mh009gN@03MiUgN7Mg009gN0AgN@04
MgQgMgMgMgL5MgPAMgL3MgP01GMiMeQgN7MgMgH02GMg17=g00=cN7=HLgP00g=h0g=g0g=h00=gMg=g
MgL02G=G00QcMg=HLeQcF7=GLeQcEg=H17=G00=gEgMFMcH00W<f00i_=W<eKcE_5FlDKa=Zm6[DJ[9^
d46<46@000P00P`P0Pa000<<80a044000a1P0Pa000L<80a0340<@0Q0344<H@024642564031B1588H
XQRR684@H@a0464DPR466:<DH@8DP`05588<@@Q0344@HP025882568258801ABS588@PQ1R34000a1Q
00@@PQB2488@HP8@H@03344@HQB3008DPP@@HP8@H@04468@PQB24882464246000a1Q584@P@034640
1AAQ464DHQB268800QB200<DHQ1R46800a1R00<@Pa1R46800Q1R1a1Q0a1R0QB200H@HA1P320@H1RQ
4842464020a0464DPQ1R464<80a0444446401aB1488@PQ1Q484<HA1Q00D@HP8<H@8@H004340@H11P
460846400a1P340@@00346000a1Q488@H@0244401@aQ344<HA1Q48801a1Q00L@H11Q464@H110460<
H@0646401PaQ368<@@a0344<H@8<@@8<H@05360880PP344<@004364334400a1Q468<H@0334022202
340336000a1Q460<H00634000a1Q58<@PP033643344010Q12408@0aP0`aQ00<<@@PP34000@a10003
344010PQ324<@A120PP000PHHCf7FXmN[EZ`EW1JL5Y_1EYa00AJL5YaFW1JT@ANT003GXmNT5j@00eN
T@04H[9N/EjAGY83GY45GY82HY805EjBI]=R/59?@L`PQ0@0000@@be9@N]6;SV::>@Pa2358<HLaABU
38<<H`0200001`a1<DLmk3g<?NdeIa1100840005200000007<DeIP02=FL063UW?JU62d7Z=J`HQ@00
100]JUJ_Ke=[46/BJaAcEWMgMgQcEflfH]9FL47]<BPHH@@0000<200PY3V;BPmN/F/BLeIkV7MhLcI_
5F[d0V[c00=Zm6[cJ_@00V[d00=Zlf[dJ_@00VlD0V[d00E^m6keJ_EZmFlE00M_50U_5@05KaI_=Vlf
KcI_=@02KcH06VlFJaI_=VleLcIcEgNJJ_<mJB13:89F2VLELgIkV7MgMeIcEV[dI[5F34g;CLYNT6Kc
KcD2LgP00fmGKcM_=`06LcH3LeL00fmGKeQ_F005KeP00fmGLeMcE`07LeL3LeP00fmHLeQcF005LeP2
LcP2LeP017=GLeQcF7<h0W<g01IkMgNJJ_E=cCU<DPiV[dh`;>HL@QQS7:@Pa1cU7<@HP``P200<80a1
46<<H`8<@P0736<@Ha1R46<DPaBT6:@00aRU00<HY1RU5:D00aBU0QBT1AB3018@Pa1R34888@@0220D
Y2DX;HTYB2UX8@H@H@PP6:8U1Qd746<200001BCSDTQN[59<ET`00UI;00IFBUIZEVYFJeI;FV/2FTX0
0eY9FVYJB@03FTX01EYZFVaJBeY;FT`00UY/00MFBeY;GTURS6K@J_9_=@02LcH00gMfMgQgN003MgT0
1WMgMgQgMgMhMgMgN@9gN005MgUgVGMhMgQgM`02MgP5MgT2MgP00gMgMgQgN003MgP;MgL00gMhLgQc
N005MgL00g=hMeQgF002MeL00gMFMgMgM`03MgL3LgL00g=hLgMcM`05LgL4LgP2LeP3LgP4LgL7LeL3
LgL00g=HKeQcF002LgP017=HLeMcEg=G0WMF00AcEg<fLcIc=P9_=P0BKcE_5FlEJa=Zm6JcJ]5^[3e9
104000PP340@H0aQ444@HA110Q100Q1Q00<DPQ1Q46000Pa000@<H@aR364<@@8@H@0D588L`aR2488D
PR34584DHA1Q564DPQS55:<DHQ1R568DHA1Q344@HP<DPP8DP`0946<@HQ22588DPa22468@HA1R00<@
PP03468<H@a100<@HP0948<DPQ2248<DXaRS588@HQ2200<DPP05568@HQ22588@HP06464011B1468@
HQ220QB20Q2200<@HQ1Q46800a1R00@DPQ1R468@HPH@H@H@HP8@H@0;340@H1B2488@HQ226:<Ha1B3
468@H@02444246400`aQ464@H@0258801a22464@HA1Q364@HA1R008<HP0:364<HPaQ460@HA1P440@
H0a0460246434684464246800a1Q440<@00246400a10444@HP0446801Q1Q368<H@a0364@PP<@H@03
364<@@a000@<H@04464@HQ1R48<2368234401`aQ368<HPaR48<@HPaQ00<<@@06364<HPaR364<@@a0
0Pa100D<@0a1344<@@aP008<@008320<@0aP460<H0a0364<H0L<@0@<H@03464<@@a100<<@@8<H@03
360<HA2200<<H@4<@04<@@000`a100`480@0224800`0200<02cSBPaN[5j_EW05FW02FU02FW06GY00
0ej?GY1NT@0;GY43GY08GY401ejBGY5NTUjAHY5RTV:A009VlP03FXe1kAb50080000G104TaCf/AP`e
QbTU7<DLaQSW5<DDY@@Q00000ARV?LTmbcV[>JXiQbCU4444000300006AAR;DD]IS5W=FLiQcfW@NQ2
2cfZ56<000a1BP][;gNBKc5[4fK?I/eNKDG;<>DPHA0000<00007200L@33SALURJfl?Lc@00WMg00Ac
EflgKaI[5@aZm09^m003K_=Zm6kd009^m09Zm@03J_A_56lD00U_50M_5@=_=@04KcI_=FlEKcD4KcH0
6W=gLeANKc48848XaDh<Ja9kV7^FKcEgEWMGKa=VdUX^DLa9c5H^I]5_EW=gKeM[=fmGKcL2LcH01W<g
LcIc=W=FLeMc=P9c=`=_E`04LeM_F6mHKeL7LeL2LeH2LeL00fmHLeQcF006LeP00g=GLeQcF006LeL0
57MGNgMcN6:cFRmF;ei/J/UFCT6:=@Ha22SU6:8@@P`R224<@A12344236801a1S58<DPaB3488DXaBT
008HY@8HY0036:DHY1RT00LDY00358@DPaB300<@H`<@HP0F344400@0244DXb45;HPiabTW58@801RR
9BPLa@@1000HXTX6GXaFC5I;FTX3ET/3FV/00eYZFVUJJ@03FVT015Y:GT]JJeY[0eY<00eJK5Y<FTaJ
C5Y;GTURRVK?J_9[5FlfLcMgMP03MgT00gNIMgUgM`03MgL2MgP7MgL017MhMgMgN7Mg0WMh0gMi0gMg
0gMh2gMg0gMh0WMf0gMg00=cN7MgMgL00WMF00=gMWMgMgL00WMg2g=g00=cMW=gLeL01G=h1W=g0g=G
0W=g00AcEg=gLgMgMPAcM`08LeQcEg=GLeIcEg=FMeIgE@9g=P05LcIg=G<eLcE_=@02KaD02f/CJ_=V
/Vk@JZX`i@01100<@0aQ46000Q1Q00<@@A1Q44400Q1100<<H@a134000Pa00PaP0`aQ00H@HAAQ564H
PAB1464256802AAQ464DHAB16:8DXaB3588DHP03588258<3588258<01a1S58<DPQB25:<@PQ1R00L@
H@03344<HQ1R00@@HP06588HY1RS588DPA1Q0aAQ0a1R00H@PQB3468<@@PP3403464246801A22588D
Pa2248<00Q1R00H@HA1R468@HQB1468846400a1R564DP@0246400a1R464@H@0246402Q1R58<DPaB3
5:<DPaB2468@HA110a1Q00<<HA1Q46400a1Q00D@H11Q464@H0aP008<H@04340880@0340446023200
1Q1P464@H@a0244<@0<@H@03360<H@aQ008<@006460<HA1P320880a10PaQ00`@HPa1344<@@Q0220<
@0aP464@PA22364334001@aQ468@HA1Q44001@a10`aQ00D@H@aQ468DPa1Q00D<H@04344<H@a13402
344434000a1P364<@00234001Q1Q460<80`P340<H0H<@006220<80a1364<H11P0Pa00PPP0PQ100<8
@0aP26000`aQ0PaP0@a100003`a1348<@@Q224488@`Q200<00P0668iIeI]G/mFK`02FVl01EY`FW5J
TUjBFY400UY`15j@00=NL5i_GXh00Uj@2ejA00ANT5i`GY1NL@MNT@=NTP9NT@9RT@07I]5[56LDHcI>
DBT820000P0001@LYCEY=L/Q9acW7@THibDX;DT48@00028QBSg;?J/i[3F:=JTeZR340P@001L000@0
100La2fY;FHeQcV7?JQ5jDi_BRh]B@a3000TiDi`DY5>LCg=;BPLH@@000@0000>500TXcE8ANeJKV/D
LeEgMgMfMeIc=VlEKaI[5@aZm09Zl`03K_=^m6kc00=Zm004K_AZmFlEKaD5Ka@7KaD00flDKaE_5@04
KaD016lfKcE_=Vle0flf01e_=FlfKcIgMgMhLeMJCRR376<XiUH/LeIgMW^GMeIkEG]fMeMV/EH<DNa=
ZEH<HY5[57=hLgUgN6mG009_=`04LcMc=W=GLeH2LcH4LcL01FmHLeM_F6mHKeL00W=G0W=F0g<f17=G
2G=H0W=G00=cF7=GLeP00W=G019cN7]hNiU_EfKDGY9JD5YbGY5Vcej=EReJCdW^=DPDHPP0468248<0
212448<@Pa2346<@PaB358@35:@96:@65:@258<01AAS46<@Ha1S46800PaR01D<@PQ1224880aR5:@Q
1RDX7<DD@AAQ5:<HY0a2000@@4GTGZeJK5I;FTX01eY;0UYZ0UY900=JJEY:FVX00UY[1EY<00aJBeY<
FT]NJf:<HZmVlV/DKcIcEgMgMiT2MgT2MgP5MgL3MgP5MgL00gNHMgQgN004MgP2MgT00gMhMgUgM`02
MgP00gMiMgQgN@02MgT7MgL2MgP00gMgMgIgMP03MgL3LgP00gMGMeIgM`02MgL2LeL2LgL00g=hLeQc
F00:LgL4LgP8LgL3LeL9LgL5LeL00gMFMcIg=P03LcH03VlfLcE_=FlEJaAZlfKCJ]=^dFZ<98<400PQ
4602440546400a11344<@@0334001a10460@HA1R488<HA1Q008DH@06464DHA1Q320<@1AQ0aB200@L
a1BS588DPP8DXP055:<Ha1c46<@DP`0358800aRS5:<DP`025884468346401aR2568@HQ1R488@HPa1
008DH@07344@HaBT6:<DPQ1Q34000QAQ00TDPA1R344<@A2258<DPQ2246800Q1Q00D@PQ1Q468@HQ22
008DPP8@PPD@HP03568DPQ22008@H@07468@PQ22488@HQ1Q46800QB100<@H@Q034400a1Q0a1R00D<
@A2358<@PQ1R008<@@8<HP<<H@<@H@08364<H0a0220<@0aQ360<@08<H003364<@@aP00@@H@03340@
H11P008@H@03468<HPaQ00P@H@8<H@<@H@03468@H@a100<<@P@<H@05340<HA1Q464<H@0222001Pa0
364<HA1R464@@@D<@@08368<H@aQ364<@@a2364@H@8@HP04364<H0a0340436401A22468@@0a03440
0`aQ00D<@@a0364@HA1000X<@005364@H11Q364@H00236400`a1340<@00234022404364136013440
0007348<@@a2248<@@PQ22000P`P00H80110:<=:25j^HZl2FVl3FU001EYaFW1JKeZ@GY0015Y`00IN
Kej>GXmNSej@GY42GY06GY47GY07GY403EjBGY5NTF:aHY1R/5j@I_AW4W<`HXdmQaQ10080000E200H
aAbT58<DQB46@NPY:0PR000HaSW]@PheZcE[=HXmbcVY>JHLXa1R00<0000;244YJ3g7=HLiZT7ZAP]:
CTi>=H/HYP0200000aB56:<4000400002@P0::4mI4WYGR]V[G<cMeEgEP02LcH00flfJaAZm004I_@<
J_@00f[cK_=^l`02K_<016[dJ_=Zlfkd0V[e00=Zm6lDKa@00flD00=_5F[dKaD016lE00=_56lEKaD0
36lE02E_5VlfMcIoMg^HMe=EjRB576<a:5Y/Le9kUWnGNgMoMWMEKcAVdUi^DPa=ZU7[FVmVlfmEKeI_
EfmHLeMc=g<fLeMcEW<fLcE_=P05LcL00fmHLeMcE`02LeL5LcH3LcL3LeL01G<gLeMcEg=GKeP00g=G
01Qc=g=GLeMc>7=GNiMkV7MhJaIV/eX_EReJ<5YcH]E_=f/CI/iV[UY_<@HDHa11588258<00a1S48<@
P`0358<258@35:@66:@01ARS6:@HXaRT5:@00QB411B30QAS0a1S0`aR00<<@Pa122400P@Q00h88A1R
588HXaAR2008811R100@@46RGZeJS5I:0eY:1eY;0UY90eYY00=JBUi:FTX015Y;00]JJUY/GV]NJej=
H[1VlF/CKcIcEgMg00AgN@03MgQgMgMg00]gM`04MgQgMgMhMgL3MgP3MgT017MhMgMgN7Mh1GMi00=g
N7MgMgL027Mg00=gMWMgLgL00g=g00AcN7MGMeIgE`=cE`04MgMcMg=gLgP2LeP5LgL2LgP3LgL017=h
LeQcN7=H1G=g00=gMgMfLgL017=G00=cMg=GLgL027=G00IcF7=GLeMg=G<fLcD2KcH2KcD02flEKaAZ
lf[cI]=Zm6[AERdTPPP032000Q1P0Pa000D@@0aQ464@@A1000<<@007440<@0a0440@H12246800Q1Q
0QAQ00<@HAAQ46400Q1Q00<DHAB258800QR200THXaS36:8HXAB1588Ha1c258800Q1100<DHAB25840
0aB100<DHA1R46801A1R00HDPA1Q468@HQB2488356401@`P344<@A1Q56400a1Q00hDHAB1464@HPaQ
464DPQRS588DXQRS6:8@PQ1Q0Pa100<@PQB148800Q220a1Q00<@PQ1R46400aB100<DHA1R48800a22
0QB100<DHA1Q46400Pa00a1Q010@HPa1224<@A22588@PQ1R368<@@aR364<HQ1Q340@H0D@H@03340<
@A1Q00D@H@04360@HA1Q468446401AB26:<DPPaR46800Q1Q00<<HA114640211Q00LDPQBS468@H@a1
220<@@0346402A1P440<H@aQ464<H@a0320<@00236401Pa0440@@@a0320<8@8<@@03364@HA1100<<
@@8<H@0;340<@@aP360<@0aP364@HA22464<H@0444433642340010a1340@@1102@a000D<H11P464<
@11P00@<H08<@004220<@0Q0340234413401460134400005244<@@aR348<@@0332402A10200<010P
=BABCUj<G]1FK`02FVl3FW0015Y_FY5JL5ZA0eY`00ENKei^GXmNSej@00INT@07GY1NL5j@GY5NT5jA
GW000Uj@15jA00=NTUjAGY800UjB0UjA00]R/F:AH[5R/F:AH[1Vd6[bGXi:;bT800<000840008200e
ZT7:58@401BT<FXn3`8mk@09>J`eRSV[@Na233h=8BP<Q@020080000:58<U9bfY;FPaJ2e8;FXU1aS5
224500002Q109>@eJTH>FXmZlVlBMeIkMgMg0W<e00E_5V[eI_AVm6Kc00IVm0QZm005JaE_5F[dJ_AZ
l`04J_@00flDK_=^m003J_D016[dKaE_5FlE0V/E1VlE00=_56lEKaD00VlE00=_5VlEKaD01flE025_
5VlELaA_5G]fNiEgETVZ744LPbd6DRa[=G=fNiQgMgMFLeM_=VKcHY5F34fYDN]F;F:aI_A[5G=iMgQc
EflgKeL00W=G0W<f1g<g17=G00A_EflgKcM_=`Qc=`AcE`0IKeQc=g<gLcMgEgMgMiQgNG=II_ENLEH>
EN]J2eY>GY9[>7MiKcEV[FkaCN`/i11246800QB311230aB300<@PaB358@011BT1QRT00<HXaRT5:@0
0QB41AB3111S00<@HPaR36800`a20108@PPQ224<8A1R46<DHP`0200480`P540mPUJ>EVaFBP=JBPMJ
B`9JBP03FTUJJEYY00=JBP03FTUJJUYZ009JJP0?FVaJJeY]FViR/6KaJa=_=VmGLeMgN7MiMgYgNGNI
009gN0EgM`=gN0=gM`03MgQgMgMh00IgN@9gN003MgMgN7Mh00AgN@03MgQgMgMh009gN09cN09gN0=g
M`04MgIgMgMgMgL2LgP00g=iMeQgF003LeP01G=GMgMcN7=hLgT00g=H00EcN7=gLgMcMg=h009cF003
LgMcF7=H00EcF0QcM`ecE`04LeQcEg=GMcH2LcD01W<fLcE_=FleKaE_509Zl`07JaEVmFKD@J/@@@@0
34400Q1Q00<@@A1044400Q1Q00@@@A10340<@@8<@004344<@11046024682464256400a1P468DHP02
56402QB1588DPAAQ584HPQRS7<@L`aBR11B200d@HAAQ588DPQR1560DHA1Q440<@0a1468@P`034880
3A1R464<@A1R488@HQ1Q564DH1AQ344@HQB2008DHP08468DPQRR588@HPa1368@P@8DPP04488DPQRS
58824880111R364@PQ220Q2300P@PQ1R464@PQBS58<DPQ22111R0Q2200<@HQ1Q46400QAQ00DDPA1Q
464<HA1Q00<@HP03368<@A1R00H@PP<@HP03464@@11Q00H@H@8@HP8@H@06484@HAB2588@HPaR0PaQ
0Q1Q00<DPQ1R46800a1R0Q1Q00D<HA1R464DPQ2200<@H@06440<@11R588DPa220Q1R00@@@@a0440@
H0<<@003464<H@aQ008<HP06364<@@aQ464@@A1Q1`a100L<@111464<H@a2344@@00234000`aP460<
H@0336424642440020a1340<8111468@H@aQ34033640111Q344<@@`P0`a000@<H11P460<@@8@H@03
364<H0a0008<H@0;360<@0a0320@@1B13608@@aQ340@H00136400005224<80aQ368<@P0432402P`P
200401AR?FIJJej]FXmJKeY^0UY>0UY_1EY`0UY_0Ui^00=NSUj@GY000Uj@00=NTEj@GW000Ui`15j@
00ANSej@GY1NT09NT@INTP9NT@9RT@0;GY5NTV:bH[9V/VKBKa=Rd4h]:@L88P03000031R3>FXTiP@0
000HQ35X?Ndmk3F[>Ja1c@91k@05@PdmkCW;9BT<A00210001@@P588DY1B322002@0000DU:E9]G_1_
DFlb009gE@06LcA_56[cJ_AZlfKC0fKD0V[d00=Ve6[dI_@00VKd1F[d16[e00AZm6[eJ_EZm@9Zm006
JaA_4f/CKa=^lfkd16[d0V[e16lE0f/E0VlE0flD00=[56lDKaD00V[d0VlD26lE021_5VlDOg=gE6[b
?J/HHaA276<mZV[`MgIk^7=gMgUgN7=FI_AVdUi`DNa=c4V/ERiR/V/DLeI_EW=gLgQcEflg0W<f17<g
0Vlg00=c=W<gLcL00fmG16lg0flf1Vlg00A_F7<gLcMc=`=cE`0GNgIgN6lfH]AFD4h>CNaJ;EX/FTeN
KejaH[5NKFk<KXa9ZAb2444@HQB248<DP`0348<258<246<258<021BS5:@DY1BT7<DLiAS45:<26:@2
6:<25:@00aB458<DP`0358<248<246<246800`aR348<@P04348010`Q344<@Q110Q1000P000@0560m
PeZ>FXaJBUYZ0UY:1EY;00=JJUY:FTT00eY90UYY00=NB5Y8FVT015YY00mJBUY[GViJKf:_I_5ZlVle
KeMcEgMgMgQgNGMhMgT00WMh1GMg0gMh0gMg00=gN7MgMgP01WMi0WMh00=gMgMhMgP00gMi0WMh00=g
MgMhMgT00g=i00EgNGMhMgMgMgMf00AgM`9cN003LgUgF7=I009cF@05LeQcEg=GLeQcN003LeP01W=h
LeQcEg=GMgMcN09cF003LgMcF7=h00=cF004LgQcF7=gLgL3MeH017=FLeMcEg=g0g=G0g=F0g=G0W=F
17=G00=g=WLeLcD00W<e00A_=FlfKaE_509ZlP09JaAVeFKE>DX40000200@@11Q00<@@08@H@03460@
@0a000@<@0<<8003344@@A1Q008DP@<DH@03588DPAB200DDP@@DPP0568<DPQB2588DP`0458801AB1
444<@A1R46401A1R00@DPQB3588@HP<@H@05364@HA1Q560@H@054682588021RS6:8DHPa2468@PAB2
48834643488246801122588@HQ1R0PaR00<@HQAQ588011B20Q1R0Pa10a1Q0Pa000@@HAB1484@P@8@
H@@@HPD@PP05468@HA1P464<H@0246401A1P464@HA1Q36000a1Q00@@HQ1Q484@P@8@H004484DPQ1Q
468246400`a0460@H@0246401@aQ368@HA1P46400PaQ111R0Q1Q0Pa00Q1R0Q220a1R0Q1Q00D<H@a0
440@@11Q00H<H@06368@HA1Q464@@0a10Pa00Pa100@<@0PP440@P08@H@04468@@0`P440346001@aP
364<H@aQ46400Q1P00@<@0`P220<80@<@006468@PPaR368<@Pa10`a000@<80a0360<@0<<@@04364<
@@a1364336001@a0320<@1B148400Pa10@a00@aP0@aQ000010PQ320<@@aR0Pa200`<8@PQ324<@@PP
000<02RRCRUJSUZ<FVd2FTh00eY=FVmJK`06FW0015Y_GViNKei_1Ej@00ENL5Y`FW1JL5i`00QNT003
GY5NTUjB00INTP03GY5NTV:a009N/P0>H[9V/VJaI]9[5FKACRl]21B5108002d88<H800800007200H
Y1c67>HPiRD7:BL00bT600<YBBD858@00P@000<800@010000P@00P00010800a1488Li2U87<D40002
=Ni[TWOhJc=ZlV[cI_=Vd@9VdP=Vd`9Ve09Vd`03J]=Zlf[d00=Vm0]Zm0=Zm@05J_A[5F[dJ_A_4`02
J_@8J_D00flEJaE[5@04JaD4Ka@2KaD00g<EKaI_5002Ka@00flEKaA_5@03KaD04VleKaEc4gLcMeEc
EV/eAL/H@A00500a258_KeMog7^jMiQcM`9cN00=I_ANT5H=DNa=ZU7/ERaNT6KdLeMcNG=hMeL00W<f
0g=G00=c=flgKcL00W<f00Ac=fmGKeM_E`A_=`9_=P03JaE_=Vlg009[=`9_=`=c=`=cE`09LgQgN7=H
I]=F;Tg]BNeFCeI>009JCP0;FTeJ;5H;GTaZK5W[>@@D@A0Q444DPP0258<248<00a1S58<DQ00558<2
5:@011BU6<HLiQS41QRT00<DY1B458<011B30Q230Q1S0Q1R00<<H@a234401@a20Pa10Pa000L@@0@0
100HXD76FXeJK002FTX7FT/4FTX3FTT2FVT01EY8FVUJJEYYFVX00UY:00QJJeY]FViRT6KAJ_=[=FmG
0WMG00IgMgMiMiQgNGMhMgT2MgP00gMgMgQgN008MgP8MgT017MhMgMgN7Mh0gMi17Mh1G=i0gMh0WMg
00=cMg=hLgP017=h00=cNG=ILeT00W=H00=cMg=HLeP01G=H0W=G00EgMg=hLeQcF7=g00QcF003LgMg
EWMF009gEPIcE`03LeIgEW=G00=cE`03LeIgEW=F009cEP03LeMc=WLe009c=@=_=P0@KaE_56[cI]9R
dfKDFW<`j@00100800a0364@HA104442464020aQ340<@0a0344<@0aQ464332001a11464DPABR588D
PAAQ00<HP@03584DHAR100PDPP04568DPaBT58<5588746801a22588DPQB2488@HA1R008@PP06464@
PA21484@HQ220Q1R00`@PQB1588DXaB2568@HQ22588@PQB256424680111Q364@HQ1R0Q230QAR00<@
H`b35880111Q00@@HQ1Q468@H@8<@@8<@009464@HPaQ364@PQ21488@PA1Q008@HP05488@PaB358<@
PP0446801@aQ460<H0a136400Q1Q0Q1R00<@HA1R46801A1R0Q2100H@HA21484@PQ1R3644464010a1
364@HPaR0a1Q00@<@0aQ368<HP8@HP04364@H11Q4684488346802122464<HA1Q460@H@aQ36823640
1@a1364@PQ1R36400a1Q10aQ0Pa100T880`P460<HPaQ360@@0`P44000Q1P00<@HA2248<0111R00<@
HA10340010a000D880`P340<@@a2008<HP8<@@05340<@@a1360<@0023602364434433643340010aQ
368<@@a10Pa00@a1000232000`a0344<@@02344040`Q344<@A10200401A0?H=BC6;;FVeFCUY>FTeJ
KUY_1EY`00IJKeY^GViNKeY_GVl3GY05FW000ei_GW1NS`02FVl015j@FVmNT5j@0UjA1ejB1UjA00eV
/6:@HY5Vdf[bG[1>D3V/7<LHQQB532<4000@000210004`P0320800@020088BT6@LQ1jDi:BT`eQa23
000UAV]=Jdm[4V:a009R/P03I]5VdVKB00MVd`9Zd`07J_AVm6[dJ_AZlf[CJ_<01V[d00=ZmF[dJ_@0
2f[d0Vkd1F[e00=_5F/EJaD00f/E16lD16lE0flD00A_5FlDKaA_509_5@9_500PLaA_57<dNgMgMW=B
DR`HH`@030<Xj3f/EY1_EG^iOmYk^WNIKeIVlfJbFTiAk4W:CL]B35Y_H[5Vlf/eLeMcM`9_F004JcM_
=flgKcL2LcL00flgLcM_E`02KeL2KcL3LcL01FlgLcI_=flgJcL00Vlg17<g00YcEg=gNiMgN6lfI]=F
;dV[CNeFC`=JCP08FW1RSeh[DLY=be7;>>@HHP8<8009444DPQBS58<@Pa1S368DPaB400DDP`8DY0<D
Y@8DY0DHY0035:@DQ1B300@DP`0448<@Ha1S46<23680111Q444<@@a21Pa10Pa000T@@0P0200ThdhX
GXaNJUI:FTX01eY;00AJJeYZFTYJBPIJB@=JJ@0>FVYJBUYZGVYNK5j>H[1VdF[cKcE_EgMGMeIgM@9g
M`06MgUgN7MiMgUgN7Mg17Mh1WMg0WMh1WMi00AgN7MfMgMgM`IgN0=cN006MgQcN7MhLgQcF7=h0gMg
0g=H0g=g00=cN7=iLeP00W=H0g=g00QcF7=hLeQcN7=gMgIcEgMf0W=g00AcEg=gLgMcM`EcF003LgQc
MgMF00AcEP05LeMcEW=FLeIcE`03LeH3LeL00g=FLcIc=P04LcH017<eLcA_=Fle0Vlf00e_5FlDJ_=V
dfKDI[=><BS8100800a0344<H@05440234001`a1220<@@aQ488@P0a0008<8004340@H11Q58435880
1QAQ684DPAB1564DP@@DPP07568DHAAQ464<@A1Q48801aB21a1R00<DPQ2246800Q1Q00P@PQB2488@
HA21584@HA220Q1R00<@HAB158400aB20Q1Q11B200<@HQ2146400`a100<@HQ2248<0111R00DDPAAQ
468<@A1Q00<@HP8@H@03344@@A1Q00<@HP03488DPQBR008@P@05360@HA1R488@P`0646801PaR240@
HA1R368<H@@@H@D@HP0;46<<HPaQ484@PPaQ340@PAB2464<@00246404Q11344<@0PP344<HPaQ464<
@0@P220<HPa2368<@0aQ464DPP8@H@8HX`0=488@HQ2258<DPQ1R364<@110320<HQ2346400Pa00PaQ
0Q1Q00<<H0aQ46800Q1Q0PaR0PaQ00@<@@`P320<@@8<@003440<8110008@@006364@HQ2348<<HPa2
0Pa10Q101`a000H<@@PP220<@11P44043403360010aQ344<@0a00`a100<<HA1R340010a100<8@@PP
22000Pa0000020a0320<80PQ324<@@`Q344234802a11220400P0:>=5jEj<HZiFCeI>FTh00UY?00=F
CeY_FVl00UY`0UY_00=JKUY_FVl00Ui`15Y`00AJLEY`FW1NK`9NL09JL0ANT09NT@MNTP=NT@9NTP0;
GY5RTF9`IY5RTFKAIa=NdDXa8>PHYP0258@00a1234480003100700006@@0224@PaRT58<<80P03248
@@P0100<8AR4<BQ234H[BThn2b4Y000<@DX8H/aR[V:?00=R/P=Vd`9Rd`AVd`9Ve004J_AVm6[dI]@3
J]<2J_@00f[cJ_AZm005J_@3J_D9J_@3J_D016[dJ_E_5FlF16/E16lD00E_5F/EKaE_5FlD00=_5@=_
50=_5@0TKaA_5FlDLaEc=W^HMiQcNEYa;@T<0@0054@Y:TX`IeQcVG_JMkUk^GNHLgM[5FKCGY5F;U8<
CNYB2e8]GY1Vlf/eLgQcNG=H0flf0g=F00=_EVmGKeL00VmG0Vlg00=_Eg=GKeL00W=G00=_EfmHLcL0
0W<g0Vlg01]_>6mGKeQgN6miI_AF;U7/BL]JCeI?FTiJ;EI=H_AV/E7<@FU1BCSV98@<00@0440@HQB3
5:D00aB300D@HaBT8@LPiAB3008DHP0958@DYA2448@<I0aS46<@Q1BT008HY0<DY00358@DPaB300<D
P`0348<@Ha1S008@H`03368@H@a2008<@P<<@@<<@P8<@@07440800009@=>:6J[FVX015Y:25Y;00AF
BeY:FTYJBPEJJP0?FVUJJeYZFVYNJEi[GViR/6KAJa=[=VmGLeMgEWMe009gM`06MgUgN7MiMgUgN7Mg
0gMh00=gMgMhMgP00WMh00IgNGMhMgQgN7MiMgP4MgT017MhMgMgMgMg1WMh2G=h0gMg00=cN7=HLgP0
0g=g00=cN7=HLeP00W=H0g=g17=H1G=g00EcEg=HLeQcF7=g009cF0=cF@03LeQcMg=G00EcE`07LeIg
EW=GLeMcEWMFLeH017=G1W<f00Ag=G<eKcE_=@=_=P0:KaAZlfJaJ]=V/ThA98P400`P340234401A11
440@@0a144000PaQ0Pa110aQ0Pa000L<80a0340@HA22588DX`06588011B1588DPAB10aB20QAR00`@
HQ22488DPQAR588DPaRT6<@DXa1R464346801@a1464DPA2246800Q1Q00H@PQB2588@HQ2248424882
46801a1Q564DPAB1588DHA1R00DDPP<@PP8@HP0<368@HQ22468@@Q11588LXaB1468@Pa1S0a1R00@@
PaB3468@HP8@H@8@HP065:<Ha1S46<8DXQB00Q1Q00@@PQ2348<@P`D@HP04368<HA1Q464236454644
46802@aR220<HA1R464<HA1Q484@PP0246401111464@HA1R0a1Q00L@PQ1Q464<@@00340@HP023442
3642464258800a235:@DPP0246400a22468<HP0234001A10460@H@aQ46400Q1100@<@@a0364@H@8<
HP03488DPa23008<HP04488<HA1P320334400`a0360<H0023642344336800`Q1220<@00534002PaQ
468<H@a0440@H@aQ340<@A110Q1010a000<@H1B236800`a10PaQ0`a100D<@0a1344<@@aQ008<@@4<
@04@@04@@00000D880`P200880a0008<@@@<8@08220800P0440a0U8YHZeNK`=FCP=JC`9JK`03FTmJ
KeY_00YJK`ANK`=NL003FW1NT5j@009NT0MNT@03GY1NTEjA009NT@04GW5NTF:AHW02HVl02f:`Ja5_
33UY56<801117:@Y1BdU:@D00R350R3U0R3500lTaBST:>DXiBT5;BLaJ3g9:BP<8@@0320DPQB33480
0P0000l801RT;BDaQSgX:DX00@00>HEN[f;>FViNT5jAH[400V:b0V;C0V:c0fKC16KD0VKC1F[C00=Z
lf[dJ_@04F[d0V[e0f[d1VlE1FlD0flE0VlD0VlE0VlD26lE011_5VlfMgQgV7MgJ]A=kab700000A0S
<BU:3F;AMgIk^@9ofP0BNiQcEVKcH]5JKeH]CNY9bDW8DP]JC6:`I]9[57=FMgMgMW=f0WMF00McEVlf
KcI_EflgKcIc=P02LcL3KeL2LeL3LcL02flgLcMc=g<fMgQcN6KeFW5=kDg/DRh00eY>00eJKfKBI_=N
Cd6<?BXdj2RU404<0112568@HP0246<248<04QB348<HaS6:9@LDPQ1R448<@a1T58@<H`Q336<@Q1B5
6:DLY0<HY0<DQ0@DP`8@P`<@H`03368@H@a200H<@@0;3488@Pa2348<@0@0000LX4X6GX]JJP04FTT2
FTX6FT/00eY[FT]JB`02FT/01EY[FVaJJUYZFVT00UY900aJB5i7FRQJC6:`I]5[56lfKeMcEgMFMgD2
MgL01GMiMgQgNGMiMgP01GMg2GMh00=gMgMhMgT00WMi00=gN7MgMgL00gMg0gMf1gMg0g=h0gMg1G=g
1g=G27=g17=G0g=H00McMg=HLeQcFG=iLeUcF007LeL017=FLeMcEg=G0g=F17=G1W<f0g<e0fle00U[
5F/CJ]5V[fJ@J[91[Q1500000P`P0Pa00a100Pa000H<HA1Q468@H@aQ464534001`a1464@HA2258<D
PQB1008@H@@DPP03584HPAAP00<DPP08568DPQB2588HXaB2568DP`<DPP03584@HA1Q00@@HP08444D
HAB2468@HAB1588@PP@@HP06588DPA1Q468@HAAQ0QB121B200<HXa2246800Q1R00X<HQ1R488@HQ1S
468DPQRS588@HP8@H`8@HP0348<DPa1R008@HP<@H@8@HP09588DXQB1480DP11P484@PQ1R008<HP<@
HP06464@HQ1R468@H0aP211Q10aQ0Pa000@<@@aR468@HP8@H@8@H0<@H@<@HP0<488DXaRR464<@PaR
464DPa1R368<@@aP0Q1P00@@H@a0344<H@<@H@04340880aQ464346000a1Q488@H@02444236400`aR
364<HP02468236400a1Q364@H00246001``P220<@@a1340@H11000<<H@05344<H@a12248@@022202
34000`aP340<@00434001110584DPA1Q0a1010a000@@@11P584@PP<<@@8<H@03344<@0a00088@@8<
@@05340<@@a1340@H00132000006340<80`P320<@0aQ10a100X@@P`P340880P06651Qej@GXiFCPAF
C`EJC`EJK`03FTmJKeY_00=JK`INK`9JL09NT0aNT@04GY1NTEjAGY42GW401V9aHViVd6lBFT`/`P84
000<664/hd6X?LXeQcUX>HXiZcV9=FTiRCV;0cf[00dmRSV:APe1jReX220000`P8<@eQbV96<D<8003
00000a238@HDQ@02000023V6H_9VkVKaH]5N/EjAG[83H[82H[<00f;DI]=Ve006I]<3J]<3J]@:J_@5
J_D7J_@00flDJ_AZm@02J_D00flEKaA_5@05Ka@3KaD2Ka@;KaD4KaH097MFMgMkNFlhI_M1[A@12004
01PR<BUB;f/gMiUkfW^iNkYk^GNHKcEVdUi`EReF;57YCJM=aeH;GViVdV/eLgMcN7=gLeM_EP9cEP=_
=PAc=P=cE`04KeMc=W<gMcL2LcL027LfNeIgN6/DFW19kDW/CR`2DRh035i_H[1_5FKcFU11[CU[=@PT
YAA3100@@@D@H`<@P`0@36<DYBU:7<DDPaAS468DPaAS46<HaRDX7@PHaARV8>L27:@26:@00aBT58@D
Q00458<248<00a1S36<@H`0336800`a2344<@@0334402`a2344<@A11464<80P0781>1eZ/FV/00eY:
0eYZ15Y;00=FBeY[EV`00UI;0UY;00AJJeY/FT]JB`9JJP0=FTUJB5iWFTUNK6:`I_9[56lfKeMcEgMF
MgL00WMh1GMi0WMh0gMg2GMh00=gMgMhMgP00WMi00=gN7MgMgL017Mg0WMf1gMg0g=h27=g00=cEgMF
MeH00WMF00=gMg=FLgL01W=g1G=G0g=H00=cMg=HLeP017=H3G=G00=cEW=GLeL00W=G00=c=g<fLcH0
1G<f00mc=FldKaA_=F/EJ_=ZdFlAJ[1RKcE;004000`P34000Pa10Q1000<@@A1034000PaQ0a1Q00<@
@@`P44000`a000D<HA1R468@PQ1R00@DPP03568DPQB2008DPP03584DHAB1008DPP8DHP03588HPQB2
00DDPP03568@HA1Q008@HP04488DPQAR320246401A1R588DPAB258400Q1Q00H<@A1Q468DHQ1Q4682
46401A22588HXaS36:<00aB20QAR00DDPQB35:<DPQ2300@@PP0348<@PQ2200<@P`0446<@Pa2348<4
4684464010a1464@HQ1Q0Q2100@DPA1Q464<H@8<HPL@HPD@H@07340@HA1Q464<@A1Q56400Q1Q00D<
HPaQ464@HQ22008@HP8@H@8@H004364@HA1R4883464248824640111R5:<DPa1S0a1R00H@HA1P340<
80PP3442464011AQ440@@@a00a1Q0Q2200@@Pa1Q444@H@@<HP06468@PPaQ344<@11Q111P0PaQ00L<
@@PP220@@A10464<HP0534400`aQ360<H@0234000`aP364<H00434001a10484@HA1P464@HPaQ00<<
@005440@H11P460<H@02344010aQ344<H@a10P`P00D<@@Q0244<@@aQ008<@@4<H04@H04@@00000@<
@0`P32088088@0<<@@0@348<@@a1460880@0200X`dX<I/iNSeYaEU5JD5Y`FVl3FTl4FVl00eY?ETiJ
C`05FVl6GVl3GW0<GY0015i`GY1NT5j@0eia00ERTVJ`La1RKD6600880004664XXSE5?JL2@LX01T7;
?J/iRSf[@La1b`8mZ`=1c00>ALa9jTi;<DL<8@00660mHdh[?P/mbS55:><HP`<0000>208000008<A:
2fK>J`i_<V/CI]=R/V:cI]=R/P9R/`03H]ARdfKC00IVd`=Zd`04J]AZdfKDJ_<4J_@00f[cJ_AZm009
J_@016[cJ_AZm6[e16[d00AZmFlEKaE_5@]_50Y_5@03KaA_5FlE00=_5@0VKcEgEgMgMgMkMUia<@T<
0P00100D8c4XCPaVlGMfMiMofWojOkUgMW=EJaARdEY_DN]AjU79DNYB35Y>H[1VdV[cJaAcEG=gMgIg
E`9cE`03LcIcEgME00Ac=P03KeIc=W<g009c=`09McMc=WmeLeIVdTh<ALaB;E8;009B300<J]5gDf[a
HY11[3DY9:HD@``R324@@Q1R1Q1S0Q23010@Q1BT8>HHY1B368@HY2D68@LHY1cV<FP]RBU87<LLY@8L
Y0<HY0055:@DQ1B356<@H`0258<0112346<@Ha1S0PaR00<<@Pa134401`a100P<HA1Q340<82B0DRQR
c5Y[0UY900=JBUYZFTX00eY900AJJUY[FV]JJ`=FB`04FT]JBUYZFV`2FT/2FV/02UY9FTQNJ5iZHXaR
[f[bJa=cEW=G0gMf0WMh1GMi00=gN7MiMgP00WMh0WMg1WMh00McN7MgMgMgMg=hMgQcN007MgL2MgH8
MgL9LgL00g=GMeIgEP02MeL2MeH4LgL8LeL2LeP6LgLDLeL00g<gLcIc=P04LcH03g<eLcAc<flCKaA[
56[cJ]1^kf[?FTha:@00100@@002464010a1440@@1100Pa000L<@@aQ364<H0`P220<800334000``P
460@H@02468021B258<DPQRS588DHA1Q4683464031AQ584HXaB2464@HQAR464@@AAR688DP@8DH@03
468@HA1R008@PP8HX`03568<@0`Q00<@H@<DP@<@H@04468<@@a1468234400a1Q488DPP05588011AR
468@HQ1R0Q1Q00@HXQBR488<@08@H@03488@HQ1R008@HP03364@HQ23008@HP04464<HPa122034640
11B3468@HQ1R0Q1Q00<<HA1P46400`a100D@HQ1Q464@HA2200<@HP03444DHAB100D@H@8<@003460D
PAB2008@HP04364@HA1Q464248800a1R460@H0023403440011B0464<H@aQ111Q0a1R00<@H@aQ3640
0Q1P00<<80P03200111Q00@@@0a1344<@08@H@05364@HA1R464<@00336400`aR464@HP0236401@a2
344@HA1Q46000Q1Q00<@PPaQ36400`a100<@@A10364010a10Pa00`aP00D<@0aP460@H0aP008<@00;
360@H0aP360@H0a0344@HQ1Q440<H@0346000`a0220<@0083402220324000`Q1340@H00134000005
344<80PQ2448@002244334402`a2368<H@aR22000112=DQFKf;AGY000UI`00AJL5Y_FVmJKP=JK`04
FW1NTEj@FW02FVl2FW02FVl5GVl4GW0025j@GY5NT5j@GW5NL5iaGY04GY43GW409Ui`GW5NLEi`HZmZ
lFZ[CN`TH000960eAT6XAN]1bD7:@Na1kDH>BS1>;dX>APe5kDX>BRiB;Th^DPe>2eI<?JX@HP00:<55
YEI]CVl2@N`01T7<<FXY222T56<@@P80000<100DHRCS>HY63UZAH]=[56[dI_=VlV:b0Ujc00=Re6;C
I]<026KC0fKD00=Zdf[cJ_<026[d00=VmF[dJ_@00V[d00=Zlf[dJ_@026[d0flE2FlD0f/E46lE00Qc
EWMhNiUkVV/FEU4a:@@00P0000L@02C6@LeJ/VleMgQgU`02OkX04g^jMgQ_=FKAHY1J;57ZCLU=b57Y
DN]JCEj@I]5ZlV[cLeIcN7Mh009kN006MeMgEWMEMcEc=W=G17<g0W<f01EkE7=FH[99jdW]CPeB34g;
FTiZlgMCIXi9cBcV66<88PP1224<@A1S46801a1S00<<Ha246:@00QbS010@@1AR8<E1bS5X7<@LaBTW
;HXQ1aS66:DLY1RT58@HY@<DY0DDP`8@P`8@H`<<HP04348<@@a1344234802`a134888@a2344<@0`P
;<1>9eZ<ET/015Y:00=JBeY:FTX00eY;00=JKEI<ET`00UI;00=JBeY:FT/015Y;00aJJUY9FTUNJ5iZ
HXaVcfKaJa=_=G=FLeD2MgD2MgL00gMhMgUgN@04MgT5MgL7MgP3MgL2LgP00gMhMgMgM`04MgL2MgH0
1GMFMgMgMg=hMgP00WMg0g=h00=cMg=hLeP00g=H0W=g00=cEgMFMeL00WMG0WMF0g=g2G=G0W=H0g=g
3W=G0VmG1g=G00=c=g<fLcH017<f0W<e00ic=6lDKaA[56[bJ]1ZcfJ_DRhXiP@1224@H@aQ0Pa100D@
HQ10440<@A10008<H@<@H@0:364@H11P460@@0a0464@HQB2568458<00aB2344@H@0446400aAQ584D
XP0258800a1R464DH@02568011B2684DPAAR0QB20Q2200<HaB3U7<@00aAR0a1R00LDHAB16:8DPA1Q
440@H@0246800`aQ464@HP0346401Q22464@HA1Q468@H@8@HP06364@HA1Q484@PQ1R0PaQ00L@HQ22
488@HQ22588@H@044680111Q468<HPaQ0a1Q0Q1R0Pa21A1Q111R0a2200@DPaRS58<@HP<@H@03584@
PA1Q008@H@07364<80`P464@PQ1Q46800Q2200D@HA1R468DPQB100<@H007340<8111440@HA214640
0Q1R0a1Q00@@HPaQ2408808<H@06460<H0PP220<@0aP0Q1Q00@<H@aR368<HPD<H@03344<@0aQ00L<
H@8<@@08364@HA1Q464@PQ1R464<H@<<HP06468@@A1Q344<@0a10PaQ10a000<@H@aQ46400Q1P00<<
@0a1364010aP00<@H11034000Pa100<<HA1Q46400a1P0PaP0PaQ00T<@@a0340<H@a0320880a03680
0`aQ0@aP0@a00@a1000020Q1324<8@Q134488@`Q344234003PaQ340<H@aR444800@178=1bEj_H/iN
SeY_FTl2FVl2FVh8FVl3FW07GW02GY03GY42GY001EiaGW1NLEj@GY400UjB00ANTEiaGY5NL@=NL00<
GVeZcV[=GRX`X@00520i8dh:HZaN[E8/0T7<00=63DG/@N`014G]01563DG]@Na5k4G;BLYBC3f[4480
02RP@HA>:SgZ?N`mc3g;00<iZ`03?JTa9A1100H0000<884e9D6ZFTeVd6lBI_=RdeZcG[=RdfKC0f;C
26KC0f[C00=Zlf[dJ_@016[d00=Zlf[dJ_@01F[d0f[c0f[d0Vkc3FlD0f/E1FlE00=_56lEKaD02FlE
00Uc=g=GMgQkVG]gLc=B;Bd830800P0001D80224=DM=jf:=I_9cEW^iOoYofGniMgM_56:aHY1NKUH;
CLY5ZDg:DP/00UI<00QJKf:bI_=_=G=gMgQgMg]g0W]F00=gEg<fLcL00W<g015g=WMFNgE_5EYaBNa=
k4W/DNaB36:?K_5^cUG[?FXTYP`R00880007468DHQ1R488@Pa1R3680111S00d<Ha1R6:<Pi1c2560@
HQRS9@D]9b3T68<HY0036<D00aRU6:@HY0026:D45:@021B458<DPaB348<@PQ234682368234800`a1
364<@@0434800`a3348@HP02320013U0DTMJRUI;25Y:0UY;0eY<0eY;0UY:15Y;00eJJeYYFVUNJ5Y8
HX]R[VK?J_5_<VmEMgEgMP02MgD00gMfNiQgN003MgPAMgL3MgP5MgL2MgH017MgMgIgMgMf0WMh0WMH
00=cF7=GLeP00g=G00IgMgMhLeMcEg=gLeL3MeL2MeH00g=FLeMcE`06LeL00g=HLeMcE`0<LeL3LeH5
LeL2KeL6LeL00g=FLcIc=P03LcH2LcD00g<dKcE_5@02Ka@01f[dJ_9Z[f[?IZi9jab300880003440<
@0a100<<@@D@@003344<H@aQ008@H007560@H0aP360@HA1R6:800QB200DDPaB248<@HPa1008@HP0;
464@H11Q564@PQB25:8DPQB1460DH@02568358401AAQ584DPA2248400Q2200PDPQ1R468@HQAR588D
HQB20QB10Q210a1Q00<@PA224840311Q00D<@11Q464@PA2200<@HP8@PP03468@PQ2200<@HP03488@
HQ1Q00<@H@09364@HA1Q464@@@`P220<@A1R008@H003480@H11Q008@H@04588@HA1Q46824880111R
584@PQ1R0a1P00L@HQ1Q464@HPa0320<@00446444682584256000a1P440<@00244000a1P360<H003
3644464010a1340880Q00Q1P00<@H@aP34000Pa00PaP0PaQ00@<HQ1Q444@@@8<@@H<H@8<@005344<
80PP340<H@02464736401Pa1364@HA11344<@0<<H@07360<@0aP340@PABR48400Q1P00@<@0a1364<
H08<@004240<@0a044023440211Q460<H0aP460@HA21360234000`aQ340<@00334000``P360<@003
34413401360134400003248<@@a1008<@@<<808<@P03344<H@aQ008@HP08368400`P;@M>CeZ<FV]N
KP=JK`03FViJKeY_00IJK`9JL003FW5JL5Y`009NL004GY1NL5j@GY42GY04GY400ej@GY5NT@04GY43
GY82GW404ei`GY1NT6K?K^eR[ce8300802bRAJMNS6/?Ia9N/5Y_ETiB;58;009=k003DPaB;E8^00=B
;@0ICPeEk4g:FTdaJPPQ000X`4GYCTa:CDX^CRi:3dX_DY1B/EJ`DTlTa0008<E1kBdT5400100000XL
HRdX?JeBDEkCHaEVlfKCH[1R/PERd`AVd`9Ve00:I]=Zdf[cJ_=Ze6[dI_EVm6[dJ_<=J_@2K_@00flD
JaA[5002Ja@7KaD6JaD6KaD5Ka@4KaD2KaH02W<fLeMkV7^iNiY[5eZD@LlPQ@P00P00018401Q0:@I1
cE9`I_=gV7^jOoaofgnjMgM_56:aH[1JKeH/DPT2BLP02Dg9DP]F;EY_GY5VdV[dKcIcE`02MgL2MeL2
MgP06WMgMgIoUF/CDRlmZd6[AL]9beX/IXiVKF9<ENa1ZbSW448<01AR468<@A1R588DXaB348<446<2
36<021RT;DPY1QRS468DPQbT7<@258827:@00aRT6<DHa@056:D011RT5:@DY1B411B300@@PQ2346<@
HP8<HP8<@P<<@@0;348<@@a1348<@0a1320HXD6TGVYNRP07FTX4FT/3FT`8FT/03eY[EVaFJeY[FVYN
JUj<HZiV[VK@J_5_EGMfMgMgE@04MeH2MgL00gMhMgMgM`0>MgL01WMfMgMgMgMhMgMgN0UgM`03MgQg
F7MH009gF006LeMcF7=GLeMgMgMh0WMG00AcEg=gLeMcE`=gEPYcE`03LeQcEg=G00EcE`03LeQcEg=G
00=cE`AcEPEcE`9_E`IcE`Ac=P05LcEc=W<fLcIc=003KaD02f/EJ_AZlVZ`IZiV[d69420400P03200
0`a10PaR00D@HA10440<@11000<<H@<@H005360<@0aQ464@HP0558801a22468@HQ1R488DPA10008@
H@0:468@PQBR5:8DPQAQ464@HQAQ588258424643488246823640111R488@PQ1R0aB2112200X@HQB2
6:<Ha1c46:8@HQAQ588@HP@@H@03484@PQ1R008@H@09484@PQ22488@PaBS6<@DXaB200@@PP<@HP8@
H@@@HP03464<@111008@@@05364@HQ1Q460DP002584021B2468DPQB2564@H@aQ464348800`a1460@
H00446400a1R344<@00246401A21488@HA1Q58400Q1Q00@@PQB1564@H0<@H@03460<H@a0008<@003
360<H@aQ008@H@03468@HA1Q00<<HP0>364@H@aQ364@H@aP340@@11Q364<HQ23588@@0@@@@04464D
XaBS488336401@a1340<811P46800Q1Q00<<@@aQ364010aQ0Pa100@<HA1R464@H@D<H@8<H0L<H@03
360<@0a0008<H0<<@003344<@0a100@<@0<<H003320<@0aQ008<@004364<@@a03402360236423601
340134400003248<@Pa2008<@@8<800322088@Q2008<@@0<368@HQ2258<<@@P056@iJ59:FT]JK5Y=
1eY^0eY_0eY`00=JLEY`FW0015i`0Uj@00=NSej@GY000Uj@1EjA0Uj@0UjA00ARTEiaGW5NL09NK`0<
I]9ZlF[9@HT<00@0724mAeXYIZU_46;a0V;B00AVdf;BG[5NT09NL@9NT@0=FW1NL5j@HY9RTF:>K`lm
c@@2000eAEj@H]000Uja015NTEZBG[=RmFLdMg9FKbC50011b6maOjiRS58<?FPPPP@000<00007888i
IdG[GVeRd6KaH]800ejb00=RdfKCI]<00fKC0fKD0V[C00AZlf[DJ]AZm@9Zm09Zl`AZm003J_=Zm6[c
009Zl`04J_AZlf[dK_@2J_@4Ja@3KaD3J_@2KaD00f/EKaE[5@02JaD00flEKaA_5002Ka@00flEKaA_
5003Ka@4KaD2KaH03FlEKcE_=W=gMgQkV7]hMeIZdeH=<@LH80`000<0000h644XiCV9CPaR[g<cNiIo
^7nHNiQgMg=FJa=R/5j>ER]B2Tg9BLU9bTg[DPaF;EY>GXmVdF[cLcAgEW]gMgQkMg^GOkE_=5H_>FTi
J4G;DNaJCF9/GPUN;5i?CPha1a12420HH11058<DXac46<@DP`L@H`035:@U1ac4008DP`035:<HPaRS
008HX`DLY0@HY@055:DHY1RT5:@DQ00458<00a22468@HP0246800`aR348<@@0234403@a0344<@@a1
320880P0320a0DhYGZYJREYZ00UJBP03FVYJBeY;00UJB`03FV]FK5Y[00=JJ`09GVaNSF:/IZiVcfKa
Ja9[=6le009c=P04McIgMGMfMgHAMgL4MgH00gMgMgQgM`07MgL027MGMeQgF7MHMgMgEg=GLeP3LeL3
MeH4LeL4MeH9LeL00g=HLeMcE`02LeL00g=FLeMcE`03LeP017=FLeMcEg<f0g=E00=cEW=GLeL01G=G
1FmG0W<g0W<f00=c=FlfKcH00Vlf00Y_=FlEKaEZm6[cJ]5Zd6K>HXliA`880003320@@0a000<<@@03
364<@0a000@<@003440@H11P008@H08<H005464@HQ22588HXP0258402AB25:<DPQ1R488@Pa21464<
@@0236400a1R588DPP0258402Q1Q468DHAR26:8HPQB1464@HQ220Q1R00L<HA11468@PQB1564DHP04
58803A22468@HQ1R488DXaS37<<HXaB2568@HQ2200@@H@04588HXa22464248400aB25:<DPP045882
488446801A1Q488@HA1Q36400PaR0a1R00T@H@a2364@HA22464@@1B048400QB100<@HQ2246400Q1Q
00D<H11Q688DPA22008@H@03460@HA1Q008@H@05468@HA1Q464DP@027<<00a1R340@H00846424602
3602340336400a1Q468@H@04468436434643460246800a22584@@00244401`a1460DPA21464<HA1Q
008<H@09344<@0a0364DPQ1Q440<@0a1008<H@09468@PPa1340<@@aQ464@@A1Q00D<H@05360<H@aP
360<@003344=3402320434000`PP340<H00436001`a1340@H0a0364<@0aP008<@04<@@0010a200@<
@@`Q324880<88@0>348<HQ1R58<HY1B332480B22BNQNS5YZFTaJCP9JC`04FVmJKUY^FVh2FVl4FW00
0eYaFW1JL002FW05GW02GY02GY400eZAGY5NT@04GY400ej@GY5NL@02GW403f9`HVmV/6K@Ia=>3A00
000<033VCPeVZFK>I/mRdP02G[84H]<06V:bH[=V/f:cHY5V/fKCH[9RdfmFJa564@01000mYf/bI_9V
m6;CH[9R/fKeIaI[N6mDCS4200002dGXMkEcTGMeKcE_=V;CDU4m[B2U20000P0000P802C6?LiFTF;f
I_AVdf;B0f;C0fKC00AVlfKCI]=Vd`9Zd`9Zl`04J_AZlf[dJ_<8J_@2J_<2J_@01F[eKaEZmF[cJ_@0
16/E0VlE0f[d0VlE00=[5FlEJaD00V/E00E_5FlDKaA_56lE009_50A_5@=_5P03KaEc5VlF009_5P0>
KaM_5VlfLcIgMg^HNk]gVW=iI]AB;SUZ888@00<00007400LPSDWANaFCFleNiP00gni02]kV7MgKaAV
df:`FVmB;58]DRa=jdg:DNYF:eH]GViRT6KBKaE_=WNHMiIcEUI?>FPmR4W;ER]RdV9]GLUJ35iaAL`X
iA0Q420HPARS6<DYBC5Y8>HDP`0446<448<258<0112358@DQ1B40aRS0QRT00DDXaRT7<DHaART008H
Y@056<DHYART5:@DQ00258<00a2358<@P`0248<00a1S468<@P023486344020aP3408010P=DABSeZ/
FXX2FV/7FTX=FT/015Y[EVaFBeI;0UY[00=JK5i/GV/00f:=00]V[VKAJ_9_=7<eLcIgEGMfMgEgMgMf
011gM`9gMPQgM`=cN004LeMcF7MgMgP2MeL01G=GLeQcMg=gLeH00WMF00=gEg=GLeP00W=G00AcEWMg
MeIgEPIcE`03LeQcEg=G00QcE`03LeQcEg=G00=cE`AcEPUcE`A_E`9cE`=cEP=_=P0=KcE_=VlEJaEZ
m6[BI]5ZdF[aETla1P@032000Q111`a11@a000<@H11Q36400PaQ00<@@A1Q46801QB200@DPaB2464@
H@T@PP0;584@HA1Q464DPAR26:8Pa1R1584DPP0248803A1R340<@1225:<HXQAQ568@HQAQ468@HA1R
008<H@06368@HQ225:<DXQB2112200D@HQ1Q464@HQ2200D@H@09488DXa22488DPQB3488@HQ1Q00@@
HP09488@HQ1Q368@HQBT5<DDXa1R008<HP0:46<<HQ1Q488@H@a0580@PQ1Q5642488246401@aP340D
HAbS58400a1Q00D@H11Q464@HAAQ00<@HP07464HXQRR588@HA1046001a1Q00@@H110464@PP<@H@03
364@HA1R00H@HP05344<H@aQ364<HP0236403a1Q484@H11P340<HQ22564@@111344@@Q1Q588@HP06
364234001@aQ464@HA0P32000Pa000<<H@aR36400Pa10Pa000<@HA1046400PaQ0Pa00`aQ0`aP00@<
H@a1344<@08<H@05360<@110460<H@024880111R340<80`P0Q1Q0`a000@880Q0340<H@8@PP@<H@H<
@04<@@0000<8@Pa234800Pa20P`Q0PPQ0PPR00h<@Pa1364@HA22588HP``Q444e@e9<I/URS5Y_0UY?
00=FL5Y_FVl015Y_25Y`0ei`1Ej@1ejA0Uj@0ei`00mRL69_HXmVcVl>BPd/aP00200a246ZGTeZc6K?
H[0016:a00AN/V:aG[9RT@=RTP0UGY5NTUjAH[9W5F;bGXla2@0056=>:fK_I_9NT5jBGY5R/VKdIaES
=VKc<@T001Q1BPUW3VlbI_5Zm6lDLcIcEG<dI/mNKD6/52<00P0000T80223>FUB;F;AIa=Rm6;eH]@0
0V;C0fKB0fKC1F[c00=Zm6[cJ_@01f[d00=Zlf[dJ_@016[d00=^lf[dJ_D016[e00IZm6lDKaE_56kd
Ka@2KaD00f/EJ_A_5@07Ka@4KaD6KaH5KaL2KcH037=GMgQkVG^IOkUkV7]fJ]5EjcUY88<<00<0000e
100D82cU@LYJC6[`LeAo^7niOmYkVGMgLcI_56KBGY5JKe8<CN]=b4W9BJQ=bU7[FTeR/F;aKe=W4eH/
>DLmRDg[GVaVlei<EJQ=c4h_>DLHHQ0P520LXR359@HY:24658@<@Pa1348@H`0648<358<258@01ART
6:<HXaR35:@00QRT0QBT00@HY1BT5:DDY@<DY08DQ08DP`8@P`0446<@HPaR3685348234403@`P340@
H0aQ220<83UUG[1Vk5j[GX]JBUY900=JBP9JB`03FTYJBeY;00aJB`03FV]JBeY;00=JK00@FV]NJeY;
FTUNBUi[IZiVkf/BKcA_=GLeMeIgMWMFMgH<MgL00g=gMgMgM`0;MgL3LgP2LeL2MgL2MeH3LeL00g=g
MeIcEP03LeL027=HLeMcEgMFLeIgMWMFLeH5LeL2LePALeL016mGLeMcEg=G0fmG27=G00=c=g<fLeD0
0W=E00YcEW<eKcEc=6lDKaE[5F[dI]9Vd09Zd@06BNdXa0@0300@@0`Q1`a100@@@0a0320<808<@007
360<@0a0440<@@aQ48801QB200@@HPa1340@H@<@PP03588DXaBR008DPP05468@H@a0460@H@025640
0abR8<@P``0458801Q1R464@H11Q488DP@8@HP8@H@03468@H@aQ008<@@03364<HQ1R00@@PP03464@
PAB2008@H@@<H@0>360<@0Q0340@HABR5:4@PQ2358<@Pa22484@H@8@HP0<464<HPaQ348<@@aR468@
PaB2468<H@aR0Pa000X@H11R464<811Q5:<@PQ1Q584DXP8@H@8<@08@H@05580@H11Q464@H0044640
0aBS48<@H@0546401a1P464<H@a0220<@11P008@H@03460<@11000D@H@06364<@0aP364@H@aQ111Q
0a1R0`aQ0a1P018<@0aQ464@HQ11448<@Q12468@HA1R364<@0aQ468<H@a1360246401PaQ560@@110
320<@08<H@<<@@<<@08@@0@<H@07344<H@aQ360<@0aP364020a000<@H11Q48800PaQ00<<@@a03200
1Pa00P@P00@<@0aQ464<H@@<@@05320880a0360@H00134000007248<@@a236<<HPa132400PPQ0PPR
0148@Pa1344@HA1R58<HY11S344Ti3fWGX]RRUi[FTaJCUI_009FC`03FTmJKeY_009JK`YJL0=JT@=N
T0AJT@0FGY5NT5i`GVmNL5i_GXmRKVJ>I/i_4f9];<<800`0:<Dmc4h^GXiR[Uj@HY06H[45HY801ejA
H[=RdejbEXm>]3f>00800004;DYNc6K`H[44HY405f:bG]9JeD6]200003EZI/UZkfKAI[5R/VKBJ_=_
57<eLeI_=FlhG[E642d830000P0000PD0BTZAS5JeUkDH]ARdV;C0V:b00AVdVKDI_AVm09Ve007I]=V
lfKcI_=Zlf[CJ_<00f[d00YZmF[dJ_A[5FlEJ_EZm6[DJ_AZl`=Zm0AZm@=Zm0=^m0=_5@9^m0M_50I_
5@A_5PA_5`03KcM_=Vlf009_=P03LcIcEg]g009kN009OiUkN7MhKaIN/dW^;BLH@0@00080000_100@
0223<BQ5k5Y_Ja=cMgNHOkYo^GnjMgQcN6leI]5NSeY>ERaB2U7ZCNU=jU8/EV]BKTW<<>@mJDh<FXeR
lUi;DHQ5Zcf:=@HHHQA1540PXR357:DHY1B3344<8@033440111R48<@Pa230Q1S0Q2300LDPa2448@D
Y1RT68<HY0076<D26:D45:@011B458<DPa230Q1S0`aS00<<@`a2348010a200X<@@a0360<H@PP320a
95I^GXeNR`EFBP06FTYJBeY;FTYJBeYZ3EY;00=JJUY/FV`00eY/0UY[0UiZ00QNS6:^I_1ZlV/DKcIc
=W=G0WMf2gMg0g=h00=cMgMgMgL00gMg0W=g1GMg0g=h00EcF7=hLgMcMgMg00AcE`04LgMcMW=gLgL3
LeP2LeL01GMFLgMcEW=GLeH017=G00=cF6mHKeP016mG3g=G1FmG00=cEg<fLcH00g<f00Ec=g<fLcIc
=W=F009gE@04LcI_=G<eLc<2Ka@2J_@046[CI[5V/FJ_?J`D@`00200<80PP444@HA1R444<@@aQ0Q10
00<<HA1Q36401@a000D@@AB2468@HQ2200@DPP05464<@A1Q464DP@0248801AB15:8HXaRS5:800QB2
00<DHA1P56400QAQ00D@@1A0688Y1Qc400<DPP04584@HQ1R48424642468346434882468010a1364<
HPb20Q2300P@PQ1R468@HQ22588@PQ1Q0Q21111Q00<DPQBR5:<00QBS00L@Pa22464<@11R368@HP02
36802`a1244<HQ1R344<@11Q5:@@Y12334000Q1Q0Pa000<@HA2248800a220Q1Q0Pa000<<HA225840
1A1Q00DDHA1R468@Pa1R008<H@03464@@0a000D@H@04364@HQ1Q464258800a1P320<@00446423203
464246801a1Q468@HQ1R488DPa2200@@H@03460@H@aQ00D<HP8<@@0A460<H@aQ468@PQ1R464<HA1P
464DPQBS560@8110340@@00234001@`P344<@@aQ34400Q1000HDHA1Q460@HA1R3682364010a0360<
H0aP1Pa000<<H0a036000Q1Q00L<H@a1344<@0`P220<800:34001P`P344<@@a1444<808<@04@H04<
@00000<8@@`Q34400Pa10P`Q10PQ01088PQ1344<@@aR468@PaB346<DPbd2BPMRJV[9FTYFC0=FCP9J
C`=JK`iJL003FVmJL5Y`00AJL003GW1NSej>009NSP0?GXeRS6[<K`eNSceZ200402bQ?FM:36:[HXeR
/6:@00IRT@03H[5R/V:A00=RT@0LGY5N/F:aH]5V[TG@30D000`3AS5[3VKaH[9RTF:@HY5V/fKBJ_1F
<BAV000@0E9@LbeZl6JbH[83I]802f[BJ_=Zm6/DKcIcEVldKa1NCCf966@00P0000D00Bd9@NaFKV;b
009Rl`04H]=R/V:bH]<4I]<3I_<00f[bI]9ZlP02J_<2J_@016KdJ_=Zlf[c46[d00I^m6lDKaE_5F[d
K_@:Ka@2KaD00flDKaE_5@04KaD3KaH00flfKaI_=P02KcH026leKcIc=G<fMeIkEg]gNiT2OmX01g^H
Ka=Zd5X/>FTLQ0@000<0000W100H@2C3<DM5k5Y^J]1_4gMGNiQofGniOiQgEVlCJ_=R/5i_DPa>2EHY
DR`iRS46>DQ=k5Z=I_5V[EWYBJXmAcD5::<D@AA07:<LY1RT00DDP`036<@LaARS008DP`@@H`0348<D
PaB4008DY@046:@HXaS46<@56<D00aS46:@HQ0025:D25:@00aB458<DP`0248<01A1S46@<Ha1S36<0
10a200l<HPa2344<H@aP3448010P<>==jdgZDNUEjUH:ERX00UI:00MJBUY;FT]JBUYZFVUJJP06FT/0
0eY[FVYJBP02FT/015YZFVUJBUY[0UY/00iJBeY[FVYNJEY9GV]R[FK?I_9[56lfLcMcEgMf0WMe0gMf
1gMg0g=h27=g0gMg0g=g00=gMg=GLeL00g=g2G=G0g=H0W=G00=cEW=GLeH00W=F17=G00=_F6mGKeL0
0fmG00=_F6mGLeL02G=G00E_Eg=GLeMcEfmH00=_E`07KeQcEg=GLeIc=W=ELeH01G<f0Vlf0Vle00A_
=7<bKa=_509Zl`08I]=R/FKAHZleJ`@0000<80<@@008460@HPaQ340<H0aQ464@H0<@@0@<@00E444@
HA1R468@HAB1588HXQB2568@HQAR584DP11P564DPARR7<@Ha1BS008DPP03488@HAB100<DH@0@464@
@1B258<DPQAQ584@H1AQ588DPA1Q468DPQ1Q340246402121488DPQ22468<@A1Q488446800`aQ468@
HP02588348400a20484@H@04464021225:8DXa22364@H@a0344246800`aR468@HP054680111Q468@
Pa1R1Q1Q0PaQ211Q00<@HQ1Q46401Q1Q00<@HQ2246400Pa0211Q00<<@0aQ4640111Q0Q100Q1P0a1Q
0Q1100D<HA1Q464@HA1100<@H@03364@HA2200<@H@8@H004360<H@aR368334400`a0220<@0024642
364246400`aQ360<@00246400a1P420@@002440010a0220880`P10a000D@@11P464@H0aP008<H@06
464<H0a0240@H0aP30a000<<@@a0340010`P0Pa000T@H0aP360<H0a1340480`P34401Pa00A100@`P
0006344010`Q32888@PR0PPQ00<48@PQ24400PaR0PaS00X8@Pa1564iA5Y<IZ]R[5I;ETaFCP9FC`9J
D003FW1JKeY`00=JL0MJL@=JL003FVmJL5Y`00AJL09NL00@GY1JT5j?GXiR[fl@I/`mc0`1000XX3e6
@LUJSFK=I/l2HY06HY408V:aG[9RTV:AHY9RTFJaI]=R/EIc?F`@00004011[5lEIa5RdUjcH[9R/FJa
I]9[56I]?@L40000>DUS56/@I]5R/VKB0VKC1FKB00=Vdf[dLeL00W=G00mW55Zd@NlPY@P0000@8B3X
?NmB]5kcH_=RdfKcH]<016KC00=Ve6KCI_<00fKc0VKD0VKe00AVm6[cJ_=ZlaEZm004KaAZm6lDKa@2
K_@2Ka@4KaD2Ka@6KaD5KaH00flfKcE_=P04KcH04G<eLaAc=GMFNgMkVGnjOm]k^W^JLgQ[=eZC@LhX
aQ@010000`0000d801107:8Y1cV;APiJKVKBJaAgN7nHNiQgEP02LeH04flCI/iV/5X/@J/mRdW/ET]V
l6l?HVaEbdF9?BHTY10R548PXabT008HQ0<HY0057<DLiQcV7>HHY00458<458@35:D00aRT6<@Ha@06
6<D01AbU6:@HYABU5:@00QB40QB30Q2300<@Q11S36<00PaS1`a20PaQ00d8@0P0300``Tg9CLQEb4g9
BLUB2UI;ETYFB`03FTX00eYZFVUJB`02FT`3FT/00eY<FT]JB`03FT/01EYZFVUJBUY[FV`00eY;00eJ
JeYZGT]JK6:>I/mVlV/DJcI_=g=GLeIgM`04MgH7MgL3LgP9LgL5LgP00gMgLeMcE`04LeP00g=gLeMc
E`06LeL00g=HLeMcE`0:LeL4KeL016lgKeM_F6mG37=G0fmG00AcEflgKeM_F09_E`04KeIcEW=FLeD3
LcH00flfLcEc=@02LcD2KcD037<cKa=^m6[cJ_AVe6:cI_AN/2e9000800<@H@03440<@0a000@<@004
360@H11Q440334002@a1340<@@a1364@HQ1Q564@PP0358803aB36:<DPAB0440@HAAQ6:8HXaBS58<@
HQ2258<@PP0248425843588256426842584258800a1Q584@H@0446401122588DPA220Q1R0Q1Q00<@
HQ1Q4680111R1A2200<@P@b136400a1Q00@@HQ22488@P`<@PP03368@HQ1Q00T@HP8@PP0348<@HQ1Q
00D@H@03340880a100<@H@8@PP0858<@PA21464<H@a1364@H@D@HP03464<@11P008@H005464@HQ22
464<H@0246400a1R464@@00232000a1Q588@H0024603464010a1340@HAB10Q1Q00<<@0a144000Q1Q
00<<@A1Q4640111Q0`aQ00H<@@`P340<HA1Q364234000`aP364@H@0246400`aQ468<H@0246454600
10aQ344<@@a110a000<<H11P46400Q1Q0PaQ00H@H@aP360<H11P360<340234400`a0320<80043403
36400`a0344<@@02344334001@a1320@@@`P34000@PP0009344010Q1224400@00`PQ00l8@@PQ2488
@Pa1444PXce5CPYJSEj[EVaJKeI?FTl00UI?00=JD5Y_FVl00eY_0eY`00ANLEY`GW5JL@=JL003FVmJ
L5Y`00AJL09NL00AGY5JT5i_H[1ZlF[>CP/PPP00540i8D6VER]R[FK=HZiR/003H[44HY402V:aG[9N
/V:BI]AVlf/BGVi1ZR260P0000L@0d7=H/eW4f/DH[9NT`02GY803F:aJ_5NKT5X500002c3GVaW4VKB
H[5R/VKB00AVd`9VdP0<I]5VdVKBI]=Ve6/DKcE_=7<bIZm5c22W0P0000`00RdY@N]FKVKbH_=VlfKC
H[9VdfKDH]@2I]<016KBI]=VdfKC0VKD00=VmFKdJ_<00V[c2F[d00=Zlf[dJ_<00V[c00=Zm6[cJ_<0
0V[d1VlD0Vkd26lD0VlE00=_56lEKaD01FlE0fle1Flf1G<e0Vlf00icEgMhMiUkVG^iOkUkV7<dHY1A
k3UY9<DD@@@0100001d<01@P8:<a9cf:BPaNKVK@Ka9gMW^GOkQgV6leGY9=kTW<ERYJJW<_J_1RKdg;
?DHTHP`186<PXabS00<HP`@DP`8@P`0358<DPQB300DDP`0458@DY1BU6:D26<@00aS57<DLY@027<D0
1QbU6:DLYAbU6:DHY0<DQ08DP`8@H`0448<@Ha1S4682368634803`a1364<@@P0300d`U79FPUN2U79
@HM5jUI[ETYJBP04FTT015YYFT]JC5Y<0eY;00=JC5Y/FT`00eY;00AJBUYYFTYJJP=JB`0@FVYJJeYZ
FV]JBej=I/mVlV/DKcI_=fmHLeIgMgMfMgL2MgH5MgL00g=gMgMcN002LgP9LgL01W=hLgUcNGMhLgQg
M`9cE`=cF0=cE`03LgMcMW=G00=cEPEcE`03LeIcEg=G00=cE`06MeIcEW=FLeM_EVmG0V/g00A_=fmH
KeM_E`YcE`=c=P04KeM_=flgLcL3KeL8KcH2LeD2Lc@016leKcIc56kc0V[d00YVe6;EH]IVmEI`:>H8
0A11564@H08@@08<@0H<H0<<@08<8003324<@A11008<HP<@H@06468@HA1R468DHQB20QB100@DH@a0
344DH@8DPP07488@HQ1R468@HAB1488021B20aB10QB200<DPAAQ46400Q1Q0Q1R00XDPQRS6:8@PQ1R
464@PA1Q468@H@@@HP03464<@@aR008@HP03488@PA1Q00<@H@03468@H@aR00@@PP<@HP<@H@03468@
HA1Q008@H@<@HP03364<HQ1Q00<@H@05484DXa1R364<@@0346401A1P440@HABR6:400Q1P00<<8110
46400QB20a1R00<@HAB146000a1P00@@HA1P340<@0H@H@04440@HA1Q4642460346401A11464@HAB2
6:400Q1Q00L<@110444@HA11320@@00346402`a0240<@@a0344880@0220<HA2146400Pa000<@@11P
46001Q1Q0a1P00@DPAR2564@H08<@@03340<@@a000<<@08@H08@H@07460<@0a0360@H0a0360020a0
00<8@0a034000Pa00PaQ00<@H0`P32000`a01A1Q00H@HPa1340<@0aQ3602220010`P340<@0a00@`P
00001Pa1244<@@a2344<@P8<@@043488@Pa2244322400`@Q2248@@0234802a1R324@8B21?FM>KeZ^
H]5NSUY_FTl015I?00AJD5Y?FVmJK`9JD09NL09JL@03FW1JKeY`00AJL003FVmNL5Y`009JL09NL00@
FY1N/6;AIZm>;RRS000802T4?JIB2f:;HZmRcf:?HY02GY42HY4096:BHY5RTV:aGY5Rdf[fI_EW5diA
;BT@0000100TaTX`GaEW4VLCH]9N/UjcH]=RdFKbFVi1Za@0000XP59>Ja5[4f;BH[9VdPIVd`04I]9V
dFKBI]83I]<056KBKaAc=G=FI_=FTd7?8:H80000200LadHbHaMRdFKAH[5RdV;DH]D2I]@3I]<2I]@2
I_D016KdJ_=Zm6[c2f[d00AZlf[dJ_A[50=Zm004JaAZm6[dJ_@8Ka@7KaD00flDKaE_5@06KaD00flF
KcE_=P07KcH4LcD3KcH017MGNgMkN7nI0Wnj00]kVG=hKaIRde8]?J`]9b23540800@000<0000N400D
@22S<DQ1kE9@G]=cVGoJKeIF;TW;CN]JBf[^Ka=ZlUi=AHPP@1@1820dhceX>BHXY1AR320@@PaR0Q1R
0Q1S00@@PQB358<DQ0<DY0055:DHYARU6:DHa@027<D01B356:@LaAc58<D00Qc51ARU0QBT0aB300@D
Y1B348<@HP8<HPL<@P8<H@0<340@8332DLQR2FHZHRU9Qd6YCTaFBeY:15Y900EJJEY;FT]JC5Y;00EJ
C0=JB`04FVYJJEYZFVX3FT/3FVX03EY/FTaNSFK?I_9Zlf/FKcM_F7=GMgMgN7=h00MgM`EcN0UcM`03
LgQcNG=i009cN003MgMcEg=G00=cF0=cE`=cM`QcE`03LeIcEg=G00=cE`=cEPY_E`EcE`Mc=P08LcM_
=flgKcMc=g<fLeIc=P9_=P03LcIcEW<f009cEP08LeEcEW<eLcAg=6leKaA^m09Zm009I]ANeUkFIaM:
3QAR000<8A1Q00<@@0<<@003360<H@aQ008<H08@H0@@@08@@@0358<@Pa1R008@H@8@HP03344@HQAR
008DPP05584DPQAR464DH@025883468246400aAQ588DPP0758801QB1588DPQB25:8DPP<@H@0@688D
PQ1R588La1RR588@HQ22484<HAB2688HPa1Q4682488246800`aR468@HP024683464010aR468<H@aQ
0a221A1Q0a1R0a1Q0Q1R00D@PQ21368@H@aP008@H@04484DXaRT5:@24683464020`P440@HAAQ460@
@0`P444246402aB3488@HQ1R488DPA21464@@11Q46001A1Q00LDPQBS5:<DPQ22464@@00846400a21
6:8HXP02464234400a1Q7<@@H@02444446401@aR468@H@aP34400PPP00<<H11P36000Pa000@@H0a0
340@H0H@H@04444@HA1Q564246401A11344<H@aQ36000`a000<@H@aQ36001PaP00<<@0aP34001Pa0
00<@H0aQ36400`a000L<@@aQ440<@0`P340@@00246402AB2464<H@a048<LY110320<@@0236423440
0`a0464@H00134400003248<@@a100P<@@06368<@@PQ22440@@Q0PPQ0Pa100d<8PP0420HPc57BP]>
Cej]FXiFKeY?ETmJD002ETl4FTh00eY_FU1JC`03FU000eY_FW1JL005FW02FVl045i_GViNKej`J_9V
/6I]<:<40000860mZ4h/GXYR[5j^0Uj?00ANT5jAGY5NT@9RT@=NT@06H]=Vm6;CFW4iSA@U0P0001TT
PdFYGVe[3fKaI_9N/EjAGW1NTEj`I^mJKT6Z7440020PALI[3flAI]9Ve6:cI]9R/P02I[800fKBI]=V
d`04I]800fKCI]9Vd`03I]<01f/DKcE_=6lCIZi:32SX00<00009;BQ>;6;>Ja5RdejdGY=R/f;D00MV
e0=Vl`9Zd`MZm0EZl`QZm0U_5005J_A^m6lDKaA_5@06Ka@2KaD2KaH00flEKaI_=@04KcD5KcH2LcD2
KcH00fleKcI_=P02KcH04G<gLeMgN7nIOkYk^G^jOkUgN7<fJ_AR/U8]@L/a9ab330001@0001T<01bT
<FQ>:e9>@LXiAdG;DTeJK6[bLc=V[dW;968PI458DNY=jdW:?DPLY@`P444@H`0346801A23588DPaB3
58@00aBT0QRU00PHaART58<DQ1c56<@HY1R40QRT00DLaART6:@LYARU00<HY0075:@DPaB3588@Pa1S
46800PaR00<<H@aR34800`a20`a100d<H11P440/XDf5GPMR2699BJTmZDh/EV]FBP05FTT015Y:FVYJ
BeY;0eY<0UY;0UY:00=JJUY:FVT00UYY00AJJUY;FT]JJP9JJ`09FVaNK5j<IZeVdF[bJaE_=fmG009g
EP03MeMgN7Mg00IgM`=cN0]cM`05LeQcN7=HLgQcF003LeL3LeP4LeL00g=gLeMcE`07LeL3LeH017=G
LcIc=W=F0W<f17=F00=cEg=FLeL01G=G00=_Eg=GLeL01W<f00Ac=flgKcM_=`=c=PA_=P03LcIcEVlf
00A_=P03LcAc56lD00=_500:K_AZm6KEI_MNee[G>HX800002204440234002@aP340<@0PP340@@1B0
484@H0024403444346801a22588HXaB2468@HaAR008DPP04584DPQB1568358801A23468@HQ1R4640
0QB100@DXQRS5:<DPP8DP@03588HXQB1008@H@03568DPA1Q00<@H@03564DPA2200<DPP<@PP09484<
HA1Q588DPA1Q364@HA2100H@HP03344<HA1Q008<H@043408@0Q0364348400a1P464@H@024640111R
464@HA220Q1Q00H@HQ21484@HA1P340446403122468DPQB3468@HA11340<80a0460@H@8@@08<@003
464<HA1R008@HP06584HXA1P460<@1101A1Q0Q210aB200L@PA1P340@H11Q460@H@0446000a1Q588D
P@0246400`aQ344@H@0258801a1Q444@HA1R464<H@aP008@H006464<H@aQ344<@11P0`aQ10a000<@
H11Q4640111Q11100Q110Pa100<<@0aP340010a00PaP0Q1Q00@@H0a0340<H08<@003360@H@a000D<
@003360@H11P00@<@009440<@0a0440@HARR7<<DP@a0008<@@03340<80a00088@@04344<@11Q4642
3601340000032448@Pa100X<@@88@@<88@0>12488@a234840@@0324HPc4VAPaFSekAFZiJKPAJC`=J
CP03FTmJKeY`00AJD0IJL00;FVmJL5Y_FW1JKei`GW5RdfKBHY8mB@0210001BQP?FA>;5Y/GZh00Uj_
00=NSej@GY000ejA0Uj@00MNTFKBI]9VleJ@@Q0Tj00200005``0=BMB;VJ^Ka9Vd6:`GY1N/6:`GVeJ
KF;AGVhmRa00000L@4GZK`]cE6KAH[800V:c00IR/VKBI[9V/VKBI]<7I]86I]<01f[dKa=c=F/CH_E:
422U00800006424]BTHaF_IRmFKd0V:b00=RdfKDI]@016KC00IVe6KcI_AZm6KDJ_<6J_@3J_<9J_@0
0f/EJ_AZm002JaD3J_@4KaD00fkeKaE_5@02KaD00flDKaE_5003KaD2KaH00flEKaI_5@0CKcH2LcH0
1flfMeMkN7^IMiUkVW^k009o^`0:Om]kVW=GH]AN/e8`>J`Ta1A0300300005PP0420H@R2S=FU63U8]
H[5[4f[cCP`i9cU:EPeVSEY>BL]1RRBU420@@A1S11230aB30QBT00<DQ1BT6:D00QS500<LaAS56<D0
0Qc50acV00DLaAcV7<HLaART008DQ08@H`0548<@Ha2258<@P`0246<236800`a2368<HP0234833440
3@`P360<@0`0;:59I5gWHPUN:TW:?JU>;5I;009JBP04FTUJBUY;FTX7FT/3FTX015YZFTYJJUY:0UYZ
0eY;00eJJUY[FV]JK5Y<GT]RS6K@I_9[56lgKeMgEP02MeL00g=HMgMcN005LgL3LgP;LgL5LeP3LgL3
LeP3LeL017=HLeMcEg=H0g=G00=cEW=GLeL00g=G00=cEW=GLcH017<f0g=F00A_EVmGKeI_E`=c=PE_
E`9cE`Ac=PAc=`03LcI_=Vlf00E_=`E_=P04KcEc=7<dKa@2KaD026lDJ_AZlfKCH]ENee:f=DX22000
0``P440@@003440534001Q1P440@H11Q340@H08@H@04444@HAAR464258800aRR7<<DPP0256824680
1a1Q444@@AAQ688DPQ23008DP`8@HP8@PP03584@PQ22008DPP085:<DPQAQ568DPQB1464@@0<@H@07
340@HA1Q464La1B246800QB200<@HA1R48800Q220Q1R0a1Q00<@PQB258800a1R00<@PQ1R46800Q1R
1A1Q00@@PQ21484@P@@@H@04344@HQ23488446804A22588@HA1Q440@HA1R464@HQB2568DPQ23468@
H@a032000Q1P00PDPA1R344@@11Q364<HPaQ0a1R00<@PAR146400Q1Q00H@PQB2468@HQ1Q48864640
0a1P320@H00246400a21464@H@0746400`aQ340<H@034640211R58<@HA1Q364<@110464336401PQ0
340@HA22464<H@8<@003360<@0a000@<H@03368@HA10008@@006460<@@a1348@HPaR0Pa10Pa000<<
80a036000`aQ00@<H0a0340<@08@H@8@H003340<H11Q00@@H@03364<@@a1008<@@0;340@@111340@
@11Q588DPa1Q440<@00334401Pa0344<@@`P444<H@<<@04<8@001Pa10a110P`Q00<8@@a134400`a1
0PPQ01840@@Q22880@PQ204<8AAR;@E62UJ?H^eN[Uj@FVmJKUY>FTd3FTh3FVl3FTl2FW001EY_FW1J
KeY_FVh00UY_0UY`00eNL6KFH_INKce:200001PP?DA9iUI<H/mNS`02GY001EjAGY1NT5jAGY800UjA
00MRdf/DH]5VkUI>>FL@000200001a@Q@JYVbfl?Ka9VdF:`009NT00>GXmJS5j]Jc9JT3f:500001a0
ALUVbgM>J/mR/@ER/P9V/P04I[5V/VKAI]45I]87I]<026KcJ_A_=FlcLe9RcT7;66@200001`P2=FYF
;F:_J_=R/F;B009Vd`03H]=VdVKC00AVd`05I]AZm6[dI]AZl`04J_@00f[cJ_9Zl`02J_@00f[eJ_AZ
m@06J_D4KaD00f[eKaE_5@04K_D4KaD3Ka@3KaD2KaH00flEKaI_=@04KcH00flGKcI_=`03KaL7KcH3
LcH2KcH4KcL01FlhLeQcN7MiMiT00W^i00Yo^W^iMgQcEfleI]5JBd7;;@HD@P<0000G500a9TH>CPiF
;ej@H[1F:dW;BNeNSV/?GVe>;CeX88@800`P56<DPQ22588@P`03468258@011BT6<DLiRD60R3V00HP
iBD5:BHY9RD69@L2:BL02bTX:BLU1RCU8>HLaABT46<@Pa1S48<00QB300H@P`aR24488@a236823484
34404Pa0440<80P0;:5=QEgXITYVJeGZ@LY>;5I;FTYJJUY:FT]JC0AJB`04FV]JJUY:FTX2FTT3FVT0
0eY:FVYJB`03FT/03UY:FVUJJEYYFVYJBUY9GXYRcfKaJ_=_=VlgLeL2MeL00g=HMeQgM`03MgL7LgL3
MgL4LeL:LgL3LeP3LeL3LeP:LeL2LeH3LcH5LeH2KeH6KcH017<fLeMcEg=G17<f00=cEW<fLcL00flg
1g<f1Flf0W<e00ic=6leKcE_5F/DJ_AZlf[BJ_5Rdf;EE[H]:P@01a1000H<@110340@H0aQ46024405
34000a1P464@H@0346400aB1588DPP045880111Q344@HAB20QRR00<DPA2348<00QB200/@HQ1Q584D
PA1Q340DPABR584DHA11008@H@8DH@8@H@09364<@0a0344@HA1R488@PA1Q00<@HP8@PP0348<@HQ1Q
008@H@0>584HPQB2568@HQ1Q584HXa22464@HQ23468<H@8@H@8HXP0;464<@11P464DH11Q3408@0aQ
368@HP023648464246801A22588DHQ1R36400Q1R00L@HA10560DH1RQ5:<@HP0246401@aQ368@HQ1R
56800QAQ00HDP11Q468@HQ1Q488:46400a1P340@H00>464236400`a0464@H@08464336401@aP464<
H@aQ34400`a000<<H0aQ36400Pa100@<H@a1440@@08@@@8<H@03348<@@a100<<@@053608@0a1340<
H00246053400111P464@H0a00Q1Q0Q1P00@@HA1P460<@0D<@@8@@004460@HA1Q364234001110340<
80`P0`a000<8@@PP340010a00@a10005344010`Q320@@A110``Q1Pa100H88@@Q12488@@110022000
2P`P568Y13g:CTmJ[eY^GViJKEY>0UY?00=JCEY>FVl00UY_0eY?0UY`00=JKeY`FVl00eY_00mJSeY`
FVmV/F;CE]LiK0P0000D03e4ALQB:Uj/GXl00Uj@1UjA00MRdfKcHaENm5:D?JhPH`0200006A00>HYF
TFMFIa=VdV:aGY1NSejaGY9JT5Z^HcIFTc5[100001a0ALYV[6/BI^mR/6:a00AR/P=VdP9V/@EVd@9V
dPYVd`07JaA_=G=hJeIJe3f/50000P0000PPHd6^FW9VmFKcJ_AVdf;C0VKC00IVdVKCI]=Ve6KCI]@3
I_<3I_@2J_@2J_<3J_@?J_D3K_D016lEKaA_5FlE16lD0VlE0flF00=_5FlFKaD026lf00=_5flfKcH0
2Flf2flg00I_Eg=GMgQkN7^IOk/2Om/07G^IMgQ_5FKCERi1cCDX968/aD7=BNi:3dh^DRiB2dg:ANeS
4f]@Jc=B;d6;78@<00`P568DPQB35:<00aBT00dHY1RU6<DLiR478@HLiB469@DY9Re7<FPaJ@02<FX0
1Be:;DT]BRe9:DT00Re900@Y22D78>LLaP<HY@035:@DPa1S00<@HP05368<@Pa2368<@P0234403PaP
320@@0`0<:5=QUWYIT]ZSE7[@L]>C5I[ET/2FT/2FT`015Y;FTaJC5Y<0UY;00=JBUYZFVT015YY0UYZ
0UY;0UY<01=NBei:GTYJBUY;FTYNJf:]I]1VlV/DKcI_=g<gLcQcF7=IMeQgN003MgL7LgL00gMgMeIg
EP02MeH00gMgLeMcM`05LgL5LeP00g=GLeQcE`07LeP7LeL:LeH00fmFLeIcEP03LeH2LcH4LcL3LcH0
1G<gLcIcEW<fLcL00flg0Vlf27<f0W<e0W<f00i_=FlfKaE_5F/DJ_AZlf[AJ_9ZmFKfCW<Pb@000a10
0Pa0111000H@@A1Q468@HA1P440534001Q11464DPQ22464@HP8@PP0B588@PQ22588HXa22468DHQB2
6:<L`abS588@PQB35:<DPaR30QB20aB100DDPQB1560DHA1R008@H@8DPP05584DPQB2464<@@023680
0`b2488@PP024642488258801Q1R464@@A11464DH@8DHP0<468DPQBS6:<DPQ1Q588DXa22368@HQ1Q
0Q1R00L@H@`P460@HAB0564@H@0336801@aQ368<H@aR36400Q1R0Q1Q00<<H@PP34400Q1R00<@HA1R
58800aB20Q1Q0Q1P00<@PA2336801A1R00T@H@a0344@HAB1464<@A1R48804Q1Q00<@H11046400Q1Q
00<@H11Q46400Q1Q0PaQ00<<H11Q46400a1Q0Q1R00L@H@a0464@HQ23488<PP0436401@a1340<@0a0
464010aQ0Pa100<<HA1Q36000PaQ1Pa100D<H@aR488<HPaQ008<H0<<@08<8003340<H0aP008<H@03
464<@11000<@H@09344<HQ1S48<@Q11R444@@11P008@H@06468@HA1Q440<@11010aQ00D<HPaQ344<
HA10008<@04<@@0000H8@@`Q324<8@a13243320;3442224040@1100800P0100<81AS9>DaAd7;CTiF
KUj>FVmFCUI=0UY=00=JKUY_FVl00UY>00AJCeY@FTmNK`9JK`9NK`0@GViNSUY^GVeV[fk`ALl@0`00
300e9DFVANQNRF:]GXl2GY04GY401ejbI_9RlV;@EY5>;bSY00<0000@;>E>:fK]Ke9W4f;DGY5NLEi`
GXmJLF;EG]=Vd4X?74@200001RB2ALMVZG<_J_5VdP9R/@ER/P04I]9V/VJaI[45I]42I]8;I]<026KD
JaA_=FmDMg5V[CeY40820000221UALiZlVKdH]AJTUjbI]<2I]8016KCI]AVdfKC0fKc00=Vdf[dJ_@0
0V[d0V[c0V[d46[e0fke0fkd00=_5FlDKa@00VlD0VlE0flF00E_5FlFKaE_5Fle009_=P9_=@A_=P03
LcIc=Flf00]_=P04KcM_=VlfLcH3KcL4KcH01G=FLeMgN7MhOiT00W^j0Wnj01IkV7<DIY9AkdG^CNi>
3TW^ANe=k46YDRe[M7ogJa5>3cT878H@8AAR588DP`8DX`045:@HY1c57<D26<D01QBU6<DPiBD58>@T
h`8Ti004:@D]Abe8;DP2:BP01beZ<FX]BBe9:BPU1b47008U1P048>HLiQRU5:D258@258<00a1R344<
@P02368334403a1P320D@110=>1=YEGZEN]RC57:@JY>;5I[ET]JBP04FT/01eY<FVaJC5Y/FT]JBUYZ
00EJJ@04FVYJJeY;FT/3FT`2GT/04EYZFVaNK6:<IZeVd6KbJaA[=VlhLcMc>7=HLgUgF7MgMgH00WMg
1g=g00=gMWMFMeH00WMF0W=G00AcMg=GLeMgM`9cM`AcF0AcE`=cF0=cE`03LeQcEg=G009_E`9cE`9g
EP03MeEc=W=E00IcEP03KeIcEW=F009cEPE_=P9_=`06LcMc=W<fLcI_=W<e0W<f0flg0Vlf27<f0g<e
00=_=VleKcH00VlE00]_56[cJ_5Z/6J`I]=Re47?58L400PP008@@08<@08@@003344@@A11008<@0<@
H003440<@0a000<<@005464DHA21584@H@0346824882588248802A1R588HXabS688DPQ2258<HX`04
588011B1588DPAB20aAQ0a1R00XDPAB26:8HXaB1564@HA1R464<@@@@H@05484@PQ22464@P@024640
3Pa1220@@AB26:@@Pa1R488DPa1R460HXARS58834680111Q364@HA1Q0Q1P00<DH1AQ46400Q1R0`aR
00@8@@a1464@H@8@PP03464<H@a00088@@03344@HA1Q008DPP056:8HPQ1Q464@H00246400a22468@
HP0446800a1Q344<@@0246400a1R584@H@0346401`aP484@PA1Q364@HA2200X@H@03460<@0aP008@
H@8@H003340@H11Q00/@H@8<H@06368@PQ2S468<H@aR0PaQ00L<H0a0220@H1B23648800236001@aQ
464@H@aP46000`a100@<@0a1320<@08<@@@<H@03340@H11P008@H@03364@HA1Q00@@H@07360<H@`P
340<@@aR468010a200P<@@aQ464@H0PP364DPQB10PaP00@<@0a1468<H@<<@@8<H@03360<@0a0004<
800000D8@@`Q324<@A1S00<<@P03344<@Pa100H<@@07348@HQ1R3448@Pa122000PPQ018880@0200<
@AR3;BLmc4i`EY1JT5Z?FVmNKUY_FTiJKUY>FTl3FTh00eY?FTiJK`03GVl04Ui]GXeJJV:[J_1B;A`P
000<03DS@LY5jUH[HX]N[eY_GY1JT09JT@08G[=Rdf;dG[9BLd8@<F`H@`80000A8251[5jcI_9W4f;A
G[9NTUYbFW5NLEj`H_ENe4jD?JhL8P0200001c33FTi_3W=CJ_1V/6Jb00ER/P05H[5R/VJbI]9Vd@08
I]8=I]<026[CLcEcEG=GI_AFTSU9200200001bd8BU5JdF<DI_9Zm6KC009Rd`07H]ARdfKCI]AVm6Kc
I_@016[d0V[C00=Zlf[eJ_D03f[e0flE00A_56kdK_A^m@A_50A_5@04KaI_5FlFKaH5KcH00fleKcI_
=P0@KcH2KcL>KcH02WMHNgQgNG^IOm]oo7oMKaQF3dg]0TG^00U5cDW]ALa>;VLeLiMBTbd964<00Q13
00HHPaB358<DPaBT6:@26<D041RU5:@@Q1246<@HY1RS7:<TiBdW<BPeBCEX=H/aJbe;0Re[00@Y:BD8
9@PU208U:@04:@PPaAc67>H27<H011S55:DDQ1B40aB300`@Pa1R368880a0440<8110560dhU7XCJP2
AJT013U6>FQ:3E9;0UI;0UY:0UY;1EY<0UY;1eYZ0eY/015JC5Y;FTaJJeY:FVaNK5j<HZeVdFKcJaA[
=VlhLcMcF7=I00=cN@04LgMcN7=HLgP6LgL00gMfLeIgEP02MeH00gMgLeMcM`02LeL01GMgLgMcMg=H
LeL00W=H3W=G00=_Eg=GLeL00W=F0W<f00AcEVlfKeI_E`9_EP03LeI_EW<f009c=P9_=P04KcM_=Vlf
LcH3KcL2KcH2LcH00g<eLcIc=P03KcL2KcH3LcH00flfKcM_=`02KcH3LcD00g<fKcI_=P02KaD03flD
Ja=^lVJaH[9N/ejA>Fd89000200@@0`P340@H@024442344234000`a1360<@0073402464358825684
588248801aB2468@HA22588DHQB2008@HP03488DPQAR00PDPP04464@HQ1Q48826:800aRQ584DH@03
46400a11340DPP02584248400a22464@H@0248801aAR468@HQ1R588DPa2200<@HP0:444@H1B15:8@
H@aQ344@HA1R368446400aAQ568@HP02468336801`Q1464@HQ1R588@PQ1Q00D@HP<@H@03588L`aRS
00@@H@04484@HA1R368246800aB2468@H@023440111Q6:8DPQ211Q1Q1122111Q00@@HQ1Q468<H@<@
H@05568@HA1Q468HXP034640211P360@H@aQ464DPQBS488446401`aQ360<@0a0364<HQ1R008<H@0:
368<H@aQ344<HA1Q368<@@`P340336400a1Q360@H00336400`aP364@@00234000`a1364<H@043643
464248800a1R464@@00244400a1R38<@HP0234000`a1348<@@06344234000`aP364@P@0236400`a0
468<HP0236401@a1340<@@aQ36000Pa00@`P000334400``Q344<@@0734400`Q1344<@@0634432240
0`Q13444000300003`PQ58@]9cg;CTmJT5j?H[1R/F:`GXmNKej?GVmJC@03FTh2GVl2GVh06Ui/I/iR
ZW<9DR`TH@00100a0TFSBPYFCEj]HZmJSeY_H[5Rdf;dH]ANdekBFY5>;c5;30D200004QQ2@HMRCFk`
H]5Re6;CG[=NTUjCFW9JDEYaH[9Ndej@?Hd80P800006@HURRVK]Ka9VdF:a1F:b00AR/f:bH[5R/@=R
d@03H[9VdVKB00QVdPQVd`AVdP07I]=[56leKc=gCf9<;<@00P0000LH83U3GV]_;f;aI_AVd`03H]<6
I]<01VKDJ_=Zlf[bJ]9Zl`YZm0AZm@03J_AZmF[e009Zm007KaE_56lDKaA^m6lDKa<00VlD26lE00I_
5VlEKaEc5FleKc@2KcDNKcH2KcL04g<gKcQ_>7=HMiYk^WMiI]E=kDG]@Ldm[TG^BPi:3Cg;?Ndi[ARW
00840@05328DI1AS56<@HP0348<03Q1S48<@Q1B46:DLiRD8:DTiZTH?ANiN]GonOol2Ooh03FLjCWE>
E4ic@NlaK2U:9BXQ21cW8<HPaAc4008La@046:DHa1BT5:D258@358<246<04Pa2340@@0`0200<82C2
AFE9Yd68AJU1RCUXBPeFJeY[FT]FBPMJB`04FTaJK5Y/FV`3FT/015Y[FVYJJEYZ0UY/01IJJeY<FTaJ
JeY:FVaNK5i[HZeRd6KcJaA_=VmGLeMcF7MiLgUcNW=iLgMcF09cN0IcM`9gMP03LeIcEgMF009cE`05
LgMcEg=GLeMcM`06LeL00g=fLeIcMP02LeH5LeL00fmGLeM_E`03LeL4LcH3KcH01VmGKeI_EW=FLcI_
=PE_=`=_=P=_=`06KcIc=W<fLcIc=G<f0Vlf00=c=VlfKcH01Flf0Vlg0Vlf00=c=7<eLcD00flf011_
5FlDKa=ZlVkaJ]5Vdf;DGY0a:`02100@@10P440<@08@@007340<80`P320<@11046001@a000<@H0aP
46401QB20a2200<DPAB258400Q210QB100H<@A1R568DPQ2246845682588356800aR26:<DPP025682
58800aB17:8DH@025642464010a0460DPAR10aB100H@H@aP464@HAB3588246801A2358<@PQ223680
0Q1R00/@HA10464@HA1P2208@11Q368@PQ21008@H@H@HP0348<@HQ1R00D@HP8@H@8@HP04364@HAB2
584246400`a0464DPP0246401a1R488DPAB1464<H@aR008@HP8@H@03364<@A1Q008HXP03584@H11Q
008@H@D@HP0:488@HA1Q464@HQ1Q588DPa1R340446401Q1R588@HPaQ464@H08<@08<H@D@H@8@H005
440@H11P464<@00436400a1Q364<H@04364010aR344<80aP0`aQ0`aP0PaQ00H@HQ1Q460@H1104602
3402360236400`a1444@@002464258801Q1Q340880a1364<HP8<H@06344880PP340@@0aQ0Pa100L<
@0PP220<@0aQ360@H0023402344236401@a1340<@11036400PaP0@a00@a10002344234800`Q2348<
@@043442348010Q224488@Q110a100P<8@PQ2448@PQ134488@000P@P0P0000/<@RCV<HY1k4X^CRiB
LEj@GY5JKej@009R/@0EHY1NL5i`HY5V/V:@HXmZd6/@Ke=NK330100802cS@LQ:25I]HZeRlF;A009R
/008H]9NdekdE[9:DCF]9@THHP800008500e:4i?H]1W56;BH[9NT`9NTP9JTP06FW5JT6;CFY1642cW
0P0000LL046/F]5W4F/cH]5R/@06H[801F:cH[9R/V:bH[400V:b00ARdV:bH[9Rd`=Vd`03I]9R/VKB
009VdPMVd`AVdP09J]=VdV[dLcEcEG=hJ_A=kBA100800007500m[5JaHa9[4f;AH[400V;C00=VdVJc
I]801FKC0V[C00=Zlf[dJ_@016[c26[d00=ZmF[dJ_D00V[e0VlE00E_56lEKaA_56lC009_509_5@03
KaI_5FlE00M_5@9_=@03KaE_=Flf01i_=P0HKcMc=g<gKcM_F7=iKeQRe58_ANe1c47]@Nhe[Be:8>LD
Y0a2224400P1224<8Pa20Q1R00hDPaS48>DPiR46:BTe[3W=?Ni:DUkFJeUgVgoM2Woo00ekgG>LJg]N
n4ic@PleS35::BPPaQc56<DHY0025:@01aBU5:@DPaB348<DPa1S008@HP0>464@80P0200HHRS4>DM>
3EI>ALXmZDh=FV]JBPIJB`04FTYJBeY;FT`3FV`2ET/015Y/FVYJJUYY0UYZ0UY;0eY<00eJBeY/FV]N
Jf:]H]1VdV[dKcIcEgMGMgMcF003LgT3LeP00g=hLgMcM`08LgL3LeL5LgL00g=GLeQcE`02LeL017=g
LgIcMW=G0W=F2G=G0VmG00AcEg<gLcM_=`U_=PM_=`04KcI_EfmGKeL2KcL00g<gLcIcEP05LcH5KcH4
KcL016lfLcEc=G<e0Vlf01A[=VlEJaA[4f[bJ_5V/FKCH]AFLBcX00480A1P420@@0a0440<@11P0Q1R
00@@@0a0340@H08<@003320<@0a0008@H005464HXac3588@PP0258801A23488@PQ2158800QBR0aB1
00@@PQ1R468@PP8DP`06468@@A1R468@PaB20Q1100DDHQB25:<DPQ22008@H@8DPP<DP@8DH@05588@
HP`P564HXP02584446402A1R488@HA1R488DPaBT588@PP0248<0111R464<@1AQ0Q1Q0`aQ00@<HQ22
484@H@H@HP03488DPa2300T@HP08588@HQ1Q464DPA1R444<80<@H@08340<@A22484HXa22240<HP8@
HP07464@HQ1R468@HAB248801Q1Q111R00<@PQ1R46400Q1Q0Q2200<@Pa1R36001A1Q00P@HPaQ364@
HA1P464<H@Q00`aQ00<<@A1Q46400Q1P00<<811P46400Q1Q1PaQ00<<H0a036400`aR00<<@@aQ3640
1@aQ00<<H0aQ36400Q2200@@HPa1444@@0D<H@8<HP03464@@11Q00<<H@03464@HPaR008<HP8<H@05
344<HP@0220<@00336400`aR364<H@0536401Pa0220<@@a1364<@@@<@004364@HQ1R3601368000@<
@@8<@P04244<@@a124443443244334400`a02208@@05344010Q25:@HXa1Q0`0000`881B29>@]9C57
=FTiRTG/CRmJCeY@GW02HY406V:BH[9R/VKCI_5_3U9^>B<800@0;<=5XdX9EXeRcfl_I_1Vd5j?GVmB
L4X=>JXa9b2T1002000020`0<@=9jF:ZI^e[46:`GY03FW4025YAEW5N/ejaHZeFCSf966<200001R2T
ERec;f/BJaARdPER/P=R/`9R/P03H[5R/V:a009R/P03H]9RdF:b009R/P9VdP03I[9RdfKB00=VdP9V
d`04I]9VdfKCI]<6I]82I]<01f[dJaEc=FkdI[51S@`3008000069<E5jF;<Ja1Rd5jb0V:b00=VdVKC
I]<00VKC00EZdfKBJ]9ZdV[b009Zl`=Zm003J_=Zm6[c00IZm003J_EZm6[e009Zm@9_5@=_5005K_A_
4flCKa=_500<KaD00flDKaE_=004KcD5KcH00fleKcI_=P0=KcH00g<fKcI_=P02KcH3KcL03VlhKeQc
N6mGG[9F;4G]@La63DH^>JXPiQ1T1042000010PP340<80a00Pa1014DPR3U<FLiZT8=BRm:<4H`CW=J
]5keJaMcFGNLOkeooWom00aoo`0;NmicNfLGF[E>DD7^=H/]:BD77<HDY@0258@24682348246<00a1R
348@@P02448030PR100@022UBL]F:d6X@JY>;EYZETYJBPEJB`9JBP9JB`9JK003FV]FBeY[009JJ`06
FVYJJEYYFVUJJUY;0UY<00aJK5Y;FVaJJei[GX]R[V:aI]9Zm6/ELcD2MeH3LgP2LeP:LgL00g=fLeMc
E`04LeL3LgL027=GLeQcEg=HLgMcMWMFLeL4LeH00g=fLeMcE`02LeL2LeH4KeL00g<gKcM_=`0:KcH5
KcL2KcH2KcL00fmGKcM_=`02LcH2LeH2LcD00g<fKcI_=P02KcH2LcH3KcL2KcH3LcD3KcD03F/EJ_AZ
m6[bJ]5Z/F[CI]=>3R240004011000D<@003460<@0a000L<@08@@08@H003464HXQRR00<@PP<DPP03
488@PAB1008DP@8@P@04584@HQ1R468248802Q1R464@@A1R464@HQAR468@@A1R1A1Q00@@HQ1Q464@
H@@DH@05468@HA1Q568HPP03584246401122468@HA210Q1Q00L@PQB2488@PQ1R368@HP0234444640
1Q1R488DPQ22584@H@8@HP05464@HQ1Q464DP@0246800`a1468@HP02468246444680211Q564@H@aQ
220<811Q4842464246800a1Q468@HP0236400`a0344@H@0?46434880111Q460@PA1Q0Q2200<@H@aQ
4640111Q00@<H@a0240<@0<@H08@H@053648@0a1364@H@02460010`P340@@1100Q1P00<@H@aQ3640
10aP00D<@0Q0344<@11000<<H@05464@HQ1Q340@H00246400`aR468<@P03344010aR364<H@aQ0PaR
00H<HA1Q444<80PP3403364246400`aQ344<@@0334402a10444<@@aQ464@HPa1340@HA2246000P`P
00<<@@a034400PaQ00<<@0PP32000Pa000@<@@a0340<H04<HP000Pa11@a210a100H8@@a1344@H`QR
3442368434400`Q1344<@@0234401@Q28@HmYCV56:<01@00024400`Q468LY235:@L]:34X=DTmRd6[
ANe>;e9aEY9F/dh^<BH@0000400PY3E5?JQ:2U9_DTi:3SV:=DPXiB355440100000XD03DXCS1N[fLC
I_5VlVKBGW1JL@9JLP07FU5JLF:cG]=JeDX@:<D00P0000LDHCF/DY1W=FLBJ_9R/003H[43H[83H[<0
1F:bH]=RdV;BH]400V:b00=RdV;AH]800f:b00AVdV;CH]=Rd`AVdP9Vd`03H]=VdfKC00EVdPAVd`0?
I]9Zm7=GLgU[FU9b:@T80000520eRUI_IcARl5kA009RdPAVd`04J_AZdf[BJ]82J]<01F[cJ_AZm6[d
J_<026[d0f[e00IZm6[eJ_AZm6lDJ_@2Ka@00flCKaA_5002Ka@;KaD00flDKaE_=@02KcDDKcH4KcL4
KcH2KcL03flhJcQcNVmHH]=F;4G;@L`mc3F/:DXLaPa220040002224234003aB16:<LiBDW=HU234H^
BU1:L4YaBU56<Cg`>JdeR`02<DX0835;>D`i2CdYFM1gG7ooOmig>UWBAD]5KDF^BNm:<E9cDYE>LdXa
AQ16<4YAAS123cg_>JdaJbDX7<DHY11R368334834682348030a3200000P088<e0cU5?JM>;EI[ETYJ
BPEJB`=JBP03FT]JJeI/009FK09FJ`03FV]JJUY9009JJ@06FVYJBeI;FT]JC5Y;0UY/00YJJei[GXeR
Sf:aI]9Zm6leKcIc=`9cF004LgQcF7=HLgL8LeP01G=gLeM_F7=GLgL01g=G0W=H0g=G00=cEW=GLeL0
0g=F1G=G0W=F00EcEfmGKeM_Eg<g009_=`Y_=PE_=`03KeM_EVmG009_E`A_=`9c=P03LcE_=Vlf00E_
=PA_=`E_=P9_=@04KaA[5F/DJ_<2J]801FZaI[5Vdd6[54800P@000@880a0344<@@8<@003360<@0a0
00<<@0<<@@04340@@110460246402Ac3584@HA22588DPaBS6:@DX`025883484258802A22468@PQ22
48<@PQAR464@@@02568011R3468@HQ1R0a1Q00P@HQB25:<DPQ22464@PQ1Q0QB200<<HA1R58<00QB2
0QB10QAQ0Q1R00<@PQ2358800Q1Q111R00<@PQ2346800Q1R00@@PQB2488@HP8@PP04588@PQ214883
464236400a1R464@H@0;46801`aQ564DHA1Q364400P0008@H@06484@PQ1R588@PPaQ0Q1R0PaQ0a1Q
00P<@@a0444DHA1Q564@HA1P1A1Q00<@PA2246800Q1R0a2200<@HQ2246400PaQ00<@H@aQ46800a1R
0PaR0Q1Q0Q220`aQ00P<HQ1R588@HA1P220<80a00Q1P00@@H@aQ340<H08<H@0:460<H@aQ368@HP`P
444@HAB348<2468246401Q1P360@H@aR468@@@8<@@@<H@05488<HPaQ364@H@0336424680211Q468<
H@aQ340<@@a0344244403Q10444@@@a1468@PQ1Q440<@@aQ464<80a034423683364020a0344<H@aQ
344<@0`P3401344000D<@@<88@8<8@033448@@a1008<@@03244<@@Q100P<@@08340<80a16:5:9E9Z
ANLDX`<0000C100800a1220400PQ448DHa12420D@AQP788T`bT4<DHY9QRT10000`0000<400`P4400
0QaP00<H@10010001@0000dH83U6BNUFCFK>I]5VlV;CH[9NTUYaGU5JL@02EW801UYbHY9RT69^@H/@
008000078:962Ek]Ke5VlFKBG[400V:a36:b16:a00=RdF:bI]802FKB3VKC0VKB00QVdf[dKcE_EGMD
I]15c1aT0P0000LXa58]J^aVkf[aI]9V/@03I[8016KBI]=ZdV[B0V[C00=VdfKcJ_<016[c00=Zm6[c
J_@00f[d0f[e0V[d00=^lf[dJ_@00f[d00=_4flDKa@00VlD00=[5FlEKaD01flE0flD0VlE16le26lf
00=_=FlfKcH00Vlf00A_=flfKcI_=PE_=`03KcE_=Vlf00=_=`0=LeUcNFKeETi1bd6Z?JXaBB353284
00PQ22000PPQ014@PQBT9@H]AbeX=HLmb47:>JTaJ2U79BLLiQBU34<8@P@Q00P0000410<410@20046
00002P@0000000@Q248@HaS58>HY9be80S5Y0SVZ00LaJ2DX8>HDY11S2448800334403A1R368@@@`0
200<010P8:4mYeY]FV]JBUYZ009JBP04FT]JJUY:FTT2FTX2FT/00eI;FV]JJ`02FVX5FVT2FVX2FV/3
FV`3FV/02Ui/GXiR[fJ`I]9Zm6/EKcIcEg=H17=g00UcN7=HLeQcF7=ILgUcFG=HLgP017=g0W=G00Ec
EW=GLeMcEg=g00AcE`05LeIcEG=FLeIcE`02LeH5LeL2LeH3LeL00g<fLcMc=`03KcH5KcL01FlfLcE_
=VlfKcL00Vlf00=c=VleLcD02Flf0g<e0W<f0Vlf00E_=flfKcM_=flf00=_=@9c=@06KcE_=6lCKaA[
56[c0V[B00MZ/6J^GW0iJPP0100<@@0244002Q1P464@H@aP460<@111468@HA110`a10`a000H@H11Q
488HXaB14842588011RS6:@LY1RS0aB20Q221AB200<DPa23588011B200<DPaRT44400a1Q00<@H11Q
46800a1Q00DDPAB2488@HQ1Q008@HP0546<DPaRT564DH003564?46801122588DPa220Q1Q00XDPQB1
464@H@a0464@PQ1Q3448808<@@03464DPA2200H@HP8@P`<@HP8@H@03364<@0a0008@H@03484@PQ22
008DPP05468<H@a0340<H@0346401`a1220@@AAQ540DH11P00H@H@05480@PA1R468<@@0246423684
36400`a1464@H@024642468258<0211Q364<H@aQ464<H@aR468246400a1P340<@004464020aQ360<
H11P340@H121584246434440111Q468@PQ220PaQ00L@H0aP364<H@a1440<@00336400`aP364<H@03
3642468348800a1R464<@@0234401`a0344<@@a1364@@A1Q008@@@8<@@03340@H0a000@<@@8<@0<<
@@07364<@@a1364@HPaQ34400`a00@a10003344010Q134488@PQ0``Q00<<@@Q124400`Q100<<@@Q1
248020a10PPP00l@@2e4DVaJcTi]9>@<80P0000HHQc5;BH]Abd5;BD00RT500DTi1c2564<80@000l0
000:100@02B1<@HmRTW]ETmVd6KaI_<2H]800ej@FW1NK`03GW005EY@EW5NT5jaETm:433W100000P0
=BI>L6LAKcARd5j@GY5N/V:aH[9R/@0=H[82H[400f:bH]9VdP03I]83I[8AI]<016KBI]=VdfKC0V[b
00Y_4WMFKcER/cU8200000P0@JeVm@9Vd@03J_9^m6Jb009Vd`03I]9Zdf[C00=Zd`03I_=Zlf[c00=Z
l`EZm0AZm@04J_AZlf[dJ_@2Ja@2J_@2Ja@3Ka@4JaD6KaD3Ka@01FlEKcE_=FlfKaH02Flf00=_=Flf
KcH00Vlf2Flg0flf0flg00YcN6KfEU95kT6]>H`a:B2U328800888@0>468DPaS59@LYBC6:<J/aRbDX
6:DDP`a1224401@0000300448P@000T00008100880a258<DYBDY;HXaZ`8]RP05:BPLaAB3588@HP02
344010a2448@@Q120P@000HThdGWGXaJJUYYFVX2FTX015Y;FTYJBUY:0eY;0UY<00=JBeYZFVT01EYZ
00EJJEY[FV]JJeYZ00=JK09JJ`0;FVYJJei]GXiR/6;AI_=Zm6leJcM_E`02LeL4LgL2LeL4LeP00g=g
LeMcM`02LgL8LeL01G=HLeMcEW=FLeD00W=F00AcEg=FLcIc=PAcE`9cEP=cE`9c=P03LcM_=flf009_
=PA_=`04KcIc=FlfKcH2KcL2KcH00g<fLcEc=P08LcH3KcD4KcH00flgKcIc=P02LcH2LcD01G<dLcE_
=VlfKcD00VlD00aZlf[bJ]9VdVJaJ]5JD3DY1008011Q460244001a1P464@H@aQ464@HPaR00@<H@<<
@007440@H11Q488DXaB134000QB200@@HQB3688HXP<DPP06464@PQ22588DPaB20QB300<@PaB27:@0
0QB200DDPaRT58<@HPa100@@H@05468@HA1Q444<@002464446802A2358<DPQB2564@HA10564DPP06
46801a23488@Pa22468<@@aR00@@HP<@H@8@PP05464<@11Q484@PP0446801`a1464DPQBS488@HQ1Q
00<@HP06344@HQ1R58<DPQ1R10aQ0a1Q00D@HQ22488@PPaR00<<@004364@H@aQ3642344010a2464@
@1AP0QB21A1Q00P@P121468@H@a0344@HA1R10aR00H<H@a0220<@A1Q3642468011B3468@H@a00Pa1
00@@HA1R48<@P`@@H@P<H@07464<@110340@H11Q46800QB20Q1Q00<<HPaQ368010aQ00<<@0aQ4640
0Q1000D<@@aQ364<H@aR00@<H@03368@HQ1R00<@HP04464@@111340236401A1Q468DPQB346400Q11
00H880`Q340@H@aQ348834400`aR364<H@0534423401320000D<@@888@03244<8@`Q00P<@@03348<
@@a100D<@@0I324880P0200DH3USG/aNl5J==FL@@P@0300PXc44?HE9jE9;EVaBKE9^BRa:2SEX3280
0`0000H401B08:0ThRT2:@@2;BD03CDU>DHiAT68BNYFC5i]HXiZcf[@J_5ZlV;A009JT@04FW1NSeY_
FVl2FW001eY?GY5N[f[^HXe1ZAa20080000;645>36[[I_1[55jbG[5NTEjBG[9R/008H[47H[83H[40
1V:bI]9V/VKBI[9V/@9V/P9VdP04H[9VdVKBI]87I]<00fKBI]=Vd`03I]<2I]82I]401fKBJ_=c<g<b
L`i5kQ0400800007=@UF36:>J_1ZlVKBH[800fKB00EZdfKCI]=Zdf[d00=Zl`04I_=Zlf[cJ_<2J_@5
J_D3J_<01V[dJaA[56/DJ_A[50A_509_5@=[5@A_5@03KaA_4flC009_509_5@04KcI_5VlFKcD3KcH0
16leLcE_=Vlf0fle1Vlf1Vlg01=_=W<eLcIc=W=HLeMNTdg_=B/e;2d;9<H<8P@1328<@AB36:@Q1P02
:BL01BTX7>HDQ0Q200401`0000@400@P220880@4000812440000100480@012440@840006468DPa23
3488@PQ10PPQ00<800@000000P@000<4800000000P0001L48AB36<DY9cEX<FTYAacV58<@H`a2468<
@@`R20880@P2<DIBB5j/HZUJJ5YY00EJBP04FTUJBUY:FT/2FT`00eY;FVYJJ@02FTX015YZFV]JBUYY
0UYZ0UY[0UY/00AJBeY[FV]JJP9JJ`06GVeRSV:`I]5ZlV/D0Vlf00Ec=WMFLgIgMW=g00IcE`03LgMc
Eg=G009cE`9cMP9cE`04KeMcEg=GLeL2KeL6LeH00g=GLeIc=P02LcH2LeL01g=FLeMcEW=GLeIcEg<f
009c=`03KcM_=Vlf009_=P07LcI_=W<fLcIc=7<eKcH00Vlg0flf00A_=G<eLcEc=P=c=@03LcIc=Flf
009_=P=_=@A_=P=c=P9c=@03LcAc=Fle009_5@0<JaA[4f[bJ_5ZdFJbI[1Z[e8`:>H400P00Q1P0Q10
10a00`a100L<HA1R460<@110340@@00346002A1Q564@HA1Q340@@A1Q568DPP0368802QB1460DPA21
588DPaB2468@PaB30aB200L@HQB35:@DPaAR364@HP0=46400a1R344<H@0246835642464346800a1Q
344@H@0946800a1Q340DH@024883468246400a21588DPP044680111Q488DXa221A1Q0Pa100P@HA22
588@HQ1Q364@H0aP0Q1Q0Q1R00@@PQ1R464@HPL@H@07444@HQ1R444@H1B04840111Q00@@PA1Q480@
H08@H@L@HP09368<@@a1344@HA1R464@HQ1Q008<H@03464<HA1Q00<<HP8@HPL@H@03364<@@aQ008<
H@8<@005220<@0`P340<@@0346400a11344<@@0536402A1Q488DPA10460<@0aQ488@H@0:36401`a1
340<@@a0320<@0aQ008@H@8DPP06464@@A1022088@a10Q1Q00@<H@a1344<@@<<@088@@<<@@<<@004
344<@0Q034013200008<@@06468<@Pa1344<@PQ210a10Pa20P`Q0Pa100<<@Pa134401@a100<@@P`P
32000PP001@HHD77Gc9NkeJa?L`Ta0`0000801b2<BDmZ4G8CRaBKU:@@P/Y9aAS0P0000LDHC4S>HM5
j5I_H]5S4P03G[401f;AI_=Zlf[AJ_5Zl6Ka009Vd@04HZmNT5Y`FW02FW42FY42FW4045Y`FViNSVKc
EU0iB@P0000@03F;D[5WEVLcIa=Rdf:b0Uja00ENTUjbH[5N/V:b009R/@QR/P03H[=R/V;C00ER/P03
H]=R/VKB00=V/PAR/P9VdPmVd`AVdP0?J_9_=6ldKgUR]34:200002ASBNeR[FKaH/iR/6:b00=VdP04
I]=Vm6KcI_@3I_<6J_@3J_D7J_@4Ja@4Ka@01V/DKaA[5F/EJaI_5PA_5@9_50A_5@04KaI_=VlfKcD@
KcH5KcL3KcH01W<eMcMcF6lfFU51[@8i:P048:H@@PP044<258<01R3V9BLQ1aS458<<HP8400<00004
10448@@Q12022242244422002`PQ348<HPaR240880a1348<@@a236<00Q1S0Q2300L@H`aS36<<HPa2
34488002200234400`PQ1000000300003@@0220DPQRT8@LYJReZ8@LDPPa1348<H`a2008400067<E6
2FL=I/UNR5YY0UY:00MJBeY:FTYJBEI:FTYJB`02FT`00eY;FVYJJ@02FTX00eI;FV]JK003FV/3EV`0
15Y[FTaJC5Y/0UY[00aNJei]HXeR[fJ`I_9[4fleKcIc=WMELgH2LgLFLeL5LeH00g=GLeIc=P02LcH0
0g=FKeM_E`05KeL6LcH6KcH01W<eLcI_=VlgKcI_=`9_=P=_=@03KcIc=Vlf00I_=P=_=@A_=P9c=P=_
=P0AKcE_=VleKaA_5F/DJ_AZlVkaI[5V/VJaIZi>3ab60008000346000a10340<@00534000`a1364@
H@02440030a0440<HA1P464DHAQQ684DPAAQ440DH@8DHP04588Pa1RS588256401a1Q588DPQ22368<
@AB300<DPP05468@PaB358<@P`074682464011AQ688DPQ1Q0a1R00D@HA22588DPQ1R00H@H@<@HP8@
H@H@HP08488@HPa1320DPQB3588DP`H@PPL@HP05488@HQ1R368<H@03464246800a22468@HP023644
464246854642588246400a11464@H@04468446401PaQ468@HA1Q584DH@8@H@8@PP05468@PQB2588@
PP07468546400`aQ468@HP044685464010aQ464@H0aQ10a10`aQ00X<@@`P340<HA1P364<@0PP340<
@@8<H@<@HP0458<DPQ1044433640111Q364<@1100Q110Q1Q00<<H@a134400PaQ00<<@@PP22000Pa1
00@<HPaQ464@H@<<H@8<@@L<H@<<@0032208@0Q1008<@@8<@08<H@03344<H11P004<800010a100/<
@0PQ2248@@a1244<8@PQ228<8Pa200D<@@05340<@@a2344<@P0234403@`Q340800@0200]1E9^JdaJ
cUZ_BP/eAaA100<00006200@@1QP880DH0@00P0000P<82B2=DI9je9^HZiVcVK`0VKA00AVdV;BH[9R
/P9R/@03GY1NSej>009NKP03GXiNT5Y`009JL003FW5JL5I@009FD005H[5VcfJ/AJ/P8`0200001RBR
ANUNcF/_G_1RdPAN/P03G[5N/Ujb009N/PAR/@]R/P=R/`04H[9RdfKBI]83I[83H[82I]8CI]<04VKB
I]5VdV/DJc=gLV[f=Dd<0P00620mQf;;Lg1[4VKCH[5VdP9Vd`05I_AVlfKDI]AVl`02J_<7J_@00f[e
J_AZm005J_@9Ja@016lDJaE_5F/E1FlE0VlD1VlE16le00=_5FlFKcH00fle3Vlf0W<e019c5G<fMgQ_
5E8_?F/`iRB3448<0A1358@LaBD68@HHY11R220410001@@P22088@PQ244010PQ00d48@PQ220<@11P
588DQ1cV:DTU9acU8@DQ1P027<D01acV6:DDPaRT6<DHY11R008@H`8<HP09344<8@PP320<@0a1248<
@@Q100888@03220400@000840008224@PQcU9BLU1Qc558<<H`88000@100802T3DV]_1f:YGVUNB5i:
FVYJJeYZFVUJBEYYFVX2FT/015Y[FVYJJEYZ1eY[0eI/00MJJeY<FTaJK5iZFV]NJ`02GV`02F:=IZmV
dF[aJa=_=FlfLcIcEP02LeL3LgH00g=gLeMcE`0BLeL4LeH00g<fLeIcEP02LeH2KeH2LeH01W=GLcM_
=VlfLeIc=@=_=@e_=P04KcEc=FleLcD3KcH00fleKcI_=P03KcH2KcD6KcH00g<eKcI_=P02KcH2KaD2
Ka@2J_@02f[aJ_1V/FJbJ]9bl4F/56D000`P44000a1P2@a000<@@0a032000Pa000X<HA1Q464DHAR0
6:4DPAAP440HP@DDPP05584@HAAQ564DPP024880111R46<DHQR20QB200DDHQ1S58<DPQAR00L@HP<@
H@8DP@04464880@0340248400aRR588@H@04464010a0464@HQ1R0a1Q1Q1R00@@H@a1344@@@<@HP04
46<@Pa224882588246824645468010aR344<@@a10Q1Q00HDPQ22464@H@aQ4443464010aQ464@HQ1R
0a1Q00<@PA2246400a1Q00<@H11034000Q1000<@HA1R46800Q1Q00H<H11Q364@HQ1Q364546424880
1A1Q584@H11P46400QB2111R0PaQ00D@PA1Q360880a0008<H@04368@HQ1R468246433643464010aQ
344<@@`Q0Pa10PaR00H<@Pa1344@H11Q344334001a1P360<H@aQ464@PQ1Q00<<@@03364<@0`P00@<
@003344<HA1Q008<H@8<@@03460<H@a0008<@@05348<HPaR464<H@0234001a1P364@H@aQ344<@0a1
008<H08<H@8<@0<8@004340<@@a0440236400`a1340@H00134000003344<8@a1008<@@88@@032488
@@Q200888@888P042248@Pa2348236<00`aR344<@P0434804Pa1320800`Q100HPT79FXeS3eZ_H]5N
/DX_>FTXXaPP200400<0000;200H@2C4>FU5je9?GXmR[f:^GZmNSP02FVh2FVl3FW02FVl2GVh01Ej>
GY1JKeY_FY000UZA00UJL5Y?ETiFCEj@I]1Ve45[30000P0000Li9e9`H^m[4fKaH[5NT@04G[49G[80
0f:aG[9R/P06H[87H[<00f:bH]=R/P04H[82I]83I]<3I]89I]<00f[dI]=Vd`03I]<3I]803V/CKc=c
NF;f@NlLI000300eJU9`G_=Rd6KbH]<2I]83I]<2I_<5J_<8J_@2J_D2J_@00f/DJaE[5@03Ja@5JaD2
KaD2K_D3KaD01FlDKaE_5FlEKaH00flE00=_=VleKcD01FlE0Vle3Vlf019c=W<DLaE_5g]iKaI9kRd9
668@@@`0448DQ1c68@LHaA1S220200000`@02208@@02244222400`Q13448@@03244334402A1Q6:<L
aB47:DX]JbeZ:DTY:0029@L01b478>LLaQRU6<DHY1B3008@P`8@H`8@P`8<@@03320<@0a100P8@@0F
224400@01008011R6:@Q:2477>H@H``P200000P0<D=FJV;;GXUNJEY:FT/2FVX3FTT00eYZFT]JK002
FV/01EYYFVYJJUY/ET/015I/0eI]00AJJeY<FTaJK09JJP09FV]NK5i/GXeR[VK@J_5ZlVlE009_=P05
LeMcMW=fLgIcM`0>LeL017=FLeMcEg=F17=G0W=F0W<f1G=F1g<f0Vlf00=_=FlfLcH017<f4Flf00=_
=FlfKcH00flf00=_=FlfKcH02Flf00A_=FlEKaE_5@9[500=J_=ZlV[aI]5R/F[aK/`iB@@1100@@11P
44000a1P00D<@11P460@H0aQ008@H@8@@@03344880a000@@H@06564HPAB1464@H1100aB20QB300L@
Pa1Q464@HAAQ588@PP0346800aAR588DPP025882568011AQ568DPaB30Q1R00H@HA1R568@HQ1Q4682
56401AB13408811Q58800Q220Q1R00H@HAAQ464@H110564258<448834680112358<@HQ1R0Pa11A1R
0Q2200@DXa22468<HPD@HP8@H@<@HP<@H@8@PP<@H@8<@006464DPQ22464@HQ1Q0Q1R00<DPQR25880
0a1Q00P<@110464@@11P564@HA110Q1Q00H<H@a1340@H@aR468446400`aQ464@HP0248801QB1560@
HA1Q584@H@D@HP05488DXQ1R364<@0033644368236400a1R464<H@0446402`aQ344<@@a1468@Pa22
368<@Pa146400`aQ00<<@@a036000PaQ0Q1Q00<<H@a034400Pa100D<H0a1340@@11Q00@<H@03344<
H@aR008@HP8@H@03364<HQ1R008<@@06368@HPaQ340<H11P0`aQ00<@@0a036400`aQ00/<H0a03408
@@a1244<@0Q0340@HA1R008<H@4<H04@@04@@00000T<@@`Q34488@Q1224<@@a224401@PQ00<<8PQ2
34800`Q20`a110a20Pa101/<8PPR204<8BSSAPUJd5kbG]5RdEj_HXiJCTh<?HPmIce6?FHmR46YALYF
CFJ]IZaRSF:>GXl01eY^0eY_00=NSeZ?GXh00Ui^0eY_00YNSeZ@FVmJCUI>FXmRceZ?CP`/i`800007
3015ZfJZH/eVd6;AG[800ejA1Uja00=NTEjaG[800ejb16:b0f:a0V:b00=N/V:cH[<00f:b00AR/f:b
H[9R/@ER/P05I]9V/V:aI[9VdP03H[801FKBI]=Vdf:cI[<036KC00MVdVKbJa=cE6lCGVda2@020000
21b5CRiVk6;aH]=R/6;AI]82I]<00fKBI_=ZlP02J]<2J_<3J_@00f[cJ_AZl`02J_@2J_D00f[dJ_=Z
m002J_@3Ja@3JaD00f/DJaE_5@0>KaD00flfKcE_5@02KaD3Ka@2KaD2KcD4KcH016leKcI_=Vlf0Vle
01A_=VleKcI_5FlFKaMcNV/EBNhXaQ@Q424<8AB38@HLiA1S34888@@10P@000H88@`P24488@@P2243
344234000`aQ368<H@0236401@a1364DPaB348<00Q2400<@Pa1S46800a1R10aR0Pa20`a10Q1R0Pa1
00<<80a034400`a11PQ10PPP01D40000000<@AS49BLQ1QS4464<@0@0000@@3f1ET]RZEiYFTYJBeYZ
FTX015Y90UYZ00=JJeYZFVT00UYY00=JJUY[EV`00eI/0eI]00AJK5Y]FVaJK0=JBP08FV]NJej=HXiV
[fKAJ_9[509_=P04LeMcMW=fLgH?LeL00fmGLeMcEP05LeL8LeH02g<eLcI_=VlfLeI_=W=FKcI_=Flf
KcD00flf0W<e00=_=FlfKcH01Flf1Fle16lf2Vle26lf00=_=FlEKaD00VlE0V/D00eZm6[bJ]9VdF:`
I/iVRSD5000801AP460@@003340346001PaP364@HAAQ464@@@8<@@06364<H0aQ464@HQAQ0QR100@@
H@a1464DHP8DPP<@HP03568DHA1Q008DH@05468@HA1R464DHP02468358800aAR564DH@0356834640
0aB1588@P@0346401QB1464@HQ22588DP`8@HP03344@HA1Q00@@H@8@HP0:464DPAB1484@PPaQ340@
HQB3588246834643468010a1464@PQ220a1R00<<HQ1R4680211Q00<<H11Q46400Q1Q0Pa00Q1P00@@
HA22468@HP@@H@03584@HQ1R00@@H@03564@HA1P008DH@<@H@03364<@@aQ008<H@8<@0H@H@8<H@<@
H@03460DP11Q00888006344<HQ1Q468@PQ1R0PaQ00l@H11Q3648@0a03648@0PP240<@@a0360@HAB2
464010a100X@@A1Q364@PPaQ348@@A1P364<@0<<8004340@HPaP240334001P`P340<H@aQ340@@08@
H003364@H@aR00H<H@8@H@03364<@0a0008<@@03368<H@aQ008<H003460<H0aQ008<H@8<@@@<@003
220<@0a0008<@0063608@0aP360<H@a10Pa00A100@a000000`a1324<@@02244524801@Q122488@`R
34401@Q20`a100<<@Pa134400Pa200/<@@a246<88@P0440a9Di`F[1J/EZ?009NS`0>I]1VdFK@HY1N
Kf:?I]5VdV:aH[1V/6:=GViJK@AJKP=JK`03FViJKeY_009JK`0@FY1JKei`GY5NT5Y`GVmNL5Y`ETmJ
KUZ^G_9FTCg^8:D2000022RUCS1S4fK>J]5R/5j@GY43GY89G[47G[800f:aH[9R/P02H[83H[<00f:b
H[=R/`03H[<4H[800fJbH[9V/P04H[85I]83H[<=I]<03FKcJaA_4g<eKa=ZmD6;400001@1@NmFeF;c
009VdP03H]9VdfKC00=VdP03I]=Zdf[c00AZm003J_=Zm6[d009Zm0=Zm@=Zm0M[5@03JaA[5FlE009_
5@03KaI_5Flf009_=@A_5@=_5P03KcI_5FlE00=_5@03KcE_5FlE009_5@03KcE_=Vlf00M_=P0FKcE_
=VlfKcIc=VlfKcMgNFleANhXYA0056<HaR476<H@H`a222440@@Q104222400`a02448@@0234433685
34401PQ1224880@0120880<000<48088808400888005124<@@a12248800434422442344336801@a2
344<@@a124400`PQ0PQ100T880@0100<@1B38@HU1QB134400PP000@TP4GXFVYRZP9JB`9JBPAJB@05
FTYJJUYZFVYJB@02FVX00eY;FV]FK003EV`3EVd4FV`2FT/02EY[FVaNK5i/HXiR[fK@J_9[5002KcH0
0g=GLgIcMP05LeL2KeL5LeL2KeL9LeL016mGKeI_Eflf0W=F0W<f1Flf0W=F00=c=VlfKcH01Flf00Ec
=W<eMcEc=Vlf009_=`E_=P=_=@9_=P03KcM_=Vlf00U_=@Q_=P04KcE_5FlFKaD3JaD03F[dJ]=VdVJa
H[1R[Ui/::8400P0560@H11000@<@003360@H11Q008@HP8@H@04440<@@PP364446802A1Q684HPAAQ
584DPQ22468DPP0258<02QB2584DHAB1564DPQ22368@PQB20QAQ0Q1Q0QB200<DPaB256800QAR00<D
HA1R46400a220Q1Q00T@HQ22484@PQ1R48<DXa1R34400Q1R0a1Q00PDPQ22464<H@a0440DHAB10Q22
00@@H@a0364@HP<@P`06488@HQ1Q464@PQAR0a1Q00@@HPaR468@HP8@P`03488@HQ1Q00D@H@8<@003
364@HA1Q00<@H@03460<@0a0008@H@06368@HQ1Q464<@A1Q0Q1R00X<HA1Q464DPABS488@HQAQ468@
H@8@HP05368<@@aR464<HP0236400a1Q364@H@024642460546402AB1464@HPaR468<HPa1368@HP02
368010a1440@@11Q0PaQ00D<@0aQ368<H@a1008<@0<@H@05340<80aQ468@H@0246801a1Q344<@110
464<HA1P00888003320<@@aR00P<H@<<@@03364@HA1R00D@H@<<H@<@H@0E488@HPa1224<HQ22464<
H0a0364<@@a0364@HPaQ344<@11P440<H@aP008<@004364<H0aP2642364334413401440134400003
2488@@a100H88P03248<@@PQ008<8@8<@@8<@Pd<@@0@220800`056<iZUZ@FZmJSeY=FVmJKUi^GXiR
Sf:@GXl2GY400eY`GW1JK`02FVh015Y]FViJKUY^0UY_00=JL5Y_FVh015Y^0UY_01EJD5Y`FW1JL5Y@
FTmFCe9@EVeVcEj??JX@8000100]1E9>J`eW46KbGY001EjA00ENTUjbH[5R/EjA00=R/@MN/P]R/PER
/`=R/P04I[9V/FJbI]83H[82I]8016KAI]9VdVKB0VJc00=VdVKCI]<01VKC0fKB1FKC00eZlg<cKc5^
jdW^40D00002?JiV[VKAJ_=Vl`02I]<01VKBI_=ZlV[bI]=Ve0=Zm09Zl`AZm09Zm@03J_AZlf[d009Z
m003JaEZm6/E00=[5@03KaA_5FlE00=_5@I_50=_5@=_5PY_5@I_=@9_=P9_=@=_5@0>KcI_5W<fOiQo
fW^GDPdTQ10P58@LiaBT22800@840@888P848P06224<@0a1364<HPaQ10a100<8@@PQ22400PPQ10@Q
00@88@@Q100480D88003224<@@a100<<@@<8@@033248@@PQ00@88@T8@@032248@@PQ00888@<88084
000:340DPQc36<<DPPa0200e8eI9H/X2FTX00eY9FVUJJ@03FTT5FVT015YZFV]JBeY;15Y[0eY/00=J
JUY[FV/00UY/0UY[00YJK5i/GVaRSV:_I]1ZlV/DJcI_=P=cEP03LeMcMg=g009cE`=_E`UcE`9cEPEc
E`9c=P=c=@04LcI_=VlfLcH3KcH00g<eKcI_=P03KcH4LcH2LcD00g<fKcI_=P05KcH00fleKcI_=@02
KcD00flfLcI_=P03KcH8KcD00flfKcE_=P08KcH00flFJaE[4`02J_@2I]<01FJaH[1R[dh;76400PP0
111P00D@@0PP340<HA1P008<H@8<@@04340<H0a03442464346801a1Q564DPAAP584HXQBR00@DPP0;
464DPAAP684LXQR3488DPaS36:8DH00246402A11340@HA1R568@HQAR68<DHP0246400a1R488@P`02
468258800a21464<H@0534401a1Q488DPAAQ488DPQ21008@HP03464DPA21008@PPD@HP04488DPQBT
48824640111P464DPQB10Q1Q0a1R00<DPQRS6:<01Q1Q00@@H0aP364<H0<@H@05584@HA1P340<H@02
464236401A1R464@HPa13400111Q00@HXQRS588DHP8DH@05464<@0PQ348@HP0246400`aP464@PP02
36424644460346401111440@@A1Q111R00L@Ha1R468<HPa1340<800246423642368236400`a0240<
@@0336400a1Q364@H@02464020aQ444<@0a0440DPABR460234000`a1364<H@0436401A1P464@H0aP
34000Pa100L@HAB258<@PA1Q460<H00336400`aP460<H00246402Q11344<HPaQ464<H@aP340<80a1
0Pa000L<@@aQ364<H@aP460<H003340336000`Q01208@@03344134014601364000042448@PQ23482
34<01PPS24<<H`a224488P88@@<<@@8<@PH<@@8<@P8<@@0:324<@@a1344400P08:=:35k@FXd2FTd3
FTh00eY=FViFCP02ETh00eI_ETmJK`02FVl3FVh2FVl2FW03FVl3FVh2FVl015Y@FW1JLEY`0UY@00iF
D59aF]E>DSE:200001aR>JaFSfLCH]1N/5j@1UjA00AN/UjaGY5NT@9RT@9R/@03G[9N/Ejb00MN/PQR
/PER/`=R/P04I[9V/FJbI[84H[800fKBI]5VdP02I]83I[<8I]<4I]84I]<03fKBJ_=_=6/cKgUJD1a3
000803UZFW5VlV/DG[9Vd`02I]83I_<00fKdJ_AVe003J_<4J_@2J_D016[dJ_=Zm6[c0V[d0V[e00AZ
m6lDKaE_50E_5@A_50E_5@=_5P04KaE_=FlEKcD4KaD5KcD5KcH2KcD03W<cKaA_56[dJ[AZe6lfNk]g
N57]::DHHac648D210000`@112488P0422800`Q22448@@07244222401``Q22488@PQ12488@@Q0088
8@88@@<88@8<8@T<@@8<8@D88@0324488@Q100P8@@0334488@PQ00888@0>244880@0220@@1B28>HL
aA1R100PP4hYGZaFB`=JBPAJB@EJJ@AJJPAJB`9JC004FVaJJUY[FV/6FV`02Ei/GXiR/6K@J_9[56/f
KcI_EP02LeH2LeL00g=HLeMcE`02KeL5LeL2LcL00g<fLeIcEP03LeL4KeL6LcH00flfLcIc=P02KcL4
KcH00g<fLcEc=P04LcD@KcH00fleKcI_=@02KcH8KcD00flfKcE_=P05KcH01FleKaE_5F/EJa@00V[c
00]Ve6KCI]9ZdV;AG[0mR@`P200<811000<<@004440<@@a03642360434000`aP364@H@0346424680
1a21488DPA1P584Ha1S300HDPP8DH@8HPP08464DXacU6:4@H11Q364<@08@H@<@HP@DPP<@HP0=48<D
PaB358<DXaRS588@PQ1R464@@11Q46800QB200<DPAB248400Q1Q00@@HQ1Q488@P@H@PP0648<@HQ1R
48<DY1222Q1Q0Q1R0Q2200<@HQ1Q46400a1Q00@@H0a0364@HP<@H@04584@HA1Q460246400a21468@
HP02468010aR344@@1AR0Q1R0aB200<DHQ1Q46400QAQ00D@HA11468DPQ1R008@H@05468<PPaQ240<
@0054642460346401A11464@HQ1R58<01A1R00P<@Pa1364<H1225:<@PPaQ0PaR00@8H@aQ364<@08<
H@04464<H@aQ364246401`aR344<80a1440@PA22008<H@8<@@8<H@8@HP@@H@06460@HA1Q440<8111
0QB30Q1Q00@@H0aQ344<@@8<H@08360<HA1Q464<@@aQ368<H@H<@0<<@@07364<H11Q364@H@aP3400
0PaP0Pa000<<H0aQ364010a10@a00A1P0@aQ0004248232400``R2288@P03248534423482344010`P
344<@Pa10`a200<<@@@P34400Pa100L80000320eAE:@H/eNK@02FTd00eI=FTeJC@02FTd2ETd01EI>
ETmJCeY?FVl00eY>0UY^1EY_1EY^00YJKeY`FW5JL5Y@EU5BD5I`AQ4XjP8000069:A:2ek>I`iNd5jA
0Uj@2EjA00=NT5jAHY400V:a00=N/UjAGY400Uja0Ujb00ER/V:aH[9N/V:a00IR/P9N/PIR/P09I[9R
/F:aH[5V/VKBI[9VdVJb00=V/@04I[9R/V:cI[<5I]83I]<4I]85I]<2I]801F/DJa5_CUY^88D00P00
00DiBF::H]5RdfKC00=VdP=Vl`9Zd`EZl`04J_AZlf[dJ_@4J_<3J_@02V[eJ_A_4f[cKaA_5FkeK_A^
mFlE1FlD16lE0VlF3FlE0fle01I_=VleKcE_=6lcLc9_4VkaGTi=[4f[DPeFDUHa@JhXaRC57:<<@P@1
204880@88@0622888@PQ2248@@Q00PPP0PPQ00<8@@PQ24400Pa100<<8@PQ22400PPQ00<48@PQ1240
10PQ00<<8@`P34400Pa100<8@@`Q32000`a100D8@@`Q22488@PP01888@04124480PP220210002@aP
4:<La1RS444LPD6UFXeFJ`03FTX4FTT9FVT00eYZFT]JB`03FT/4FVX00eY[FVaJK002FV`2GV`01V:<
HZmVd6[bJ_=[=@9_=P04LcIgEWMFKeP3LeL3KeL4LeL5LcH2LeH5KeL00flfLcIc=P03LcH00flfLcIc
=P03KcH01fleKcI_=FleLcE_=G<e00E_=P=_=@E_=PQ_=@04KcA_=FlfKcD3Kc@00fleKcA_=@09KcD2
KaD00flDJaA[5002J_<02VKCI]9Vd6KAJ_9N/CU9200400a11`a000<<@@a036000Pa000@<80a0440<
H08@H0@@H@0:484@PQ22464DPABR588@PQB26<@358802AAR564HHAAQ340@HQ22584@@00346454682
5887468258<02QBS6:@DPa22464DP11P464HXaRR0QB200HDPAAQ340@@A1Q584346402a1P360<@0a0
584DPa1R344@HQB348802a1Q0Q1R0a1Q0Q1P2A1Q00<@H11034000Q1Q00<@PA1Q46403A1R00@<811Q
564DH08@H@08588HXa1Q468@HA1R368<H@8<@08@H@07588DPA1Q460<811046000Q1000D@H11Q464@
H@aQ00D<HP07464<HA1Q488DPQ22464010aQ00@<@0aP460@@@8@H@04364<H0PP220434400`aP464<
H002364010aP364<@0a10`aQ111P00@<H11P460@@08<8005340@H11P460<@002220010a0364<H@aQ
0a110`a100/880`P220<80a0360<@0PP344<H11P008<@004464@H0a0360334001Q21488<H@a1340<
@@8<@04@@04<@@000PQ100D8@PPR228<8@`R00@8@P03244<@@a100<<@@05348<HQ1S348<8@033440
0`a2468<@P03344234802@PR204401bS@NaJKV:>FVeJCP02FTl3FTh00eY^FVmFC`02ETl2FTl3FTh2
FVh7FVl00eY^FVmJK`02FVl2FW001Ei?ETeJTDH?78H00P0000HTXdH=GZiRlEj_GXl5GY03GY400ej@
GY5NT@04GY42HY42GY45G[800ejAGY9N/P04G[82H[<;H[800f:aH[9R/@02H[84H[42I[4016;BH[9R
/f:c0VKB0fKC00=VdVKCI]800VKB26KC0VKB00Y_=6mDKiQN/BcV100@046:G[9Vd@9Vl`05I]9VdfKC
I]=Vl`02J]<00f[cJ_AZl`06J_@4J_<5J_@3KaD01F[dK_A^m6keKaD00flD1VlE0VlF36lE00E_=FlE
KaE_=Flf009_=@0AKaE_4gLbKc=ZleX^EPiJ;EXZETiF;TG>:>LPaQAR20080@0422400`PR22448P06
22401PPP22488@Q1344<HP8<@@D88@848@0>12848@@Q2248@@`Q320<8@`P3248@@`Q320<8AP88@<4
8@03224880PP00800009120DPQRS584HPCV5EXiJJeI:00AJBP9JB@03FTYJJUYZ00IJJPIJB`06FV]J
JUYZFVYJJeYZ0eY[0Ui[00INS6:^I]1VlV[cJcD2KcH2LcH00g<gLeMcE`02LeL3KeL6LeL2LcH00g=G
KeM_E`03KeL016mFKeM_=flg0Vlf0W<f00=_=VlgKcL00Vlg00=_=VleKcH02Vlf00=_=FlfKcH00flf
36le00=_=VleKc@00Vld0Vle00=_=W<eKcD00Vle1Vlf00A_=FlDKaE[509Zl`0:I]=RdV:aH[5ZleIb
<@L400003442340634401@a0360@H11Q44400Q1000P@H11Q464@@A1R688DHA211a2200<DPQB358<0
0QB300PHXaR2664HHA1Q340@HAB1111Q00<@PQB346802Q1R0Q230Q1R00<@Pa2248800Q2200`@HA1R
468@HA22588@PQAQ464@@A1Q564346401Q10340@@11P564@PP<@HP0348<@HQ1R00@@HPD@H@04364@
HA1R464344094640211R3208011P484DPA21464546800a22468@HP034680111Q448@@a1R0aAQ00D@
HA1R58<DXa2200<@HP07368<HA1R468@PQRS5:<00Q1Q00<@H0`P44000a101A1Q00@<HPaQ348<@`<<
HP04364<HQ1Q48824642364010a1460@H11P0a1Q00@<HPaQ348<@P8<@@04348<HPaR368336401A1Q
360<H@aQ34400PaQ0Q1Q0Q1P00<<H11P46400Q1Q00<<@11046000PaP0`a000P<H0aQ360<HA1Q444@
@0a11@a000@@@120364<H@8<@@03364@H@a000<<@08<H@05340<@@a0488@P`023643344134014601
46400088@@0922848@PQ224<@@Q224488@`Q00P<@@05324<@@`Q220<8004344534802Pa3108400`P
;@A>:ei^GXiFCEI>0UY>0UY?0eI?15Y?0UY>00=JKeY^FVh00UY>00AJKUY_FVmNK`9JKPAJK`06FW1J
Kei<HXa:3RS60P0000Da1E9;H/e[3eZ?009JL0ANT0=NT@03GY1NSej@00QNT@04HY5NTEjAGY43H[40
15jbHY9R/V:b0ejb00=R/ejbH[401F:b00=R/F:bH[800f:b16:a0VJa0V:a00AV/F;BH]=R/PIVdP03
I]5VdVKB009VdPYVd`0=I]9[56/cLe1R[SD7200D0TG=J^iVlV[cI]8016KC0V[b0f[c0f[d2f[c2F[d
1flD0VlE0VlF3flE00=c57<eLaD00VlE011c4g]BLcEZdVI`LaIomgoaOo]o^Ei_>FXPaA12200880`8
8@05124880PP22048@0222400`PP22488@05224010@Q12848@@Q0PPQ0``P0P`Q00H8@@`Q320<8@PQ
324222000`PQ32488@0;224010@Q220880PP0PPQ00@48@PQ12488@88800;120400@0340DPARQ7:4i
QUZ>FXaFBP02FTX2FT/2FTX6FT/4FV/3FV`3FV/015YZFVUJJEYY0UYZ0UYY00UNJEY8HX]RSFK?I_5Z
lf/DJcD00Vlf0W<g00=cEg=FLeH02W=G0g<f0W=G17=F00I_=VlgKcM_=VlgKcH3KcL01VlhKcM_=g<f
LcA_=@I_=P9_=@04LcE_=FleKcD2KcH:KcD3KaD2KcD3Kc@3Kc<2Kc@01FleKaE_5FleKcH00VlF0Vlf
00I_5FlDKaA[56[cJ]<2I]801f:bH[5V[dX>:<H000@0008<@@03320<@@a100<<@@05444<@0a0560<
@00344000a1P464@H@02464021R2564DHQ22588@PQB24682464258824682588256400aB1588DH@02
46401PaQ344@HA1Q488@P@D@HP073448@0a1468@H@a146400Q1R00<<@0a146801Q1Q111R0QAQ211Q
0QAQ00<DPQ2246802A1R211Q0Q1000<@H11Q4640211Q00L@HQ1Q220DH1RR6:4@H@0246800a1Q468@
HP0446401a1R464DPQ1Q368@Ha1200@@H@08468@PQ22468@H@a1224<@@@@HP09464@PA1Q464@H0a0
460@HA1P008@@0<@H@06468<HA1Q348<@`a20PaQ00H@H0a0340<H11P464234000`a1340@H0044640
111R368<@Pa20Q1R0`a20Pa10Pa00Q1P00@@H@aQ344<@@<@H@8@@0@@H004464@H0aP460534001A1P
360<H0PP32000Q1000X@H0aP340<H11Q460@@1B0484<H@8<@@03364<@0a0008<@003320<@@a100<<
@@03464@PPaQ00@<@@4<@04@H04@HP000`a10`Q20`Q100<88@`Q32401`a100<<80`Q22000Pa100<@
@@a134400Pa10`a200l<@@Q234<400`0668eAeI`HZiJKUI>FTiJCeI?FTl00UI?00=JKeY?FTl00eY?
0UY_00EJKUY]FTiJCUY^009JK`03FViNKUY>009JCP07FTmJD5I`GViNC5H/<@D00P0000PXiTY@FZiS
4UZ?FVmJL5ZA0Uj@00=NL5jAGY400UjA00=NT6:?GY002EjA00=R/EjAGY400UjA00MR/F:bHY9RTV:a
G[9R/@06G[85H[800f:aH[9R/P03H[8026:aI[9VdFJaI[9R/V;AH]82H]<00f:bI]9VdP02I]8016KC
I]9VdVKB36KC0VKB00a[4VlbLgIV[2AR000PHeY;IaA[56KCI]@2I]<016[CI]9VlfKc0V[c0f[d2f[c
2F[d1flD0VlE0VlF1VlE00=_=FlEKaD02VlE019c57<CLc9c=F:@FPec5goKOoYoogomHVhmJAbT4448
00PP244;224512400`PP12488@07224010@Q12848@@Q0PPQ00<<80`Q34400Pa100H8@@a1320<@@Q1
324;22400`a224488@042242220010PQ12448@@Q0`PQ0`PP0PP000T881R18:4iQE9^EVaFBUY:FV/0
25Y;0Ui;00MJBUi;GT]JBeY<FVeJK003FV/00eYYFVYJJ@03FVX02eYYGVYNJUi:GXaRSVK?I_5Zlf/D
JcD00Vlf0W<g00=cEg=FLeH01W=F00=c=W=GLeL00W=G1G<f0g=F00=c=VlgKcL026lg0Vlf00=c=7<e
KcH01Flf0fle0flf16le00=_56lEKc@016le00=_5FlDKa@016lD0Vld0flc0fld0Vle1FlE00Q_=FlD
Ka=[4f[dJ_=ZdfKB0VKA00QRdV:?AJ`HI000200880a10Pa200<<@@aQ34400Pa10Q1Q0Q1P00@@HA10
440@@0<@H@<DH@05568@HAB26:<DPP0356802aB248<@Ha1R344@HAB1588DPAB256800Q1R00D@PQB2
488@PPaR008@H@05468<HPaR368@HP023642464446801a10568@HPa0444@H@aQ00D@H@04468@HAB1
5646464246800aB258<DX`02588546800a1Q364<HP0546400a22588@H@0=4642468021226:8H`aRR
488<HA1R58824684464346801a1Q368<@P`Q220<@A1Q00<@HP05464<@@a1444@HP02464246800a1Q
340<H@05464258401A1Q440<H@a046400Q2200d@HA1R368@HQ1Q364@@0`P460<H0PP340<H0023400
0`aP464<H@03464020aR468@Ha1R368<H@aR468234002@a1364@PQ21464<@0aQ468<HP024680111Q
440@@0aP0a1P0a1Q0PaP1@a000@<H11P360@H08@@00?460<H0aQ488<H@a0460@P@aQ360<@0aQ344<
@0Q00088808<@003360<H@aQ008<@@8<H@06340<@@a1368<HA1P0A1R000224400`a12448@@042240
10Q1324<8@`Q1Pa10``Q00<<@A1R46400`a10`a20`a100P<8@P0200<01bT@LaVkEZ?0UI>00AJCeY@
FTmFCP9FC`03ETiFCeY?00=JC`03FViJCUY]009JK@9JCP9JKP04FTiJKEY>GTh2FU002eY`IXiNC45U
200002S3CRaNcV;^FXh00UY`0Uj@1Ei`0ej@00=NSej@GY003EjA00=RT6:AH[4016:a00=N/EjbG[80
15jb0V:b16:a16:b00AR/FJbI[5V/@=R/@04H[9R/F:bH[82I]8016:bI]9VdVJb0VKB16KC0V:c1VKC
00iVdVKAI]5_4V/=LbYB3Q04400mIf;bJaAZm6KD0fKC00=VdVKcJ_<04F[c0f[d00AZmF[cJ_=Zl`9Z
m0I_509_5@05JaI_5VlEKaE[5@0:KaD00flDKaE_5@02Ka@04VlEKaA_4flCKcER/E7;AFY=beI=FXiN
JdG;=@HHHQ0P200<80H88@0312488@PQ00<88@05124880@P2204800222000`@P12448@0522400`Q1
22448@02124210001@P0220<@@aQ34800`a100<8@@PQ22000PPP3PPQ0`PP1@@Q1@PP0`@000P@@2C2
@JIFKEI<ETYJBUI;0UY;00=JJUY:FTX00eY;0Ui;00INJUi:FTYJBeY<FV`4FV/6FVX02eYYGTYNBEi;
GVaRSFJ_I]5ZlV/CKcD00Vlf00=c=W<gLcL00g=F0WMF0W=F0W<f00Ac=g<fLeMcE`9c=P04LcMc=W<f
LcH2LeH2KcH3KcL3KcH3KcL00flfKcE_=@04KcD2KcH3KcD00flEKcE_=@05KaD00flDKaE_=002Kc@0
0fleKaE_5@02Kc@4Ka@2Kc@5Kc<01FleKcA_57<DKa@00flE00=[56lBK_800V[c00aZlV[BI]5V/6[a
I]5VT3e[308400P0340334401@a0460<@0a032001Pa00Q100a1Q11AQ00D@H1B16:<HPQB100<DH@04
588DPaB3588258402A1Q584@HAAR588HPQR3584DPP0246800a1Q564@H@0246424882364246434680
0a12444@H@024680111Q468@HQ1R0PaQ1a1Q0Pa000<@HA1R46801A1R00@DPQB3588DHP<@HP8<@@04
364@HA1Q468446400aAQ464@H@03464234000a10464@H@05464011AQ588DPQB20Q1R00<@PQ214640
0a1Q1A1R00<@H@a1344010aQ0Q1Q00@@HQ1Q340@@0D@H@8@HP03464<@11Q00<@H@035:8DPQ1Q008@
H08@H@@<H@03460<@11Q008@HP03464@@11P00L<H0@@H@03364<@@a000H<@@03340@H0aQ008<H@03
464<H0a000H<@003440@H11P00<@H003340<80a000H<@003220<@11P008@H08@@003340<H0aP008<
H006340@H11P360<@0PP10a00`PP00D<@11P464@H@a1008<80H<@04@H04@H@0000@8@@PQ2448@@<8
8@88@@<88P03224<8@a100D<@@8<@P03368@H`a200<<@@<<@P0<324<@@a1444<@0P0000<8RdWDVmJ
/5I^0eI?0UI>00IFCeI_EVmFKeI?FVl3FTl015Y_FViFCUY]0UY>0UY_019JKUi]GViNCUY@FS1RKfZ]
FRhXX`00881>CUZ^G]5JSUY^FVl5FW000eiaGY1NT003GY000ej?GY1NT@07GY45GY800ejAHY1R/@05
H[42G[42G[85H[84H[46H[801F:aH[9R/V:bH[4016:b00=Rdf:bH[800V:b00=V/VKBI]802fKC0VKB
0VKA00]Vd6K>K`e_F3D/200TXeJbJaAZe6Jc00=Ve09Vl`EZl`9Zm0]Zl`AZm09Zl`EZm005KaE_56lD
KaA_5@03JaD=KaD00flDKaE_5@04KaD03VleKcA_5F[dGW1F3E7:DLQAjTfZ@HX`iAQR420222052240
0`a224888@022282224010@Q220880PP10@P00@48@PQ224880848003124480@Q00P00004100480Q1
244F22400`PP12448@061242224020PP100400a09>=:1ej]EV/2ET/015Y[FT]JBeY:1EY;00=JJUY[
FTX00UY:00AJBeY<FT]JB`9JJ`9JK0EJJ`0;FVYNJei[GVaNKEj>HZmVdF[bJa=_=@02KcH3LeL00g<f
LeIcEP03LeL2LcH3LcL3KeL4LcH00g=FLcIc=P07KcL016lfKcM_=Vlg0Vlf3Vle1VlE00A_56leLcE_
=P9_5@03KcE_5FlD009_5004KcE_=6leKc<2KcD016lDKc=_=Fld0flD0flE00=_=FlDK_800V[c00eZ
lV[BI[5V[f[@J_=RT3TZ104400`P340<@@02348010aR364<@@a10Pa000<<@@a034000Pa000<<H110
36400Q1Q00<DHAB156400QAQ00@DPAB2588HPP<DH@08568DHaB35:<DPQB1564DP@<DPP8DHP04684L
XaB1564258800aAQ464@H@0248801A23488@PQ1R48800a1R00@<@A1R488@HP8@PP<@HPH@H@8@PP03
464<HA1Q00<@H@@@HP03464@HQB2008DHP<@HPP@H@04564@HA1Q4642468246400`a0464DH@044640
1@aQ464DHAB158800a1R0Q221A1Q00PDPAB258<@HQ1Q468@HaB30a22111R0Q1100X<HA1Q444@HAB3
6:<DHQ1R464DH@H@H@03360@H11Q00@<H@03344<@11Q008@HP0948<@HQ1Q460@HA225:<@PPaQ008@
H@@@HP8<HP04468@@A11348234424400111P364<H@a10`a00`aP0Pa000<@H11046001A1P0Pa000D<
80PP340<@0aQ008<H004364@PA1Q460634001@aP340<@11Q364010a000<<@@a034000Pa00PaP0PaQ
00D<@A11320@@@a1008<@003440<811P004<H@0000L8@@PQ2448@@PQ12488@0224401@Q222888PPR
24402@a110`Q0PPQ1@a100`@H0a0220400006:A1bEj_H]1JT5Y@ETh2FTh01EY?ETmFCeI?FTl00UY_
00=JCeY_FVl00UY>0UY^00IJCUY_FVmJKei/GVh2GTl03ei@HVe^k4F/3044046RG/iVkUI]ETmJCeY_
FW1JK`03FW0015iaGY1NT5j@0ej?0ej@1UjA0UjB0UjC00=NTUjAH[000f:a16:`00=NTF:aH[401F:b
0V:a00=R/6:aH[802f:b0V:a0V:b0fKB00AV/VKAI]9VdP9Vd`03I]9VdfKC00MVd`0=I]9Vd6KAI]9Z
d7<bKcIJ3QP030163flcI]8016KD0VKc0f[c00=Vlf[cJ_@03F[c00AZm6[cJ_AZm09^m005J_A_56[d
J_A_5@04Ka@01FlEJaE[5FlEKa@02FlE0flD2FlE0W<e0fkd00IZmF:DES0iB1QR3202220622431240
1@PR22488@PQ22000`@P0`PP0P@P00<880@P10000P@00PPP00H480@Q224<@Q1R488258<0111R3688
@@Q10`PP0P@P00<880PQ22401PPQ00<8@@PQ22401@PQ00<880PQ22401P@Q0`PQ00P40000320Y0TX7
FXeJJeI;0UY;00=JJUY[FV/00UY;00EJBUY;FVYJJEY9009JB004FVUJJUY;FT/2FV/01Ei[FTaJC5Y<
FV/00eY/00aJJei/GVaNK5i]HXiR[fKAJ_5[4f/DKcH2LcH4LeL01G=FLcIcEW=FLcH00W<g00=_=g<g
LcL00W<g0W<f0g=F0W<f0flg2Vlf0Vle00=c=FleKcD00Vle00Ac=FleKcE_=09_=@E_5@9_=@I_5@04
KcE_5FlDKa@4Kc@01FlcKa=_56lDKc<00Vld1flD00m^m6kcJ_9ZlV[aJ]5V/6J^IZeZlUi@<>P80@@0
44000Pa000@<80`Q324<H@8<@@04320<@0a0340536000a10464@H@02464456400a22588@HP025640
0aB1588DHP03468246401aAQ584DPA1Q344<@1AQ008DP@8@H@8DH@06588@HQ1R488DXaB20Q1R1A1Q
00H@HQ23588@PQ1R364246801A21464@H@a046400a2200<@HA2148400a1Q00<<H@a146400Q1R00@@
HAAQ564DH@8@HP03364@H11P00`@H@04468@HA1Q5642584346401@aP464@H1R158800Q1R00<@HA1R
4640111Q00D@H1B0588LaQRT008@H@8@HP046:8H`a22464246801Q1Q444@@@aQ348<@@8@HP03564@
HA1Q00<@H@05460<@0a1364@H@02340246000`aQ368<@P05468234800`aQ360<H00236400a1Q460@
H002340436403PaR464@HQ1R348<@@a0440<@0aP364<@@Q1220234053600111P340<@1100Q1P0a1Q
00<<@0`P22000Pa00Q1000<@H0aQ36001`a000<<H0a0440030a00PaP00@<H@a1344@H08<8006340@
@0a0340880aP0@a100001PQ1324<@PQ22288@@<<@@05248<@Pa2248<@P0534423482344432401@PQ
320<@@a134800PaR0PaQ00X<@@PP000<@Bd4DTiN[Ej_ETeJC@=JCPUJC`9JCP03FVeJKUY_009JK`0B
FViJKEY>GTiNCeh`IXe^bSU[000H8598I`iN[EY=ETmJD5Y_15Y`0UYa0ej@0ej?15j@0UjA00=NT5jA
GY800UjB00ENTejBGY9R/F:`009N/@ER/@04H[9R/F:bH[84H[42HY000f:`H[5R/@02H[49H[800fJa
H[5V/P02H[83I]801FKAI]9VdVKCI]802FKC0VKB00aVdFKBI]5VdFlBKcEVTS3W100eJV[`J_<2I]@0
1f[eI_AVdfKcJ_9Zlf[b009Vl`03J_AZlf[c00UZl`UZm004KaAZm6/EJaD5Ka@2JaD00flDKaE_5@09
KaD2Ka@8KaD2Ka@02VlEMcEgEWMGNgQgF6KE>FTD@@`00PP00PPP10PQ0`@Q10PQ00<880@P22000`@Q
0PPQ0208@@a1344<HA1R568HQ1cV:BP]BSF:?Ne23dH`@PhmkSF[;DTU1aS558@@Ha1R368@HPa2220<
@Pa124488@@Q2PPQ00<880PQ22401P@Q0PPQ00P48@00000402d2BPMBKEI/0UI;00=JBeYZFV/00UY[
00AJBUY;FT]JJP9JB@9JB004FTUJJUY:FT/2FV/01Ei;FTaJBeY<FV/00eY/00iJJeY<FV]JK5i]GXiR
[fK@J_5[4f/EKcIc=W=F17=G0W=F00=c=W=GKcH01g<g0W<f0g=F00=c=VlgKcL00Vlg00=_=VlgKcH0
1flf00A_=FlfKcI_=P9_=@03KcA_56le00=_=@U_5@03KcE_5FlE00=_5@=_509_=09_5003Ka=_56lD
009_5005KcA_56lDKaA_5@02Ka@016lCKaA^lf[c0f[b019ZdVJ`IZiV[6J`CNdPH`@0200@@1113408
80PQ344<@0aQ34443404360234000a1P464@H@0246400aAQ584@HP0248800`aQ464DH@0246404AAR
468DPQ22464<@A1Q564DPAAQ588@H@a0464@PA2248400a1Q00D@HQ22588HXaB200H@H@8@HPD@PP8@
P`04488@HQ1Q464246800a1Q484@P@02488446400a1R568@H@02464356400a1Q588@PP0>46400aAR
488@PP0258800a22584@H@0446400aB1488@HP0446434680211Q564HXQBS488@HQ1Q344246801A21
488@HPaQ46400Q1R00<<@@PP34400Q1Q00L<@11Q464@H@a0464DPP0446424684464010aQ468@HQ1R
0Q1Q0Q1R0`a100D<@0aQ364<H@aP008@H003464<@0a000D<H@8<HP03364<@@a000@<H003364<HPaQ
008<H@H<H08<@003440@H11Q00<@H@09364<@0`P440<@111440@H0aP00D<@0@<H0@<@003320<@0a1
00H<@004360<H@aP3643344234001P`P440<@0a0344<H04<@P0000@<@@`Q2448@@D<@@T8@@@<@@@<
8@<<8003324<@@a100@<@@0:360@@@a0320DHCU5GXeJ[EY]FTd3FTh00eY?FTeFCP05FTl2FVh2FVd0
0eY>FTmJC`02FVh045Y]FTiJCUY?FU1RSFJ:>DX00AQ1EVYVkEj_ETeFCeY?1EY_00=JL5YaGY000ej?
00=NKej?GY000ej@0UjA00ANT5jAGY5NT@=NTP03GY5NT6:`00=N/@=NT@9RT@03GY5R/F:a00AR/@03
HY1R/F:`00AR/09R/@MR/P05H[5R/V:aH[5V/P02H[800fKBI]5VdP02I[83I]82I[85I]83I]402fKB
I]5V/6J`J_=_5D7>104PY6J[Ka<00fKC1FKB00AZlVKcI_=Vl`9Zl`03J]=Zlf[c00AZl`UZm006KaEZ
m6lDJ_A[5FlE1FlD0V/E1FlD1FlE00A_56lEKaA_4`9_50I_5@03KaA_5FlE009_5@06McEgEG^GJ_<m
JA0P0`P00`PP00<88@PP22401@PQ0`PP1PPQ00`8@@aQ58<DXaRT7<@PiR3W:BPaJSf:AN`2CRh03TH>
BRi:3T7<=FT]BBTY8@LLaQRU6:@@Pa1S368334800`PQ12488@09224322000`@Q22488@0622404PPP
1008834QCRQFS5I[FTYJBeY:FTUJBUY9FTYJBeY:FVYJBPQJB@EJBP05FT]JJeY/FV]JK003FV/035i;
GVaNSF:^I]1ZlF[cJaE_=W<eLcIc=`AcE`=c=P=_=P03LcMc=W<f00Ac=P=cEP03KcI_=flg009_=`03
KcI_=flf00M_=P03KcE_=Vlf00=_=@07Lc=_=6ldKcE_=6leKa@01VlE0flD1FlE1flD0flC16lD00=_
4flDKa@00VlD01=_4flDK_AZlfkaJ_5ZdFKAI[1VSFJ[HXi1Ra0Q100<8A10444<@@02324234023605
340236000a1P340<@003460246401QAQ464DPAB2468@H@<DH@8@H@04468DPac46:8346400aRR584D
PP0246801Q1Q484@PAB1460@@08<@08@H@DDH@8@H@<@HP04440@HARS5:<44880111R464@HA1Q0Q1R
00@DPAB0460@@08@H@07584DPQB2584@HA1R46400aAQ00<@HAB26:<02a1Q00@DPQAQ464@HQ<@H@@@
HP<@H@07468@H@a0468<@11P46401A1R00<@HA1R4680111Q00<DHA1Q46401Q1Q0QB21A1Q00<<H@aP
36000Q1Q00<<HA1Q344010a10PaP00H<@0aP464DPQ1Q46023642340010a1364<@@a10Pa00Q1000D@
H0aP364@PQ1Q008<H@08464@H0a0460<H11P360<@08@H0<@H@8DPP03444<@11000X<@0<<H0L<@008
344<@0a0340<H@a1340@H08@P@8<H@03244<@@a000<<@08<H04<H@4<@@4<@P0000<<@@`Q24400`Q2
0`Q10`Q200<8@@Q224400PQ100<8@PQ1244010a10``Q00D<80a1344<@@aQ00@<@@0;340<@A11200<
02B2BP]J/5j/GVeJCP02ETh00eI?ETiFC`02ETl3FTl2FTh015I>FVeJCUY>15Y^00eJKeY@FU1JDF:>
IV/XYP017:E>BVK^GXmFCP02ERh00eY?FW1JK`02FW02FW4015Y`FVmNT5j@0Uj?0Uj@15jA0Uj@0UjA
0ejB0UjA00=NT5jaG[400eja00INTF:AHY5NTF:aHY04H[400f:AGY5R/@06H[47H[801F:aH[9R/V:a
I[800V:b00=V/VJaI]8036KB0fKA00eRdVKBI[1ZdF[cKcI:<@P2501JBVldI]=VdP02I]<3I]85I_<2
J_<2J]<4J_<5J_@3J_D6J_@2JaD01V/DKaA[56lDJaA[5@=[50A_50=[5@=_5@04KaA_4flDKa@6KaD0
0flDKaE_5@02LaH01WLENeEkMVKc>DT@00880005320880PP22488006224222000`PQ344<@@033443
2480111R368<H@aQ0PaR00T@HQ1S568DHQA1688HPaB368<00QAR00DDQ1S57>LLiaS600<HY@0458@D
Pa234683368334832482228422400`PP12448@0222400`@Q22488@0224402@a0000<@3ESDVYJcEI]
FTYJB`02FTX015Y;FTYJBUY:0UI;00=JJeY:FTX015Y:00=JBEY:FTX00UY:00AJJeY;FT]JB`EJK00:
GVaJC5Y/GXeR[VK@J_5Zlf/DKcH3LcH4LeL3LcH3KcH3LcL016lgLcMc=flg0flf1Flg00A_=VlgKcM_
=`Q_=P06KcE_5FlEKaE_57<D0fle26lE00=_56ldKcD01FlE00=_56lCKa@01flD00=_5FlDKa@026lD
0V[d0V[b00YZdVJbI[5VSVZ/GVhmJA0P200@@@8@@004444<H@aQ364244000`aP464@H@0234000`Q0
340<@00246002A1Q460@HA1Q484DPQBS588DP@02588041B1564DHAAQ568DPQ1R588Q1R3U588@HQ22
588DXa230Q1R00@@HA22584DP@@@H@06440@HAAQ564HPQB10QAQ0Q2200H@HQ1Q320@HA1R488248<0
0a22484@PP024680211Q468DPAB1684DHA1Q340346400aAR564DPP0358801A1Q588HXaB14640111R
0Q1Q00@880a0464@H@8@PP@@HP04464@HQ1R468246401A21464<@11Q48800Q1R0Q221a1R00<DHQ1Q
46400Q1Q00<<@11R36400Q1Q0a1R0a1S00@@HQB26:<DPP<@H@03468@HA1Q00L@H@03364@HA1Q008@
H@8<@006464<HPaQ368@H@aR0Pa100<@HPaR36400`aQ00D@HA1R464@H0aP00H<H@06340880a0460@
@11Q0Q230PaR00<@HA1P46401A1Q00<@HQ1Q4640111Q00HDPQ22364<H@aP36424642460344000`aQ
464<H@03360334001`PP344@HPaQ340<@A1Q008<H@@@H@03364<HPb2008<H@03360<@0aP00<<H@4<
@04<@@0000@<@@`P22488@88@@033448@PQ100@8@@032488@@Q100@8@PD<@@888@05324<80`P340<
H@023444340020P0100400`P:@A:CF;;FX`5ETh3ETl2FTl2FTh015Y=FTiJKEY]15Y^00=JKeY@FU00
0UY@00UNSV9;<@P00AQSBRYJ/5Z@ETl00UI>00=FCeY@FVl00eY`00UJLEY`FVmJKej@FViNSUj?GY00
15jA00ENT5jAGY5NTEjB00=NT@9NT003GY5NT5jA00ENT@04H[5R/6:`H[02H[42GY8015jbH[5R/F:a
0V:B1f:b16:a00UR/VJbI[9R/FJbI[5V/6:aI[4016KA0fKB00AVdFKBI]9VdP=Vd@0=I]9V/FJaI]9Z
lg<eEW8DA100DPU_=6KCI[800VKC16KB16Kc00EZlf[bJ_9ZdV[b00IZl`9Zm09Zm@03J_AZlf[d009^
l`9Zm0E[5003KaA[56/D00=[50A_50M_5@E_5003KaE_56lD00E_5@07KaIc=WMGNgIR/SDY30000P@0
00<<80PP22000PPP10PQ00<880`P34000P`P1@a10`PQ0PPP00<480@010002`0000<400PQ58<01aB3
0aRS00@DPQ1R468<HP8<@@0324848@@Q00D88@8880@88@0<12488@PQ104400PP000883USEXUNk5Y]
15Y:00AJBeYZFTYJBP]JB`AJBPAJB`9JK003FV]JK5Y;009JC006GXeR[FK@J_5ZlV/D0Vle00Mc=GME
LeIc=VmGKcIc=P03KcH2LcH2LcL016lgKcI_=Vlf0flg26lf0Vlg1Flf1Fle1flE00=_56ldKcD01FlE
00=_56ldKcD01FlE00I_56lCKa=_4flDKaD4Ka@2KaD01FlDKaE_5FlEKa@00V/D16[c0f[B00UVdVJa
IXe^cEY>>BL<00P034000Q100Pa00`aP00<@@11P36000Pa00PQ00Pa000@@H0aP460@H0<@H@07468D
HAAQ584HXQB146400QAP00XDHAB2584@PQ1R488DPQAR468DPPH@HP8@PPPDH@0?464DHAB1564@HA1R
464@HQ1Q444<HA1R364<@A1R008@H@03340<@A1Q008@H@8DP@04688DH@a0344246401@a1464DHAB1
6:400QB100TDHAB1588@P@a0344@@A1Q36401A1Q00@@PQAQ464DH@P@HP05464@PA22464<H@064646
46844640111P440<@1220Q1Q111R00D@H`aQ464@HA22008@H@04444<80PP340246001A1Q460<@110
46000a1Q0Q1P00@@H@a0340<H@8@HP05368@HQ1R364<@@02340236001Q1Q364@H110340<H08@H0<@
H@0:360<@0a0360<@110460@H@aQ3682348030a0460@H11P340<80a0460@PQB1340@H08@H@03360@
H11P00<@H003464@H11P00<@H008440<@11P460<H11P464@H08<@003344<@0a100<<@@03364<H0aQ
008<@004320<@0a0340536000`a0364<H@023641360134000003244<@@PQ00888@033248@@Q20088
@P042448@PQ2244222401@Q12488@PQ224400Pa10`aR0Pa100@<8@`P340<H@H<@@0:340400@0000@
HSF8EXeNcUI^FTd2ETh015I?EU1FCeI?0eY?0UY>1UY^0UY_0UY`00aJD5IAFW1R[DG=30<003EZDY9>
CUJ>EVl4ETl2EW06FW000ej@GXmNT004GY05GY400ejBGY5NT@02GY400ej`G[5NT004GY43G[43H[02
H[43G[800f:aH[9R/@02HY83H[801V:aH[9R/V:bH[5R/P9R/@9R/P9R/@9V/P03I[5V/V:a00AV/P9R
/PEVdP=Vd@=VdP0:H]5[56ldEW8DA0P0CPQ_=6[dI]82I]<4I]84I_<2J]<2J_87J_<2J_@2J_D3J_@2
K_<00f[dJaA[5004Ja@00flDJaA[5009JaD2KaD2JaD016lEKaA_56lD2VlE0VlF00EgN7MfHY8a2@P0
008400@8800532088@PP220<8@0232002@a0444@@A1Q468DHQ1132488@03220224001@Q1120400@0
0040200000@400PQ368<H`<@HP8@H`0>48<DXaBS58<HXaS45:@@Pa22468@Pa1S3688@P888@042448
8@PQ220222400`@Q22448@0322401`PP100000@0<D9JREZ/00=FB`03FTaJBeY;009JB`03FTYJBeY:
00YJB`9JBP03GT]JBeY/00=JB`03FV]JK5Y/00=JK00;GXiR[VK?I]5ZlV/DJaE_=G<eMeAcEP02LcH7
KcH3KcL3KcH3KcL00flfLcIc=P02LcH2KcH3KcL6KcH3KcD00flfKcE_5@05KaD00flDKcA_=@05KaD2
Ka@00fleKaE_5@04KaD2Ka@016lCKaA_5FlE0flD0flE16lD00A[56[dJ_AZm09Zl`0;J]9ZdfKBH]=V
/VJ?JZaB3BcU0008000344023402360334001A10360<@0a024000Pa0111P00X@H@a0340@HAB2564D
PAB2484@H@8DH@8DPP03564@PQ22008@PP8@HP07464@@A1Q568DHAB25:<00Q220a1Q00@DPQR2588D
H@<@H@03588@HA1Q00<@HP@@PP8@HP8@PP03564@@0a0008@H@8DH@0:688PiAAR340@HQB2468@@@a0
58425880111R464@HA220QB200<@H@a146800a1R0a1Q00<DPAB268800QAQ00D@HA1R468@HQ22008@
HP06464@HQ225:<H`a22111Q00<<80P034400Q1R0`aR111Q00@@H110340<H@@@H@04468<HPa23643
46402Q1R464@@11P340<H11Q460@HA1P0a1000@<@0aQ464@H@8@H004464@HQB3468236800`a1364<
H@02344234001`aQ360<@0a0320@HA2100@@H@07468@PQ1Q364<@0aP56800Q1Q0Q1100<<@@a24640
0Q1Q00`@@0a0344<H@aP368@HA10340<H11Q3604340010aP364@HA1Q111000<@HA1P46000PaP00H<
H@aP340<@0a13404344010aR364<@@a11@a000L<H11P464<H@aP364<HP0234413641460134400003
224<80PQ00<88@L8@@032248@@Q200<8@P<8@@032248@@Q100@<@@L<@00;344<@0a0220800Q2228X
`di9H^iNc`02FTd2ETl3ETh3FTl3FTd3FVd2FTh2FVl03eY?FVmJL5Y@GY5VdEY@:>L000P3BNiNSE9^
FXiJK`03ETh00eI@EW1JL003FVl3FW03FVl2FW02GY02GY400ej@GY5NT@04GY47GY000ejAH[1R/005
H[02G[4015jbH[5R/F:a0V:A00=R/F:@HY401F:a00=R/V:aH[4016:a0VJb0VJa00=V/6:aI[400VJb
0f:b00AR/FJbI]5Vd@MVdP0:I_=_4eH`54<80587Le=Zm6JbI]<8I]83I]<2J_88J_<2J_@016[eJ_AZ
lf[c0Vkc00=Zlf[dJa@01F/D00=_56/DJaD00f/E00=_56lEJaD00V/E00=_5FlDKa@01flD16lE0VlD
00a_5FlDKaE_=gMiMeMJLRS8200400`Q320222033202220232003`a0344@@A10588HXaB2440<80PP
224880PQ24488004224512400`@P1004000300003`@01208@0Q1468@Ha1R46<@HQ2358<@Pa2248<D
X`026:<021S46:<DPa2336<<@Pa1224;22001P@00000034QGXQJRP=FB`03FTaJBeY:009JB`04FTYJ
JUYYFVX2FT/4FV`015YZFTYJBUY:0Ui;00AJBeY/FVaJB`AJK00?FV]JK5Y]GXeR[V;?I]1VlV[cJaE_
=G<dMcAcEW<f00=_=P03KcE_=Vle009_=@9_=P04KcM_=VlfKcH3KcL:KcH00fleKcI_=P02KcH6KcD6
KaD2Ka@00fleKaE_5@03KaD2Ka@00flEKaA_5003Ka@00flEKaA_5003Ka@00flEKaA_5007Ka@2Ja@0
1V[dJa=Zlf[bJ_=ZdP9VdP09H[=RTVJAJXa5ZR23100<811P008<@003440@H11P00@<@003440@H0aP
00@<@08@H006584@PA1Q464DHAAR0QB10QB200@@PA22564DH@8@H@06564DPAB1484DPA220aB200@D
HQAQ460DP@8DPP04488@HA10464256400a1Q468@HP0446803A1Q468@HQ1R588La1RS568@HQ23468<
HQ1R00H@H@07468DHQ1R584HXaR256800Q1R00<DPAB258800a1R00<DPQRS5880111R00HDPa1R464@
HAAQ688258801aAQ464@HA1Q468@HA23008@HP03464@HQ1Q008@H@03468DPA1Q00<@H@04444@HA1Q
4644364346401a1P440<80`P440@HA1P008@H@05344880a0464@HP034645460346401Q10464@HA10
220<@0<@H08@H@<@HP07368<H@aQ344<80PP32000Pa000L<H@a1340<@11P360@H00246401110464@
PQ210`aQ00<@@@aQ46000Q1Q0PaQ00@<@110444<H@@<@@03364@H@a000L<@0@<@@8@@08<@003360@
H0aP008<@003320<@0a000@<@005244<@@a13448@@03344434001P`P460@PAB1484<H@8<@0043448
80Q0360134400006244<8@PQ224<8@PQ1@Q10PPQ00<8@@Q224800PQ200<<HPa124400`PQ0`a100<<
@Pa134400Pa100D<@0a1340<@111008<@@0:2208@0aS104D@CV4E[1N[Ej=FVh3ETl2ETh2ETl2FTl0
0eY>ETiJCP02FTh2FTl2FVl2FW006UYaEU5JLEjaFY59k@`0000L8TW]DY9JSUj=ETaF;5I>EU1FCeI@
ETmJD5Y?ETmJKeY`FVl2FW07GY06GY400ej@GY5NT004GY001EjAGY1RT6:@H[400Uj@00=NTEjbG[80
0ejb00=R/F:AHY4026:a0f:b0V:a00QV/F:bH[9R/VJbH[5V/F:b0VJb00AV/f:cH[=R/`9VdPEVd@0;
I]9RdF;BH]9RdFlCDPlH@a00DPIc<@02I[82I]<2I]84I]<00fKBI]=Vd`02I]<2I_<7J_<4J_@2J_<0
0fkcJ_=Zl`02J_@4Ja@00f/EJaA[5@02JaD00f/DJaE[5@03JaD00flEJaE_5008Ka@5JaD4KaD026lF
LeMc=EIB9:P800@0200222000`PQ324<@@0234400``Q344<@P0546801AB3464@@@a132400PPQ0PQ1
1@PQ1`@Q00<4000000001@0000D400@P100880Q100<<HP04468@Pa2358<35:<02AS46<DDY122368<
@@`P32488@082202000010P0=B1RR5jZ0UI;0UI<00IFBeY<FTaJC5Y;ET/2FVX3FT/3FV`00eY[FT]J
BP02FTX00ei;FV]JK007FV`2FVd025i^GXiR/6KAI_9Zm6/EKcD2LcD7KcH00g<fKcI_=P0>KcL6KcH0
16lgLcI_=Vlf1Fle26lE00=_56lEKaD016lE0flD0flE00A[5FlEKaE_5@=_=@E_5003JaA_56/E00I[
509Zm003J_=ZdV[B009VdP0>H[=NTVJaIVa1JA0Q100@H0aP220<@11P440@H08<@006240<@0a0360<
H@aP0`a000L<H11Q5:8@PQ1R464@HP0458834882564011B2468@HA1Q0aB10Q2200<DPQB358<00QAR
00@DPA22488@PPD@H@8@HP04488@HQ1R468248802PaQ344<@A1R58<HXa1Q344<HQ220PaR0Q1R111Q
00D@PQB2468@HA1R008DPP0358<@Pa1R00@@HP0346<@Pa22008@PP03468@@A1R00<@HP07464DPQB2
58<DPQ1R46400a1R00H@HA1R368<HQ1Q4684464011B1588@HQ1R0Q1Q00<@HQ1Q46800PaR00<<HA1Q
46400a1Q00@<H@`P220@@@L@H@04340@HQ1Q4442468746425882464020a1364<H@aQ368@HA1R4645
36800`aQ464@@@0336401A1Q364<H@aQ46000PaP00@<HA1Q440<@08@H@D<H@8@H005464<H@a0340<
H@02440346423643344234001PaQ3408@0a0244<@08<@@04364<@0a03403364010aP364@HA100`a0
00<<@@Q124400Pa000<<@@Q134400Pa11@a000L@H0aQ464@PQ1Q440<@0022202340134400007244<
8@Q1244<8@PQ32400`Q100<<8@PQ244010Q100@8@PQ12448@@<88@8<@@8<@P06368<@Pa1344<@0a1
0`a00Pa100/8@@aQ248000@06851jEZ=GX]NSUY>009FC`AFCP=JCPEJC`=JK`9JL00FFU1JDEY@GY5N
SVJ/>H`80`004051RUY[GZiR[UI>EVmJL5Y_ETiFCeY?FTh2FVh2FVl3FW06GY08GY45GY001UjAGY1N
T6:`GY5R/@9R/P=N/P03H[5NTF:a009RT@9R/@03HY5R/F:a00ER/@04H[9R/FJaI[02H[400f:bH[5R
/@02I[801V:bH[=V/f:cI]AR/`9V/P9V/@=Vd@=Vd00:HZmVlVlDDPlD8a@0BNMZkf:bI]85I]<2I]80
16KCI]9VdVKB0VKC00=VdV[bJ_<01f[c00=Zm6[cJ_<00V[c00=^lf[cJ_<01F[d00A[56/EJ_AZm0=[
50=Zm0e_509_5@I_5006K_E_5G<gKcAFDR2X0`@000<<80PP22400`a10a110a1R1A110`a10P`Q00<<
@@Q122400PPP0PPQ00<880@P12401@@Q00L000PP5:8Q1QC4368400050002100010@P224<@@aR0Q1R
00P@PQB26:<H`aBS6:<<HA110P`P00<<8@`P22401PPP00H40000340mHEj7GZX2ET/4FTd2FT`00eY:
FT]JB@02FVX00eY[FTYJB`08FT/00eY[FVaJK002FV`3FV/03eY/EVeJKEi]GXiR/6K@I_9Zm6/EKaEc
=G<dKcIc=P02KcH00g<fLcEc=P03LcH6KcH00flgKcI_=P03KcH00flgKcI_=P06KcH00fleKaE_5@02
KaD3KcD3KaD00fleKaA_5@02KaD01VlDKaE_5FlEKaA_5@A_50=_5@03JaE_5FlE009[509_5003Ka=_
56lC009_5003JaEZm6/E00=[5004J_A[56/DJa@2J_<2J]82I]803EjbFY9R/Ui=>BL400P0560@H@aQ
340@H11000<<@004240<@0a03204340246024642488246400a1R588DPP0558801AB1588DPQB14640
0aB10Q1R0QB200DDXa1R468@HAAQ00H@H@<@HP0<488@HQ1R468@HA21488@H@a1464@HQ1Q0Pa100<<
HQ1R46800a1R2A1Q00<@HQAR46800Q1R00@@Ha1R46<@H`D@HP04464<@A1S46<246834644468<4640
211P580DHA1R464@H0aP344246400`aQ464<H@0346401@aQ464@H@a14440111Q0a1P0a1Q0Q1100<@
H@aR46400Q1Q0Q1P111Q00L@H11Q464@H@aQ3448@00236400a1Q344<@@02344020aQ464@HA11440@
H11Q46073603440234000`PP344<@@023402460011B1588@PA1Q0PaQ00@@H110460@H08@H@D<@@L<
@00732088110468<@@PQ22000Pa000<<@A1P44000Pa000@<H@a13408@0d<@08<H006364@HA1P460<
@0a10Pa00@a1000424800`Q122488@05224:24400`PQ344<@P02348236800`a2344<@@0234404Pa0
344<@@a13688HPaR24840000320Y8di<G/iN[UY>ETiFC`AFCP=JCPAJC`=JK`03FTmJL5Y`009JD00?
FTmJCV:_HZiN/d6]600000@0::8iRTX^FY5JSeY_009JKP06FTmF;UY>FTmJKUY_0UI`15Y`00EJKeY`
GY1NTEj@00UNT@03GY1NTEj@009NT09NT@9N/@EN/P04H[5NTF:aH[82H[43HY400f:bH[5R/@03H[42
H[8016:aH[1R/F:a0f:b00=V/FJbI[<00f:c00AR]6:cI[=V/PQV/@08H[1[4fkaCNh401@0GV]VlPUV
d`=Zd`04I]9VdfKCI]<3J_<00f[dJ_=Zl`03J_<00f[dJ_=Zl`06J_<00f[dJaA[5002Ja@00f/EJ_AZ
m002Ja@01FlDK_A_56lEKa@00flE36lD0VlE0flD00I_5FlGMgUcETha78L210000`P0320<80023440
1Pa2448@@A1Q444<HP@@HP<@@@@<@@0;324<@PPR224<811Q48<<@@P02204800412403`PQ344DPReX
ARa2KcF[9@HLaQc56:D@H`Q12204800300001@@01208@@a136400Q1R00TDY123348<8A0Q444@HQ11
32401PPP00H400004651Y6:8GZX3ET/3FTd2FT`3FTX015Y;FVYJJeYZ25Y;1eY/0UY<00iJJeI]FVeN
KEj>H[1VdFKcJ_A[56lEKcEc=G<f0g<e00=c=W<eLcH017<f1Flf0flg2flf00=_=FlEKaD02VlE00=_
56lEKaD01flE1FlD1F/E0VlD0V/D00I_4f/CJa=_56/DJaD3J_@5Ja@01F[dJ_=ZlV[BJ]<00VKB00aN
T5ZAG]5FKbd61008011Q364<@A10464244000`a0344<@@02344234001Q10360<@0aP460@H@@@HP03
464@HQ22008@PPHDPP065:<DPQB2584DHA1Q0Q1R0aB200<<@A1R56800QAQ00@@H@a0468@PP<@HP8@
PP<@HP04464@PA2246824644468010aR464@HAAQ0a1R0Q1Q00<@H11Q5840111R00DDHQ1R468<@A1Q
00<@HP8<@P09344@HA1Q464@HQ1S48<DPa2200<@H@H@HPT@H@03564DH1B100@@H@04488@HQ1R4642
46804@aR344<HPaQ368@HA1R464@@A1Q564@HA1R464<@11P56400Q1P0Q1100@@HQ1Q464@H@8@H0L@
H@04364@H@aQ344236400`aR364<@@0246400a1R464@H@024640111P440<@0a010aP00<<@0aP4400
0a1P0`aQ00L@HPaQ340<@0aP460@H@0246801Q22368<HA1P420@@0<@H@8<H@04344<H@aQ24433400
20aP460<@@a0344<H@a13402344234000`a1444@@00334000`aQ340<@00534000`aQ440<@0053404
3642464010aQ344<@@a00@a1000424800`Q122488@0422400`Q134488@0824433243344234833442
340434403@Q1344<@PPR200401B1?LQBT6;?FVeJCUY?00AFCP=JCPUJC`0;FVmJL5Y?FTiJCEY]GXiR
[VJ/AL/PHP0200001@P0864iAdX<EVl00Uj?00EJKUI>ETeF;EI=00=FC`09EW1JL5Y`FViNKeY_GY1N
TEj@009JT@UNT@ENT003GY5N/EjA00=NT@03G[5NTEjA009NT@ERT@03H[9R/F:a00IR/@03H[1R/F:a
009R/P04I[9V/FJaH[42H[83H[<00fJbI[5V/@04I[42I[802VJaI]5[=6lb=DX002BUHZi[=FKc2VKC
0VKB0fKC00=ZlV[cJ_<03V[c00=Zm6[cJ_<01F[d0V[c00AZm6kcK_=^m09_50=Zm0e_500>KaE_56lD
KaA_5G=HNiYc=DW`76H400P0220<808<@@03348@@Pa200<@@@8@@P03444@HQ1R008@@@8<@@0>440@
@@`Q324<@P`R324@@1RR6:@<@PPP000400<4800C220480a148<]Qdj>BY1:L47]>J`eRS5Y:BPU1ac5
6:D@Q0Q110001@0000L400@P244<@P`R324<0@0232400``P2208800522001P@0000<@3f4HZQNZ@=J
BP05ET]JC5I;FTaFB`03FTX015Y;FTUJBEY90eY;0eY/0eY;00=JJeY/FV`00UY/0UY<0UY/0UY]00YN
KEj>H[1RdFKBJ_=[56lEKcEc=09c=@04KcEc=G<eLcD3LcH00g<eLcIc=P04KcH3KcL;KcH00fleKaE_
5@03KaD00flDKaE_5@03KaD6Ka@00f/DKaA_5002Ka@2Ja@3Ka@00f/DJaE[5@02JaD016lDJaA[56/D
0flC00=_56lCKa@00flD00EZm6/DJaA[4f[d009Zl`0>J_9ZdVKCI]=ZdV:_I]5VlU8]9:@40@P0464<
H@8<@@04340@@110344:34000a1P464@H@0246402A1R464@PQB25:<DPPa0464DPP0246400aAR588D
PP025844464346800aB2568DHP0256401A1Q348@HQAQ56801AB200<@HPaQ46400a2100DDHA1Q344@
HA1R00<@H@03440DH11Q008@HP8@H@8@H005340@HA1R468@H@0546800aAR468@HP02344446444684
46434680211Q468@HA1Q568HXaB244044643564246444682464010aQ244<@@a20`aR00H<H@aR364@
HAAQ584246401A11464@H11Q46000a1000D@H0aP460<@11P00X@H@<<H@04464<H@a12206464011B0
440@@0PP0Pa00`aP00<<@11P44000a1P0PaQ00<<@@aQ36400PaP00`@H0a0340<@0aP364<@@a0460@
@11Q588246401A1P340@@0a046000PaP00L<@110440@H11R464@@0023644344332001Pa0360<H@aP
364<H0<<@@04340<@@aP344734000`aQ360<H@0336423442340134400088@P<8@@<88@8<8P<<@@@8
@@<8@P0324488@PQ008<8@T<@@03340<@@a1008<@@05244<@Pa2248<@@0222001BCT@PiFKej?FVh0
0UI?1UI>0UY?0UI?0eY@00=JCeY@FU000UY@15Y_00IJSUj_IaAJTD7=98<300001AQ19<HeBD7=CRh0
0U9@00UJD5Y_GVmJKUZ@FY5JT5Y`GY400Uj@1EYa00AJTEj@GY1NT0MNT@03GY1NTEjA00INT@=N/@9N
T@06HY5R/F:aHY9RTF:b0V:B1V:a00=R/6:aH[800V:b00AV/VJaI[9R/@=R/P9R/`IV/@=V/P0:I[5V
lFmhI]4TaP00>F]N/FLEH]<;I]<026KBI]=VdfKCI_=Vm6[dI]@5J_<00f[dJ_=Zl`07J_<4J_@00f/E
J_AZm002J_@3K_@4J_@00f[eJ_A_5@04KaD5Ka@2KaD00f/EKaE[5@02KaD03flgMgU^m4F^66D400P0
324<@0a1468@Pa1R448@@@04448244402A1234488@a2344<80P0320@@P02348244802AR346<<@Pa1
2244000010048002100200003258?Re6TD8_>Nde[36;=H/eZc6:<FXY:08Q1`066<HHYA23344880@0
20000PP000<880PQ22400PPQ0PPP00@40000220iQ09RZ@=JBPEFB`=JBP03FT]JBUY:00=JB`=JK0AJ
B`05FV]JK5Y/FVaJC002FTd00eY]FVaJK@02FVh02Ej>GXmR/6KBJ_=[56lEKcEc=004LcD00g<fLcEc
=P02LcH00g<eLcIc=P04KcH3KcL>KcH01FlFKaE_5FlEKa@00flE1flD0f/E00E[56lDKaA_56/C00=_
50I[5@9[509[4`03Ka=[4flC009_4`9_50A[500@J_AZlf[cJ_9ZdfKCI]9VdFJ`I_1VdDG<568000PQ
3646344010aQ468@@11020a000H<HA1Q464DPQ22468258802aB3584@@0a1468DPQ1R344@HQB25840
0Q220Q1R00L@HA1R468@HQAR588HP`02564346800aAR488DPP03588011AR588DPQ220Q211Q1Q00HD
HQ1Q464@HAB1464246800a1Q340<@00246401A1R368<HPaR34400Q1R00@DPQ22468@PP@@HP<@H@03
488DPQ1Q00<@H@<@HP09464@HQ1R468<@A1R7:@HY11R008@@@03464DHAB2008@HP<@H@<@HP05368<
H@aQ364<HP0246801a23468@HQ1R368@Ha1R00D@H@0<468@HA1Q464<@0PP340<@@aQ460<H11P2Q1Q
00<<HPa234400Pa00Pa100@<HA1R468@HP8@H@0:460@8110340<H0a0360@H11Q36423603460010aQ
340<@@a10PaQ00D<HQ1Q320@@0aP008<H@06344<8110440@HA1R111Q0a1000<DHA1022000Pa00Q1Q
0Q1000@<HA1R488<HP8<@@04444@81103404364436823649340236400`aR364<@@04344134013440
00D8@@08248<@Pa2348<8@a1324<@@88@@<88@<8@@888@8<8@T<@@03340<@@a100H<@@0=364<@0@0
344aB4h^FXmJKUH^ETiFCeY?ETh00eY?00=FCUY?ETl00UY@00=JL5Y@FTl00UI?00=JD5Y_FVl00eY_
00UJCeY_GXmR[ej>FTe5ZCD564400`0000PH@BS3>DM1ZTG;CRiFKf:?0Uj?00MJKeY^GY1R/EjAFW5J
D006FW03GY0CGY42HY43H[400f:bHY9RTP04H[4016:bH[5R/6:a0f:b0V:a00=R/VJaH[800f:b00=R
/FJaI[4016Ja0VJb00]R/V:@Ja9W=DH=420<0TG_JaEVmF;C00QVd`9VdPEVd`04J]=Ve6[cJ_<7J_@0
0f[cJ_9Zl`07J_<2J_@00f[eJ_AZm002J_D3K_@4J_@3J_D5KaD00flDKa=_5005Ka@036lEJaE[5Flf
LeQZe46<56@000P0324<@0@<@@8@@@07468@@Q11448<@Q1120000`@000L800`P3208011256<@H`02
448010a2224800@0200000h00B4X?Ri2<3h>=J`eS3F[>J`e[3F;<FXaJC5Z0S6:00PaRC5Y<FPU1aS5
5:D<H`@Q10000`@00P0000@400PQ22888@880003000<@3fV009RZ@03FT]JBUY:00MJBP9JB`9JBPeJ
B`03FTaJCEY=00AJC@0<FVeJKUi]GXiR/FKBI_=Zm6/EKcE_=6le0g<d0g<e00=c=VlfLcH00W<f4flf
0VlF00=_5FlFKaD00flE1VlD00A_4flDKaA_509[509_5003Ka=[4flC00=_4`=_50A[5@03JaA[4f/C
00A[4`03Ka=_56lD00EZm09Zl`0<J_9ZdVKAI[1V[f:=HZ]JKd6:200000a21`a10PaQ00<<@1103400
0Pa00Q100`a000<<HA1Q46400Q1Q00HDHAB1588DPQB1564346801122588DPQB20a2200@@H@aQ464@
H@8@HP8DHP03564DHQ1R00D@HP03588HXaRR00<DH@03568@HQ1Q00<@H@04564DPQAQ5646464:4680
0a1Q368@H@024640111R464@HQ1R311Q00H@HQ1Q464@HA1R46434682464234401P`P440DP11P564@
HP<@H@06468<H@Q0220<@@aQ0Q1R00@@HA1R5:<DXP8@H@043648@@a1364446402Q11440<@0aP464@
@0a0348<HA1P0Q1Q00D<H11Q464@H@`P008@H@06484@H@aP120880a11`aQ0Q1Q00<<H@PP32000a1P
0PaP00<@H0aP36000PaP0Q100`aP0Pa000L<@@a0364<@0`P440@H@0234001@`P344<@11046000Q1Q
00D@@0a0340@@0a000<@H0@<@003344@@110008@H00:360<@0a0340<810P460<H11P340536401A1R
364<@@a0320010a000<<80PP34400`aQ1@a10@Q10@a00@a10003224224401@PR328<8P`R34801@a1
0PPQ00<8@@Q224800PQ200<8@@`Q324040a100@<@PaR348<@084000668<mZUZaFVeJ;5Y>25I>00=F
CeY@FU000UY@0eI?00=JD5Y_FVl00UY_0eY?00YJKUj?H[5R/6;BGY1:;cV;:>HH@@<0000=100@8B2U
:@LeJ3f:ANa>;Ti@FW1NTUjcGY<00V:c00=R/UjAH[400V:b00=NT5jAGY4025jA0UjB0UjA00MN/EjA
H[5NTF:aGY5N/@02GY4016:aG[9R/F:b0V:B00MR/F:bH[9R/F:bH[5R/004H[43H[86H[400fJaI[9V
/P03I[802fJcH[=V/f[BI_5>Tb39000Ta5ZAJa@00V;C26KC00=VdVKCI]<01FKC0V[C00=Zlf[dJ_@0
1V[d1F[c0f[d00=Zlf[dJ_@00V[d0f[e00AZm6[eJ_EZm@=Zm0AZm@E_5@E_500=KaE_56/EJaI[=W=G
MeQ^e45/42<000P024400``Q01P<80a1444@@@a2448@@A12224800@0200D810P30080000224DQ1AT
44@@@``S2002000010@0300@80P00P@00`0000L88B4W?N`n3Sg]>Lde[002>J`00cW=?LdeR`02<FT0
2CV[>L`ic3g]>L`ec36;:DTU1`027<H01bD8;BPTiQR2420400000084000:244<@Pa1220400004411
aVK9HXT9FTXBFT/00eY<FTeJC@02FTd035Y<FTeJKEY^GViNSf:`I]9Vlf[dJaE[=@9_=@03LcAc=G<e
009c=@9c=P=_=P03LcEc=W<f015_=PA_5PA_5@A_5003Ka=[56lC00E_5004Ka=[56lDKa@3Ka<00flD
JaA[5006Ja@3Ja<2Ja@2Ja<3Ja@4J_@3J_<026KBI]5V/6J_GXeV[E9?>BL20006344234001@a1364@
@0a044000Pa000D@H@a0340<@11000D@H@03468DPQB2008DPP04488@HQ1R468248800aB258<@PP02
46400a22464@H@034683564346801aB348<@HA1R58<HY1RR008DH@<@HP@@H@04588DXaB156424682
4644468346464680112358<DHQAQ0Q1Q00<@HQB246401Q1Q00<DHA1Q46400Q1R00<<HA1R46801Q1R
0Q1Q0Q110Q1Q00<HPAAQ5640111Q0a1R0PaR00<@HA1R46401Q1Q0Q1R0`aR00<<H@aR46800Q1000X<
@110464@H@aR348<HA1P464<H@8@H@04468@HA1Q364246801@aQ340<@0a136400PaR00<<HA1Q4640
1PaQ00<<H11P46400Q2200<@HA1P46000`aP0Q1000@@H@aQ364<H@<<@@03364<@0a0008<H003340@
@111008<@@03440@H0aP008<@003440<H0aP008<H003364<H0aP008<@08<H003460@@0`P00H<@004
320@H0aP360236402@a1340<@0a1364<@@aQ340<800434000`aP340<@0033643344010Q13448@@a0
0@a1000422400`Q122888@0322800`PQ324<@@0232422243244010Q2244<@@PQ0`a10P`Q2@a10P`Q
1@a100P400P0200XiDi?GZiJC5I=2EI>00AJCeY@FW1JD09FC`QJC`AJK`0;GY1N/6;?I/mZcUj>CPdm
RBd688@@0P0400003100760TXBcT=DTmRd7>CS1B<5I@HY1V/09R/@9R/P06GY5R/EjbGW1JL5Ya15jA
00=NTUjAGY400Uja2EjA00=N/F:aH[400f:a0f:A0V:a0f:`0f:a00=RT6:aH[0016:`0V:a00AR/VJb
I[9R/`9RT`0=H[AVeF:bJ/`mK001200mYfK`I]1R/F:bI]803VKC0f[C00=Zlf[CJ_<00f[d00=Vm6[d
J_@016[c16[d00=Zlf[dJ_<00V[d00=ZmF[dJ_@01F[d00E^m6kcK_A^mF[e00E_5@03JaE_56lD00E_
509_5@09J_AcEW]hK_@mB`P2000800Q100<88@09324<80`P320<8@a1440@80@00080000F;:1FBUX6
>80X02`0<00l@DB4=6<PI1@R30400@@R?Li[4Uj`GXiBCcU:44<200001PaQ9BHibSW;?L`eZ`8i[008
=J`eRcF;=HXaJS5Y<FXeRP<eZ`04=J`ic3W=>J`2=H`02cf/BRiBL59_?L/Y1aB522880@P034400Pa0
00H400003411a6K8HXT8FTX<FT/2FTX5FT/00eY<FVaJC@04FTd2FVd01Uj=GXiR[f;AI_=Zm09[5003
KcA_=G<d00Ac=@03LcIc=Flf009_=P=c=@9_=@a_=P9_=@U_5@9_509_4`03Ka9[4flC009_4`9^m003
KaA_4f/D009[509_4`03J_=_56lD009Zm0A[50A[4`04JaA[4f/CJa<3Ja@3J_@2J_<2J_82I]402VJ`
H[1R[f[?DTla1@@0000@@0a00`a100<8@0`P34000Pa000@@H110440@@08@H004320@@11P46054642
34001@a1464DHA1R58800a1R00<DHQAQ56400a1Q00<@PA2246800Q1Q00D@HQAQ564@HQ1Q00<@HP03
48<@HQ1R008@HP8DH@8DHP8DPP06468@HA1Q440@HA220Q1Q0a1R0Q1Q00<@HQ1Q46400Q1Q00<DHA1R
46800Q1Q00D@HQ1Q468@HQ1Q00<@HPT@H@8@@0<@H@8<H@<<@@04464DPa1R364646400aAQ464@H@04
464446801QB3488@HA1Q340@H0H@H@07468@H@aQ3448@0a044400Q1Q00L@H11Q364880a2364@H00;
46443640111Q364@H11P0Q1Q10aQ0Q2200@<H0a0460@H@D@H007360<@0a0360<H@aP34000`a10`a0
111P00D@H@aQ440<@11P00<<@007440<HA1Q360@H0a046000`aP00D@H0a0460@@0`Q00H<@004320@
H0a036033645344010aQ340<80`P10a000@<H11P364<@@<<@0<<@@48@@4<@04<@@0000L8@@PQ2248
8@Q122888@03228232400`a132488@0322422446344232401@a2344<@@a132401@a100<<8@`P3440
0`a100X<@0`P320000a2=J]FT5j_ETeB;@AFCP=FC@9FCPEFC`IJC`=JCPEJKP03GViRSV:_009Vd008
H]9NTEIaBQ0m[C4Y8:<@00@0000E100D@QAU66HTac4Y?J]1c4X>CRmFD5j@H]=Vdf:cHY5R/FKBI]=V
dUja00=NT@03GY9NTEja00MNT@=N/@9NT@03H[5R/V:a00ER/@9R/0IR/@=R/09R/@9R/P0@H[=R/V:c
H[9R/f:dH]AN/eJeAJd80000=DURRV/BI_82I]85I]<5I]86I]<4J]<2J_<2J_@01FKdJ_AZm6[cJ_@0
0V[c16[d00EZlf[dJ_=Zlf[d00=Zm@=Zm004J_=^m6kdK_<2K_@2J_@2J_D01f/EJaI[5F/DKaE[5FlE
00=_500;K_A^lfkcLa=oN6Zb=@T400002208@@04224532005@`R20000000=>AoRgooOhm]AE@5G01/
@WASJ6=/a4QQ948<000038EWV`02Ool037OKOomofd6_008001B3:FPiZSV[=JXeZ`@eR`05=HXeJC5Z
;FTaJP02<HX3=J/0636[=Ldic3F/<FXaJcW>AS5>TTkECY=243587:D<8@P0368<H@@0000@H475HZUN
R@=JB`04ET]JBUY:FTX=FT/2FTX3FT/4FT`4FTd035Y]FViJKEj=GXiR[f;AI]9Zlf/DKaA_=09_=@M_
=P07KcM_=W<fLcIg=G<eKcD016lf00=c=VlfKcH01Flf0Vle1FlE0Vle0VlE1FlD00E[56lDKaA_56kc
00=_50=[5004J_A_56lDKa@3J_@016/EJaA[56/D16/C0V/D00=[5F/DJa@00f/D00AZm6[cJ_=Zl`9Z
d`9VdP08H[5NTF;BI]1>;bBU1008008@@003340<H@aQ00D<@003364@@11000@@@003460@HA1Q008@
H@04468DHAAQ564246400a1R568@HP024682464256401AB1588DPAB146400Q2100D@PQ1Q588DPQ22
00<@HP03464<@A1R00<@HP03568DPQAQ008DHP0;584DPQB2588DHA1Q340@PQB2464<@@0446834640
0aB1484@P@0646800`aQ344<H@0446800a1Q468@HP044640111R464@H@a00Q1Q111R3A1Q00<<@11Q
46801a1R2A1Q1Q1R00D<H@a1464@HQB2008@H@03360<HA1R00@@H@03468@HA1Q00H@H@03468@Pa1R
00<<H@03460@HA1Q008@H@03364<@@a100<<H@03340<H0aP00@@H006360<HA1Q360880a00PaP0`a1
00L<811P460@H121584@H003464010aQ360<H0aQ1Q1Q00T@@11P464@H@aQ464<HA1P44001Pa00`aP
00P<@0a1364<HA1Q468<HPaQ1@a12@a000H<@@a0340<H0aQ344234013440000324488@PQ00D88@03
22888@a1008<@@D88@03324<@@a1008<@@03244<@@`Q008<8@<<@@03244<@@a2008<@PH<@@8<800:
440<@0a0200402CUCR]N/5j@DRd3ETh015I=ETaFC5Y<0UY=15I>1EY?0UY>1UY]1EY^00mNKUj?G[1R
/6KAI]1VcfJ^FVmB;DG;>FPXi22S54<01@0000TD@1aP884Xa34W=DTiRd7<ETl00f:?00UV/F[bI_=V
lf;CG[9JTEjAGY8025jA0Uja15jA00AR/F:@HY1RT0=R/0=R/@AR/005HZmR/6:`H[5R/P02H[<016:b
HY9R/VKC0VKD00aN/V:?AJh<0P0096=JCG<^Ja5VlfJbI]83I]<2I]84I]43I]85I]<2J]<3J_800f[c
J_AVm002J_@016[cJ_AZlf[c16[d0f[c00E^lf[cJ_EZmF[d009Zl`M^l`AZm005J_E[5V/EJaA[5@02
KaD4Ka@2K_8017LdNeIZL2QT0P0000X<@0Q1224480PQ2448@0a03208008<000G200@03@4OZaojgo/
OdQhhV@6N6IdIfaVI8MHPe2R8408000048AK=GokOoaooP02Ool02Dhc00<001B3:DPeZS5Y<HTaJ@02
=HX2=JX00cF9=FPaJ@02;FT2<FT06C6:=HXeRSF;=J/ec36::BH@@Q13;:DhiDU6DP]BCU9=?L`Pj112
468<HPPP000DH3g5009NRP04ET]JBeY;ET/6FTX015Y;ET]FBeI;1UY;0UY:0eY;00AJC5Y/FTaJC0AJ
C@0<FVeJKUY]GXeNSV:_I]1VdF[bJa=_56ld0Vle2flf0fle0flf00=_=G<eLcH01Flf00=_=FlEKaD0
16lE0flD00=_4flDKa@00VlE0VlD0V/D0VlD0Vkd0f[d0V/D00=_56[dJ_@016[d00A[5F/DJaA[4`IZ
l`=Zm0=[5004J_AZlf[cJ_<2J]<02VKBI[9R/UjAI]9ZlDF]44<400`P0a100`aP00<<@0a1344020a0
00`@H11Q464@HA225:<DPQAQ584DHA1Q4682588246401@a0464@HA1Q58000QB100<DP11P48400a21
00<@PQ1Q46400Q1R0Q1Q1A1R0a1Q0QAQ00@DPAB2588@HP<@H@04488DPQ224883468246401@a1320D
H12158400QAQ0Q1Q211R0Q1Q0PaQ2Q1Q00D@H11Q464@H@a000<@H@03340@HA1Q008@H@03344@HA1Q
00@@H@07364@HQ1R468<@@aQ36800PaQ00@@@A1P460@H0@@H@@@HPX@H@<@H003464<HQ1R00/@H@<<
@003460@HA1Q008@H@04364880@0220336400`aP340@H00246001PaP460@HA20464@H08<@08<H@04
344<@0`P4403460011B0460@H1100P`P00@<@11P460@H@8@H008440<@A10340@@0a1364<@@8880P<
@003460<@0a0008<@@@<H@<<@@04340880`P3402440:34000`aP340<H@033400000324888@PQ0088
8@0832488@PR22888@`Q244<@@D8@@04344<8@a2348334401PQ1324<8@`Q244<@@<8@P@<@PD<@@04
340@@@a0440220001P`P<BEBL5j>EVeFC@=FCP9FC004FTaJCEY=ETh2FTl00eI>FTmJC`04FTl015Y>
FVeJKEY]15Y>25Y^019JSej@H]5Vd6KAI]1VdV[bI]=NT5I@ANm1cCU[:@LLPQ@P3003000030P0300D
81aR9<Da1cV9ALaBCejaH]AVm@9Vm005H]=N/EjAFY5N/@04GY43GY800ejaG[9R/@02GY4016:AHY1R
T6:?1V:a00ANTF:aH[5R/09R/@9R/P0AH[=V/f:CGY5RTVJbI_ER]59e?Fd@0000945RC6/BJa1VlP02
I[8016KBI]=VdVJb0VKB0fKA26KB0VKC00IVlf[cJ_9ZlV[cJ_@3I_@2J_@2J_<2J_@5J_<00fkcJ_=Z
m003J_@00f[cK_=^l`02K_<2K_@3J_@2J_D00f/FJ_E[5@04JaD2KaD046lDKaEblfkbNeAg=VIA8480
00@032088@Q1348<@@Q10Pa101/88000200402@0C49Y1Gl?OlYo1gf2N61/06@0F05<04P0B64lHBA1
300000Q3BY=kg7^jLid00Woo011:F003000<@RE8<HX]JC5Y<FXaRSF:=JXebcFZ=FTaJ08]B@8aJ@@a
RP0H<H/a[2eZ:@H400P0700l04@0@8=1B59>CY8eRQR42248@PPP100@HCg7FZeRc5I<0eI;0UI:0eY:
00=FBeI<ET`00UI[00AFBeY/FTaJC0MJB`04ETaJC5Y<FT`6FTd02EY^GVeNSf:_H[5VdF[bJa=_5003
KcD=KcH00fleKcI_=P09KcH016leKaE_5Fle0Vlf00=c5FlEKa@00VlC1VlD00=[56lDJa@00flD0f[d
0V/D1F[d00A[5F/DJaE[509Zm003Ja=Zlf[b00IZl`04JaA[5F/DJ_@2J_<2J]<036[BI[9V/V:bGY5V
dV:>>DX40@@0440<H08@@004560@H@aP360234453402344020a0360@HA1R488DPQS46:<356400a1R
464@HP0246801A1Q344@HAB25:801AB10Q210Q220a1R00<@HA1R46802a1R00L@HAAR568@HAB16:8D
PP064880211R464<H@a0440@HA21584256400a22464@HP0546800a2248<@HP0246800a22468@H@02
46401AAQ588HXaRS58<01A1Q00D@HQB2468@HA1100<@H@03468@HA1Q00D@H@@@HP03368<@@aR008<
HP03364@HA1P008@H@04488@HA1Q24434683464020aP464@HA1Q468@PQ1Q460246400`aP340<H002
46400`aQ464@H@06464236400`aP460@H00346401PaQ220880a1364<H0<@H@8@H00:464@H11P588D
XQB2460@@11P360236401110320@@1100a1P0Q1Q00<@@11132000Pa000L<H11Q464@HA10340<H@03
34400`aQ344<@@0236443403360334000`a1364<H@0836400`a0320@@@0734001PaP340<@0a0360<
H@8<@@4<@04<@@0000@88PPQ22488@8<8@0332888P`Q00<88@@8@@<<@@04320<@@a2344224423240
10a13248@@a10PQ20`a200@<@@`R224<8@8<@@05368<@@a0340@@00232002@@0568mIej>FZiJSUI<
ETiJC@04ET`01UY=ETiFCUI>ETeFCP9JCP04FTmFCeY?FTh5FTd5FTl00eY>FViJKP06FVh015Z?GXmR
/6:`0VKA00eZdF[aJ^mZkV:=ETe>34G:?FPa9RCT8:8D@00400004P@0540PPBS4;@LiRTX=GXmVd6;A
I_=Zm6KdI_=Rdf:bH[5NTP9NT@03G[5R/UjA00=NT@06GY1RT6:@H[5NTEja0V:a1F:@0V:a0V:b00UR
/ejBHY=RTf:bI]=JTDG^9>/00P0000DT8ei=LbaVkVKb009R/P05I[9VdVKCI]9V/P05I]43I]82I]44
I]801FKCI_=ZlV[BJ_800V[c0V[d00EVm6KcI_=Vdf[C00]Zl`9Zm09Zl`=^l`9^m003KaA[5F[e00AZ
m@05JaEZm6/EJaA[5@02KaD2K_@026kcK_9kE7LfFNlL8P0010040002100220004A00500P04@0F89d
hWh8O[1nd7H@JBQ4I4AR=00T01`060000R1R01<H@@P00008@U;GNmmgWVLlNomoodXF00D000PQ8BP]
JC6:<FTaJP02<FT01369<HXeRCEY0S5Y00@]:2e8<FTaRP8eRP8aR`8aS00H<BP@8A@0A05H8f@0C08l
0443CPa5YQb2200880`P100@HCF6DXeJ[UI]ETYF:UH[0UI:0eY:0eI<0UI[00AJJeY/FTaJC0MJB`9F
B`06ETaJC5Y<ET]FC5Y<0UY=00UJKEi]GXiRSfJ`I]1ZlV[cKa@00fle36lf16le0Vlf00=_=FlfKcH0
0flf0Vle0VlE0f/E0VlD00=_4flDKa<00VlC16lD0VlE16lD16[d00Y[56[dJ_=Zm6lDJ_=[56lDJaAZ
m0=Zl`MZlPAZl`03J_AZlfKC009VdP0<I]5V/VJbH[9V/VJaFThe1`P1200@@0aP0Q1000@DP11P360<
@08<@@D<@003240<80a0008@H005588HXaS3488DPP0358401AB2464@HA1R56400Q1Q00H@PQB1588@
PQAQ4642584248400aB2468@H@0246400aB1488@HP0;46800a1Q564DH@026:825885488246824640
211R464@H@aQ468@HA21488346400a22464@H@0246400a1R368<H@02364546400a1R488DP@064640
0a1R464<H@02444946401A1R488@PQB248800Q1R00@@H@aR364<HP8<@003460@HA1Q00<@H@<@HP05
488DPQ1Q464<@00646400a1P464@H@0346400a1P364@H@0246400a21464<H0024604464246054640
0a10360<@00246000aB25:8@H@02460346400aB2484@H00246001@aP464@PQ1Q32000Q100a1P0Pa0
00<@@0a034000Pa00PaP111P0Pa010a110aQ0Pa000<@H11Q360010a000H@@0aQ364<H@a136423440
1@a0460@H11P34000P`P1@a000D<H0a0340<@0aP00@<@@4<@04<@@0010PQ0P`Q1`PQ0`Q10Pa100<@
HPa134400`Q200H<@P`Q324<8@Q1248334801PQ23448@Pa224888@8<8@<<@P0>344<@110440@80@0
200XXTh[G_1JSEI]ETiJC@AFC@06ETiFCeI>ETiFCEI>0UY>00AJCeI?ETmJC`9JCP03FTeJCUY>00IJ
C`03FVmJKUY_00=JK`03FW1JKeY_00AJKP0CGViNT6:@H[1V/6KAI]1VdFK@J_9VdV;BGY1>;d6[>FXa
:2345200100000/4010P7:<]1cV[@Ne>D5Z@G[9R/fKd009Zm007I]=R/VKBI]=R/F:bH[400UjA0Uj@
00]N/F:bH]=R/EjAGY1NL5j@HY5R/F:b00=Vd`9Ve00=H[AJLe9C>JlU2P@0000D03RTJW1_EV/AJ_80
0f:b0VJb00=VdVJbI[800fKA00EVdVJaI[9VdVKC00AVdP05J]9VdVKCI]=VdP02J]<2J_<00fKDJ_AV
m002I_@2I]@;J_<3J_@3J_<016kdJ_AZm6[d0V/E0f[e0V[d0V/E00A[56/EKaE_5@=^m005LaAkEG<F
BJh@000200000`@000000003000210003aP0@01PPgc4O<=mIGh:OLQUAEUZBFddjR2442<@@`024480
4aB456888@@0000@Q5/GOoigWFLlNomoodGD00<000PP8@LaRBeX00DaJ@03<FXeRS5Y008aJ@8aJP04
=HTaRSF:=HX2=H/01S6;<J`a9aA2:01dP`9lH`06K01@03`0>>99Q22R0PP000/<@0P0220Y0d7ZD[1F
K5HYFT]FBeI:00=JBP04ET]FC5I<ET`3EV/2ET`00eY/FT]JC002FT`2FT/01EI;EV]FJeI<ETd015Y=
00=FCUY=FT`00Ui]00=RSfJ_I]400V[c00=_5FleKcD03Vlf26le0Vlf0Vle16lE0f/E00=_56lCKa@0
1FlD0VlE0V/E0V/D00=Zm6/DJaD01F[d00A[56[dJ_AZl`9Zm0A[5004J_=ZlV[bJ_85J_<01F[dJ_=Z
lf[dJ]<00VKC0VKB00YV/V:aHY5V/VJ`DRhXY0P1200@@08<@003440@H11P00/<@004320@H11Q4683
48<01aBR588@PQB26:<DPQB100<@H@8@PP8@H@03564DPAB1008@P@04464@HQ1R468346401aAQ488@
HQ1Q468@HAAR008@HP04488DPQ224682464011AQ568LXaRR0QB200P@HQ2248<@PQB2488@HQ1Q0a1R
00<@PQ2348<00QB200<@PPa04640111R0a1Q00<<HPaQ36400PaQ00<@HA1R4680111R111Q00P<H11Q
464@H@aQ340<811Q111R111Q00@@HQBS5:<@PPH@HP8<HP03364<H0aQ00<@H@<<H@03464DXaRR00<@
H@03468<H@aQ00<<H@04460<HA1Q46424600111Q364<@0a00`aQ00<<H11P46001`aQ00@@HA22488@
H@8@H004364@HA1Q36434643364246400`aQ464@H@05364334000a1Q588DP@02440934002PaP364<
H@aR348<@@a0344<H@aR10aQ00@@HPaQ344<@@8<@003460@@0a000@<H@03344<80`P008<H@03488<
HPaQ008<@@P<@08<H@043408@0a0340126800003224880PQ008<8@<88@0332488@PQ00D88@03324<
@@a100<<8@<<@@@<8@<8@@@<@@03348<@@`Q00<88@04324<@@a1344244002P`P200000`P=D=BSek<
FXaJKeY=0eI=0eI>00AFCEI>FTiFCP9JCP04FTmFCeI?ETl2FTl3FTh5FTl2FTh3FVl015Y`FVmJKeY^
15Y_00=JKUi]GVh00Ui_00AJL5i`GY1NT09R/0=Vd@0;J]5Zd6J`IZmJCe8]AL/iB2S4888D80030000
3@@0420HH233;@HeB46[BPeNKVJ_I[1Zlf[d009Zl`09I_=Vm6[dI_AVdfKcI]9VdfKd00=Vd`=Zl`09
J_AZlfJbI[9NTE9@@J`eBQb600<000069<E9jFj8L`m[4f[c16:b0fJb0VJa0fKA0VKB1FKC0VKB00EZ
dFKBI]9VdV[B009Zd`04J_=ZlV[cJ_<5J_@;J_<2J_@3J_<3K_<00f[cJ_AZm003J_@01FkcK_A_56lD
Ja@01FlD0Vkd00Ec=W]fLcQEca@00080000H444eR4XZ>JT`iQ00000T04P1J:Ela7ARL:9/i6DVB@I9
9Df/?@X/bA1442<@@QAS0QB300T@@@a1200001c5HcEong^lJeh00Woo00M5/P02000<@RU8>JPaI`03
<FP01358;DP]:35X135Y00<aJSF9=HX00SF:0SF;00HaS3F[;@D<0200G003O6<02600?011J4VU7848
00`P440232001AR2<DMBL6;;ETT015I:0eY:0eI<15I;0eY;0eY<0eY;0UI;15I<00MJCEY<ETeJCEY<
GVeRSP02IZl01F[AJ_=^m6lDKcD03Vlf1Fle0Vld00E_<fleKcI_=Vle00Q_5@03KaA_4flC00E_509[
50EZm09[50QZm0=Zl`9Zm09[509Zl`9ZlP03J_=[4f[c009Zl`05J_AZlf[cJ_AZd`02I]<02FKBI]5V
/6:@GVmRKf:?BL/LHP0220000``P340<@@0534000`aP340<@00734000a1P464@H@03468248803a1R
588L`a1P564@HAAR464DPA1Q564@HA1R488DP@02488546800a1Q444@H@0746401a22588DPQ1Q468<
@1AP00@DH@04460DPAAQ588348800a1R464@H@044680111S488@PQ221Q1R0a1Q0Q1R0`a10Q1Q1Q1R
0Q1Q00@<H@a0340@H@8@H003340<@A11008@H@<@HP8@H@05460@HA1Q464@PP0246800`a2464@H@03
46800a1Q460@H@0346401a1P360<@0aP464@PQB100@@H@05364<@0a0344<@0024600311Q460@H110
460@H@aQ320<@0a1364<H08@H004464<HA21468436401Q1Q364<H@aP460<H08<H@888004364@H@aQ
240222000`aQ468@H@0436402PaP340<@0a0320<@AB2584@@11P0`a000P<H@aP340<@@a0220<@0aQ
0`a100H8@0a0340<HA1R36423442348434403`a0460<@11P364<@0PP320<@@a0320<@0aQ468<HP02
364010a1340<@0a00Pa10`a000<8@0a034000`a00@aR00022244324722401@`Q344<@Pa234401P`Q
3@a100@8@PQ1348<@PD<@@8@@@0;448880@0000PXd8;EXeFS5Y]FTaFC@06ETh00eI?ETiFCP02FTh0
0eY?ETmFC`02ETl015Y?FTiJCUY>1EY?0UY>00MJKeY`FW1JKeY^FVmJKP05FVl00eY^GViNL002FW00
15i`FW1JKeY^0eY_0Uj?02AR/6:aI]9Zlf[bJ_=Vdf;CGY1:;d6[=FT]1R2R420800@000040100664L
PR2S;>DeB47;@Ne63TX_EU1FL5jcH]ANdfKBI_@2I]802f[CJ_AZlfKDGY1BDDW_@LdeJbT968@00`00
00T802T8@NiNdfKbKcEZlV:bH[401f:b0fJb0VJa00=V/VKBI]<01FKC1FKB00EZdV[CJ]=Zlf[b009Z
l`05J_AZe6[DJ_=Zm007J_<00f[dJ_=Zl`07J_<00f[dK_AZm004J_@3K_<6Ka@2Ja@02V[dJaA[5G<g
MeQV;a@0000XHV[A0goo01AofEeYA29D06a4O<EdHf@0A014Pd2R6004010R7:HDQ@P1300DI1BT0QB3
00T@HP`P100001c6IaIoo7oLJgd00Woo00Q9/002000<@ReX?LTaIc5X0S5Y00@]B2TW;BLaB@LaJ@0F
<HXeZcg<=H/aJc6;<@H<02@0E01h8GaSO49`04QR>FY9YR21420DH1R0560242001223BP]RZUjZ1UI;
00AJBUI;ET]JC0MJB`EJC09JB`04FTYJBeY;FV`2ET/03EI:ETaJC5Y]GXeRSVJ_I[1ZdF[cKa=_56le
00e_=P9_=@05KcA_=FleKcE_=002Kc<4KcD7KaD2Ka@00flCKaA_5003Ka@3Ja@2J_@5Ja@00f/CJaAZ
m006J_@3J_<3J_@3J_<01F[bJ_=Zlf/CJ_<00V[d00EZlf[dJ_AVlfKD009Vd`0<I]5V/F:AGW1RTFJb
@HX@80@0200@@0a00Pa11@a000<<@@a0340010a000<<HA1Q46000Q1Q00`<@@a0344@HQ23464@PQB2
564@H11Q588546434884468246401QB3588@HA1Q440<@08@H@03468@HA1Q008DPP05584@H11Q464D
H@0246401@a0460@HAB156400Q1R0Q2200<@HQ1Q46800Q1R0PaR00@<Ha1R468@HP8@PP0448<DPaB3
488346400a22468@HP0246801A11468@HQ1R48800Q1R0a1Q00@DPQ1Q340<@08@H0D@H@04588@HQ1R
3642464010aP464@HA1R0Q1Q00P<@11Q468@HQ2258<DHA1P1A1Q00<<HQ1Q46001A1Q1PaQ00<<@11Q
46000a1Q00@@@11P464@H@@<@@06360@H0aP364<PQ1Q0PaQ00<<@@aQ36401`aQ00D<HPaQ344<H@aR
008<H@03240880a000H<H@03360<@0a000<<@007360@H110460<H0a034400PaQ00D<H0a1340880a0
00<<@@032208@0a0008<@003344<@0a0008@H@03364<@@a100<<@@8@@004464<H@a0320234402Q11
344<@@aQ368@HPaR348880a10`a00`Q10`Q010a00@a1000010a1324<8@a10``Q00@88@`Q224<8088
8@8<8@05224<8@`Q324<@P063242344232400`a1324<@@0434400`Q1344<@@0734403111348<@@P0
100802T3CRUNS6:/FTYFC0AFC@AFCP=JCPAFCP9JC`=JCPEJC`=JCP9JD003FVmJKUY^00MJKP9JK`06
FW1NL5i`GVmJKei^0eY_0Ui_01eNKUY_FW1NTF:aH]9VdVKCJ_=ZlV[?IZmV[Ui]DRa5bcf9<DLTi1QR
200400P0400@8110540DHAb100<P``07:>@a1S4U<@Da9C45:><00bC300@TXaaR524800@00008664i
J4h/I/ic<f/DJ_ERd`YR/P9V/P05I[5V/VJaI[9VdP04I]<00fKBI]=Vd`04I]84J]8016[bJ_=Zlf[d
0V[D4f[c00=Zm6[cJ_@016[d0fkc1f[d00Y_56/DJaA[5FlFNgQ^SRPP401^CP9om`0>OoEom7ogOoIn
<6PQJ2UP:D01;00h07I^INP`H`800004100<8@`Q44425:@05ART58<@@A0P1000011SF[=ong^iLiao
ogonCJl00@00220YASVX=HPeJ@09<FT08S69<FT]J2e8;FTaRSF:<HXaJc5Y;@H@@B`0G01h8Gb4O49`
04@Q=DU1IB21420DP1R0540<010P568e8UI7GX]JReI;0UI<0UY;15Y:1eY;1EY<00EJBUXYFTQJBEI9
00AF:P0:ETYJK5Y]HXaRSFJ_I[1ZlV[cKa<2Ka@8KcH2LcD3KcH2KcD2Kc@01W<cKcA_=6lcKc9_<`=_
=@03KaA_5FlE009_5@A_50=_4`A_509[509Zm004J_=Zm6[dJ_@2J_<2Ja<6J_@4J_<00f[dJ_=Zl`02
J_<2J_800f[aJ_9Zl`06J_<03fKcI]=VdfKBH[5RTUi`I[=RTSU9200400`P440<H@0434400`a0344<
@@0234400`aP340<@00234000`aP464@H@02464246801Pa1468@HQB2468@H@8DH@8DHPT@H@<@HP05
464DPAB2588DH@07464010aQ464@PAB11A1Q00<DHA1Q56400aAQ0QAR0QB21A1R00D<HQ1R468@HPaR
00D@HP03464DPA1P008@H@03584DPQB2008@H@04444@HQ1R468246401Q1R464<@11Q5:8DPP<@H@8<
@08@H0<@H@<<H@8@H@03360@H11P00L@H@04468@HAAP46034642468010aQ464@H11P111Q00<<HA1Q
46800Q2200<@HQ1Q46000Q1P00<<@0`P44000a1Q00<<@@`P34000PaQ00<@H0a036400`aQ0`a000<<
@@aQ36400PaQ00<@H@aQ36401`aQ00D<H0aQ3408@0a0008<H@03344<@0a0008<@007360<HA1P360<
@0`P46000PaP1PaQ1Pa000<880a022000`a000H<811P464@H@aQ344232001`a0440@H120360<@0`Q
00D<@@04320<@@aQ3643344334001@Q12408@@Q124001Pa0000010a1224<8@`Q0Pa110`Q00@<80PQ
22488@8<8@06344<@P`R348<8Pa20`a100<<8@a134400P`Q1`a100<8@Pa134400`a100<8@@`Q3240
10a200T<@0@0000@HCf6GXiRZUYZET`015I>00AFCeI>ETiFCP9JCPAFCP=JC`=JCPQJC`9JD004FVmJ
KUY^FVh5FVl01UY^FVmJKeY_GVmNL0=NK`=JL0=JK`03FW1JTEZA009JT@9NT005H[1VdFKAI]5VdP02
J_8046KcI]5NT5Y_EU1>3dG<>FTeBC4V9<<HH1@P400800@00P0000<4000000002@0000`801QS;@Pm
[DhaFVmRdV/BJaAZlfKBH[42H[800f:cH[9R/P07H[82I]8?I]<00fKBJ]=ZdP02J]800f[CJ_=Zm002
J]@00f[cJ_AZm002J_@6J_<3J_@5J_<7J_@3J_<8J_@2JaD08F[eJaEkNGKb?>HT8gJeOiInm6F_M[Eo
nWolOW9/H505@0<P0000=89onGo/ILLL0000404<@aAS6:@Q1bf:;DPHY00254401``P000@@U9@Om]c
N7Nm009oo`08CJl00@00220YASF8=HTaR@8aRP8]JP8]J@8aJ@0J<FXaJBeY;FTYB2TX<FTaRC6:<FX]
B2SU548`06@0O49lQ7aSL00l035:?D@LHA0P560HH08@@007540LHBB0ALIBKEZ:FV/00UI=00AFC5H[
ETYFBP9JBPEJB`05FTaFBeY<FTaJC@02ET`00eY;FRUJB002ERT0358YERUF:EHZETYJJUY/GXaV[VK?
J]5Zl`9_4`9c50m_=P9_=@05KcAc=7<dKcE_=005KcD3KaD3JaD00flDKa=_4`03Ka@3J_@016/DJ_A[
56[d0V[c0V[d00AZlf[bJ_=Zl`EZm0EZl`03J_AZlf[d00aZl`0=J_9VlfKCI]=R/V:cGY9JLF:AFW8a
1`0020000Q1000<<@0a134400Pa100<<@0a134400Pa100T<H@a0344<@@a0460@HAAR46401A1R00HD
HQB3568DHQ1R564546801A1Q468@HA1Q34400Q1Q00<@HPa144400a1R00@@HA1R588DPP8@HP03488@
PA1Q008@PP05588@PQ1Q464DP@0246400a22588DP@0356400aR2568@HP0246400aAQ464@H@024682
464646802Q1Q564@@11Q468HPQB1568@HQ1Q1A1R1A1Q00<DXa1Q46400Q1R0Q1Q0Q1P111Q00D<H@aR
464@H@aQ008@H0<@H@03468@HA1R008<@@03464DHA1Q00@@H@06468@HA1Q364@HA110Q1Q00@<@@aQ
364@H@8@PP03468@HA1Q008@H@8@HP8@H@8@HP08368<@@a1464DPQB1340@H0<<H@<<@003464@PQ1R
008<H@8<H003340<HA1R00<<HPH<H@8<@@8<H@04464<80`P340236400a1Q364<H@03360336402`aP
464<H@aQ488@HQ1P360<@0a136000Pa000P@H0a0344<@0aP364@HPaQ0Pa100HDHQ10440<HA1Q3642
34400a1R348<@@023482320534400`a2368<H@02368334423644340000888@033248@@`Q00<<8@04
344<8@`P22022242324:34453248344010a2344<@@a10``Q0`a200X<@A11200400PP9:=5aej9GX]F
C0=FC@EFCP9JCP=FCP=JCP04FTmJCUY>FTh9FTl01EY_FViJKUY]FVh00eY_00=JKUY_GVh015i^15i_
00=JKeY`FW0015Y`00ANT5ZAGY1NT0ANSP06GXmNT5j?GY5R/VJb16KC00EVdVKAI]1V/5i]009F;@0;
DPa5jd7:?HTiAcDU<@@a0c44<@<]1002<@@043DU>DLmId6ZAL]F;F:>I]5^lflDKaE[56KcH]=R/V:a
0f:b00=R/f:bH[8016:b0fJb00=R/VKBI]800VJb00=VdVKCI]<02FKC00=VdV[CJ]800V[B0f[C0V[c
16[d1f[c0f[d2V[c0V[d1Fkc00=Zm6kcK_@00Vkd01AZm6[eJ_IZmW<fMeMfl5e6B>MMdG8cF:dl1d@5
KE1nE7F8C4<`0``00P0000P/@7obOnmo9Ba4200<011S0QB300dYBD8_@N/HPaAS568<80007:E[=goi
MgMcVP02Ool01d6@008000a0;FLiZC5X00<aR@8aJ@8]J@03;DT]B2e9008]B00E:FT]JBU9<HXaRCW;
=HX]B2ST448`06P0O49lHga2L0100CE/>BDH@1A0008DH00?440LXRS39:8LH34SBPYNZEZ;ETiFCEI<
ER]FBUY;009JBPEJB`0LFTaFBeI;FTaFC5Y<ETaJBUXYERUF2E89DRUB:5HYERYB:UY9FVYNRf:]J_1Z
dF[cJa=_<fldLa@9KcH3KcD2KaH01VleKaA_56lDKaE_=@M_50=_5@=[5@03Ka=^lfkc00=Zm0=Zl`04
J_A[4f[dJ_@2J_<2J_@00f[cJ_9Zl`02J_<2J_@00f[cJ_AZm003J_<00f[bJ_=Zl`0:J_<01FKcJ_9Z
lVKaI]800VKC00UV/f:dHY=RTV9_CRlXaP@032000Q1000L<@0a1344<@A1R464<@0043442340010`P
340<@11P0a1Q1A1R00L@Ha1R568@HQAQ468DPP024680311Q468@HQ1Q364<@PaQ484@PQ1R344@H@8@
HP<@H@08560@H11Q488H`Qc4588DH@8@H@@DP@8@P@07584@HA1Q564@HQ1Q46800Q1Q00T@HQ1Q464@
HA1R464@@A1Q46800a1Q00@@HQ1Q468@HP8@H@03468@HAAQ008DH@03584DPQ2200<@HP03464@HQ1R
008@H@03468@H@a100<@HP<@H0D@H@06340@HA1R464<@11P1Q1Q00<@HQ1Q46402a1Q0Pa000D<@@aQ
364<H@aP008@H@8<@08@H@<@HP<@H@<<HP8@H@04584@H0`P440236000`a0364@H@0346400`aQ464<
H@0546400`aQ464@H@0346401PaP460<HA1Q364@H@8@H003420<80a1008<@@8<H@07360<@0aP364<
@0PP34000Q1P00<<H11Q46400a1P0`a00a100`a000@@H11Q464@@08@@@8@@08<H@l<@@03244<@@Q1
00P<@@<<@04<@@0000<8@@PQ24400PQ110PQ00<<@@a034400Pa10``Q0PPQ00<<8P`Q344010a12@`Q
0Pa100@<8@a1348<@@<<@P8<@@D<@P888008000<@341DTUNcEI/ETaJC@]FCP04FTiJCeY?ETl9FTl5
FVl00eY^FVmNKP05GVl3GVh00ei_GViNK`02GVl00ei^FVmJL005FW04GY001Ej?GY1NKei_GXh00Uj?
1Ej@00MNTF:bI]=VdVKAI]=ZlP02I]402V[bKa9_56lCJ_=VdFK@J]1ZdF[@0V[A00IZd6[AKa=c=FlE
Ka@2KaD01FkdJ_=ZdfKBH[400V:b0f:a0V:b00=R/f:bH[800f:b00AR/fJbI[9V/P9R/P04I]9V/VJb
I]8<I]<3J]<00f[BI]=Zd`06J_<00f[dJ_=Zl`02J_8AJ_<3J_@01VkcK_A^lf[dK_=^m09^l`0EK_AZ
mF[fJ_Ec=W<FKW1QIeeZNaQn/eQ4;09406A0L85DQ5eYKTm1S`P100800007Oo=ok7od?BT800@01280
0Pa200TDYBf[:DPDHQ1134480000:BL00Wom00igU7=hOomoocfA00800122;HPibS5X<HTaRS5Z0c5Y
00D]JBe9;DPYBBU8008YB@0;:FX]JRf:<HXeZcF:<FT]1A12901T0003O4801F`0A4<eK3TU76000QA0
00`DH1bR<B<iYbC3564LHCf8FXeNkeI[ET`2ETd00eI<ET]JB`06FT/00eY<ET]JC@02FTd025Y<ER]J
:UHZERUF2E89CRX2DPT02dh9DPYB:UIZGV]R[VK`JaA[5FleKa@00Vle0flf00=_=FlfKcH00flf0Vle
36lE16lD1F/E00E[56lCK_9^lf[d00AZl`=Zm09Zl`=Zm0IZl`EZm0=Zl`03J_9Zlf[c009Zl`=Zm0MZ
l`03I_=VlVKB009VdP0:I[9R/V:BIY1RKTW=68@000`P44023404344236433442468334000a1P464@
H@02488448<01QB346<@HQ1R464DH@<DPP0458<DHQ1R46824880111R488DPQ231Q1R1A1Q00D@PQRS
6<@DPQ1P008@H@8@P@<@H@04484@HA21464246803@aQ464@HA1Q584@PABR6<<HXaAR440DHA1R008D
PP@@HP06344@HA22364@HAAQ0Q1Q00<DPQ2246801Q1R111Q00@@@11R58<DH@8@H004464<@11Q5882
464020PP340<H@aQ368@HQ1Q3642464246800a1S48<@HP0246400a11464@H@03464246800a1Q368<
HP0234433645464546800a1Q468<@@03368010aQ464@H11P0PaQ00<@H11Q46400Q1Q00D<HA1Q360@
H11Q008@PP<@H@0=444@HA1Q588@HQ1Q364@HA11468DPaB246400Q1000P@HPaR364<@@a0364<@A1P
0Q1Q0Q1P0Q1Q00<@H11Q46400Q1Q0Q1P0`a000<@@0a034000Pa00Q1Q00P@HQ10320<8111464@@@a0
0PaQ0Pa10PaQ00@<@@PP320<8@8<@@03348<H@a100<<@@88@@04344<H@aQ36033443340134400004
24488@PQ2445224010PP340<@@a10P`Q00<88@`Q32400PPQ00<<8@a134400`a11P`Q00<<@@`Q3240
1@`Q0`a100<<8@a134400Pa210a10PPP00L401AP@LAFSUj/ER]JC00;ETh015Y>FTmJCeI?0eY?00=F
CUY?FTl01UY?0UY>0UY_15Y>15i_0Ui^1Ei]00=JKeY`FW0015Y`00ANL5Y`GW1NL0ANK`03GXmNT5j?
00INT0=NT@9NT0AR/004H]5VdFKBI_83J_8016[cJ_9[4f[c0V[b00EVlfKCI]=Ve6:c009R/P=R/@iR
/P04H[=V/VJbI[83H[82I[800fKBI]=Vd`0;I]<01FKBJ]=ZdVKBJ]800f[C0V[c0f[d00AZlf[bJ_9Z
lQ1Zl`9Zm005K_A^lfkcK_=Zl`05K_<056[dJ_EZmFlDK_IQkV5WK[9oogokJK@H03@0D01H0S`4OVmo
mGooDQ8200002UFTOnQom6I_820000@1248<@Q220QBT00X<80PP58<80000?LUoogonMkEcU`9oo`0;
@M800P005:8YIcFY>JTeZSF:<HXaJP03<FT01be9;DPY:2TX:BTYBBUY008]J@0S<FTaJ357;DLa9Q12
901L07@0O49d0F00A6<iJcdV520@81@P440ThT7VCR`eIb23648/`dG9H/iVk5Y[ETiFCEY<FT]JBP06
FT/00eY<ET]FC002ET`05EY<ETaJBUXZFRUF2E89DPY>2DX8CPQ>2E8:ERYJBEi[HZiVd6KbJ_=[5004
KcD00flEKcE_=@06KcD01FlEKaA_56lEKa@01flE1flD0V/E00=[56lCJ_<00f[c00=ZlV[cJ_<00V[d
36[c00A[4f[dJ_AZm0AZl`03J_9Zlf[c009Zl`=Zm0=Zl`05J_9Zlf[cJ_=Vl`03I]42I[0025j@HY5R
KFZ^?HX88P002202440236400`a1440@@002340244000a1P364<@00234000`aP464@H@0358824880
0aB3588DPP0258801QAR464DPAB2584DH@8DHPd@HP8@H@05468@HA1Q468@PP0258801A1Q340@HAR2
48800a1Q00@@HQB2588@P@8@H@03468@HA1P00<@H@06584@PAS27<@DPQ100Q1Q1Q1R0a1Q00<@HQ1Q
46400a1Q111R00@@HA1R468@H@8<H@@@H@04588@H@a04606464010a0344<HA1Q0`a100L<@0aQ444@
H@aQ464@HP0:46400a1R368<HP023682348010aQ464@H11P0Q1Q0Q1R0a1Q00@DPQ21468<H@<<HP05
464<H@aP364@H003464021B2484@H@aP364@HA1P34024642460234400a11464@H@0246402111348<
@Q1R568@@@a0440234000`a1364<H@033643460346424602464010aQ464@H11P1`a00Q1000@@HA1R
440<808<@00=440@@@aQ364<H0PP344<H@aP240400PP34002@a100D<H@Q0464@PQ1P008<@004344<
@0a034013440000324488@PQ0088@@042488@@`Q22443445324010a234<@HPa11@`Q00@<8PPQ224<
@@8<8@03344<8@`Q00D<8@8<@@03324<@@a2008<@P<<@@0:224<@@Q2200<82T2CTeFKEZ<FVd<ETh3
ETl2FTl025I>ETmFCeY?FTiJCeI?FU03FTl01EY@FTmJCeY>FTl00eY>0Ui_00=JKei^GVh00ei]00=N
KUY_FW0015Y`0ei_00=JL5i`FW000ei`00ENT5i_GY1NT5jA00ENT0=NT@]NT003GY5NT5j`009N/003
GY1NTEjA009NT@ANTP04HY9R/F:aH[83G[8;H[800f:cH[9R/P03H[82H[<@I]<2J]<016KCJ]=Ve6KD
0V[C00QZlf[dI_AZm6[cJ_9Zlf[b3V[c1f[d00=Zlf[dJ_@00V[d00Y^m6[dJ_EZmF[dKaA^mEf=HDIb
d`9oo`07Oe/d1a`0@0=<0cP3EDX00Woo00ekVR12000@07n5Oo=ondg=44D48PQ23688@0043440111R
420403g/0Woo00eooG_mOomoocfb008001229DLaQcF9<HTaRP03<FX0136:;FT]BBdX0bTX0RU90ReY
00laJC57;BLY9bT5204T05`0M01l@V`0H00lHSDY>@@00``000dPP3fUDVaBSdGY9:4L@1@P<@A>CEI[
FXeFKP03ET`00eY;FTaJB`04FT`045Y=ETaFCEI=ETaF:eY<FT]JBUH[EP]B:dh;CPa>;58/0dX:00UF
2EY9GVURSVKAJ_9Zlf/EKcD00flf00=_=FlEKaD00VlE0VlF0flE00=_56lEKaD00VlE00=_5VlEKaD0
0VlE00Y_56lEKaA[56/CJaA_56/EKaE[5@=[5004JaEZlf[cJ_<3J_@8J_<00f[bJ_=Zl`08J_@7J_<3
J_@2J_<01F[dJ_=Zlf[cI_<00VKB00QVdFJ`I[5NTF9`IXmVT3E;0P0000<880a144000`aQ00<@@0a0
34000Pa000@<HA1Q440<@08<@@0=364@HA225:8@PQ1Q344DPR3U688@HAB248800QAR00@DPAB2588D
PP<DHP@@HP03488@HQ1R00<@HP03488@HQ1Q00D@HP03488DPA1Q00<@H@03468@HA1R00@@HP04464<
HQ1Q368=464258<346800aAQ468DH@0246401122364@HQB20QAR00<@HQAR56800Q1R00@DPa1R464@
PP8DP`03488@HQ1Q00P@H@04588@HQ1Q44423642344010a0344<@@aQ10aR00@@HQ1Q464@H@<@HP<@
H@8@HP0548<@HPaR348<@@0244024600111Q468@HQ1R1Q1Q00<@HPaR36800`aQ0Q1Q00<@H11Q4640
1Q1R111Q00<<HA1Q46000`aQ00/@@A1Q464@@11Q468@Ha1R444<@0`P008<@08@@003464<H@aP008<
H@03360@H11Q008@H@04468<HA1Q36423680211R464@H0a0440<@0aP364246400a11464@H0023640
1@a1340<H11P44000Pa00PaP0Pa100<<H@a134400Pa000@@HPaQ344<@@D8@@8<@@<<H@8<@0<<@@4<
@04<@@000PPP00@88@Q12448@@888@<<@@<<80P<8@08344<8@`Q2488@@PR224<8Ph<8@D<@@03220<
@@a1008<@@071008011Q>FEBJeZ=FXl04UI>0UI?00EJCeY=FTmFCeY@00=JC`=JD003FW1JD5Y>00=J
CP03GVmJKeY_00IJKP03FVmJL5Y`009JK`=NKP03FVmNKei`00QNL0ANT0=NT@03GY1NSej@00QNT@MN
T09NT@9N/@9NTP03G[9R/EjA00=R/@9N/P9R/P03H[5R/V:b00IR/P=R/@AR/PER/`03I]AVdfKC015V
d`9Ve005J_=Zm6[cJ]=ZlP0=J_<:J_@016[cJ_AZm6[e0f[d0f[e019^lfkEHJiUIW:^Oo9ooWooJSDX
0R`2C0<d02P0FHeooWojAFX2000037m7Oomoog=I9</000a1368400a158<DX`8HY006300403UXNoao
oWom0goo00TiT001000@PRDW<FL]Ic5X;FP00c5Y02/aRS5Y;DP]B2dW:BLY:2TY:DTaJBeZ<FT]9bTW
9BLTi@@1601H07bUO>=m15`P?6<iBCC1100000`0>D5>Bej]FZaBBSU3840D021P=DE62EI]GXiFB`03
FT`00eY;FTYJB`03FT`2FTd06EI=EReF:eHZEPYB2Th;CPa:347:?JTmRT6YANY:2dX:BPU5j58:FVQN
Rf:>H[1VdV[c009[50A_5@04KcE_5FlfKaH3KaD00flDKa=_5003KaD3JaD5J_@5J_<3J_@2J_<00f[d
J_=Zm009J_<6J_84J_<5J_@;J_<2J]<2J_<02fKCI]9VdVKAI[1R/6:aHXmVSeI@;@P00P0000H880a1
364@HPa1340344023403344010a0344<@PaQ0Q1Q00X@PA22464<@11Q584DH@a0344@HP@@H@8DH@07
568@HQ1R468@HA1R46400a1R0QB200@@HQ1Q464@H@8@HP8<@@P@H@05564@HPa1344<H@0246833646
46400aAR488@HP044640211R464@HA1Q468DHAR2564246401122468@HQB20QAR00<@HQAR58<0111R
0Q1Q00@DPQBS588@HPT@H@04588@HA1Q46434443344010a2464<HPaR0Pa200<@@11Q46402A1Q0PaQ
00L<HQ1R464@@@aQ460@@002464258<0211R444@HA1Q460880a0344234001Q10444@H@aP460@@08<
H@8@H@8@HP8@H@05460<H0aP364@H@02460010aQ440@@110111P0Pa00``P00H@@11Q460<@1103643
360010a0460@PPaP0Pa100@<H@a1340<@@L<H@05344<HA1Q444<H@0244001@a0360@H@a022001Pa0
0`a100L<H@a0340<@0Q0340<@@0324401`PQ220480@P124880Q100<<@08<@@48@@48@0488@000PPQ
00<<8@Q1244010Q100<<8@`P32000P`P0``Q00<88@`Q324010`Q00<<8PQ224400PPR00<8@Pa13240
2@`Q0Pa10P`Q0Pa10Pa210a100T<80P0100801R1APUFSeZ/EVd00UI?0eI>0eI?00=FCUI?ETh01UI>
0UI?00=JCeY=FTl00UI?00=JCeI?ETl00eY@0UY`0UY>1UY_0eY^0UY_1EY`0UY_00=NKej@GY001Ej@
0ei`15j@15jA00=NT5j?GY002UjA00ENT6:@HXmR/5j@009NT@9N/@=NTP=N/@EN/PYR/P9R/@03I[5R
/V:b009R/PIR/a9Vd`9Ve005I_AVlfKcJ_=Zd`04J_<00fKcJ_=Zl`08J_<9J_@00f[cJ_AZm002J_@5
J_D01fkdK]AZ3VEVJRio<gom009oo`0<GI4/0d00>04X0301FLifT4E/200d`GoX0Woo019koa1Y000<
@@PP484La2D5;FPY9Qc6444401@P;>M5ke[ELm`2Ool043E>004000a18@LeRBe7<FPaJBeY<FTaJS6:
<FP]AbdW0RTW01@Y:2TY;DX]JBeZ<DTa:2dX:DPQ1Pa2901`hGj[O`YoJWfWFDTiBCBP0P0000lTP4X8
EZiJSEj[HXYB:cT3720P@2BP?HM:;Ej;GV`00eY<00YJBeY:FT]JBeY=FTaJCEI<ETeF;09F:`0FEPY>
2e9<APa1k3F9;DPTa2S3<BHeJ46XANU9jDX:CP]F:eY[GXeR[V;AI_<2Ja@4KaD00flFKaE_5@02KaD0
1FlDKaE_5FlEJ_D00f/E0V[e0V[d00=ZlfkcJ_<00V[c00=Zm6[cJ_@00V[d0f[c0f[d0f[c0f[d1V[c
0f[b0V[c00=Zdf[cJ_@00f[d1V[c00IZm6[cJ_=Zlf[dJ_<3I_<036[CI]=VdVKBI]5R/6:aF[5N/6:@
AL`DQ0840003220<@@a100<<@@03440@@A1000H<@@09348@HPa2344@HA21488@PA1Q008@H004464@
HQ1R46834648468246402A1R588DXaRR588@HQ1Q364<HP0246800`a1340@H@0746400aAQ468@HP04
46801@aR364<@11P46400QB200<@HQ1Q56400Q1R0Q1Q00H<H@a0240<@@a03442464356401Q1Q468@
HA1Q584@PPL@HP03488@HQ1R00<@HP04368@H@aQ4642468248824684464344401A1Q468<HPaR3640
0PaR00@<@Q1R440@H0@@H@07468@HA1Q464@@@a144001A1Q00D@@A1P464@HA1R008@H@09444<@11Q
468@HA1P340@HA1R008<H@8@@003360@H0aP008<H@8@H@04468@Pa1R46844642364246401a10320<
@11P464@PQ1Q00@@@@D@H@09460<@0a0340<H0aQ360<H@a0008<H@04344<@1104642368536401@a0
364@HQ1Q460010a000<<@@a034001@a00`a10`aQ0Pa000<8@0Q1244010Q100H480Q12488@@Q02445
34012441240122400004224<8@`Q32462247320:32400`PQ324<8@083244344332400``P340<@@02
34400``P344<@@0234402@P00008034RCTaVjej^ETmF;P03ETh2DTh00eI>ETeFCP06ETh3FTh2FTd0
15I>ETmFCeY?0UI?00EJD5Y?FU1JL5Y@009JCPEJK`AJKP9JK`EJL09JK`03GVeJKUY^009NK`03FVmN
L5Y`009NL09NS`04GXiNSej@GY02GY42GY02GXl6GY03GY43GY03HXl4GY04GY43G[4015jAG[5N/Eja
0V:a00=R/UjbH[801F:b00AR/FJaI[1R/@ER/PER/`9VdPmVd`9Ve004I]=ZlfKCJ_<2J_8016[cI_=V
lfKc1f[c00=ZlV[cJ_@026[d0f[c0V[d00=Zlf[dJ_D00f[e00M^mFkDKVmU96G=M[9o]003Ool02V6A
=0<`0D@0>00d0414>4HH07ld0goo00=NE1Q810000P`P00PPi4H;DVe234G/>H/XY@`0100000@eJF<i
I_P`jP800005220HiRe8;DPaJ002;DP01ReY<FT]JBe79@HPi08Pi@039>HY22e9008]B@09;BT]:2TX
:DTQ1QBT>:Amigoh009oo`0FONEUJC4Y964<02B0BNQJJUZ/EVaFBV:9HVY5abRP640TP2S1@LQJJej<
ET`2FR/4FTX2FT/2FR/2ET`2ER/06UH:FVYJKDi=>JXTaBC4568800@0468La2T3=D<iICf7@NY:;5I/
GXeN[fKaI_=Zlf[dJa@3JaD00flEJaEZm006J_@4J_D2J_@00f[eJ_=Zl`02J_<00f[bI_=Vl`05I_<5
J_<00f[CI]=Vd`05J_<00fKcJ_=ZlP03J_8016KcJ_=Zlf[b0f[c00=Zm6[cJ_<00V[c00=Vlf[cJ_<0
0f[c00aVlf[cJ_=ZlfKcJ_9VdVKbI]9VdFJ`H[02GXh01ej@?H/@@@@0220<@0PP00H<@@03340<@@a1
00H<@@07324<@A1Q588HXaRR58801AB100<@HQ1Q46000a1Q1Q1R00P@HAAQ460@HQBR6:4DPA1Q0Q1R
00D<HA1R468@HQ11008@H@05588@HA1Q464@HP02464546801A1Q340880aP46000a1Q00<@HQ1Q5840
0Q1Q00D<@11P460@H@aQ008<@@03444@HA1Q00H@H@03460DPA1Q008@HP043648@@Q1368346823440
0`aR364<@00346400`aQ464@H@0248800a1R464@H@0246434440111Q364<H@PP0PaQ0PaR00@@HA10
560<H0H@H@<@@@06460@HA1Q464@@11P1A1Q00D@H110320<811000H@H@8<@@04440<@0PP46064640
1`aR244<@11Q588@HA1P00@@H@06460<@0a0460@HA1R211Q00@DPA1P460<80888003340<H@aP008<
@003344<H@a100<<@0@<@@03340<H0aQ008<@003464<H0aP008<@003220<80a000L<@0<<@@06368@
HPa0240<@0Q00`Q100@<@@Q12448@@888@<8@@03344<@0a000@<@0488@0000<88@`P32401P`Q00<<
@@`Q32001@`P1P`Q0Pa12P`Q00@88@`Q324<8@8<@@06324<80`Q320<8@`P0``Q00<<80`Q34400Pa2
00/<@@@0000HPSfWHZaN[E8/EReFCUI?00IFCP03ETeFCUI>00=FCP=JCP03ETiJCEI?009FD0=FC`03
FU1JCeY@009JD004FTmJD5Y@FVl3FVh015Y_FViJKUY^0UY_1EY`0UY_00=NKUY_FVh00UY^00=JKei_
GVl015i_00=NSUj?GY001Ej@0ej?1Ej@0ejA0ej@0f:?0Uj@0V:@0f:A00=NTEjaG[4015ja0UjB15jb
1V:b0f:a1F:b1F:c0VKB46KC00EVe6KcJ_9Zdf[c00IVl`MZl`03J_9Zlf[c00EZm09Zl`03J_AZlf[c
00EZl`03J_AZmF[e009Zm@07K_EbT6g9IHaV3gKdOm/00goo01]^E50PD01<0500>00X02P1M_EonWoC
LY</I1@230480110<DA22dH]AS163cf/<BLa1b2T20400`0000<Y23e[66@00P0000H801cV:DHaIbeX
<HX2<HT02beY;FPYAbDV9@DPiB358<HU1bTX:BL00RTX0RTZ014U:B4736@dI7D2OR]nZ7h6M:0lQBSW
<@@mQdX<FXiNZeZ;009B:`0>ERYRReY[?JPT`APP760aA4h/G/iFBeXYFTYJB`=JBP0:FT]JBUX[FR]J
C5Y;FTYJBEH:ANX2BP`01c58428<00`P10088@PP0084000;220DHBCT<FQ635:@G/eNcV;>I_9Zl`02
I_<00f/fJaE[5@03JaD016[eJ_AZm6[d0f[e0V[d00=Vm6KeI_@00VKd36Kc00AVm6[dJ_AVdPAVd`03
J]=VdVKc00AVl`04I_9VlfKcI_<3J_800f[cJ]=Zd`0=J_<4I_<046KdJ_AVdfKBI[9R/F:_HZiJLCe[
420800PP340<HA1R1@a100<<@11Q58<00Q1110a10P`P00L@HAB15:8DPQBS6:<DPP02584011RR588D
HA1Q0Q1R00<@HA225880111R00H@PQB1464<H12158425646468246424843464546800`aR468@HP0:
464011B1464@@A1Q0QAP00LDPA1R464@@AAQ464DH@0346401AB2488@HA1P56400a1R00<@HA1R4680
0a1R00`<HQ1R364<HQ1Q468@H@aQ464<H@a14645468746400a11364<HP0336801a1Q440@H@aR364@
H@aQ008@H@04364<@@a0440346403AAQ464@HA11464@@A10460DH11Q460<@11000<@H@8<H@05340<
H@aQ364<@00246000a1Q444@@@024640211R368<HPaR364@HQ1Q44023404464236424605364010a1
444@HAB10Q1P00<<80a034400`a000H8@0Q1344<H@a1340634400`a0364<H@0336401@aP340<@0a0
22002Pa000@<@@aQ364<@@D<@003244<@@aQ008<H@033448@@Q100@8@@06344<@0a0340<80PP0@Q1
0003320332400a10320@800832001P`Q320<80`0320<8@8<@@03224<8@`Q00L<808<8@04220<8@`Q
344232401@a1340<@@PQ22000P`Q00l<810Q324<8110444<80P0300TXTh8EViNS5H[ETh015I=00AF
CUI=ETeFC@=FCPEJCP9FCP05ETmJCeY?FTmFC`04FTl3FTh2FU000eY_FVeJK@02FVd6FVh3FVl01EY`
FVmJKeY^FVl025i^15j>2Uj?1Uj@00ANTEj@GY5NT0=RS`9NT0=RT003H[5RTF:A00=N/@04G[1NTEja
G[82GY86G[82H[85H[48H[83I]82I]<00fKBI]=Vd`0=I]<00fKBJ]9ZlP05I_<8J_<01F[bJ_=Zlf[d
J_D00V[d36[c0V[d0V[e00M_5G;AKU1QSVF]JU9fmP04Ool037lcIG141SP3<0<d04@0G@MbBfE5>8<L
0088000B100HPCf3<FHY1bC68:H]1dG:DTm>2bCV448800P148@DP``00P00014<@2f7BT/ijSW;?Na1
k48=APi23DH>@Ne1k3W<<FTY:2D7008U1P0D:BLU1bD99@/U:RCW204X05P0O2El@W`0E00`03f<BP]B
CEY[GXaJJ`AF:`0;FTYRZTi=?HHPH1@P760iQeZ>HZYJ:005FTX015Y;FTYJ:eX[0UY:00YJBEY7DPXe
ARSR=DHXiP@0420D@@840003220400@00080000E220DPRCT<FE5j5I^J^eRcfKcJaA_EG=GLeI_5F[d
I]AVmF[eJ_AVmF[d00UVm09Vd`03I_=[56Kc00]Vd`UVdPUVl`04J_9ZdV[BJ_82J_<8I_<00f[cI_=Z
lP02I]801FKcI]9VdfKCH]<00V:b00ER/F:@I]1FLSDY008800<<@004460<@0a0344234001110464D
HA1Q0a1000D@@@a0340@@11Q008DP@8DHP8DPP08584DHAB1588DPAAR468@H@<DP@05488@HPa1468@
PP0348402QAQ464@HAB1688@PQ1Q564HPQB20Q2100@@H11Q464@H08@HP05364<HPaR368<H@0>4640
111R464DH11P2a1Q00@<HA1Q464@H@H@HP<<HP04348<@11Q3645464946844643468336802@aQ368@
@A10320<@@PP320<H@03464010a1320@@11P1a1Q0Pa000h@H1RQ6:8DHA10444@@11P464@HQ22468<
HQ1R0a1Q0Q1P0Q1100<@HA1R468010aR00H<H@a0340<80a04604464010aP460<@0aQ0Q1Q00<<H0aQ
34400Q1R00H@HA10460<@0aP340234400`a0220<@@0336400`a12208800234400`Q1344<@@053646
340010aP340<@0PP0P@P00@8@0aP340<@0<<@@<<@003240<@0a000<<H@@<@003244<@@a1008<@@05
340<80`P3208800124400003344@8A0Q00<@8@T@8003440@810P008@8003300@8111008@@@03344<
8@a100<<@@03324<80`P00<<80@<8@L<@@8<8@8@8@03444<@A11008@@@880006540eA59^HZ]NS5H]
15I=00=FCUI=ETd00eI=00=FCUH^FTh00eY>0eI?00AF;eY@FTmFC`AJC`=JCP9JD005FTmJCEY>FViJ
K`03FVh01UY_FViJKUY_FW1JK`=JL09JK`0:FViJKeY^FViNKUY^GViNSUi^GXh9GXl2GY000ejAGY1N
T004GY001UjAGY1NT5jAGY1RT0=NT09RT004GY1RT6:AHY43G[400ej`G[5N/@04G[47G[800f:bH[5R
/@06H[44H[800fKBI[9V/P02I]<2I]8@I]<00f[bI_=VdP04I_<4J_<00f[dJ_=Zl`03J_<00fKdJ_AZ
m002J_@9J_<7J_@01g;dK[AUcfV;JQ1ZLgKf00Eoo`0;Ogm^=F2[H6EXiG42H41H83@0:00D00022000
3AbT?HHmbRd68:@LYAR4<DU:Cd7[9@LHY1R4008HY00Y6:<DPa1S444DXc69BW1>/dYACU1BLEJbG]9N
m5kcG]=JdU[CEY96;d7]?L`iZc5Z;BTU2BDZ9D/Ti`@0801D07P0O49l0600B215kUZ=H/aJJP02ETX0
4UI;ER]FC5H[ERYFJeZ^DT/e121R320P`dH<FV]NRUi/FTUJBP9JB`0@ETaFBeI<FT]J:UHZFTYJBE89
ALPiIbcS544801A1668220000`PP34088002200040PP344DPQB37:<T`c56@NeBLUkCIa=cEW=ELeIc
=flF0V[e00EVmF;DI_AVe6KC009Ve0=Re007H]=Re6KdH]ARlfKdI_<00fKd00AVdfKDJ_EVm09Ve09V
d`06I]9RdfKCI]=VdVKC1FKB00=VlfKbI_<01FKc00=Zlf[bJ_803FKc00=VdVKbI_800VKB0V;B00eR
/V:aGW5RT6:aCU8/j@00200<@110340@@00234000`a1444@@00744000a11460@H@02464011RR564<
@0a10QAR00@DPQAR588DPP8@PP03568DHAB1008DP@06488@HQ1R468@HA210a1Q0Q220Q1Q00<@HQ1Q
46400Q1Q0Q22111Q0Q210a2200<<HQ1Q46400Q1Q0Q1R1a1Q00@DHA22488@P@8DP@04484DXaR25646
46400`a0364@H@04468246401aB258<@Pa1S468<8@a0008@H@03468@HA1Q008@H@04364@HA1Q5687
46801Q1Q364<@A1R5:<@HP8<HP0:468<HPa1320@@A1Q460<811Q46844642364346400a1R464@HP02
4682464011AQ588@H@aQ0`a000H@@A1Q58<<HPa146<34682464344401A1Q468@HPaR46800a1Q0PaQ
0Q1Q00<DPQ1Q46400a1Q0Q1R00P@HA10340@@0aQ464@HQ1Q0Q1P10aQ10a00PaQ00<<HPaQ36400Pa1
0PPP0Pa10PaQ00<@H@aR34400Pa000H<H0aQ364<H0aQ360334023640111P340<@0a00Pa10PaQ10a0
00@<H@aR368<H@@<@@04340<@@a1244234000a1P320<@00124400003444@8A0Q008@8@03420@@10P
00h@80<@8@<@@@8@@0L@808@8@07324@8@`Q424<8A0Q32401A0P00<D@AA044400Q1100XD@0`P200<
01b2ALQRREj;ETeF;0=FC003DTaFC5I<00=FC003ETeF;UH^00=JCP=FC`03ERiFCUY>009JCP03FTmJ
CEI>00EJCP04FViJCEY=FTh6FVh00eY_GViJK`04FVl015Y^FVmJKUY_0ei^00ENKei^GViNKUj>00=N
KP9NS`06GVmNSej?GXmNT5j?0Uj@00=NL5j@GY000Uj@0UjA0ej@00ART5j@GY1NT0ARS`07HY1R/Eja
G[5N/6:_GXl00Uj@00ER/EjaG[5NTEja009R/@=N/P9R/@IR/0=R/@=R/P9V/P9VdP03I]5VdVKC009V
d`=VdPQVd`04I]9VdfKBI]84I_<3J_<00fKcJ_=Zl`05J_<4J_@>J_<036[dJ_=Zlg<DLaIZDFE[IJi^
<FZDL_Io^PQoo`0VOeanTG8EI@i0IBPP300D@ART<@I1c3E98<H@I0P16:D]B34W6:<HXQR26:8HXac3
7<@LY1RS7:<LaBe8<FXeRSg<BRiBTF;AHaAW=@=W=P0DIcEW5F;cG]5JSdX`@Nhi[CF=;F/Y2@P2601H
07@0O6=l06`0D411c09JJP04ETUFBUI:ET/2ET`03EH[ERaFCEZ=FV]1ZBC5644D@BdTAPQFK5i/009J
B@05FT]JC5I<FTaFB`02ETX02EH[ERYF:UHXGXQFKSV:888<0002420210000`PQ344<@@02344010a0
220400@00`0000L8@Q238@Hmk5Z`Jc5[4`02LcH037<eKaE[5F/EI_EVm6KCH]=N/UjBG[9N/`9N/P9N
T@03GY1N/Ej`009N/09N/@06H[9RdV:bH[9RTV:b0VKB00=RdVKBI]<026KB00=VlFKAI]8016Kc0f[b
00EVlf[cI_=VlfKC009Vl`03I]9VlfKc00=Vl`AVlP05I]9RdV;AH[5RT002GY401Ej@AO0LQP002000
1A100Pa10a100`a0111000<@H11Q46400QB200XDPaB2468DHQ1R568DPQB1488@P@8@H@06564DPA1P
564@PAB20Q220Q1Q0Pa0111Q00P<@11Q464@H@a0364@HQ1Q0Q1R00L@HAB2484@H120588@PP034684
46400a22584@H@0246401Pa0464DPA21584@H08DP@03688DPQAQ00D@H@03364<@11Q00@@H@04468@
HA1Q4647468246400a1R464@H@0446400a11464@HP03468246400a1R464<H@03468258<246802123
468@@11P464@H0a0464246801aB2464@H11P360@H111008<@08@H@8@HP03464<HA1Q00<@H@03460<
@0a0008@@00<364<HPaR348@HQ1S468HPa10340@@1110`aQ00<<@0aP46000Q1P0Q1Q00<<HA1Q5880
0Q1Q00X@H0aQ364<HA1P364<@0`P340<H@<@H@03444@H0a100<<H@8<@0@<H@0:368@PQ1R344<@0PP
100880a1464246001@a0220<@0aQ48801@aP0Pa000@<H121484@P0D<@003344<@0a000@<@0H<@@8<
@004364<@@Q024033401220124400003444D81A000D@@@8D@P8@@@03544D810P00<@808@8@<@8003
424@810Q008@8@03420@@110008@@@<D@@8@@0D@@@05448@@A11540H8002520254400aA0544D@@03
5440210P200<02c1DRYNSEj<ER/2ER`00eI=DTeFC@03ETd00eH]ETiFCP04ETh5ETl3FTh01EY?ETiF
CUI>FTl00eY>00EJCeY>FTiJCUY_009JKPeJK`03FW1JKeY_009JKP=NKP04GXiNKUi_GVl9GY03GW09
GY4015j?GY1NSej@0f:?00=RT5j@GY400UjA00ENT5j?GY1NT5jA00QN/@9N/P=N/@ER/@ER/P9V/P03
I]9VdfKB00EVd`9VdP]Vd`9Vl`04I]AVdfKDJ]<2I]<00fKcJ_=Zl`03I_<2J_<4J_@2J_<016[dJ_=Z
lf[b1f[c16[d00][56[eK[AbLVF^KLi^<VZDL]=fm7ni00Moo`9oW`0BOcYU1c@P200@8P`Q568TaAc5
58@80@@0324DPaB2564@HAAQ0aB200<HPQRS68<00aR30QB300/LY2T6;BLeJDX_F]=O5UkeIcI[EVLe
009W500AH_=N/UJADY9:DD8@<DX@I2@0G01h8GaSO49/04Q0@LaF:P03ETX055I;ETaFC5I<ER]F;58/
EVaJK4i?<BLLHAQ1660madi^EVaJBeY:ET/2ET`2ET/2ETX02UHZDRYB:U8YDTYJ[Ti>>FLLH0`01000
00<48@@000002`0000`<PbUY<HTiZd7=CS1BL5YaFY5Rdf/EJcH2JaD2J_D01VKdH[=NTEZAGY5JL0=J
K`9JL09FC`AJL0ANT@03G[9R/V:c009R/P9Rd`9RdP03H]=VdfKb00MVdP9Vd`04I]9VdfKCI]<2I_<0
0fKBI_=Vl`03I_<02FKBI_=VlfKcI_9VdV;BH]5R/002GY003UZAFW4m[Q13000<80a0440@@A104448
80@P4642440334001A1P464@HA1Q46000Q1Q00DDPQc36<DDXaAR008@HP06568DPQB248<@PQ1R0Q1Q
00<DPA1Q46400Q1Q00HDPQBS488@H@a0368446400a1R488@PP02488010aQ464DHQ1R0a1Q00<DPQB1
46401A1R0a1Q00`@HQ225:<DPa1R444<@A1Q564DPQB1564246400aB1464@H@03464248801@aQ464@
HQ1R36400Q1Q0`aR00<<HA1R4640211R0Q1Q00<@HQB24680111R00<DPQ2246400Q1Q00<@HQBS48<0
0a1R0a23018@H`aR368<HQ1Q468@H@aQ464<HA1R488@HA10444<HA1Q444346424680111Q468<HPaQ
111Q00D@HQ22444@H@aQ008@HP8<HP8@HP06568@HA1Q364<@@aR0PaQ00<@HA1P46400Q1Q0PaQ00D<
@@aQ364@HA10008<@006364<@0a0364@H@aQ0PaP111Q00H<H0a0344<HA223683364536801`a1320<
80`Q344<HA1Q008@H003320880a1008<@@8<@003364<@0a000<<@005464@PPaQ488<H@0834063442
36400`a02408@0052442240124400006444D81Q0520D@111110Q1Q0P00@D810P420@80<D8003420@
@11000@@8@03520@@AA000<D80@D@0<D@@03424D@AA1008D@003520D@1A0008H@08D@@0<540H@1A0
640@00`06415Q5I]IZ]F:eH/0UH]00=B;EH]ETh02EI>00EFCeI>ETiJCUI>00=JCPEJC`=JCP07FTmJ
CUY>FTiJCeY^FTl00UY`0UY@0UY_00=JKUY_FVh01eY_0UY^1Ei^00ENKei`GW1NL5Y`00ANL0UNT0EN
T@MNS`ENT09NS`03GY1RSf:?00=NT0=NT@=N/@04G[9R/F:aG[4:H[82I[800fKBI]=Vd`05I]<3I]89
I]<036KDJ_AZm6KDI]EVe6[cJ]=Zlf[dJ_=Vl`]Zl`04J_AZlf[CJ_82J_<2J_87J_<2K_<037;dM[=b
LfE/HFiZ479`L[9flgLENgMof`Aoo`0AO_inTGi/J<8d00`0100<8Q11448HPaAS324000@0344@@002
3400111Q564DHQB20aB300HDHQ12448@HPa1348234407A1S6:@LY2D7=HY1kDY>CW1Nd6KbIa=RlekC
E[9BTdib?LdPab@0H01l@gbUO49/04`PALaJBUYZETT00UI;1UI<00mFBeZ<FXi1bRST668LPC55CTiR
cEj<FTYFBeI<ET/00UI:00=JB5HYERT00UH:00YB2E8YCT]BBdh[@JL`hR22568401<0000@324DHR2S
9>@]9S5Y>JXmc4H=CRiFCeY_GY5N/V:aG[82G[43GY400eZBGY9JL002EU03FVl2FTl3FW001UI?FW5N
TEjAG[9N/`=N/P03H[9R/F;A009Rd@04H]9VdFKaI]42I]<3I]800fKCI]9VdP03I]8016[BJ_9VlfKc
16KB00]RdFK@HZmR[ej?GVeR/UYA<BX80P@000<<@0<@@0<<@08@@008340<@@a0460@HA1P440<@08@
H@03584@HA1R00T@HP03464DHA1R00T@H@8@HP<@H@8@HP8@PP03588DPa1R008@HP03464DHA1Q00@@
H@05468<HA1Q468@H@0246803A1Q468@HQB25:<DPQ1R568DPQB1588DPAAQ00L@H@03468@PQ2200@@
HP<<H@04240880Q13447464346801111464@HQ1R0Q1Q111R0Q1Q00<@@11Q46800Q2200H<H@PP344@
HPaQ368434800`aR468@H@02364446401`a0464@HQ1Q444@HQ22008@H@03344@@@a1008<HP8@H@03
340@H0aQ00D@H@05368<H@a1444@H@0256400a1Q364<@@0236400`aP460@H0024642460234003Pa1
364<H@a1440<@@aQ444<H@a0364@@A1P3602460246401@aQ344<H@aQ34000PaP00<<H@aP36400`aQ
00<<@@`P32000Pa100L<HA1Q464<@11P340<@@02220224000`PP2408@00=340010PP340<@0a00`a1
0Pa00PQ10`Q000P880PQ2448@@a13408@0a00@Q100000a11520H@00252000a0Q420@8@02424:4202
520011@Q520D81@P0Q0P00<D81@Q52000a@P00<D@1A152000aA01AA100<H@AQQ66402QQ000HL@1Q0
400H82b0BNX2GV`00eH/EReF;@0<ETh015I?ERiF;UY>15I>1eY?00=FCUY?FTl00UI?00=JD5Y?FU00
0UY@00MJCeY_FViJKeY^FVmJKP05FVl015Y^FVmJKeY_0ei^00AJKUi^GVmNK`9NL003FW1NL5i`009N
L003GVmNT5j@00ANT003GY5NT5jA00ANT@=NS`UNT003GXmNT5j?00ARS`04HY1NTEjAGY45G[82G[43
G[800f:cH[9R/P02H[82H[<00f:bI]9VdP07I]<3I]8;I]<01f[CJ]AZe6[DJ]=Ve6[d00=Vl`04J_=Z
m6[cJ_<2J_@5J_<00f[dJ_EZm006J_<00f[bJ_=Zl`03J_<046kbK_=^m7;dM[9fDFV]KLeYkVY?K[5b
m6kDHY9Ze7om0Woo00QbU6eYJ<QP@3P1500P@Ab40QR300LLYAc658D<8QA2568D@@0356401QAR464@
HQ1R568@H`8DH`<DHP06468@@@a1344<@Pa10PPP01P@@AbS9>D]AcF:@Pi:DDibD[=BTTYa>L`Lb200
H01l@gb4O49X050PAL]NJUI9ETX2ET/00eI=ETaFC002ET`03EY;FRUJJeZ]ETdmRB2U78<P`cg:FXeR
cUI<009FB`03ER]F:U8Z009F:@03EPUB2E89009B2@0JCRUB:U9<DTeBKe9>CRi5k3f[=DTTa1R38:<e
J3g/?L/iZC5W9>DHX`a0344<HQbS66<@@PP0000L344HPARR7<<XiC4X>H/mc47]APi6;di@DW5FTEJB
FW5FD5I`FY5N/5j?GViRT6:AGY5NL5iaFW02GY42EU0025ZAGY5JTEZAGY5RdVKdI]<3H]801VKcH_=R
dfKDI]=VdP9Vd`9VdP03I]5VdV[B009ZdPAVdP0=I]=VdV;AI]1R[f:`GXmN/5jbCS4/i`@020000Q10
0Pa10PaQ00D@@11P460@@0a0008<@@8<@004360@HA1P3405464846824640111R488DPQ1R0Q1Q10a0
00@@H11R468@HP8DH@8DHP0658<DPQB258<DHQ1Q0Q1R00<DHA1Q46400Pa000<@HA1R46800Q1R00D@
HA1R468@HQ1Q008@HP0348<DPaB3008DPP03584DPQB200D@H@03460@HA1Q008@HP8@PPD@HP04464<
@@aR3682468246401a1R464@HA1Q468@Pa1S00<@H@03468@H@a1008@HPD@H@06344@HA1R468<H@a1
0Q1R00D@H@aR3488@@a2008<HP<@H@03364@HA1Q00@@H@<@HP03368@PQ1R008@H003444<@@Q0008<
H@8@H@8<H@<@H@8<H@06368@HA11340<81AP0QAQ00D@H@aQ344<@@aQ00H@H@07360<@0aQ364@HPaR
46800Q2200<@H@a144400a1000@<HA1Q464@H@8DPP03468<H@a1008<@@<<H004364<HPaQ36023640
1Pa2344@HA1R588@H@L<@@04340<80a1344334000a1R464<@002340244000a1Q344<@@02340010a1
340<@@a00Pa100<<@0Q124400`Q000<8@@a134400Pa100<<H@aP34000@aQ00000a10520D80025202
420242400a0P520@800942025200110P520D810P1a@P00<D@1@P52000Q@P0aA00QA121A01aQ000TL
@1@P500D83T3DRYJSUI=DR`00eH]2eI>0UH^00=JCUI>ETh00eI>1EY?0eI>00EJCeI?ETmJD5Y?009F
C`05FTmJCEY>FVeJKP02FVd015Y^FVmJKeY_0UY`0eY^00IJKei^GViNKUY^GVh3GVl2GY001Ui`GVmN
Kei_GXiNS`ANT0=NK`03GW1NT5jA009NT0=NS`ENT0ENS`03GY1NSej?00=RS`9NT09NT@QN/@03G[9R
/V:b009R/P04H[5R/V:bH[<2H[82I]85I]<6I]89I]<016[CI]=VdfKC0V[C00AVe6KcI_=Vl`9Zd`04
J_=Zm6[cJ_@2J_<00f[CJ_=Zl`03J_<2J]<00f[bJ_=ZlP02J_85J_<08F[bJ_=^lfkDM_Ajdg9bJLeQ
SFW]JTiZTFjAKY1ZTG[aOoaoogkfGFiHC60QD6=0Y4DU@HXe1Q0P544XYQ0T428DHP02668011QQ6:8H
PQAR0a1R00@@@@a1344<@@8@HP@DHP8DP`0L588@@@`P220400PQ348@HaB37:@]AcFZ@P`ijcV968@L
04`0M05lHga2J01@84G:FTQF:5I9ETX2ET/01UH[ETaFC5Y;FTUJ:@9JJ`0<FVY1jbdX68<<@RdUBRYN
[EY^ER]FBUI;0U8Z0U8900=B2589DPP00U890ThZ00IB:eI/EVeJKV:^H/h2IZl04F:`EW1FD5jbKc=g
LVldIaAFKd6Z<BPLYAB37<@XiP`S20400`@00PPP00<<@A1R5:<00QB300@LXb349>DPi@8Y9P0;9>DP
a2C5:@L]B35Z=FXiRdG]BRmFL002H[000ej?GY1NT003GY03FW0025Y@ETmJL5jaFY5FL5ZAG[42GY02
G[400f;BH]=Rd`02H]<4I]84I]400fKBJ]9VdP05I]8016;AI]1R/6:`0Uj?00YN/Th?::@400PP440<
@11Q488<@@8<@003464@H0a000L<@004460@HA1Q484346444683588546800aB2488@HP0246400aAQ
464@H@05464258801QAR464@HQ1R588DP@8@H@03460DHAAQ00@@H@03364<HQ1R00<@HP<@H@0858<@
HQ1R36<@HAc27<<HXP<@H@0;440<80PP340@H1BR584@HA1R58<DPP03468021B26:<@PQ1R5:<Ha1B2
360546401Q1P464@HA1R444@HP8DPP8@H@05468@HA1Q464<H@054642468010aR364@HA1Q10aQ0`a1
00<<@0aP46400Q1P00@<H11Q464@H@<<HP06468@PQ1Q360@H1100a1Q0PaQ00@<@@aQ464@H@8@H003
360@H@aQ008@H@0:460<811P588HXaB2468<@@aR468236444640111P360<H@aQ0Pa100<DPQS45880
0Pa100D@HPaQ340@@0aQ00<@H004584@HA1Q364234402@a0360@PA1P340<80a0460@H@0534423648
344224401@a1340<@0a036400Pa000<<80a0340010a000<<@@a024400PQ10`a000<<@@a024001@Q0
0`Q100<88@PP34000@a100001Q0Q520D810Q520@@@<@8@04444D@A@P520:420;520252401AQ1520D
@1A052400aA100<D@1A154001aA011Q000<LH1a064000Q0000DL@468FY1BCE8/00=F;@=BCPAFCP03
EReFCUI>00EFCP03ETeFCUI>00YFCP=FC`=JC`=JCP03FVeJKUY^009JKP03FVmJCeY`00IJK`9NKP03
FViJSei^00ANK`03FW1NL5i`009NL003GVmNL5i`00=NT0ANK`ANT003GXmNT5j@00=NT@9NT0=NS`QN
T09NT@=NTP03GY5N/Eja00AN/@03G[9R/V:b00ER/P04H[=R/V:bI]85I]<6I]84I]<00f[dI]=Vd`05
I]<3J]<2I]<00fKDI_=Vl`02I_<016[dI_AVm6[d16Kc0V[d0V[c0V[C1F[c1F[d01aZlf[dJ_AZm6kd
K_Efm7:AKPiYbVW[LW5^;fX?JS5bL7l_OomooW[BKLi``FSUOTinlV9^AHTT@08@0008204000`0424<
8111568DP`8DHP8@HP03444880P0008<8003344@@A1R00<@HP0856<DHQAR568@HQAR468<@@88800:
344DPRD5:DD]J2CU44<P04P0M002O4801GP0E419bV9WFTT00UI:15I;00mFBUY;FTYJBeY:FVYJRe9`
=H/HQ0PR8:=1bE9_ETd00UI;00EB:dh[CP]B2Th:00AB2@04DPY>:ThZCR/2DT`0158/DReFCEY^0Uj>
00aNSf:@I[5VdFKbIaAJ]4h`?H/XiQB348<220001``P7:@U:2U9;FTaJBTX00<U1`039>HPaB35008T
i@<Pi@077<<DPQ11444DPaRT7:D00QbT00PY9c58;DPaAcEX=HXm[3g=0Sf/0115kTX>ANi5kTh`DW9F
LUZBEW5FKeY_FViJSeZ@F[5N/@9N/P9Rd`9RdP=VdP04I]5ZlV[cJ_83I]801FKCI]9VdVKBH[400V:`
00eR[f:>GVeVddW=768400P0320<@0a1364<@@02320634001Pa1340<@0a0344<H@@@H@L@HP04488D
Pa1R46<346800`aR468<HP02468358800aB3468@H@0346400a1R464@H@0246401QAQ468@HA1Q564@
HP<@H@L@HP8@H@03488@HQ1R00<@HP8DPP8@H@8<H@05440<8110440DP@0346400a1R588DHP034680
2A1Q58<DXaBT58<@PQ1R464<H@023680111R464<H@aP0PaQ111Q0Q2200<@HQ1Q46800Q1R00<<HPaQ
46400Q1Q00/@HPaR368@HPaR364@@0aQ464@Ha1R008<HPH<H@8<@@03364<HQ1R008@PP09368<H@aR
364<@111588@@0a100<<H@08344<@0aQ464<HA1R368<H@<@H@03588Ha1B300<<HP06468<HPaR368@
HQ221@aQ00<<HPaQ364010a100<<@0aQ36401@aQ0Q1Q0`aQ10a100P@PQB2340<80a0360<HPaQ0`a1
0`a00Pa100l<80a1344<@@Q13448HPQ1224880Q1340<H@a0220010a01@a100D8@0Q12448@0PP0088
@@033448@0PQ00@88@88@@<88@488048@@0000L<8A@P520D81A1444D@@0342001A0Q420D810P5200
2A0P2A@P11@Q00PD81A0520D@A@Q540H@AQ00QA000HD@AA0540D@1@P5406640274002Q@P500D033U
CRiJKEI<FTiF;EH^0UI>00=BCUI>ETh02EI>00AFCEI<FTeJCPEFCP03FTeJCeY?00=FCP9JC`9JCP9J
K@EJC@03FVeJKUY_009JL09JK`AJKP9NKP03FViNKej>009NKP9JK`05FW1NL5i`GW1NK`06GW000ei_
GXmNSP06GXh3GY02GY42GY02GXl6GY05GY43GY8015jAG[5N/Ujb0eja00=N/V:bH[8026:b00=VdVKC
I]<00fKC00AVdVKCI]=Vd`AVdPIVd`05J]=VdfKBI]9ZdP02J]<00fKCJ]=Vd`02I]<00f[bI_=Zm002
I_@00fKcJ_=ZlP02J_<2J_@016[cJ]=ZlV[c1V[d00AZlf[dJ_AZm0EZl`0JK_=blVkBL[1bTFiaKW9^
DVGbGI5MSVjAOg5omWolOoMoCWk^OZef/GKAM_1g=7;b@F/@0@D000840004200<8111444246801A11
344<811132000PP000<880a034400Pa100@@HA1R564@HP8DH@0E440<@110588LXabT448@8SPQJ69l
PgbUO8A`05BPBLYRIeYYETUFBUI;00=FBP=JBP0DERYF:eXZFXaJ/47]9>L<@QaR>HQ>CeI]DR]F:U8[
CP]>2U8:CPY>2@EB2@05DRUB:Th;BPa63002AN`08dH<DReFCUY>ETmFL4i?CRhm[2SX228000P0460D
XRD5<BHaAbTW<DPaJ3UW=DH]1R347<@HY11R444@HAB36:<La2359>D00RdV00@aABT57<@@HP8<@@06
224480PP468DHQ1R0Q1S00l@Pa2458@DQ1RT9<D]1RdW;BPaBCEZ?J]:;U9`FXl00UI^00EJT5I_ETmJ
L5ja00IR/@04I]5VdVKAI]43I]82I]<02fKBI]5RdFK@HZmRSUi/HXeR/4F:20000`@010PQ10PP0PQ0
10PP0Pa00Pa100<<@11P4640111Q00@<@@`P320<@@<@H@07364<8@PP344<@Pa136800`a10Q1Q00T<
H@a0320<@0a1440<@@a034400Q110a1Q00D@@A1Q464<H@a0008<@@@<H@8<@@05320<@0aP464<H@02
34000`a1340<@002240434003A10340@@0aQ320800a0444@H0a0360<H@aP00P<H@8<@@05348<H@aQ
340<@@0232033402344010aQ340<@@`P0`a100@<@0a1340<808<@@@<H@06340<@@PP240<@0a10`a0
00<<@@a034401@a10`aQ00@<@@Q12208@@D<@088@006340880PP340<H@aP1@a100D<H@aR364<H@a1
00<<H@04344<@0a0364234000``P344<@002340324000`a02408800524000`Q1344<@@04344010PQ
120880PP0PQ110a000<8@0PP22002@PP00@88@PP2448@0888@0522088@PQ2208@00422000`Q02208
800:22062242220010PQ24448@@Q0PPP0@PQ000010`Q520D81@P0aA100@D8A@P420D8A0@80LD80<D
8@8D808D8@<D@@<D@003544H@AQ1008H@@<H@0<H@@8H@00:740H@1@P400D@SE6DVeJ[UY]FTd2ERd0
1E8]DTiFCU8]ERd015I>00=FCeI>ETh00UI>0eI=0UI>00AFCeI>ETiJC@MJC`9JCP9JK@AJC@04FVeJ
KUY^FVl2FW000eY_FViJKP03FVh00ei^FViJKP04FVh01EY_GVmNL5Y`GW0015Y`15i`00INKej@GXmN
Sej>GXl3GXh00ej@GW1NT@03GY0015jAGY1NT5j?15j@25jA00=RTEjAG[400eja00=N/UjaG[802F:b
16KB0fKC00=VdVKCI]<016KC0VKB1FKC0V[C00=VdVKCI]<01FKC00AVdVKCI]9Vl`=Vm005I_=ZlV[B
J]9Zl`02J_@3J_<00f[CJ_AVm004I_@00f[cJ_AZm005J_@2J]<00f[bJ_=^d`02K]<02FjcL[9fTGI`
KRiVCWJaOcAooP02Ool03GonObef/7Z[Ok=oogohNeLhbB@0@DTeBBBQ008PH003640<00P00088000<
3208811146<@@Q11440<@0`P200<@@a20PPP00<<80a034000a1Q01<@@A1Q464@@10P300@81A2A6=m
AGbTO:ElPg1PD<=9beY9ETUFBP03ET/3ETX00eI;ER]F:`02ERX02UI/E[1:;RdX448@@C4UBPeBCE8[
14h:0U8Z00=>:Th:CPT00e8:00M>2TX;BN]9jdG/BPe>;P02BRh2CRh01DX?@JdaBQR310000`0000X4
01AR7<DU9RU8:BPU:23U7:@DH@8@@008340@@110464DHAB268<HX`8HP`088<DY1BdV8>DLa1R3444<
80@880@400070004000P124480@000000P@000`880`Q46<PaBTW<DTmbdX_CU1FKe9?DTd2ETd01UY^
G[5RdekBG[5R/@9Rd@07I]9VdFKBI_=VdVKCI]800VJa00UVdFK@HZmRSV9/IZeJL3TX00000P@000<8
8@Q122400`PQ10Q00`PP0PQ00PQ10Pa100L<@11Q364<H111464<H@0334001@`P340<@0aP36800Pa2
00<88@PP34000`a100H<@0`P340<@11Q3405344236400`a1340<@@0236400`a0344<@@0234000`a1
364<H@033446340010PP340<@0a00Pa11Pa000P<@@a0340<80`0444<@@`P10a00PPP0Pa000@<@@aP
3448@0<<@@04220<@@a034423402320334001P`P220<80a0344880<<@@05340<@@a1344<@0023440
1`a02408@@a1220480PP00D<@0<<@@04244<@@a1344522000`Q12408@004240422000``P340<@002
244534401Pa0220880a0440<@0@<@@05320<@0`P220<@00332042446240222001PQ0344<@@Q12408
80888@052208@0Q124048003240322000`Q02208@00522000`PQ22088@052244220324000`PP2248
800<22032243220010PQ24448@PQ0`PP00001``Q524D8A@P540D810P00HD8004420D81@P520;4208
5204524;52000aA0640D@00252000aA0640H@00364002aa0400@02B2BLMJKV:/FTaF;Dh=ER`00UI=
00AB;EH]ETiF;@AFCP=F;@03ERaF;EH/009F;P03ETmFCUI>00=FC@03FTeJCUI>009FCP03FTeJCUY=
00MJC@03FVeJCUY_009JK`=JKP=JK@MJKP=NKP03GW1JL5Y`00AJL09NL003GVmNT5j>00=NKP=NSP03
GY1NL5i`009NL09NT003GVmNT5j?00ANT0=NT@=NT09NT@03HY5NTEjA00IN/@04H[5R/V:bH[83H[40
16:bI[9R/FJa0fKB00AVdfKBI]5VdPEVd`EVdP=Vd`9VdP03I]=VdVKC00=Vd`09I]9ZdVKBI]9VlfKD
I]=Ve6[c00=ZdP03J]=Zlf[c00=Zl`03I_=ZdfKd00=Vm003J_AZlf[d00=Zm004J]AZlf[dJ]<3J_<0
0f[bJ]9^lP02L_801G;aL/m^dG;BK]D00Uid01Ic>GokOoAoCW9^IH1o:7odOo5kMTeZ><AAZFJ]K`ig
LWoEM/m5BR@Q308@8P@80003300@@1AQ008@H@@<@@03340@@0a000888003340@HA1Q00<@H@0=564D
@@`05494PVC3J:9H@U15A6@laTW/ERT00UI:0eI;0eI:00mFBeH[ER]F:UXZEVaF[U9>=DPH@aA1:>@m
RDh]DR/00Th900I>2U8:DPUB:U8YCPX2BPX3BP/034G[BN]:34h=CRi>CTX^AN`mZSfY;BL@H`800004
200<80`P3202464010a0320880@P0P@000H880P0200@HAc4:>@2:@@01B3T8<@HPPa020001`@000<0
00@010002@0000<400@P10000PPP02/@@0`P22040000100000PP58<Y9CEX?L]:;DY>ETiFKEI<ETeF
CUY`GY1N/F;AH]9VdVKAI]9VlfKbI]=VdVJaH[5R/6:_GXmRSV9/HV]FCc3U0004000234001PQ02248
8@PQ2208@0888003240880PP00<880032248@@a100D<@08@@0@<@003220<@0a000<<@0<<@@033408
@0a000<<@@l<@004440<@0a032043403344010Q1220<@0a00P`P00P<@0a1340<@0aP364<@@Q01@a0
0Pa100P<@0`P320<80PQ324<80Q00`a00PPP0Pa000@<H0a03408@@88808<@@X<@003320<@0a000<<
80<<@005320<@0a03408@@0824000`a0244<@00234000`Q1344<HP04244222432209240634042442
34000`a1340<@00434023202340010`P340<@0a00``P00@<8@Q13448@@P8@00322088@PQ0088@088
8@8880032408@@Q000T880<8@0L880<88@0424088@PP224322000`Q02208800A22000`Q022088002
24400`Q02208800122000006328D8A@Q544D@1A111@P110P2a@P0a0P1Q@P1A@Q0a@P00<D8A@P5200
0a@P1QA00QPP00<H@AA154400aQ000XL@1@0400H83D2DTiJK5i/EViBCP9B;@04ERaB;EI>DTh2ETh2
ERh015H]ERiF;UI>0UI=00AJCEH^ERiFC`EFCP9JC@9FCP=JC`QJCP03FTeJCUY>00QJKPQJK`=NK`03
FW1JLEY`00=JL0=NL004GY1NSei_GVh2GVl00ej@GXmNT002GY000ej?GW1NL002GY0015i`GY1NT5j@
1EjA0Uj@00=RSf:@GY400UjA15jB00=NTejBG[800Ujb0V:b0f:a00AR/f:bH[9V/@9VdP9Vd`03I]9V
dFKB00EVd`03I]9V/VKB009VdP=Vd`9VdP=Vd`=VdP03J]=ZdVKC00=Vd`9Ve004I]=ZdV[BJ_85J_<0
0f[CI_AVl`05I_@2J_@01V[cJ]=Ze6[DJ_=Zm0]Zl`0DJ_A^m6ZdI[AB3d5ZAFQRCFY?IJ]]jW9^Oc5o
dGnjIY9A95gZOiQonP9oo`09OmY^;6W;GNm1JSCU;8<PPQQ1008@8007568@Ha1R344@@Q1R44400Q1Q
00@@@A10320@@@D@H@08468DHQAR444X@4@P>00T008X0004=>I9k5Y:ETX5ET/3ETX04EHZER]F:UHZ
ET]N[UI]>HTPQ1A29:<iIdX:CRa:2Th:CP/00dh:00A:2DX:CP]>;09>;@0ACPe>;TX=AN`mZSV[=FXY
1bCW8<DLaARU58<<8Q12544DHP0246800a1Q2008000222001@a0240<@0a146400QB200PLPR2R8<8T
hR3S8<4HHAA0111000X<80P0220<80PP100800PP1000008400D00004100880a14684344322431000
1A1R9>DaJ3g<ARd00Ti?00UB;UI=EViJKeZ@G[5R/V:aH]800V;C00MVdV;BH[9R/V:aH]5R/002GXh0
269/HV]=k2B4000400a1340222022244220324032202224010Q1340<@@a110a000<<@@aQ34000`a0
0`a100<<@0a134400`a100@<H@aR368<@PP<@@03340<@@a100@<@003440<@0a000D<@0@<@@8<H@07
344<@0a0364<HPaQ34400Pa000<<H@aP340010a00`a100H<@0Q022088@`Q3443240534001Q1P320<
@0a0344<H@8<@@<<@003240<@0a000<<@007244<@0a0340<80`Q32001@a000<8@0a024400PQ100<8
@0Q124000`Q00`Q100<8@0Q124402@Q100<88@Q024401`Q00PQ100<8@0a034000Pa000D<80Q1344<
@@a000H<@@8<@003320<@0Q100<<@0@<@@8<8003240<@@Q10088@@042408@@Q124442403224010@Q
22488@Q00`Q100<8@0PP22002@Q000L<@0Q0240880Q024488@0224401@PQ2448@@PQ244010Q000<8
80PQ220010PP00<480PP22000PPQ0PPP00<8@0PQ24000`Q00PPP0`PQ0PPP0@PQ00001@a1524D8A@P
54001a@P1Q0P21@P110P1Q@P00<D8A@P520011@P00<@81@P52001A@P0QA00QA100DD8AA1544D@AQ1
008H@007620D8100300L@CeUETX00UY]0e8]00AF;58]ETiFCPEF;@9F;P03ETiFC5I<009FC003FTiF
CUY>009JCP9FCP=JC@EJC`05ETiJCeY?FViJCP03FTd3FVd4FVh8FVl2FW02FVl2GVl2FW03GW0025Y`
GW1NL5i`FW1NL5j?GXh2GVl2GXl2GW03GXl3GY0015i`GY1NT5j@1UjA00ART6:?HXmNT09NT@9NTP=N
T`9N/`9N/P9R/P=R/@9R/`04H[5V/6JbI]82I]<3I]88I]<2I]82J]<00fKCI]9VdP03I]<2I]83J]82
I]800fKCJ]=Vd`02J]<7J]82J]<6J_@9J_<00f[bJ_=Zl`06J_<4J_@04FkdJ]9RTDV;?DU1BDf=C@Q@
aUc]LS1o4GneOoAo]7ngOo`00Woo015oNfX>KRYbKWJbK]9^Sei?DL]19bRT76<LHQQR544@80`P00@8
0004300<80a0440246400aB2464@HP0246802QAR668L@1`0400801`PAFM5be9=1UI;0UHZ0eY9021J
BUXZERYFBUZ<ET`mZRC5548LHSU6BNQFBe8[CPY:2dG[ANY5jE8XDT]JKEJ?DVm>;DG;=FP]1RSU8<DH
Y0PQ0`0000L4011Q464<@A1R568DPP0246800`aQ464@@00334003``P340@HA21464@@@`P440DH1R0
7:4T`RSS=DDmQ`02?JL02D6X@LU1Z3f8?HTiRCfY?HTiR002>FL023UX>DLa9S4V:@DHP`@P00021002
200010PP324880`Q0PP00P@00P0000l481238>D]9CF8@L]:;E9_FVmJT5Y_G[5R/V:aH[800V;B015V
dV;BH]5R/F;AH[5R[ej>GViRSVZ/@FTD@`002008@0a000X88003340<80@0008880032248@@a1008<
@@06340<H0a0344<HA101@a000<<@@a0340010a010a100<8@@a134401@a10Pa000D8@@a0340<@0a1
00/<@003344<H@aQ00<<@@03340<@@a1008<@@X<@004364<@0a02202324010a0244<@@PP1Pa000<@
@0`P32000Pa000D8@0a0340<@0Q000/<@0<<80L<@0053448@0PP2208@@0424001`Q13408@@Q03408
@@a100H8@@<88@<88088@08<@004240<@0PP240834000`Q0340<@@0334000`a1340<@00334001`Q0
340<@0a03448@0PQ008880<<@0<<@@09244<@@Q1244<@@Q0340880Q000D88@D8@0888088@0032208
@0Q000/8@003224880PQ0088@@032408@@Q000@8@0T880@88@0322088@PP00X880488@0000@<@Q@Q
524D8@HD@08D80<D@@03444@@10P00LD808D8@<D@@DD80<D8@03540D81A0008D@@04444D@AA15403
520354055446644031PP300@02B0CNMFKU9<DRaB;U8_DRiBCP9FCPEF;@9F;P04ETiFC5I<ET`2ETd0
15I>ERiF;UY>0UI>0UY=0UI>15Y?1EY>0eY=1EY^00=JKEY^FVh02UY_00EJL5Y_FVmJL5i`00=NK`03
FW1NL5Y`00=JL003FVmNKeY_00=NK`9NL0=NS`03GVmNL5i`009NL0=NT0ANT@03GY1RTF:?009NT0AN
T@9NTP9RTP03H[9N/Ujb009R/P=R/@03H[9R/f:c00=VdP9Vd`AVdPQVd`9VdP04J]=VdfKCI]85I]<0
0fKBJ]9Zd@02J]87J]<5J]82J]<00fKcJ_=Zm004J_@3J_<4J_@;J_<3J_@09f[CLcEZde7[?FY9[4g^
FJY8a4QQI<1b2glBOoQoogonOmioW6jfC<U@XEUTFLYRCfkdL]5ZL5G^CFU0iS2S:88THBBS:<@/iBCU
8:<D@00220001@`0200800P032000a1R00D@H`a2320<8@`P00840007300m@eH/GXeFSE9;ER/00UI;
0UI:00AF:UI:FTUF:@9J:@03ERUF:U8Z009BC008@L/PYAAS44<eATh9DRa9jP95jP0<APa:2eY^EXiB
KTX]@L`eJBT77<D@HP@00`000`@000@480PP344<H@D@P`8<HP03268000@00084000=220@H23S=JU2
34X^ETiFCEY/HXeRSUj=HZl00f[`00U_<g=DLa9Zl6lBLeEgEg=FKcD00flC0W<D00Q^lV[BK_A^lfJb
@JXL@0P00P0000<40@`S32400`@00`000P@00P0000d<@1B38<D]9SV:BRiBL5I_FVeNSej`G[9R/P03
H]803f;AH[5RdF:`GZmNSUY^HZiVSCe8328000PP240<@00>22000`PQ344<@@0334400`a0360<@006
340234400``Q344<@005340334400`Q1344<@@0434433403344010a0344<@0a12@a00Pa100<<@PaQ
34400Pa010a100@8@@Q02408@0D<@0<<H@<<@@03324<@@a1008<@@03340<@@a0008<@003320@@0`P
008<80D<@003244<80`P00<<808<@0<8@0<<80P<@0043448@0PP240924400`Q02448@@0524422242
2442344534001@Q0360<80Q0244010Q000@<@0a1344@HP8<H@@<@@033408@@Q00088@006244<@0a0
340<@@aR1`a100T<8@Q1244<@@aQ3448@0a036000PQ110PQ1PQ00PPP00D88@PP2248@0Q100H8@0@8
@@03240880PQ00888@032448@0Q10088@0032208@0PP00@88088@0042248@0PQ2204224:22011241
220122400004328D8A@Q52465207540C5202524011@P540D@1A011A100LD@1@P520H81Q0540H@002
544011@Q540H@AQ00QQ1010D@1Q0640H@10P200D03dPDTaNSEI=DRm>;e8^DTiFCPIF;@9F;P03ETiF
C5I<00=FC006ETeF;UH]FTeF;UY>0UY=1EI>00UFCEY=FTaJKEY^ETiJCEY>FTd01EY>0eY^2EY_00AJ
KUY_FVmJK`9JL09NK`03GViNKej?00=JL09JK`=NKP0:GXmNKei`GW1NKej>GViNSUj?GY02GW000ei_
GXiNT002GY02GY42GY000ej?GY1NS`02GY05GY4016:AH[5R/Ujb0V:a00AR/6:aH[5R/PAR/`04I]9V
dfKCI]83I]400fKBI]=Vd`02I]<6I]82I]<3I]83I]<3I]82J]800fKCJ]=Zd`02J]<3J]800f[bJ]9Z
dP02J]800fKBI]=ZlP02J_<00f[CJ_=Zl`02J]<2J_<2J_@=J_<2J_@07f[BLc=^lei>AHY1Ze8<DLM9
AcRRC:5M9FH<L[1Z/VZBFJm4ZcQUA:UES5X<HY5ZlfJ@HPU9J43U@:@`HB0P008XH00:;80XXSdUAJY9
bD68?FLa9BS44442200510003`0010080@@0000803E6ETYVbFK[FVUFBeH[DR]F:`02ET/01EHZETYJ
BEHYFRP00UHY00IF2EHZCRa>:cf988D244<03S4W@JQ1jT79@JU:359>DVi>;DG[=FPY1AB310020004
200010a0464@HA1Q0Pa000T<@A11344@HQB3468<80PP10000P0000/4022R>FE5bEI=H/e_<G=DMgAk
MGng009oUP9oU`9gM`04NgMgMWMfMgH3MeH00gMgMgQgM`02LeL017MGMeIgEgMF0WMG00MkEg]hMgIg
DV:>AJTPQ00300001SDWAL@]9AR31000008400<8800J10000000100@HRT4>FM1bTh]GVeVd6;BI]9R
/VKBH]9RdF:aH[1RSf:^GVeJKV:]HVde1P800004320880PP320222000`a022088007220222423440
0`a0344<@@08340334400``Q344<@00246400`a1340<@003340724423402344010aP340<@0Q02`a0
0Pa100<8@@a134400Pa00Pa100<8@@Q0340010Q01Pa010a100<<8@PQ24400PQ10`a000@8@0a0320<
80P<@003344<80`Q008<8@<<@0<8@003220<80a0008<@003240<@0a000D<@0/8@0D<@0L8@0L<@004
240<@0a024432409340334400`a02448@00224000`Q1340<@00334022445344010`Q224880Q10PQ0
0PPP00<8@0PQ22400PQ10`PQ1@Q01PPP00<8@@Q024001`Q000<8@@Q0244010Q10PQ000<<@0Q02200
1`PP0PQ000H880PQ24088@Q0224;22011241120112400003328D8A@Q00<D8@LD80<D@004520D8A@Q
5442524011@P524D8A@Q11@P0aA000<D81A054400aA100@D@1@P520D@0<D@@06540D81@P620H@1A1
1AQ100<D@AQ064400QA10aQ000TD80`0300XX4G8EViN/59?CU000U9?00=FCUH]ERd00eH]00=FCUH_
ERh015H]0UI=0UI>00AF;UY=FReJC`9FCP9FC`=FD003ETmFCUI=00=FCP9FC`IJC`03FTiJKeY_00EJ
K`9JCPMJK`04FW1NKei_GVl2FVl3FW02FVl3GVh00eY_GVmNK`02GVl00ej>GXmNSP02GVl01ej@GVmN
Kej>GY1NL5jA00ANT09NT@ENT0=NT@9RT0AR/@03H[1R/F:a009R/P=R/`AVdP=Vd@03I]9VdfKC00AV
d`04I]9VdfKBI]85I]<00fKDI]=Vd`02I]<5I]82I]<3J]<2I]<3J]<2J]801VKBJ_9VlfKDJ_AZe0=Z
d`03J_=Zdf[c009Zl`05J_AZlfKDJ_=Zm005J_<06V[CJ_=Zm6[cK_=c57<dI[19ZSf:BNaB2TFZ=>H`
H6W7KTaUbFh]JNQYYUdVFDU^]W]IOod2Ool067oMFJ``8R`0700H01`0920X@20P:64LHSDUAJU>;EI_
G]9JSdG;;>DLPaQR420800<4000;664mZDX<ANa1k5Y]I`m[<Ej/FV]JBP02ER/3DT/2ET/2ERX05UHY
ERYB2TgYCPU>C4G9<BHHQ0a2448]9SV6BRe>;E9>BN]1ZcV9:@HHP`P00P0000P40@PQ424@0222520@
@@PP10@000L800@0220<@0PR1048000200001`P0:@<mbTh^FVmVd7=E009kU`05NgIkMGMEMeEg=@02
Lc@01G=FMeMcEfleJaD00V/D00A_4f/CJaA[50=[5@04J_EVm6[eJ_@2J_<016/DJ_=ZdflE0WMF00ec
EVlDH[91Ra@0100D@DWWG_9FST7Z8<<80009000040@0440TXcUXCRiNKFK@H[1VdV;BH]=VdV:aH[1R
Sf:>0UY^00=RSUI<::<00P0000<8@0Q122003PPP00@<8@a0444@HP8<@@8<@0<<@@03340<@@a100D<
@@04340<@@a034433402344624400`a1340<@@04344010a0244<@0Q00`a000<<@@a0340010a000H<
@@Q1344<@@a0344224400`a1340<@005240534063443244010a0344<@0Q00`a00PQ100<8@0a03200
0Pa01Pa100<<8@`P340010Q020a000D<@@a0340<@0Q100D8@0032448@0Q00088@0@<@0033448@@Q1
00@8@003244<@@a100D<@0032408@@Q100@8@@T<@08<@@8<H@043448@0Q02409244010a1244<8@`Q
0`PQ00<8@@Q024000PPP00@8@0Q122448@<88@032448@0Q10088@004244<@@a1244222401PQ02448
@0Q12408@@<8@0032448@0Q100@8@@042408@@Q1240:220324022242244010PQ22088@Q00PPQ00<4
8@PP22400`PP0`@Q00000`a2524D800@5240110Q524D8A@Q2A@P00<D@1@P54000aA000@H@1@P520D
80<H@003540D@AA1008D8@8D@@<H@@04524H@AQ1640764401a@0400D833RBNYJ/5JA009BD003DRmF
CUH]00AF;@9FCPQF;@05ETiF;UY=ERiJC`02ETl6EU001UI?FTeFCUI=ETiJC`9FC`04EU1JCeY?FTl2
FTh3FTl3FVl2FTh2GVl01eY_FW1JKeY_FViNKUY_00ENK`03FVmJKUY_00ENKP03FViNKUi^009NKP03
GXiNSej>009NKPANSP03GY1NSej@00MNT@03GY1NSej?00=RS`03GY1RT6:@00MR/09R/@=R/P=V/P06
I]9VdFKAI]5V/VKB26KC00=VdVKCI]<01fKC0fKB0f[B00AVdV[BJ]=Zd`=Vd`=Zd`05J]9ZdF[BJ_9V
d`02I]@00f[DJ_=Zd`03J_<2J_82J_<00f[dJ]AZe005J_@00f[CJ_=Zl`04J_<056kbJ]1AjSf;AN]F
:DW[?BPd`V7UM_=b]7:cM[1oJWl;K[1^eGndOo/2Ool01WnnAE0L0P00400D00<L000N600H81@P860i
8d67IZmgU7^AFVi1RCD6<>@dhbc2;><TXRSR?HERS7M;LdmgLg=CKc=VlEj=FT]JBUI:0UH[0eI;01IB
BeH[DRYB:U8:CNU9jDGWANTmR2cT8:D@@Ac4<FI62dI=BR`mR34V7:D400800007100880a1228DI111
42000P`001`880@000040000100HXSESBN<di000100000a0<B=:2Ej=J^ecDW<cKaAZm6lEKcEc=6lE
KaA^m0=_5004JaA[4f/DJa@2J_@4J_<016[dJ_EZmF[d0fKd00=Zm6[cJ_<01FKB00mZm6lEMeMgEW]C
HW0`jP@0640m@6:[L`iVl3g;5:H010000P@00P000`@000H<@Bd3ALUJKFK`I_82H[4016:bH[5R/6:?
0Uj>00ANKF9^CNTD@P8000052408@@a0220<800522000`PQ22088004220334000a10444@@0033400
10a1340<@0a010a10Pa000@<80PP220880D<@08<@@03224<@@a1008<@@<<@08<@@04240<@0aQ3402
24400`Q0340<@006340734443403240>340010Q0340<@@a11@a00`Q000@<@0`P320<80@<@@063248
8@PQ224<@0`P10Q00Pa00PQ01`a00`Q00`a000<8@0Q124000PQ010a010a10`a00`Q12`a000<8@@a0
34001`a000L8@@Q0244<@@Q12408@@05240524401@a122488@PQ32400PQ10`Q00PPP00@8@0Q12448
@@8880<8@00324488@PQ00D88@88@@888@03220<@0Q100888@032208@0Q000D8@0H880<8@0888003
240880PP00<8@0032208@0Q100888@0422088@Q022032243220412400003328D8A@P00PD8@8D@@8D
8@8D@@DD8@04520D8A@Q52475205540262026443640264400aA1644H@@05644262400aQ1640H@@07
64402Q@0400D@3DVCU1BCe9>CRmB;eI>45H]0eI>1EI?15I@00aFCeY=FTiJCEY>ETiFCeI@EW1FCeY_
FTl2FTh3FTl5FTh2GVl2FVl015Y`FVmJKeY^0UY_1Ei_1Ei^00=JKei^GVl00Ui^00ANSUj?GXmNS`=N
Ka5NT09RS`04GY1N/EjAH[45H[02H[45H[83I[8016KBI[5V/FJa0VKB3fKC00AVdVKCI]9Vd`EVdP03
J_9ZdV[C00=Vd`03I]AZdf[C009Zd`07J]9VdV[bI]=Ve6[dJ]@00V[C00=Vlf[cJ_<00f[c00AZm6[D
J]AZe0=Zm09Zl`9Zd`0OJ_=Zm6[dI_EZm6[BK_5JCT6/@JYB2dW/>DP``Tg:I]5kEG<CNeMoUWnaOeE^
m6JBHY9VmFKdFY@i:B0040000P`001h@01@0400@01@0940/H3SRAHIVSVmDHZmB;CeW=DHiASTUAJQF
Cf[AJa5VcF:[I/]_4W=DKcAVdEj>FT`2FT/2ETX05eI;ERYF:UH[DTaB;58[DPY>2TGZ@LTmYcV8=FL/
i1c558<LiC5X<JT]RQcV34401@0000@880a032080084000B220<8@`P100881c3;BDmREZbJcE[=589
<84800`0@FAFSfK^0W=C00E_=6[bJ]5VdVKC00AZm007K_A^lfkdKaA[4f/DJa<016[d00AZlf[bJ_=Z
l`MZm09Vm09Vl`AVdP9Vd`0?J_=c=G=DMiQ^mDW;9204032QGVm_DfoJGaI23aBU00800004424Y21cW
200400005@@08:91jej/Ja9VdF:`I[5R/F:@HXmNSV:?GVeNCTFX420000@02208@006220322462200
1@`P340@@11036400`a00`a100H<@0a1344<@@`Q3443340334400`a0344<@00434400``P344<@@02
34400`a0344<@@0534401@aQ264<H@aQ34400Pa000<@@0a034000`a01`a100@<@0Q12408@08880D<
@005244<80a1344<@006344534000`a12448@@0224401PPP244<80`P3448@@D88@03324<80`P0088
@@032408@@a0008<@0D8@@8<@@043408@@a03403320334000``P340<@003340010`Q244<@@a110a0
0PQ11`a000`8@0a0340<@0a13408@0a0344<@0a1340324400`Q022488@0324400`a02408@0022405
24400`a1244<8@02324010a1244880PP1@Q000@88@Q12448@@<8@00324488@PQ00@880042248@@Q1
224232000`PQ24488@02224624022245220424022243220010A122088@Q11@PQ00<8@0PP22400PPQ
10PP0@@Q0@PQ0@@Q00001P`R524D81@P524D808D8@03544D8A@Q00@D8@<@8@05524@8A0Q524D8002
524011@P640H@1A021@P00DD@APP620H@1Q100@H@003644D@AQ1008H@@8H@003544H@APQ008H@003
620D81@P00HH@@0:400D810P88=1ZU9=EVmBCe8_DRd4ERd00e8]EReF;@0<ERd5ETh01EI?EU1F;eH^
ETh00eY=00EFCEY=ETiJCeI?00=JC`03FTiJCEY>00QJCP05GTmNKei_FW1JK`04FVh00eY>GVmNK`02
GVl3GVh2GVl00eY_GViJKP03GVh2GVl01EY^GViNKUi^GVl00Ui`0Ui_00ENSUj?GXiNSei_00ENT003
GXmNT6:?009RS`05GY5RT6:aH[1RT003H[02H[401F:bH[5R/V:aH[8016Jb0fJa00=V/VJaI]801VKC
00=VdVKCI]<016KC00=VdV[BI]800VKB00=VdfKBI]800VKB0f[B0fKB0fKC0V[C0VKB00=ZlVKCI]<0
0f[C00QVdfKcJ_=Zlf[bJ]9ZlV[d0V[D0f[c1F[C0f[c02EVm6[dKaAc=5i`AJ`mRDG:BPdmIbbQ=BMJ
Jg]aLa9^lf[@Nc1o/7odM_I9SdV>EQ1NT6J;GNQ1ARb2800@00@0200D03RQ?B8m9002?DH05T68ANa5
jcUV<@8/hCE4=DI9k6:@Lc5gMG^GLeE_<f/CH]5NSej>GVeJC5I<0UI:00IJBUI:ETYF:UI;DT/2DR`0
0eHZANY1b@02>HP023EX<BDTa11Q364DPQBS3449000410005PPP344<00P0440aHe9]Ia5o]7nfMcE9
bbc2300THEi;OhUkT7McJa5VdFKB0V:a00=VdFKCJ_@00f[d0fkc16[c0f[d0V[c00=ZlV[cJ_800V[c
1F[d00AVm6KCI]=Vd`MVdP0EI]5_4VlAMe1^lDW;800002B4CRi[<W_DKgAJdb48000<02C4BP`mZ0a2
00@0000B100T`Dh[J^i[4FJ`I[5R/F:@HXmNSUi]IXeJCce7200000P020PP0`PQ1PPP20a00PQ110a1
00@88@a1344<@@H<@004344<@0a0340332001@`Q344<@@`P34001`a10PaQ0PaP3Pa000<8@0a03400
0PQ00Pa00`Q000<<@0Q024000PQ10`a100@<8@Q13448@@<<@@D<@0@8@@03240<@0`P008<8003244<
@@Q10088@@08340<80`P320<@@Q13448@@<8@0<8@@042408@@Q0244:34000`a1340<@00234001@`P
3248@@a124400`a000<8@@a124401`a000D8@0Q12448@@Q000L<@0042448@0Q12202224010PP240<
@0Q10PQ000<8@@a0244010Q100P88@Q122488@`Q320<@0Q00`PP0PQ00PPP0PQ00PQ10`Q01`PP00D8
@@PQ224<80PP00@88@<8@0042208@0Q0240:2202224422000`A124088@0222401PQ12408@0Q12408
80<88@<8800324088@PQ00448@0000D<8Q@Q524D@A@Q008D8004524D@A@Q524352000a@Q544D@P03
54800aA1524D8@025243540011@P640H@AQ10Q@P00PH81@P644HHQQ1620H@AA00QQ01QQ10QQ000<L
HAQR66400QQ10QQ01AQ100/D@AQ1644D@AQ0500@8331CRYN[eI^009B;@=F;@AB;@MF;@04DReF;EH]
ERh6ETh2ETl00eI>FTiFCP03FTd01EI>FTiJCUY?ETh01UY?15Y>00MJKUY_FTiJCUi>GVmJKP05FVl0
0eY^FVmNK`08GVl00eY_GVmJK`03FVh3FVl00ei_GXmNK`05GW001Ej?GY1NKei`GXl015j@00=NL5j@
GY000Uj@00ART5jAGY5NT@9RT003H[1R/F:a00UR/P9V/P05I[5V/VJaI]9Vd`02H]<00fKCH[=Vd`09
I]<00fKBI]=Vd`06I]<3I]800fKCI]9Vd`07I]<2I]82I]<2J]<2J_<3I_<016[cJ]=Zdf[c0V[D0V[c
16[C00=ZlfKcJ_<00VKC0V[d03e^lg<dGY15ZSDVAL]FCTG:<<<XaDh<Lc1_4f[cIY1V/7mEOoac5eH?
FNeZdf[dJ]9c=WnjOka^e4f]><L`Pcd7?FU1RCf9>DPe9SE6>HTeB2SS9<8X`CEUAPaBL4X>@La>3UjA
H_=W4V/BI/mRSEi/FTaJ;5H/ER]FC005ER/03E8/CRa>;Dh/@LXmR3UW=FHeIbST68<@@@@P00D00084
00D0000G1008010P8<8iQDY@;>X4033PFZakd7olLgQRTRc6000L84G9I/mcMGMcLeAZlP02H[03H[40
0fJbI]9Zm003J_D02VlDK_AZm6[dJaA[5F/DJ_AZmF[d1V[c1F[d00=VmFKdI]<00VKC1FKB00=VdfKB
I]800VKA01A_=6mFJ]9Ac2A4000PHe8]J`eonFmcAPl40000400e:59a?S0HY0@00`00014403fWI^i_
46:_I[5R/F:@GXmNSUi]IZmJD33U000400P000T8800512488@PQ2408@@02224434400`a0344<@002
340?34400`a03448@@023402344010`Q320<@A1R0Pa01`a100<<H@a1340030a00`a10`a00Pa100<<
80a0240020Q100<<@@`P32400PQ11@a110a010Q100<8@0`P32000Pa11@Q100D8@0`Q320<80a100D8
@@033448@@Q100L8@@033408@0a000@<@003244<@@a1008<@08<80@<@@033408@@Q000D8@@8<@@04
3408@@Q12405244234401PaQ440<@0a03448@@8<@08<@@D8@@032408@@a100X8@@04320<@0a03402
22000`PQ2408@0022205240010Q122088@PQ0P`P00<88@PP22400PPQ00<880PQ22400`PQ00<880Q0
240010Q000<88@PP22000`PP00<8@0PP22001@PP00D88@Q014488@@Q00<88@88@0@8@@06224880PQ
2408@@Q00PPQ0@@Q00000``Q524D8@02524011@P524D8AA10Q@Q11@P00<@8A0040000Q0Q00<D8A@P
52000Q@Q0QA00a@P00DH81@P620D81PP008D8005544H8APQ624H800264046444640011aP640H@AQ1
0aa000<H@1Q1640011Q00QQ100PD8100400H84F3FViR[E8/15H/00=F;E8]ERd03eH]00=F;UI>ETh0
0UI>00EJCUY=ETeFC5I=00UJCP=JC`05FTiJCEY<FTiJKP03FTh00ei>FTiJCP02FVh5FVl<GVl3GVh0
0ei_GXmNL003GW000ei_GW1NL006GW02GXl00ei_GXmNS`03GY06GY42HY000f:`H[5R/P09H[801F:a
I[9V/FKBI]400fKB3FKC0VJc2fKC00=VdVKCI]8016KC1fKB00EZlV[cJ_=Vlf[b00AZd`EZl`9ZlP9Z
dP0fJ_9Zlf[bJ_=Zm6KDJ_=ZdVlBJ_9B2SDV@JYF;U8<>@DXaDG/J^]_<f[cJ]=Ze6[eKaIZdfJ`K_9k
MG<DFRiZdgomOomoo7oLNcMbTUh>BNi1S3f;>DTi:3U8>FTa9b2S7:8eIdX[CRe1bbSV0QQT00HPYC58
@N]JKF;;FV/2FT/01EY<ETaJCEI<ER/00U8/0U8[019B;5I=BRi5jcfY>FPeIcV7<DHLa1AQ588DPaBS
56<40@PQ1002000310007000320PXSU1CNIB:EYZCNhLQ`@0AL9[;Go^IZi1K100000T`dWXK`akLV/B
I_AN/UjAGY1R/6:a0VJa00=VdV[CJ_@00f[e0Vke16[e00A[5F[dJ_AZm0IZl`EZm003I_EVm6KC009V
d`MVdP=Vd`0EI]AVlflCKaANDB1T000TP59;Kg1kSC41300XQ0P1000Tj5JBDT/HX`@000<00007<DAV
kVl=HZaR[f:?H[000Ui^00ANKFJ=CNd/a@800003200880PP00T880D88@H<@@D<@0d<@@03340<@@a1
008<@@<<8@8<@@<<@0T<@@033408@0a000@<@0<<@@@<@003344<@0a0008<@0<880<<@003344<@0Q1
00D8@@032248@@Q100<8@@03344<@0a000D<@0<8@003340<80`P00<<@@88@@032408@@PP008<80H<
@@D8@@<88@032448@0Q000<8@003244<80a000H<@@8<80033408@@a000T8@@8<@@05240880Q02448
@004244234401Q1Q460<@0a0344<@0D8@088@@04344<@0a0244332432446240234000`Q022088005
22000`a02408@00224000`Q12408@@03320622001Pa032088@`Q2448@0D88088@0h880032408@@PQ
00<88@<88088@0032248@@PQ0088@0888003240880PQ00448@0000<<8A@Q52000Q@P1a@Q0Q@P1a@Q
00<D81@Q52400Q@Q11@P0QPP0a@P0QA000PD81Q0640L@1PP640D81A10aQ100DH@1Q1644H@AQP008H
@@04744L@1a07402644264000aQ1640H@@02644021Q0520D8100=<19jEY]ERd2ER/3ER`AERd00eH^
ETiFCP05ETh00eI=FTeJC@08FTh015Y?ETiJCeY>0UY=0UY>00=JKeY>FTh01eY>1EY_00ANKeY@FU1N
L0QNK`03GViNKei`00=NL0=NK`QNL0ANS`03GY5NT5j@00=NT0=NT@05HY5R/F:aH[5R/P03H[<8H[80
0fJbH[9Rd@02I]82H[<PI]<016[CI]9VdVKB1fKc00=ZlV[dJ]@00V[C0V[c00=Ze6[cJ_<00V[C0V[B
01IZlV[cJ_=Zlf[dI]AZdf[BLa=c=5i]?HTmRTX=BNXi9BcU?HQVZVleJ_EZd`=Zm00;K_=_4g^IOgQZ
/U7=FPig=g^KMeQkM`02OgL016I_DNa9c46Z0SU80SUZ0SEY01<ibdH_@Pd]:11S200<8Q1S58<@HQb2
<FM635J?FXaNS5Y/FVeJC002ER`0<58/ETeJKEY]DTi:;DG/?JXiRCEX<DL]9RCV68<@81B26:DLaA1R
100000@022040000320Phcf6ANU9jEI;FVaRd5Y;><8401B2BRE_TU9=920000@0?FMFSf/?Le=Vl@9N
T09JL006GXmRSf:aI[5VdV[B0V[d00AZmF[dJ_AZm0IZm@EZm003J_=Zm6[c00IZm003I_EVm6KC00AV
d`=VdP04I]=VdVKCI]<2I]8056;AJaAcNFmGES0L8@00=B=Jde8=300TP59aANh88P00:>QJTU9a6:@3
00001Bd2I^i_3F:<HZh00V:?00UNKEi/HXiNCT6;66@000@032000`PP0`PQ0`PP1`PQ1Pa11`a03@a1
0`a01@a10`a01@a100@<80a1340<@@D<@0D<@@@<@007344<@0a0344<@0`P32401@a100D<HPaQ344<
@@a000L8@@033448@@a0008<@004344<@0a03403240232002110344<@@Q13448@@Q0340332063442
24422242244222400`Q12408@00424000`Q1344<@@0334401`a2344<@0a03208@@a000@8@@03344<
@0a000<8@@D<@@033408@@Q10088@@09344<8111444<@@a0320<@0Q100<8@0@8@@03240<@0a1008<
@@0432488@`Q32422442240010Q13448@@Q10PQ00PQ11`PP00H8@@Q02448@@a13404220322432203
24401@Q0220880PQ220010Q030PP0PQ000<8@@PQ224010PQ00@880PQ22088@88@@03224880PP00@8
80448@0000<@8A@Q520011@P00<D8A@P52001a@P0a@Q4Q@P0QPP00HLH1Q0640H@1@Q544564035442
64400aa1740L@0056446640021PP500H83T1CPUJCEY/DR`4ER`@ERd00eH^ETiFCP05ETh01UI=FTeJ
C5Y=FTiJC@EJCP04ETiJCeY?FTh2FTd00eY^FTeJC@04FTh00eY<FTiJC@02FTh3FVl00ei_FTiNC`02
FU000ei`GVmNK`06GVl00ei^GVmNK`07GVl7GW0015i_GXiNSUj>1Ej@1UjA0f:a0V:b00ER/f:bH[9R
/V;C00AR/P05I[9RdV;AH]9VdP02H[<II]<00fKBI]=Vd`03I]<2J]<4I]801F[bJ]9ZdfKCJ]<00fKC
00QVe6[CJ]9Zdf[cJ]AZm6[D0V[C0V[B0V[c03mZlV[cJ_=Ve6[CJ]9_4flBI/iAjcf;AN]>2CeV<>@/
hf::KeI_5V[cJ_9ZlflDLcEc<fJbCPhdia`R;>M5ZdEZ>@I9@g;YNgAc4UXYENY5bTFZ>DTe:SUZ?JY:
3Di=?L`]B0a300440@PQ46<@HPa2100@@C56DTeR[5j]HZd00ei^015RKUi]HXiRSUY=AN/iJ357;BHY
1RCU6:@DQ1BT444800@0008<@@031208811Q00800007320eHThTDTQJJeI[ET/00ThZ00Q>:dgX7400
02STBPHibQ130P0000LmIei9H/YVkUY]FVmJL002GVl025Y^GViNSf:aI]5ZdV[bJ_<7J_@2J_D3J_@0
1f[cJ_AZm6[dJ_=Zm6[c00IZm003I_AVe6KC00AVd`9VdP=Vd@9VdP0GI]5Vd6JaH[5RdVldJaA5Z`00
100m:B12000e86LAKc51d0P7100/j5KEAPX8000200003Rd2I/i_36:;IZiRSV9^GT]JJf:^HXhiB@P2
000222400`PP2408800:22032244344334000``P340<@005340234400``Q2248@@0434400`a0344<
@00234033442340234401Pa0344<@@a1340<808<@@03340<@@a000<<@0L<@@03340<80a000<<@003
468<@0a100<<8@<<@@L<@0<8@@8<@@043408@0a0320322000`a0320<@00234023202340434400``P
340<800232073442340422400`a12448@00724000`a0320<@00222400``P340<80053403344=3400
10a1340<@0`Q10`P0PPP00@8@@Q02408@0<8@@88@0D<@08<@@033248@@Q100T8@003244880PP00D8
80033408@0Q00088@0D880<88@<880042248@@Q1240;22022407220224000`PQ22088@0422400`PP
224880042246220112400003424D81@P00<D80@D8@TD8003524D81@Q00@D8@03520D8A@Q00TD808H
80@H@005644D@AQ0640H8002640554402QQ1740L@1Q1664LHQb278<LHAa10aa000TH@1PP500D0210
?DEFKeY]DR`00U8]0UH/15H]0UH/2UH]00=F;UI>ETh01EI>00=FCEY=FT`015Y=0UY>1EI>00=JCEY>
FVd00UY]0UY>00IJKUY>FTiJC5Y>GTd2FTh2FVl2FTh01Ei>GTmJD5Y@FW000ei_00=JKei_GVl01ei_
2Ei`0Ui_0Ui^0Uj>00=NSej@GY400Uj@1ejA00=RTF:aH[4016:b00=N/V:bH[<00V:c0f:b00=Rdf;B
H]<00V;C0V:c00=VdVKCI]<046KC00=Ve6KCI]<00fKC00=Ve6KCI]@016KD16KC00IZdF[BJ]=Ve6[d
I_D2I]@00fKEJ_AZdP02J]<2J]@026[dJ]=VdfKCJ_A^m6lEJ_<2J]<00fKCJ]=ZdP02J_804fK@DRhi
RdG;FRY5Z3D5881=jfmGJaIZm6/BK_=_5F[dETleK10Q0080000:760hhR@07010P7K/OkMgEUi<EN`2
CN/03TF[@HY1ZdG]@NdaJ2CU7:<HYAc66:D@Ha1R3482224060P0320XhcfXAPa:34h_DRm>;e8_FTmB
CTh<?FL/hbC39>HTiAB3320<@AB336<48080000>444DYAS5460000`P<>5>2UkAJ^iV[58XCNM>2P9>
:`06DTdi9@@0000DHARQ0P00010]9Di@H_5RZf:<GT]JKEY^FTiNKUi_GXmRT6:`I]5VdP9Zl`03J_AZ
mF[e00MZm004J_EZm6[dJ_<3J_@00f[cJ_AZm005J_@2I_@5I]@00fKCI]9VdP02I]43I]802FKAI[5V
dV:bG[9Vm7=hJ]4iB002100030P0301>:V]BIa=[>T5^10080SiD@P`DH@80000<=D=VcFk[HX]R[Uj?
GVmNKUY>G[1JKc3V0P0000@400PQ2208@0L88003120880@Q00@88@<<@@8<H@8<@@03340<@@a1008<
@@<<@003344<@0a100h<@@8<@08<@@03340<@@a100D<@@8<H@05464<@@a0340<@@03364234473404
34400``P344<@@04344434000`Q1340<@002344324401@a0344<@@a122400P`Q0`a00Pa100<<@0a1
34401@a100<<@0`P34400Pa100L8@@a1344<@@Q1340<80022242244010a12448@@Q11`Q000<<@@`P
32400P`P00<<@0`P32000Pa00`Q10`a10PaQ00<<@@Q124400`a10Pa00`aQ0Pa100<<8@`P320010PQ
1`Q10PQ010a000@<80a0340<@@@8@@88@0<88@032408@@Q1008880033408@0PP00<88@032408@@Q0
00P88003244880PP00<88088@0<88@0322088@PP008880D8@0L88088@0`88@0312488@@Q00D88044
8@0000<@@1@P52001A@Q00<D81@Q52001a@P00<D@1Q052000Q@P0a@Q0Q@P00<D8A@P52002A@P0aPP
0QQ000<D@1PP64000QQ000LH8AA1644D@A@P420D800262000aQ0764L@002640021Q1740L@1a0640H
81@P6202500012QQBL]JCE9=0U8^0eH/15H]00=F;5H]ERd02UH]00UF;UI>ETiFCUH/ETaJC5I<FT/0
0eY=1UY>2UY=0eY<00AJCUY=GTiNCPAJCP03GTiNCei_00=NK`03GTmNKeY_00iNK`9NL09NK`ANKP9N
SP03GXmNT5i_00=NT0ENT@03HY5R/F:a009R/@ER/P=R/`9R/PERd`9R/`03I]9V/VKB00=VdP03I]=V
dVKB00AVd`05I]9VdfKCI]=VdP04I]<3I]@00fKCI]AVd`05I]@3I]<016KBJ]5ZdV[C0fKD0VKE00=V
mF[dJ]400V[B00EZlf[DKaEc56kd009Zd`03K_AZm6[B00EZd`9Zl`0<J_5JKcf;@LY>2DG:=BHTXS4W
G]A[=V[d0V[a00=^lUi>;>H0100001@PX46UAHDi0U5RMc5of7MEFPa=c4g/DP]5bdh=BRhmZbTX8<HT
ibT60RdV00hTiB3U7<HHY0aS348<8@@0200<@AbT:><Xi2cU0RSU00H/iBd5:>@T`aR3468246<02Pa2
444DHPa0220000PP6:8aB23X0PPP00hL`T6TFX]Zk5Z=DTa9ie86BNI9jE8/FXi>;S47100000LU04GR
GXQ[2Ej[GXiJC@03FT`02eY/GVeRSV:?HZmVd6KAJ_9Zlf/CJaD00f[e2F[d2F[c0V[d0VKd0fKD16KC
0fKB1FKA01eV/FJbI[=R]6KfKeMkU5I@948000@0@LY_;F/@I_=[5FZa;8D001SX:BL800@0000mHV/<
K^]RRV:=009NS`09GW1NLF:_DR`/a0@1000800PQ00l88003320<@0a000<<@0H<@@P<@0`<@@@<@003
240<@0a1008<@003440<@0a000@<@009344<@110340<@@a0244<80a100<<@0<<8004340<@@a13445
3403344734022403244334433242320234400`a0344<@00:34000`a1340<@@04344232000`a0324<
@@0334422446240334000`Q1340<@003320234000``P3448@@082442344334000`a1364<@@033440
0``Q320<8004224010PP2408@0Q10PQ02`a01@Q10PPQ0PPP0PQ10PPP00<<@0PP240010PQ00<8@@a1
22400PPP00<<@0PP22000PPP00<8@0PP22000`PP00<8@0PQ22400PPQ1`PP0`PQ10PP00@<80PP3208
80l88@0312488@PQ00<880488@0000<D@APP64400QA100<@81A1544011A01QQ10QQ000TH81@P620D
8A@P544D8A@P42000Q@P00<@81@P42000aA00Q@P00<D@1@P52000Q@P00<D@1@P52000QPP00DH@1PP
644H@AQ0008H@@8D808H8003520H81PP008H@08L@00=764L@1a0644D81@0400H8CTWDTiJ/EI@ERh0
1eH]0U8^00=F;UH]ERd00UH]0UH^15H]00AF;UI>ERiFCP9FC005FTaFC5I<ETeJC@07FTh9FTd015Y]
FTeJKEY<0UY>0Ui>00=JCUi>FTh00eY>15i_00ANCei_FW1JK`ENK`03GViNKei_009NK`04FVmJL5Y_
GVl3GW03GVh00ei_GXiNS`03GXl4GY04GY42HY42H[46H[83H[<2H[84H]<00f:bH[=R/`05I]82I]<2
I]84I]<5I]88I]<9I]@2I]<2J]800f[CI]AVe003I]@03fKEJ_AZdf[CJ]9Zlf[eLcIVT57<DJiN;f[A
J_AZdP04J]<2J_@04VkeJ_ARTTg<?HY5jdX<?HPTa2CWCW1[=6leJ_1Zd6Z`AJdL0@<0000B460mYf:Y
LeAVm6[cMgQo^V[DELa5Rd6/ANaFLDH>;FXPaB2T0RT700h]9be8;DPaBBe8:BLQ1QcW7<D@@PP0100<
80a10P`P00H800@022088@PP320234407A1R58<DXa23344880P0100L`cg[@N/YB0Q2000P`Di:FZeR
[Th/AJM1QdG8CPU:2d7;?L/iZbdZ42800P0000LL@4F4FXaRbFK9GXUJJ`02FVh01eY]FTeJK5i]HXeR
SVJ`009Vd@05J]9Zlf[dJ_A[5@02J_D3J_@01F[eJ_AZm6[dJ_D00V[d2F[c00=Zm6KdI_D016KD16KC
00=VdV;CI]800fKB01QVdFKBI[5V/V:dH]EVmV/hJ_AFDBB2000@@E:AKbmVcej@H]5c4eX`56@000`P
100200001dG5LbeZkF:<GXiNT5i`009JC`07GVm9jBB3000400PP22403PPP00@<@0a1468<@@8<@08<
@@03340<@@a1008<@@H<@004364<@@aQ348:344434000`Q0340<@00234043443340010a1340@@111
0`a000<<80a0340010`P0Pa00`a10`a01`a11@a00PQ00`Q100<<@@Q132400``Q0``P00<<8@a03400
2@a000P8@0Q1344<@@Q1340<@@a02@a10PQ11@Q01@Q100<8@0PP340010a000<<80Q124401PQ110a1
0Pa02@a100<<80PQ22400PQ110a12@a000<8@0a024401PQ10PPQ0PPP00H8@0a1344<80a024042242
2442224222001@a02208@0Q022000`PQ00D880Q02408@0PQ00<8@@P880@88@88808<808880042244
8@PQ124:22400`PP22488@032241220122400003560L81Q0008H@@DD@@LH@@@H@0DH@@04524D81@P
420340000a0P540H@00364000aPP640H@002640011PP640D81@P0QPP00<D81@062000QQ00aQ10aPP
1A@P00<H@1a074000Qa00QPP00LD0101;:=9bejaGY5FCP04DR`3ERd2DRh00eH^EReF;@02ERd00eH^
DRiF;@04ERd2ERh00eI>FTeFC004ET`015Y<FTeJCEY>0UY=0UY>2EY=0UY<00=JCEY<FTd015Y>00=N
CEY>FT`00eY>0Ui>00=NKUi_GVl00eY_0ei_00=NKUi]GVh00Ui^00ANKei`FW1JK`INK`03GViNKei^
009NKP9NS`03GVmNKUi`00ANT003HY1NTF:A00=R/@ER/P=R/`QR/PAVdP03I]5VdVKC00AVdP03I]=V
dVKB009V/PEVdPQVd`EVe005I]=Ve6KCI]=VdP02J]800fKCJ]=Ve003I]@2I]<036KBJ]9Vdf/FLcMN
;2b4504i:6I[KaAZl`=Zd`9Zl`0CJ_AZmFlFH[=FCSV:@Na>Cd6X:>DTj4H>LeA_E6lcKa=ZdT5/3080
0P00010Q1Di>Lg=onGohOkU_5gMHMi]R]UH@DLe5cDF[?FXXi@8HQ0049<DY1BTW<DL3;DP02cEY<FTa
J2U7:BHHY0`R324<81AR46400`a100X<80a1468@PaRS58<DPQRS8>@DH@88000D344U14HXBT`iZA1R
000Y0Ti9H/eVbe9<AN`mJ3U6>FLe9BRS644400@00008761B:FK:I^]Zk5j;FVaJK@AJKP05GVeNSV:>
HXmV/003I]801F[cKaA_56[dK_@00f[d1V[e0V[d2F[c0V[d0fKD16KC00=VdVKCI]800fKB01QVdfKB
I]5VdVJbI]=Ve6;EJ_IRTdha:>D@8000101:CW=AI/iNKej?Ka5_4d6Z100300003A0PCPI_36K=GXeN
Sej@GW1NCUi^FTm1QQ00008400l88004320<@@a03446340434493403344234063442340232053404
344334000`a1340<@005340332000`PP320<800:34001`Q1344<@@a1320<@0`P00<<@007240<@0Q0
2408@@Q024400`a100D<8@`P320<8@`P00H<@003344<80a0008<@005240880PP2208@00334023203
340010a1320<@@a10PQ10PQ02@a00`Q010a000<8@0Q124401@Q100@<@@Q1344<@@<<@0D<@@03340<
8@`P008<8@03244<@@a1008<@@D<@08<80@<@006240<@0Q02208@0Q10PPQ00<8@@PQ22000`PP0PPQ
00<<80PQ24400`PQ0`Q100<8@0PP220010PP0PQ000<8@@Q024000`Q00PPP00<88@Q022401@PP00<8
8@PP224010PQ1PPP00<8@0Q122400`@Q20PQ0PPP10PQ0@PP0@PQ00002QQP740LHAQQ540D810P544H
HAAR0QA100<H@1Q1764011aQ0Qa11AaQ00@L@AQ1644HH@8H@@05540@81Q0764LH002764274001B10
740LH1aP64000Qa000<H@1PP64000QPP0Qa10aaR0QaQ00<LH1a064001QPP00/L@1aP864PH1@P400L
@CT6CRmJCeY^00MB;09B;P08ERiF;EH]EReF;U8^DRmB;@AF;@9F;P9FCP03ETeFC5I<009FC005FTaF
CEI=ETiJCP02FTd2FTh00eI>FTeJC@05FTd2FT`2FTd2FTh3FTl2FTh015Y<FTiJCUY>0Ui>00=NKeY_
FVl015Y_00AJD5i?GTmNK@9NKP9NK`9JL003FVmNKei_00ENK`04GW1NKei^GVh2GXh2GVl015i`GY1N
T5j@0UjA0V:A0V:B00=R/V:aH[800f:b1f:c0V:b1VKB00=VdFKBI]800V:c1FKC00AVdVJcI[=Vd`=V
dPQVd`03I]AVdfKC00AVe0=Vd`AZd`=Ve09Vd`=VdP0:I]=ZmG<hGN/T01P0=<IZRflDJ_<2J]<3J_<0
4f[DJ_A_=VlgEW8icCg=DW55jbd69<Lm[6;cLiMcM7^FLa91J``20080000F:FQS<WonOoUoogonNgQg
FG^KH]AN]5iADNe1JBRS544<81AR6:DTiBTV;DL2;BL03358<FTeRSF:>L/]IQc5448@81AQ688HX`@D
Y08HY00I6:DLaQc57<DU1bSU640@81QP<D9:C4i]?NX@PP00<DERd6/>J`mJKTW]=D/Xiab310000`00
00/<02C0=DPXPPP0=@=JlUk<I^]JJUi[009NK@03FTaJKEj?009NT09R/007I[5VdVKBJ_=Zm6/EKaD0
0fkd0V[d2F[e0V[d1f[c0V[d16KD0fKC1FKB0V;C01QVdfKAI]9VdFJbJ]=[669fAJdH@000;:0<0000
CU1gD6[aGVmNSfLBLiQB;QQQ100200001340HXYZkEj<0Uj>0Ui`00ERCVJ>HVlmA0@0008800<88003
224880PP00T88003320<@0a100@<@@03340<@@a000<<@@03340<@@a000@<@0<<@@05340<@@a0344<
@0063442340232043406344<3402344232000`a1340<@@03340;34453402240324401Pa0344<@@a1
320<8@8<@@<<@005344<@0Q0344<@00234400`a0344<@@023443340232033402320334001Pa12448
@@Q13408@0D<@003320<@0Q000<8@0<<@0033448@@Q100@8@@<<@@05244<@@a1344<@00D34423202
340010`P3408@0a00``P00<<@0PP22001PQ000<8@@Q0240020Q10PPP00<8@0Q124001`Q100<8@0Q1
24000`Q00`PQ0`Q000<880PQ220010PQ00<8@@Q0224010PP00L88@@Q12448@PQ1248800822400`PP
22488@0222412201224000037:4PH1A000<D@003440@811000<@8003520D@1Q000<H@0XD80LH@08L
@003840L@210008PH003740H@1a000HLH@<L@@06864PHR1S768PH21Q0R1P00<PP22186000QaP121P
00XPPB1P764H@1PP:64mAe8]FViF;0EB;0IF;@05ERaF;E8^DTmFCP09ERd5ET`2ETd00eI>FTiJCP03
FTh015I>ETeJCEY/0UY<00EFC5Y=FTaJC5Y=00=JCP=JC`9JCP9JC007FVeJCUi=FTiNCUY>GVl015Y_
00=JL5Y@GVl00ei]0Ui^0eY_25i_0ei^0ej>00=RSUi_GY001EjA00=RTF:BHY800f:b00=R/F:bH[80
0V:b1F:c00AR/VJbI[5V/@EVd@9VdP9R/`EVd`04I]9VdfJcI]<3I]8AI]<8J]<03f[BJ]=ZdV[CI]9V
df[eLcQEc2@S508m:6k=Ka=Zl`02J]83J]<04f[cJ_AcEVmHF[E1cSg=BS15k3E89:DXiSf/H/mk]7_G
Ng@mJA0R008800047<9>KVnFOo/2Ool07gMiOoiongMgK_ERD4EZ>@DL@@`0424@@A1R58<PaBT5:@HX
iRT6;DPaJCUX>FLiIQRT448<81AP584HPQS4008Pi@8La@8PiP0E6:DDY1c67<DHHaA08:8mYU9XDXe:
;1AQ100aA5J=KdmkTeI`?H/TYP010080000D440X`CU5CNQRJ7M7KdiB2P`0::1>C6/:GZYJKEi]GViN
SUj?HXmRT09R/@03I[5VdFKB009Zl`9Zm003KaEZmFke009^m0MZm0AZm@9Zm0MZl`9Zd`EVd`AVdP0^
I]5RdFKBI]=Re6KCI]9Vdf[bJaAc=6JE>DlD0000;DE>23T6000eRgM@J_1N/UZ@Ia=RlTX;44040000
3415ig=<J`eNSEj>GXmNL5i_HT]VJeY>=@<000@0320522000`PQ2208800722023405344534000`a1
340<@004340010a1324<8@`P1`a00`a110a000<<80a034000Pa01Pa11Pa000D880a0340<@0`P00<<
@08<80<<@@<<@0043448@@Q12444344010Q132488@a00P`P2@a00Pa10Pa000<<80a0340010a000<8
@@a024400PQ11`a00``P0Pa000<<80a0340040a000<8@0Q124400`a000<<80a024400`Q10`a100@<
@0a12448@@8<@@L<@0052448@0Q13448@@043405344232000`a0320<800734022202240010PP2408
80Q00PPP1@Q01PPP0`Q00PQ10`PQ0`Q10PQ000<880Q024000PQ00PPP0PQ000<880Q022000`PP00@8
8@Q124488@D8800612488@@Q22088@Q01@PQ10PP0`PQ0`PP000012C3::8/XbS40bC4123400`PY22S
9:<TPRAQ760PH21Q868PPRB388826643888376400b1Q860L@003740021`P740L@2AP980LH1Q06602
764264002AaQ988PHAa1864THR1R748PH@02860011a0884TPB220R211BB100XXPBB1764L@1@P940/
H46YDTiFC09B;003CPeB;E8]009B;PAF;@05ERaF;U8]DRmFCP08ERd00eI>ETeFC@03ET`2ETd8ETh4
FTd015Y>FTeJCUY=15Y>0eY?0eY>00=JCEY<FTh00ei=00=NCUi_FVl00eY_0eY`25Y_00=JL5i`GVl0
1ei_0ei^0Ui_0Uj@1EjA00=RTF:BHY800f:b00=R/F:bH[800V:b1V:c00=R/VJbI[800fJa00AVdVKA
I]9VdP9R/`UVd`=VdPEVd`03I]9VdfJc00EVd`05I]9VdfKCI]=ZdP02J]<00fKCJ]=ZdP02J]83J]<0
36KCJ_9Zdg<fK_IAcB0S300e1fk]KcEZm09ZdP=Zd`0CKaA_5FmFHaI6435Z=FU1k4GZ>DPXiQaS64@a
:5Z`LoaRlSTW42400P`001LD@2e7F_AkfWolKg]ogGooOme^m5W]AHdhiC2S864PPR2T:>@LXaAR464D
PaR4008HY00;7<DU1Rd5:<@Ta0a21008011P588HXP026:<27<D09QS56:@DY1BT5:DDQ0`Q320PPCV6
CXmJ[di_7:<402d3EXmVkekc@LhXj0`1000<02d5ANaNSfK>Lc5gDg]bLdiof69/800@03EXGXh2I^h0
16K?H[1R/FKA16KB00QVdf[bJ_=Zlf[dJaA[5F[d0V[e00=Zm6[eJ_D00V[e0f[d1F[e0V[d00AZlf[d
J_AZm09Zl`03J_9Zlf[C00EVd`9VdP03I]=VdVKB009Rd`0ZH]AR]6;DJ_E_=f/fIcUFEC4;104003UU
H`mgCD6[000HXej^I_1N/U[dF[9:<2CV300400009@5Fd6/_I/iNSEj>GXmNLEi`GRYVBTg;<<@000@0
0PPP00D88@PP220880PQ00X880032248@@a1008<@@04364<@@a0340334400`a0344<@00434033445
3406344834073442340234401@a0320<@0a146000Pa000D8@0`P320<@@Q100@<@@03340<@@a1008<
HP8<@@@8@@888@04340<80`P320734043442320534000`Q12408@@04244534043202340224000`Q1
340<@00834000``P2408@0033403344010Q1340<80PP0PPQ0PQ11@a10`Q100<<@@a034000`a000<8
@@Q0244010Q11@a00Pa100<8@@`Q32002Pa00`PP10Q010PP1@Q01PPP0`Q00`Q110PQ00<8@@Q02200
1PQ00`PP00X8@0PQ220880a122088@@Q22448@D480@48@042248@0PQ22472203224322000003<D<e
0SDV00@iA`<eA`07=BHe9CD5=@Ddi3CS=>@00ST41S3T00<``cCS=@@00SST00<hhcSR=<801S2R00</
XS2R;:800RbQ00@XXBBR9:8TXP<PPP<PHP8LHP0598<LHAQP880LP00378402R1Q984/XBRQ884HH1QQ
884LHAQP0QQ000DH82AP=BA5jeY;009F:`03DPaB;58]009B;P9F;@AF;004EReB;EI=DRd6ERd2ETh2
ER`5ET`2ETd015I>ERiF;UY>0eI>0UI=0eY=00=JCUY=FTh00eY>0eY?0UY>00EJCEY>FTeJCEY<009N
C003GTeJCUY_00QJK`08FViJKeY_FVmNKUY_GVmJK`INK`05GViNKei^GVeNKP02GVl00ei`GY1NT004
GY4016:@HY5R/F:a0V:b0f:a0f:b1F:c00=R/V:aH[400V:a00=V/FJbI[400VJb1FKB0VJb00AVdVKC
I]9VdP9V/P03I]9VdfKC00=Vd`03I]9VdfJc00EVd`AVdP06J]5ZdV[CI]=Zdf[B0f[C00iVdfKBJ]9Z
dV[cLcE^mEW]948D03dWK^acEF[d0V[B0V[C03AZdVlDLcIVlDH>:@LPY2dV@JU:2cf9<DPPa`P2000P
aDI@APdXi111320@@10P9<IFTFmFIaIRmFmHNi]_5eG>?BX`YbbU<<</PRRR=DM1bS5X9>@LPQ11344<
80`Q224<8A1R568<8@800006100<8110340<80P00`PP01/<@@a234480@@0200PXSf7DVeK4eZa<@H4
0223CNYR[Uj^<F`01@00004iRf:;LdakSg]bNg@00W<c011c<W=BLg=_3cU9000H8T6:JZigCfl@Ja9V
lVKcJ_=Vd`9Zl`06J_AZlf[cJ_=[56[d0V[c0f[d16[e1f[d0VKd00=Zm6[cJ_@00V[d00EZlf[BJ_9Z
lV[B00AVd`03I]9VdFKB00=Vd`04H]=R/f;EI_L2JaL016KfHY91T0`70P0000i1Zf/9Mhmol4W;000D
@Di;H^mNdDibAPlY2@`S0P@0010002TPF_5[46:]GXeNKUj?FW1ND5hZJVY5R1b3000801888005320<
@0aR348<@@0834000`a1340<@00:34063448340634400``Q320<@@0434000``P244<@00334000`a1
324<8@0434400`Q1340<@00534442442224010PP320<80`P20a00Pa100<<8@a134401Pa01@Q11Pa0
10`P10a000<8@@a0340020a00Pa100<<@0PP34000Pa000@8@@a1344<@08<808<8@06244<@@a1344<
H@a10`Q11`a010Q00`Q11`a00PPQ00<880a034001Pa00``P0PPP0PQ000<880Q022001@PP0`Q00`PP
00<<80a024000PQ00PQ100<8@0PP224010PQ0PPP0PQ000@880Q0240<@0888088@003224880PP0088
800324488@PQ00<480L880032248@0Q000h8800000<aACE5=DL00SEW13UX0cUY00<iJ3UY?FT01Sf9
00DmRSf9?HU1RCeX008mA`03?DPmJ3eX00HmJ006?DLiAcUW?FLeACTT13e50SU600<i9SD4=>D00SD5
0c3U00Ha1CDT=B@e8c44<@<3<><2<>806C3S<>@/i2S3;></i2cS<>@XXRB1;<=1RE8/DTeFC58<DPe>
3E8]DRiB;EH]ERaF;EH/009F;@9B;@03DRiB;E8]00QF;@03ETaFCEI=009FC@=FCP9F;P03FTiFCUI>
00=FCP06ETeFCUI>FTmJCUY?0eY>00=FCeY?FTl00eY>00=JCeY>FTh00UY>0Ui=00=JCUY^FVh02eY_
00EJKUY_FViJKUi^00INK`04FVmNKei^GVh2GW02GY05GY4015j@GY5R/F:a26:b1V:c0V:b00AR/FJb
I[9R/P=V/PEVdP9V/P05I]9VdfKCI]=VdP02I[89I]<00fKBI]=Vd`03I]<4I]82I]<00f[BJ]=Zd`02
J]<2I]<036[CI]=ZmG<fLcMEk2@P6015R6k[KeEVd`AZd`0>K_=_4flEEPdTaAPR764iAD6YCRa:;CV9
9@LDI088000458<TiAc568<2688081A198<mREI=H]5JKejAGPm9[3T7=<Hi1cD6<>8THAQ1?JUJ[e[b
BRhmZC4U:><T`Qb1668LPR2R9<@Xi2CT7:@28<@011c3560<80`P0`P001T<@0aR344000@05655afK`
H_5SESU[200@8CU[DS0mAb2000040c5<CU9W5FmBLe=_4@02Ka82J_804F/CKc=cEGMeFY8PQ@0096=A
k6JZJa1_4FldKaAVlfKBI]<00V/D00IZlf[dJaA[56[dJ_<4J_@2J_D@J_@01f[cJ]9ZdV[cJ_9VdfKB
00=Vd`0=I]9VdfKCI]9RdfKDJaE_>6/hIaUBDcg>::@00P0000lT@4g]Ha=[3WNCNdiF3@@0321>BelB
CW8n42T932800P0000L40000485BdVLaHZiNS@02GXh025Y`FU5VKFZ;@DL<0@00200@220332000a10
344<@@05344010a0240<@0a00Pa10Pa000<<H@a034001Pa01`a11`a00`a100@<@Pa1324<8@8<@@<<
@088@@88@0<<@08<@@888@D8@@H<@@D8@@888@03220<@0a000P<@0<<@@03324<@@a100L<@@043408
@@a03403344232000`a0344<@@0234400`a0344<@@03344234000``P340<@0023405344010a0344<
@@a10PQ100D<@0`P32088@a0008<8005344@HPa12448@002244734000`Q02448@@02244222433442
3402344010Q1224880PP0`a00PPP0Pa000<<80PP22000PPP1@Q01PPP0PQ00`PP00@<80a0340<@088
@@03240880PP00H88@0322088@PQ00888@04240<@0PP220224400`PQ12448@06124212000`PP1208
800422001@PQ2448@@Q022402`PP0@PQ00000c56=DDeAP04=DH>=DL00cUX>FLiJ005?FP00cUX?FPm
J004?FP4?HT01Sf8@HU1R468AHQ5Z0E5Z@95bP95Z@03AJQ1R46800=1R004AJU5Z468@FP3@HP0145X
?HU1RCf80T6900XmJ3U7>BHiAcTW?FM5bU8]ER]>30=>3@03DReB;58]00=B;0MB;@QF;@06ERiFCUI>
EReFCEH]0UI>0eH^1EI>2EY>00=FCeY?FTl00eY>0eY?15Y>00=JKEY^FVh00eY^00=JCUY_FVl00UY_
1EY^0Ui^00=NKEi^GVh00ei_0ei`0Ui_0ei`00ANT5jAGY5NT@=NT003GY5RTF:a009R/@MR/P03H[=R
/V:c009R/`IR/P=V/P03H[9VdVKB009VdP=V/P03I]9VdfKC009VdPMVd`9VdPMVd`IVdP9ZdP=Zd`0U
I]=Ve6KDI]AVm7<fLaI=bb006019Qg;XKc=Vdf[CJ]AZdf[dKaEcDf:@AJdH@a0R888eA3f6CRaBKcfZ
;DPTaP`Q100DPaRT58<00QRT01XHPaA1540XX46VETi>3D6:;:@X@BaS?>Hm1CT3>>4TH1PP?HI_2Uj]
HZaNK5Y<DTe:2T7:0Sf802XmIdG9DR]FCE8[BLU5ZD6X?FHiACUV?FLiASUV@LPiZAc5100002SSEVYW
<F/aAQ0DI`@0:895SC2W2000022V=F]JKf/<H/eR[ei^GVmRSf:_I]02J_405V/BLeEkV7=IDQ0L8P00
9655Yf9[J/]R[F:aH]5VdFKBI_=Zm6/DKaA[56[d0V[c0V[d00=Zlf[dJ_@00f[d00=Zlf[dJ_<016[d
00AVm6[dJ_AVl`=Zm004J_=VdV[BJ_82I]800fKAI]9VdP02I]802VKCI_A[5FlfKcEZlf:bGVm1S1Q4
0P0001@PP3eQGVMcBVl_Kc9Vkf[>@HX80@`PDTYF/D8>:BT@A0@0000<0@`P0P@000]6;fmBI]1RSei^
GVeJCeYAHXmVJcD500800005200880PP220400052202100010P0220880PP10`P00<<@0a134400Pa0
00<<@@a034000PPP00@<80a0340<H@8<@@@<@003320<@0a000H<@003344<@0a000L<@08<80D<8@8<
@@D<@003220<@0Q100@<@0888088@@8<@@05244<@@a0344<@0033442320334401@Q1220400PP3440
2@a00P`Q2@a100<<@0a134000Pa000X8@@PP100<80a1340<80`Q320<@0@<@@L<@0T<@@062248@@a1
340<80PP0P`P1Pa000<8@0a034001Pa00PPP0Pa100D8@@PQ22088@Q1008<@@03220<@0a100<<@@03
244<@0PP00@88088@003320880PP00<8@0D880<4808880@8@0<<@0032208@0a00088@005220480@P
2208@0022202120222400`@P2208@002220324000`PP2408800222021202220212072204240<2201
22400003<DLeASE600<eAP04=DLaAcE7=DP5=DL3=DP3=DL013E8=DLeB3E81SEX0SUX00<iB3U7>FP0
0cUX0Se813eW00@mJ3eW?FPmJ0@mR091Z@91Z0=1Z@07@HQ1ZDFZAJY1ZD6ZALX00T6Z00A5ZTF[AJ]5
b`=9k008AJY1RD69@HU1ZTG/CPaB;@9>;@eB;@=B;PAF;@AFCP9F;P03EReFCUI>00IFCP03ETmFCUI>
00MJCP9FCP=FC`=JCP9JC`03FU1JCeY?009JCPMJKP9JCP9NK`03GViNKEi]009JK@03GViJKUi^009N
KP=NK`04GW1JL5i`GVl3GW02GY03GY43GY02GY44H[46H[800f:cH[9R/`02H[<5H[83H[<00f:bI]9V
dP03I]800fJbI]9V/P02I]8:I]<00fKBI]=Vd`06I]<00fKBI]=VdP03I]800f[BI]9VdP02I]82I]<0
0fKDI]EVe@02KaH07TW<700L04F6L^M_4VKCJ]A^m6[eJaIcN7<eFRh`iaa276<Xi34T>FI5bDi=AL/a
B2TW8<HLYAR456<@HP8DQ00F56<@821Q;:19adX=@FXH00@0700h`SST?@Di13dU:60L@466K/MVZF::
HX/2GX`0:F:]I^iNSDWY?HI5Z58;DRa>2Th;CN]9bTFZAJUB36:aH[1NSeI]FZm5iaAQ104Y9dY<FaE:
Cb2U32<LPcD1840000`0@DMJLEj@GZmJJUY:FT`00UY>01INKF:>H[1Vd6[bJa=_=FmGMk]cFE8?98<4
0100740a1TG]FY1RdV:aI_9[4`=_=@06JaA_5FlEJ_AVm6LE16[d0f[c1V[d00=Vm6[dI_@016Kd0VKc
00AVdf[CI]=Vd`=Zl`9_5@9_=P06KcM[5EZB@Lh]:1a00P0000@H046ZEXmNc09VkP9Vl009I_5RSSU9
100@83fYAU0U1P`R0080000E200a9DX:8<<0035YI^eVd5j?GViNKEY>DS5JT5I=<<@000@0220<80a0
00<8808<@0032208@0a000D<80<<@08@@08<@@8@@@8@H@03364<@@a1008<@@04364<HPb236824640
1A11440@@11144000`a00Q1000<@@@a134400`a11@a000@880P0200<8@H<@@<<@003320<@0a000@<
H@8<HP03348<@@a100L<@@888003344@@A1000@<@@06324<80`P340<H@a00Pa10`a00`a100<<@Pa1
34401`a100<<@0a134401@a100<<@0a132400``P00<@@11Q464030a100D88@a13448@0Q100D<@@03
340<80`P008<808<@@03340<80PP008<@003344<@0a100<<@@88@003244<@@Q100<8@P888@03244<
@0a100H<@@04320<@0a03402240010a0240880Q00`a00Pa100<8@0PP22000PQ00PQ100@<@0`P3408
@@88@0@<@004220<@@a1364234400`Q12208800424433442244236400`a02448@00224000`Q12408
@@0224401@Q02448@@Q1240010PP1`Q10`Q00Pa100@<@0Q0220880<8@@0000<aAcE6=DH013E600<a
AcE7=DL01CE71CE800HeJ3EW=FLeIcE7=DP2=DL013U8=FPeJ3EX0SU81CUX0Se800<mIceV?FL01CeW
0Sf80Sf700DiJ3eW?FI1QSf6008mQ`05?HPmJ3eY?FQ1Q`02@HP2?HP02Sf9@HTmRD69?HU1RD6YAJU1
ZD680T6900A5ZTg[ETiB;PiB;@=B;PAF;@03ETeF;EH]009F;PIFCP05EReFCUI>ETiFC`02ETh2FTh3
FTd2FTh5ETh3FTh2FTl00eI?FTmJC`03FTh01eY?FVmJKeY^FVmJKEY>00=NK`03GViNKEY]009JK@AJ
KP03GVeNKUi_009NK`03FW1NKei_009NK`=NL0=NT@=NT003G[5R/F:a00AR/@mR/P=R/`IVdP=V/P=V
dQ=Vd`=VdP9Zd@IZdP0@J]=Ve6KEI]EZmV/GAJ`P01P0AHMc1g<bJ]=Zm6lfI]@2J_D056Ja@H`TQ1aS
8:@/i343=DA1b4X;BP`aJ358;BLXiabU56@<8@P0344232001AaQ>BE9b3DW52800P0000lL@3RP>><m
13CU=<@XHBB0@JI^aeiXFTYJBeY]GX/00V;;02eVR3e0=@0/X3T2?FDmI3TT>BDe9S3U=>@mIe9=HZeN
S6:/FX]FQbSS228HQ46YCRl]20`078@mQdF1960L84ESIV]R[FK=FV]FBeY<FR]F:eX/GTaRSF:`I]40
0VKB00QZmFlgLeQkVGMFJ]11[A020P00018H@BS3=BM1ZeI>I/m_57=EKaA_=G<fKcE_5FlfLcM_5V[d
JaD2KaD016/DKaA_56/D0V[d00AVe6[dI_AZl`AZm003JaEZmF[e009_5@0<KaI_=W=FMeMgEW<fKaAR
/EH^AL`iB22T0`0000LX`DG6HVU_;6/@Ja9Vl@02H]4016KbH]5NTCE80PP000<LYBDY68@00`0000TX
`e:>KbheA@00;BMNJf:^GXl00Ui/00MJCE8`GY5=jb2210088@0234400`a0364<H004340234400`aQ
464@HP0234000`a1444@@@064640111R464@HQ1R0Pa200P<@@aR468@HPaR464DPQ1R0a1Q0a1P0Q1Q
00<@@11134401A1Q00<<H@aP36000Q1P00<@@11134400Pa100<<@PaQ36400PaQ00P@@0a1344<@A1Q
468@H@aQ1@aR10a20`a100<<80a134400Q1P00<@@0a1368010a10a1Q00@<@0a1344@@@8@H@8<@@8<
@P06364@HA1R464<@@`Q0`a100<<HA1134401`a10P`P00<@@11Q46400Q1Q00<@@@a1364010aQ0Pa1
00H<H@aR368<HPa236823646344010a0364@H0a01@a100@<@110464<H08<H@04348<HPa134023642
34801Pa346@<@Pa1468DP@8<H@H<@@04340@H1B2464234001PaQ360<@0aP364@PP8<H@04344<H11Q
3403344234000`Q0244<@003340<34401`a0344<@@a1364<HPaQ008<@@03244<@0Q00088@003244<
@0a000<8@@07344<H@aQ340<HA1Q36400Pa10PQ11@a10Pa000<<@@a0344010a10@Q10@a10@Q10000
0c58=DHeAP02=DH2=DL5<DP3=DL2=DP00cEX=FLeJ002=FP2=FL01cE7=DPeAcE7>DPeJ3E8008eJ0Li
J003?FPmIceV00HmI`8mR003>HPmR3UX008mI`<mQ`8mR004?FPmRD68@HL2@HP00cf8?HTmR@03?HT4
@HT0246Y@HU1RCeX@HU=k58]DR`4CRd:DRd3DRh00e8]EReF;@04ERd2ERh=ETh2ERh6FTd00eI=FTeJ
C@03FTl00eI>FTmJC`02ETl00eY@FTmJC`03FTl3FVl00eY^FTiJCP02GVl01Ei^FVeJKEY]GVd01EY^
00ANKUi_GVmJK`9JL0ANK`9NL003GW5NTEjA00=NT@03G[9NTF:B00AR/P03H[5R/V:b00YR/PER/`03
H[9VdVKB00=R/`05I]9R/f:cH[=VdP0EI]<2I]82J]46J]80@V[CI]AVeFKdJaAVmDF[920L04g9MbQc
<FKBKa=c=5Zc@LlmSCU;<>PLPaR49<DTY2BS;BA1b4h]CR`mbcEY;@PLaQR556<<@@`P344DPabR:>0i
ABc386880000300XPTDR?@@hi3CT=><XPBRQBNYZbFJYFTYJ:UY/GZiRcEk>DRXi0@8XP00@?BA1A45R
?DH/aBB496<H01aR?JYJSUk=CTaJJeJ:;BH200003AaR78<@01@P>BQFT4gY=>55Z6J>J/]N[5Y[009F
B`0DFTeJC5X/FRaNC5j>GY1R/6;AI]5VdVKCJ]9^m7MFLeI[EeIa=F/H80<0000:100@8BC6=H]1kEI@
H[5[57=FMeL2LcH02WMGMeQgF7<fKaAc=G<fLcE_56lE16lF00A_5FlFKaE_5`9_=`0=KaI_=W<fLeM_
5F/FJaERe5I?ANliJbCW64000`0001<LH35XBRmRlV/ALeAc<flCJ]9V/F:aG[9FTDib@PlTiP`P100<
8@0300002`@0;:5JSFNdEXdT`@00>HUVbV:^GXh00Ui/00aJCEH_DW51ZA0P10048@a1364@PQ1R3442
46000`a0320<@@0234401PaQ368@HQ11460@HP8DPP8@H@04468DPaB248864680211Q468@HPaQ464@
PQRS68825682464248800a1R464@HP0346800a1Q468@HP0346801AB2468@HA1R46<00a1R00@@PQ1R
468@HP8@H@08368@HQ1R468@HA1R588DP`@@HP03464@HQ1Q008@H@03468@HA1R00@@H@@@HP09368@
Ha22468@HA11344@HA1R00<@H@@@HP03488@HQ1R00D@HP0>464@@@a1368@HPaR344<HA22364<@A10
464@HP<@H@03440@HA22008@PP@@HP04364<HQ1R46<348<01Q1S368@HQ23368@HP8@H@03468DPQ1R
008@HP03588@HQ1Q008@@@@<H@<<HP0?364<HQ2346<<HQ2348@<HPa1364@PQBS48<@PPaR008<H@0B
360@@11Q588@HA10364DPQ22464<HA1R58<DXaB346<@HPaR0Q2300D<H@a1364DPQ1R008<H@03468@
@@a0008<@@8<H@8<@@<<H@H<@@05340<H@aQ368<@P02344010Q12408@0Q10Pa010a10PQ10Pa100<<
HA1R36401Pa100<<@0a134403@a100000c57=DHeAP02=DH5<DL2<DP2=DL01357=DLeASE61cEW0cE7
00@iB3EX=FPeJ0HiJ08iA`03>FPiIceV00@mI`03>FLmIceW00@iJ0@mI`05?HLmR3f8?FPmJ@0=?HP4
@HP2?FP014G<DPeFBdh<14h]3E8]1eH]0eI>0eH^15H]15I>0UH^00=JCEI<FT`00UY<00AFC5Y=FTeJ
C09JC@03ETiJCeY?00aJC`IJCP04GTeNC5i=FVd6FVh3FVl00eY`FVmNK`02GVl4GW000ej@GY5NT@03
GY42HY4016:bHY9RTV:b0f:a1F:b0V:a00AV/V:bH[9R/`=R/P04H[=R/V:bH[83H[<00fKBH[=R/`0=
I]<6I]85I]<00fKBJ]5Zd@02J]42J]80Ef[AJ]9ZdV[CKaE_57^EKaA9c2@P:65AjG]XLe1_4g<cMgA6
3ab730880A1356<LY2C59<@DHR2R>FI:2di<@N/iRRC644@<8AQS344@@1RS8>@eHek]OoecFCdZ2000
00`0<<59HTE4>>@hhc31964/`TWYK^YV[6:<HVaNK5Y]FTe>CT6Z<>@P@BAQ;:11@dVRAFL`abB64048
010Q>FQBK59^EVe>:E97;BH00@02000030@0200TPC3SAHTi132Q@FIRSFK9GX]JJ`9FB`03FVaJC5Y<
009JC006FVeJKUi^FViNSf:?0Uj>0V:?00QVlF/AJ`mR[E8/@HPX`Q00100000d801AQ8:8a9CV8@L]=
k5H]HY1RTF[BJ_=ZlP02J]800f[CJ_A_5@04KaH047<FKaI_5VKEHY=NTf:bHY5JCDW/?HX]9bC578<D
@@P00`0001DLH3eQFRMVYf[ZLe9_=6/DJ_A[5FLEH]=NT5YaCU0m[2TY8<LDP``P1000100001@XiEZ>
OlaS4CV8200D84X]I^]R[Uj>GVaRJei/GTeJCcU7200000PP1Pa000L@H0`P3208@0a0344<@0023440
20a0460@HAR2588@HQ1Q58426:<00a22468@H@0946400a1R464DH@0356424644468246400a1R464@
HP02468011B2468@HQ1Q0a1R00@<HA1Q488@HP8@H@046:8DHA1Q34424645468846400a1R464@H@02
46400`a1348@HP0246400a21364@HP05468946400a11464@H@0746400`a0348@HP02464246824880
0a1Q460@H@0246401Q1R464@@11Q460@P@<@H@03588@PQ22018@HP8DPP03464<@@a100@<H@<<H003
464<H@aR008@HP03464@HPaQ008<@008344<H@aQ364@HA1P360@H0<@H@04444<@@a134443640111Q
468<HPaR0Pa20PaR00@<HA10344<@@8<H@8<@@07320<@110344<HQ2346400Pa100<@@@aQ34400Pa0
00<<80a032000Pa000@<@@aQ348<HP8<@@8<@004240880Q13402344424400`a1340<@00;34023440
1Pa0344<@@a0244<@@8<@0<<@@0000<]AcE7=DH01S571C5800<aAcE7=FL00SEW00<eJ3EW=DL013EW
00<eB3EX=FL013EX2CUX1CeW13UW13UX00@iIceW?FLmI`8mR08mJ@03?HTmR3f800XmR0A1R007@HTm
J3f9BNaF:dh/CPd00dh]0Th=2e8]2UH]0eH^0eH]15H^00EFCUH^ERiJCUI>00AFC@9FC003FTaJCEY=
009FCP=JC`=FCPUJC`AJCP=NC@06FTiJKUY_FViJKeY^15Y_00=JL5Y_GVl00ei_0Ui`15j@0ejA0V:A
0f:B00AR/V:aH[5R/@ER/P03H[5V/F:a009R/P05H[=R/V:bH[9R/`03H[83H[<00fKBH[=R/`0:I]<9
I]86I]<2I]800f[AI]9ZdP02J]405f[BJ]=ZmFlFLeMc=F[BAFXT02A1AHQbjW^EMgAo^6ld>H`80P@0
324<@Q1R7:D00R35014HPa0P:<@a9DG:>JX]9aAS200<0AAS320@@1RS:BDmjE/c009oo`0UGS4D@P00
300di4ESAD@hi3SR<<8PPR1Q?DEB;5I>BPa9bdG;AJY1ZCf8<BDTXaPP300L@341BJ==QCdT=BPi2Q`R
304/aDG9BP`00Sg9014mYRT4444800`0200@82BR;:<L@0`0520``SeUALI9jUY:009FB`=FC09JC003
FTeJKEY]009JK@03FTeJC5Y]009NKP9NK@0;GXeR[fK@I_5N/4i@?H/XiQb4668D800500003PP0300@
@1R29<DXiRd6=DPiJCV:?J]63TW^ANh2?J`02cf[>H/eBC4Y:@TTj23668<D@0`010000`0000T@01bR
<BQ1cDh>GVeZcGMBMe400VlB00]Zm6KdIaERm5JBCU11cC59:@LLY@a20084000B20040000000DPSgZ
F]9_f5ka@LTL@0@0>DEN[VK^GZmNKei]0Ui[00=RJei?=@L00P@000H<8110340<@0`P340244000a0P
3408@0033402344010aQ464@HA1Q111R00@DPaRS58<DHPX@H@8@HP05464DHAAQ564@H@0346801@aR
468@HA1R56800QB20QAR1a1R0a1Q00L@PQ1Q464@HAB1464@HP0256801122588DPa220Q1R1Q1Q1A1R
00<@HA1R46800a1R00<@HA1R46801A1R00@@HA1R468@HP8@H@<DH@8@H@05344@HA1R464@HP034640
0`a1348<HP084682464011B2468@HQ101a1Q00@@HQ1Q368<HPH@HP8<HP03468DPa1R00@@HP04464@
HQ1Q444234001@a1364<H@aQ36000PaQ00<@HA1R46800Q1R0Q1Q00L<H@a1344<HA1Q364@H@033400
211P488DPQ1Q444<@@a034443680111R368<H@aR0Pa200D@HA1R464@@A1000<<H@8<@003320<@11P
008<H@0848<<HPaR468@H@aQ344<@08<8003344<H@aQ008<@@<<H@8<@@05340<H0aQ344<@0043440
10Q1220<@@a10`a000<<@@a024001@a01Pa110Q10PQ00Pa00@a100001C58<DLaAc57<DH00S570SE7
1C580SE700DeIcE8=DPeB3E700@eI`8eA`04>DLiIcEW>FL3=FP4>FP2>FT2>FP2>FL3?FL3>FL6>FP3
?FL3?HP3?FT;?HP4@HP01d69?HTmRCfYBN]>358;009B;09>3@04DReB;58/DR`4DRd00dh]DReB;@02
DRd5ERd2ER`00eH]ERaF;005ERd4ERh01EI>ERiF;UH^ETh00UI=00AF;EI=ETaFC0=JC09JC@9JCP9J
C`03ETiJCeY?00QJC`AJCP09FTeNCEi=FTiJKUY_FViJKeY^00IJK`ENK`03GW1JL5j@009NT0ANT@=R
T@ER/@=R/P9R/@9V/@03H[5R/V:b00]R/P03I]9R/f:c00EVd`=VdP9Vd`9VdP03I[9VdVKB00EVdPIV
d`03I]9ZdFKB009Zd@0DJ]1ZdVKDJ_ERTUH<AJ]1JBb3700D032SALUZbg]_J^m>;b2V108@@P8DHP0;
468HY1c48>DLY10Q448PPbdU:BLTi@0258<06QB4468801106:<ThbTU?PeK5W=GAFTLP`00300`i4UT
@@<lhcS2<<8PPQaQ;<<e9RdU;@@3<>@013D4<@@``RAP0QP0014PH34S@HAAXUhRGR]1C2Q5200P@S43
;BH]12CS;@<]0Rc2008TXP0>;<8i0SCS<<@H8@@0200H82c1=@8mIE89ETYFB`=FC0=JC09JC@03ETaJ
C5Y=00MJC00AFTeJKUj^H/iVcV[>J/eV[Ej>FTe>2dGZ>HP]11b1520<000400002P@0300@01A0640D
@10P520D@1@P0Q0P01D<00P020840@@0200@01b1;><iITgYFPYNBf:<J^i_<W=CKcE_5V[eJaD00VlD
00QZe5jBANhiRS589<<@HP@00`0000<400P000000P0001HQ0e::Ie1gSU9]=DLLH0P0<@=JBVK_I_1N
SUi^GTeNBUiZIXY=jc3V200<008@@0D<@003460@@0a000@<@08<@@<<H@8@H@8@HP<DHP03588@HQ1R
008@HP8DH@<@H@03460@HA1Q008@HP03564DHQAQ00D@HP@@H@8DH@04568DHAAQ4682464246854644
56401A1Q468DHAR258801A1R1Q1Q0a1R00<DHQ1R46801a1R0a1Q00H@HQ1Q464@HA1R588246800a1Q
460@H@0346400`a1364@HP0546800`a2368@HP0546400a1R464@HP0246401121468@HA100Q1Q00<@
PA1Q46400Q1Q0`aQ00@@HA1R468<HP<@HP<<HP<@HP@@H@06360@@0a1340880a11PaQ0Q1Q00H<@0aR
464@HA1P4402364346801Q1Q440@H0a0464<H@8@H@8@@@04344<H@aQ348334402@aR464<@@aQ220<
HA1R464@@0023640111Q364<H@a10Pa000D@@0`P344@HPaQ008<@@05444@H0a03408800334023440
0`a0364<H@023447340334400`Q0220<@00634022406340010Q1340<@0a020Q00@Q100002C56=DHa
Ac57<DHaAcE7=DPeA`05<DP00cE8=DLeA`02=DP01CE7=FPeB3EW=FP00SEW0SE70cUW0SEX0SUX0cUY
00<iJ3EX>FP013UX0ceW0SeX23UX00@mIcf8?HPmR08mJ@DmR003?HTmR3f800HmR091R009?HTmZSfZ
=FU1bdW[DP]B358/009>3@04DRe>3E8/DR`3DRd3CRd4DRd3ERd3ER`00eH]ERaF;005ERd4ERh9ETh5
ETd4ETh3ETl00eI>FTmJC`07FTl8FTh2FVl015Y^FVmJCeY`1UY_15i_0UY`1Ej@0UjA0V:A1V:a0f:b
0fJa00=V/V:aH[802f:b16:c0fKC00AVdVKCI]9VdP=Vd`04I]9V/VJbI[82I[<016KCI]9VdVKB1fKC
00AVdVKCI]9ZdP9Zd`04I]EReEY@<@L27000ARA0820P0200820/`Cf6?J/TY@`Q228DHaRS58<@HaBT
7<DPiR35568<81aR;@DYAbD69@PLj1B5224801AQ6:<Pi1S46<<YB3UX;:@DHP00200X`dE4@@8lhSS2
=<8LHBBQ=DDiIcE6<@De1CTV?DM1ISTT=<4/H3CQAJMNB6;>IZmVcVJ/KaEVDSd90R0001He13E6;@@]
1344;><a0SDT?DHmAD66DP]9QRQP400<02b0=>4`h3e2CPQFJ`9FBP=JB`03ETaJC5Y=00=JC@09FTiJ
CEY=FTaJCEY<FVeJCEY]009JC@07ETaJCEY/HXeVcVlAKc<00W=E00egMg=FJaARTEY?ERi>3DW]@L`i
JCE8<BHXi@029<@04RS49:<Ta2d6=FPeRSf[ANe9kTX?DRiF3UX]I[5_57<eLcAgE0=gE@0<LeI_=FlF
JaI[5f[fGY95kSV;<DXLY@PP1@0000<8811044000P@001LDH3g5Fa9SDe[c?J/PH0@0200iAEj<I^i_
4F:>GY1JL5Y>FRaNJfI[AHTLQ0@000<@@0<<@004320<@11P440634001A10444DPQBS48<00a1R00<D
HQ1Q3440111R00<DPQR256400Q1Q00<DPQ1Q46400Q1Q0Q1R00@DHQ1R488@P`8@HPH@H@03564DPQAR
00@@HP03344@HA1R00@@H@8DH@066:8DP@PP464DHA1Q111R00<<@@a046401A1Q0a1R0QAR00LDHAB2
564@HPa1440DH@024680111Q340<80a00Q1Q00@@HQ1Q468DPPP@H@H@HP0348<@Ha1R00<@H@0:468@
H@a0340@HQB25:@DPQ22468346401Q21464<H0a0360<H@<@H@04364@HQ1R48<3468236800a1R364<
H@02344234000`aP364<H@0636401Q1Q468@HQ1R464<H@8<HP03464@@110008<HP<@HP03368@HA1Q
00D<H@8@@@04364<HPaQ368334400`a2468<@P0334800`aR364<@@033640111R488@HQ1Q0Q1000<<
811034400Pa000@@@A1Q468<H@@<@@07468<HPa1340<H0aQ360010a000<8@0a0244020a10`a000@<
H@aR364<@@H<@08<@@053408@@Q02408@@05240124400005<DHeACE6<DHeAP04=DL2=DP00c58=DPe
B00<=DL2>DH00cUW=FLiI`03=FP023UX>FTiJCUY>FLeJ3UW>FP2>FT2>FP00ceW>FLiJ002>FP5>HP;
?HP00cf9?HPmR@08?HP2@HP023f8?HTeIcEX?FU5bdgZCP`5DR`0158<DRaB;58/14h]0e8]00EF;58/
ERaF;5H[009F;003EReF;5H/00EF;@=F;P9F;@03ETaF;UH^009F;PMFCPEJCP9FCP04ETmJCUY>FTh7
FTl9FTh2FTl2FU000eY`FVmJK`06FVl2FW0015i`FW1NL5i`0ej@00=NTF:AHY400f:A16:a00=R/V:a
H[401F:a00AR/V:aH[5V/PQR/P=R/`9VdP9V/P03I]9VdfKB009VdP03I]=VdVJb00=V/P9V/`04I]=V
dVKBI]8;I]<02F[CJ]AVeF/HES0iBS3W=@Li1P02>BH07ST5=>@/`c3S;<@D8@P0448HY1c468<DQ1BT
8<DY1bd6;@Da9c58>H/ibd7;<DPHY@PR100<81AQ688L``8La@0B6:@Ta2BT424400`P;<=18T3R?>8l
hCSQ984i8D67AHM1IceW0d5W02Q9YdF7>@9MY7maOoMolgofOoQofGomOomooW:aBHQ9IdfYAL]1RCE7
=BHmId68AHU5RTVYERYNS5i9?@4XH210AF9JBeH9AH=B1ej:HXUFB@=FBP03ET]FC5I<009JC@08FVeJ
CUI=ERaJCUi^GVeJK@=JKP0?FTiJCEY=FTeJBej;GXeR/6KcKaA_=W=FMeMkN7]g009gE`0DMeIgEGLd
LaAZdVJaI[9R/V:AHY1V/FKBJ_9Zlf[bKa=_=7=FMeIgE`9gEP03LcI_=VlE009_5@0;JaEVm6;CI]9R
TDh`?J`aBbT978D<@P0600003AB18>@PhaB1560HP34UEVYRjeJ/CT/]:00100800006@JUVb6[/J`mR
[Uj?0Uj@00QJD5X^FTaJBd5X428801QP0Q100`a000@@H0aP440@@0L<@004440@H11Q464546802112
344<@A11464DPQB1440246400aB1464@H003464446800a1Q468@HP0244400a1R464@H@0646424680
111Q440@@A1R111Q0QAQ00PDH110464DHA1Q344@HQB30Q1R0a1Q00@<@11Q468@HPD@H@03564DPAAQ
008@HP05464DH11Q468@H@0346824643468646400a1P360@H003464246800a1Q368<@P0234400a11
464@H@05464010aQ464@HQ1R111Q00@@HQ1Q440@H0D@H@04468<HA1R46824642368236401Q1Q364<
@@a1364@H@8@H009340<H11Q364<HPPP460<HA1Q008<H@07464<@PaR340<811046400a1R0Pa100@@
@A1Q464<H08<@007364@HA1Q464<H@a136802Pa20Pa10`aQ00@<H11Q464@H@8@@08<8004344<@0a0
360236463443340236000a1P360<@002340010Q03408@@a02Pa100<<80a034400`a000<<@@a03400
1@a01@Q000<<@0aP36000@aR0000135U=B@eAC560SE613E700<eB358=DP00SE700<eB3EX=DP00cE7
00<eB3E7=DL013E700<iIcEW=FL00SEX00<eJCEX>FT00SUY00@iIcF8=FPeJ0<iJ@03>FPiQcUX008i
J006?HPiR3V8>HPmR3V82Sf813f923f800=1R3f9?HT00cf900HmJ4FYBN]B;E8/CP`2DPd2DR`00e8<
DRaB;004CRd00dh=DReB;@02DR`00eH]ERaF;00:ERd3ERh3ERd015H^EReF;EH^1eI>00=JCUY=FRd0
0UY=00=J;UI>ETl00eY>0UY?0eI?00AFCUY?FTmJC`MJCP9JC`9JD004FW1JKeY_FVl3FW000eY_FW1J
L003FW000ei`GY1NT002GY001UjAHY5RTF:AH[5RT@9RTP03H[9R/F:b00QR/P9R/@03I[9R/V:b00IR
/P=R/`05H[9VdVJbI[9VdP05I]<00fKBI[9V/P02I[82I[<016KCI]9VdVKB2VKC03EVe6[DJ]AVe6/H
H[ANDUhbHW=RTUjBGW5F;dF:@FQ5J3c4<:@D8BS69@LHY1B3348@HQR38<Da9cV[ARi>LDH_?LdaBAbU
204000P0344DPQR37:<La1bT68<HHAb3420401A0<<A1943R008lhP0C><4XPCTTBJU9Yd5V@DM5J4VZ
CNa=kDW;@DMoLGo_OoYomgoiOoh017oo00Qog5FYABE=ZdW/@JTiASTU0Se50155R4F9?DI=bFJ?FTa5
QcD4>>9=aeY=DN]5Z4gZFTaJBeH[009FB`04DRaBCEI=EVh2FVh00ei_GY1NT003GY000ej>GXmNS`02
GXl00eY_FViJC@02FT`00ei]GXmN/002H]42I_<00fKdJ_AZm002KaD01FlDKcAc=G<fLcD00W<f00Ac
F7<gLcIc=P=cEP03KcE_56/C009[50=Zm00=J_=VlfKCI]=Rdf;DF[9>DCf/<BPPYAAS10001P0000d<
HBD6:FTQ1b3V58<<@A1Q=DMBKU[B?JXLH002000021@P>H]BL6LDI^iVkf:^GXl2GY001Ui`FU1F;UY=
ET`i9P880008660@@110440<@0aQ464<H@H<@006220<@11P464@H11Q1Q1R0Q1S00D@HQ11464@HQ1Q
008@HPH@H@03564@HQ1R008@HP07344@HA1R444<@0aR46800Q1Q00X@HQ1Q344<80a1464@HQ1Q440@
@@P@H@8DH@04568DHA1Q4643468346400a1R464@H@0246801A1Q468@HA1Q46000QAQ0Q1R0QB20Q1Q
2a1R1A1Q00H<HA1Q464@H@a1464346800`a2344<@008464224003@aQ468@HQ1R464<H0aR464@@11Q
364@H@aQ00@@H@05340<HA1Q464<H@03368010Q0368<HQ1R0a1Q00H@H0a0364@H@aR348234423640
1@aR468<H@a236800PaQ00<@H1113440111R00H@@111464@HA1046023640111R464<HA1Q0PaQ0Pa2
0Pa110a200<<@@a236800`aQ00D<HPaQ464@HA1P008@@003344<H@aP008<@@<<H@L<@@<<@003464<
H@a1008<@003320<@0a1008<@@04340<@@a034423206344010a0320<@0a10`a000<<@@a034000Pa0
0Pa110aQ0@b10@b300001354=B<eACE51CE600@eAcE8<DPeB0<eA`05=FLeB3E8=DPeI`05=DL2=FL3
>FL4=FP5>FP00cUW=FPiJ@02>FT00cUX>HLiJ002>FP00cf8>HPmR003>HL00cf7?FLmI`02?FL013f8
?FLmIcf80cf91cf800@mRCf8?HQ1R0DmR@91R007AL]B;EH/CPa>3E8=ER`00U8<0Th<00YB;4h]CRi>
;Dh=DPeB35H/DRaB3@9F;0=B;0eF;@03ERaF;EH]00AF;@AFCP03FTiJ;EY=00=JC@03FTiFCUY>009J
CP9JC`=FC`=JC`03ETiJCUY>00EJCP=JC`EJK`=JL0AJK`03GVmJL5i`00=NT09NT@ERT@9RTP03H[9R
/F:a00QR/P9R/@03I[9R/V:b00MR/P9V/P9VdP=V/P06I]9V/VJbI]9VdfKB1fJb0fKB2fKC0VJc01AV
e6LGI[AJ45h?IRmN;e8?DPe=k468?DPmAcD698<D8AAS8<HDQ11R0PPP00l800a26:@U1cV8=HT]J1S5
34<4000010488A1R58800QRS00@DXaR2568DH@8HHP04200DHCT4ADD2?>801cRP=:4TH2bS?DI5QT5W
008mA`0<@FU1Rd6;>DTi9gmcOo9ofGnHOkIof7ol0goo02U^ScdT<84`aS4W<BDa1342=@<e0Rc1;:4X
XC32=@@i13D5=@@i0d54@DH``bQQ=>A=bEI<FViNSEY]ETeB;5I=FViNSej@G[1N/F:aH[9RdVJb009V
/@06H]5R/F:`GY1NSei_0Ui^00ANSejAH[5RdP=VdPEVd`EVdP08I]=Zm6[dJ_AZe6[dI_=VlP9VdP0A
H[9R/F:bH[9RdfKdI_=ZlVKAGY1:;cg<=FX]:1c548@4000600003P@06:@aAcfW?LPY9aB3100000@0
340a13f57:@300001cUXETYRc6/AI_5VdF:`009NS`03GXiNL5i?009JCP06GTiFC33T100801AP0Q1P
00<<@11P34001Pa000<@@0aP34000Pa01A1Q1a1R00<@@A1Q4680111R111Q0aAQ00@@HQ1Q468<@@<@
HP03464@HQ1R008@H@03468@HA1Q00@@H@03564@@A1100/@H@<DH@8@H@09468@HA1Q464@HQAQ464@
HQ2200@@H@<DH@03464DHA1R00D@H@L@HPL@H@04364@HA1Q4645468346401aB2464@HA1Q468@H@a1
008<H@8@H@<@HP@@H@04340880a0364346424683464010aQ468@PQ1R0Pa20`aR00<<HA1Q4640111Q
00H@HPaR348<@PaR364246801`aQ368<HQ1Q364@H@aQ008<@P0>468<HA21460<H@aP460<@0aP364@
HAB2464<@0<@H@07364<@@a1344<@Pa132400Pa10PaR10aQ00X<@A1Q464@HQ1Q440<@@a0360<@08<
@@03360<@0a0008<@0<<@@<<@0<<@@<<@00:220<@0a0340<H@a02408@@a13202220332001Pa0344<
8@`P340<@@8<@003320<@0aP00<<@@8<H@05368@PQ1R364@P@0148800003<DDe93E500HeAPDeA`8e
I`<eA`03=DPeAcE700<eA`DeI`03>FLeJ3EX008eJ005>FPiIcUW>FLeJ003>FP013V8>FPiJ3UX0SUW
00@iJ3V7>HLiI`<iQ`03?HLmIceW008mI`@mR0<mR@03?HPmRCf900HmR@8mR0@mR@06@HU1R3eW>FQ5
k4h<1U8<00a>358/DRa>;Dh^CReB;E8/EPaF;58]DPh4DRd0158^EReF;EH/2UH]0UH/1UH]0eI>00=J
CUH^FRd00UY=00=J;UH^ETl00UI>0eY?0eI?1EI>00=JCeY>FTh00eY>0eY?15Y_00AJCUY_FW1JL0AJ
K`04GVmJL5i`GW03GY02GY44HY42HY85H[800f:aH[9R/P0?H[82I[800fKBH[9VdP03I]82I[83I]80
0fKCI[9V/P05I[82I]83I]<5I]800fKCI]9Vd`02I[<05V[dI]EJ<3TY:6@X8C22=<@`XbQP:80/`341
<DLLI0@0448HQ1AS224880a10Q1R00P880@0100480PP120400@Q0PPQ04/@HQB358<La1RS588DHQ10
564DHQR2440LPcTU@BDm0ccR>:4`P21098<XY2c3;><`hc3T<@Ha9cU8<>HTXbBQCNQZl5i^ERaJCEi_
GXmNLDF]968D01a0=BDeJBdV9<<T`RBP:<0iA2S1420<01a0::4`hbR2964/PCC1:80<00P0520e14G;
CRaBKe9`DTmFKEj>H]400fKc00EVm6/EJaEZm6KC009Vm003H]=R/V:a009NT@0<GY1NSej@H[5RdVKC
I_9VlfKdI]AVdfKB0VKC0fKB00EVdfKAI[9V/VKB00=R/P=R/`9R/P0<H]5RdfKCH[=JTEIbCS0mcC59
8>HDP`@0200000@DPS69?Pdmk@8aJ@036:@4000000<0000<10000000100XiD7^EY5VlfL@Jc=[4V;A
0Uj@00iNSej@GVmJKeY?FRiJ;EY>CNXXP`P0100@@0a00PaQ00<@H0a0340010a000@<H110440@H08@
H@05468@HA1R468@PP0446801A1Q344@HA1R46401A1R111Q00PDHQAQ564@HAB2464<@11Q1Q1R0a1Q
0Q1R00@@PQR2564DH@H@H@0:364@H@aQ344<HQ1R364@HAR25883468011B3468@HQ1Q0QAQ00<DPA22
46400Q1Q00@@HQAQ564DH@<@H@X@HP0358<@HQ1R00T@H@04468@PaB2468246424682488346800`aR
344@HP0258<01Q22468@PQ2258<@PP@@H@03364@HA1Q00H@H@03468@HA1R00<@HP03344<@PaR00<<
HP08364@HA1R488@HQ1Q468<HP8<H`8<HP8<H@<<HP<@H@@@HP8@H@04488@HQ1Q4644364246400`aQ
464<H@02364246400`a1368<HP0334400`aR344<H@02364234400`aQ360<@@0234001@a1364<@0a0
34400PaP00X<H@aP364<@0a1340<@@a0344@H@@<@08<@@<<@08<H@03340<H@aQ008<@@03320880PP
008<8004340<80`P3445364446400a1R48<DP`0248<23681464136800003<DHeACE500PeAP03<DLe
ASE6008eAPDeA`TeI`03>FLeIcUW00PiI`03>FPiIcUW00HiI`03>FHiQcV700<iQ`03?HLmIceW00<m
I`03?HLmR3f800@mR006?HTmR3f8?HPmRCf80Sf913f80Sf900U1R466>DHeAd6ZANa>358[DR`01U8<
00QB;4h]DRa>3E8=DPaF;58=0U8>0U8^0U8]00=F;EH/ER/00UH/2UH]0UH/1EH]00EJCEI=FTeFC5H/
00AF;P03ETmFCUI>009FCPMJCP03ETiJCUY>00AJCP03FTeJCeY>00AJCP9JC@03FTiJKeY_00=JK`03
FViNKUY_00ANL004GY1NTEjAGY43HY49H[4@H[800fJbI[5Vd@05I]82I[83I]400fKBI[9V/P03I[83
I]82I]<2I]85I]42I]804VKCI[=V/fkdI]EJD2d884@XI2Q0;64XHRbR>BA>2V[YEY4e:P8<000968<D
I11S344<@1AQ464<@0P000840084800M244<@@a1468DPaRT6<@DPaB2468<@@`P440HPQQR568LQ3D5
@BA113cR><4`X210400@81AR7:@LXP02688021b39:<XXb23620/hEHZFR`2CLX06dW:?FP`iB114004
02AQ@HE1bRd59:8DH2S0?F9=jDFX:88002QQ@F<iAC2S620PPCD2;<0<000300002P`P684]13eXBPaN
SfK`Ja9RlV/D0Vle00I[5V[eI_EVe6KdI]@2H]<2H[800ejAGY1NT@02H[400f;AI]5Rd@02H]800f;C
I]=VdP02I]8026:bH[5V/FJaI[1R/6J`H[42H[803UjBG[=N]5ZCG[9RdVK@G[5><3f[>FXaBAQS1008
00003PPP7>@maTXZEVe::d79;BHDQ0@0200<8`01100300002a1P=D5>:6K:I^e[4FKaI_9RdV:aG[00
0Uj@00YNSej@FVmJKeY?EReJ;5i>AHLD@@880004440<80@03202440834000a1P464@H@0346800aB2
488@HP044640111R464<HA1Q0a1R1A1Q00H@HQ1Q464@HA1P584246400`a0464@HP0246401@a1340@
HA1Q68800QB200H@PQ1Q464@HAAR56444640111R464<@0aQ0a1R0QAQ00<@HA1R46800a1R0a1Q00<D
H1R046400Q1Q00<@HQAR56400QAR1A1R0Q1S1a1R0Q1Q00<DPQB146001Q1Q0QB200@DPA1Q560@H0D@
H@P@HP03464DPA1Q00<@H@06340@HA1Q488HXaBR211Q00<@@@a134400Pa10`aQ00D<HPaQ364<@A11
00<@H@03468<HPa2008<@P8<HP07364<@11Q468@H@a046000a1Q0Q1R0Q1Q00L@HPaQ464@H@aQ360<
H@034640111P340<80a00Q1P00<@H@aR34400Pa10PaQ0Pa10PaQ0Pa11@a010a10Pa00`aP00@<H@a0
340<@0<<@@`<@0052408@@Q0220<@00222000``P340<8003340010a1364<H@aQ1a1Q10aQ0Pa10@aP
0@a100000c57=DHeAP04=DH2<DH2<DL00cE7=FLeI`03=DH4=DL4=FL5=FP;>FL00cUX>FLiI`05>FL2
>FH4>HL2>FP3?FP3?FL6?HP013f9?HPmJ3f80cf900<mR3f9?HP00Sf80cf900M1Qcf8?HPmJ47;APaF
:`02DR`5DP`01e8/CRe>3Dh=DPeB;5H/009B3@05CPeB;E8]DRaB;@02DR`00eH[ERaF;002ERd2DRh=
ERd01eH^ETiFCUI>EReFCUI=009FCP03ETmFCUI>009FCPMJCP03ETiJCUY>00AJCP03FTeJCeY>00EJ
CP03FTeJCUY?009JC`9JK`04FViNKUY_FW03GW000ej@GY5NT@02GY400f:AH[5R/@04H[400f:bG[9R
/P06H[800f:cH[9R/P09H[800fKBI]5VdP04I]82I[83I]400fJbI[5V/P02I[800fKBI]=Vd`04I]<2
I]82I]400fKBI]5VdP02I]82I[<06FKCI]AR/UjcGU15[3C6;40diE7ZJ^]cLg=aKeE9c100200@8AAT
324400P0440@HQ1Q008<800Q344@HPaR468<HA1R488HY1S56:@@Q11S348880`P444HHQAR344<8C3U
@DE113SS=<4`X1a0400<01b26:@HXaB2008@@@0V568HQ2239611I5i<IXaNSUH_BPe5RCSU:6@@8PP1
;:=>1dG/9<H<01Q0>D=B:5i[HVa1R1@P201=c4h>=>8D01Q1:>@mQ3F67:<800@0000:100D@2T5@PeJ
/FLDI_=_56leKcH2KcL00flfJaIVm002H]<2H[801EjBGY5N/V:aH[800f;B0f;C00ER/V:cH[9R/f:b
00=NT@0@HY5RT5i_GW1NTEjaG[9N/eZBDW9:;d7<=FTaJBCV3447000070@0560XhcV6CReFTEkdEY5:
Ccf[9>D@@000440LPbBU20040000200TXD78EY1W3VmBJa1ZlF;?1Uj@00eNSej@FY1JKeY^FTiF;Ei<
HVliAP`0100<8@0344000`aP340<@00834000a10464@HP03468011B2488@HQ1R0a1Q1a1R111Q00@@
HQ1Q464@HPP@H@@@HP<@H@03568@HA1R00<@H@0=588HPaAR444@HA22468@H@a0464DPQRS58800Q1Q
0Q1R00<@HA1R46800Q1R00D@HA11464HPAB200<@H@03468DPQ1R00L@HP0346<@HQ1R00D@HP8@H@03
488DPQ1Q00D@H@<@HP04464DPQB24885464946800aAQ464@H@03464346800a23488@H@0346402Q21
464@HA1Q444@@Q11468<HQ1R0`aQ00<@HA1R46400Pa00a1Q00<<@0a134800PaQ010<HQ1Q444<@A1R
464@@11P360@H11Q368@HQ1Q468@H@8@HP03464<@0aP00@<H@05464<8110440@H002464020aQ2248
80a1368@PPa14684344434000`Q13448@@0234400`aP364<H004364234000`aQ3408@00=340010Q1
22088@a10`aQ0Q1100L@HA1R468@PaB3488@H@033640111Q360<H0aP1PaQ0@a00@a100000c57=DHe
AP04=DH01C56=DHaAc57=DL00SEW1SE60cE700<eIcE7=FL013EX4cUW13UV0SUW0SUX0ceX0ceW13f8
0Sf90Sf800<iIcf8?HT013f913f800TmRCf8@HLmQd67?FPmJDG/DR/00dh<158<00UB;4h]CPe>3E8=
DReB;58=CPd00e8]00MB358/ERaF;5H[DRaF;002ERd2DRd00eH]DRaB;@04ERd3ER`8ERd00eI=ETaF
C@04ETh015I=FTeJCEH^0UY>0UY=00AJCUI>FTiJCP9JC@04FTiJCEY=FTd2FTh7FTd2FTl2FVl02eY^
GViJKeY_GW1NT5i`GY1NTEj@GY400V:A16:a00=RT6:aH[801F:b00AR/F:bH[9R/`AR/P9R/@03I[9R
/V:b00=R/P04I[5V/V:aH[82I]82I[84I]42I[42I[800fKBI]=Vd`04I]<2I]82I]4016KBI]5VdFKA
0VKB0VJb01UVdV[cKaAgE5i?>@PX@3CUHVYoSW=?Lg=_<eX[820000`132440000100<80PP200<8002
44444640AaB258<Pa1bT58<@H`aS24888@`Q440DHQ11200<8Bc5@DDlhcS3=<4dX21P400<81bQ8<@L
Y1RS688LQ1bT8:@PXbbQ@HAFBUYZANTiJBcU=BHi:BR552<803D4DRLmZQQ4200/hDh9GVQNB6JYDR/i
900052=1B332300000`P8<<mI474>HDiIB3422001@0000TH@2d5AN]JKV[AJ_=c=flfKaH00V/E00AZ
mF/DJ_ARdP9NT@04G[9VdfKCI]<2H[<00ejcH[9Ve002H[82H[<00f:bH]=R/P02GW402f:AI[9V/VKC
GY5BD47]>HT]9R2R4440200001<@HBdR?JA:1eYZI^m_46KcH]A>3SEZ7>T8A001368eITW3<@<@8@02
100022d1CRMVZgM=Kbm[4VKaH]42H[000ej@GXmNT002GY03GXl02eZ?FXiJKUI>DTaRS5I?=@D<00P0
44400a1000D<@110340<@0`P00H<@08@@004460@HA1Q464446800a1Q340@H@0646844642468:4644
4683464244400a1Q364@H@0246401A1R564DHQ1R46400Q1R0Q1Q00P@HQB2584DPQ1R464<@A110Q1Q
1A1R00<@HAB14680111Q111R00<@HA1R4680111R0a1Q0a1R00<@@A1Q46801A1Q00<<H@PP34000Q1Q
0Q1R00<@H@aQ3640111Q00<<HA1R46801Q1R0a1Q00<<@11Q46400a1R00P<HPaQ364@HA1P464DXaB2
0Q1Q0a1100`@HQ23588@HQ1Q340@HA21584@@0a0360446002111364@HA1R464@@11Q468446401A1P
364@HQ2258800Q1Q0`a00`aP00L<H@aP340<@0`P340@@00236401A1Q364<@@PP34000PaQ1@a11`a0
0`a10`a000@8@@a0244<H0h<@088808<@0<<@@07368@HQ1Q464@HQB258<00Q1R0Q1Q00<<HPaQ3640
0PaQ00<<H0a036000PaP00<<@0aQ36400Pa10@a00@a10002<DL7=DH00cE7<DLeA`04=FL00cE6=DLe
A`04=DL2=DP2=FP00cEY=FPeJ002>FP2>FL00cU7>FLiI`02>FL00cEW>FLiI`03>FL3>FP01CUW>FPi
J3UX>FL01CUX0SeX00<mIcf8?HP023f80cf900<mR3f9?HT01cf900U1R3f8@HLmIcUX@L]62dX]CP/0
0Th<0U8<00I>3E8/CRe>3Dh>CPd7CRd2DR`2ER`2DR`00eH/EReB;006DRd00eH]DRaF;@02ER`9ERd0
15I>ETeFCEI=0eI>00=JCEI>ETh00eI>00=JCUY=FTh00UI>0UY>00AJ;EY>FTiJC@=FCPMJC@9JC`9J
L003FVmJKUY_009JL003GW1NT5j@00=NT@04HY5RTV:BHY84H[400f:bG[9R/P04H[83H[<5H[800f:a
I[9R/P03H[8016;BH[9V/VJb1FKB00IVdFKBI]9VdVJbI]83I[87I]<016KBI]=VdfKC2FKB01U_=GMe
FW8/abQ1=@IRS7M>Lc5_4W<eJ/m1ZbRU::@iJCEY<BDaAbd468<800@0344<H@0346402A1R588La234
668DH`a232888@0232404@a1468DH@00424a1SdU?@@hi3d2?>4TP@`0320HXB347:<00QRS00XHY1bT
7:@LXbBR<@51b3ET:><LHP8@800M768H@@@0300iA5I8=DH80R1Q@JQFKUiZFRQNJV:=DPXP@000300H
HQRS8:8HH0@0000LXc6;@Nm:D002BRh00cV::BHHH00300003PP0424PYC5:@Li>45I@H]A[5F/FJ_AZ
lfKCI_@2JaD00f[cI_AVe003I_D00f[fI_ER]003H[@036:cG[=N/V:cGY9JDDX?@LdiRbTY7:D880H0
000Q100@HRT5<FQ1k59`F[9VlF/@Kc1_46/BEY55kC45400000QR8@L]JacY;DTXh``0200`hE9=Ha1_
D7=CJa1Vd6:_00MN/09NT0=NS`0;GY1JSUY]DTiFSf:=DPd/aP@0200<@@03440234000`aP464@@007
34001Q10444@@A1R464<@@8@HP03488@HQ1R00L@HP04488@PA214642468346400a11464@H@024645
468346425682464020aR468@HQ1R464DPAB258<346800a1Q468@HP0246825680111R464@@A1Q1A1R
00<@HA1R46401a1Q0a1R00<@PQ1R46800Q1Q00<DHQ1Q4640111R00<@@A1R4640111Q00D<H0aQ468<
H@a1008@H@06468<@@a0364<HPaQ0a1R0`aR00D<H`aR468@HA1R00<@H@H@HP<<HP05464@H11Q468D
H@024642340234400`aR468<HP0346401a22564@@0a0364@H0aQ008@H@09364@HA22468@HA11468@
PQ1Q008@HP04368@HQ1Q364246800a1Q340<800244033642360336401@aP340<@@a136400`aR00L<
H@a1444@HQ10320<@00234401Pa0344<@@a1340<H@<<@@<<@003240<@0aQ00<<@088@003220<@0aP
008<H@04360<@0PP340436000a1Q364@HP0336800a1R368@HP024680111S468@@A1Q0`aQ00@<H0aQ
364<H@<<H0<<H@8<@@4<@04<@@0000<aAcE6=DL00SE723E60cEW00<eASE7=DL00cE70SE80cEX0SEY
0SEX00<eJCUX>FP00cU70cUW00<iJ3UW>FL00SUW13UX00<iJCUX>FP00SV800@mR3UX?FLmI`DmR08m
I`XmR0LmR@=1R@0:?HQ1QT67?FPmRDG;CRaFJdh/CP`2DP`4CPd01dh>DRe>;Dh]CRa>34h/00AB;0=F
:`03DRaF;5H/009B;003EReB;E8]009B;@03EReF;5H/009F;0AF;@03ERaF;EI=00=F;@03ETiFCEI<
00=FC@06FTeFCUI>ETiFCEI>0eY>00=FCUY>ERh00UY=0UY>00AJCEI>ETiFCP9JC@=JC09JC@07FTiJ
KeY@FU1JKei^FVl00UY`00=NL5j@GY000UjA00ERTF:aHY9RTV:b009R/@UR/P=R/`AR/P9R/@AV/P04
I]9RdV:bI[82I[401FKBI[9VdVJbI]400VJb2FKB36KC16KB01]Vdf[cLcAB<2RW924e9f:?Lc5[4F[c
KaA_4VkbHY1RCV9_J]1c<6/AEVl/i@P11008011Q44000Q1Q0QB201XLY233668@@Pa2228<8@a1324@
@QbT564000`P=BHmACd4>>@m0ccQ984<00`P684LXAbR0QRQ01hDHAR27:<HHQ0P660]92SS2004010P
660LPB21::0mHdh7ETT`i10S<DU:2eZ>GV]F2UHZGVaVZTh<96D200001BcRCP=BJ4GT78000P0000/D
I46[GZm_<WMaIa9VlEI_@LT]1QA200@00007304HHR2T:>HaB47<CRh00UY_00=R[fKAI]400V:b00=N
TejcGY<00V:d00eNTeYbFW9BLTX_ANhm[3EZ:>LTY2225484000400004PP0660ThSEV@LU:;59?FY5R
dVKaIa5[4F[`I]1NdE9>=FXDQ@800006584PhbDS;B<Ti@a30P0000LT`DGUHXYcC6/`Ja9Rd@05G[00
0ej@G[1N/004GY02GXl2GXh02Ui/FTaF:e8/HVa9bb241008011111100`a000<@@0a034001@a000@@
@111444@H@h@HP03464DPA1P00@@H@8<@0@@H@@@HP8DPP03564@HA1Q00<@H@03468<HQ1R008@HP04
464DPAB248824685464246800a1Q468@H@034643468246401110464DPQ1Q0Pa0111Q0Q1R2Q1Q00@<
HQ1R444<@@8<@0H@H@05364@HA1Q464<@@0236400`a1368<HP06468222400a11464@HP0246824645
468246401A1R464@@A1Q46800Q1Q0Q110Q1Q00@@@@a0340<HP8@H@09564@HA1Q444@@0aQ360@HA1P
00<<H0<<H@03464<H@aQ00<@H@03344<@Q1R008@H@03344880`P00D@@005444@HA1Q468@H@023602
34001@a1364<H@aQ36800`a10Q1000<<@110340020a100<<@0a1340010a00PPP0P`P0`PP00<<@0aP
36001@aQ00P@HAB2584@HA21488@H@aQ0PaR00<<H@aR36800`a20`a100<<H@aP34000Pa000<<H0a1
34401`a10@aQ0@a100000c57=DHeAP03<DL2=DH00cU6=DHeAP02=DH013EW<DLeIcE61CE700XeB3EX
=FPeJCEX=FTeJ3EY>FPeJ@8iJ003>FLeJ3EX00<iI`03>FPiIcUW008iI`@iJ003>FTiJ3V8008iR08m
R003?FLmR3f800@mR08mI`LmR08mJ004?FLmR3f9?JT5?HT3@HT2@HL01d68?FPmRDG[ET]BCDh=009B
3004CPe>34h=CPd4CRd014h/CPa>;4h/0e8/0eH[00AB;5H/ERaB;09F;@AB;@03EReF;5H/009F;0]F
;@03ETeFC5I=00=FC@=FCP03ETeFCUI>00=FCP03FTiF;UY>00AJCP=FCP05FTeJCUY<FTaJC@02FVd2
FTh2FTl025i_GVeJKUY_FW1NL5jAGY02GY42HY42HY800f:bH[5R/P09H[83H[<4H[82H[44I[83H[80
0fJbI[5V/@07I[42I]83I]<016KBI[9V/VKB36KC0VKB0VKC00mZdflEJ_=B3bB6700i9VKALc9ZdVKC
J_=_56lELcH00WMG00MgEW=DNkUgDDF[3288000256801Q1R464@HAAR588LY08Pa@0=468<@P`R324<
80PP448PaQAR100802SV@DD00SSR00TdhCC2884<00PP688LPAbR68800QR10QR300@<80P0300@@08P
P00?8:8iJ4h/DVmBCeY]HVaRJUXX980@@beZBReNSeY;009F:P0NGX]NS5k@BNd@8@00841JSG>bKdiV
kd6/98880000744iS5JCJeMcUW^hLgE_=UjBBS4m[RT976<@00P00`0001H@81AQ664LXb34:>H]1S4W
<DTiRcf/>H/eJSV<>HdeSC5/;DXPiaR5348400@00003560Q1S59008iRP0:ANa>CUJAH]5W4fLDH]=N
/5Z?EW02EW4014h_>HTaJBCV0P00018<@ac76>LPiAbS200000@08<@mbe:?H/a[3f[^I/mR[V:?H[05
G[05GY0025jaGY1NT5i^GVeNJeY<FR/2GT/013e742<400`P0Q1P00<@811044001@a00Pa100H8@@a0
320<@110464236434682464346800a23568@HP0346800a23484@H@07464446800`aR468@HP024680
0aB1464@H@0246833682468246401A2248<@HQ1R3680111Q00<<HA1R36400Q1Q0Q1R00<@HA1R4680
0a1R0a1Q00<@HQ1Q46401A1Q0Q1R00<@H@a046400Q1Q00@DHQ1R464@H@<@HP8@@@L@H@03468@PQ1R
00@@H@<@HP05368@HPaQ468@PP0346800a12444@H@03468246400`a1468DP`02468646400a1R568@
HP0246424680111Q320@@@aR1A1Q0Q1R0`aQ0PaP0Pa030aQ00<@HA1144400Q1000P<@0aP340@@111
440@@A100Pa000<<H0a034000Pa10`aQ00H<HPaQ344<@@aP460244001@a0344<@@a134800`a100<<
@0a134400Pa000<<H0a034000P`P00<<@11P36400PaQ0a1Q00<@HQ2248800a1R00<@PQB24640111Q
0PaR0PaQ1`a100<<H@aP36000`a020a10PaQ0@a2000012e7=DHaAS560S5713E600<eISE6=DH01CE6
13E70SE800LiIcEX=FTeJCEX>FPeI`05>FP;>FL00cUX?FPiJ002>FP2>HP00cUW?HPmR005?HP4?FL2
?HP013f7?HPmR3eX0SUX13f813f9146900U1Qd68@HM1ZD69ALU>2Dh<BPd00dh<00AB34h/CPa>3@9>
;@08CPa>3Dh<CRa>:dh/DRaB309F:`=B;09B309F;003DRaF;58/00=B;0EF;003EReF;5H[009FC003
ERaF;EH]009F;@EFC003ETeJCEI=009FC@04EReFCEI=ETh2ERh5FTh3ETh00eY=FTiJC002FT`2FTd2
FTh2FTl01UY>GVeJKUY^FW1NL09NT005GY5RTF:AHY5RTP03H[47H[83H[47H[82H[43I[8016:aH[9R
/V:a26Ja00=VdFJaI[4016KB16Jb16KB00=V/VKBI]801FKC00=VdVKCI]<00VKC00U_5VJbDNh/YR@P
@FIVl6lcJ]8016KC00iZlf[dI]9Zdf[dKa5oT4h>76D<0A1158<DHQ1Q0QAQ01TDHQB27<<PY11R3248
8Pa1340400`P8<DHP`00100TaD54?>0m0CdR=<8THA0P444HHP0368803AAQ440@@P`Q100801R1<B@m
QD77DT]R[6[]009Rc@09HZaVRUhYERPa10`Q468a9Dh;009RS003GX]JC5Z<009JS@0O@N`LHP00;>=V
l7n`Lg5gM6[@ERd]2@0100040SU[FVi[47=cLgEcMg=GKcIZlfJ`DRi1bcf:<DLP`aQQ3200100000/4
010P440<@1R28<@TiAbV56@88P@100D0000G100T`3E2?JI>:eI_HZmVcf[aI]1R[eZ@FVmFKeI@DRmF
Kej@DW163SV/:BTDQ00400000`a234<<@`0200002AQQ?HMBBej<I^e[46/AI]1R[`02HZh01V:?HZmN
/5j`GY1NS`=NT0=NS`0=GY5NSei_GVeNC5i;FR]F;5i<FT`e1@`R10000Pa000<@@0`P44000Q1000<<
80a044001Pa00Q1000<DHA1R46400Pa10Q1Q1A1R00H@HA1R468<@A1Q468646400aB25:<DPP044640
0a1R464<@@054642468336824684464346844642364234001A1Q468DPa1R34000Q1Q00<@HQB34680
0a1Q0Q1R00<@HA1R46403A1R00H<@@aQ444@@A1Q46864644468246400a1R588DPP0546800a21364@
HP024686464746801a1Q468@HQB3588DHQ1R00@@H@04588@HA10444546401A11340<80PP34400PaQ
00D@@0a0340<H0a1008<@08@H006464@HQ1Q360@H0a00Pa100<@@A1044000PaP00P<@11P440@@0a0
440<@0aP1@a000D<H11Q464<H@aP00<<@00;460<@0a0240<80a1464@P`aR344<@00222001P`P340<
@0a0364<H08@H0@@H@8DPP8@HP8@H@03488@HPaR008<HP8<H@04344<H11P3609340334400`aP340<
@002340;34400006<DPeAc57=DLeIc581CE70SEW13E600<eAcEW=FL00cE800@eJ3EW=FPeJ08eJ@03
=FPiIcUX00<iJ003=FPiJ3UX008iR@03>HPiJ3UW00<iJ005>FLmJ3eX?FPiI`02>FP3>HP01cf8?FPm
R3f8?HLmR46800DmR003@HPmR3f800<mR@DmR0<mR@04?HQ1Z468@HP3@HL02T68?HQ1QTGZAPa:3Dh=
CPaB358;0dh<0Th=0dh<0dh/00E>358<DPaB;5H[00AB;09F;0EB;004DReB;58/ERd2ER`00eH]ERaF
;007ERd5ET`2ETd00eI>ETeFC@03ETd7ETh01UI=ETiFCUI>FTeJCP9JC@03FTaJCEY=009JCP9JC`03
FTiNKEY^009JL005GW1NT5jAGY5RT002HY4016:BH[5RTF:A16:a0ejb00=R/V:aH[8016:b00IR/f:b
H[9R/V:aI[85H[88I[43I]42I[42I]801fKCI]9V/VJbI]=VdVJb009VdP9Vd`04I]9VdfKCH]<5I]<3
I]@01fJbDNdi1bQ0BJMRd6lC00=Vd`05I]9VdfKCI_AVe002I]<02FkbMe9NT2cX428<8Pa2344@@@02
56403AAR468DHQA2448400@1224<8000440LXaQR0080000>9<E5QT4T>@=1ISSR988@8@`068<LY11Q
344880<000087:8aR47ZDVmJSV:]HZaVcP9R[@0gFXeJK5Y9GTQNBDW[640000`Q;BI5bEI_ETeBCEI]
H/iNkU/BAR`D00009:5NT7>iLiEo^7=gKeUFM34Z400001@09<Dmc4iaH_AW=FKbJ_=ZlVKCI]9R/EZ@
EU1><47]@J/iRSUZ<DPaAc58=FT00S5Y0Re800<LY`@100000`0000L402C3=HU1je9`GXmRd003H[00
3ej@FY1JSeY_FY1JKe9>ETiNSf:?FW4mcC5[8>P40@06000030PP8:<iRTi@FY1VlFl@Kc9Zkf:_HZiN
S`=RSP03HXmNSej@00INT007H[1NSej?GY1NL5Y_GVh00Ui<00EJ;5H<GTiFCC3U00840004340@@11P
460344000``P440@@00334002Pa1464@@11Q560DPA22464<@11Q3A1R211Q0Q220Q1R0QB20a1R111Q
0a1R0a2200@DPaAR464@H@D@HP8@H@05340<HA1R368<H@0246434680111Q468@HQ1R0a1Q0Q1R00<@
PQ1R46802Q1R00D<@@aR468@HQB2008@H@03440@HA1Q00@@H@L@HP8<@@03488DXaB300<@HP04488@
HA1R36834683464:46800a236:<DP`044680111Q468DPQB21A1Q00H<HA1Q464@@@a1364236823642
4442344010aQ368<HA1P0Q1Q00D@PQ1R364@H@aQ00@<@@@<H@07460@@0aQ364<@@a036000`a000@@
H@aR364@H@@<H@03360<@0aP008<H08<@@03440@@@aQ008<@@06340<@A11464<HA1Q0Q1R00D@HA22
58<DPaB2008DX`0458<@PQ1R4682464246800`aR468<HP043640111P340@@0a00Q100`a000D<@@a0
340<@0a100D<@0/<@@0000<aB3E7<DL00S5700<aB3E8=DP00SE713E600DeIcE7=DLeAcEW008eB08e
B@04=FPeAcU8>FP2=FT3>FP013UW>FPiJ3UX0SUY0cUX00<iR3UX>FP00SUX00@iIceW?FLiI`<iJ0<i
R0<mR0<mQ`03@HPmR3f800TmR08mR@03?HPmRCf9008mR@04?HQ1Z46X@HP2@HL03466@HM1R467?FM5
ZDG/BPaB;Dh=DPaB2`9>2`03CPa>3Dh=00A>309>;003DRaB358<009B:`=B;09F:`03ERaB;58<00=B
;004DReB;5H]ERd2ER`01UH[ERaF;EH]ETeF;@=FC0=F:`UFC09FC@IFCP04ETeFC5I=ETd2FTd2FTh0
1UY=FTaJCEY=FTiJC@=JCP05GVeJKUY_FW1NL002GY000ejAHY5RT@07HY44H[400ejbH[9R/P05H[80
15jcH[9R/V:b0f:a16:b0V:a0fJa00=V/6JaI[400fKA0VJa00MVdVKAI]9VdVJbI]9Vd`05I]800fJb
I]9Vd`04I]<03VKBI]=VdfKDI]=Zm6kcEN/mAc2P@HIRd6/DI]82I]<00fKBI]=Vd`02I]<2I]@03V[B
MeAVld7=78H40PP2200<81AQ568@HQ123242200020PQ100480@0200HPBd66882000032cUBHI5ACT5
?BHhhb11200<01QS46880080000:320LPBdUANYJ[F/;H/aR[EY/FV/2FV`02EY;FV]JJeY:GVURZUj=
?HH4000200005`P0;><mQdWZEViN[VL?H`i_:eI_78<00103BPi[36/AKeA_=7<cJ_1JC3UY52800P00
00H@02ST@LYB;EZ?I]02I]800fJbI]=Vm002JaD037<fMeMgEWLdLc9_4UjbCRi1bcDW88<40080000;
220e@dG5DRYRSFK^Ja5RdF;BH[=N/`02GY8036:bH[5N/V:aH]9R/Ej@H]1FTDX<<DL@H`H0000;344Y
0cfXDTaNSFK=I/m[4FKbI]5R/004GXl3GXh2GXl7GY02GXl01Ej>GY1NL5Y_GVh00UY=00UF;EH<ERi=
k2c4000400a044000a1P0Q1000<<@0`P34000Pa000D<H0aQ440@@11P008DH0@@H@03468@HA1R00D@
HP03588@HQ1Q018@H@8@HP03564@HA1Q00H@HQ4@H@03488@HQ1R00D@H@03344<@11Q00l@HP03348<
@A1R008@HP07464@H0a0464@HQ1Q46000QAQ1a1R0PaR00@@HQ1Q58<@PP@@H@<@HP05488@HQ1Q464<
@@02464946800aAR468@HP0234401A1R464@HA1Q46800a1Q00<@HQ1Q44000a110`aQ00<<@@a04600
0a1100D@HQ1S368<@11P008<@004440<@0a0340236400`a1348<@P0334402`a0460@@11P364<@@a0
360@HA1144000PaQ00<@HA11340020a00PPP00@@@11P464<H@8<@@8@H@03568@HA1Q00<DPP03488@
HQ1R00<@HP04368<H@aQ4644364010a1440<@@a10PaQ0`a000<<80a044003Pa02`a100000be8<DLa
A`02<DL3<DP00cE8=FLeAP02=DH2=FL2=DL2=FL023UX=FTeBCE9=FPiAcU8>FP2=FT3>FP00cUW>FPi
J002>FP013UY>HTiRCV91CUX0cUW00@mIcUX>FPiJ08iR004>HTmR3f8?HP2?HL00cf8@HQ1Q`05?HP3
?HT3?HP013f9?HPmR3f80cf900@mR46X@HQ1R091Q`0:@HQ1Z46W@HLmIdG;ANa>;TX=DP`2DP/00dh;
CPa>3002CPd2CP`3CR`00e8/CPaB;002DR/00e8/DR]B;008DR`0158]DRaB;5H]0UH/00=F:eH/ERd0
0eH]00=FC5H]ER`015H/00=F;EI=DTd01EI<15I=1EI>15I=15Y=0UY<00MJCEY>FTiJCEY>FViJK@02
FVl015Y`GW1NT5j@0UjA0f:A00=RT6JAHY4016:A0V:a0Ujb00=R/f:bH[800V:b00=N/UjcH[<00f:b
0V:a1V:b00IRdFJaI[5V/FJ`I[43I]43I]8016KAI]9VdVKB16KC16Jb00=VdV:bI]<00fKC00=VdVJb
J[800V[C00Q^m6J`FRi=[D5XBLURlfKd0fKC00AVdVKCI]9VdP=Vd`0BI]5_4V/DG[4eJP`Q100800@0
220<@@PP32440000200880PQ0P@000@<83eVCRX]9P84000:;>I5QSdT>>Di1SC3620@01aP<>82;@@0
2CD5@HU>;Ej>J_9[4F[`HZeNS008FV`01eY;FTYNS5j^FXi63AQQ00<0000h200PPSUYBRiN[f/@Jbmg
^5ZB9:D400`0?HaFTV;@I_5Zl6lBJa9Zm5i`ANh/a0@0000<02d4?La:<5ZBH[5VdFkbKcAcEWNINiYg
VFlfJ]AN/eZCAL`a9AQ0100801Q0<BQ63UJBI_5[3g<bLc=_509Zl`=Zm003JaEZmV[e009Ve007H[5B
LTG_>J`eJbDX68<01@0000/<@2TU@LYBKf:_Kc9c<VlbJ_5Vd6:_00MNS`=NSP03GXmN[ej@009NT0=N
S`=NT006GXmNT5Y`FW1JKeY>0UH]00AF34h_@JXTa@840004344<@0a0460246400a1P364<H@033402
34424403560346424882464346800a23488DP`0446800aB2464@H@0246400a1R464@H@0446400aAQ
464@@@0246400a1R464@H@024642468258<00aAR444@H@02464246824640111R464@HA1Q0Q1R0Q1Q
00DDXaB2588@PQ1R00@@H@05468@HA1Q464@HP02344;46800`aR468@HP02468746400aAQ468@H@02
46801aAR468@HQ1S48<@HQ1Q00L@HPD@PP05568@HQ1R48<DPP0346800a1Q468@HP0346800a1Q468@
HP0246834645468246402P`P340<@0aQ468DPPaQ344<@1100Q1100@@HA1R488<H@<<@08@@003464<
H@a0008<@@03348<@@a1008<@@03440<@0a0008<@003364@HPaQ008@H0D@@@8<@@<<@004360<@0PP
3402364246024643468356800aAQ464@H@0446433642368636400a11440@@@043442364234423400
0`aP340<@004340336400`aP340<@00234000`a1340<@005340144013400008aA`<eAP04=DLeB358
=DP6=FL2=DH02SU6>FLiAcU8=DPiB3E8>FLiB3UX0SEY00@iJ3UW>FLiI`DiJ005>FLiJ3E7<BHeI`03
>FP4?FL2>FP3>HP00cV9?HPmR002?FL01cf7?HQ1R3f8@HLmR468008mR0<mR@PmR08mR@8mR0M1Q`06
@HPmR468AL]>3E8<158;14h<00EB34h<DRaB;4h/00=>3003DPaB:e8;009B:`03DRaB358/00AB;003
CReB;E8]009B;@9B;009ER]F;5H]EReFCEH]ETaF;EH/00EF;@04DRaB;EI<ER/7ET`00eI=ETiF;@02
ETh2ETd2ET`6FT`00eY=FVeJC@02FTd2FVd2FVh015Y`GW1NL5j@0ejA1F:A00ARTV:AHY5RT@9R/@9R
/P03H[=R/V:b009R/P03G[9R/f:c00=R/P9R/@AR/P03H[5R/V:a009V/@03I[1V/FJa00IV/@=Vd@04
I]9VdfKCI[<2I[82I]82I[800fKBI]=Rd`02I]<2I]802f[BI]=V/fZaHVaJ<4fa@FYF2fKeI_@00fKC
00=VdVKAI]800VKB0fKA00IVlF/BKc=N[SV8524400001`@0200400P0320800`P008<8@0D561=iU8W
>DD800@0;<E5ICd3>>De1S2S940dhE9<J/]Vc6[?J/i^k`9c<P09J_9ZlfKAGY1NSUj<FV]JC5Y]00=J
K0=JC008ETaJK6:/FVe>2SeV8:4800<0000V788/i3U6BPaFKej_BS0PRP01108a2Th^Ja5cDf/cJcE_
EGNENgEgDF:@BL`hhbB110080RS5>FQ1bTh]EViN[UI_BRlmc3V:;BT<8P800007:80m84W6GVabkgMb
Le@00WMg015gEW<fKcI_=flFJ]AVdf[cJ_9N/Dh`ALe1c3f:<BHPYA0R00H00009780iHdX9EVeR[Fl>
Lc1_4F[`009Vd003HZmNSUj>00MNS`ENSP9NT004GXmNSUj?GXl3GY000ej?FVmJK`02FVl2FTh025Y=
GVaBCceY68<800PQ4405340020aP340<@0a0460@HA10340244001A1P464@HA1P46400a2100H@HA11
344<@A1Q4682464446801AAQ464@H0a046400Q1R1A1Q0QAQ00D@HQ1Q464@HA1R008@H@03340<@A1R
008DPP08568@HA1P340@HAB2468@H@8@HP<@H@04364<@A1Q46425882468246401122464@H@aQ111Q
2Q1R0a1Q111R00<<HPaQ46002A1Q0QAR0Q1R00@<HPaQ484<H08<HP033448@@aQ008@HP03364@PA21
008@HP04568DPQ1R468246401a1R464@HA1P444@HQ1Q00D@HP03464@@A11008@@@<<H@03360<@0a0
008<808<@08@H@03460@@A1000D@@005344<H110440<@003440334401111344<@@a120a000@<H0a0
460@H@<@@@05344<80PP2008800336033644464258801AB3488DPQB246800a1Q0a1P0Q1Q20aQ00@@
@0aQ364<H@8@@08<@0D<@@0334<<@A1P00@<@08<H0D<@@03340<H@aP00D<H005340880P0220@H001
3600008aA`<eAP04<DLeAcE7=DL4=FL3=FP00cEW=DLiAP04=DL01CEX>FLiJ3UX=FT013UX00DiIcUX
>FPiJ3UW008iJ003=FPiJ3UX00DiJ004?HPiJ3f8>FL2>FP3>HP00ceX>FPmI`02?FL2?HP00d68@HLm
R003?HP3?HT>?HP4@HL02d6X@JU1ZCf8@JU5jdh;DRa>2e8;DP`00Th<00M>3E8<DPaB34h=CPa>;@02
CPd2CP`01Dh[CRa>;4h/DR`00e8<0e8/0Th]1E8]1UH/00=F:eH/ER`00eH]00AB;UH]DRaB;@=F:`9F
C004EReF;5H/ER`4ETd00eI>EReFCP02ETd015I<FTeJC5Y<0eY=00QJCUY=FTeJCEY]FTeJCUY^0UY`
0Uj@1EjA0f:A00ARTV:AHY5RT@9R/@04G[9R/UjbG[84H[800f:cH[9R/P0;H[8016:aI[5V/FJa1FJb
00=V/FJbI[800fKB2FJb0VKC0V;C0VKC0VKB0VKC00QV/V:?FU5J<dV;CNaRmFKc0fKC00=VdVKAI]40
0fKB015VdFKBI]5[4fldKeIN/4G]=DTPPQaR9>@iIS3T544400`0008<800M344801AP:>@mIb2S300@
8332AFDm0cST=@D/PC20ERQcKgNAMgAc=G<dLcE_=6kcJ_=VdFJaH[5N/@02GXh01ei^FViJKUY]FTaJ
CEY<009FC00;FT]JBUi/GVeJKeI`CRlmRbd58808000200001A008:0ThbU98:L00`0000DPY3V]APm>
LUJb009J/`07G]ENe5ZeES0la33310001@000Q1P00<<@0000000100000<H82a0BJT00UZA015R/V:a
G]5NT5I@DRmF<59ACU9:4D7?>H`eJRdV8>DLPP`P00H0000<100H@C4X@NaBCf:_J^icDgMDLeEZl6:^
0V:_00=N[ej`GY000Uj?0ej@00=NSej>GXl01ej?00=NT5j?GXl00Uj?0ej@00iNSeY_FVmJKeY?FTiJ
CEI<GVa>;SU9444400`Q0Pa000<@@0a0340020a000@<H0aQ460@H0P@H@03444@HQ1R008@HP8@H@@@
HP<@H@8@HP04368@HPaQ364446400aAQ588@HP0346400aAQ464@HP024680111Q488@HQ1R1Q1Q0Q1R
00DDPQB3468DPa1R008@H004484@HA1Q364234001@aR468<HPaR36400a1Q0a1R00@@HA1R468@HP8@
PP8@HP06464@HQ1R468@Pa220Q1R0Q1Q00<@HQ1Q46400Q1R0Q1Q0Q1R00<@HA1R36800PaR00H@HPaR
368<HQ1R368236444640111R464DPQ220a1Q00P@HQ1Q464DHA11464@@A1Q1Q1R00<<@Q11364010aQ
00T@H11Q464<H@a1340@@0a044000a1P0a1010a000<@@11142000a1000@<@0a1340@@@<<@@H<@08<
@@8<H@8<@006344@@A11344<80a00Q1R0Q1Q00<@HQ2258<00Q220aB21a1R00D@HA11364<H@a1008<
H@8<HP04468<@@a13442364334400`aQ440<@002340434401@a0344<HPaQ46000Q1000D<@11P440<
H0a000<<@@8<H003364<H0Q00088@003340880PP0088804<H04@P@4DP`0000<aAcE6=DH013E60cEW
13EX0SE800PeIcE7>DHiASUW>DLeAcEW13UX0SUW00<iAcUW>FL00SUX00<mIcUW>FP043UX00@mJ3UX
?FPiJ08mI`05?HPmJ3f8?HQ1Q`09?HP00d68?HTmR002?HP01cf9?HPmR3f7?HQ1R3f800=1R00:@HM5
Yd68@HPmId5W@JQ9jU8;DPX2CP/00dh<DRa>3004DP`01E8/CPe>34h<DP/00dh<00=B358/DR/00e8<
1E8/00=B;E8/DR`00UH]0U8/00IF:eH/ERaB;5HZDR`3ER`00e8<ERiF;@02ER`2ER/015I:ETaFC5H/
0UH]00=FC5H/ER/00UI<00AF;EI>ETiJCP=JC@=JC09JC@05ETeJCEY=FTeJK@02FTd01EY^GVmNL5Y`
GY001EjA00ARTF:aH[5RT@=R/@03HY5R/F:b011R/P=V/P=R/@9V/PAR/P04I]9V/VJaI[45I[83I[40
0fKBI[9V/P02I[87I]<2I]82I]<01V:BFU5F44V;DPmRe0=VdP03I]=VdVKB00IVdP03I_9VdV[c009_
500PKa=ZdVZ`GY1N/7<_FY8XY@@0300<8110444@@0`P200<010P764``STS@D=10SSS=@@/P2Q0IX=g
K7^BKc9[4`=Zl`0:J_9VdVKBI]9VdF:aHZmNSei_FVl2FTh2FTd00eY<ETaFBP02FT/04EI;FTaNKF:>
IZeZcV[=IZaNC4gZ?FL/i22Q640@@1@P4000100000/40AA27<@U224958LHZ1B676<P@A0000@00007
420PX2CR8>8HXAAP42000`@001<@@B22::@XaR2U8<HLQ1R36:<HXQR378<LHaA244<<8`@100040002
20004`@000000000100PX3E4AJQB;6:=K`mgDgMdLeAc=F[dI]=VdV:a009R/09NT005GY5NT5j@GY1N
T@02GY000ej?GXiNSP0;GXl4GXh03Uj?GXiNKUY^FTeFC5I:DPYJC58^=@L800@02203440:34000a1P
464@H002460346401A1P464@HQ1R4640111R00<@H@a04640111R00<<@A1Q46800Q1R0`aR00<@HQ1Q
46400Q1Q00<DHA1Q46400Q1Q0a1R00<DHQB358800a1R2Q1Q0QB200/@HA1P460<H11Q364@H@a1364<
HPaQ0088@003368@HA1Q00H@H@05468DPQB2464@HP06464546803AB2468DHA10320<@110468<@Pa1
364<HPaQ008<@@8<HP<@HQ<@H@8<@@03348<@@aQ008@H@<@HP0:348<H@aR364<H11P360@H@a03442
340234400a1Q460@H00246000a10340<@00334001@`P440@H11Q44000P`P2Pa00``P00<<@0a13400
0Pa00Q1100D@HA1R468DPaB2008@HP03588@PQ2200H@H@06444@H@aQ340880a11@aQ00<<HPa23680
1@a100H<H@a1344<@A113643440234033444340244000a1P440@@00244001@a0320<80a024000PPP
0P@P00<000@034000a1P00<DPAS36<@00ASV00000c57=DHeAP04=DH3=FL4=FP01SE8=FPeB3E8=DLe
I`8iI`03=FLiIcUW008iJ003=FTiJ3U800<iJ08iI`8mI`03>FPiIcUX00<iJ003?FPmIceX00DiJ004
>HPiJ3eX>FP2>FT01CUX?FLmJ3f8?FT00Sf91cf80Sf90Sf800<mZCfZ?JX00SfZ00<mZCf9?HP00cf8
1D6800i1ZDFY@HU5R4F7BLU:2dgZDPY>2e8<DP]B358;0U8<00=F;58<CPd024h<1E8<00E>358/DRaB
358=00=B3004EReFCEH]ER/2ER`00eH[ET]FC003ER`00e8<EReF;@02ER`00eH[ERaFC007ERd015H/
ETaF;5H]0UI>0UI=00EFC5I=ETeFCEI<009JC@=JCP05FTeJKEY=FTeJK@02FVl015Y`FY5NTUjA0ejB
00EN/EjbH[5NTF:A00=R/@04GY5N/EjAH[42H[87H[45H[82I[84I[400fJbH[9R/P04H[801FJbI[5V
/FJbI]8016Jb00=V/FKBI]800VKB0VJb0VKB0V:c00eVdf;CI]AVdfKBI]=RdejAEPm9[D6;ES1Re002
I]<2I]800fKAI]9VdP04I]809VKCI]9VdV[bKa=_57<DLcIgEg=hOmYkeV<B;<@80100300@8A113208
01A0640LHSC1AFE=adV4A@0hhC31:60X@5XULg5_<VlBJ_82J]82J_801f[cI]9VdfKBI[9R/6:?00=N
K`03FVmJKUY>009FC@9FC0AF:`05FV]NSFJ_Ka5c<`02MeD02g<dJ_9V/F:@GViNCEH^BRm:DCg=6:@0
100002<<AAc/:DhiSCEW?HU1ZTG<BNeFCei^HXiR/6[cJa=RdEY^ETiFCe9@CRi:3D7<?J/iRS58;BLY
1BCT9@DY1bTW9>@LHP`P00880003324@@QAR00<<800>200D@3E5CReRcf[_Lc=gEGMFLcEc=6lBJ_9V
/PAR/@05G[5NSej?GY1NT@06GY04GXl015j>GViNSUj?15j>00ANKUi_GViNSPENKP0;FTeFC5I<ERYB
2UX[DRh/iP00100<800244001Pa0460@HA22464<H@H<@005460@HA1Q488DPP025640111P464@HQ1R
0Q1Q0QB200@@HQ1Q440@H@D@HP05464@HQ1R48<DP`0346<2468646401QAQ488@HQ1Q564@HP8@H@03
564@HQ1Q00`@H@03440DH12100<@H@8@HP03368<H@aQ008@HP8@PP03468@HA1Q00@@H@04468DHA10
4448464546800aAQ440DH@02464234494680111Q468@HQ1R1Q1Q0Q1R00<@HA2246401A1Q0PaR00@<
@Pa1364<H@8@H@<@HP04368<H@aQ34024602364334401@a0344<@@aQ46400Q1P0Pa000<<@@a03400
0Pa000H<@A1Q464@HA1P44024442440010a0344<@@a10Pa000@<80a0464<H@<@H@<@HP8DP`/@HP8@
H@04364@HA1044443642368336400`aR364<@@02344010a2344<@@aQ0Pa10Pa200@<@@a0344@@08<
@0<<@@8<H@8@H0<@@08<@@03340<80PP00D88006200<@11P6:8H`ac30QcT00@TiBTU:BDQ104QB000
00<aAcE6=DH00cE600@eAcEW=FLeI`@eJ0@eB003=DLeIcEW00@eI`8iJ003=FTiB3UY008iJ003>FLi
J3eW008mI`DiI`03>FPiIcUW00DiJ003?HPiR3V8008iJ08iJ@03>FPmIceX008mJ08mR@8mR003?HLm
R3f8008mR006?HTmR468@HQ1ZD691Cf90cf8246800U1ZD68@FM5Z4G9BNU=jDgZBN/014W/14g/0dh<
00=:34h<CP`00dh;0dh<00EB34h<CPa>358<00=>3@=B3004DRaF:e8;DP/3DP`3DP/00eH/DPaB;003
DR`2ER`3DR`4ERd00eH/ER]F:`03ERd015I=EReFC5H]0UH/1UI<0eY<0UY=00IJKEi^FW1JLEjAGY04
GY400ejaGY5NT@0<GY4016:AGY5RTEjA16:a0V:b0VJb0fJa0V:a1V:b00AV/VJaI[5Vd@9VdP06H[9V
/VJbI[5V/VKA0VKB16Jb00=V/fJbI[<00fKC00UV/VKBI]=RTEiaDPiF3UjBI]@00VKB0fKA00MVdVJa
I[9VdVKCI]9Vd`05I]802F[BJ_9Zlf[cJa5gLV;>@HTL8002200050@0200@@AR28:8X`b2S<<99aUY/
FPM9@3cP;:0P82@PDNI_DV/CJ_85J]85I]801FKAH[5R/6:`GXl00UY^00=JCEI<ER`00eH[0UH;00]F
:eXZFT]JBei/GXiVdFkbKa=c=7<e009gEP9kMP07NiIgMG]dJ_5:3RCX00400P0000`eCcE`KcIod7oD
OmIoU7nfOkMoUWnHNiT2MgP0:G^HNiMkMg]fMgEc<flAK_5_4VlAI]1NSeZ`FXm:;C59<DLa8bSS788H
H1QQ564D@111200000`P>FE>:F:[Kbic<W=EKaAZlfKCI]9R/FJaI]800V:B0V:@00=RSej?GXl015j?
1Ui_0eY^1Ui^00=NSEi]GVd00Ui]00=JKUY]GT`015Y<00UJ:eH[ERYF2Ui:CL//aPP0320011100`a0
0PaP10a000<@@0a034000Q1P2a1Q00<DPA1Q46400a1Q211R0PaR1Q1R211Q00DDHA1Q464@HAAQ00T@
H@8<@003460@HA1P00@@H005360@H11Q468<HP024682464011B25:<@HQ1Q0Q1R2A1Q00<@H11Q4640
0Q1Q00<<H@a136400a1R00HDHAA0564HXQB1464346800a1Q468@HP0546400`a0464@H@0446434680
0a1Q564DPP05464246801A12348<HPa136400Q1Q0a1R0`a100D<HA10460<H0a000<<@@04440<@@a0
364336000`a0344<@@0434000a1R5:<DPP024602440434001@`P2208@0a03640111Q00<@HQB25880
0a1R00<DPQB358800a1R00<@HA1144400PaQ00@<@@a0344@H08@H@05440<@@a1364@@00836401A1Q
440@@11134400PaQ00<<@@aR34800Pa10Pa000<@@0a044000PaQ00L@@0a0340<@11P440<@0021000
30`Q220400@0220<@11P584HXAc28><U108Y9@8]A@05<DDeICEU<F@]A001:DL00007<DLeASE6=DHi
ASE6=DL00SEW1CEX0cE800<eJ3EW=FL00cEW13UX00<eJCE9>FT00cUY1CUX00<iQcV8>HP00cUX00<i
IcUX>FP00SUX00<mR3UX>FP01CUX00<iR3f8?FP00ceY0Sf913f800<mRCf8?HT00Sf900Q1RSf9?FTm
J468@HU1ZD6X0cf814680151RD68@HQ1RD6ZAJU1Ice5@HQ9jDgYCNY634G[ALa5k4W[009=k0=9k0=:
30E>3003CPe>34h<00=>30I>3@03ANa9k4h<00=B2`EB3003ER]B;58/00AB;09F;0AB;004DPeB;E8]
ER`2ER/6ER`4ERd5ETd02EI<ERaF:eI<FTeJKUY_FW1JL@02FY4025YbFW5JTEj@GY5NT5Z@FW08GY42
GY05GY401EjaG[9R/F:AGY400V:a00=R/V:BH[800f:a1f:b00=R/F:@GY000V:a00AR/V:aH[5R/@=V
/P9R/@=V/P9V/`05H[=R/V:BH[9V/`03I[801FKCI[=R/f:cI]<00VJb00=V/FKBI[800VJb0fJc16KB
0VKC0fJb0VKB00]Vd6[`J_9RT4F[::<H8100200<8111008LPP0?540XXDW8K^iVBDf4AD<d`1`0941F
1f/@J_5Z/F[B00IVdP=Vd`0<I]9RdV:aH[5NT5j?FTiF;EH/DRaB2dW;14G:00a9bTg:ERUJBei]HXiR
/6;BI]9Vdf[cJ_@2J_<03flCLcAc=7MgKeIW5dXa:@PD80P086Hm[UZAIaI_=P02MgL2NiP027]hMeMg
Eg<gKcMcEflfKcD2LeH076lDI[1NL5Y`DW5:;dH>>HX]9RC3760HH2CT=BL/Xa@Q20040000540]0d79
H/e_3flbI_1VdFKB0f:b0f:a00ER/V:BHY9RT5j@009NS`05GXiNSej?GXmNK`03GXl2GVl3FVh4FVl0
1Ui_GViNKEi]GXiNKP=JKP03GVeNCEi=00=JC00;FR]FC5XZFR]NBTF99:D80110460D@00244063400
0`aP440<@002440;46401`aQ464@HA1Q468@H@a0008@H@@@HP03464@HQ1R008@H`8<HP<@HP04464@
HQB25882564010a0464@PQ223Q1Q00<@@@a044001A1Q0Q1P0Q1Q0Q1R0PaR0Q1Q00<DPQB346800a1R
00<@H@aQ46400a1R00@@PaBS464@@08@H@8@HP03464@HQ1R00<@HP06464@@11Q464DXa230Q1R00<@
HA1R4680111R0Q1Q0a1R00<DPQ2246400Q1Q00<@HQ1Q46401a1Q0Q1R00H@@@a2368<H@aR36424640
0`aQ444<@@0234401111440@H@aP0Pa00`a10PaQ00<<@0aP36400`aQ00D<@@a0340@@111008@HP8@
H@04444<@0`P344246400a11464@H@02468011225:<DPaB30QBS00@DPa1R48<@P`H@HP8@@@8@H@8@
HP@@H@8<H@@<@@03440<H@aQ00H<H@08464@@110340<@@aQ360<@@<<@P<<@@L<@0<8800I340880`P
340@@1R26:<LY1c49@DY1BdU;DDaICF6<FHaA35U=FHaIRe4<D@aI354;D@00Be800001357=DHeASE6
0cU60SEW0SE800<eJ3E8=DP00SEX00HiIcEW=FLeIcE7=FP5>FP013EY>FTeJSUZ0cUY13UX00<iQcUX
>FP023UX00<mIcUX>FP01SV800@mR3UY>FTiJ@8mJ004>FPmR3f8?HP2?HT02Cf8?HTmRCf9?FXiJCUX
?HQ1Q`03?HL2?HP00d68@HM1Q`05@HP01469@HQ1R4F70SeV00I5Z4g9CPY634H=ANd2BN`00dW[CN]=
j`02CN`014h<CP]>2dh;14h<00=>3Dh<CP`014h<0U8<0U8=00AB;E8=DPeB30=B2`9B309B;003ERaF
:e8/00AB;09F;003ER]B;5H]009F;@9B;P03DReF;5H/00=F:`9FC003ETeF;5H^00EJCP03ETiJCEY>
009JCP=JK`9JL09NT005GY5JL5I@FW5NT@04GY05GY4015jaH[5NTF:A15jA00ENLEjAGY5R/F:b00ER
/@03HY9RTF:A009R/@9R/PQR/@9R/P9R/@09I[1V/FJaI[5RTV:AH[5V/VKB009V/P=V/`9RTP05H[=V
/VJbI[9VdP02I[82H[8026:cI[9VdVKBI]=V/V:cI[82I[<00fJbH[5V/P02I]809FJcH[=R/fJcI[9R
/FKAI]9Vdf[dK_AZdFJ=CPdiAb23224400P0520@82RPCNUVSFI9CH==Y3SP820/P5hXJa5[4VJaI]9Z
df[B00AVdP=Vd`9VdP05I]5R/F:`GY1JKP02ERd015H[DNYAjTgZ0TWZ0TW:00I=bUH9GTaNKF:>I[03
I]84I]<3I]8056/DKcA_=7=DJ_5JC3eY78D40@0032<PYSf<FTmNLF:aI]=Zm6[DI]@2GY807UI@CPm5
cD6[>FPe9S4W9<DHQA1520488B33=FE5b58ZAHPdiBA2100001@Q?HUNJfl<Lbm[46/BI_9Vd@9V/@9R
/@9R/P07I[9V/f:cH[=RTV:aHY000Uj@00=RSej?GXl015j?0ej>0Uj?00INSUj?GVmNKej?GVh3GXd0
0ej>GXeNKP02GVh3GVd045Y]FTaJC5Y<FR]J:UX[FTXiAQA3100<811P440<80P01@a000<@H0aP3400
0Pa000<@@0a036001A1Q00<<H11Q46401A1Q00L<HA1Q464@HA1R464<@004464346800`aS46<@HP05
46401A1P564DHAAQ46800Pa16a1Q00@<@A1Q468@HP8@H@04468<@@`P344246400`aQ464@HP034680
0`aQ460<@002464021B2464@H@a1220<@A1Q4682444346400`aR468@H@02464646800a1Q444@H@0>
464246001A22464@@A1134800PaR00@@H@aQ440<@0<@@0<<@@8<H@09340<@@a1344<H111440<@11P
00<<H@03464<@@a0008<@004440<@@a1344234001A11464@HA1Q46801QB200<DPa1S46801A1R00H@
HA1R444@@@a13483444246401111464@HA1Q0PaQ0PaR20aQ00H<@@aQ364<HA10460344000a11364@
@00234400`a2448<@@0722002PP0100800PP460HPARQ7:8Thc4T0RdT00@]9C4T=DDeI@8eIP@]A@06
<FDaA355;D@]@c5S0S540Be700001357=DHeASE60cU60SE700<eJ3E8=FP00SE80cEX0SEW0SUW1CUX
00<iIcUX>FT01CUY1SUX00<iIcUX>FP01SUX00<mJ3UX>HP01cV80cV900@mRCf8?HPmR@8mR003?FXm
RCf800<mR@8mRP8mR@04@JLmZ3fX?HT2?HP00d68@JQ1Z002@JP0146Y@HU1RD690T6800Q5Z4FW?FI1
ITW9CP]63DX=0Th<0Th;00A>358<DPaB309>2`03DPaB2dh<00A>3003CPe>34h<009>3004DRaB358<
DP`2DPd00dh=DRaB;003DP`2DR`00dh]DRaB;00;DR`01EH]DReB;U8^DRd00UH/00UF:eH]EReF;EI<
ETeFC5H]ERh015Y>00AFCUY=FTiJCP9JK`=JL09NT003GY5NTUjB00=NTP05GY5R/F:AHY5NT@05G[80
1V:aGY5R/F:aHY5RTPAR/P03H[5R/V:b00=R/P0;H[5R/V:bH[=R/V;CH[9R/FJaH[5V/P02I]800fJb
H[5VdP02I]82H[43I[42I[801VJcI]=VdfKBI]=V/`=V]09V/`03I]AVdfKC00=Vd`03I[9V/fKC00IV
d`9Ve0=Vd`03I]9VdfKB00AVd`03I]AVdfKC009VdP0JI]=ZmFlFKcIc=W=GJaAN/DX>?HX`i1PP520T
P4FWETe=jDETAD@i0bA0;<1RJG=DKcA_50=Zd`03I]=VdVKC00EVd`0>I_AZm6[dJ_=Zm6KBH[5RTF:?
GV]NBUY;ETYF:P9F:`06FR]JBei]GXiR/6KA0VKB00=Vdf[cI]@00VKC00=VlfKdJ_<00V[c00i_57<e
NgQkVGMiH]A9kRd752080000400Pa34X0SV;020m[3E:;BPY1bCV7:<D80P0100800`P660Pa3E[@LiB
D6KcJ_9R/e7]>:8L01@0<>A5c5i_KcEgE7MdLc=_4f[b16KB00AV/FKBI[9V/P=V/`9R/P04H[5NT6:@
GY02GXl00ej>GXmNS`06GXl00ej@GXiNS`04GXl3GXd01Ei^GVeNKUi^GVd00eY^00mNKUY]FTeJC5H[
ERYJC5I;<@H80@@0320@@11P46401@a00Q101@a000<@H11Q46401A1Q00<@HQ1Q46400Q1Q00H<HA1Q
464@HA2258864643468346<01A1R464@HA1P34000Q1000<DH1AQ56800Pa100<@HQ1Q46402a1Q00<@
PQB346800Q1R2a1Q00P@HPa0464@HA1R444@81AQ0Q1Q00<<HA1R36800`aR00<<HA1Q46400a1Q00H@
HQ1Q468@HQ1146424444464010aR468@HA1Q1Q1R00@@PQAQ444<@@X@H@04444@HAB2588246401a1R
444@HQ12344<H@aR00<<H@04440<811044433442364434401@a0440@H@aQ46000Pa000P@@A1Q364<
@0PP340<HA1Q0a1R00<@HA1R46800Q1R11B3211R0`aR0a1R0Q1100D@HQ11444@@111008@H@04444<
@@aP3646368736434402464246002110444<@0PP344880P0220434004110340@H1AP688LXbCT;BD]
934T=F@eQCET<D@eA3540SE400<a8c54<D@00S5500@aIC5T<DDaA@DaI@4aA04aA`0000XaAcE6=DHe
ASU6=DHeAcEW=DLeI`LeJ003=FLiIcUW008iI`8eI`03>FPiIcUW008iI`TiJ0@iI`LiJ004?FPmR3f8
?HP3>HP5?HP00cV9?HTmR@02?HP01Cf7?HPmJSf9?HL00T680Sf900E1RD68@HQ1Qcf700@mR003@HPm
R4680091Q`91R0A1R@09@HQ5Yd5V@FM5ZE8;CRe>34g/00I>2`07DP]>2dh;CPaB2dh;DP/02Dh<1E8<
00A>358/DRaB2`=B3005DRa>;58<DP]F:`06DR`00eH/ER]B;002DR`0158]DRiB;U8]0U8/00YF:eH]
EReFCEI<ER]FC5Y=ERiF;@9JCP=JC@9JCP03FTmJKeY`009JL004FVmNT5jAGY44GY800f:aH[9R/@02
H[42GY401EjaG[9N/V:aGY000V:a16:b0V:a00=R/6:aH[400f:b0f:a0f:b00AR/FJaI[5V/P9V/@03
H[5V/6Ja00=R/@9V/@03I]5V/VJb009VdP06I[9VdVKBI]9VdfJc0fJd00=V/fKDI]<016KC0VKB00=V
/VKCI]<026KC0fKB0VKA00=VdVKCI]<016KC0VKB01YVdfKDJ_AZmF/EKaE_=W=EMgA_4U8^=<<D82R0
@FEB34EX@DDm8cCR840/X5i9KeA_=6[c16[C00=VdVKCI]<00fKC0VKD00aVdf[cJ_AZdfKCI[9R/Ej=
HX]JBEY;ET/2ER/01UI:FT]NK5i]GXiR/0=Vd@03I]9ZlfKc009Zl`AVl`9Zl`0KJ_A_5G=GMeMkMgMF
La=RKEH:@HT]1B2S568@80P0300<8A11568HPbC3:<<X`S44>FM:35Z?009N/@0?ETmJKeY`AL/PQ0`0
600/XdW:K^]gDW]dLeA_=6/C009Vd@EVdP9Vd@=VdP9V/P9R/P05H[5NT6:?HXmNS`02GXd00ej>GXmN
S`03GXl01Uj>GXmNSej>GViNS`9NSP07GVeNSEj=GXeNKUi]GVh00Ui]011NKUY^FViJKEY/FTeJ:eHZ
FRYNBe8Y<@H40@@0320<@08@H@03460<@0a0008<@08@@005340@@11P460<H006464010a1464@HA1Q
0QB200<@PA1P46400a1Q00<DPA1Q46400QAQ1A1Q00@<@@a2368<H@@@H@09440@@AAQ564@H@a1464@
HQAQ00h@H@07468@HA1Q464@HQ1Q46801A1Q00<DPQB14640111Q00<@@A105600211Q2A1R0a1Q0Q1R
0Q1Q00@@HQ1Q364<HP<@H@03444<H@a000<@H@07560@@11Q464@@A1044401A1Q0Q110a1Q00<@@A1R
468010a100H@HA1R464<@A1P444346400`aQ344<@@0534401@PP320<@0aP36400Pa00PPP00<<@11Q
4640111Q00D@HQB2588DPaAR008@HP03568DPa1R00D@HP07344<H@a1364@H@aR36401@a200@@@@aQ
464@@@<@@006444<@0a0360<H@aR0Pa200@<HPa2348<@@<<H@03464<HA1000L<@003320880P00084
000;000400PP460DPARS7:<L`bCT:>@]1@02=DD01SUV=FDeICEU<F@aA@8eI@06=F@a@c53<B<a@cE4
0c5500LaA35T<DDaAC5U<FHaI@02<DD1<D@1<DL00006<DLeASE6=DLeASE70SEW00<eB3EX=FP00SEX
00@eJCE8=DPeJ0<iI`<eI`@iI`03=FLiIcUX008iJ003>FLiJ3UX00`iJ08mR004?HTmR3UX?HP2>HP0
0cV9?HPmR008?HP01cf7?HTmJSf9?HPmRD6800=1R@91R003@HLmR3f800<mR@0=?HPmZD6X@HQ1Z469
@HQ1RCf9?HXmRD6XAJL00T6700A1ITG[BRi6309:30Q>2`04CPa>2dh;CP/2CP`7CPd02Dh<DPaB358<
DRa>;58/DPaB2`03DP`01E8/CRaB358;ER/0158/00A>3E8/ERaF:`=B;09B;@05DRiB;E9<DReF;003
ERd2ER`01EI<ETeF;UX]ERh00UI>0UI=0UI>0UY?0eY`00AJKej@GY1NT@ANTP04H[5R/UjAH[43GY46
G[43G[82H[83H[400f:AH[5R/P05H[43H[83H[42H[82H[43I[43H[42I[43I]801VJbI]9V/VKCI]9V
d`AV/`QVd`9V/`YVd`AVdP03I]5VdVKB00EVd`03I]9VdfKC00EVd`0EJ_=[=FmEMkUZdCdV720/XD55
CLY1Ice6>@@XXQ`P;:5RJfldI_9VlfKC009Zd`03I]=VdVKC00IVd`=Zd`9VdP06H[9R/Ej>GVaFBeI<
0U8/00UBBeI;FTeJKEi^GXiR/6:aI]400fKB00=Vm6KcI_<016Kc00=ZdfKDJ_@00V[d00=_5G<eMeH0
0WMF01ig=GMFKaAR/EY?ETmB;DH?@Nm5kcg==FTe9RS5<@Q1S59@G_IFTTH>;BLHPQ0P10080210?FQB
;FKcMeH2Le@016lCJ_=VdVKC0fKB00=VdfKBI]800fKB0fKC00IVdV:cH[9N/UjAGY02HXl2GXl015j>
GXmNSeZ?0Uj?15i_0Ui^00=NSUj?GXh00Ui^00=JSUi]GVh015i]00QNKUY^FViJKEY=ETeFC5I:0UhZ
00I=abS420080110364246400`a1340<@0023402440010a0440@HAB20Q1R2Q1Q00<DPQ2146400a1Q
0Q1R00<@H@a046400aAQ0Q1Q0Q110`a10a1Q0Q1R00D@HAAQ564@H@aQ008@HP04564DH1AQ46844640
0aAQ464@H@04464246800a1Q568@HP0246800aB2488@H@0846401111340@HA1P1A1Q00<@@A1Q4640
0Q1R00<<HA1R4680111R0Q1Q0Q1R0a1Q00L@HQB3368@HPaR464@@@02468546401111340@HA1R0a11
0a1Q00<@HQ1Q44400Q1100<@@0a146400Q1R0PaR0Q2300D<HQ1Q464@H110008<H@03468<HPa100<<
@@05364<HPaQ344<@005368546800a22588@P`03468446<746801A1Q468@HQ1Q36400Q1Q0`aR00/<
@PaR368<HPaQ368<H@a1444@@111008@H@03364@HA1Q008@H@8<H@8<@@03468<@@aQ008<H@03360<
@0PP00888003240<@0a000<88006320@HARS6:@HXac40RT500L]1C4T<D@iQSVW>HLeIP02=DD3<DD0
1354<DDaAC560c550c5U00LaAC56<DDaA35T<FDaIP02<FD0135V<FDaAC540C5700001S5W=DHeAS56
=DHeA`8eI`HeJ006=FTeB3U8>FLeIcE70SU61CUW00<eJ3UW>FP01cUW0cUX00<mJ3UX>FP00cV813f8
0SeW0cf800<iRCf9?HP02Cf700<mR3f9?HT00Sf900=1R469@JP00T6X0d670cf800HmRD69?HQ1Yd68
@JP3@HT00d6:@JY1Z@02@JP01467AHI1IDFY0TW[00=:34X;BN/00Th;0dh:1Th;1Th<00A>3Dh<CPa>
30=B3003DR]>:e8;00=B2`07DR]B358/CRaB358;ER/00e8/00=F:e8/ER`00UH[0U8/00MF;5H]DRaF
;E8/ER]B;005ERd00eH/ER]F;@02ERd01UH^ETiFCUI=ETaJC@=JCP=JL0=NS`9NT003GY5N/Eja00AN
T@=RT@9NT@05G[5NTEjAH[5NT@03H[8=H[42H[800fJbH[5R/@03H[400fJbI[5V/@02I[4016:aI[5V
dFKA0VKB00ER/VJbI[9V/VKC009VdPAV/@04I]5VdVKBI]84I]<2I[800fJcI]=Vd`06I]<00fKBI]5V
dP0BI]82I_<04FmFLgM^kcSR:60/PCdUCJU5IcdU>@</PQP0<<=Z[W=EI]800VKC0V[C0V[B00AVdVKC
I]=Vd`9Ve004I]=Zdf[CJ]82I[401f:bH[5NSeY]FTeFCEI<009F:`07ET]FC5Y<GVeRSV:@H[4016KB
00AVlf[bI]=Vd`AZd`08I]AZe6[dJ_AZmF/EKaE_509c=@=gEP0?MeEcEFmEIcIVmDh`>H/]1Qc33244
0Pa47:HHYPPQ00@000086215a6JWMdic<G=DKaA_4`9Zd`AVd`9VdP03I]=VdVKC00IVd`9Rd`05H[=N
/UjAGY1RS`03GXl015j>GViNKUZ?0ei_0eY^1ei^00=NKei^FVh015i]00aNKUY^FVeJCEY<FTeF;58;
FRYF2TF5664220000a1Q364<H@04344334001@`P440@@11044400Q1Q00<<HA1Q46800Q1R0aAQ211Q
111R00@@HAAQ564DH@@@H@03444<@0a000<@H@<@HP03464DHA1Q008@HP06464DHA1P564HXaR20a1R
00<DHA1Q56400Q1Q00@<@0a1468@H@@@HP8@H@05488DPA1Q464<@00;46401A1R464@HA1Q44000Q1Q
00<@HQ1Q46400a1R0a1100<@HA1R46800Q1Q00<@HPaR36800PaR00D<@Pa1444@@@aQ00<@H@8<@@@@
H@8@@@8@H@<@HP8@H@06344@@A11444@HA1R0Q1Q0Q1R00P<HPa2344@@A1P340<@@aQ0Pa000<<80PP
10000PPP0`a100H<H@aR468@PQB248825886468546<00`a2448@@P0534400`aQ464@H@0546433682
34400`aQ344<H@05444234400`aP460@H00246000`aQ464<H@024403340222000``P340880021000
2PPP340@H1B16:8L`R3S9@@]9CEU0cEV00<aIS56=FH00cEV00<aIS55<DD00c550S5U1c5613550S54
1C5U13540C570000135W=FLeIcEX0SE70cEW13EX00@eJCEX=DPeA`TiI`04=FLeJ3EX>FP5>FL6>FP7
>HP00cf8>FPmI`02?HP00cf9?HPiR@02?HP9?HL00cf8?HTmRP04@HT3@HP00d6X@HQ1R002@HP00cf8
?HTmR002@HP2@JP00d6Y@HTmR@02@JX02D6Y?JU1ZD6XAJI1ID5WBJU9jP02BP`5CP/00dh:CP]>2`04
CP/3DP`3CP`014h=CPa>34h<0U8<00=B;58;CP`01E8;00=B358/CR`01U8/00=B2e8<ER`01U8/0UH]
00EF;5H[EReB;E8^00QF;@04ERiFCUI>ETd2FTd3FTh3FW02GY000ej?GY1NT@05G[400ejAH[5RT@02
HY401F:aGY5N/EjAHY402F:a00=NTF:aH[403f:b00AV/VJaI[5R/@AV/@03I[9R/V:b00=V/P9VdP04
H]=V/VJaI[42I]400fJbI]9Vd`04I]<016JbI[=V/VKC0VKB1VKC0fKB0fKC2FKB00=VdfKBI]800VKB
01MVlfKdIaE_F69=><<`P2bP?BA=QdE6?@@hhbb2400``fZ]LeI_4f[BJ]=Vdf[C009ZdPAVd`=Ve003
I]=Zdf[B009VdP05H[9R/5j?FViFC@02ET`045H[DR]F:eI<FTaNKF:>HY1R/F:bI]9VdfKBI_=ZlVKC
1F[C00EVe6[DJ_AZm6[e009[5@AZm009KaA^m6kdLcI[=FMkBU8a:AAR008<800322488P0100H00006
9:15b6/>MiIcDflc0f[B1f[C00=VdVKCI]801fKC0V;C00AR/f:bH[5R/0ANS`=NKP03FVmNKei_00AJ
KPMNKP03FViNKUi^00=NK@9NKP0>FVeJCEY=FT]JC5H/DPaN:Uh/@FH@80P0300@@@D<@@@<@0<@@003
320@@0a100D@HP04488@HA1Q340246401A1R464@HA1Q46800Q1Q0Q1R00<DHQAQ56400QAQ1Q1Q00@@
@11P464@H@L@HP<@H@03564@HQ1R00<@HP03568DHA1Q00<@H@<@HP8@PP@@HP03464@HQ1Q008@H@<D
H@<@H@8DPP04468@HA1Q4642468446400a1R464@H@024642468234000a1R464@H@024680111Q468<
HPa210aR00<<H@a144000a1P00<<HA1146402a1Q0a1R00<<@Q1R46801PaR0Pa100@@@A1Q3648@0L<
H@05360@HA1R468@P`02468011B36:<DPa221Q1R0a1S0PaR0Pa200<@@Q1144400`a10PaQ00<@HA1R
4640111Q00@<H@aR368@H@8@@@03344@@A1Q008@H@04364@HA1Q46433400111P360@H@aQ0Pa100<8
@0PP22000PP00PPP00P<@11P588LXac48>DY9C550S540SEU00HeISF7=HLeQcEW<FL8<DH2<DD00c54
<FDaAP04<DH00c5W<DHaAP02<DH2<DD01354<DDaIC5V0S5U0S5600<aAC5U<FD00C5700000c5W=FLe
I`08=FL2=FP01SE8=FPiB3U8>DLiIPPiI`03=FPiIcUW00DiI`LiJ004?HPiR3V8>FP2>HP00cf8>FPm
I`02?HP2?HT00cV9?HPmR009?HL00cf8?HTmR@06?HP3@HP2@HL00d68?HPmR002?HP01468@JQ1Z46X
1D6Y00E1ZT6Y@JQ5YTF5008mIP04ALU>358;CNX2CPX00e8:CP]B2P02CPX4CP/00e8<DP]B3008CP`2
DP`00e8;CP]>2`04DP/01U8<DRa>358/DPaB2`9B:`03DPaB2e8/00=B;09B3003DRaF;5H/009F;004
ER]B;58]DRh4ERd015H/EReF;EI>0eH^00AJCEY<FTeJC@9JCP=JL003FVmNT5j?009NT003GY5NT5jA
009NT@03H[5N/V:a009R/@03HY5RT5jA009NT@03HY5R/F:a00=R/@ART@aR/@=R/P03H[5R/V:a00UR
/@04H[9R/F:aI[82H[8016;CI[9V/FJa0VKA0VJb0VKC00=VdVKCI]<016Jb00=V/FJbI]801FKC16KB
0VKC2fKB0fKA00UVdVKCH]=cF69@?>@h`CC2?B@00T4T0ScS00P/HAP0<:5ZZg<dKa9ZdF[B0V[C00=Z
dVKBI]800VKC00=Ve6KCI]<00fKC0fKB00MR/F:`GXmJKUI=ETaF;002DR/025H[ETaJCEi]HXeRSf:a
H[85I]801fKCJ]=Vdf[CJ]9VdVKD009Zd`03J_=Zm6/E00=Zm003J_=Zm6[d009Zm@04J_AgEV/G>D`2
1002320222002`@000000000560e@dh9J/U_3g=DJa@00V[c00=ZlV[CJ]801F[C00=Zlf[CJ]8016KB
1VKC00IRdf:bH[9NTEj@GXh2GXl00ej>GViNKP05GVh3FVh2GVh5GVd3GVh3GVd01ei^FViJKUY=FT]J
BEXZ009F:`0;GR]F;CTU300800`0460<@0a134088004340222001``P340<@110364@H@aQ00<@HP<@
H@04344@HA1Q468346401AB2464@H@a046001AAQ1Q1Q00<@@11P46000Q1Q1Q1R0Pa000<@H11Q4680
0a1R0aAQ0Q1Q0Q22111R00D@Pa1R468@H@aQ014@H@03468@HA1Q00P@H@03588@HQ1Q008@@@@@H@06
444<HPaR348<@@aR0Q1R00T<HPa1320@H11Q460<@11Q36400a1Q00<@@@a136401A1Q00<<H@a13440
0Pa100D@HA1R344<@@`P00<<@@03340<80a000@<H@04368@HQ1R464358800aBS58<DP`0446824880
1Q1R464@HA1Q468<H@<<HP@@HP8@H@06444<@@a1340@H11Q0Q1R1A1Q0PaQ00<<HQ1Q34400Pa100@@
H11Q464@H@@@H009340880`P340880@P100880PQ0084000:464DPAR17:8L`bST;@@aA3EU>HL2=FH0
135V=FHiQcV70SEV00@aIS5U<FHaIP<aAP03<DDaIC5U008aAP<aA@05<F@aAC56<DHaI`04<DH00c55
<DHaAP02<DD00c54<DDaA@02<FH3<DH2<DD1<FD1<DL00003<FPeIcEW00HeI`@eJ08eB003=FPiAcU7
00TiI`04=FPiIcUW>FL8>FP013UW>FPiIcUX1CV800@mJ3UX?FPiJ@8mR@03?FPiRCf800<mR08mQ`Hm
R003?HTmR3f8008mR006?FLmR467@HLmR4680T690d6Y00A1bT6Z@JU1Z091R0=1Z@91ZP91bP09ALY5
Z4F7@HLa1468ANY>2TgZ00==j`04CP]=jTgZCNX2CP/3CP`00e8<DP]B2`02CP`5CPd2CP`024h;CPa>
34h<CP]B;58<DR`4CP`2DR`3DP`00dh<DRaB;003DP`00e8/ERaF;003DR`3DRd0158/EReF;EH]0UH/
0UH]0UH^00=J;EX/FR/00UY=0UY>00AJD5Y`FW1JK`ANT09NT@03G[5NTEjA009N/P03GY5RTEjA00IN
T@=RT@9NT@=RT@05H[5RTV:bG[9NTP07H[47H[87H[43H[82H[43H[800f;CH[9R/P02I]82I[8016KB
I]=VdVKB0VKC0VJc0fJb0V:c1fKC00=VdVKCI]<00fKC1FKB00=VdfKBI]801FKB01EZdfKDLeQVD44U
?>8i0cdT@BE193cS?<8`P2A0<<5VRVlcJ_9Z/F[BJ]<00fKB2FKC00]VdVKCI]=R/F:`GXmJKUI=ETaB
;58[009B;007ETaJCEY^GVmRT6:aH[800fKB0VKc16KC00=ZdVKCI]<00V[C00IZm6[eJ_EZmF[dJ_D3
J_@2J_D01FlEMcAAcB02000010@00`0000DTXDX:G_1[<WNF009gMP03KcEZm6[c00=Zl`=Zd`=Zl`03
J]=Zlf[b00YVd`06H]=R/f:cGY5NT5j?0Uj>25i^0UY^0eY_00=NKUi]GVd00Ui^0eY^0Ui]00eNKUY^
FViFCEY=FT]JBEHZEPYB2eH[CN/`i@022000110P464@H@aQ0Q1Q10a000H<H0aQ364<@0a136424640
2Q1R58<@HPa1468DPQ22464@HQ1Q0Q1R0Q1Q00@@HQ1Q464@@@<@H@04564@HA1Q4643468446400a11
464@HP0246800a22468@HP023683464446800aB1564DH@0846800aB2468@HP0246854640111R464@
HA1Q0Q1R1A1Q0Q1R00@@HA1R464@HP<@H@04440@HA1Q4642468546400`aQ368<HP03368030aQ368@
HPaR240<811P364@H@aP464<HP8@HP04464<HA1Q368246433645344010aQ344<@0a010a100<@H@aQ
46400Q1R00<@PQB358<00Q230a1R0QB30Q23211R00<<HPaQ36400Q1R00H@H@aR468@HQ1146834640
1A1R464@HQ1Q46800PaR1A1Q00<<H@aR36400PaQ0a1Q00@@@A1Q464@@0D<@00;240880PP220<@110
588La23U9@H]9@02<DD01SEV>HHiQcfX>JPeI`8eIP06<FHaAS5V<DHaIS560c5V13560S5U00<aAS5V
<DH00c5500<aA35U<FD00c560S5500@aIC56<FHaAP<aIP8aAP<]IP8aAP8aA@4aA04aAP0000<aJ3EW
=FL00cEW23EX0SE72cUW00HeJ3UW>FLiIcUX>FT2>FP00cUY>FPiJ003>FP00cUW>FPiJ006>FP00cf8
>FTmR@02?HP00cV8?HPmR00@?HP3@HP013f8@HPmR3f80d6900I1R3f8?HPmId68@JT2@JP01468@JU1
ZCf90T6Y00Q5Z4F8@HPiIceWAJQ=j4WZ0TW[00I=jdW[CNY9jTgZCP/2CN/00dW[CN]=j`03CP/014h<
BPe:3DX=0dh<00]>2e8;DPaB34h<CP]B2e8[DRaB:dh/009B;09>30QB309B;09F:`9B;004DPaB;58/
DR`2ERd2ER`00eH[ERaF;@03ERd01EX]FRaJ:eX[FT`00UY=00=JCeY_FW000Uj@25jA00=R/EjbGY40
2EjA0f:A00UNTF:AHY5RT6:aH[9NTV:AHY8026:a1F:b1f:a16:b16:a00EV/V:bH[5R/FKB00EV/PMV
dP9V/P9R/aEVd`=Zd`9Vd`0CJ]=^mW<GITm5AScR?@=10d4T@@@lhcSR;80P@3DSHXY_=6KAI[401FKB
2fKC00MR/V:aHXmNSeY=ETaFB`04ER/01UI<FTeJKUi`GY1R/@9R/PUVdPAVd`03J]=Zm6[d009Zm09Z
m@08J_A^m6[eK_I_5VJa=D/<0@<00084000:000<83TQIZYo[W^CMgIc=FlEJaD2I_@9J_@3J_<00f[b
J]=Zd`02J]<5I]<01fKBH]=R/ejbGY5NT5j?00YNKP9JKP=JK`03GViNKEi]009NKP=JCP=NK@07FViJ
KEY]FTeJBUY8ERX00UH:00=F:TG;;<H00PP000<@@11144000a102@a000@@H11Q464@H@8@HP0436<<
HQ1R4683464246800a1Q468@H@06464234024443464010aQ344<HA110Q1Q0Q1R00<<HA1Q46800Q1R
111Q111R0aAQ0Q1Q00<@HQ1Q46801A1R211Q00@@HQ1Q464@H@8@HP05464<H@aQ464@@@0234400a1Q
468@H@0446400a1P464@H@0746401a11468@HQ1Q240880a100<<H@0=368<H@aP460<H11Q460<H0a1
368<HA1Q44000a1Q0Q1100D<HA1P440<@0`P00<88004320<@0aQ444546400aB2488@PP0258<>4680
1@aR348<HPaQ36801A1Q00D<HA1Q368<HPaQ00L@H@05364@HQ1R468<H@0446400a1R464@H@024640
20a1320<80a0320800@022033400211P584L`acS:><]93E4=F@2=FD2>HH5=FH01CE6=FHeISEV<FH0
0SEV00<eIC5U<FD01S5V0S5U00<aAC56<DH00SE50S5500<aA35U<FD00c5U0c540S550S5U0S5V0S56
0S5V00<]IS56<DD00S550C5T0C5700000c5X=DLeA`03=FL5=FP013EY=FPeJ3EW13UW00<eIcUW>FL0
1CUW13EX00<iJ3UY>FT013UY2cUX00<iR3V9>HT013V90cf80cf93Cf80Sf913f81D6900=1R46X@JP0
0d6Y00A1Z46Y@JU1Z@91Z008@HQ1Z46X@HTmITF7BLU9jP=9j`9=j`9:2`=9k0==j`9>2`03CPa>2dX<
009:30A>3004CP]>34h<DP`3CP/8CP`00e8/DPaB3003DP`:DR`3ERd2ER`00eH[ERaF;002ERd01UH^
EReJ;EX/ETaJC09JC@03FTmJKeY`009NT0ENT@9R/@03G[9NTEjA00ANT@=NT0=NT@9RT@03HY1NTEjA
009RT@04GY5NTUjAGY42HY4DH[48H[83H[43H[8016KBI[9V/VKB1fKC00=VdV:cH[<05FKC0VKB01IZ
dfKCJ]=Vdf[DK_EZCDE7?>8lhd43ABA193d4>><``B1P>FIRZfleI]=V/P9Vd`9V/P07I]9VdfKCI]=V
dV;CH[<016KC00ERdf:bHY1RSei^009JC@9FB`03ER]B;58/009FC006FTiJKej@HY1R/F:b0fKB00=V
dFKBI]8016KB0fKC0VKD0f[d0V/E01=ZmFkeK_EZmFKcG]5FeDH@8:D<01a0=@<mQdG:FRaVZgMBMg=c
E003J_<;J_@3J]@00f[cJ_9Zl`03J]<7I]<01V:cG[9NTEj@GXiNS`9NK`UJKP=JK`04FViJKei^GVl2
FTh015Y_FTiJCUi^0Ui]00]JKEY=FTeFBeI:ERYF2UhZFT]1ZQb50088008@@004340@@11044053402
240234000`aP464@H@0746800a1Q468@HP06468846400a1R464<H@02344236801a1R464@HQ1R488@
HQ1Q00<@HP03344@HAAQ00D@HP03464DHAAQ008@H@04344<HA1R4645468546401@aQ468@HPa14640
0a1R00<<H@a136800a1Q00@<@@a0344@HP@@H@06488@HA1Q460<@11P0Q1Q00<DPaB246400a1Q00L<
HPa2340<@11Q364<HP0536453440111Q440@HA1Q0Pa00PaQ00D<@0`P220880a0008<808@H@8@HP0:
568DHAAQ564HPQRS488@HQ2248<246<64685368246800a1Q468@HP04468246423642368336454642
4688464010a0220880a00`PP00`<80P0220@HAc37>@Pi2CU:@DaACEV=HH2>HH013V5>HHiQcV61SEV
00<eASEV=FH01CEV2S5V00HaIC55<DHaASE6=DD3<DD3<FD01C54<FDaA355<FD00S550S5U00<aIS56
<FH00c5V00HaIc5V<DDaAS5U=FD1=DL00003<FLeAcE700@eI`@eJ003=FTeJ3EX014iI`8eJ08iJ0<i
J@PiJ0@iR0DiR@04?HTmR3f8?HP3?HT:?HP01D68?HPmR3f8?FP00cf800=1R469@HT00T690T68246X
00A1Qd6X@JQ5Z@91Z@0:@HQ1Qd5VAJQ9bTW[BNa=jdgZCN/2BN/014W/BNe9k4W[14g[0dh;00AB2dh;
BPa:30=>2`03CPa>2dh;00=>2`03CPa>3Dh=00=>3003CPe>358/00IB30AB;003ER]B2e8/00=B;09F
;@9F;003ER]F;5H/009F;@06ERaF;EH]FRaFC5Y<0UY=00AJCUY^FVmJL0=NT0YNT@03HY1NT5j?00AN
T004GW5RL69aHY02GY400f:@GY5NT@02GY42GY04GY45HY401f:aHY5NTF:AH[5RT6:A00QR/@ER/P03
H[5R/6:a00AR/P9V/P03I]9VdfKC00IVd`03I]9VdfKC00IVd`=VdP=Vd`03I]9VdfKC00EVd`=VdP03
I]=V/VJb009Ze00@ITa19SS3><518dDTADA193SS=><TP3UWI/e_=F/DI[82I[<3I[88I]84H[801V:@
HXiNK5Y<FT]JBP9F:`9B:`07ER]FC5Y=FViNKf:@HY400V:a0fJa1VKA00AV/VKBI]=Ve0AZm00@JaE_
5F/EKaE^m6kcKa=_=6mGKcIVdfJ`J]5^lG<BNe@2NeD00g<eKaAZlP05J_<5J_@016[cJ_AZm6[d0f[D
00=Zm6[cJ_<00V[c00AZdfKCI]=Vd`9Zd`9Vd`07H[AN/UjAGY1NSej>GVh02UY^00=JKEY^FVh00UY^
25Y>0Ui=00=NKEY=ET`00UH[00aB:eHZFR]JC3UY32<400`0440@@@a0440234000`a1340<@0033400
20PP340<@0aP464<H0a04649468010aQ368<H@aQ0a1Q00<@PQAQ46400a1Q00<@HQ1Q34400Pa000@@
HA1R468@H@8@HP04588@HQ1Q464246800a1Q468@H@0546800a1Q564@H@02464020aQ464@HA1Q340<
80a0444346801A1Q460@H0a036400a1Q00H<H@a1344880a03643464010aQ468@HQ1R0Q1Q00<@PQ1Q
46400a1Q0Q1P00D<@11P464@HA10008@@@04464<HPaQ4642468236400`aP340<@@02364234422200
0`a1340<@0053402464010a1464@HQ1Q0a1R00DDHQB2588DPQR200<DH@03464@PQ1R008@HP8<HP<@
HP03464<H@aQ008<HP04348<HPaR46824642468336801Q1R464@H@aQ464<HP8<H@03360@HA1Q00L@
H@03340<H@a000D88084000B220<@QB458<L`bST:@@]9355<FHeISEW=HLiR3VX>HLiQSEV1SEU3CEV
00TaICEU<FDaAC5U<FHaIC5V<FD00c5500DaAS55=DDaAC56008aA@8aA08aI@04<D@aAC55<DD3<FD2
<DD2<DH4<FH2<DH1<DD1<D@1<DL00003<FPeIcE7008eI`DeJ08eB08eJ0<iI`8iJ003=FPiJ3UX00@i
J0<iI`8eJ005>FPiR3UY>FTeJ@02>FT3>FP:>HP5>HT3?HT2>HT00cf9?HPmR@02?HT00cf8?HTmR005
?HP2@HP00d69?HTmR@02?HT00d69?HPmR@02@HT3@HP5@JT2@JP3@JT0347:@JU1ZD6X@HLmITFYAN]:
34WZCNY9jP99j`05BNe5kDW]BNa:3003CN/2CP/2DP/00dg[CNa:3002BP`2CP`5CP/6CP`3CPd00dh<
DPaB3007DP`2DP/00e8<DRaB;006DR`00eH/EReF;@04ER`02UH[ERaFC5I=FTeJCUY^FVmJL5j@2ejA
00ANTUj@GY1NL0=NT005GW1RL69`HW5NT00?GY47HY42H[400ejAHY5R/@09H[43H[800f:aH[9R/P02
H[84I]83I]<00fKBI]=Vd`0;I]<00fKBI[9VdP0?I]<05f[CI[9Zm6[eHR]19SS2?>=5ADEVBFE19CST
<<@PH3E6I/e_EF[dI[9V/f:cI[<00VJb1V:b1F:c00MR/V:aIZmNKEi<FTaFBP03ER/02U8[ER]FC5Y=
FViNKej@HY5R/F:b0fJa16Jb00AR/VJbI[9V/P9Vd`04I]AZm6[dJ_@4JaD02f[dK_A_56lELeMgF7Mh
MgUkVG]hMeL00WMF00=c=F[cJ]<016[c2f[d0f[D00=Zm6[cJ_@00V[c00iZdfKCI]=Vm6KCJ]=Zm6KC
H[=N/UjAGY1NSUi_25Y_2UY^00=JCUY?FTh00eY>019JCEi=GVeJCEH]ER]B;4h/CP]F:dh;;@L80@@0
420@@111364334000`a1340<@00634000`aP464@H@09468236800`aQ368@HP04468011B3588DHA1Q
1Q1R0Q1Q00<@HQB34680111R00<@H@a146801Q1R00H<HQ1R464@HAAQ4642488946800`a2468@H@02
46401@aQ468@HQ1Q46800Q1Q00<<@Pa036000PaQ0Q1Q00<@HQB358<00Q1R111Q00H@@A1Q464@HA1P
3602340244001A11344<@@aR46400a1R0PaR1`aQ00<<HPaQ34400Pa100<<HQ1R4680111R00/DPaRS
6:<DPQRS58<HY1B3588DHQ1R008DH@03464@HQ1R00<@HPD<HP04468@HA1Q4682368010a2368<HQ1R
0Q1Q00@<H@aR368<HP8@HP04464<H@aR3685364346400`aQ344<@@052202100040`P464DPQBS7<@U
1RTV:@DaASEV>HLiQSV8>JPiR3EW0c5W0c5V0SEV00<eICEV=FD00SEU3SEV00<aIC55<FD01C5V0S56
00<aIC56<DD01S55135U00@eASEW<FLaIP8aI@8aA@<aAP<aIP04<DHeIc56<DD1<BL00003<FLeIcE7
008eI`TeJ0<iI`04>FPiJCUY>FP8>FL4>FP4>FT9>FP5>HP00cV9>HPiR@07>HT00cf9?HPmR@02?HT2
?HP00cf9?HPmR003?HP3@HP01Cf9@HU1RD69?HT00T69146800=1RD6Y@JT00d6Y00M1Z469?HPmR468
@JQ5Z002@JP2@HP0145WALU62dgZ0TWZ0TW[00Q5kDW]BNe=k4W[CNY9jTgZ0Th;00=:34W/CN`00TW/
0dX<00=>34h;BP/01Th;00AB2dh<CPa>3@=>3003DPaB2e8<00EB30=B2`=B3003DPeB;58/00IB;0AF
;003ER]J;5X[00=JC@06FVeJKei`GY5NT5jA0UjB00=NTEjBHY400V:a0ejA0Uia00ANL5j@GW1NL0EN
T003GY5NLEia00QNT@9NT09NT@ART@03HY1NT6:@00iRT@9R/@ER/P]VdPAVd`03I[9VdVKC009Vd`9V
dP9V/PiVd`0GJ]=Vdf[CJ[9Ze6lEHPU59D43ABE5ATUWBFDm13T4:88H83U7I/a_=F:bI[9V/`02H[<2
I[86H[84H[<2H[801f:@HXiNKEi<ETaF:e8/009B:`0:ERYF:eI<FTeJKEi_GY1RTF:aH[83I[84H[80
16:cI[9V/fJc0VKC00AVe6[dJ_AZm0=[509_5004Ka=^m6keKaD5KaH00flEJ_AZm002J_@2J]<00f[c
J_AZm004J_@00f[eJ_AZm004J_@2J]@00f[cJ_AZl`02J_@00f[cJ]=Vd`02I]@00f[CI]=Vd`02H[<0
1UjbGY5NT5i^FVmJKP9JK`9JL0EJK`9JCP9JK@9JKP=JK@06FTiJCEY>FTiJCEX/0eY<00]FC5H[ETa>
;4g/DRe5bBC5204801AP008@H@05360<@0a0340<@@0734001110364@HA1Q2A1R0PaR00<@H@aQ4440
0Q1Q0a1R0a1Q0a1R00<DPQB346800a1Q0Q1R00@@HA11464@HP8@H@8@HP<@H@<@HPD@H@8DPPT@HP03
3488811P008@H@06364@HA1Q464@@A1Q0Q1R00@<HA1P364@HP@@H@8@HP0:344@HA1R464<@PaR348<
@A1146423602340244000a11344<H@0346400`aQ344<@@023443340010aQ464<H@aQ0PaR0Q1R0a1S
0QB30aRS00<DPQB146401Q1R1A1Q0Q1R00@<HQ1R468@HP8<HP0A468@HA1Q464<HA1Q368<@PaR468@
HA1P364@H@aR468<HP044640111R364@H@a110a000l<80PP200400P0220@@11P584HXQc3:@DaABe4
=FH00SV70SV600<mQcV7>HL00SEV135V00DaAS5V=FLeIS5U00PeI@deIP03=DDeICE500HaAP04<FHa
IC5U=D@2<DD012dU<DDaIC5U0c560S550c5600@aAC54<DDaA@@aAP03<FHaAS5600<aAP4aA`0000<a
IcEW=DL00SEW23EX00@iJ3UW>FLiI`8iJ003>FTiJ3UX00LiI`@iJ0@iJ@03>HTiR3V800DiJ08iR004
>HTiR3V8>HP:>HT00cf9?HPmR@06?HT4?HP00d68@HU1R@02@JT01468@HTmZCf91D6900=1R469@JT0
1d6Y0d6X0d6Y00U1R3eW@JU5jTh:CNY9jdW/AN`00dW]00=9k4W[CN/00dX;00=9jdX<BP`00dW/0dX<
00=634X<BP`024h;1Dh<00AB34h<CPa>30=B30=B2`AB30UB;09F;@9F;003ER]J;5X[00=JC@03FVeN
Kei`009NT09NL@05GY5NTUjBGY5R/@04GY42FY42GY000eY`GY1NT004GY03GY400ej@GY5NT@05GY45
GY08GY4016:AHY1RTEjA26:A0V:a1F:b00AVdVKCI]=Vd`9VdP04I[9VdfKBI]84I]<00fKBI[9VdP04
I]<016KBI[9V/VKB3FKC0VKD00UZe6ZcI]AZmEh9ABA10d4UADD00T5500/i9CD5944D03f9J/e[56:c
I[=R/f:d009R/`03I[9R/f:b00AR/PAR/`09H[9R/EjaGXiNKUY<ETaF;58/009B2`09DR]F:eH[ETaJ
KEY_GY1NTF:a00QR/P=R/`05I[=VdfKCI]=Zl`02J_@2Ja@02F/EKaE_5FlDK_=^m6[dJ_E_5@02J_D0
16[dJ_EZm6[e0V[d00EZlfkdKaA^m6[d009Zm@9Vm@03J_EZm6[d00=Zm09Ze003J_AZlf[c009Zm005
J_=Zm6[dI_AVe002I]<01FKBI]=Rdf:cH[400Uj@35Y_0UY>1UY]00=JCEY>FTd00eY>00=JCEX[FTX0
0UI:00aF:UH[CPa>;59>@HTHQ0@0200@H122364234001@Q0244<@@a034401@a000<@@11P46400Q1Q
0Q1R0a1Q00<DHQ1R46800PaR00D@H@a2348<@Q1Q00@@HP8@H@D@HP04464@HQ1Q464234400`a2364<
H@0346800a1Q468@H@0546800a22464@H@034646468346400a1R368@H@0346400`aQ348@@@024440
1@a0468@HQ1R46400Q1R00D@HA1P464@H@aQ008<@@05444<H@aQ364<@@05364346001PaQ444<@0a0
344@H@8<H@04220400PP34423402464346800a2248<@HP0348<02A1S468@HQ2358<DPQAR588DH@07
4685464846844642468536834640111R368<HPaQ111Q00<<@@`P22000`PP0P`P018<@11P688La1c5
:>@]1354=FDeISV7?HPmZCVX=HLiQcF7=FH2=FD6=FH00cEW=FHeIP07=FH4=FD==FH013E5=FDeICEV
13E600@aAS5V<FDaI@8eI@03<FDaIS5600PaAP03<DDaIC5U008aI@04<DDaAS56<DH3<FD2<DH2<DD1
<DL00003<FLeASEW00DeI`HeJ0<iI`03>FPiJCUY008iJ0TiI`8iJ0<iJ@8iR@8iJ0<iR08iJ08iR003
>HTiR3V800<mR003?HTiRCV900DiR@03?HTmR3f800<mR@04?FTmRCf9?HP3?HT3?HP01Cf9?HPmR468
@HT00T6800<mRD69@HT01d69146Y00]1Z468@HLmQd68@JQ1QceX@HU5bTWZ0099j`03ANa:2dW/0099
k@03BNa9jdW[00=9j`04BNY9jdW[BN/3BN`00dX<BP]:3002BP/6CP/2CN/2CP/01dh:CP]>2dh;DP]>
2dg[00=B2`03DPa>34h<00MB309B;003DPaB;58/00=B;09F;0=J:`9JC003FTeJKEY_00ANL004GW5N
TEjBGY86GY43GY02FVl00ej@GXiNK`05GW04GY02GY45GY03GY400ej@GY5NT@04GY401Ej@HY1RSf:@
HY400f:a00=RTEjAHY400V:A16:a0f:b0VKB16KC0VKB1fKC00=V/VKBI]<016KC00=VdVJbI]800fKB
0VKC00=VdVKCI]<016KC0fKD0VJc00=ZeF/EGPT00SS100dm0d4S@B@m93T5<<@XHaP1@JY^k6/CH]AR
]004H[<00f:bH[=V/P02H[400fJaH[5R/P03H[82H[401ej`HXmNKUY]ETaF;58/00=B2`09DPYF:eI<
FTeJKej?GY1RTF:b00=R/@ER/P04I[9V/fJcI[<2I]<00f[cJ_A[5002Ka@01f[dK_AZm6kdK_=_4V[c
00=Zm@9Zm003J_EZm6[d00=Zm09_50=Zm003J]AVmF[d009Zm007I_AZm6[dJ_AZe6KDJ]<00f[c0V[C
0VKC00=Vlf[CI]<016KC00IRdf:aGXmNSUi_FVl3FVh2FTh01EY?FVmJKeY_FTl00UY>00=JKEY=FTd0
1EY=00MJC5Y=FTeJCEY<FTYJ:@04ERX02U8;DReBCcU7324000P0460<H0aQ0Pa00PPP00<<@@a03400
1Pa00Q1P0Q1Q00<@HQ1Q46400Q1Q00H<@0a2468@HPaR464234800`a1464@H@0>464234400a11464@
@@02344010aQ464@HA1Q0a1R111Q00<@H0a034400Q1R00D<HQ1Q3688@@PP00<@H@8@HP8@H@04364@
H@aQ4682444346400aB1464<@@0234400`a0460@H@0246401Pa1340@H@aQ344<@08@H@04444<@@aQ
364246000a10320<@00434000`aQ344<@0023442464021AQ6:8HXaRS588@PQ2358<348<246<=4689
464446801A11468@HA1Q468010aR00@<H`a2468@HP<@H@04468<HQ1R3403220310002@PP340@HAB1
6:8L`b33;@@aA002=DH00cV7?JPmY`03>HL013f8=FLeISEW0SEV00<eICEV=FD02SEV0cEW00@eISEW
=FHeIP@eI@`eIP8eA@03<DDeASE600<aA@8aAP03<FDaAC54008aA003<DDaAS5600HaAP03<FDaA3ET
008aI004<D@aABe5<DD2<FD2<F@012e4;BDaAC550C5700000c5W=DHeAP02=DL2=FL4=FP2=FT01CEX
>FLiIcUW>FP00SEX0SUX2CUW13UX00@iRCUY>HTiR08iJ08iR0<iR@03>HPiRCV8008iR08mR003?HTi
RCV900HiR@XmR@04?HPmRCf9?HP2?HT2@HP0146Y@HQ1R468146900M1ZD69@HQ1R469@JU1Z007@JT0
1d6X@JU1ZD69?FU5ZTWZ0099j`04BNa9jdW/BNd3BN`4BN/2BNX02DgZBNY9jdg[BN]:34X;BPa9j`02
BP/2CP/00dh<CNa=k002CN/01Th;CPa>2dX<CNa>30==j`9B2`I>2`YB30AB;09F;003ER]J;5Y=009J
C@03FTiJKei_009NL09NT@03GY9NTEjA00MNT@03FY5JL5j@009NT0ENK`9NL0INT0ANT@9NL@03GY5N
T5jA00QNT@9RT0=RT@04H[5NTEjAGY42HY4015jAH[5R/F:a0V:b16;C1fKC00=VdVKCI]<036KC00EV
dVKCI]9Vdf;C00=Vd`AVe00GI]EVe6KDI]AZe6[eJaIN33RQ;60h`D4S@@=18ce4?B<XH1`RAL]^kV/e
H]AR]002H[<4H[82H[400fJaIY5V/@04H[83H[402Uj?GViJCEI=DRaB34h;CR]B2U8;0UH[00MFCEY_
GW1NT6:AH[9R/@02I[83H]<2I]8016JbI[=V/fJc0VKC00AZm6/EKaE[509Zm004K_A[56/DKa@<J_@0
0f[cJ_AZm003J_@01F[DI]AZm6KdI]@00VKd0VKC00=Ve6[eJ_@00V[c00AZdV[CI]9VdPMVd`04H]=R
/V:aGXl2GVh2FVd00eY^FVeJCP03FTh00eI>FTiJCP0:FTd015Y<FTeJCEI=0UI<1EHZ00AF:e9=CRha
9`840003320@@0a100H<@@H<@003460@HA1Q00@@H@03468DHA1Q008@H@03340<HPaR00D<HP04464@
@@a1464246864642368246401AAQ440@@@a144400PaQ111Q0a1R00<@H@aQ4640111Q00@@HPaR368<
H@8<@@H@H@8@HP04368@HA1R4642444246400aB3588@H@0234000a1Q364@H00646402@aQ344@HA1Q
444<@@a0364<H002340246001A1Q344<@0a046401A1R00HDPaRS6:<HXaR25882488758<00a23468@
HP0246801Q1Q468@HQ1R46<<HP@@HPL@H@@@HP04444@HA1Q46434684368246400`aQ340<@0032202
10002`P0340@HAB26:<Li2T5:BD]93E5>FH00SV70SfY00DmZ3V7>HLiQcEW00<eIP8eI`06<FLeISEV
=FDeISEU1SEV1CEW00@eISEW=FLeI`8eIP@eI@heIP8eAP06<DDaAS55=DHaAS5V135U00<aAC56<DH0
13560c5V00<aAS5U<F@00c5U135V0c5U00@aIS56<DDaA@4aA`0000@aIcE6=DHeAP8eA`03=FLiIcUX
008eJ08eJ@03>FPiIcUW00<iI`03=FPiIcUW00TiI`DiJ003>FTiJ3UX00DiJ003?HPiR3V800<iR003
?HLmR3f8008mR@LiR@8mR@<mR0<mR@PmR091Q`A1R0Q1R@91R003@JQ1ZD6Y00=1R@03@HQ1ZD6Y0091
Z@91R@07@JU5bTG[BN]62dX;BN/00TW/00E9jdX;BNY9jTgZ00=9jP03CNU=jTgZ0099jPI9j`==j`06
CNa9k4g/CNa9jdX<0TW/0Tg/0Tg[00Y=jTg[CNY>2dh:BP]>2Th;DPY>2`9Aj`UB3003DRaF;58/00=F
;007EReF;UH^FTeJCUY_FW000ei`00=JL5i`GW001Ei`0UYa0UY`00=NL5j?GVl00Ui_00ANKUi_GVmN
K`=NL007FW1NT5j@GY1NTEZAFW8015ia0ej@00YNTEjBGY9NLEjAGY1NTEj@HY1RS`9NT@9RT@9NT@04
HY5NTEjAHY43H[400f;BH]=Rd`02H[<00f;CI]=Rd`02I]<016KBH[9R/V:b0fKB0V:c36KC0V;C0VKC
16KD00=VeFKDI]D00V[e015_5VKfFNddXRaP><510T4RAD99HdUQ<:0P@DFZK^i_=VKe009R/`9R/PER
/@03I[5RTFJa009R/P9R/@05G[5NT5j?GXiJKP02ET`04U8/DPaB2U8:DPUB2U8;DRaF;EY>FVmNL5jA
H[5V/F:aI]5Rd`=Vd`=R/P=VdP=Vd`03I]AVm6[d009Zm004I_=VdfKCI]<4I_<01VKCI]9VdVKBJ_=Z
lPAVdPQVd`03I_AVe6KC009Vd`04H[=RdfKBI]<2I]800fKAI]9R/P05H[82I]802F:aGXmNSEi/FVeJ
C5Y]FViJK@04FTd00eI=FTeFC002ET`3FTd00eI<FTeJC@02FTd3FT`2ET`3ER/02eHZEPYF2UH;DRe>
;S471008010P32001@a11`a000D@@11P460@HA1100D@H@8@H0<@H@03468<HQ1R008@H@04364@HA1Q
464234401111464DPQ1R0Q110PaR00H<HA1Q464DH110444246400a11344<@@02460546401@aR464@
HA1Q46800a1Q00@<HA1Q364<H@<@H@03460@@111008@H@03364@HA1Q008@@@04344@@A1Q58824640
1110360<H0aP1A1P00L@H@aQ364@@@aQ440<@002220236400a1Q460@H@0546400aB258<@PP034682
56800a1Q468@H@0446400a1R464@HP0846801A1Q468@HA1R46<00Q1R00@<HQ1R368<HP8@H@03364@
HA1Q00<@H@05348@@Q11464@HP0246401@aR344<@@Q022000Pa000H880@0220880@0220246000aB2
7><Y1002<D@01CEU>JLiYcF6>JP00SfX00<iQcV8>HL00SEW1CUW0SEW1CEV1SEU0cEV0SEW00DeISUV
=FHeICEV00<eI`03=FHeICEU008eI@heIP03=FDeACE600@aAP03<FHaIC5U00<aI@PaAP8aIP03<FDa
I35U00/aI@4aA@4aA04aAP0000<aIcEW=DH00SE70SEW0SUW0SEX0SEY00<iJ3UW>FL00cUW1CEX1CUW
33UX0SeW00@iJ3eX>HTiR08iR@04>HPmQcf8?HP2?HT4>HT2>HX00cV9?HTmR@03?HP3?HT6?HP00cf9
?HQ1Q`03?HP3@HP6@JT01T69@HQ1Z46X@JU1R@91R003@HU5ZD6Y00=1Z@=1R@0;?HU5bTG[APa5jdG/
BNa:34W/ANa9j`05BNX014gYBNY9jdWZ0Tg[00=9jTW[BN/00TWZ0TW[00I=jdg/CNa=k4W/BN/6BN`0
14W[CN]=je8:0Th;00E:2dh;CP]>2U7Z00=Aj`AB2`MB309B;003ERaF;EH]009FCP03FTmJKeY_00IJ
L09JL@=JL003FU1JLEYa009JL003GW1NSei_00=NK`9NC`=NL09NT003FY5JLEYa009JL@ANL@03GY5N
TUjA00=NTPANT@03GY1NTF:@009NT@9RT@=NTP=NT@05HY1R[ejaH[5Rd`02I]@2H]<00f:cH]=Rd`04
H[800f;CH[9R/`05H[<2H]<3H[<01F;CI]=Rdf;CH[800f:c0V;C0f:c01MV]6KDI]EVeF[fJaIW5Tg=
<80dX3S1?@95A4E3DJEAY3CR8695Zf[`JcIRe6:c00=R/P07H[=R/V:AH[5R/V:aI[800f:b00ER/ejb
G[9N/Ej@009JK`0CETiFC58/CP]>2TX:CNYB2Th;CRaF:eI<FTiJKej@H[5V/F:aI]800VKd00=Ve6KC
H[<00V:c00IR/V;CI]9R/V:cH]<2H]@00f;CH[9R/P02H]<3H]801f;CH]9R/V;BI_=Vm6;C00=RdP9R
/@03H[9Rdf:b00=R/P0;H[5R/V;BH]=R/f:bH[5R/V;DI_AVd`02H]8016:bH[5R/F:a0Uja00=R/Ujb
GY400ej@00QNSei]FVeJKEY^FVmFCUI<0UY=15I=1UI<0eI=0UI<0UY<00=J:eH[ER/00eH[0UH;00QA
jeH;DRe5kRC5100<01100Pa000@<@@a0340<@@<<@0<<@@03340@@11P008@H@03444<@11Q008@H@03
444@H11P00<@H@@<H@@@H@04468@HA114442464244401Pa1348<HQ1R464@HP<@H@8@@@<@HP8@H0D@
H@<<HP@@H@04564@HA1Q364446402AAP440@@A1Q364<HQ1R364<@@0234001@a1464<HA1Q44400PaQ
00@<H0aQ364@H@8<@08@H0<@H@8<@0<@HP05488@HQ1R468@PP03588258<3488248<246800aAQ464@
H@0:464346824640111R464@HQ1Q111R0`aR00@<H@aR368<H@H@H@D@HP03344880PP008880093208
80`P320@H1R27<@LiBD5008]A@04=FHeQcVX?JP3?LT01SV6=FHeISV7>FHiI`DeI`<iI`@eI`@eIP03
=FDeQSEU008eI@@eIP8eI`8iIP03=FLeISEV00@eIP<eI@leIP03=FDeACE600DaIP03<DDaIC55008a
I@HaAP8aIP03<FLaIS5V00daI@4aA@4aA04aA`0000<aIcE6=DL00SE70SEW0cUW00@eJ3EY=FTiJ0Li
I`<eJ08iI`8iJ003>HLiIcUW00TiJ0<mI`8mJ005>HTiR3V9>HTmR003?HL2?HP00cf9>HTiR@02?HX0
13V:>HTmRCV90cf80cf91Cf80Sf91Cf80d680T690d6Y0T6900I1R46X@JQ1Z468?FL2@HP014FY@JU1
ZD6Y0T6900Q1R3U7>DPmRDG:BPa5jdW[14G/00E5jdW[BN]9jTgZ009=j@04BNY9jdgZCNX2BNX2BN/2
BNX01TG[BN]9jdG/BN]9k0A9j`A9k00:BN]=jTgZDNYB2TgZBP]9jTgZCPX2DNX3CN/014gZDNYB2Th<
0e8<0Tg/0e8<00IF:eH/ERaF;EH^ETh2FVl00eY`FVmJL002GY001eY`FU1FCeY?FW1JD5I@009JL@04
FW1JKeY`FVl2GXl025i^FVmJCei?FU1JL5j?GY03FW001EYaFW1JL5i_GW000eia0ejA0UjB0UjA00YN
LEjAGY1NT5i_GY1RT5jAHY5NTPENT@06GXmR[V:_H[1N/EjA0UjB00=R/f;DH]@00V;C0fKC16:b00=R
/f:bI]<00V:b0V;C00=R/V:cH[<01f:b00=VdVKCH[800V:b0f:d01ERe6KDJaEW5Tg=<80hX43R@@=5
ADf5CHA=PbbQ8495Zf[@JaERdejbH[400f:b0UjB00=R/F:bH[800V:B0V:b0UjB00UN/UjaGY5NT5Y_
FViBC58/CP/014WZ0Th;00IB:eH[FTaJKUj?HY02H[401FKcJcE_=VKeI]@00V:c0V:b00=Ve6KCH[80
0ejA00MN/f:bH[5RdV;CI]9R/P03GY04H[403EjaGY1N/F:`G[1NT6:@H[1V/F:aGY5R/FKB009Vd@07
H[5NT5jAGY1RTF:aHY400V:a011RT5i_FViJKUj?HZmR/6:?GXmNT5j?FTiJCEY^FVmJKP9FC@03DTeF
;5I=00AFC09FC@03ET]B;5H[00=FC004ER]F;5H/ERd2ET`3FR/3ER/02eXZER]F:e8<CN]B35I>?H/@
@`0020002Pa00`a100H<@11P580@PA1Q340546400a10460@H002460346400`aQ344<@@0234434642
44401Pa1444@@111368@HP8@H@08468@HA1Q464@80a1444@H@8@H007440@HA1Q464<H@a144400Q1Q
00P@@@`P440@@1B0460@HA100Q1P00@@HA1P560@H0<@H@03344<H@a1008<@@8@@@03464<H@aQ008<
@005364<@0Q03448800234000a1P464@H@03464246800aB2488@PP03488458800aB1568@HP064680
0a1Q460@H00;46400`aQ464@H@054642468246400`aQ464<H@0336400a1Q460@H003460246423400
10PP100400PP0Pa000d@H0a0688L`bT4<D@a93EV=HLiQcfY@LTmZ@03>JP013F7=FHeISEV0SEU00<e
ISUV=FL01cEW0SUV00<eIcUW>FL00cEW00<eISEU=FD00cEU00TeISEU=FHeISEW=FHiISUW=FL00SEV
1cEU1SEV0SEU0SEV0SE600HeACEU=FHeICE5=DH4<FH00c56<FDaA@04<DD01C5U<FHaAS55<FD0135V
00<aAS5V<FD02c5U0C550C540C5600000c5W=DHeAP02=DL2=FL3>FL01CEX=FTeJCEX>FL00cUX00<i
IcEW>FL00cEX3cUX0ceX00<mR3V8>HP013V900@mRCf8?HPmR08mR@@iR@<iRP8iR@03>HPmRCf800Dm
R@03?HPmRCf900XmR@91R@03?HU1RD690091Z@03@HU1ZDG90095Z@91R0A1Z@09@HU1ZT6Z@JY1RCeX
?HU5ZTGZ0099j`E5j`99j`99jP9=jP06CN]9jdgZCNY9jdWZ0dW[00A9jTG[BP]9k0E9j`9:2`=5k099
k003BN]9jTW[0099jPA9j`9=j`03BN]9jTgZ009=jP04DNY>2dh<CP`3CN`014h<DPaB358;0U8<00]F
;UH]ETmJKeI?ERiJCeYaGW5NL5ia009JL@05FTmFD5I@EU5JD@02FU000eY`GY5JT@04FW03FTl6FW00
1EYaFW1JKei_GW0015Ya00=NTUYbFW0015i`00INLEj@GY1NL69_GW02GY400f:BGY9NT@03GY4015j@
GXmNSej?0Uj@0UjA00ENTejcG[=JTejb009NT@07H[5R/UjAGY5NTV:bHY400ejA00ER/V;DH]=N/ejB
00=NT@04GY1NTF:bG[42HY400ejAHY5NTP04GY804EjbI_5Rm4G<=:4hX442ABA5ADf5CFA5@BQP7211
RFJ]I_<00V:c00MR/UjbGY9NTUjbH[=R/P08GY802F:bG[5NTEZ@FW1FCU8]BPe5j`04ALX04DG[BPaB
;EI<FTaNSf:?HY5NTF:cI_E_>6mHKcQVmV:dHY<00V:A00=VdfKBGY400UY?00=JL5YaFW000U8^00IF
Cej@GY5JKUH]ETh3FVl015I>ETeFCEH]0UI=00AF;5H]EReF;@9B;@9B3@08DPaFCEY^EReB3EH]FTiB
;@9=k003DNa=k57/00AB309Ak004DPaB3E8]DR`2DP`0258/ER]BC58]DRiB;E8/ER`3ET`00eH/ETaF
C004ER/4ER`00eH]ER]FC003FR/3ER/015XZER]B34h=0Tg/00IB;CE9228000P0240334001@a1340<
@0`P34001@a100D@@1B1464@HA1000D@H@03444@H0aQ00<@H0<@H@@<@@04444@HA1Q464244423440
1Q1Q368@HA11464<H@8<@@8@@@07468@@A10440DHA1046000Q1Q0Q11111Q0Q1100L@@1AP460@HA10
444<H@0646423642344010a2368@HQ110Q1000H<H@a03408@0a034423682468446401aAR58<DPaB2
488@Pa2200<@P`DDPPP@HP<@PPT@H@D@HPd@H@06364@H@aQ464<H0a01`PP00`<@11P588Li2T5;DD]
935U=HHiQcVX?JT2?JP00cV7=FLeI`05=HL2=FL00cEV=HLeQ`05=FL00cEV=FLeI`02=FL00cUV>FLi
I`02>FL4=FL7=FH2=FL2=FH00cUV=FLeI`08=FH2=FD013EV<FHeISEW13EV0c5600HeASEU=FHeICE5
=DH<<FH2=FL00c5W<FHaIP02<FH2<FD2<FH9<FD2<DD1;FD1<D@1;BH00003<FLeASE7008eI`DiI`05
>FPeJ3EX=FPiI`03>FP5>FL00cEX>FPiJ00<>FP01CeX>FTiJCUX?HP00SV800HiRCf9>HTiRCf9?HP8
?HT00cf:?HTmR@0@?HT01469?HTmRCf90d6900<mRD69?HT00T690T6Y00=1RD68@JT00T6Y00=1R46Y
@JT0146Y1D6Z00A1RT6YAJU9j@99jP03BN]9jTW[00=9jP03BNU9jTWZ0099j`9=j`03CNY9jdWZ0099
j`05ANY9jTWZBNY9j`03BNX01DW[BNY9jdW[AN/00TW[00A9jTW[BN]9j`==jPI9jP99j`06BNYAj4gY
CNY=je7[14g[0dg/00==jdg/CN`00Tg/0Tg]0U8=00a=kDg^CNeF;UH_CPi9kTW]DPi=kDh>ES02EU00
1UI?FW1JL5Y`ETmF;P=FC`03FW1NLEY@009FD003ETmJKeY_009JK`AJC`04FU1FD5Y@FU03FTh3FTl2
FVl3GVl2FW02FU001UI@ETmFL5Y`FViJC@9JK@04FViJCUI>ETl2FW42EU402eI@ETiJCEY=GVmNSeY_
FTmJD5i`GY400UY?00MJL5ZAGY1NTEY`FTmNL002HY02GY000ei`FViNKP04FTh05UY_GY1NT5Z=I/aJ
KSeX=80lhD43@B=5IDeTCF95@C2Q9691If[<FXmJTUjB0Ujb00EJLEY`GY1N/Ej@009JL0AJL@9JL09N
T007FVmFKU8]DRe:3D7;@JX00Sf900diJ3f9?HU1ZTG/CReF;EI=FTiNLEYaGW9Ve@02JaL01F;EH[EN
TeiaGTl00Uj?00IFC58<DPa=kDG/?J/4>H/01d6[ANe5k47;@J/mZcV:00<iR@06>HPiJ3EX=FTiRCEY
0SE80SE900<a:2dW<BL00S4W00Da9S4W<BLa9S4600<a9P03<@Ha9S4W008a9`03<BH]1Rd600<a9`06
=DPiJ3V8?JU9jU8/0e8]00EB;5H/ETaFC5H/00QB;003ERaF;EH[00UF:`0:ERYF:dh<BPe9k4W[CN/a
20P21005340010Q1340<@0a01`a100@@@@aQ464@H0H@H@04460@@110440246034643344446434442
34401111464@H@aQ10a10Q1100`<@A11344@@A10460@HA1P320@H11Q56424642444344001111440@
@1100Q110a1Q00<@H0a134401@a10Q1100<<H@a03400111Q00@@HQ1Q464@HPLDPP04468@PQ23488@
46800`aQ368<HP0:46400a1R368@HP034645460346424602340222000`P01008800222004@a0440D
PAc39>@]8c4S=F<mYCfV?JLmZ3g9@LTmZ3V7=FH00SEW00<eISV6>HL01SF70cEW0cUW23EW00<iISEW
=FL02SEW0cEV0cEW33EV0SEU13EV00<eIcE6=DH00SEW0S5700<eASE5=DH00SE500<eAS56<DH0235V
1S560c5V2C5U0c540c5U0C550C540C5700000c5W=DHeA`02=FL5>FL01CUX=FPeJ3EY=FP00cUX0cUW
00DiJ3UW=FPiJ3V800`iJ0<iJ@04>HTiR3V9>HP4>HT01Cf9?HPmRCf9>HT03cf90Sf81Sf90T691Cf9
00=1RCf9@HT00T6Z00<mRD6Y@JT00d6900=1ZT6Y@JT0246Y0T6Z00Q1RT69?FQ1R4G:BN]9jTgZ1DWZ
0TWY00=9jTW:BN/02DW[0TWZ00=9jdWZAN/00TG[00E9jdG[ANY5jdW[0099jP05CNY=jDgZCNU=bP05
CLT024W:BNY9jdW[CNY=jDgZCLT2BLX00dW;BN]9j`03BN/02DW/BN]5bd6Z@HXmRT6[@JXmRP02>FT0
13f:>FTiJCUZ13f;00PmZd6/ANi:3dh?CPi=kTh>0U8=00E>3Th=CPi>;U8=009>3P=B3P05DReB;UH]
ETiFC@02DPd2ERh3DRh2ERd015H/DPeB358^0UH^00=F;EY@FTl00eI@00]B;dh?DS1B;e8^ETiJC5H/
DNa=kE8=009>3P03DPiB;U8_009B3P9B3@AB3004EReF;U8]DRd2DPd01Tg]DPeF;E8]DPeF;@9B3@03
DPaB3EH]00=B3004ERaFCEH/EPd2EP`05E8<FVeNKDG/?BL`P44S?BA194EVCFE9@dUU=>8/PD55FTeB
SdX>CReB;P02DTl015I?ERiF;UH^0UH_00EB;eI@DU1B;eH_009B;@09DRaB;Dh=ANe1bcfZ>HXeJ34V
00<]1@06;BHaB3UY?HY1bd7]0TX>00U>3UI@H]AReEjdH_IVeEYADN`00Tg/00Y>3DW/?J/eJ357<BLY
1RSV9<HTiP<Xi@09:>@T`bBR9:<Ta2SU:@DXi2C2008Th`0A9>@P`bCT9<@PXR20884TXRCT:>DTa22R
9<@Xa2C49:8TX`029<<29:<04RBR:<<T`bC3:>@XiBcU:>D/iBd6<BHeJ3V9?JY1bdW/DPeB;09B;@9B
C0UB;003DReB;5H/00IF:`=B;00<ER]F:UH[CPe:3Th<CPe9bbSW208401110`a100<<@0Q1340010a1
00<<8@a134400Pa100@<H@aR364<H@H@H@04460<@0a04402460346400a1R368@HP03464236401@a1
444<HA1Q4440111R00H<H@a1344<@@a2368246824442464436401Q1Q440@@110464@@@8@@005444@
HA11440<H@0246400a1R464<H@02344010a0220800`P0Q1R0Q1Q0a1R00@@PQBS58<@PP@DPP06568D
PQB2588DPaB20QAR00<DPQB34880311R00@@PQ23468@HP8<HP03468<HA1Q00@@H@8@HP03464@HQ1R
008@H@8@HP8@H@03440@HA1P00@<@08<800:220<80`P340@HAbT7<DTi2dU=DH2=FH01Sf7?JPmYcfX
?JLmQ`DiQ`8iIP03>FLiQcV600@iQP<iQ`PiI`<eI`<iI`deI`@eIP@eI`heIP04<FHeISEV=FH3=FL3
<DL00c56=DHeAP03=DH00c5V<DHaIP05<FH00c5W<DHaAP06<DH00c5W<FHaI@08<FD013EU=D@eA354
0c5U0C540C5700000c5W=DHeA`02=FL5>FL023UX=FPeJ3EY=FPiJ3UY>FP5>FL00cEX>FPiJ00<>FP3
>FT013V9>HPiRCV81CV90cf83cf900<mR468@HP00Sf813f90Sf800<mRCf8?HT00Sf900=1RCf9@HT0
0T6Z00=1RT69@HT01D692T6Y0d690Se700M1R4FYALU5bDWYBLU9bP02BNX2BNT00dG9BNY9bP03BL/5
AL/00dG:AN]5jP02BNX2BLX00dG:BNY5jP02BNX2BLX01DW9BLQAaTFVCLP00dg91DW900A9bTG:ALY5
bP=9bP03BLU9bTW:0095b`=5bP05AJU1RCeX>DLeA`03<BH01Rd5:>D]1Rd6:@HXiP<Xi@05<@LaB3f:
@La1k@02@Ld01d7>ALi5kDG]ALa1c4G<0095k@91c@03ALi5kDG^0095k@99k@04CNa9k4W]BNd2ANd0
1DG^ANe5kDG]BNd00Tg/00Y9kDG]ANe9kDg]BNe9kTh>CNi9kP95k`09@Ni5kDG]ANa5c47<@Ja5cD7=
00I1c0=1b`95b`06ALa5bd7;AL]1c4G;14G<00M1c47;AL`mRcf:?H]1b`08AL/2AJ/2@J/04T6Z?HTe
1SC1?@8m0d4TABA9AD44?>@``Bc0>BA1R47;@N]5k0963P03BPi5kTG]0095k@=5kP03BNi:3TG^0095
kP95k@06ANa5bd6Z?HTaAbSU0RST00`]12d3;@DXi2SU;@H]9cEX>JXmbd7<ALd2ANd2ANh03T7^@Le1
c4G<AN]5jSV9<DLeJ3V[>HXeJC5Y<DP5<DT01C58=FPiRCfZ>HT00SEY01HiRSfZALXmbSVZ?JXmbd7:
ALU=jEH9CLY5bTg[DPa=jdG;BJ]=beH[FRaJ:`9Aj`0EDPaF2eH<DP]F35Y>FVmJCeH^FU1NL5j@GY5N
T5I@BLe9kU8=DPaF;58]01=B;00@ER]B;58/DRaF:e8[DRa>3Dh]DRaB;TFZ7:D40@@0444334401@a0
2408@0Q034000`a10P`P00P<@0a1444@@A1Q364@H@aQ0Q110Q1Q00H@H0a0340<@110460346400`aQ
348@HP0244474642444546400a1R348<@P0234833443364234001@a1460@@11034001A1000<<HA11
44400`aQ00P<@@a0340<@0a1364@@A1Q1A1R00PDPQR2588@PQB258<DPQ220Q1R00<DHA1Q56802a1R
00<@HA1R46400Q1R111Q0Q1R00<<HQ1R36800PaR00<@HQ1Q46400a1Q0a1R1A1Q00<@HPaQ22000P@0
010880`P220880@0200<@1B07:8P`bSS;@<]93EV>FLmR0<mZ008?HPmZ3f8>HLiR3V7>FHiQPLiQ`Li
QP<iQ`PiI`<eI`8iI`05=FLeISEV=FHeQ`02=FH2=FL8=FH4=FL00cEV=FDeIP0;=FH00c5V=FHeIP02
=FH00cEW=DHeAP02=FL00c56=DHeAP05=DH00c56<FDaIP03<FH00c5W<DHaAP07<DH00c5V<FDaI@0>
<FD1<F@1<DL00003<FLeIcEW008eI`@iI`8iJ08eJ003=FTeJ3EX008iJ0<iI`03>FPiIcEX00<iJ003
?HPiJ3UX00DiJ08iR004>HTiJCUY>FT3>HT00cV8>HTiR@03>HT2?HT00cf8?HTmR@0;?HT00cf8?HTm
R002@HP2?HP5?HT3@HT2?HT>@HT6@JT2AJT034FZ@JU1ZD6Y@JY1ZCeX?FM1R4G9ALY9j@99bP95bP06
ANY9jTG[AN]9bdW:0TG:0dG;0TG:00=9jdG/BN/00TG:0dW:0TG[00U9jdG:ALY5bDW9BLQAadV6BLP0
0TW900A=jTg9CLU9b@99bPA5bP=5b`03ALY5bdG:00=5b`05@J]1ZT6Y?FTiB@02>DL2>FP4=DP01359
=DTa:2d70S4V00DeB34W<DTiRcV/008m[006?H`mRcf;?Ja1[3f/0T6[00E1ZT6[@J/mRT6[00=1c091
[091c003@J]1[46/0091[007@La1cD7=@La1[46[@L`00T7=0d7<00Lm[3f;?H`m[3g=@Ldmc@03?J/0
33UZ=DPeB3U9<BPa9c4X=DPaB34W<DPaA`8a9`03<DPeB3E800Da9`<a:0<a9`03<DLa9c4X008a9`05
<BHa9c4W<DLeAP02<BH4<@H01cE7>DLe9S3T<:8hhcd400=1900;@@@i1Bc3::4a13f9@L`mZcV;@La1
c@02@Nd2@Ld00dG=@Ni1c@02@Ld00d7>@Le1c@02@Ld02D7<@J/mZSV9=FLaAS4U;><Xa0029<@02RC5
:>DXiBd6<BLeJ3V9>HXmZcfZ0cf[00hiRcf/@Le1c3f[@J]1ZSEY;@Q63Uj_HaARm6;D0Ujc16:d0V:c
00AR/V:cH[=Re09Ve@0;I_AZlf[dJaE_=VlgLeMc=W<dLeIc=P02KaH016lgLcMc>7<h0W<g0W=G00Qg
F7MiNgUgNG]iMgQgF7Mh0W^J00]gNW=ILcMcF7^jNiQ[5E8`BPi>358<00MB;09>;A5B;00;DR]>;4h=
AP]>2U8=>DP<8@@0200<800232423445244734401A11468<HQ1Q4440111Q00D<H@a1344@@A10008@
@@8@H@8@HP04348<@@a14446464344401Q1Q468@HQ23468<HP8<@P<<@@04364<@@aQ360634400`aQ
444@@@0234000a10444@@@023443464646800aB368<HP`0258801QRS6:@HY1B3588@PPD@HP03464@
HQ1R00/@HP<@H@<@HP<@H@<@HPH<HPL@H@8<H@03464<@0PP00888005340800@0340DP@0246003Qc3
:>@]92dS=FDiQCf6?JLmbD79?JPiR3f7>HL6>FL;>HL5>HH5>HL01SUW>HLiQcV7>FLiQ`<eQ`03=FLi
IcUW008eI`DeIP<eI`LeIP<eI`DeIP03=FLeISEV00LeIP03<FHeISEV008eIP03=FLeASE6008eI`03
=FHeASE600DeAP03=FHaIC5V00<aIP03<FLaAS5600DaAP03;DLaAc5W00DaIP/aI@4aA04aA`0000@a
J3EW=FLeI`<iI`03>DLeAcU800<iJ003=FPiJ3UX008iJ08iI`HiJ0<mI`HiJ003>HPmR3UY00<iJ@04
?FPmR3f8?HP7?HT00cf8?HTmR@03?HT3?HP7?HT00cf8@HQ1R002?HP2?HT2?HX00cf9@HU1R@02@HT2
@JT2@HT01T68@HU1RD69@HQ1R@E1R003@HU1ZD6Y00]1Z@91R@06@JU5bDWZBNU9bTW;0dW:1dG:00=5
bdG:ALX01dG:00=9bTG:ALX014G:14G90dVX0TFX00=5bDW8BJP00TVX00E5Z4FYAJU5ZTFY0095ZPE1
ZP0?@HXmRT6:@HU1R3f:=DY5cEH<GVeNSEi^ETeF;EH^009B;`0<ERmNLF:`J/mRSdG<;<@a9cE9=FXe
JcV;0SU[00LeJcU[>H/iRSf:@JTmZP04?HX2?H/3>H/00cV<?H/mR`03?H/5>H/2?H/2>H/00cUZ>H/i
R`02>H/3>H`2>J`01SV;=FTa:2d7;@HXi@8Xi0079<<TY22T9<@XiBd6:<D00RC400<TaBS4:<@00RS4
00@Xi2SU:>DXi@8Xa@8Xi@0;;@H]1Bd5;>DXaBC4;>D]1BS49<8X``02:>@2:<<2:<@02BC4;@@a9C3S
<:8d`cT5@BA11002?@D01CD6<>@TP2RS=DT00bdY00<aBCF;>H/00SV;0Sf<0SV;00<iS3f;>H/013V;
00TmZSV:>FPaAS4U;@<X`bC37:<00aR300/HXabT8<@TiBd5;DLeIcUX>HTiRSf[00DiR`0:?H/iRSeX
=BPPYeZcMiEcUgNIMiX3Ni/2Mi/2MgX017NJNiYkVgMj0W=I00egFG=ILeUgNGMjLgU_FG=IMgUkNGNJ
NiYgVP04MgX00g=IMgUgN@06MgT017MILeQcF7=H1G=I00I_=g=ENiE_55YaALd2DP`6DR`0258[DRaB
;E8/ER]B;5H/DR`2ER`5ER/03UH/DPaB35H/DP]>2e8<CP]=jDWWCLX`iP@00003324010`P324<80a1
10Q110a100@<@0a1344@@@<<H@03444@HA1Q008@@@03440<@@a1008<@@8@@@L<@@8@@@05360<HA1P
464@@@0834400`a2344<@@0534400`aQ340<@@033442220334000``P220@@00646400aB2564@HP02
588011R2588DPQB211AR2Q1R0Q1Q2Q1R1Q1Q0Q1R1A1Q111R0`aR0a1Q0`aP00<<80PP22000PPP0P@0
00D<@1B27<<Xhbd4008]8`04=D@iQSfV?JL2@LP00d77?JLmY`04>HH2>HL4>FH01CUW>HLiQcV7>FL0
0cV700DiIcV7>FLiQcUW00diQ`<iI`8eI`03>HHeQcEW00<eI`@eIP03=HLeIcEW008eI`/eIP03=FDe
ISEV00XeIP03<FHeISEV00<eIP@eAP04=FHeACEU=FD3=FH3=FD6<FH5<DH3<DL00c5W<DHaI`02<FH4
<FD5<FH2<DH1<DD1<D<1<DL00004<FPeJ3EW=FL2>FL00cU6>DLiA`02>DL6>FP013UY>FPiJ3UW1CUX
1ceW0SeX00<iR3eX?HT00ceX0cf90Sf80SeX00DmJCf9?HTmRCf8008mR@03?HXmRCf800<mR0TmR@<m
R004?HTmRSf:?HX3?HT2@HT2@JT00d69@JU1R003@HT01468@HU1RD690d683T6Y0d6900A5ZDG9BLU9
jPA9bPE5bP=5b`95bP03ALU5bTG900E5bP03ALU5bTG:00=5bPA5b@03ALQ5Z4FX00A5Z@A9Z0A5Z@03
AJY1ZD6Z00=1ZP04@HXmRCf:?HX2?HT01cUZ=D]B3VlbLgM[56/E00=_5P=_5`0:JaIZm6ldMgQVScT6
::HXaS59<DX2<DT05C4Y=DTeBSEZ=FTeJ356<BLaB3EZ=FTaB34W=DTeJS59;BPaBC5Y<DTaB008=DT3
<BP01358<DTaBC590c5:00/aJReZ:DXY:BCW;BPmZd7;ANe1c3f[008iRP03>H/iRSf:00PmR`03?J]1
Zd7<0091c008?J/mRcf[@Le9k46/?J]5Z`9=k@04CLe9ZdFZCL/2DP`00e7/CNa=k@02CNd01e8/BN]1
ZSD5;84`Y3T5008m9009?@@e1C3V:<DTP3eXDTmBLSF=008Tj@03:>PY1bT700<Y1`03;BP]:BdY008]
:004;BLY22T79@H2:@H29>@012C38:<HPQ100P`000L<80P0200<811158<LX`028<<02BCT:@@Y9RdW
:BL]9bdX;BLY1`02:>H02Bc4700HA4i@MkMg^G=GLeQ_F003LeT02FmIKcQcFG=IMgUkNWmiMgYcF@02
KcP02G=iLgQ_F5kEF[EBDUjCI_EcF@02LgT4JaL6JcL2KcL5JcL2JaL02f/gJaM[5f/FKaEc=6lEEU0m
Zdg[DP`00U8/00EB358/DR]B;58[00=B;004ER]B;5H/DP`2EP`5EP/2ER`00e8<EPaF2`02EPX01E7Z
EPYB2Tg]<>P00P@00``Q00D<80a1320<80PQ00<8@@@<@@08340<@@a1344@@0a0440<@@<@@@04440<
@0a1340;344010aQ444@H@aQ0Q1Q20a10Pa200<<@@a2344010a100<<H@a134401@a100<<HQ1Q4680
111R00@DPaR368<HP`@DPP8@PP`@HP0346<@HQ1R00<@HP03464@HQ1R00T@HPH@H@8@HPL@H@<@HP03
3688@@PP00D880042008811P6:<27<@02b3U:@DeIC55=FE1YdGY@NU1b46W?JL00cf61cV60cV70cUV
0SUW00<iQcUW>HL00cUV0SV70SUX00<iIcV7>HL02SV70cUW00<eIcF7=FL00cEW00<eJ3EW=FL01CEV
0cEW33EV00@eICEV=FDiIP@eI@03=FHaISEV00DaIP04=FHeIcEV=FL3=DH00cEV=FDeI@06=FH00c5U
<FHaIP05<FH3<DH5<DL2<FL2<FH3<FD00c5V<DHaIP02<FH3<DH1<DD1=D@1=DH0008eJ003=FLiAcUW
00DiI`@iJ0@iJ@8iJ08iI`8iJ08iI`HmI`06?HLmIcf8>HPiJ3UY13eY00<mR3f9?HP00Sf80cf913f8
0cf90Sf800<mRCf8?HT023f900@mR469@HU1R@DmRP03?JY1ZD6Y0091Z@U1RA91Z@=1R@04@FQ1ITW7
BNT2BLT2BLX8ALX2ALT014W9ALU5bDG90TG:0dG900E5Z4FYALU5bTG900=5b095b@95Z0=5Z@03AJQ5
ZDFX00A5Z004AJU5Z4FYAJT4@JT2@HT02SeY?FXiJCf9=DXeK58]Lc1ZlFKB0VKC00MVe6KdI_AVm6KD
H]=Vd`02KcD01fJ_<>HD0aaT78<LY22T008Pa@0:9<@PY22T8:@Pa2S39<<LXaR27:<39<@01b348:@P
Y22T8<@PaB3400<TX`DPY00F8<@TiBT59>@PY1bT8:DPaB2U8<DPYAbT7<LHQR3W?LeN/F/AH]9VdfKD
I]<5I]@6J]@01f[eJ_A_5FlFKaE[5V[e00=Ve003I]=Ve6[D00=Ze006J_EZm6kdKaE_56lE0V[d00YV
e6[dKcE_=7<bH]55ZcBS<:@m1@91900<?B<diC379:D/iEj>MgE_FDWb78P<1AbW0R2T0R3400DTi23U
7:@HPb2T008Ti@8Pa@8La0067:<HPAA0564@@@PP0P@01@0000L400PP460DH1bQ8<<Th`028<<38<@0
32339>DTiAbV88@PA1aUCTmgMG=ELeI_=P=_=`03JcQ_=flg009_=`03JcM[5f/G009[5`0=JaI[5f/f
KcEVm5YaBPm1STW>FU5Vm6ldJcH00f/G00A[=f/fJaM[=`M_=`03JcM[5V/f009[=`9[5`0:JaI[5fkf
LcM_5UH?>HU9jE8:ER/2DP`4DR/2DR`2DR/00e8/ERaB3002EP`5EP/2ER`0158<EPaF2eH:0UH900UA
jUX]BLhXZ@@0200<8@`P324010`P00<88@Q124400PQ100/<8@a1344@@0a0440<HA10340@@0a1008@
@@8@@0@<@003444<@@a100D<@@8@@006364@H11P464@H0aQ10a10`a01Pa10`PP00H<@0a1220880a1
3683468021B3468@HQ1R58<HXaRT68<35683588346800a1Q468@HP08468346<446800a1Q468@HP04
4642468:46402Q1R464@HA1Q460@@11P440<@0Q00PPP00h8@0PP220<@11Q6:8La23S9>@]93EW>HLe
IcVY0T790SfX00@mYcf7?HHmQPLiQPDmQP04>HHiISV7>HL4>FH00cUW>HLiQ`04>HL01CUW>FPiJ3UW
>FH00cV700<iISV7>HL01CV70cUW13EW0cEX0SEW00<eICEV=FH03CEV0cEW00DeISEU=FDeICUU008e
I@8iI@03=FDeISEV00DaIP@eIP<eAP03=FHeICEU00HeIP03=DDaIC5500@aIP@aAP@aA`@aAP8aI@03
<FHaIC5600LaAP4aA@4e@`4a9P0000@aJ3EX=FLiA`HiI`<iJ08iJ@03=FTeJ3EX008iJ0<iI`<iJ0Pm
I`05?HPiR3eX>FPmJ003?FT00cf8?HTmR002?HP013f9?HPmRCf80Sf90Sf800@iR3f9?HTmR08mR@8m
R0@mR@03>HTmRCf9008mR@91R@DmRP8mZP04@JY1RT6:@HT4@HP3@HT00d6:@JY1Z@0A@JT01dFY@HTm
AT55BLU5bTG800=9b@03ALU5bTG:00E5bPM5b@05ALY5bDG9ALU5b009ALT4AJT00d6YAJU5Z@02AJT2
AJP00dFWAJQ5Z002@JP2@JT01T6X@HQ1RD68?FTmJ08iJ007>FXiK5I>K`mV/6JbH[<00f;C00=Vdf;C
H]<00V;C00aVm6lFER`/iaaU64<LPQQR688LY2347:<266801Ab3788LPBCT:@H00RT700lXiRT6;BL]
1bSV8<DTiRT7:@PXibCU9<@XiS4X<DT00c4X00@aB357<DPaA`<]B003<BPaBC4X008a:00:;@PY22dY
DU1[EfmFLeM_EflgKcP3LeP3LcP<LeP4LcP00g=ILcQc>002LcP6LcL4LcP06W=GMgQ_M6LfBNdhiCBT
>>Dm13d3?@8dhcD69:8]9V;aNkMk^eIA@Ha1[TG?BNi5cD7<ANd4CPh2BPl00dX>BPm63`02APl01d8>
@L`mZSV8<DL]11R2008@@009688DHAAQ6:8/i34U>FLmZT7[009:;`04@NheRSE9>FX2=DP02T7=DRmF
LUH?CJa9[V;DLeIcEgLf0VlG00=[=flgJcL00f/g00=_5f/GJaL00f/G00eZmfLGIaM_=F:bCNe5S58@
DS1JL6KCKaA_=P03JaL2JcL4JaL9JcL2JaL2JaH02FlFK_Ec=W<DEP`iR4gYEPYF:P03DR`0158;DPaB
:e8/0U8[00AF:U8/ERaB309F309F2`03EPYF:eH[00=B;00;ERaB35H;EPYJ2U7ZCN/mJa1400040004
32400`a1324<@@042442224834400a10344@@@0344400`a0344<@00:344636483442340334402`a0
220880aR468<HQ1Q468DPaBT6:@00QB300<HY1S56:@00QB300@HXaB2468@HP8DHPL@HP03464@HQ1R
00T@HP<@H`D@HP<@H@8@HP`@H@05340<@@a02208000422003@`P464HXac48>DY9Be5<FDeQcVX?LY1
jT7[0091bP03?JTiR3V7008iQ`<mQ`03>HHiQcV600`iQP<iQ`<iIP03>FLiQcV700@iQ`@iI`@iIP03
>FLiQcV700DiQ`@iI`PeI`<eIP03=FLeISEV00LeIP<eI`@eIPHeI@03>FDeICEV008eIPDaI`8eIP03
=DDeASE6008eAP03=FHeICEU008eIP04=DHeISEV=FH2=DH01356<FHaIS5V0c561C5W1S5600@aIS5W
<FLaI`@aAP05<FDaAC5U<FDeA001=BD00004<FLeIcUW>DL6>FL4>FP013UW=FPiIcEX0SUW1SUX13eW
0ceV00<mIcf8>HP00cf80SeX1Cf800@mQcf8?HPmR0<mR@04?HPmQcf7?HL2?HP01Cf7?HPmQcf7?HP0
2Sf91Cf:00XmZT6Z@JY1ZT6:@HU1Z46W@HQ1Z091R005@HU1ZT6Z@JU1ZP02@JT00dFY@JU5Z@02AJT6
@JT3AJT01TG9@JU1R3e6@HQ5b@=5b003BLQ5bDG:00A5bPI5b@03AJQ5b4G800A5b@03AJU5bDG900M5
b@05AJU5Z46Y@JU5ZP04AJT01DFX@JQ1Yd67@JL0146X0T680cf800TmIcf8>FPiJSf]FW1_4VJ`H[<0
0f;D0VKD16KC00ERe6;fDRlm[47>009B;`0BBPm>;dh`APi1c3f[>FXa:CUZ@LaFCeY^ERiB3TW^CPiJ
D5i`0UY@00UFD58?CPmF<5iAGW5JD5YAFW400UY`00QNL5YaGW1JL5Y_FW1JCeYa0eia00eNL5i_FU5B
3e8_GY9[=VmEJaAZm6KeJ_I[5`02I_H01F[fJaIZmV[eJaH00VlF00=[5V[eI_D00VKe00IZmF/FI_EV
mV/GJ_L4J_H2J_D4KaD2KaH2J_H05V[gKaM_=g=FMiIW557;?>@ha3cT?><lhSSP=>4/`B1P=DIN[GNE
LeIc=Fkd0V[E0V[e00=Zm6[eKaD00VlF01i_5f[fI_M_>7<iKcQ[5flhJaIVdV;@EW1:;CfY>HPiACDU
;>@a9C44>DI1ZDh]HXmVl6mDKeE[56KCH]D2I_D026KDHY9Ze7<fLeQgF7<fLaH2KcL00f/FKaM[5`02
KcL01FlFJaI[5V/GKaL00f/G0V[f00eVmf[gJ_M[5f/EI]AJLEH_DQ1JLVKCJ_A[5@05JaH7JaL2JaH2
KcL00f/GJaI[5`04JaH02F[eJ_Ag=FkbGT]5QUH7EPUF:P02ER/2DP`2DP/4DR/00e8/DPaB3002EP`2
EP/01EH:EP]F:e8[ERX00UH[00YB35H[EN]AjDW/BN/a20@2000800L88@<8@@888@88@@L<@@03440<
@A1100D<@@03340<@@a100D<@@03340<@@a100D<@@03364<@@a1008<@@08320<@@a0220<80a0344<
@P8@H@<@HP0358<HXaRS00<DPPP@HP03464@HQ1R01<@HP04464@HQ1R468246<246800a1Q468@HP03
46400a1R464@H@034644340010`P220<80`P0`PP00/<@1AQ7:<L`b33:><a93E4=FHiQSV8008mZ005
@JPmZ3fX>JPiQ`02>HP5>HL00cV6?HHmQP02?HL00cV7?HLmQ`02?HH013f5>HHiQSV60Sf600@mQCV6
?HHiQP@iQ`03>FHiQcUV008iQ`<iIP03>HHiQcV700HiIP@iQ`PiI`04=FLiISEW=FH2=FL4=FH00cEW
=FHeIP02=FH2=FL00cUV=FHeIP03=FL4=FH8=FD3=FH00cEW=FHeIP02<FH4=FH3=DH4=FD00cE5=DHe
AP03=DH00cE5=DHaAP07<DH4<FH2<DH6<DL3<DH00c55<FDaI@03<FD1=D@1=BD00005<FLeIcEX>DPi
J006>FL5>FP013UW=FPiIcUX0cUW00<iJ3UW>FP01ceW0Sf71SV800<iRCf8?HP00Sf800@mQcf8?HPm
R08mR@03?HPmIcf7008mQ`04>HPmQcf7?HL4?HP:?HT5?HX01Cf9@HY1RT6:@HT00T6X00A1ZD6X@JU1
R@91RP=1ZPE1Z@95Z@I1Z@A5Z@95ZP0;@JTmR46YAJM5b4W8BLU5bDG:ALU5bP08ALT3ALP6ALT3AJT0
0dFX@JQ5Z@05@JT2@JX4@JT2@JP3@HP2@JP01468?HPmR3f71Cf800LiJ3EY@LiJT6/CH[5Rd`03H]@0
16:cI]AVe6KD0VKC01=Vm5keDW9BCf;BJcI_=V/gIaI[=flfH]AFCe8?ES1JLF;CJaE[5004J_D01FlF
J_EZmFlFKaL00V/G0VlG00=^mfkfK_H00f[f0VlF00I_5F/EJaE[5FlEJ_H2KaH2K_D2KaD01F[CHY5R
/V/EI_<00VKd16Ke1FKf0VKe1V[e00AZm6[eI_EVmP9Vm@AZm@EZm003J_EZm6[e00EZmP0CLcIgMF[c
CL/la3RT?>@lhccR>>4dhRB1740a9FKaMgI_56[dJ_D00VlF00U[5VlGLcM_=flEK_E_5FlFJ_H00V/G
00a[66/GJaMVmV;EH]9NdEZ]CTliZSF9<BD2;@<042T4;@@eIcf9BPeNSV;BI_9[56lDLcIcFGoMOoio
gG=H0VlF0V[e00MZe6[eJ_EZmF/FKaM_=`02KaL016lFKaM_5VlF0f/F00i[5f[fJ_IZmV[gJ_I[5flG
I_IRTfKELcU_>6/F0V/E1V/F1f/G00=_5V/FJaH026/F00U_5G]fLa9RJD5SDNIF:EH9ERX0158;00=B
2U8[DR/0158[01IB;58<ERaB358;EPYF2e8:CP]B:U8[DP]>34g/DN]>2dh^CP`/j0P3000880H88@@8
@@888@88@Al<@@03444<@0a1008@@P03468@HA1R008@HP@DP`056:@Ha1RT6:@DP`04568346800a1Q
468@HP0H4682464746801A1Q468@HQ1R46400a1R0Q1Q00<<@0`P34001@`P00P@8110564La2d5;B@a
93UV0cf700M1ZDG:ALY1ZD79@LXmZ@03>HL00cV8>HLiR005>HL01CV6?HHmQSf6?HL013eW00<mQSUV
?HD00cV60SUV00<mQSV6?HH00SV61CV700<iQSV7>FH00cUV00<mQSV6>HH01SUV00<iQcV6>FH00cUV
00<iQcUW=HL00cUW00DiQcUV>FHiISEW00<eIP03>FHeISEV00<eIP<eI`07>FHeISEV>FLeIcEV=FL0
1CEV1cEU0SEV00<eIcEV=FH01SEV0SE60SE50cEU00<eACE6<DH00S5600@eASE5=FDeIPDeAP03<FHa
AS5V00<aI@@aAP<aA`@aAP07<DDaIC5U<FDaA35U<DD00C4V00001S5W=DLeB3E7>DPeI`DiI`05=DLi
B3U8>FLiJ008>FL01CUV>FLiIceV?HL01CeW00<mQcf8?HP00SV800/iJ3f8?HPmQceW?HLmR3f7?HPm
Qcf8008mJ003?HPmQcf700DmQ`8mR0<mQ`8mR0DmR@04?HPmRCf9?HT2>HT4?HT01D6:@JU1ZD6X@JL0
0T6X00E1ZD69@HU1RT6Z0091Z@04@JQ1ZD6Y@JT2AJT5@JT00d6XAJU5Z@02AJP00d6X@JU5Z@02AJT0
0dFXAJM5b002ALP4ALT3ALP3ALT00dG8AJQ5Z002AJP00dG8ALU5b@02@JT00dFXAJM5Y`02AJP4@JP7
@JT00d69@HQ1R003@HP2@JP00d67?HLmQ`04?HL00cf8>FPiR002>FP01D7/FY1[4f;BH]<00f:d0V:c
0VKD00YVdfKBJaAS5EJBDRYVkFKbI_ARd`9N/`09G[9N/Ei_EPe=kTh>FY1Vm6Kc009NTP06HY9R/V:b
HY9R/VKC0VKD0V:d00ARU6:CHY=RT`AR/`9Ve00>H[=R/V:bH[9R/fJcH[=V/f:cH[9R/6K?GXiRd@9V
l`9Vd`9Ve09Vm@=Ve@AVm@0:J]EZe6[DJ]AVe6KdJ_AVmFKfI]D2I_D3J_@5J_<01F[CJ]AZe6[EJ_D0
0V[f01AZmfKGJ_E_<f;ACL/h`cRS@<A0hd3Q?@8dhBQP720a0fLDLeIVdVKD0fKC1FKD00AZm6KDI]AV
e0=Ve@=Re@08G[=N/EY[FXU62cfZ<DHa908X`@0?8:4/hS44>FQ9k5H[FTiNTF;AJ_9VdVKCI_AZm6KD
009Vd`AVe005I[=Zdf[dJaI_5P02JaH00flFKaE[5P05JaH00f/GJ_IZmP02J_H01FKfI]IVeVKfJaL0
0flg00E[5V[eJ_EZmV/E00A[5P9[=`9[5`04JaI_=flgKaH3JaH3JaD04VLFJ_E[5FlFKcIgMg<AGRDe
04FSDPQF:5H9DPYF2UH9DPYB:@AB:P05DR]B:U8[DP]B3004DP/00eH:DP]B2P02DPX2DP/01dg[BPe>
CdW/:<H40P0100P88@032408@@Q100888@03244<@@a101D<@@8<8003344@@@a000888003344@@A1Q
00D@HP06588DHQB26:<HY1R30QAS0QB300<DPQAR5680211R1Q1Q211R0Q1Q1a1R1A1Q00<@PQB24680
1a1R00@@H@a134488084000@220<80`P220<@1R27<<T`bd3=B<eA3f6?JQ1Z3fX@JL3@JP013fX?HPm
Qcf70cV700@iR3f7?HLmQ`TiQ`04?HHiQSf5?HH4?HL00cf6>HHmQ@03>HH00ceU>FDiIP05>HH00cUW
=FLiQP02>FH2>HH013UV?HHiISeU0SV51cUV00<iICUV>FH00cUV0cV70cUW0SUV0SEV00<eICUV=FH0
0cUV0cUU00<eISUV=FL00cUV00<eISUV=DH00SEV00<iISEU=FD02SEU13EV00@aACEV=FHeI@@eA@04
=D@eHcE4=D@2=FD3<DH00c55=DDeI@02=FD2=FH013E6=DDeASEU0c5U00<aA355<DD0135600<]AS56
<DH00S5600<eAC54<D@00S540S550C4V00000c5W=DLeA`02=DL3=FL01SU6=DHiASU6>DLeA`HiI`04
>FHiIcUW>FL2>FH00cUW?FHmQP06?FL2?HL3>HP2>FP2?FL00cf7?HPmQ`02?HL013UW?FLmIceW0Sf7
00<mIcf7>HL023f70Sf800<mZ3f9?HP01Sf800<mRCf:?HX00cf:00<mRD68@HL0146700=1R469@HT0
0d691D681D6X0d6Y0TFX00E5ZDFXAJU5Z4FY0095R005AJM9bDWYALQ5Z006ALP4AJP2AJL3AJP014G8
ALU5Z46X0d6W0T6X1T680T6X00U1ZD6X@HQ1R3f8@HPmR468?HP00Sf700DmISeW?HLmQcf6008iQP09
>HLiIcV8>FLiAT7;F[1VlV:b00ER/`0<H[AR/f:cI[9VdFKbF]9BCTFYGXe[4eja0UjA0UZA00QJLEI?
CL]=kE9@FY9J/eZB0UjC00=N/f:bH[800f:b00=R/f:bHY<00V:c0V:C1V:c0f:b00AR/f:bH]=R/PAR
d`04H[9R/F:aI]84I]<00fKeI]AVe@03I]D01FKfI_EVeFKeI]D016[D00AZm6KdI_=Vm0AVe09Zm09Z
l`03J_9Zlf[c009Zl`9Zd`9Ze00EJ]EZmV[FI]IZmFlDH[99bcSU=:A0a43S@<4l`32R960D03E4HcA[
4fJa009Ve003I]=Ve6KD009Ve004I_EVdfKCI]<2I]@4I]D2H]D05ejcGY5JK5YYAP]1ZCUV=D@]0C41
;>0iA3UV@JU:35I<GVmR/VKCI_9VlfKCH[400V:@00YV/V[dJ_EVmF[dI[=V/V[DJ_E[5P=[5@=[5P=[
5@=Zm@9Vm@EVe@9Vm@03J_I[5V[e00=Zm@07JaI_5V/FKaI_=g=HLeT00Vlg00A_5f/GKcM_>09cF0=c
E`0=KeQ_EflgJaIVmF/FLeQcEg<eHTHdh465DPT00UHX0U8900QF2E89DPUB:E89CRU>:Th;158:158;
0U8Z0e8:00U>2UHZDPa63DX^?HPLQ001108020PQ00@8@@@Q22448@888@03244<@@a100X<@@D<@P03
344<@Pa2008<@P07220800P0320<@Q1R46<00Q1R00D@HaRT6<DHY11S00DDH`03568DHa1S008@HaL@
HP/@H@03468@HA1Q00D@H@08460<@0a0460@HA10460<@088800@100800`P460DPQbS8>@]9C55<B@e
ICf6@LQ5b478@JL2@LP00cfW>HHiIP02>FH00cV5>HHiQ`04>HL00cV8>HLiQ`03>HH5>HL3>HH00cf6
?HDmQP02?HH2>FH00cUU>FHiI@03>HD00ceU>FDiI@02>FD00cV5>FDiIP02>FH01SUW>FHiISV6>HDi
QPDiQ@<iIP04>FDiISUV>FH2>HH00cUW>FHiIP03>FH2=FH00cEU>FDeI@02=FD2=HH2>FH4>FD4=FD5
=FH2>FHA=FD3=FH2=DH2<DD5=D@00cET=FDeA@03<DD00c56=DDeI@03=FD013E6<DDaACE513550S5U
13550Re60S5600HaAC56<DHaAC54<D<3<D@1<DD1<BL00005<DLeASE5=DHeI@05=DH3>DD5>DH4>FH0
23f7>FHiICU5>FDmQSf5?HH5?FH3>FL2>FP2>FL2?FL4?FH3?FD2?FH01CeW?HLmIceW?HL00cf600Hm
Qcf6?HHmQCf6?HL3?JL0146X?JPmZ3fW0Sf700@mQSf8?HTiR@8iJ@8mR@05?HPmQd66@HI1Q@02@HH2
@HL2@HP00cf7@HM1Q`03@HH2AJL7@JP00dFX@JQ5Z002AJP01d6X@HQ5Qd67@HI1QD6V00=5YPU5Y`07
AJI5YdFWAJM1Yd6V@HH00d6W0d6700A1R467@HM1Q`PmQ`8mR004?FLmISeV>FH4?FH03cUV?FDiQCUU
>FHiQcF8>DHe0dW[G]1VlF:aG[9NT`02G[<2H[<2H[804FJaI[1Rcej_DRe=jEj>I]9N/EjAGY1N/Ej@
FY5FCe8=FTl015jB00=R/f:bH[801F:b0f:B00AV/VJcI[=V/P9V/`03I]=R/f:b00=R/P03I[9VdVKB
00IVdP04I]=VdVKBI]86I]<00fKDI]EVe@04I]D016[dI]AVe6KD0VKC1FKc0fKB0V[b0f[B00IZlV[c
J_=ZlV[CK_<2J]@3J]D2KaH04G<fG[99c3S5=8Dla431@<0hX32Q940H04FWIc=cDf[AJ]@01V[d00AV
m6[dI]AVd`=Ve0=Ve@9Re00CH[=NTEY<ERU:2d79@JLmQCeT>F@mQSf7ALU9jeH[GXiR/FKCJ_@01f[c
0V[d00=ZmF[dJ_@00f[d0V[e16[d16[c0VKc0VKC00ER/fJcI]AVdfKD009Ve@04I_EVmV/EJ_D2I]@0
0f[dJ_EVm002I_@2J_D2I]@01F;DH[AR]6;DH[<00V:b00IR/F;AH[5N/F:aH[<2GY802F;EIaM[5fKc
GTQ1I466DPUF1`04DPL01U88DPMB2587CPQ>2@9>2P04CPUB2E89DPT2EPT01589FTUJ:E7Y0TgY00Y>
2E88DRa1k4H>=BDD8@@022888@8880888@0412488@PQ2242220622433242348534400`PQ348<@P02
348334400`a236<<H`0246800a12468@HP0258@346<00a1R46<@HP0546<00a1R448@HP0446<64680
0`a2368@HP08468946400a11464@H@05464346001a10340880P0100800`P008<@00:320880a07:4T
hbd3;B<iQD77ALL5@JL4?HH01CV5>F@iQ3UU>FH00cUU00<mQCUU>HH01CV700HiQSV5>HDiQCUU=FD2
>FH4>FD013f5?HHmQCf513UU00@iI3EU>FDiI@<iI003?F@iI3UT008iI005>F<iI3UT>HHeI`02=FD0
13V5?HDiQ3UT1CUU00DiQCUU>F@eICUV00<iQPDiIP@eI@8eA08eI006=HDiQCUU>FDe@cUT0SUV00<e
ICE5=FD013E50SEU00DiICEU=D@eA3E3008eI0<eI@03>FDeICEU00DeI@03=D@aACE5008eA@8aA@03
<D@eA3E300<e@`03<D<eA3E4008eA003<D<aACEU008eI@03=DDaAC55008aA@03<D@a9C4U008aA005
<DDaA355<D@]9@02;DD2<DD02354<B@aAC55=D@a8cE2<B<3<D@1<BH00003<DLiASE600PeAP05>DHi
ACU6>DHiA@04>DH00cUU>FHiIP02>FH5>FD3>DH2>FH013UW?FLiIcUW0cUX00<iIceW?FH00ceV0ceU
0SeV00<mIceV?FL00ceW0Sf700@iQcV6?FHmQP@mQ`<mR0@mQ`04?HHmR3V8>HT3>FT00cf9>FPiI`02
?HH013f5?HHmQT661D6700=1R467@HL00d6700A1R467@HM1Q`8mQ`91Q`03@HQ1Yd6X0091R004@HM1
Ice5?FD2@HH3@JH2@JL014FW@JM1YT6V0d6600=1QD66@HH00T6600=1Qcf7?HL013f700@mQSf7?HLm
Q`8mI`8mIP<mQP8iQ`8iJ003>FLiISUV00<iAP<iIP0=>FDiISEU=FDaIC68=BHi0dWZFXiVcej`G[40
0ejC00AN/f:cH[9R/P9R/@05HZmRT5j@GXiNS`02GY04G[400ejbH[9R/`02HY801f:AGY9RTV:cHY9R
/V:a009R/P03H[=R/V:c009R/P03I[9V/fJb00=V/`08I]=R/fJcI[9V/fKCI[=V/PEVdP04I]=VdVKB
I]88I]<4I]@3I]D6I]@016KcI_AVlfKc0VKB0fKc00AZlf[BJ]9ZlP=Vl`03J_9^lf[C00AZd`0CJ_A^
m6kcJ_9JL45Z;68/I3BS@>50h3RP;84P82PPAHQS<gMdKa800f[c1V[d00=Vm6KcI]@00fKD01IVmFKE
I_EVe6:bGY1JC5HZCP]5bT6X?HHmICUU?LPmYdX;GV]R[Ej=H[1VdP=Zl`03Ja=Zlf[c009Zl`9Zm003
J_EZm6[d00=Zm003J_EZm6[d00=Zm0=Vl`EVdP9R/`04H]AVdfKDH]@2H]<09EjcGY5B3TW]DPiB;Th=
CPaB;EH^DRiB;E8^CPe9k4W<BLe=k4W:AJU9bDX:ANU5bDFYALU9k58^DRmFL5kCH]=NdUXZAJLmITWY
009B1`==i`9>1`05DPM>1dh8BPU62@02BPX014h9DNUAj57Y0UH900iAjE7XCNQ=j4WYANU:2TH;@NY6
;3DR400800@00PPP1PPQ00H880PQ22448@PQ228222443243348010a12448@Pa120a200@<Ha1T48@@
I08@H`0348<@H`aS00<<H`0534<<@PaR368<H`0346<446800a1244<<@`033483368336<010a2368@
HQ1R1A120Q110a1Q111100H<HA11464@H@aP34022202320522001a10460DH1R17<8Thc54008eI@07
?HI1YT78ANQ1jD6W?HH00Sf50Sf60cUU00@iISUU>FDiI0@iI@8iQ@8iQP03>FLeIcEW008eI`05=FHe
ICEU=FDiI@02>FH013F6>FDiICUU0cUV1CUU00<eICUT=FD00SEU0SUU00@iI3UU>F@iI@@iI003>FDe
ISEV008eIP03=FDiI3UT008iI0<eI@05>FDeICEU>FDeQ`02=FH3=FD2>FD01cEU=DHeISEV<FHaACE5
00LeI@0;>FDiI3UU=FDeACEU=DDe@cE4=DDiI@02=DH01CEU=DDeA3E4=D<01CE400@eICE5<DDaA@De
A003<DDeACE500@aA@8aA08a@`05=D<eA3E4=D@a@`04=D@00c55=D@aA@02<D@2<DD4<BD01C55;DD]
A2e4;B<00RdT00<]AC55<DD00S5500Da9C55<DDeAC53008aA04a9@4a904a90000RUX00<aIcE5=DD0
1CE60cE500<eASU6=DH013E600<eACU5>DD00SU60cU500<iA3U5>DD00SE500DiACUU>FHiISUW00<i
J0<iI`8mIPHmI@8mIP@mI`06?FHiQSUV>HLmQceV0cUV0SUW0cUX00PmR3V7>HHmQcf5?HLmR3V80cUY
00<iB3UX>FL00SUU00HiI3eU?FDmICeV?FL4@HL2@HH0145V@FM1Qd5W13eW0SeV0d6600E1Qd66@HM1
Qd5W00<mIP06?HI1QD65@HE1QT6V0d6600=1QCf5@HD014650T5U0SeU0cf60cf500<mQSeV?FH00ceV
0SUU00<mICUU>FH00cUW00<iASU5>DD00SU50SU60SU500`eA3E5=DDeICUU=FLe9Se6ALYFBej[GZh2
GY401EjBGY=N/f:cH[800V:a00=R/6:?HY000f:?0ej@00ER/6:aH[5R/V;C00ER/P=RTP04IY5V/FJb
I]<2I[<01FKCI]9VdVJbI[<00VJb00EV/fKCI]9VdfKB00IVd`AVdP=Vd`03J]=Vdf[C00EVd`05J]=V
dfKCI]AVd`05I]@6I]<016KBI]=VdVKB0VKb0V[b0f[B00=VdV[bJ_8016[B0V[A0f[@019VcfK=ER]1
JCRU=8Dhi441@>4hP2b286@/PSe7DVaVkFK@J_82J_<6J_@00fKDI]=Vd`02I]<05VKdI_EVmFKEI]AR
/ejAFTaF:TgZALQ1QSe4?F@mHcf5@JI5b4gYERUNJV:>0VKA0V[b1f[c0f[d0V[c0V[C00=ZlfKDI]@0
0fKC16KB0fKA00=V/V:bH[<00f:c00UR/VKcI]ANTE8>CNiB;eI>DRd00UH]0e8/0e8=0U8>0UY?00MF
;E8/ETaJKUI=ERaFCP02FW003Ui`G[9RdVKbG]5J:dVYAHM9YdW5CNM=iTWWCNL2BNH01DgVCNM=idX8
BPT00TWY00=9j4gXBNL00TWX00=9jDgXBLP00dW800Y5b4FX@JM5acfT=@0H81@P2008808400<40@84
8@0310048@PQ00<88@03228<@@`Q00<<8@D<@P8<HP8<@`8<@P8<HP8<@P0934<<H`aS46<<H`aR36<<
HPaS00<<@`03348<@@a2008<@P8<H`0546<@@Pa2348@@P0534800`a1348<@@0534800`a1348<@@05
348234400a10444@@00544400a1Q460<@00334024440311Q584DPARQ7:8P`bCS9<<Xhc4R=D8eH`8e
I005=FDeA3E4=FDiQ@02=FD01SE4>F@iI3eU>FDiIP/iI@05>F@iICUV=FHeI`03<DH00cE6=DDeI@02
=FD2>FD00cEU>FDiI@04>FD5>F@2=F@3=FD01CUU>F@iI3UT>FD00SUT00HiHcUR>F<iI3EU=FH2=DH0
1CEU=D<i@cU2=D<01CE413EU00HeACE4=D@e@cE4>DD4=DD01355=DDaACE40S5400<aI3ET<D@013E4
0SE50SE40SE300<iACE5=DD00cE500@iACE4=D<eA08a8`03<D<aA35400@aA08a9006<D<e@cE4=DDa
AC560c5500La92dT;@<a8c4R<D<eH`02<D<01CDT<B<e93E4<D@00S5300<a@S54<D@00S5500<a9C4T
<BD00RdT00/]8be3;B8]8bdT;BDaA2e5;B@]12dU00<a9@8a9003<B<]92dS004]0`0000@MJBh89FLa
9`DaA`@a9`05<DLa9c4W<BLaA`03<BL01357<BLa9c4W1CE70cDW00DeB3E7=DLeAcU800<eB003=DTi
B3E700TiA`03>DPiAcU7008iB0<iJ005>DPiJ3UX>DPeA`05>DP2>FT013EX>FTiJCUX0SUY00<eBCUY
>FT00cU900<iB3UX>FP00SUW00@mIceX?FPmJ0@mJ@04?FPmAd5W@FP2?FP013eY?FPiJ3U81CeX00Dm
JCeX?FPmJ3eY00<mJ004?DPmIcf8?HP2?FP01Cf8?FPmJ3eX>FP00SeX0ceW0Se700DmB3U7>DLiAcUX
00<iI`05>FPiAcU7>DLiB006>DL013U8=DPeB3DW0cDV0cDW0cDV0SE700Ta9c4V<@DeB3f:ANeFKeZ?
FY400UjB0UjC00=NU5jCGY<00UjB0ejA00ANLEjAGY5NTP=NT@9N/`03GY=R/f:c009R/`03HY9NTV:B
00=RTP03IY9RTV:B00IR/`05H[AR/f:cI[=V]003I[<2H[<00fJcH[=R/`03I[<3H[<3I[<016JdI[=V
]6Jd0VJc00]Ve6JcI[=V/f:dI[AVe6JdH[AVe6KE009Re0EVe003I[=VdfKC00MVd`05I[=VdfKCI]=Z
e004J]<01f[BI]9VdVKcH[1Ak459008liP0<?>Dlhcd5>:4XHR1S98<mB4h=G[5VmFKE16KD00=ZeFKD
I]@01VKD16KE0V;E00MNTUY?DPa9k469?DLiA`02>DH02Ce6@HQ5bTW/ER]JCUj@H[9Vd`03I]@00f[d
I]AVe003I]@00f[EJ]AZe004J]@3I]@3H]@016;CH[=R/f;C1F:c15jC00=NTUjbG[<00UjC00AN]5kE
G[AN]09R]0=N/`ENT`=NTP07G[=NTUjBG[9N]5jcFY<00ejB00UN/ejbE[9F;DF:@DM5ITW9AN/00dW:
00I5bTW:BNY9jTgZBLX3AL/00dG:BL]9bP02BLX014W;ALY5bTG:0TFZ00Q5bTG;AL/mQc4T8:4D0100
0PP00P@00P@100D48@@1104480@Q00H88@03324<@Pa2008<@P03324<@Pa200<<@P<<@a8<@P8<@@8<
@P0334<<@Pa200H<@P03344<@Pa2014<@P04344@@A114444344030aR468@HPa2468DPaB46:@LYAc5
8<DTa@8Xi00::BDaAc57<DLeAcE6=FLeAS57=DH2=DL2=FL0135X=FLeIcEW0SE700<iAcE7=DL00SE7
0cE613E700<eIcE7=DL00cE80S5800@aJC57<DLaA`8aJ0<aA`HeA`DeAP03=DLaAc5700<aA`03=DLe
ASE700DeAP05=DDeAS57<DLa9`02<DL2<DH00cE5=DHa9P02<BH6<DL01BdW<BHa9S4V<DL00S4V00Pa
9c57<BHa9S4W<DLa9RdV0be700HaAc4V<BHa9S57<BL2<BH00c56<BHa9P02<BH2<BL3<BH01S56<BHa
9S4V<DHa9P@]9P03<BH]9RdV00Da9P04<BL]9bdW;BH3;BL4<BH00c4U;BH]9@04<BH012dV;BDa9RdU
12dV00@]9bdV;BL]9`8]9P05:BDY9RTW:BL]9`02;BH2;BL00bd7;@H]9P03;BH00bd6;@@]0`01;@<0
0001\
\>"], "Graphics",
  Evaluatable->False,
  ImageSize->{756, 504},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]],

Cell["\<\
The glass is coated with  ITO (Iridium Tin Oxide) and is \
conducting.\
\>", "Text",
  FontSize->18],

Cell[CellGroupData[{

Cell["Simulated Annealing", "Subsection",
  FontSize->16],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.031746 0.309017 0.505795 [
[(Potential Well)] .5 .61803 0 -2 Msboxa
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
[(Potential Well)] .5 .61803 0 -2 Mshowa
P
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-0.05 0.0125 moveto 0 0 lineto -0.05 -0.0125 lineto fill
-0.05 0.0125 moveto 0 0 lineto -0.05 -0.0125 lineto
-0.05 0.0125 lineto stroke
grestore
} def
% End of user PostScript
p
p
1 0 0 r
.03 w
.23016 .18257 Mdot
P
p
.004 w
.23016 .46076 m
.23016 .25844 L
s
% Start of user PostScript
-8.5 0.3 -8.5 -0.1 MAarrowhead1
% End of user PostScript
P
p
p
.004 w
.02381 .20528 m
.02505 .2048 L
.02629 .20449 L
.02753 .20433 L
.02877 .20433 L
.03001 .20449 L
.03125 .20481 L
.03249 .20529 L
.03373 .20593 L
.03621 .20768 L
.03869 .21006 L
.04365 .21664 L
.04861 .22555 L
.05357 .2366 L
.06349 .26405 L
.08333 .33098 L
.09325 .36413 L
.10317 .39272 L
.10813 .40438 L
.1131 .41387 L
.11558 .41772 L
.11806 .42093 L
.12054 .42349 L
.12178 .42451 L
.12302 .42536 L
.12426 .42604 L
.1255 .42654 L
.12674 .42686 L
.12798 .42701 L
.12922 .42698 L
.13046 .42677 L
.1317 .42638 L
.13294 .42581 L
.13418 .42506 L
.13542 .42414 L
.1379 .42175 L
.14038 .41867 L
.14286 .41489 L
.14782 .40536 L
.15278 .39335 L
.1627 .36296 L
.18254 .28703 L
.19246 .24855 L
.20238 .21469 L
.20734 .20059 L
.2123 .18888 L
.21478 .18402 L
.21726 .17988 L
.21974 .17649 L
.22098 .17507 L
Mistroke
.22222 .17386 L
.22346 .17284 L
.2247 .17203 L
.22594 .17142 L
.22718 .17101 L
.22842 .17081 L
.22966 .17081 L
.2309 .17103 L
.23214 .17145 L
.23338 .17208 L
.23462 .17293 L
.2371 .17524 L
.23958 .17838 L
.24206 .18234 L
.24702 .19265 L
.25198 .20598 L
.2619 .24061 L
.28175 .3305 L
.29167 .37776 L
.30159 .42066 L
.30655 .43912 L
.31151 .45494 L
.31647 .46769 L
.31895 .47278 L
.32143 .47698 L
.32267 .47872 L
.32391 .48023 L
.32515 .48149 L
.32639 .48251 L
.32763 .48328 L
.32887 .48379 L
.33011 .48405 L
.33135 .48406 L
.33259 .4838 L
.33383 .48329 L
.33507 .48251 L
.33631 .48147 L
.33879 .47861 L
.34127 .47471 L
.34623 .46378 L
.35119 .44884 L
.36111 .40779 L
.38095 .29221 L
.40079 .16176 L
.41071 .10389 L
.41567 .07902 L
.42063 .05759 L
.4256 .04009 L
.42808 .03294 L
.43056 .02693 L
Mistroke
.43304 .02208 L
.43428 .0201 L
.43552 .01843 L
.43676 .01706 L
.438 .01601 L
.43924 .01526 L
.44048 .01483 L
.44172 .01472 L
.44296 .01492 L
.4442 .01543 L
.44544 .01627 L
.44668 .01743 L
.44792 .0189 L
.4504 .02279 L
.45288 .02795 L
.45536 .03434 L
.46032 .05075 L
.47024 .09704 L
.48016 .15855 L
.5 .30902 L
.51984 .45948 L
.52976 .521 L
.53472 .54627 L
.53968 .56729 L
.54216 .57609 L
.54464 .5837 L
.54712 .59009 L
.5496 .59524 L
.55084 .59735 L
.55208 .59914 L
.55332 .60061 L
.55456 .60176 L
.5558 .6026 L
.55704 .60312 L
.55828 .60332 L
.55952 .6032 L
.56076 .60277 L
.562 .60203 L
.56324 .60097 L
.56448 .5996 L
.56696 .59595 L
.56944 .59111 L
.5744 .57794 L
.57937 .56044 L
.58929 .51414 L
.59921 .45628 L
.61905 .32582 L
.62897 .26374 L
.63889 .21024 L
.64385 .18796 L
Mistroke
.64881 .1692 L
.65377 .15425 L
.65625 .14828 L
.65873 .14333 L
.66121 .13942 L
.66245 .13786 L
.66369 .13656 L
.66493 .13552 L
.66617 .13475 L
.66741 .13423 L
.66865 .13398 L
.66989 .13398 L
.67113 .13424 L
.67237 .13476 L
.67361 .13553 L
.67485 .13654 L
.67609 .13781 L
.67857 .14106 L
.68105 .14525 L
.68353 .15035 L
.68849 .16309 L
.69841 .19738 L
.71825 .28753 L
.72817 .33467 L
.7381 .37743 L
.74306 .39596 L
.74802 .41205 L
.75298 .42538 L
.75546 .43093 L
.75794 .43569 L
.76042 .43965 L
.7629 .4428 L
.76414 .44406 L
.76538 .44511 L
.76662 .44595 L
.76786 .44658 L
.7691 .44701 L
.77034 .44722 L
.77158 .44723 L
.77282 .44703 L
.77406 .44662 L
.7753 .44601 L
.77654 .44519 L
.77778 .44417 L
.78026 .44155 L
.78274 .43815 L
.7877 .42915 L
.79266 .41744 L
.79762 .40334 L
.81746 .33101 L
Mistroke
.82738 .29163 L
.8373 .25508 L
.84722 .22469 L
.85218 .21267 L
.85714 .20314 L
.85962 .19937 L
.8621 .19628 L
.86334 .195 L
.86458 .1939 L
.86582 .19297 L
.86706 .19222 L
.8683 .19165 L
.86954 .19126 L
.87078 .19105 L
.87202 .19102 L
.87326 .19117 L
.8745 .19149 L
.87574 .192 L
.87698 .19267 L
.87946 .19455 L
.88194 .1971 L
.8869 .20416 L
.89187 .21365 L
.89683 .22532 L
.91667 .28705 L
.93651 .35398 L
.94643 .38144 L
.95139 .39248 L
.95635 .40139 L
.95883 .40498 L
.96131 .40798 L
.96379 .41035 L
.96503 .41131 L
.96627 .4121 L
.96751 .41274 L
.96875 .41322 L
.96999 .41354 L
.97123 .4137 L
.97247 .4137 L
.97371 .41355 L
.97495 .41323 L
.97619 .41276 L
Mfstroke
P
P
[(Local Minimum)] .23016 .51134 0 0 Mshowa
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{282, 174},
  ImageMargins->{{34, 0}, {0, 1}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004J0000[Q000`40O003h00Oogoo6goo003oOolK
Ool00?mooa]oo`00ogoo6goo001lOol3002KOol007aoo`04001oo`00002JOol007]oo`05001oogoo
Ool0002JOol007Yoo`03001oogoo009oo`03001oogoo09Qoo`00NWoo00<007ooOol00goo00<007oo
Ool0Ugoo001jOol00`00Oomoo`04Ool00`00Oomoo`2FOol007Yoo`03001oogoo00Aoo`03001oogoo
09Ioo`00NGoo00<007ooOol01Goo00<007ooOol0UWoo001iOol00`00Oomoo`06Ool00`00Oomoo`2E
Ool007Uoo`03001oogoo00Ioo`03001oogoo09Eoo`00N7oo00<007ooOol01goo00<007ooOol0UGoo
001hOol00`00Oomoo`07Ool00`00Oomoo`2EOol007Qoo`03001oogoo00Moo`03001oogoo09Eoo`00
Mgoo00<007ooOol02Goo00<007ooOol0U7oo001gOol00`00Oomoo`09Ool00`00Oomoo`2DOol007Mo
o`03001oogoo00Uoo`03001oogoo09Aoo`00MWoo00<007ooOol02Woo00<007ooOol0U7oo001fOol0
0`00Oomoo`0:Ool00`00Oomoo`2DOol007Ioo`03001oogoo00Yoo`03001oogoo09Aoo`00MWoo00<0
07ooOol02goo00<007ooOol0Tgoo001fOol00`00Oomoo`0;Ool00`00Oomoo`2COol007Eoo`03001o
ogoo00aoo`03001oogoo09=oo`00MGoo00<007ooOol037oo00<007ooOol0Tgoo001eOol00`00Oomo
o`0<Ool00`00Oomoo`2COol007Eoo`03001oogoo00aoo`03001oogoo09=oo`00MGoo00<007ooOol0
3Goo00<007ooOol0TWoo001eOol00`00Oomoo`0=Ool00`00Oomoo`2BOol007Eoo`03001oogoo00eo
o`03001oogoo099oo`00M7oo00<007ooOol03Woo00<007ooOol0TWoo001dOol00`00Oomoo`0>Ool0
0`00Oomoo`2BOol007Aoo`03001oogoo00moo`03001oogoo095oo`00M7oo00<007ooOol03goo00<0
07ooOol0;Goo1000H7oo001dOol00`00Oomoo`0?Ool00`00Oomoo`0/Ool20002Ool00`00Oomoo`1N
Ool007Aoo`03001oogoo00moo`03001oogoo02aoo`03001oogoo009oo`03001oogoo05eoo`00M7oo
00<007ooOol03goo00<007ooOol0:goo00<007ooOol00goo00<007ooOol0GGoo001cOol00`00Oomo
o`0AOol00`00Oomoo`0ZOol00`00Oomoo`04Ool00`00Oomoo`1LOol007=oo`03001oogoo015oo`03
001oogoo02Uoo`03001oogoo00Eoo`03001oogoo05aoo`00Lgoo00<007ooOol04Goo00<007ooOol0
:Goo00<007ooOol01Woo00<007ooOol0Fgoo001cOol00`00Oomoo`0AOol00`00Oomoo`0YOol00`00
Oomoo`06Ool00`00Oomoo`1KOol007=oo`03001oogoo015oo`03001oogoo02Qoo`03001oogoo00Mo
o`03001oogoo05]oo`00AWoo0`00:Woo00<007ooOol04Goo00<007ooOol0:7oo00<007ooOol027oo
00<007ooOol0FWoo0015Ool00`00O01l0002000YOol00`00Oomoo`0AOol00`00Oomoo`0XOol00`00
Oomoo`08Ool00`00Oomoo`1JOol004Aoo`03001l07`0009l0003001l07oo02Ioo`03001oogoo01=o
o`03001oogoo02Moo`03001oogoo00Qoo`03001oogoo05Yoo`00A7oo00<007`0O0000g`000<007oo
Ool09Goo00<007ooOol04goo00<007ooOol09Woo00<007ooOol02Woo00<007ooOol0FGoo0013Ool0
0`00O01l0004O0000`00Oomoo`0UOol00`00Oomoo`0COol00`00Oomoo`0VOol00`00Oomoo`0:Ool0
0`00Oomoo`1IOol0049oo`03001oogoo00El0003Ool007oo02Eoo`03001oogoo01=oo`03001oogoo
02Ioo`03001oogoo00Yoo`03001oogoo02Uoo`<002eoo`00@Woo00@007ooOomoo`=l009oo`03001o
ogoo02Aoo`03001oogoo01=oo`03001oogoo02Ioo`03001oogoo00]oo`03001oogoo02Moo`800003
Ool0000002aoo`00@Goo00<007ooOol01goo00<007ooOol097oo00<007ooOol04goo00<007ooOol0
9Woo00<007ooOol02goo00<007ooOol09Woo0P0017oo00<007ooOol0:Goo0011Ool00`00Oomoo`08
Ool00`00Oomoo`0SOol00`00Oomoo`0COol00`00Oomoo`0UOol00`00Oomoo`0<Ool00`00Oomoo`0U
Ool00`00Oomoo`04Ool00`00Oomoo`0YOol0019oo`@002]oo`03001oogoo00Uoo`03001oogoo025o
o`03001oogoo01Eoo`03001oogoo02Aoo`03001oogoo00aoo`03001oogoo02Eoo`03001oogoo00Eo
o`03001oogoo02Qoo`005Goo0P00:Goo00<007ooOol02Woo00<007ooOol08Goo00<007ooOol05Goo
00<007ooOol097oo00<007ooOol03Goo00<007ooOol08goo00<007ooOol01Woo00<007ooOol0:7oo
000FOol00`00Oomoo`0WOol00`00Oomoo`0:Ool00`00Oomoo`0QOol00`00Oomoo`0EOol00`00Oomo
o`0TOol00`00Oomoo`0=Ool00`00Oomoo`0SOol00`00Oomoo`07Ool00`00Oomoo`0WOol001Moo`03
001oogoo02Ioo`03001oogoo00]oo`03001oogoo021oo`03001oogoo01Eoo`03001oogoo02Aoo`03
001oogoo00eoo`03001oogoo02=oo`03001oogoo00Moo`03001oogoo02Moo`0067oo00<007ooOol0
97oo00<007ooOol037oo00<007ooOol087oo00<007ooOol05Goo00<007ooOol08goo00<007ooOol0
3Woo00<007ooOol08Woo00<007ooOol02Goo00<007ooOol09Woo000IOol00`00Oomoo`0SOol00`00
Oomoo`0<Ool00`00Oomoo`0POol00`00Oomoo`0EOol00`00Oomoo`0SOol00`00Oomoo`0>Ool00`00
Oomoo`0ROol00`00Oomoo`09Ool00`00Oomoo`0VOol001Uoo`03001oogoo02=oo`03001oogoo00ao
o`03001oogoo01moo`03001oogoo01Ioo`03001oogoo02=oo`03001oogoo00moo`03001oogoo025o
o`03001oogoo00Uoo`03001oogoo02Ioo`006Woo00<007ooOol08Goo00<007ooOol03Goo00<007oo
Ool07goo00<007ooOol05Woo00<007ooOol08goo00<007ooOol03goo00<007ooOol087oo00<007oo
Ool02goo00<007ooOol09Goo000JOol00`00Oomoo`0QOol00`00Oomoo`0>Ool00`00Oomoo`0NOol0
0`00Oomoo`0GOol00`00Oomoo`0ROol00`00Oomoo`0?Ool00`00Oomoo`0POol00`00Oomoo`0;Ool0
0`00Oomoo`0UOol001Yoo`03001oogoo025oo`03001oogoo00ioo`03001oogoo01ioo`03001oogoo
01Moo`03001oogoo025oo`03001oogoo011oo`03001oogoo021oo`03001oogoo00]oo`03001oogoo
02Eoo`006Woo00<007ooOol087oo00<007ooOol03goo00<007ooOol07Woo00<007ooOol05goo00<0
07ooOol08Goo00<007ooOol04Goo00<007ooOol07Woo00<007ooOol03Goo00<007ooOol097oo000K
Ool00`00Oomoo`0OOol00`00Oomoo`0?Ool00`00Oomoo`0NOol00`00Oomoo`0GOol00`00Oomoo`0Q
Ool00`00Oomoo`0AOol00`00Oomoo`0NOol00`00Oomoo`0=Ool00`00Oomoo`0TOol001]oo`03001o
ogoo01moo`03001oogoo011oo`03001oogoo01eoo`03001oogoo01Moo`03001oogoo025oo`03001o
ogoo015oo`03001oogoo01ioo`03001oogoo00eoo`03001oogoo02Aoo`006goo00<007ooOol07goo
00<007ooOol047oo00<007ooOol077oo00<007ooOol067oo00<007ooOol08Goo00<007ooOol04Goo
00<007ooOol07Goo00<007ooOol03goo00<007ooOol08goo000LOol00`00Oomoo`0MOol00`00Oomo
o`08Ool00`00Oomoo`06Ool00`00Oomoo`0LOol00`00Oomoo`0HOol00`00Oomoo`0POol00`00Oomo
o`0BOol00`00Oomoo`0MOol00`00Oomoo`0?Ool00`00Oomoo`0SOol001aoo`03001oogoo01eoo`03
001oogoo00Qoo`03001oogoo00Ioo`03001oogoo01aoo`03001oogoo01Qoo`03001oogoo021oo`03
001oogoo01=oo`03001oogoo01aoo`03001oogoo011oo`03001oogoo029oo`0077oo00<007ooOol0
7Goo00<007ooOol027oo00<007ooOol01Woo00<007ooOol077oo00<007ooOol06Goo00<007ooOol0
7goo00<007ooOol04goo00<007ooOol06goo00<007ooOol04Goo00<007ooOol08Woo000LOol00`00
Oomoo`0MOol00`00Oomoo`07Ool30008Ool00`00Oomoo`0KOol00`00Oomoo`0IOol00`00Oomoo`0O
Ool00`00Oomoo`0COol00`00Oomoo`0KOol00`00Oomoo`0AOol00`00Oomoo`0ROol001eoo`03001o
ogoo01aoo`03001oogoo00Moo`<000Qoo`03001oogoo01]oo`03001oogoo01Uoo`03001oogoo01mo
o`03001oogoo01=oo`03001oogoo01]oo`03001oogoo019oo`03001oogoo025oo`007Goo00<007oo
Ool06goo00<007ooOol027oo0`0027oo00<007ooOol06goo00<007ooOol06Goo00<007ooOol07Woo
00<007ooOol057oo00<007ooOol06goo00<007ooOol04Woo00<007ooOol08Goo000MOol00`00Oomo
o`0KOol00`00Oomoo`08Ool30008Ool00`00Oomoo`0JOol00`00Oomoo`0JOol00`00Oomoo`0NOol0
0`00Oomoo`0EOol00`00Oomoo`0JOol00`00Oomoo`0BOol00`00Oomoo`0QOol001ioo`03001oogoo
01Yoo`03001oogoo00Moo`D000Qoo`03001oogoo01Uoo`03001oogoo01Yoo`03001oogoo01ioo`03
001oogoo01Eoo`03001oogoo01Uoo`03001oogoo01Aoo`03001oogoo021oo`007Woo00<007ooOol0
6Woo00<007ooOol01goo1@0027oo00<007ooOol06Goo00<007ooOol06Woo00<007ooOol07Woo00<0
07ooOol05Goo00<007ooOol06Goo00<007ooOol057oo00<007ooOol087oo000NOol00`00Oomoo`0J
Ool00`00Oomoo`07Ool50008Ool00`00Oomoo`0IOol00`00Oomoo`0KOol00`00Oomoo`0MOol00`00
Oomoo`0EOol00`00Oomoo`0IOol00`00Oomoo`0DOol00`00Oomoo`0POol001moo`03001oogoo01Qo
o`03001oogoo00Qoo`D000Qoo`03001oogoo01Uoo`03001oogoo01]oo`03001oogoo01aoo`03001o
ogoo01Ioo`03001oogoo01Uoo`03001oogoo01Eoo`03001oogoo01moo`007goo00<007ooOol067oo
00<007ooOol01goo1`001goo00<007ooOol067oo00<007ooOol077oo00<007ooOol077oo00<007oo
Ool05goo00<007ooOol05goo00<007ooOol05Woo00<007ooOol07goo000OOol00`00Oomoo`0HOol0
0`00Oomoo`07Ool70008Ool00`00Oomoo`0GOol00`00Oomoo`0LOol00`00Oomoo`0LOol00`00Oomo
o`0GOol00`00Oomoo`0GOol00`00Oomoo`0FOol00`00Oomoo`0OOol001moo`03001oogoo01Qoo`03
001oogoo00Yoo`03001oogoo00Uoo`03001oogoo01Moo`03001oogoo01aoo`03001oogoo01aoo`03
001oogoo01Moo`03001oogoo01Moo`03001oogoo01Moo`03001oogoo01ioo`0087oo00<007ooOol0
5Woo00<007ooOol02goo00<007ooOol02Goo00<007ooOol05goo00<007ooOol077oo00<007ooOol0
77oo00<007ooOol05goo00<007ooOol05Woo00<007ooOol067oo00<007ooOol07Woo000POol00`00
Oomoo`0FOol00`00Oomoo`0;Ool00`00Oomoo`09Ool00`00Oomoo`0GOol00`00Oomoo`0LOol00`00
Oomoo`0KOol00`00Oomoo`0HOol00`00Oomoo`0FOol00`00Oomoo`0HOol00`00Oomoo`0NOol0021o
o`03001oogoo01Ioo`03001oogoo00]oo`03001oogoo00Uoo`03001oogoo01Ioo`03001oogoo01eo
o`03001oogoo01]oo`03001oogoo01Qoo`03001oogoo01Ioo`03001oogoo01Uoo`03001oogoo01eo
o`008Goo00<007ooOol057oo00<007ooOol037oo00<007ooOol02Woo00<007ooOol05Goo00<007oo
Ool07Woo00<007ooOol06Woo00<007ooOol06Goo00<007ooOol057oo00<007ooOol06Woo00<007oo
Ool07Goo000QOol00`00Oomoo`0DOol00`00Oomoo`0<Ool00`00Oomoo`0:Ool00`00Oomoo`0EOol0
0`00Oomoo`0NOol00`00Oomoo`0JOol00`00Oomoo`0IOol00`00Oomoo`0DOol00`00Oomoo`0JOol0
0`00Oomoo`0MOol0025oo`03001oogoo01Aoo`03001oogoo00aoo`03001oogoo00Yoo`03001oogoo
01Eoo`03001oogoo01ioo`03001oogoo01Yoo`03001oogoo01Uoo`03001oogoo01Aoo`03001oogoo
01Yoo`03001oogoo01eoo`008Woo00<007ooOol04goo00<007ooOol037oo00<007ooOol02Woo00<0
07ooOol05Goo00<007ooOol07Woo00<007ooOol06Woo00<007ooOol06Goo00<007ooOol057oo00<0
07ooOol06goo00<007ooOol077oo000ROol00`00Oomoo`0BOol00`00Oomoo`0=Ool00`00Oomoo`0;
Ool00`00Oomoo`0COol00`00Oomoo`0OOol00`00Oomoo`0IOol00`00Oomoo`0JOol00`00Oomoo`0C
Ool00`00Oomoo`0LOol00`00Oomoo`0LOol0029oo`03001oogoo019oo`03001oogoo00eoo`03001o
ogoo00]oo`03001oogoo01=oo`03001oogoo01moo`03001oogoo01Uoo`03001oogoo01]oo`03001o
ogoo019oo`03001oogoo01aoo`03001oogoo01aoo`008goo00<007ooOol04Goo00<007ooOol03Goo
00<007ooOol02goo00<007ooOol04goo00<007ooOol07goo00<007ooOol06Goo00<007ooOol06goo
00<007ooOol04Woo00<007ooOol07Goo00<007ooOol06goo000SOol00`00Oomoo`0AOol00`00Oomo
o`0=Ool00`00Oomoo`0;Ool00`00Oomoo`0COol00`00Oomoo`0OOol00`00Oomoo`0IOol00`00Oomo
o`0KOol00`00Oomoo`0BOol00`00Oomoo`0MOol00`00Oomoo`0KOol002=oo`03001oogoo011oo`03
001oogoo00ioo`03001oogoo00aoo`03001oogoo019oo`03001oogoo021oo`03001oogoo01Qoo`03
001oogoo01aoo`03001oogoo011oo`03001oogoo01ioo`03001oogoo01]oo`0097oo00<007ooOol0
3goo00<007ooOol03Woo00<007ooOol037oo00<007ooOol04Goo00<007ooOol08Goo00<007ooOol0
67oo00<007ooOol077oo00<007ooOol047oo00<007ooOol07Woo00<007ooOol06goo000TOol00`00
Oomoo`0?Ool00`00Oomoo`0>Ool00`00Oomoo`0<Ool00`00Oomoo`0AOol00`00Oomoo`0QOol00`00
Oomoo`0HOol00`00Oomoo`0LOol00`00Oomoo`0@Ool00`00Oomoo`0OOol00`00Oomoo`0JOol002Ao
o`03001oogoo00ioo`03001oogoo00moo`03001oogoo00aoo`03001oogoo015oo`03001oogoo025o
o`03001oogoo01Moo`03001oogoo01eoo`03001oogoo00moo`03001oogoo021oo`03001oogoo01Yo
o`009Goo00<007ooOol03Goo00<007ooOol03goo00<007ooOol03Goo00<007ooOol047oo00<007oo
Ool08Goo00<007ooOol05goo00<007ooOol07Woo00<007ooOol03Woo00<007ooOol087oo00<007oo
Ool06Woo000UOol00`00Oomoo`0=Ool00`00Oomoo`0?Ool00`00Oomoo`0=Ool00`00Oomoo`0@Ool0
0`00Oomoo`0QOol00`00Oomoo`0GOol00`00Oomoo`0NOol00`00Oomoo`0>Ool00`00Oomoo`0QOol0
0`00Oomoo`0IOol002Ioo`03001oogoo00]oo`03001oogoo011oo`03001oogoo00eoo`03001oogoo
00moo`03001oogoo029oo`03001oogoo01Moo`03001oogoo01ioo`03001oogoo00ioo`03001oogoo
025oo`03001oogoo01Uoo`009Woo00<007ooOol02goo00<007ooOol047oo00<007ooOol03Goo00<0
07ooOol03goo00<007ooOol08goo00<007ooOol05Woo00<007ooOol07Woo00<007ooOol03Goo00<0
07ooOol08Woo00<007ooOol06Goo000VOol00`00Oomoo`0;Ool00`00Oomoo`0@Ool00`00Oomoo`0=
Ool00`00Oomoo`0?Ool00`00Oomoo`0SOol00`00Oomoo`0FOol00`00Oomoo`0OOol00`00Oomoo`0<
Ool00`00Oomoo`0SOol00`00Oomoo`0HOol002Moo`03001oogoo00Uoo`03001oogoo015oo`03001o
ogoo00ioo`03001oogoo00ioo`03001oogoo02=oo`03001oogoo01Eoo`03001oogoo021oo`03001o
ogoo00aoo`03001oogoo02=oo`03001oogoo01Qoo`009goo00<007ooOol02Goo00<007ooOol04Goo
00<007ooOol03Woo00<007ooOol03Woo00<007ooOol08goo00<007ooOol05Goo00<007ooOol087oo
00<007ooOol037oo00<007ooOol097oo00<007ooOol05goo000XOol00`00Oomoo`07Ool00`00Oomo
o`0BOol00`00Oomoo`0>Ool00`00Oomoo`0=Ool00`00Oomoo`0TOol00`00Oomoo`0EOol00`00Oomo
o`0POol00`00Oomoo`0;Ool00`00Oomoo`0VOol00`00Oomoo`0FOol002Qoo`03001oogoo00Moo`03
001oogoo019oo`03001oogoo00ioo`03001oogoo00eoo`03001oogoo02Aoo`03001oogoo01Eoo`03
001oogoo021oo`03001oogoo00]oo`03001oogoo02Ioo`03001oogoo01Ioo`00:7oo00<007ooOol0
1goo00<007ooOol04Woo00<007ooOol03Woo00<007ooOol03Goo00<007ooOol097oo00<007ooOol0
5Goo00<007ooOol08Goo00<007ooOol02Woo00<007ooOol09goo0P005Woo000YOol00`00Oomoo`05
Ool00`00Oomoo`0COol00`00Oomoo`0?Ool00`00Oomoo`0<Ool00`00Oomoo`0TOol00`00Oomoo`0E
Ool00`00Oomoo`0QOol00`00Oomoo`09Ool00`00Oomoo`0YOol4000COol002Yoo`03001oogoo00Ao
o`03001oogoo01=oo`03001oogoo00moo`03001oogoo00aoo`03001oogoo02Eoo`03001oogoo01Ao
o`03001oogoo025oo`03001oogoo00Uoo`03001oogoo041oo`00:Woo00<007ooOol00Woo0P005Woo
00<007ooOol03goo00<007ooOol02goo00<007ooOol09Woo00<007ooOol04goo00<007ooOol08goo
00<007ooOol027oo00<007ooOol0@7oo000[Ool200000goo0000000GOol00`00Oomoo`0?Ool00`00
Oomoo`0;Ool00`00Oomoo`0VOol00`00Oomoo`0COol00`00Oomoo`0TOol00`00Oomoo`06Ool00`00
Oomoo`11Ool002aoo`<001Qoo`03001oogoo011oo`03001oogoo00Yoo`03001oogoo02Ioo`03001o
ogoo01=oo`03001oogoo02Aoo`03001oogoo00Ioo`03001oogoo045oo`00Agoo00<007ooOol047oo
00<007ooOol02Woo00<007ooOol09Woo00<007ooOol04goo00<007ooOol097oo00<007ooOol01Woo
00<007ooOol0@Goo0017Ool00`00Oomoo`0@Ool00`00Oomoo`0:Ool00`00Oomoo`0VOol00`00Oomo
o`0COol00`00Oomoo`0UOol00`00Oomoo`04Ool00`00Oomoo`12Ool004Moo`03001oogoo015oo`03
001oogoo00Qoo`03001oogoo02Moo`03001oogoo01=oo`03001oogoo02Ioo`03001oogoo009oo`03
001oogoo04=oo`00Agoo00<007ooOol04Goo00<007ooOol027oo00<007ooOol09goo00<007ooOol0
4goo00<007ooOol09Woo0P000Woo00<007ooOol0A7oo0017Ool00`00Oomoo`0AOol00`00Oomoo`08
Ool00`00Oomoo`0XOol00`00Oomoo`0AOol00`00Oomoo`0XOol30017Ool004Moo`03001oogoo019o
o`03001oogoo00Moo`03001oogoo02Qoo`03001oogoo015oo`03001oogoo079oo`00Agoo00<007oo
Ool04Woo00<007ooOol01goo00<007ooOol0:7oo00<007ooOol04Goo00<007ooOol0LWoo0017Ool0
0`00Oomoo`0BOol00`00Oomoo`06Ool00`00Oomoo`0YOol00`00Oomoo`0AOol00`00Oomoo`1bOol0
05eoo`03001oogoo00Eoo`03001oogoo02Uoo`03001oogoo015oo`03001oogoo079oo`00GGoo00<0
07ooOol01Goo00<007ooOol0:Goo00<007ooOol04Goo00<007ooOol0LWoo001NOol00`00Oomoo`03
Ool00`00Oomoo`0ZOol00`00Oomoo`0AOol00`00Oomoo`1bOol005ioo`03001oogoo009oo`03001o
ogoo02aoo`03001oogoo00moo`03001oogoo07=oo`00Ggoo00D007ooOomoo`0002ioo`03001oogoo
00moo`03001oogoo07=oo`00Ggoo1000;goo00<007ooOol03goo00<007ooOol0Lgoo002BOol00`00
Oomoo`0?Ool00`00Oomoo`1cOol0099oo`03001oogoo00moo`03001oogoo07=oo`00Tgoo00<007oo
Ool03Woo00<007ooOol0Lgoo002COol00`00Oomoo`0>Ool00`00Oomoo`1cOol0021oo`D000=oo`<0
00=oo`<0009oo`D00003Ool0000000<000Moo`06001oogooOol007oo1@0000Aoo`00001oo`800003
Ool0000000<00007Ool007oo001oo`00Ool01@0000Ioo`00Ool007oo000UOol00`00Oomoo`0=Ool0
0`00Oomoo`1dOol0025oo`04001oogoo0002Ool01`00Oomoogoo001oo`0000=oo`03001oo`00009o
o`03001oogoo009oo`03001oogoo00Moo`05001oogooOol00003Ool01@00Oomoogoo00000Woo00<0
07ooOol00Woo00/007ooOomoo`00Ool007oo001oo`00009oo`08001oogoo001oo`00Ool002Eoo`03
001oogoo00eoo`03001oogoo07Aoo`008Goo00@007ooOol0009oo`07001oogooOol007oo00001Goo
100017oo00<007ooOol01goo00D007oo001oo`0000=oo`05001oogooOol00002Ool00`00Oomoo`02
Ool02`00Oomoogoo001oo`00Ool007oo00000Woo00P007ooOol007oo001oo`009Goo00<007ooOol0
3Goo00<007ooOol0M7oo000QOol00`00Oomoo`03Ool01`00Oomoogoo001oo`0000=oo`03001oogoo
009oo`03001oogoo009oo`03001oogoo00Moo`05001oo`00Ool00003Ool01@00Oomoogoo00000Woo
00<007ooOol00Woo00/007ooOomoo`00Ool007oo001oo`00009oo`08001oogoo001oo`00Ool002Io
o`03001oogoo00aoo`03001oogoo07Aoo`008Goo00<007ooOol017oo0`000goo10000Woo0`0017oo
00<007ooOol01goo0P0000=oo`0000000Woo0P000Woo1@000goo0P000Woo200000Aoo`00001oo`H0
02Ioo`03001oogoo00aoo`03001oogoo07Aoo`0087oo0`0067oo00<007ooOol01Woo0P000goo0P00
BGoo00<007ooOol037oo00<007ooOol0M7oo000iOol3000AOol00`00Oomoo`09Ool00`00Oomoo`0h
Ool00`00Oomoo`0;Ool00`00Oomoo`1eOol009Aoo`03001oogoo00]oo`03001oogoo07Eoo`00U7oo
00<007ooOol02goo00<007ooOol0MGoo002EOol00`00Oomoo`0:Ool00`00Oomoo`1eOol009Eoo`03
001oogoo00Uoo`03001oogoo07Ioo`00UGoo00<007ooOol02Goo00<007ooOol0MWoo002EOol00`00
Oomoo`09Ool00`00Oomoo`1fOol009Eoo`03001oogoo00Uoo`03001oogoo07Ioo`00UGoo00<007oo
Ool027oo00<007ooOol0Mgoo002FOol00`00Oomoo`07Ool00`00Oomoo`1gOol009Ioo`03001oogoo
00Moo`03001oogoo07Moo`00UWoo00<007ooOol01goo00<007ooOol0Mgoo002FOol00`00Oomoo`06
Ool00`00Oomoo`1hOol009Moo`03001oogoo00Eoo`03001oogoo07Qoo`00Ugoo00<007ooOol01Goo
00<007ooOol0N7oo002GOol00`00Oomoo`05Ool00`00Oomoo`1hOol009Qoo`03001oogoo00=oo`03
001oogoo07Uoo`00V7oo00<007ooOol00goo00<007ooOol0NGoo002IOol01@00Oomoogoo0000O7oo
002IOol200000goo001oo`1lOol009Yoo`<007eoo`00ogoo6goo003oOolKOol00?mooa]oo`00ogoo
6goo003oOolKOol00?mooa]oo`00ogoo6goo003oOolKOol00?mooa]oo`00ogoo6goo001ROol30005
Ool30003Ool30003Ool4000017oo000007oo0P000Woo0`000Woo1@0000=oo`0000000`0000=oo`00
00000`001goo00@007ooOol000=oo`@00003Ool0000000<00003Ool0000000<006Aoo`00Hgoo00<0
07ooOol00goo00D007ooOomoo`00009oo`06001oogoo001oo`001Goo00@007ooOol000=oo`04001o
ogoo0003Ool01@00Oomoogoo00000Woo00<007ooOol00Woo00<007ooOol01goo00@007ooOol0009o
o`03001oogoo00Eoo`03001oogoo00=oo`03001oogoo06Aoo`00Hgoo0`000goo00D007ooOomoo`00
009oo`03001oogoo009oo`D00005Ool007ooOol00003Ool00`00Oomoo`04Ool01000Oomoogoo1000
17oo00<007ooOol01goo10000Woo1@000goo00<007ooOol00goo00<007ooOol0I7oo001SOol01000
Oomoo`000Woo00D007ooOomoo`00009oo`03001oogoo009oo`07001oogooOol007oo00000Woo00D0
07ooOomoo`0000Ioo`03001oogoo00Aoo`03001oogoo009oo`03001oogoo00Moo`04001oo`000002
Ool01@00Oomoogoo00000goo00<007ooOol00goo00<007ooOol0I7oo001SOol01000Oomoo`000goo
0`000Woo10000goo0`0000=oo`0000000`000Woo10000goo0P0017oo0`0017oo00<007ooOol01goo
00@007ooOol000=oo`<000Aoo`03001oogoo00=oo`03001oogoo06Aoo`00HWoo10002Woo00<007oo
Ool03goo00<007ooOol047oo00<007ooOol01Woo0P000Woo0P002Goo00<007ooOol00goo00<007oo
Ool0I7oo001`Ool00`00Oomoo`0?Ool00`00Oomoo`04Ool00`00Oomoo`07Ool3000EOol30003Ool3
001VOol00?mooa]oo`00\
\>"],
  ImageRangeCache->{{{0, 281}, {173, 0}} -> {-17.3119, -0.610959, 0.123216, 
  0.00773361}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.031746 0.309017 0.505795 [
[(Potential Well)] .5 .61803 0 -2 Msboxa
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
[(Potential Well)] .5 .61803 0 -2 Mshowa
P
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-0.05 0.0125 moveto 0 0 lineto -0.05 -0.0125 lineto fill
-0.05 0.0125 moveto 0 0 lineto -0.05 -0.0125 lineto
-0.05 0.0125 lineto stroke
grestore
} def
% End of user PostScript
p
[(Global Minimum)] .44127 .51134 0 0 Mshowa
p
1 0 0 r
.03 w
.44127 .02577 Mdot
P
p
p
.004 w
.02381 .20528 m
.02505 .2048 L
.02629 .20449 L
.02753 .20433 L
.02877 .20433 L
.03001 .20449 L
.03125 .20481 L
.03249 .20529 L
.03373 .20593 L
.03621 .20768 L
.03869 .21006 L
.04365 .21664 L
.04861 .22555 L
.05357 .2366 L
.06349 .26405 L
.08333 .33098 L
.09325 .36413 L
.10317 .39272 L
.10813 .40438 L
.1131 .41387 L
.11558 .41772 L
.11806 .42093 L
.12054 .42349 L
.12178 .42451 L
.12302 .42536 L
.12426 .42604 L
.1255 .42654 L
.12674 .42686 L
.12798 .42701 L
.12922 .42698 L
.13046 .42677 L
.1317 .42638 L
.13294 .42581 L
.13418 .42506 L
.13542 .42414 L
.1379 .42175 L
.14038 .41867 L
.14286 .41489 L
.14782 .40536 L
.15278 .39335 L
.1627 .36296 L
.18254 .28703 L
.19246 .24855 L
.20238 .21469 L
.20734 .20059 L
.2123 .18888 L
.21478 .18402 L
.21726 .17988 L
.21974 .17649 L
.22098 .17507 L
Mistroke
.22222 .17386 L
.22346 .17284 L
.2247 .17203 L
.22594 .17142 L
.22718 .17101 L
.22842 .17081 L
.22966 .17081 L
.2309 .17103 L
.23214 .17145 L
.23338 .17208 L
.23462 .17293 L
.2371 .17524 L
.23958 .17838 L
.24206 .18234 L
.24702 .19265 L
.25198 .20598 L
.2619 .24061 L
.28175 .3305 L
.29167 .37776 L
.30159 .42066 L
.30655 .43912 L
.31151 .45494 L
.31647 .46769 L
.31895 .47278 L
.32143 .47698 L
.32267 .47872 L
.32391 .48023 L
.32515 .48149 L
.32639 .48251 L
.32763 .48328 L
.32887 .48379 L
.33011 .48405 L
.33135 .48406 L
.33259 .4838 L
.33383 .48329 L
.33507 .48251 L
.33631 .48147 L
.33879 .47861 L
.34127 .47471 L
.34623 .46378 L
.35119 .44884 L
.36111 .40779 L
.38095 .29221 L
.40079 .16176 L
.41071 .10389 L
.41567 .07902 L
.42063 .05759 L
.4256 .04009 L
.42808 .03294 L
.43056 .02693 L
Mistroke
.43304 .02208 L
.43428 .0201 L
.43552 .01843 L
.43676 .01706 L
.438 .01601 L
.43924 .01526 L
.44048 .01483 L
.44172 .01472 L
.44296 .01492 L
.4442 .01543 L
.44544 .01627 L
.44668 .01743 L
.44792 .0189 L
.4504 .02279 L
.45288 .02795 L
.45536 .03434 L
.46032 .05075 L
.47024 .09704 L
.48016 .15855 L
.5 .30902 L
.51984 .45948 L
.52976 .521 L
.53472 .54627 L
.53968 .56729 L
.54216 .57609 L
.54464 .5837 L
.54712 .59009 L
.5496 .59524 L
.55084 .59735 L
.55208 .59914 L
.55332 .60061 L
.55456 .60176 L
.5558 .6026 L
.55704 .60312 L
.55828 .60332 L
.55952 .6032 L
.56076 .60277 L
.562 .60203 L
.56324 .60097 L
.56448 .5996 L
.56696 .59595 L
.56944 .59111 L
.5744 .57794 L
.57937 .56044 L
.58929 .51414 L
.59921 .45628 L
.61905 .32582 L
.62897 .26374 L
.63889 .21024 L
.64385 .18796 L
Mistroke
.64881 .1692 L
.65377 .15425 L
.65625 .14828 L
.65873 .14333 L
.66121 .13942 L
.66245 .13786 L
.66369 .13656 L
.66493 .13552 L
.66617 .13475 L
.66741 .13423 L
.66865 .13398 L
.66989 .13398 L
.67113 .13424 L
.67237 .13476 L
.67361 .13553 L
.67485 .13654 L
.67609 .13781 L
.67857 .14106 L
.68105 .14525 L
.68353 .15035 L
.68849 .16309 L
.69841 .19738 L
.71825 .28753 L
.72817 .33467 L
.7381 .37743 L
.74306 .39596 L
.74802 .41205 L
.75298 .42538 L
.75546 .43093 L
.75794 .43569 L
.76042 .43965 L
.7629 .4428 L
.76414 .44406 L
.76538 .44511 L
.76662 .44595 L
.76786 .44658 L
.7691 .44701 L
.77034 .44722 L
.77158 .44723 L
.77282 .44703 L
.77406 .44662 L
.7753 .44601 L
.77654 .44519 L
.77778 .44417 L
.78026 .44155 L
.78274 .43815 L
.7877 .42915 L
.79266 .41744 L
.79762 .40334 L
.81746 .33101 L
Mistroke
.82738 .29163 L
.8373 .25508 L
.84722 .22469 L
.85218 .21267 L
.85714 .20314 L
.85962 .19937 L
.8621 .19628 L
.86334 .195 L
.86458 .1939 L
.86582 .19297 L
.86706 .19222 L
.8683 .19165 L
.86954 .19126 L
.87078 .19105 L
.87202 .19102 L
.87326 .19117 L
.8745 .19149 L
.87574 .192 L
.87698 .19267 L
.87946 .19455 L
.88194 .1971 L
.8869 .20416 L
.89187 .21365 L
.89683 .22532 L
.91667 .28705 L
.93651 .35398 L
.94643 .38144 L
.95139 .39248 L
.95635 .40139 L
.95883 .40498 L
.96131 .40798 L
.96379 .41035 L
.96503 .41131 L
.96627 .4121 L
.96751 .41274 L
.96875 .41322 L
.96999 .41354 L
.97123 .4137 L
.97247 .4137 L
.97371 .41355 L
.97495 .41323 L
.97619 .41276 L
Mfstroke
P
P
p
.004 w
.44127 .46076 m
.44127 .1067 L
s
% Start of user PostScript
-1.85 0.3 -1.85 -0.4 MAarrowhead1
% End of user PostScript
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{282, 174},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004J0000[Q000`40O003h00Oogoo6goo003oOolK
Ool00?mooa]oo`00ogoo6goo001lOol3002KOol007]oo`03O00007`0008009Yoo`00NWoo00=l0000
O0000W`000<007`0Ool0V7oo001jOol00`00O01l0002O0000`00O01oo`2HOol007Yoo`03001l07`0
00=l0003001oogoo09Moo`00NWoo00<007`0O0000g`000=oo`00Ool0Ugoo001jOol00`00Ooml0002
O002Ool00`00Oomoo`2FOol007Uoo`03001oogoo00Eoo`03001oogoo09Ioo`00NGoo00<007ooOol0
1Woo00<007ooOol0UGoo001iOol00`00Oomoo`06Ool00`00Oomoo`2EOol007Qoo`03001oogoo00Mo
o`03001oogoo09Eoo`00N7oo00<007ooOol01goo00<007ooOol0UGoo001hOol00`00Oomoo`07Ool0
0`00Oomoo`2EOol007Moo`03001oogoo00Uoo`03001oogoo09Aoo`00Mgoo00<007ooOol02Goo00<0
07ooOol0U7oo001gOol00`00Oomoo`09Ool00`00Oomoo`2DOol007Ioo`03001oogoo00Yoo`03001o
ogoo09Aoo`00MWoo00<007ooOol02Woo00<007ooOol0U7oo001fOol00`00Oomoo`0:Ool00`00Oomo
o`2DOol007Ioo`03001oogoo00]oo`03001oogoo09=oo`00MWoo00<007ooOol02goo00<007ooOol0
Tgoo001eOol00`00Oomoo`0<Ool00`00Oomoo`2COol007Eoo`03001oogoo00aoo`03001oogoo09=o
o`00MGoo00<007ooOol037oo00<007ooOol0Tgoo001eOol00`00Oomoo`05Ool00`00Oomoo`04Ool0
0`00Oomoo`2COol007Eoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo099oo`00MGoo00<0
07ooOol01Goo00<007ooOol01Goo00<007ooOol0TWoo001eOol00`00Oomoo`04Ool30006Ool00`00
Oomoo`2BOol007Aoo`03001oogoo00Eoo`<000Ioo`03001oogoo099oo`00M7oo00<007ooOol01Goo
0`001Woo00<007ooOol0TWoo001dOol00`00Oomoo`05Ool30007Ool00`00Oomoo`2AOol007Aoo`03
001oogoo00Aoo`D000Ioo`03001oogoo02eoo`@0061oo`00M7oo00<007ooOol017oo1@001Woo00<0
07ooOol0;7oo0P000Woo00<007ooOol0GWoo001dOol00`00Oomoo`04Ool50006Ool00`00Oomoo`0/
Ool00`00Oomoo`02Ool00`00Oomoo`1MOol007Aoo`03001oogoo00Aoo`D000Ioo`03001oogoo02]o
o`03001oogoo00=oo`03001oogoo05eoo`00Lgoo00<007ooOol01Goo1@001goo00<007ooOol0:Woo
00<007ooOol017oo00<007ooOol0G7oo001cOol00`00Oomoo`04Ool70006Ool00`00Oomoo`0YOol0
0`00Oomoo`05Ool00`00Oomoo`1LOol007=oo`03001oogoo00Aoo`L000Ioo`03001oogoo02Uoo`03
001oogoo00Ioo`03001oogoo05]oo`00Lgoo00<007ooOol01goo00<007ooOol01goo00<007ooOol0
:Goo00<007ooOol01Woo00<007ooOol0Fgoo001cOol00`00Oomoo`07Ool00`00Oomoo`07Ool00`00
Oomoo`0XOol00`00Oomoo`07Ool00`00Oomoo`1KOol004Ioo`<002Yoo`03001oogoo00Moo`03001o
ogoo00Moo`03001oogoo02Qoo`03001oogoo00Qoo`03001oogoo05Yoo`00AGoo00<007ooOol00P00
:Goo00<007ooOol01goo00<007ooOol01goo00<007ooOol0:7oo00<007ooOol027oo00<007ooOol0
FWoo0014Ool00`00Oomoo`02Ool00`00Oomoo`0VOol00`00Oomoo`08Ool00`00Oomoo`08Ool00`00
Oomoo`0WOol00`00Oomoo`08Ool00`00Oomoo`1JOol004Aoo`03001oogoo00=oo`03001oogoo02Eo
o`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo02Ioo`03001oogoo00Yoo`03001oogoo05Uo
o`00@goo00<007ooOol017oo00<007ooOol09Goo00<007ooOol027oo00<007ooOol027oo00<007oo
Ool09Woo00<007ooOol02Woo00<007ooOol0FGoo0012Ool00`00Oomoo`06Ool00`00Oomoo`0TOol0
0`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`0VOol00`00Oomoo`0:Ool00`00Oomoo`0YOol3
000]Ool0049oo`03001oogoo00Ioo`03001oogoo02Aoo`03001oogoo00Qoo`03001oogoo00Qoo`03
001oogoo02Ioo`03001oogoo00]oo`03001oogoo02Moo`800003Ool0000002aoo`00@Goo00<007oo
Ool01goo00<007ooOol097oo00<007ooOol027oo00<007ooOol027oo00<007ooOol09Woo00<007oo
Ool02goo00<007ooOol09Woo0P0017oo00<007ooOol0:Goo0011Ool00`00Oomoo`08Ool00`00Oomo
o`0SOol00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`0UOol00`00Oomoo`0<Ool00`00Oomo
o`0UOol00`00Oomoo`04Ool00`00Oomoo`0YOol0019oo`@002]oo`03001oogoo00Uoo`03001oogoo
025oo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo02Aoo`03001oogoo00aoo`03001oogoo
02Eoo`03001oogoo00Eoo`03001oogoo02Qoo`005Goo0P00:Goo00<007ooOol02Woo00<007ooOol0
8Goo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol097oo00<007ooOol03Goo00<007ooOol0
8goo00<007ooOol01Woo00<007ooOol0:7oo000FOol00`00Oomoo`0WOol00`00Oomoo`0:Ool00`00
Oomoo`0QOol00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`0TOol00`00Oomoo`0=Ool00`00
Oomoo`0SOol00`00Oomoo`07Ool00`00Oomoo`0WOol001Moo`03001oogoo02Ioo`03001oogoo00]o
o`03001oogoo021oo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo02Aoo`03001oogoo00eo
o`03001oogoo02=oo`03001oogoo00Moo`03001oogoo02Moo`0067oo00<007ooOol097oo00<007oo
Ool037oo00<007ooOol087oo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol08goo00<007oo
Ool03Woo00<007ooOol08Woo00<007ooOol02Goo00<007ooOol09Woo000IOol00`00Oomoo`0SOol0
0`00Oomoo`0<Ool00`00Oomoo`0POol00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`0SOol0
0`00Oomoo`0>Ool00`00Oomoo`0ROol00`00Oomoo`09Ool00`00Oomoo`0VOol001Uoo`03001oogoo
02=oo`03001oogoo00aoo`03001oogoo01moo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo
02=oo`03001oogoo00moo`03001oogoo025oo`03001oogoo00Uoo`03001oogoo02Ioo`006Woo00<0
07ooOol08Goo00<007ooOol03Goo00<007ooOol07goo00<007ooOol02Woo00<007ooOol02Goo00<0
07ooOol08goo00<007ooOol03goo00<007ooOol087oo00<007ooOol02goo00<007ooOol09Goo000J
Ool00`00Oomoo`0QOol00`00Oomoo`0>Ool00`00Oomoo`0NOol00`00Oomoo`0:Ool00`00Oomoo`0:
Ool00`00Oomoo`0ROol00`00Oomoo`0?Ool00`00Oomoo`0POol00`00Oomoo`0;Ool00`00Oomoo`0U
Ool001Yoo`03001oogoo025oo`03001oogoo00ioo`03001oogoo01ioo`03001oogoo00Yoo`03001o
ogoo00Yoo`03001oogoo025oo`03001oogoo011oo`03001oogoo021oo`03001oogoo00]oo`03001o
ogoo02Eoo`006Woo00<007ooOol087oo00<007ooOol03goo00<007ooOol07Woo00<007ooOol02Woo
00<007ooOol02Woo00<007ooOol08Goo00<007ooOol04Goo00<007ooOol07Woo00<007ooOol03Goo
00<007ooOol097oo000KOol00`00Oomoo`0OOol00`00Oomoo`0?Ool00`00Oomoo`0NOol00`00Oomo
o`0:Ool00`00Oomoo`0:Ool00`00Oomoo`0QOol00`00Oomoo`0AOol00`00Oomoo`0NOol00`00Oomo
o`0=Ool00`00Oomoo`0TOol001]oo`03001oogoo01moo`03001oogoo011oo`03001oogoo01eoo`03
001oogoo00Yoo`03001oogoo00Yoo`03001oogoo025oo`03001oogoo015oo`03001oogoo01ioo`03
001oogoo00eoo`03001oogoo02Aoo`006goo00<007ooOol07goo00<007ooOol047oo00<007ooOol0
77oo00<007ooOol02goo00<007ooOol02Woo00<007ooOol08Goo00<007ooOol04Goo00<007ooOol0
7Goo00<007ooOol03goo00<007ooOol08goo000LOol00`00Oomoo`0MOol00`00Oomoo`0AOol00`00
Oomoo`0LOol00`00Oomoo`0;Ool00`00Oomoo`0:Ool00`00Oomoo`0POol00`00Oomoo`0BOol00`00
Oomoo`0MOol00`00Oomoo`0?Ool00`00Oomoo`0SOol001aoo`03001oogoo01eoo`03001oogoo015o
o`03001oogoo01aoo`03001oogoo00]oo`03001oogoo00Yoo`03001oogoo021oo`03001oogoo01=o
o`03001oogoo01aoo`03001oogoo011oo`03001oogoo029oo`0077oo00<007ooOol07Goo00<007oo
Ool04Goo00<007ooOol077oo00<007ooOol02goo00<007ooOol02goo00<007ooOol07goo00<007oo
Ool04goo00<007ooOol06goo00<007ooOol04Goo00<007ooOol08Woo000LOol00`00Oomoo`0MOol0
0`00Oomoo`0BOol00`00Oomoo`0KOol00`00Oomoo`0;Ool00`00Oomoo`0;Ool00`00Oomoo`0OOol0
0`00Oomoo`0COol00`00Oomoo`0KOol00`00Oomoo`0AOol00`00Oomoo`0ROol001eoo`03001oogoo
01aoo`03001oogoo019oo`03001oogoo01]oo`03001oogoo00]oo`03001oogoo00]oo`03001oogoo
01moo`03001oogoo01=oo`03001oogoo01]oo`03001oogoo019oo`03001oogoo025oo`007Goo00<0
07ooOol06goo00<007ooOol04goo00<007ooOol06goo00<007ooOol02goo00<007ooOol02goo00<0
07ooOol07Woo00<007ooOol057oo00<007ooOol06goo00<007ooOol04Woo00<007ooOol08Goo000M
Ool00`00Oomoo`0KOol00`00Oomoo`0COol00`00Oomoo`0JOol00`00Oomoo`0<Ool00`00Oomoo`0;
Ool00`00Oomoo`0NOol00`00Oomoo`0EOol00`00Oomoo`0JOol00`00Oomoo`0BOol00`00Oomoo`0Q
Ool001ioo`03001oogoo01Yoo`03001oogoo01Aoo`03001oogoo01Uoo`03001oogoo00aoo`03001o
ogoo00]oo`03001oogoo01ioo`03001oogoo01Eoo`03001oogoo01Uoo`03001oogoo01Aoo`03001o
ogoo021oo`007Woo00<007ooOol06Woo00<007ooOol057oo00<007ooOol06Goo00<007ooOol037oo
00<007ooOol02goo00<007ooOol07Woo00<007ooOol05Goo00<007ooOol06Goo00<007ooOol057oo
00<007ooOol087oo000NOol00`00Oomoo`0JOol00`00Oomoo`0DOol00`00Oomoo`0IOol00`00Oomo
o`0<Ool00`00Oomoo`0<Ool00`00Oomoo`0MOol00`00Oomoo`0EOol00`00Oomoo`0IOol00`00Oomo
o`0DOol00`00Oomoo`0POol001moo`03001oogoo01Qoo`03001oogoo01Eoo`03001oogoo01Uoo`03
001oogoo00aoo`03001oogoo00aoo`03001oogoo01aoo`03001oogoo01Ioo`03001oogoo01Uoo`03
001oogoo01Eoo`03001oogoo01moo`007goo00<007ooOol067oo00<007ooOol05Goo00<007ooOol0
67oo00<007ooOol03Goo00<007ooOol037oo00<007ooOol077oo00<007ooOol05goo00<007ooOol0
5goo00<007ooOol05Woo00<007ooOol07goo000OOol00`00Oomoo`0HOol00`00Oomoo`0FOol00`00
Oomoo`0GOol00`00Oomoo`0=Ool00`00Oomoo`0<Ool00`00Oomoo`0LOol00`00Oomoo`0GOol00`00
Oomoo`0GOol00`00Oomoo`0FOol00`00Oomoo`0OOol001moo`03001oogoo01Qoo`03001oogoo01Io
o`03001oogoo01Moo`03001oogoo00eoo`03001oogoo00aoo`03001oogoo01aoo`03001oogoo01Mo
o`03001oogoo01Moo`03001oogoo01Moo`03001oogoo01ioo`0087oo00<007ooOol05Woo00<007oo
Ool05goo00<007ooOol05goo00<007ooOol03Goo00<007ooOol037oo00<007ooOol077oo00<007oo
Ool05goo00<007ooOol05Woo00<007ooOol067oo00<007ooOol07Woo000POol00`00Oomoo`0FOol0
0`00Oomoo`0GOol00`00Oomoo`0GOol00`00Oomoo`0=Ool00`00Oomoo`0<Ool00`00Oomoo`0KOol0
0`00Oomoo`0HOol00`00Oomoo`0FOol00`00Oomoo`0HOol00`00Oomoo`0NOol0021oo`03001oogoo
01Ioo`03001oogoo01Moo`03001oogoo01Ioo`03001oogoo00ioo`03001oogoo00aoo`03001oogoo
01]oo`03001oogoo01Qoo`03001oogoo01Ioo`03001oogoo01Uoo`03001oogoo01eoo`008Goo00<0
07ooOol057oo00<007ooOol06Goo00<007ooOol05Goo00<007ooOol03Woo00<007ooOol03Goo00<0
07ooOol06Woo00<007ooOol06Goo00<007ooOol057oo00<007ooOol06Woo00<007ooOol07Goo000Q
Ool00`00Oomoo`0DOol00`00Oomoo`0IOol00`00Oomoo`0EOol00`00Oomoo`0>Ool00`00Oomoo`0=
Ool00`00Oomoo`0JOol00`00Oomoo`0IOol00`00Oomoo`0DOol00`00Oomoo`0JOol00`00Oomoo`0M
Ool0025oo`03001oogoo01Aoo`03001oogoo01Uoo`03001oogoo01Eoo`03001oogoo00ioo`03001o
ogoo00eoo`03001oogoo01Yoo`03001oogoo01Uoo`03001oogoo01Aoo`03001oogoo01Yoo`03001o
ogoo01eoo`008Woo00<007ooOol04goo00<007ooOol06Goo00<007ooOol05Goo00<007ooOol03Woo
00<007ooOol03Goo00<007ooOol06Woo00<007ooOol06Goo00<007ooOol057oo00<007ooOol06goo
00<007ooOol077oo000ROol00`00Oomoo`0BOol00`00Oomoo`0KOol00`00Oomoo`0COol00`00Oomo
o`0?Ool00`00Oomoo`0=Ool00`00Oomoo`0IOol00`00Oomoo`0JOol00`00Oomoo`0COol00`00Oomo
o`0LOol00`00Oomoo`0LOol0029oo`03001oogoo019oo`03001oogoo01]oo`03001oogoo01=oo`03
001oogoo00moo`03001oogoo00eoo`03001oogoo01Uoo`03001oogoo01]oo`03001oogoo019oo`03
001oogoo01aoo`03001oogoo01aoo`008goo00<007ooOol04Goo00<007ooOol06goo00<007ooOol0
4goo00<007ooOol03goo00<007ooOol03Goo00<007ooOol06Goo00<007ooOol06goo00<007ooOol0
4Woo00<007ooOol07Goo00<007ooOol06goo000SOol00`00Oomoo`0AOol00`00Oomoo`0KOol00`00
Oomoo`0COol00`00Oomoo`0?Ool00`00Oomoo`0=Ool00`00Oomoo`0IOol00`00Oomoo`0KOol00`00
Oomoo`0BOol00`00Oomoo`0MOol00`00Oomoo`0KOol002=oo`03001oogoo011oo`03001oogoo01eo
o`03001oogoo019oo`03001oogoo00moo`03001oogoo00ioo`03001oogoo01Qoo`03001oogoo01ao
o`03001oogoo011oo`03001oogoo01ioo`03001oogoo01]oo`0097oo00<007ooOol03goo00<007oo
Ool07Goo00<007ooOol04Goo00<007ooOol047oo00<007ooOol03Woo00<007ooOol067oo00<007oo
Ool077oo00<007ooOol047oo00<007ooOol07Woo00<007ooOol06goo000TOol00`00Oomoo`0?Ool0
0`00Oomoo`0MOol00`00Oomoo`0AOol00`00Oomoo`0@Ool00`00Oomoo`0>Ool00`00Oomoo`0HOol0
0`00Oomoo`0LOol00`00Oomoo`0@Ool00`00Oomoo`0OOol00`00Oomoo`0JOol002Aoo`03001oogoo
00ioo`03001oogoo01ioo`03001oogoo015oo`03001oogoo011oo`03001oogoo00ioo`03001oogoo
01Moo`03001oogoo01eoo`03001oogoo00moo`03001oogoo021oo`03001oogoo01Yoo`009Goo00<0
07ooOol03Goo00<007ooOol07goo00<007ooOol047oo00<007ooOol047oo00<007ooOol03Woo00<0
07ooOol05goo00<007ooOol07Woo00<007ooOol03Woo00<007ooOol087oo00<007ooOol06Woo000U
Ool00`00Oomoo`0=Ool00`00Oomoo`0OOol00`00Oomoo`0@Ool00`00Oomoo`0@Ool00`00Oomoo`0>
Ool00`00Oomoo`0GOol00`00Oomoo`0NOol00`00Oomoo`0>Ool00`00Oomoo`0QOol00`00Oomoo`0I
Ool002Ioo`03001oogoo00]oo`03001oogoo021oo`03001oogoo00moo`03001oogoo015oo`03001o
ogoo00ioo`03001oogoo01Moo`03001oogoo01ioo`03001oogoo00ioo`03001oogoo025oo`03001o
ogoo01Uoo`009Woo00<007ooOol02goo00<007ooOol087oo00<007ooOol03goo00<007ooOol04Goo
00<007ooOol03goo00<007ooOol05Woo00<007ooOol07Woo00<007ooOol03Goo00<007ooOol08Woo
00<007ooOol06Goo000VOol00`00Oomoo`0;Ool00`00Oomoo`0POol00`00Oomoo`0?Ool00`00Oomo
o`0AOol00`00Oomoo`0?Ool00`00Oomoo`0FOol00`00Oomoo`0OOol00`00Oomoo`0<Ool00`00Oomo
o`0SOol00`00Oomoo`0HOol002Moo`03001oogoo00Uoo`03001oogoo029oo`03001oogoo00ioo`03
001oogoo015oo`03001oogoo00moo`03001oogoo01Eoo`03001oogoo021oo`03001oogoo00aoo`03
001oogoo02=oo`03001oogoo01Qoo`009goo00<007ooOol02Goo00<007ooOol08Woo00<007ooOol0
3Woo00<007ooOol04Goo00<007ooOol03goo00<007ooOol05Goo00<007ooOol087oo00<007ooOol0
37oo00<007ooOol097oo00<007ooOol05goo000XOol00`00Oomoo`07Ool00`00Oomoo`0SOol00`00
Oomoo`0=Ool00`00Oomoo`0BOol00`00Oomoo`0?Ool00`00Oomoo`0EOol00`00Oomoo`0POol00`00
Oomoo`0;Ool00`00Oomoo`0VOol00`00Oomoo`0FOol002Qoo`03001oogoo00Moo`03001oogoo02=o
o`03001oogoo00eoo`03001oogoo019oo`03001oogoo00moo`03001oogoo01Eoo`03001oogoo021o
o`03001oogoo00]oo`03001oogoo02Ioo`03001oogoo01Ioo`00:7oo00<007ooOol01goo00<007oo
Ool08goo00<007ooOol03Goo00<007ooOol04Woo00<007ooOol03goo00<007ooOol05Goo00<007oo
Ool08Goo00<007ooOol02Woo00<007ooOol09goo0P005Woo000YOol00`00Oomoo`05Ool00`00Oomo
o`0UOol00`00Oomoo`0<Ool00`00Oomoo`0BOol00`00Oomoo`0?Ool00`00Oomoo`0EOol00`00Oomo
o`0QOol00`00Oomoo`09Ool00`00Oomoo`0YOol4000COol002Yoo`03001oogoo00Aoo`03001oogoo
02Eoo`03001oogoo00aoo`03001oogoo019oo`03001oogoo011oo`03001oogoo01Aoo`03001oogoo
025oo`03001oogoo00Uoo`03001oogoo041oo`00:Woo00<007ooOol00Woo0P00:7oo00<007ooOol0
2goo00<007ooOol04goo00<007ooOol047oo00<007ooOol04goo00<007ooOol08goo00<007ooOol0
27oo00<007ooOol0@7oo000[Ool200000goo0000000YOol00`00Oomoo`0;Ool00`00Oomoo`0COol0
0`00Oomoo`0@Ool00`00Oomoo`0COol00`00Oomoo`0TOol00`00Oomoo`06Ool00`00Oomoo`11Ool0
02aoo`<002]oo`03001oogoo00Yoo`03001oogoo01=oo`03001oogoo011oo`03001oogoo01=oo`03
001oogoo02Aoo`03001oogoo00Ioo`03001oogoo045oo`00FWoo00<007ooOol02Woo00<007ooOol0
4goo00<007ooOol047oo00<007ooOol04goo00<007ooOol097oo00<007ooOol01Woo00<007ooOol0
@Goo001JOol00`00Oomoo`0:Ool00`00Oomoo`0COol00`00Oomoo`0@Ool00`00Oomoo`0COol00`00
Oomoo`0UOol00`00Oomoo`04Ool00`00Oomoo`12Ool005]oo`03001oogoo00Qoo`03001oogoo01Ao
o`03001oogoo011oo`03001oogoo01=oo`03001oogoo02Ioo`03001oogoo009oo`03001oogoo04=o
o`00Fgoo00<007ooOol027oo00<007ooOol057oo00<007ooOol047oo00<007ooOol04goo00<007oo
Ool09Woo0P000Woo00<007ooOol0A7oo001KOol00`00Oomoo`08Ool00`00Oomoo`0DOol00`00Oomo
o`0AOol00`00Oomoo`0AOol00`00Oomoo`0XOol30017Ool005aoo`03001oogoo00Moo`03001oogoo
01Aoo`03001oogoo015oo`03001oogoo015oo`03001oogoo079oo`00G7oo00<007ooOol01goo00<0
07ooOol057oo00<007ooOol04Goo00<007ooOol04Goo00<007ooOol0LWoo001LOol00`00Oomoo`06
Ool00`00Oomoo`0EOol00`00Oomoo`0AOol00`00Oomoo`0AOol00`00Oomoo`1bOol005eoo`03001o
ogoo00Eoo`03001oogoo02Uoo`03001oogoo015oo`03001oogoo079oo`00GGoo00<007ooOol01Goo
00<007ooOol0:Goo00<007ooOol04Goo00<007ooOol0LWoo001NOol00`00Oomoo`03Ool00`00Oomo
o`0ZOol00`00Oomoo`0AOol00`00Oomoo`1bOol005ioo`03001oogoo009oo`03001oogoo02aoo`03
001oogoo00moo`03001oogoo07=oo`00Ggoo00D007ooOomoo`0002ioo`03001oogoo00moo`03001o
ogoo07=oo`00Ggoo1000;goo00<007ooOol03goo00<007ooOol0Lgoo002BOol00`00Oomoo`0?Ool0
0`00Oomoo`1cOol0099oo`03001oogoo00moo`03001oogoo07=oo`00Tgoo00<007ooOol03Woo00<0
07ooOol0Lgoo002COol00`00Oomoo`0>Ool00`00Oomoo`1cOol005Aoo`@0009oo`D0009oo`<0009o
o`@0009oo`D00003Ool0000000<000Moo`06001oogooOol007oo1@0000Aoo`00001oo`800003Ool0
000000<00007Ool007oo001oo`00Ool01@0000Ioo`00000007oo001cOol005=oo`05001oogooOol0
0004Ool01@00Oomoogoo00000goo00<007oo00000goo00<007oo00000Woo00<007ooOol00Woo00<0
07ooOol01goo00D007ooOomoo`0000=oo`05001oogooOol00002Ool00`00Oomoo`02Ool20002Ool0
1`00Ool007oo001oo`00009oo`03001oogoo00<00003Ool007oo079oo`00Dgoo00<007oo00000P00
17oo00D007ooOomoo`0000=oo`03001oo`0000=oo`03001oo`0000<000Aoo`03001oogoo00Moo`05
001oo`00Ool00003Ool01@00Oomoogoo00000Woo00<007ooOol00Woo0P000Woo00L007oo001oo`00
Ool00002Ool00`00Oomoo`0300000goo001oo`1bOol005=oo`03001oogoo00Ioo`05001oogooOol0
0003Ool00`00Ool00003Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`07Ool01@00Ool0
07oo00000goo00D007ooOomoo`00009oo`03001oogoo009oo`0;001oo`00Ool007oo001oo`00Ool0
0002Ool00`00Oomoo`0300000goo001oo`1bOol005=oo`05001oogooOol00004Ool00`00Oomoo`02
Ool30002Ool40003Ool30004Ool00`00Oomoo`07Ool200000goo00000002Ool20002Ool50003Ool2
00000goo00000007000017oo000007oo1P00Lgoo001DOol40004Ool00`00Oomoo`07Ool00`00Oomo
o`0;Ool00`00Oomoo`06Ool20003Ool2000@Ool00`00Oomoo`0<Ool00`00Oomoo`1dOol005Yoo`<0
00Qoo`8000]oo`<0015oo`03001oogoo00Uoo`03001oo`0000eoo`03001oogoo07Eoo`00U7oo00<0
07ooOol02goo00<007ooOol0MGoo002DOol00`00Oomoo`0;Ool00`00Oomoo`1eOol009Eoo`03001o
ogoo00Yoo`03001oogoo07Eoo`00UGoo00<007ooOol02Goo00<007ooOol0MWoo002EOol00`00Oomo
o`09Ool00`00Oomoo`1fOol009Eoo`03001oogoo00Uoo`03001oogoo07Ioo`00UGoo00<007ooOol0
2Goo00<007ooOol0MWoo002EOol00`00Oomoo`08Ool00`00Oomoo`1gOol009Ioo`03001oogoo00Mo
o`03001oogoo07Moo`00UWoo00<007ooOol01goo00<007ooOol0Mgoo002FOol00`00Oomoo`07Ool0
0`00Oomoo`1gOol009Ioo`03001oogoo00Ioo`03001oogoo07Qoo`00Ugoo00<007ooOol01Goo00<0
07ooOol0N7oo002GOol00`00Oomoo`05Ool00`00Oomoo`1hOol009Moo`03001oogoo00Eoo`03001o
ogoo07Qoo`00V7oo00<007ooOol00goo00<007ooOol0NGoo002HOol00`00Oomoo`03Ool00`00Oomo
o`1iOol009Uoo`05001oogooOol0001lOol009Uoo`800003Ool007oo07aoo`00VWoo0`00OGoo003o
OolKOol00?mooa]oo`00ogoo6goo003oOolKOol00?mooa]oo`00ogoo6goo003oOolKOol00?mooa]o
o`00ogoo6goo003oOolKOol0069oo`<000Eoo`<000=oo`<000=oo`@00004Ool00000Ool20002Ool3
0002Ool500000goo0000000300000goo000000030007Ool01000Oomoo`000goo100000=oo`000000
0`0000=oo`0000000`00I7oo001SOol00`00Oomoo`03Ool01@00Oomoogoo00000Woo00H007ooOol0
07oo0005Ool01000Oomoo`000goo00@007ooOol000=oo`05001oogooOol00002Ool00`00Oomoo`02
Ool00`00Oomoo`07Ool01000Oomoo`000Woo00<007ooOol01Goo00<007ooOol00goo00<007ooOol0
I7oo001SOol30003Ool01@00Oomoogoo00000Woo00<007ooOol00Woo1@0000Eoo`00Oomoo`0000=o
o`03001oogoo00Aoo`04001oogooOol40004Ool00`00Oomoo`07Ool40002Ool50003Ool00`00Oomo
o`03Ool00`00Oomoo`1TOol006=oo`04001oogoo0002Ool01@00Oomoogoo00000Woo00<007ooOol0
0Woo00L007ooOomoo`00Ool00002Ool01@00Oomoogoo00001Woo00<007ooOol017oo00<007ooOol0
0Woo00<007ooOol01goo00@007oo0000009oo`05001oogooOol00003Ool00`00Oomoo`03Ool00`00
Oomoo`1TOol006=oo`04001oogoo0003Ool30002Ool40003Ool300000goo000000030002Ool40003
Ool20004Ool30004Ool00`00Oomoo`07Ool01000Oomoo`000goo0`0017oo00<007ooOol00goo00<0
07ooOol0I7oo001ROol4000:Ool00`00Oomoo`0?Ool00`00Oomoo`0@Ool00`00Oomoo`06Ool20002
Ool20009Ool00`00Oomoo`03Ool00`00Oomoo`1TOol0071oo`03001oogoo00moo`03001oogoo00Ao
o`03001oogoo00Moo`<001Eoo`<000=oo`<006Ioo`00ogoo6goo0000\
\>"],
  ImageRangeCache->{{{0, 281}, {173, 0}} -> {-17.3119, -0.610959, 0.123216, 
  0.00773361}}]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Data", "Section"],

Cell[CellGroupData[{

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:00001h1000`40O003
h00O10@Q00<000@Q12401@@Q00D<HaBU48@48@Q200<<H`0424848@Q22482
36<01@Q21248@PQ236<01@Q200<<H`Q224801`Q200D48@Q2248<H`Q200<<
H`<8@P0336<8@PQ20088@P0336<8@P@Q0088@P8<H`L8@P03124<H`Q200<8
@P<<H`88@P041248@PQ236<3248436<424800`aS248<H`0436<2248336<0
0a2436<<H`02248236<00`Q236<8@P0436<00`Q236<8@P03248010@Q36<<
H`aS20Q200D<H`Q224848@Q200<<H`@8@PL<H`88@P0336<8@PQ200<8@PL<
H`03248<H`aS00@<H`0348@<H`aS008<H`88@P<<H`05248@Q0aS36<8@P03
36<0112436<<H`Q20PaS00<@Q0aS24801@aS0PQ21PaS00<@Q1BU48@00Q24
0`aS0Q2410aS00<8@PaS36<00`aS00D8@PaS48@@Q0aS00<8@P0436<8@PaS
36<2248236<5248336<01A2436<<H`aS24800`aS0Q2400<<H`Q224800`Q2
0PaS112420aS0a240`aS00<8@PaS48@00Q240PaS00@DYA2436<<H`8@Q08<
H`03248<H`Q200@<H`8@Q0<<H`8@Q0<<H`8@Q00736<8@PaS36<@Q0aS2480
0Q2420aS00<8@PaS24802`aS00@8@PaS36<@Q08<H`88@P<<H`0324848@Q2
0088@P8<H`88@P031248@PaS008<H`<8@P<<H`88@P@<H`0424848@Q22485
36<00`@Q248<H`0336<010Q236<8@PQ20`aS00<8@PaS24800PQ200<<H`Q2
24800PQ20PaS00<8@PaS248010Q200<<H`Q224800PaS00@8@PaS36<<H`<8
@P8<H`0624848@@Q36<@Q0aS0PQ200<48@aS36<010Q200<<H`Q224801PQ2
00<<H`Q2124020Q200<<H`Q236<00`Q200<<H`Q2248010Q20PaS0PQ20`aS
0`Q200@<H`Q22488@P@<H`88@P0436<8@PaS248236<3248436<00`Q236<8
@P0336<424802@aS24848@Q236<8@PaS248<H`07248010@Q2488@PQ21PaS
00<8@P@Q24800PaS00@8@P@Q36<<H`88@P031248@PQ200<8@P8<H`<8@P03
124<H`Q200T8@P8<H`0724848@Q2248@Q0Q212400PQ200<<H`Q2248010Q2
00<<H`Q2124010Q200000`0012448@031240100012448@000P@Q00<8@QBU
36<010aS00@8@PaS48@<H`@8@P0336<8@PQ200<<H`0424848@Q236<22480
0`aS248<H`06248336<010Q236<8@PaS10Q20PaS0`Q20`aS10Q200<<H`Q2
24801PQ200<48@Q236<00PaS0PQ20`aS0`Q200<<H`Q2248010Q20PaS0PQ2
0`aS00<8@PaS36<00PQ20PaS00D8@P@Q248<Ha240088@P0736<8@PQ2248<
H`Q236<00`Q200<<H`Q236<00PQ20PaS00@8@P@Q248<H`<8@P0336<8@PQ2
00<<H`88@P04124<H`aS36<224800`aS48@<H`03248336<3248436<00`Q2
36<@Q00248@00`aS248<H`0436<00`Q236<<H`0236<00a2436<<H`0536<0
0`Q248@<H`0248@00`aS48@@Q00248@00`Q236<<H`02248636<248@436<0
0aBU48@@Q00348@01QBU36<<Ha2436<@Q0D<H`0348@<H`aS008@Q00336<8
@PaS008@Q00336<8@PaS00D<H`03248<H`aS00<<H`0;248<H`aS36<@Q0aS
48@<Ha2436<@Q00336<010Q236<<Ha240`aS1A241@aS0a240PaS00<@Q0Q2
36<01PaS0Q2400<DYA2436<00PaS0Q240PQ200H<Ha2448@<H`Q236<348@3
36<00a2436<@Q00248@436<348@=36<224800`aS2488@P02248010aS48@<
Ha2410aS00@8@P@Q36<<H`<8@P0336<@Q0aS0088@P0436<8@PaS248336<2
24802P@Q2488@PQ236<8@PaS248<H`Q210aS10Q200<<HaBU36<00`aS00@8
@PaS48@@Q0D<H`<8@P<<H`88@P0736<8@PQ236<8@PaS24800PaS00P8@PaS
36<8@PaS24848@Q210aS00D8@PaS36<<H`Q200@<H`03248<H`Q2008<H`D8
@P0336<8@PaS0088@P8<H`<8@P8<H`@8@P041248@PQ236<4248010@Q2488
@PQ20PaS00<8@P@Q24800`aS0PQ21PaS0`Q21PaS0PQ200@<H`Q236<<H`<8
@P0336<8@PaS00@<H`88@PH<H`88@P<<H`L8@P0336<8@PaS00<8@P8<H`88
@P@<H`P8@P0336<8@PQ20088@P0436<8@PaS36<4248236<4248236<62480
0`aS2488@P0524800`aS2488@P03248236<3248336<224800006124000@Q
00048@0010@Q00H000@Q248DY@aS248236<2248436<224800`aS2488@P02
248236<00`@Q2488@P0236<00`Q2124<H`0224801@aS2488@PQ212400PaS
00H8@PaS248<H`Q236<2248436<00`Q21248@P0336<010Q212448@@Q0PaS
0PQ20PaS00<8@P@Q248020Q20PaS0PQ210aS0`Q210aS00D8@PaS248<H`Q2
00<<H`03248<H`aS00<<H`04248<H`Q2248536<01@Q236<8@PaS24800PaS
1@Q20`aS00<8@PaS36<00PaS0PQ200@<H`Q22488@P@<H`03248<H`aS00<<
H`05248<H`aS36<8@P0436<224800`aS48@@Q00836<01Q2436<<H`aS2484
8@8<H`8@Q0<<H`04248<H`aS36<448@336<00`Q236<8@P0836<224801Q24
36<<H`aS48@DY@8@Q0035:D@Q12400T<H`8@Q0P<H`8@Q08<H`04248<H`aS
36<348@00`aS248<H`0336<010Q236<8@PaS0Q242`aS0Q2400<<Ha2448@0
1A240PaS0a240`aS0Q2400<<H`Q236<01`aS0Q240`aS0Q241@aS00@@Q1BU
48@@Q0D<H`0348@DYA24008@Q00536<@Q0aS36<@Q00336<248@010aS248<
H`Q20a2400D<H`Q2248<H`Q200D<H`03248<H`aS00@<H`04248<H`aS36<3
248436<4248010aS2488@PQ20PaS0`Q20`aS0PQ210aS0PQ200<<H`Q22480
0`aS00<8@PaS36<010aS00D@Q0aS36<<Ha2400<8@P0436<@Q0Q2248236<6
248236<00`Q236<8@P05248436<010Q236<8@PaS0`Q200D<H`Q236<<H`Q2
008<H`H8@P0336<@Q0Q200H8@P0436<8@PQ236<324800`aS2488@P052480
0`aS2488@P02248010@Q36<<H`aS0PQ200<<Ha2436<01@aS10Q20`aS0`Q2
00@<H`Q21248@P8<H`88@P8<H`88@P8@Q00636<8@PQ248@<H`Q20`aS10Q2
00<<H`Q236<010Q20PaS00<8@PaS248010Q20PaS0`Q200D<H`Q236<8@PaS
0088@P<<H`0524848@Q2248<H`09248010aS2488@P@Q0PQ200D<H`Q22488
@P@Q00D8@P0336<8@PQ200L8@P041248@PaS36<324800`aS248<H`012480
00P48@0500048@@Q1248@P0248@336<010Q236<<H`aS10Q200@<H`Q2248<
H`<8@PD<H`88@P061248@PQ236<@Q0aS0`Q20PaS0`Q200<<H`Q236<00`Q2
00<<Ha2436<00PQ200D48@Q236<<Ha24008<H`H8@P8<H`88@P<<H`<8@P03
36<8@PQ20088@P8<H`0324848@Q2008<H`<8@P0536<8@PQ21248@P0236<3
24800`aS2488@P0436<2248536<00`Q236<8@P0236<010Q236<<H`aS0PQ2
00@<H`Q236<8@P8<H`<8@P8<H`04248<H`aS48@236<010Q236<<H`Q20PaS
0PQ20PaS00<8@PaS36<00PaS0Q2410aS00<@Q0aS36<00PaS00<8@PaS36<0
0`aS00<@Q0aS36<00`aS00<@Q0aS36<010aS00<@Q0aS36<01@aS0Q2410aS
0Q240`aS00<8@PaS36<00`aS0Q2400@<Ha2436<<H`<@Q00336<@Q0aS00@<
H`05248<Ha2448@<H`02248236<2248836<248@336<00a2436<<H`0636<2
48@236<00`Q236<<H`0236<00a2436<@Q00236<01A245:D@Q12436<01124
0`aS00@@Q0aS48@@Q0@<H`8@Q08<H`04248<H`aS36<648@00`aS48@<H`05
36<248@336<248@01@aS248<Ha2436<00PQ20Q240`aS0Q240`aS00@8@PaS
36<<H`8@Q008248<H`Q2248<H`Q236<8@P<<H`0848@<H`aS36<8@PaS248<
H`88@P0336<8@PQ20088@P@<H`03248<H`Q2008<H`03248<H`aS00@<H`04
248<H`aS36<2248336<2248236<3248336<00`Q236<8@P0448@236<32483
36<224800`aS2488@P0224800`aS248<H`0224800`aS2488@P0224800`aS
48@<H`02248536<3248236<4248336<2248236<00`@Q248<H`0336<01PQ2
36<8@PaS24848@88@P8<H`@8@P0536<8@PaS248<H`02248236<3248236<3
248436<010@Q248<H`aS0`Q20PaS00@8@PaS36<8@P<<H`<8@P<<H`03248<
H`aS00@<H`D8@P<<H`<8@P8<H`@8@P0548@<H`Q236<48@02248236<32480
10aS2488@PQ20`aS0`@Q0PQ200<<H`Q2248020Q200H<H`Q2248<H`Q236<2
248336<224800`@Q248<H`0224800`@Q248<H`0424802@aS2488@PQ236<8
@PaS24848@02248136<1248124800006124000@Q00048@0010@Q00D000@Q
248DYA24008<H`<8@P<<H`05248<H`aS24848@0224800`aS2488@P0236<0
10Q236<8@PaS1PQ200<<H`Q236<00`aS00<8@PaS24800PaS0`Q20PaS0PQ2
0PaS0`Q20PaS1PQ200<<H`@Q24800`Q20PaS0`Q20PaS1@Q200<<H`Q22480
0PQ20PaS0PQ200X48@aS36<<H`Q236<8@PaS248<H`88@P<<H`03248<H`aS
0088@P8<H`04248<H`Q2248336<3248010aS248<H`Q20PaS0PQ20PaS10Q2
2PaS0PQ20`aS00@8@PaS36<@Q0X<H`03248<H`Q2008<H`05248<H`aS36<8
@P0236<0212436<@Q0aS48@<H`Q236<248@236<01@Q236<<H`aS24800PaS
00@8@Q2436<@Q0<<H`0348@<H`aS00H<H`@@Q00336<@Q0aS00<<H`0448@<
H`aS36<248@336<01A2436<<H`Q236<00a240`Q20`aS00<8@PaS48@00Q24
0PaS00D@Q0aS36<<Ha24008<H`03248<Ha24008@Q00436<@Q0aS36<448@3
36<00a2436<@Q00348@00`aS48@<H`0236<0112436<<H`aS112400D8@PaS
36<<Ha24008<H`8@Q0<<H`8@Q00536<@Q12436<@Q00636<348@436<248@2
36<448@01@Q236<<H`aS48@01@aS00@8@PaS36<<H`88@P<<H`88@P/<H`05
248<H`aS248<H`02248536<00`Q236<8@P0336<01@Q236<<H`aS248020aS
0`Q200<<H`Q236<02@aS0a241@aS0`Q20PaS0`Q200<<H`Q224800PQ200@<
H`Q2248<H`<8@P@<H`03248<H`Q200<8@P8<H`@8@P0336<8@PQ20088@P8<
H`@8@P8<H`@8@P8<H`D8@P8<H`88@P031248@PaS008<H`H8@P8<H`@8@P04
36<8@PQ236<324800`aS2488@P02248236<01PQ236<<H`aS48@<H`@8@PD<
H`03248<H`aS00D<H`H8@P<<H`03248<H`Q20088@P0336<8@PQ200@8@P03
36<8@PQ200D8@P0336<8@PQ200H8@P8<H`88@P0336<8@PaS00H8@P0348@<
H`Q200<8@P8<H`88@P0436<8@PQ2248236<224800`@Q36<8@P02248010aS
1248@P@Q0PQ20P@Q00<8@PaS24800PQ20@aS0@Q200000`0012448@031240
0`0012448@03124010aS5:D<H`Q20`aS0PQ21@aS20Q200P<H`Q2248<H`Q2
36<8@PaS30Q210aS00@8@PaS36<<H`@8@P<<H`0324848@Q2008<H`<8@P04
36<8@PQ2248436<424800`aS2488@P03248236<3248236<010Q236<8@PaS
1@Q200@<H`Q236<<H`<8@P8<H`88@P061248@PaS36<8@P@Q0PQ200@<H`Q2
248<H`8@Q00536<8@PQ236<@Q0025:D00a2436<<H`02248010aS48@<H`Q2
0PaS00D@Q0aS2488@PaS0088@PD<H`0448@<H`aS248236<224801@aS48@@
Q0aS48@00PaS00D8@PaS36<<Ha2400<<H`0348@<Ha2400@<H`8@Q0H<H`03
248@Q124008<H`0448@<Ha24248836<010Q236<<H`Q20PaS1A240`aS00@8
@PaS48@@Q0@<H`0448@<H`aS248536<00a2436<<H`0236<0112436<<H`aS
0Q240PaS00D@Q1BU48@<Ha2400<<H`<@Q00436<8@PQ236<248@336<348@0
10aS48@@Q12410aS00<@Q1BU48@01@aS00<@Q0aS48@00PaS00@8@PaS36<@
Q0<<H`<@Q08<H`0348@<H`aS00@<H`@@Q0@<H`88@P0336<8@PaS00<<H`04
248<H`aS48@736<00`Q236<<H`0236<01PQ236<<H`Q236<8@P@<H`03248<
H`aS00D<H`@8@P<<H`0448@<H`aS36<2248336<3248236<2248336<22482
36<00`Q236<<H`03248236<324801PaS48@@Q0aS48@<H`8@Q00336<8@PaS
00<<H`D8@P8<H`<8@P8<H`88@P8<H`88@P<<H`03248<H`Q200@<H`03248<
H`aS00D8@P0636<8@PaS36<@Q0aS0`Q200<<Ha2436<00PQ21PaS1@Q200<<
H`Q224800`Q200@<H`Q22488@P8<H`<8@P<<H`88@P031248@PaS008<H`<8
@P0336<8@PQ20088@P8<H`03248<H`Q200<<H`03248<H`aS00@<H`03248<
H`Q200<<H`T8@P0436<8@PaS248336<724801`aS2488@PQ236<8@PaS0088
@P8<H`@8@P8<H`0424848@Q236<424800`aS2488@P0236<010Q21248@PaS
0`Q200D<H`Q2248<H`Q2008<H`88@P848@D8@P051248@PaS248<H`022480
0`aS2488@P02248236<2248000@48@0300048@@Q00848@0700048@@Q248@
Q0aS24802@aS0PQ20`aS0`Q200@48@Q236<@Q08<H`@8@P0448@<H`aS36<4
248436<2248248@00`aS2488@P0<24800`aS2488@P03248010aS248<H`aS
10Q20PaS1@Q200@48@Q22488@PP<H`05248<H`Q236<8@P0236<2248536<3
24801@aS2488@PaS48@00PQ210aS00@8@PaS36<8@P8<H`0548@DYA2436<8
@P0436<3248636<2248336<2248836<01@Q236<<H`aS24800PaS00@@Q0aS
36<8@PD<H`8@Q08<H`0348@<H`aS00<<H`0448@<H`aS248236<01Q2436<<
Ha2436<8@P8<H`0948@<H`aS36<@Q0aS48@<H`Q2008<H`8@Q08<H`D@Q003
248<H`aS008@Q003248<Ha24008@Q00336<@Q12400D<H`05248<H`aS36<@
Q00436<0112436<<H`aS112400@<Ha2436<@Q0`<H`0348@<Ha24008@Q006
36<@Q0aS48@<Ha240PaS00<@Q0aS36<00PaS00<@Q0aS36<00PaS0Q240PaS
00<@Q0aS36<00PaS0a2400@<Ha2448@@Q0@<H`<@Q00436<@Q12448@236<0
0`Q236<<H`0236<3248:36<00`Q236<<H`0436<01@Q236<<H`aS248010aS
00<8@PaS36<010aS00<8@PaS248010aS0`Q210aS00L48@Q2248<Ha2436<8
@P0336<010Q236<<H`aS0PQ20PaS00@8@PaS2488@P<<H`04248<H`aS48@5
36<00a2436<<H`0236<010Q21248@PQ20`aS00@8@PaS2488@P@<H`@8@P06
36<8@PaS248<H`Q210aS00@8@PaS2488@P8<H`88@P0436<8@PQ2248236<0
1a2436<<H`aS248<H`Q200<<H`05248<H`aS36<8@P0236<01@@Q2488@PQ2
48@00`Q200D<H`Q236<8@PaS00@8@P8<H`@8@P@<H`04248<H`aS36<32480
0`aS2488@P0436<3248236<010Q236<8@PQ21PaS00H8@PaS36<8@PaS2485
36<2248236<3248436<724800`aS2488@P0324800`aS2488@P04248236<2
24800`aS248<H`02248010aS248<H`aS10Q200L<H`Q22488@PaS248<H`03
24801P@Q2488@PaS24848@88@P8<H`<8@P0336<8@PQ200<8@P@<H`48@P00
00<48@0012400P@Q00<000@Q12400`@Q00<000Q236<00PaS00<8@PaS36<0
20aS0`Q200<<H`Q236<01PaS0PQ20PaS0`Q200D<Ha2436<48@Q200<<H`03
248<H`aS00<<H`88@P<<H`0348@<H`aS00<8@P0436<8@PaS36<224801@@Q
2488@PaS48@00PaS00<8@PaS24800`Q20PaS10Q20`aS0`Q20PaS0PQ200L<
H`Q2248<H`Q236<8@P0336<224800`aS248<H`05248336<2248336<00`Q2
1248@P0336<01ABU6<HHaQS636<00`Q200<<H`Q236<00PaS0PQ20`aS00<8
@PaS36<00Q240PaS00<8@PaS36<00`aS0a240PaS00<8@PaS48@01PaS00@@
Q0aS2488@P8<H`0348@<H`aS008<H`0348@<Ha24008@Q0D<H`<@Q0<<H`03
48@<Ha2400`<H`8@Q0@<H`L@Q08<H`<@Q00436<@Q0aS48@536<01@Q236<<
H`aS24800PaS0a240PaS00<@Q0aS48@00Q240PaS0Q240PaS00L8@PaS36<D
YA2436<8@P0236<248@01ABU48@@Q0aS24800`aS00@@Q0aS36<@Q0/<H`8@
Q0@<H`0548@<H`aS48@DY@0448@00aBU48@<H`0448@00aBU48@8@P0236<0
112436<<H`Q21PaS00<8@PaS36<00PaS00D8@PaS36<<H`Q200D<H`04248<
H`aS48@<36<00`Q236<<H`0536<5248336<2248336<2248936<2248236<0
1PQ236<<H`aS248<H`D@Q08<H`88@P0336<8@PQ20088@P<<H`88@P0336<@
Q0Q20088@P0336<@Q0Q2008<H`@8@P0436<8@PQ2248236<00`Q21248@P04
36<010Q21248@PQ20`aS00<8@PaS48@010aS0`Q20`aS0`Q20PaS10Q20PaS
00<8@P@Q24800PaS0`Q20P@Q00<8@PaS36<00PQ20`aS0PQ210aS0`Q20PaS
1@Q20PaS0PQ200<48@Q236<01PaS0`Q20`aS20Q20PaS2@Q20PaS00<8@PaS
36<010aS10Q20PaS10Q200<<H`Q224800`Q200<48@Q236<010Q200<<H`Q2
24800PaS1PQ200<<H`Q212401`Q200<<H`Q224800`Q200<<H`Q224800PQ2
00<<H`Q224800`Q20000100012448@0010@Q00H000@Q00048@Q248@336<0
10Q236<8@PQ20PaS00@@Q0Q224848@<<H`031248@PQ2008<H`88@P@<H`03
248<H`aS00D8@P<<H`@8@P@<H`88@P0436<8@PaS48@336<2248336<22482
36<32480112436<<H`aS0`Q20PaS0`Q210aS00<8@PaS36<010aS00@8@PaS
248<H`@8@P031248@PQ200<<H`04248<H`Q236<5248436<4248236<22480
1A245:DLiacW5:D00PaS0PQ220aS00<8@PaS36<00`Q21PaS0`Q210aS00@8
@PaS48@@Q0<<H`0448@<H`Q236<248@536<248@00aBU48@<H`0336<00a24
36<<H`0236<248@01PaS48@<Ha2436<@Q0D<H`8@Q00536<8@PaS36<@Q003
36<00aBU48@<H`0236<248@236<01A2436<@Q12436<00Q240`aS0Q2410aS
00H@Q0aS36<8@PaS48@236<248@436<448@=36<00a2436<<H`0448@236<0
0`Q248@<H`0736<0112436<<H`Q20PaS00D@Q0aS36<@Q0aS008@Q08<H`8@
Q0065:D@Q12436<DYA240PaS0a240`aS00<@Q0aS36<01PaS00<8@PaS36<0
30aS0`Q20PaS00D8@PaS36<<H`Q200D<H`03248<H`aS008<H`03248<H`aS
00H<H`04248<H`aS36<3248436<2248010aS2488@PQ210aS0PQ210aS0`Q2
0`aS11241@aS00@8@PaS248<H`D8@P0436<8@PaS248336<00`Q236<8@P02
248336<010@Q2488@PQ210aS1PQ20`aS0PQ200<<Ha2436<00`aS0PQ200<<
H`Q224800PQ20`aS10Q200<<H`Q224800`Q200<<H`Q2248030Q200D<H`Q2
24848@Q200@<H`<8@P8<H`@8@P@<H`@8@P8<H`0548@<H`Q236<8@P0236<3
24800`aS248<H`0236<00`Q236<8@P0324801a2436<8@PQ236<8@PaS0088
@P<<H`051248@PQ2248<H`0224800`aS2488@P0324800`aS24848@022483
36<7248336<010Q212448@Q20PaS00L8@P@Q248<H`Q21248@P0236<00`Q2
36<8@P0324802@@Q36<<H`aS24848@Q236<8@P0336<1124000848@050004
8@@Q12400005124010Q25:D<H`Q20PaS00@8@PaS36<@Q0<<H`03248<H`aS
008<H`88@P<<H`0448@<H`aS248212401@Q236<<H`aS24800PaS00<8@PaS
36<00`aS0`Q200<<H`Q224800PQ21@aS00@8@PaS248<H`88@P041248@PQ2
248236<2248010@Q248<H`aS0PQ200<<H`Q236<00`Q20PaS0PQ20PaS1@Q2
00D<H`Q236<8@PaS0088@P8<H`03248<H`Q200@<H`@8@P0336<8@PaS00<<
H`<8@P0436<8@PQ2248436<00`Q236<@Q00436<2248336<3248020aS2488
@PaS248@Q0aS48@436<00`Q236<<H`0248@00`aS248<H`02248936<22480
10aS48@@Q0aS0a240PaS11240`aS00@@Q0aS36<<H`<@Q0H<H`0448@<Ha24
36<248@236<248@010aS248<Ha240`aS0Q2400<<H`Q248@00Q2400<<Ha24
48@01@aS00@@Q0aS36<8@P/<H`<@Q0<<H`0348@DYABU00<<H`03248<H`aS
00@<H`0448@<H`aS248236<248@436<248@936<00a2436<<H`0436<02124
36<<Ha2436<@Q1BU48@336<00aBU48@@Q00236<248@00aBU48@@Q00348@2
36<0112436<8@PQ230aS00<@Q0aS36<00`aS1@Q200<<Ha2436<00PQ20PaS
0PQ220aS0`Q20`aS00@8@PaS48@<H`<8@P0336<@Q0aS00<8@P0336<8@PaS
00<8@PD<H`88@P@<H`88@P0548@<Ha245:D@Q00436<2248336<324800`aS
2488@P0236<00`Q236<<H`02248336<2248010aS248<H`aS1`Q21@aS00<8
@PaS36<010aS0a2400D<H`Q236<8@PaS00D8@P0436<8@PQ2248236<010Q2
1248@PQ20PaS0`Q20PaS0PQ200<48@Q212401@aS00L8@PaS2488@PaS248<
H`03248236<01@Q236<<H`Q236<00PQ20`aS0PQ200D<H`Q2248<H`Q200@<
H`08248<H`Q236<8@PaS248<H`<8@PD<H`@8@P0436<8@PaS48@236<22480
10aS2488@PQ20PaS10Q20PaS30Q20PaS10Q200@<H`Q21248@P8<H`032484
8@Q2008<H`<8@P031248@P@Q00<8@P0336<8@PQ200L8@P8<H`0000<000@Q
12400P@Q00D000@Q12448@0000848@0336<@Q0aS0088@P0336<8@PaS00D<
H`0348@<H`Q2008<H`03248<H`Q200D<H`0348@<H`aS00@8@P<<H`<8@P03
36<8@PQ200<<H`<8@P8<H`<8@PH<H`88@P8<H`88@P041248@PQ2248536<2
24800`aS2488@P0236<010Q236<<H`aS0`Q200<<H`Q224800PQ20`aS0PQ2
0PaS00@8@PaS2488@P@<H`<8@P0336<8@PQ20088@P0336<@Q0aS008<H`88
@P0436<8@PaS248436<010Q236<<H`aS0PQ200D<H`Q2248<H`Q2008<H`03
248<H`aS00L<H`04248<H`Q2248236<00a2436<<H`02248736<0112436<<
H`Q20`aS00@@Q0aS36<<H`D@Q0<<H`0348@<H`aS008<H`@@Q0D<H`8@Q0@<
H`<@Q00336<8@PaS00<<H`03248<H`aS00<@Q0<<H`8@Q08<H`8@Q0<<H`05
248@Q12448@<H`02248536<00a2436<@Q00236<0112436<<H`aS0a2410aS
00<@Q0aS36<00PaS00L@Q0aS36<8@PaS48@DY@0248@436<00a2436<<H`09
36<0112436<<H`aS0Q241PaS0a2400<<Ha2448@00Q2400L<Ha2448@@Q0aS
48@DY@0248@00`aS48@<H`0236<00`Q236<<H`0236<00`Q236<<H`0636<4
24800`aS2488@P0436<01`Q236<<H`Q236<@Q0aS00<8@P0348@<H`Q200<8
@P<<H`04248<H`aS248236<010Q236<<H`@Q0PQ20`aS00@8@PaS2488@P@<
H`05248<H`aS36<8@P0236<00`Q236<8@P02248236<01Q245:D@Q12436<@
Q0@<H`03248<H`aS00<<H`D8@P@<H`@8@P0336<8@PQ200<<H`<8@P8<H`88
@P041248@PaS36<224800`aS2488@P0236<0112436<<Ha240PaS0PQ20PaS
0PQ200L<H`Q224848@Q236<@Q003248336<224800`aS2488@P04248836<0
10Q212448@Q20`aS0PQ200<<H`Q236<00`aS00@8@PaS36<<H`@8@P<<H`04
248<H`aS36<224800`aS2488@P0436<7248436<2248436<4248436<00`Q2
1248@P05248236<4248010aS2488@P@Q0PQ200<<H`Q236<020Q200<<H`Q2
24801@Q200<<H`Q224801@Q200<<H`Q236<00`Q20`aS0@Q20@@Q00001@@Q
00048@@Q00001P@Q00D000Q248@<H`Q2008<H`8@Q08<H`<8@P<<H`@8@P03
36<8@PaS008<H`@8@P<<H`88@P<<H`88@P<<H`03248<H`aS008<H`88@P8<
H`<8@P<<H`L8@P8<H`<8@PL<H`@8@P@<H`<8@P0436<8@PaS248236<42484
36<00`@Q248<H`0424801`aS248<H`Q236<8@PaS00<8@PD<H`848@03248<
Ha2400/<H`88@P8<H`03248<H`Q200<<H`0648@<H`aS48@<Ha2410aS00@@
Q0aS36<8@PD<H`0448@DYA2436<2248236<01a2436<<H`Q236<@Q1BU008<
H`03248<Ha24008@Q08<H`0348@<Ha24008@Q0<<H`0448@DYA2436<22484
48@536<00a2436<<H`0436<248@00`aS248<H`0336<00a2436<<H`0736<0
0aBU48@<H`0336<01Q2436<<H`Q236<@Q08<H`03248<Ha24008@Q0<<H`8@
Q0D<H`8@Q0<<H`8@Q0<<H`<@Q0@<H`0348@<Ha2400D<H`03248<Ha2400<<
H`<@Q08<H`03248<Ha24008@Q08<H`8@Q0045:D<H`aS48@236<548@936<0
0aBU48@<H`02248<36<00`Q236<<H`0236<2248236<3248736<00`Q236<<
H`0236<00`Q236<<H`0224801@aS248<H`aS24800`aS0`Q20PaS00<8@Q24
24800PQ20PaS00<@Q0aS36<00PaS0`Q20`aS0PQ200@<HaBU5:D@Q08<H`88
@P<<H`<8@P@<H`88@P@<H`D8@P0336<8@PQ200<<H`07248<H`Q236<8@PaS
24801@aS00@8@PaS2488@P<<H`0448@<H`aS248236<010Q236<8@PQ20`aS
0PQ20PaS0PQ20PaS0`Q20PaS1`Q20PaS00@8@PaS2488@P8<H`88@P0336<8
@PaS00D8@P0436<8@PaS248436<2248236<2248236<00a2436<<H`052480
0`aS2488@P0224800`aS2488@P0236<7248236<3248010aS2488@PQ210aS
0`Q200<<H`Q2248010Q200<<H`Q224800PQ200D<H`Q236<8@PaS00<8@P8<
H`X8@P031248@PQ200H8@P@<H`@8@P<<H`48@P000P@Q00D000@Q12448@00
00848@0800048@@Q36<HaQ24248<H`88@PT<H`88@P041248@PaS36<32482
36<01@Q236<@Q12436<00PQ20PaS0`Q210aS0PQ20`aS00@8@PaS36<<H`88
@P<<H`88@P@<H`04248<H`Q21242248436<00`Q248@<H`0236<00`Q236<<
H`0236<00`Q236<8@P0336<4248436<01@Q236<8@PQ236<00PQ20`aS0`Q2
0`aS0`Q20PaS0PQ200D<H`Q224848@Q200@<H`88@P8<H`04248<H`aS36<2
248336<324801`aS48@<H`aS248<Ha24008<H`0448@<H`aS248736<010Q2
36<<Ha240PaS00<8@PaS36<01@aS00@DYA245:D@Q0D<H`<@Q00336<8@Q24
00<@Q0<<H`8@Q08<H`04248<H`aS36<348@236<248@236<00`Q236<@Q003
36<348@00`aS248<H`0248@336<00a2436<<H`0236<0112436<<H`Q20PaS
0Q2420aS0PQ20Q240`aS00<@Q0aS36<01`aS00<@Q0aS48@00`aS0Q241`aS
00<@Q0aS36<00PaS0Q240PaS00@@Q0aS36<<H`<@Q005248<Ha2436<@Q003
36<348@236<35:D336<00aBU48@@Q00448@536<01@Q236<<Ha2436<00`Q2
20aS0PQ200<<H`Q236<00`aS0`Q21@aS0PQ200L<Ha2448@8@PaS248<H`03
248236<00`Q236<<H`05248436<02@Q236<8@PaS248<H`Q236<8@P0436<0
1@@Q36<<H`aS48@00PQ200<<Ha2448@00Q241@aS0PQ200H<H`Q2248<H`Q2
48@436<3248336<624801`aS2488@PQ236<8@PaS0088@P<<H`0624848@Q2
36<8@P@Q0PaS0a241@aS0`Q20`aS10Q200<<H`Q236<00`Q210aS0PQ200T4
8@Q236<@Q0aS248<H`Q236<00`Q20PaS00<8@PaS24801@aS00L8@PaS248<
H`Q236<8@P0336<4248536<00`Q236<8@P0536<224801@@Q248<H`aS2480
0`aS0`Q20PaS00@8@PaS2488@PD<H`03248<H`Q20088@P<<H`T8@P031248
@PaS00P8@P8<H`0324848@Q20088@P0336<8@P@Q00848@03248<H`Q200D8
@P031248@PQ200@<H`88@P4<H`48@P0000@000@Q124000H48@0600048@aS
48@<H`Q22`aS0`Q20PaS10Q210aS00D8@PaS36<<H`Q200@<H`03248<H`aS
00<<H`<8@P<<H`<8@PH<H`<8@P0436<8@PaS248336<2248436<2248336<2
248336<3248336<2248236<010Q236<<H`aS1@Q20PaS00<8@PaS48@00PaS
0PQ22@aS0`Q20PaS0PQ20`aS00<8@PaS36<00PaS0`Q200L<Ha2436<<H`Q2
36<8@P0236<01@Q248@@Q0aS24800PaS0Q2410aS00<@Q0aS36<00PaS0Q24
0`aS00<8@PaS36<00Q2410aS00<@Q1BU48@01@aS0a2400<<Ha2436<00a24
00@<Ha2436<@Q0D<H`0548@<H`Q236<@Q00236<010Q248@@Q1240PaS00D8
@PaS36<@Q0aS0088@P8<H`8@Q0@<H`<@Q0<<H`8@Q0<<H`0948@<H`aS36<@
Q0aS248<Ha2400D<H`0348@<H`aS008@Q08<H`0348@<Ha2400@<H`0348@<
H`aS008<H`0348@<H`aS00<<H`0448@<H`aS36<348@336<00a2436<<H`03
48@336<01A2436<<Ha2436<00Q240PaS212400D<HaBU5:D@Q0aS00<@Q0@<
H`03248<H`aS008@Q004248<H`aS248436<00`Q236<<H`0336<00`Q236<<
H`0336<2248336<00`Q236<<H`0236<2248348@236<01@Q236<<H`aS2480
0`aS0PQ20PaS00D8@PaS248<H`Q200D<H`@8@P@<H`07248<H`aS248<H`Q2
48@02`aS00@8@PaS36<<H`@8@P8<H`@8@P8<H`03248@Q0aS00<8@P8<H`06
248<H`aS36<8@PaS1@Q20`aS1PQ211240`aS00<8@PaS248010Q20`aS00<8
@PaS24800`Q20PaS1@Q20`aS00<48@Q224801@aS0PQ200<<H`Q236<010Q2
0PaS00<8@PaS24800PaS00<8@PaS24800`aS0PQ200<<H`Q2248010aS0`Q2
00@<H`Q236<<H`@8@P8<H`0448@8@PQ2248236<3248010aS2488@PaS10Q2
0PaS1@Q200<<H`Q236<04PQ200D<H`Q22488@PaS00@8@P0436<8@PaS36<3
24800`@Q248<H`0336<010Q236<8@P@Q0PQ20PaS0PQ2000412401@001244
8@@Q00000`@Q00<@Q1S636<00PQ200<@Q0aS36<010aS00<@Q0aS36<01@Q2
0PaS0PQ200@<H`Q22488@PD<H`@8@PD<H`88@P0336<8@PaS00<<H`88@P03
36<8@PQ2008<H`0324848@Q2008<H`88@P8<H`<8@P<<H`03248<H`Q200<<
H`<8@P0336<@Q0aS00<8@P0436<8@PQ2248236<4248236<5248436<00`Q2
36<<H`0236<2248010aS48@@Q0Q20PaS00H8@PaS248<H`Q236<2248236<0
0a24248<H`0436<3248010aS248<H`Q21PaS0Q2400<<Ha2448@00`aS00<@
Q0aS36<00PaS00D@Q0aS36<<H`Q200<<H`04248<H`aS36<348@01@aS248<
Ha245:D01@aS00D@Q0aS36<@Q1BU008@Q0<<H`0348@<H`aS008<H`0448@<
H`aS36<248@010aS48@@Q1240PQ200@<Ha2436<@Q0H<H`04248<H`aS48@4
36<248@010aS48@@Q1240`aS00<@Q0aS36<00Q2410aS0Q240PaS00L8@PaS
48@<Ha245:D@Q00336<248@336<0112436<<Ha240`aS00<@Q0aS36<01@aS
0Q241@aS00<8@PaS36<00a240PQ200@@Q1BU48@@Q08<H`<@Q00436<@Q0aS
36<:48@536<248@436<0112436<<H`Q20`aS00@8@PaS36<8@P<<H`03248<
Ha2400<<H`04248<H`aS36<2248536<2248436<248@01`aS248<H`Q248@<
H`Q200<<H`03248<H`aS00@<H`0648@<H`aS24848@Q210aS00@@Q0aS2488
@PD<H`04248<H`aS248336<348@00`aS248<H`02248336<224800`aS2488
@P0324801`aS248<H`aS248<H`Q2008<H`88@P0636<8@PaS36<8@PaS0`Q2
10aS00@8@PaS248<H`88@P0436<@Q12448@636<01@Q236<<H`aS12401PQ2
00@<H`Q22488@P8<H`88@P0636<8@PaS248<H`Q21@aS0PQ20PaS0PQ20PaS
0`Q20PaS0`Q20PaS0`Q20PaS00@48@Q2248@Q08<H`88@P0636<8@PaS36<8
@PaS10Q20`aS20Q20`aS2@Q200<<H`Q224800`Q200L@Q0aS2488@P@Q248<
H`0224800`@Q248<H`03248236<6248010aS248<H`aS0`@Q00@8@PaS248<
H`X8@P<<H`88@P8<H`48@P0000<000@Q00000`@Q00@000@Q124000848@06
248DYA24248<H`Q20PaS0Q240PaS00<8@PaS36<00`aS0`Q20PaS00D8@P@Q
36<<Ha2400<8@P<<H`<8@PH<H`88@P<<H`H8@P0336<8@PaS008<H`03248<
H`Q200@8@P0:36<8@PaS248<H`Q236<8@PaS248236<2248436<224800`aS
2488@P0324800`aS248<H`0236<00`Q236<<H`0236<00`Q236<<H`0236<0
0a2436<<H`0224800`aS2488@P0:36<2248436<01PQ236<8@PaS48@<H`<8
@P8<H`0448@<H`Q2248248@736<010Q236<<H`Q20PaS0Q240PaS00D@Q0aS
248<H`Q200<@Q0<<H`<@Q0P<H`<@Q0<<H`<@Q0H<H`<@Q08<H`@@Q088@P03
36<@Q12400<<H`<@Q0<<H`03248@Q0aS008<H`<8@P0336<DY@aS008<H`05
5:D@Q124248<H`0248@01aBU48@<H`aS48@<Ha2400<<H`05248<H`aS48@D
Y@0248@010Q236<@Q1240`aS00@@Q0aS36<@Q0<<H`8@Q00336<@Q0aS00H<
H`0448@<H`aS36<248@236<010Q248@@Q0aS0Q241`aS1A2400<<Ha2448@0
0Q2400<<Ha2448@011240PaS00<8@PaS36<00Q2420aS00@8@PaS36<8@PL<
H`05248<H`aS36<@Q00236<3248436<010Q236<8@PQ20PaS0Q240`aS00H8
@PaS36<8@PaS248336<00`Q236<8@P0336<010Q236<8@PaS1@Q21PaS00H8
@PaS2488@PaS248236<010Q236<<H`Q20PaS0Q2400<<H`Q236<00PQ20`aS
00L8@PaS2488@PaS248<H`0324800`aS2488@P02248336<324801PaS248<
H`Q236<8@PP<H`<8@P0336<8@Q2400<@Q00336<8@PaS00<8@PH<H`<8@P09
36<8@PQ224848@aS248@Q0aS00@8@PD<H`88@P03124<H`Q200<8@PD<H`03
248<H`Q2008<H`0448@<H`aS1242248010aS48@<H`Q21@aS00<8@PaS36<0
10Q200@48@Q236<<H`88@P0336<8@P@Q0088@P<<H`<8@P0436<8@PQ22482
36<00`@Q248<H`0236<:248236<2248010aS2488@PQ20PaS0`Q200<<H`Q2
24800PQ20PaS0PQ200<48@Q236<01`Q200<<H`Q224800PQ210aS0@Q20@@Q
000412400`0012448@0512400`aS48@<H`0224801@aS248<H`aS48@00PaS
0PQ21PaS00@8@P@Q2488@P<<H`06248<H`Q2248<H`Q220aS00H8@P@Q248<
H`Q236<324800`aS2488@P0336<4248010aS2488@PQ20`aS0PQ200<<H`Q2
36<00`aS00<8@PaS36<00PaS0PQ20PaS00D8@PaS248<H`Q200<<H`03248<
H`Q20088@P0336<8@PQ20088@P8<H`04248<H`Q2124224800a2436<<H`02
36<4248436<01@Q236<<H`aS24800`aS00@@Q0Q22488@PP<H`03248<H`aS
00<<H`0348@<H`aS00D<H`8@Q00436<@Q12448@636<01a2436<8@PaS48@D
YA24008<H`<@Q0H<H`D@Q0<<H`0548@<H`aS248<H`0248@00`aS2488@P06
36<248@336<00`Q236<8@P0236<01A2436<<H`aS48@00`aS00<8@PaS2480
0PaS1Q2410aS00H@Q0aS36<@Q1BU48@736<00`Q236<<H`0448@436<00a24
36<8@P0236<248@336<348@010aS248<Ha240`aS0Q241@aS1Q240`aS0Q24
00D<Ha2448@DY@aS0088@P@@Q0<<H`8@Q0035:D@Q12400H<H`0548@<H`aS
36<8@P0336<01@Q236<<Ha2436<010Q20Q240PaS00<8@PaS36<00PaS0PQ2
00<<H`Q236<00PQ20PaS0PQ20PaS00<@Q0aS36<00Q2400H<H`Q236<8@PaS
248336<00`Q236<<H`04248336<02PQ236<8@PaS248<H`Q236<8@PaS10Q2
0PaS00<8@PaS24800PaS10Q21@aS1@Q20PaS1`Q200<<H`Q224800PaS20Q2
00<<H`Q224800`aS00<8@PaS36<00PQ20`aS00<8@PaS24800`aS0Q241`aS
0`Q200<<H`Q224800`Q200D<H`Q22488@PaS00<8@P8<H`0448@<H`aS36<3
248236<010Q236<8@PaS0`Q200D<H`Q236<8@PaS00<8@P8<H`88@P8<H`88
@P8<H`03248<H`Q200H<H`D8@P8<H`88@P0336<8@PaS00<<H`05248<H`aS
248<H`0324800`aS2488@P02248236<2248010@Q2488@PaS0`Q200@<H`Q2
36<<H`L8@P031248@PaS00<8@P0336<8@PQ200@8@P0536<8@PQ224848@03
24800`@Q2488@P0324800`aS248<H`0224800`aS248<H`0136<000030004
8@@Q00848@0=00048@@Q00048@001248@Q2436<8@PaS24800PaS10Q20`aS
00<8@PaS24801@Q21@aS0`Q200<<H`Q2248010Q200<<H`Q236<010Q20`aS
10Q200D<H`Q22488@PaS0088@P0336<8@PaS00<8@P0536<8@PaS248<H`04
248236<010Q236<<H`aS0PQ200<<H`Q236<00`Q200<<H`Q224800PaS1@Q2
10aS0PQ200D<H`Q236<<H`Q200H<H`03248<H`Q2008<H`03248<H`Q2008<
H`0648@<H`aS248<Ha241@aS00@@Q0aS36<<H`<8@P8<H`8@Q08<H`88@P8<
H`0348@<H`Q200<8@PX<H`0348@<H`aS008<H`8@Q08<H`8@Q08<H`0448@<
H`aS36<448@436<348@01@Q236<@Q1BU48@010aS00<@Q0aS36<02`aS00D8
@PaS48@@Q0aS00<8@PD<H`035:D@Q0aS008<H`0648@DY@aS248<Ha240aBU
0`aS00@@Q0aS48@<H`<8@P@<H`0348@<H`aS008<H`8@Q088@P0736<@Q1BU
48@<H`Q236<00Q2400<<H`Q236<01`aS00<@Q0aS36<010aS0Q2400<<Ha24
48@00Q240PaS00<@Q0aS36<00PaS00P8@PaS48@@Q1BU36<8@PaS11240PaS
00<@Q0aS36<00PaS00<@Q0aS36<00`aS00<@Q0aS36<00`Q200@<H`Q22488
@P<<H`03248<H`aS00H<H`06248<H`Q236<8@PaS0`Q210aS0PQ200<<Ha24
48@00`aS0`Q20`aS0`Q210aS0`Q210aS00H8@P@Q248<Ha2436<424800`aS
48@<H`0236<5248236<00`Q236<<H`0336<4248236<424800`aS2488@P03
248236<00`Q236<8@P05248336<00`Q236<<H`0524800`aS48@<H`0236<2
248236<648@00`aS2488@P02248336<224800`aS48@<H`03248236<22480
1@aS248<H`aS248010aS1@Q200<<H`Q224801PQ20PaS00<8@P@Q12400PQ2
00@<H`Q22488@P8<H`<8@P<<H`04248<H`aS36<5248236<00`Q236<8@P05
248236<00`@Q2488@P0424800`@Q248<H`0224800`@Q2488@P0724802P@Q
2488@PQ236<8@P@Q24848@aS1@Q200<<Ha2436<00`Q200X48@Q22488@PaS
248<H`@Q248<H`@8@P0536<8@PaS248<H`02248136<12481124000041240
00@Q0008124020aS5:D<H`Q236<@Q0aS248836<5248236<2248010aS48@<
H`aS0PQ210aS0PQ200D<H`Q236<8@PaS0088@P<<H`H8@P@<H`P8@P8<H`88
@P0336<8@PQ200<<H`04248<Ha2436<2248336<224802@aS2488@PQ236<8
@PaS248<H`02248236<2248536<01@Q2124<H`aS48@00PaS00@8@PaS36<8
@P<<H`88@PL<H`88@P0336<@Q0aS00D<H`88@P0436<@Q0Q2248236<00a24
36<<H`0436<01Q2436<<H`Q236<8@P<<H`03248<H`aS008@Q0D<H`D@Q0<<
H`<@Q0@<H`<@Q00536<8@PaS48@DY@0536<00a2436<@Q00236<00`Q236<<
H`0736<00a2436<8@P0224800a2436<<H`0236<00a2436<8@P0636<448@2
36<00a2436<DY@0248@01PaS48@<Ha2436<@Q0L<H`0348@<H`aS00@<H`03
48@<H`aS008<H`8@Q0045:D<H`aS36<248@336<00`Q236<@Q00248@436<0
0a2436<<H`0236<00a2436<@Q00248@25:D0112436<<H`aS0Q241`aS00<@
Q0aS48@01Q240`aS0Q243@aS0PQ200D<H`Q236<<H`Q200@<H`05248<H`aS
36<8@P0336<010Q236<<Ha240PaS00@8@PaS2488@PD<H`03248<H`Q200@<
H`88@P8<H`03248<H`Q200@<H`03248<H`aS00@8@P8<H`<8@P0336<@Q124
00H<H`@8@P05124<Ha2448@<H`0224800`aS2488@P02248436<00`Q236<<
H`04248236<724800`@Q248<H`0236<00`Q236<<H`02248236<0112436<<
H`Q21`aS0QBU00<@Q0aS24800PaS0PQ20PaS00@8@PaS36<<H`H8@P@<H`03
248<H`Q200@<H`03248<H`Q200<8@P<<H`<8@P<<H`88@P@<H`<8@P07124<
H`Q236<8@PaS24800PaS0`Q21@aS00<8@PaS24800PQ200<<Ha2436<00PQ2
00@48@aS36<<H`88@P0536<8@PQ2248<H`0224801PaS2488@PQ21248@P<<
H`031248@PQ2008<H`88@P031248@PaS008<H`P8@P0336<8@PQ200@8@P05
36<8@PaS248<H`03248010aS24848@Q20`aS0PQ20PaS0@Q20@@Q00041240
0`001240000212401P0012448@aS5:D<H`88@P0436<@Q12436<624800`aS
2488@P0224800`aS48@<H`0424800`aS248<H`02248236<00`Q236<8@P02
36<00`Q236<<H`03248236<3248010aS2488@PQ210aS10Q20`aS0PQ20`aS
00<8@P@Q248010aS00<@Q0aS36<00PQ200<<H`Q224800PQ200@<H`Q236<8
@P8<H`D8@P0336<@Q0Q20088@PH<H`09248<H`aS36<@Q0aS248<H`Q2008<
H`0348@<H`Q200@<H`05248<Ha2436<8@P0236<2248010aS48@DYABU0`aS
0`Q20PaS0Q2400<<H`Q236<01PaS00@@Q0aS36<<H`8@Q0<<H`0348@<H`aS
008@Q0D<H`<@Q00336<@Q0aS00<<H`8DY@0348@<H`aS00<@Q0<<H`0448@<
Ha2448@536<0112436<@Q1240`aS00@@Q0aS36<8@P<<H`04248@Q12448@3
24800a2436<<H`0336<248@336<01A245:D@Q12436<00a2400<<Ha2436<0
10aS00<@Q0aS36<00`aS0a241@aS00<@Q0aS24800PaS0Q240PaS00<@Q0aS
36<04@aS00D@Q0aS36<@Q0aS00@@Q0<<H`8@Q00336<@Q12400@<H`8DY@03
48@DY@aS00@<H`<@Q0H<H`0748@<H`aS36<8@PaS248010aS0`Q20`aS0Q24
00D<H`Q236<<Ha24008<H`<8@P8<H`03248<H`Q200@8@P8@Q08<H`05248<
H`aS48@<H`0224800`@Q248<H`0236<2248336<01Q2436<<H`Q21248@P8<
H`<8@P8<H`8@Q00536<8@PQ2248<H`02248536<00`Q236<8@P0236<00`Q2
36<8@P0236<010Q236<8@PaS0`Q20PaS0`Q200<<H`Q224800PQ20PaS10Q2
0`aS00D8@PaS36<<H`Q2008<H`0448@<H`aS248336<2248236<348@00aBU
36<<H`03248010aS2488@PQ20PaS20Q20`aS0PQ200D<H`Q2248<H`@Q00<<
H`0424848@@Q248236<4248236<2248010aS2488@PQ210aS0PQ21@aS00<8
@PaS24801`Q20PaS1`Q200<<H`Q224800PQ20PaS00@8@P@Q2488@P8<H`D8
@P0536<8@PQ2124<H`0324800`@Q2488@P03248010aS2488@PQ20`aS00@8
@PaS2488@P8<H`<8@P051248@PaS248<H`03248336<00`Q236<8@P0336<3
24800004124000@Q00071240100036<@Q0aS0PQ20PaS00@@Q0aS2488@P@<
H`<8@P0336<8@PQ20088@P0436<8@PQ2248336<01PQ236<<H`Q236<8@P8<
H`06248<H`Q2248<H`Q21@aS0PQ210aS0PQ200<48@Q2248010Q200H<H`Q2
36<8@PaS48@236<2248436<;248936<3248936<2248436<010Q236<<Ha24
0`aS00<8@PaS36<00PQ200@<Ha2436<<H`88@P0636<8@QBU6<HDYA2410aS
0PQ21PaS00D@Q0aS36<<H`Q200D<H`8@Q0P<H`<@Q08<H`<@Q0D<H`0848@<
H`aS48@DYA2436<8@P8<H`8@Q08<H`8@Q0D<H`0348@<H`aS00P<H`03248<
H`aS00L<H`<@Q08<H`03248<Ha2400<<H`8@Q08<H`0348@DYABU008@Q08<
H`0448@8@PaS36<348@236<010Q236<<Ha241PaS0PQ200<<Ha2448@00`aS
0Q2430aS0a240PaS00L8@PaS36<<Ha2436<DY@0448@;36<010Q236<@Q124
0`aS0a240`aS00D@Q0aS48@<Ha2400<<H`0348@<H`aS0088@P0336<@Q0aS
00<<H`<@Q0T<H`05248<H`Q236<8@P0436<00`Q236<8@P0536<00`Q236<<
H`0236<4248336<010Q236<8@PaS0PQ20PaS00<8@PaS24800PQ20PaS00<8
@PaS36<00PaS00<8@PaS48@00PaS00<8@PaS24800PQ20`aS00<8@PaS2480
0PaS0PQ20PaS00@@Q0Q224848@88@P8<H`@8@P0336<8@P@Q0088@P0336<8
@PaS00<<H`04248<H`Q236<324800`aS248<H`0236<010Q236<<H`aS0`Q2
0PaS00<@Q1BU5:D00`aS00H8@PaS36<<H`Q236<4248336<224800`@Q36<<
H`0336<324800`aS248<H`0624801@aS1248@PQ236<00PQ20P@Q0PaS00<8
@PaS24800PQ200<<H`Q224800PQ200H<H`Q236<8@PaS48@336<4248010aS
2488@PaS1@Q20PaS0`Q200<<H`Q224801PQ200<<H`Q224800`Q200<<H`Q2
24800PQ200@<H`Q22488@P8<H`P8@P0436<8@PaS248236<01@Q21248@P@Q
36<00`Q200<<H`Q224800`Q20`aS0`Q210aS0@Q200000`0012448@021240
100012448@000`@Q00@<HaBU48@8@P@<H`@8@P<<H`88@P03124<H`aS00<<
H`04248<H`aS36<324800`aS2488@P0336<010Q236<<H`aS0`Q200L<Ha24
36<<H`Q21248@P0336<2248336<2248336<224800`aS248<H`0236<22483
36<224800`@Q36<<H`0236<00`Q21248@P0536<01@Q236<<H`aS248010aS
0`Q20`aS00<8@PaS36<01`aS00<8@PaS24801@aS00<@Q0aS36<00`Q21@aS
0`Q200<<HaBU48@00`aS00@8@PaS2488@PT<H`@@Q00336<@Q0aS00<<H`<@
Q0@<H`88@P8<H`@@Q08<H`0448@DYABU48@536<348@336<248@25:D01PaS
248<H`aS48@DY@8@Q00536<@Q12448@<H`02248736<00a2436<<H`0536<0
0a2436<<H`0536<948@00aBU48@<H`0236<00aBU48@@Q00436<2248236<2
48@324800`aS48@@Q00436<248@236<248@636<248@336<248@236<00a24
36<@Q00236<01Q245:D<H`aS248<H`<@Q0<<H`<@Q0<<H`0348@DYA24008<
H`<@Q08<H`8@Q08<H`88@PD<H`04248<H`aS48@236<00`Q236<<H`0336<0
0a2436<@Q00536<00`Q236<<H`0336<424800`aS48@8@P032480112436<<
Ha240`aS00<8@PaS248020aS0`Q20`aS0`Q210aS00<8@PaS36<00`Q200<<
H`Q236<00`Q200<<Ha2436<00`Q20Q2400L<H`Q22488@PaS248<H`032480
10@Q2488@PaS0`Q20PaS10Q20PaS0`Q20`aS1PQ210aS00<8@PaS36<00`Q2
0PaS00H8@Q245:DDYA24248336<00`Q236<<H`0236<224800`aS248<H`02
36<00a2436<<H`0224800`aS48@<H`03248236<324800`@Q2488@P032483
36<2248010aS248<H`aS1PQ20PaS00<8@PaS24800PaS2PQ200D<H`Q22488
@PaS00@8@P0336<8@PaS00<8@P8<H`<8@P0336<8@PQ200L8@P8<H`052484
8@@Q1248@P0236<224800`aS248<H`0324800`aS2488@P0324801@aS2488
@PQ212400PQ20`aS10Q200L<H`Q22488@PaS248<H`01124000@48@030004
8@@Q00<48@0500048@aS5:D<H`0224801Q2436<<H`Q236<8@P<<H`D8@P<<
H`@8@P0336<8@PaS00@<H`D8@P@<H`88@P<<H`<8@P8<H`03248<H`aS008<
H`<8@P8<H`<8@P<<H`@8@P0336<8@PQ20088@P@<H`88@P0336<@Q0Q200<8
@P@<H`03248<H`Q20088@P@<H`88@Pd<H`0824848@Q2248@Q0aS248<H`88
@P<<H`88@P<<H`06248<Ha2448@<H`Q20Q2400@<H`Q22488@P8<H`0348@<
H`aS00D<H`8@Q00436<@Q12448@436<248@00`aS248<H`0336<00`Q236<<
H`0348@336<348@00`aS48@DY@0236<010Q236<<H`aS112400<<Ha2448@0
0Q2410aS00<@Q0aS48@00PaS00L@Q0aS36<<H`Q236<8@P0236<00a2436<<
H`0248@536<01A2436<8@PQ236<00a2400<DYA2448@00Q240PaS0Q2410aS
0Q241@aS00<8@PaS36<020aS00@@Q0aS36<<H`@@Q0L<H`8@Q00436<8@PaS
48@336<00a2436<<H`0448@236<348@010Q236<@Q1241PaS00<@Q0aS48@0
0a240PaS11240`aS00<@Q0aS36<00`aS00<@Q0aS36<01`aS00D8@PaS36<<
Ha24008<H`03248<H`aS00L<H`0348@<H`aS0088@PD<H`88@PP<H`05248<
H`Q236<8@P0236<00`Q236<<H`0236<424801PaS248<H`Q236<8@PL<H`03
248<H`Q200H<H`04248<H`aS48@236<4248336<3248336<3248010aS2488
@PQ20`aS00<8@PaS36<00PaS00<48@Q224800PaS00@8@PaS48@<H`<8@P8<
H`03248<H`Q2008<H`03248<Ha2400<@Q0<<H`88@P<<H`03124<H`aS008<
H`03248<H`aS00@<H`<8@P8<H`d8@P0336<8@PaS0088@P0336<@Q0aS0088
@P8<H`<8@P0436<8@PQ2248436<224800`@Q2488@P0236<3248236<42480
0`aS2488@P0236<00`Q236<8@P0924801@aS248<H`Q236<00`Q20PaS0`Q2
00<<H`Q224800`Q200@<H`Q236<<H`88@P0336<8@PaS00<8@P8<H`@8@P8<
H`@8@P@<H`03248<H`Q20048@P0000<000@Q00000`@Q00<000@Q12400`@Q
00L<HaBU36<8@PaS248<H`03248236<424801Q2436<8@PQ236<8@PD<H`03
48@<H`Q20088@P0336<8@PQ2008<H`0:48@<H`Q2248<H`Q236<8@PaS2488
36<424800`aS2488@P0336<00`Q236<<H`0236<00`Q236<<H`0236<22482
36<010Q236<<H`aS0PQ20`aS00H@Q0aS2488@PaS48@336<248@236<020Q2
36<<H`aS248<H`Q248@536<00`Q236<<H`0236<3248248@01@aS2488@PaS
24800`aS00<8@PaS36<01@aS00<8@PaS36<010aS00T8@PaS36<@Q1BU48@8
@PaS24801@aS00@@Q0aS36<<H`8@Q0/<H`D@Q08<H`@@Q0@<H`8@Q0D<H`03
48@DYA2400D<H`0348@<H`aS00<<H`8@Q00336<8@PaS00D<H`0648@<H`aS
36<@Q0aS0PQ21@aS0PQ200@@Q1BU5:D@Q0P<H`0348@<Ha24008@Q0<<H`03
248<H`aS008<H`04248<H`aS36<2248236<01PQ236<@Q0aS48@<H`8@Q08<
H`03248@Q0aS008<H`@@Q00336<@Q0aS00<@Q0@<H`@@Q0<<H`8@Q0<<H`04
48@<H`aS36<648@00`aS48@@Q00348@236<0112436<<H`aS0PQ210aS0PQ2
0PaS00@8@PaS48@<H`88@P0336<@Q0aS00L<H`<8@P0436<@Q0aS248336<3
248536<00`Q248@<H`0236<00a2436<<H`0324800`aS2488@P0436<00`Q2
36<<H`0236<2248436<010Q236<8@PQ21@aS00<8@PaS36<02@aS0a240`Q2
0`aS10Q200<<H`@Q248010aS0PQ220aS0`Q20`aS00<8@PaS24800PaS10Q2
00D<H`Q236<<H`Q2008<H`8@Q0035:D@Q0aS00D<H`0748@<H`aS36<8@PaS
24801`aS0`Q20`aS00@8@P@Q1248@P8<H`03248<H`aS0088@P0436<8@PaS
36<2248336<3248010aS24848@Q20PaS0PQ200@<H`Q22488@P8<H`@8@P8<
H`@8@P0336<8@PQ200P8@P0436<8@PQ236<324801@aS2488@PQ212400`Q2
00D<H`Q22488@P@Q00<8@P0536<8@PaS248<H`0?248336<3248236<42480
0`aS2488@P01248000D48@0500048@@Q12400002124021245:D8@P@Q248@
Q0aS248236<2248436<2124436<00`@Q248<H`0236<00`Q236<8@P0836<0
0`Q236<<H`0236<00`Q236<<H`0236<3248236<248@00`aS2488@P052484
36<2248010aS2488@PQ20PaS00D8@PaS36<8@PaS00@8@P0336<8@PaS00D<
H`04248<H`aS48@336<248@236<00a24248<H`02248336<0112436<8@PaS
0PQ20`aS00<8@PaS36<01@aS0Q240`Q21PaS00<8@PaS36<00`aS00<8@PaS
36<01`aS00<@Q0aS36<00PaS11240PaS11240PaS00<8@PaS36<01@aS1124
0`aS1A241PaS00L@Q1BU48@<H`Q236<@Q00236<248@00aBU48@<H`0236<0
0`Q236<<H`0248@236<00a2436<<H`0236<248@636<01A2436<@Q0aS48@0
0`aS11240PaS0a240`aS112430aS00<8@PaS36<010aS00<@Q1BU48@00a24
10aS00D8@PaS36<<Ha2400<<H`X@Q0@<H`8@Q08<H`0448@<H`aS36<248@0
0aBU48@<H`0248@01ABU48@@Q0Q236<0112400P<Ha2436<@Q0aS248<H`Q2
0PaS00<8@PaS48@00PaS00@8@PaS48@@Q0D<H`0348@<H`aS00@<H`03248<
Ha24008<H`88@P0436<8@PQ2248336<010Q236<<H`aS0Q241@aS00<8@PaS
24800PQ20`aS00<8@PaS36<020aS0PQ210aS00D8@PaS36<<H`Q2008<H`05
48@DY@aS36<8@P0236<00a2436<<H`0336<2248436<3248236<724800`aS
48@<H`0236<2248010aS2488@PQ21PaS0PQ210aS00<8@PaS24800`aS00HD
YA2436<@Q0aS248536<00`Q236<<H`0336<00`Q236<<H`02248436<22480
1@aS248<H`aS24800PaS00D8@PaS248<H`Q200@<H`03248<H`Q200P8@P03
36<8@PQ20088@P<<H`@8@P8<H`03248<H`Q20088@P031248@PQ2008<H`@8
@P0536<8@PQ2248<H`02248010@Q248<H`Q20`aS10Q200H<H`Q22488@P@Q
248236<010Q236<8@PaS1@Q200@<H`Q236<<H`@8@P<<H`<8@P8<H`D8@P04
36<8@PaS248236<22480000400048@@Q000412402@0012448@@Q36<DYA24
248<H`0424801PaS248<H`aS248<H`<8@P8<H`0548@<H`aS36<@Q00236<0
0`Q236<<H`0324800`aS248<H`0436<01PQ236<<H`aS248<H`88@P071248
@PaS248<H`Q236<01PQ200<<H`Q236<00PaS0`Q200<<H`Q224800PQ200<4
8@Q224800PaS00<8@PaS36<00Q240`aS10Q200<<Ha2448@010aS0`Q200<<
Ha24248010aS00D8@PaS36<<H`Q2008<H`88@P8<H`0448@8@PQ2248536<0
10Q236<8@PQ210aS0`Q200H<Ha2436<<H`Q236<248@2248636<00`Q236<<
H`0336<248@336<348@336<00a2436<<H`0348@336<348@336<0112436<<
H`Q210aS00H@Q0aS36<<Ha245:D248@336<548@00`aS248<H`0436<010Q2
36<<Ha241`aS00P@Q0aS2488@PaS48@<H`Q20PaS00@@Q0aS48@<H`<@Q0<<
H`035:D@Q0aS00D<H`0348@<H`aS00T<H`031248@PQ200L<H`0348@<H`aS
00<@Q0H<H`8@Q0055:D@Q0aS48@<H`0348@736<348@01@Q236<<Ha2436<0
11240`aS00<@Q1BU48@010aS00@8@PaS36<@Q08<H`06248<H`aS48@<H`Q2
10aS00<8@PaS36<02PaS00<8@PaS36<00`Q20`aS00D8@PaS248<H`Q200@<
H`88@P0536<8@PQ21248@P0336<248@236<3248>36<3248236<010Q236<8
@Q240`aS00<@Q0aS36<00`Q200<<Ha2436<00PaS00<@Q0aS36<00PaS00D8
@PaS24848@Q2008<H`0624848@Q2248<H`Q22`aS00<8@PaS36<00`aS00<8
@P@Q24800PaS0`Q20PaS00<8@PaS48@00PaS0PQ200<@Q0aS36<00PaS00H8
@PaS36<8@PaS248236<2248436<2248436<224801@aS2488@PaS24800PaS
1`Q20PaS0PQ200L<H`Q236<<H`Q236<8@P0336<2248236<324800`aS248<
H`02248010aS248<H`aS0PQ200@48@aS36<<H`@8@P0336<8@PQ200<8@P8<
H`<8@P0336<8@PQ200@8@P8<H`0324848@Q20088@P061248@PQ236<8@PaS
0PQ200@<H`Q2248<H`@8@P<<H`@8@P0436<8@PaS36<2248236<2248336<1
248136<1248000848@0500048@@Q1240000312401@00124<HaBU36<00PQ2
00D<H`Q236<<H`Q200@<H`@8@P8<H`0348@<H`aS00D<H`<8@P0336<8@PQ2
008@Q00336<8@PQ20088@P@<H`<8@P0336<8@PQ200D<H`03248<H`aS00<8
@P8<H`03248<H`Q20088@P@<H`04248<H`Q236<3248010aS48@@Q1240PQ2
10aS00P8@PaS48@@Q0aS248<H`Q20PaS00<8@PaS248010aS00@8@PaS36<@
Q0D<H`88@P0736<8@PQ2248<Ha2436<00PQ21@aS0PQ20`aS00<8@PaS36<0
1@aS0PQ210aS0Q241PaS0Q241PaS00@@Q0aS48@@Q0<<H`0448@<Ha2436<3
48@436<00a245:D@Q00248@436<01QBU48@<H`aS248<H`8@Q00436<@Q124
48@236<01A2436<<H`aS48@02@aS00<@Q0aS48@00PaS00D@Q0aS36<<H`Q2
00D<H`@@Q00336<8@PaS008DY@0448@<H`aS36<248@436<00aBU48@<H`02
36<010Q248@<Ha240PaS0PQ200<<Ha2436<00`aS0a240`aS0Q2400X<Ha24
36<@Q0aS48@<Ha2436<@Q08<H`8@Q0035:D<H`aS00<@Q0@<H`<@Q00436<@
Q0aS36<348@020aS48@<Ha2436<@Q1BU48@336<348@00`aS248@Q0025:D0
0a242488@P0:36<02@Q236<<Ha2436<8@PaS48@<H`03248536<00`Q236<<
H`0336<3248236<4248236<00`Q236<<H`0236<01@Q236<<H`aS24801@aS
0`Q210aS0`Q200<<H`Q224800PQ20`aS0PQ20PaS00D@Q0aS36<<H`Q200T<
H`04248<H`aS248236<5248236<00`Q236<<H`0536<3248236<01@Q236<<
Ha2436<00PQ20PaS0`Q200@<H`Q22488@P@<H`88@PP<H`08248<H`aS36<8
@PaS248<H`<8@P8<H`88@P<<H`88@P<<H`D8@P8<H`04248<H`Q2248436<0
10Q236<@Q0aS0PQ200<<H`Q224800PQ20PaS0PQ20P@Q0PQ20PaS0`Q20`aS
00D48@Q2248<H`@Q0088@P8<H`88@P041248@PaS36<2248336<9248236<3
24800`aS2488@P04248236<010Q236<<H`aS0`Q20`aS20Q20PaS0`Q20PaS
00@8@PaS48@<H`448@0000D000@Q12448@0000L48@0636<HaQ24248<H`Q2
0PaS00L8@PaS248<H`Q236<8@P0236<2248336<01A245:DDYA2436<00PQ2
1@aS00D8@PaS36<@Q0aS0088@P@<H`88@P<<H`03248<Ha24008<H`04248<
H`Q2248236<5248336<4248336<224800`aS248<H`0436<2248336<01124
36<8@PaS0Q2400X<H`Q22488@PaS248<H`Q236<8@P/<H`88@P8<H`0448@<
H`Q2248636<010Q236<<H`aS0`Q20`aS0PQ200D<Ha2448@<H`Q200<<H`03
48@<H`aS008@Q003248<H`Q2008<H`0348@<H`aS00@@Q0@<H`0348@<Ha24
008<H`<@Q00336<8@PaS008@Q0@<H`<@Q0<<H`8@Q0<<H`8@Q0<<H`<@Q0<<
H`0348@<H`aS008<H`03248<H`aS008@Q08<H`0648@<H`aS36<8@PaS0PQ2
0`aS0a240`aS00<@Q0aS36<00PaS0Q2410aS00<@Q0aS36<00a2410aS00<@
Q0aS48@01PaS00<8@PaS36<010aS0a240PaS00<@Q0aS36<00PaS00@@Q1BU
5:D@Q0<<H`0448@<Ha2436<248@00aBU48@<H`0236<00a2436<@Q00336<0
112436<<Ha240QBU00H@Q0Q236<DYA2436<548@636<00a2436<<H`0636<0
0`Q236<<H`0436<00`Q236<<H`0248@236<00`Q236<<H`0336<3248236<3
24800`aS2488@P0436<4248536<2248436<02P@Q248<H`Q236<8@PaS248<
Ha240PaS0PQ20PaS0`Q20`aS00<8@PaS248020aS00<8@PaS36<00PaS0PQ2
0PaS00<8@PaS48@00PaS0PQ20`aS00@8@PaS36<8@P<<H`<8@P0536<@Q0aS
36<8@P0436<248@010aS2488@PaS0`Q200@<H`Q236<<H`<8@P<<H`04248<
H`Q236<324800`aS48@<H`0536<224800`aS248<H`0236<00`Q236<8@P03
36<3248236<00`Q236<8@P0236<00`Q236<<H`02248010aS248<H`Q20`aS
1PQ200<<H`Q224801@Q200<<H`Q2248010Q200D<H`Q224848@Q2008<H`<8
@P<<H`848@04248<Ha2436<3248236<7248236<324800`aS2488@P032480
0`aS2488@P03248010aS2488@P@Q0PQ200<<H`Q224800PQ20PaS0`Q20PaS
00<8@PaS24800`Q20PaS000312400`0012448@0312400`0012448@025:D0
1PaS248<Ha2436<8@P8<H`88@P<<H`88@PH<H`0448@DYA24248336<01@Q2
36<8@PQ236<010Q200<<H`Q2248010aS10Q20PaS00D8@PaS2488@PaS0088
@P0336<8@PQ20088@P0436<@Q0Q2248436<00`Q2124<H`0236<00`Q21248
@P0248@736<00a2436<<H`0236<00a2436<<H`02248736<224800`aS48@<
H`0236<010Q236<@Q0aS0`Q20Q2400D<H`Q236<<H`Q200@<H`03248<H`aS
00<<H`88@P<<H`0348@<H`aS00@<H`8@Q0@<H`03248<H`Q200<<H`0348@<
Ha2400<<H`04248<H`aS48@736<548@00`aS248<H`0348@01PaS48@<Ha24
36<@Q0`<H`@@Q0@<H`88@P0548@<Ha2436<@Q00436<3248:36<00a2436<<
H`0236<248@336<01A2436<@Q0aS48@00PaS00<8@PaS36<00`aS0Q241PaS
00D8@PaS36<<Ha24008<H`8@Q08<H`0348@<H`aS008<H`0448@<Ha2448@4
36<848@436<00a2436<@Q00836<348@00`aS48@@Q00736<010Q236<@Q124
0PaS00@8@PaS36<<H`8@Q003248<H`aS00<<H`03248<H`aS00L<H`0348@<
H`Q200<8@P8<H`0548@<H`aS36<8@P0336<2248436<3248236<00`Q236<8
@P0336<010Q236<@Q1240PaS00@8@PaS36<<H`88@PD<H`04248<H`aS36<3
24800`aS248<H`0336<2248336<2248436<424800`aS48@<H`04248010aS
2488@PaS0PQ20`aS00<8@PaS248010aS00H@Q0aS36<<H`Q236<324801PaS
2488@PQ236<8@P8<H`03248<H`aS00@8@P<<H`<8@P<<H`0348@<H`Q200<8
@P<<H`88@P0536<@Q0aS36<8@P0636<00`Q236<<H`0236<324801@aS248<
H`aS24800`aS10Q200<<H`Q236<00PaS10Q200T<H`Q236<8@PaS248<H`Q2
36<00`Q200<<H`Q2248010Q200<<H`Q2248010Q20PaS10Q20PaS1`Q20PaS
2@Q200<<H`Q236<01@Q20PaS10Q200D<H`Q22488@PaS00<8@P@<H`L8@P00
00<48@0012400P@Q00@000@Q124000<48@0336<HaQ240088@P<<H`<8@PH<
H`03248<H`aS008<H`8@Q0<<H`03248<H`Q200<8@P8<H`<8@PD<H`04248<
H`aS36<2248236<324800`aS2488@P02248236<2248436<424800`aS2488
@P03248010aS248<H`Q21PaS0PQ20`aS00X@Q0aS36<<H`Q236<8@PaS248<
H`88@P0336<8@PaS00P<H`04248<H`aS248336<2248010aS248<H`Q20`aS
00@8@PaS36<<H`88@P8<H`04248<H`aS36<248@00`aS48@<H`0448@336<0
0a2436<<H`0736<00a2436<<H`0336<348@336<248@00aBU36<<H`0236<0
212436<<Ha2436<@Q0aS48@336<248@236<00a2436<<H`0224800a2436<<
H`0236<248@236<010Q236<@Q0aS0PQ200@<Ha2436<@Q0D<H`04248<H`aS
248336<224800`aS48@@Q00348@536<448@010aS2488@PaS0Q2410aS00@D
YA2448@@Q0<<H`03248<H`aS00<<H`8@Q00536<8@PQ2248<H`0248@32483
48@436<01A2436<<Ha245:D00Q240`aS0Q240PaS00H8@PaS36<<Ha2436<3
48@336<01ABU48@DYA2436<00Q240`aS00D@Q0aS36<8@Q24008<H`031248
@Q2400T<H`0348@<H`aS00H<H`0348@<H`aS00<<H`03248<H`Q200<<H`<8
@PD<H`<8@P8<H`<8@P8<H`88@P0336<8@PQ200@<H`88@P<<H`88@P@<H`03
248<H`Q20088@P@<H`88@PH<H`0348@<H`aS008<H`<8@PL<H`@8@P0336<8
@PQ200<<H`88@P<<H`<8@P0336<@Q12400D<H`@8@P<<H`<8@P0436<8@P@Q
248336<00`Q236<<H`03248248@00`aS2488@P0636<00`Q236<<H`022487
36<01A24248<H`Q236<00`Q20PaS0PQ200<48@Q236<00PQ210aS30Q20PaS
0`Q200<<H`Q236<03@Q200<<H`Q224800PQ200<<H`Q224800PQ200<48@Q2
12400`Q20PaS0PQ200@<H`Q224848@88@P0336<8@PQ200@<H`<8@P0536<8
@PQ224848@02248236<324800`aS2488@P03248336<2248336<000050004
8@@Q1240000512401`00124<HaS648@<Ha24008<H`<8@P0336<8@PaS00<<
H`07248<H`aS36<@Q0aS24800`aS00@8@PaS248<H`88@P8<H`03248<H`Q2
0088@P8<H`88@P8<H`05248<H`Q236<@Q00236<00`@Q248<H`0236<32480
0`@Q36<<H`0236<2248010aS248<H`aS0PQ200D<H`Q236<<H`Q200<<H`88
@P8<H`0348@<H`Q200<<H`0348@<H`aS0088@P8<H`0324848@aS00<<H`03
248<H`aS00@8@P<<H`88@P0336<8@PQ2008<H`8@Q00436<8@PQ2248336<3
248236<2248236<224800`aS48@@Q00336<248@011BU48@<H`Q21PaS00<@
Q0aS36<00PaS00<@Q0aS36<00`aS00<@Q0aS36<01@aS0a240`aS00<8@Q24
48@00Q241PaS00<@Q0aS36<00Q241PaS0Q240PaS0Q2400<<H`Q236<00`Q2
0`aS0Q241PaS0PQ20PaS0Q2410aS0Q2400<<Ha2436<00`aS00<@Q0aS36<0
0`aS00<@Q0aS24800Q2400@DYA24248<H`@@Q08<H`03248<H`aS00L<H`03
48@<H`aS00L<H`8@Q0<<H`<@Q00436<@Q1BU48@336<248@336<02A245:D@
Q0aS248<Ha245:D@Q00336<248@436<248@536<01A2436<8@PaS48@010aS
00<@Q0aS36<00PaS00/8@PaS36<@Q0aS248<Ha2436<@Q0aS0088@P0436<8
@PQ2248336<01PQ236<<H`Q236<8@P<<H`03248<H`Q200<8@P0336<8@PaS
00<8@PX<H`04248<H`aS48@236<00`Q236<@Q00436<00`Q236<8@P0536<4
24802@aS48@@Q0aS24848@aS248<H`02248436<010Q236<<H`Q21`aS00<8
@PaS36<00PaS00@8@PaS36<@Q0L<H`03248<H`aS00<<H`88@P0436<@Q0aS
248536<324800`aS248<H`03248336<2248936<00`Q236<8@P0324800`aS
248<H`0236<010Q236<<H`aS0PQ20`aS0PQ20PaS0`Q200@<H`Q22488@P8<
H`88@P0536<8@PQ2124<H`02248010@Q36<<H`aS0PQ20`aS0`Q200<<H`Q2
12400PQ20PaS0`Q200<<H`Q224800`Q20PaS1`Q20PaS00<48@Q224800`Q2
00<48@aS24800`Q200<<H`Q212400PQ200<<H`Q224800PQ210aS10Q20PaS
00D8@PaS248<H`Q2008<H`88@P448@000P@Q00D000@Q12448@0000D48@04
36<DYA24124236<00`Q236<<H`0236<00a2436<8@P02248236<01@Q236<<
H`aS48@010aS00<8@PaS36<00`aS0PQ200@48@Q248@<H`88@P0336<8@PQ2
0088@P<<H`<8@P0636<8@PQ236<8@PaS0PQ200<<H`Q224800`aS0PQ21@aS
00<8@PaS24800PaS00<8@PaS24800PaS00D8@PaS248<Ha2400@<H`0748@<
H`aS248<Ha2436<00PQ200H@Q0aS248<H`Q236<224800`aS48@<H`0536<0
10Q236<8@PaS0`Q210aS00<8@PaS36<010aS00L8@PaS36<<Ha2436<8@P06
36<01@Q25:DDYABU48@00`aS00<8@PaS36<00Q2400<<Ha2436<00`aS00<8
@PaS36<00Q2410aS1A240`aS0Q240PaS0Q240`aS00D@Q0aS248<H`Q200P<
H`0448@<H`aS36<248@236<248@3248348@010aS48@<H`aS0PQ20`aS00<@
Q0aS36<00PaS00D@Q0aS36<@Q0aS008@Q00336<@Q0aS00<<H`8@Q00336<8
@PQ200<<H`0448@<Ha2448@236<011245:D@Q1242@aS00@8@PaS36<@Q08<
H`05248<H`aS248<H`0448@236<348@236<00a245:D<H`0236<248@236<3
48@436<25:D248@00`aS48@@Q00248@436<0112436<<H`Q21@aS00<8@PaS
48@00`aS00T8@PaS36<<Ha2436<@Q0aS48@01PaS00H8@PaS36<<Ha2436<4
248436<010Q236<<H`aS1PQ200@<H`Q236<8@P8<H`03248<H`Q200<8@P@<
H`<8@P<<H`03248<H`Q2008<H`03248<H`Q2008<H`@8@P0336<8@PaS00<<
H`07248<H`Q236<8@PaS24800`aS00<8@PaS36<00`aS00<8@PaS36<00`aS
00<8@PaS36<00PaS1@Q200L<H`Q236<<Ha2436<@Q00236<00`Q236<<H`03
36<7248010aS48@<H`Q20PaS00<@Q0aS248010aS0`Q20PaS0PQ20PaS0`Q2
0PaS10Q20PaS00P8@PaS36<@Q0aS248<H`Q20PaS00<8@PaS24800PaS00@8
@PaS48@<H`<8@P8<H`04248<H`aS36<324800`aS2488@P04248010@Q2484
8@aS0PQ200<<H`Q224800`Q20PaS00D8@PaS2488@PaS00H8@P0436<8@PQ2
124924800`aS2488@P02248236<010Q236<8@PaS0PQ200<<H`Q236<01@Q2
0PaS1@Q200@<H`Q236<8@P<<H`<8@P8<H`88@P0000<48@0012400P@Q00<0
00@Q12400P@Q00@000@Q36<DY@P<H`88@P0436<@Q12436<2248536<248@4
248336<00`@Q2488@P0236<2248236<011242488@PQ20PaS00D48@Q236<@
Q0aS0088@P0336<8@PaS00@8@P0336<8@PQ200<<H`P8@P@<H`88@P0336<@
Q12400P<H`0348@<H`aS00<8@P<<H`03248<H`aS008<H`031248@PaS00<<
H`88@P@<H`<8@PL<H`88@P0436<@Q0aS36<2248236<00a2436<8@P0336<0
1Q2436<<H`aS48@HaP<DY@P<H`0348@<Ha24008@Q00336<8@PaS008@Q003
5:D@Q12400<<H`<@Q0@<H`0448@<Ha2436<248@336<248@010aS248<Ha24
0PaS00<@Q0aS36<00PaS0Q241PaS0Q241`aS00<@Q0aS36<00PQ200<<Ha24
48@00PQ200<<Ha2448@00PaS00@@Q0aS36<<H`8@Q00336<8@PQ200<@Q0@<
H`<@Q0H<H`0448@DYABU48@2248536<00`Q236<<H`0236<01@Q236<<H`aS
48@00`aS00@8@Q2448@DY@8@Q0<<H`D@Q00436<@Q0aS36<648@01@aS48@@
Q1BU36<0112430aS0PQ20PaS00<@Q0aS24800PQ210aS0a2410aS00<@Q0aS
36<010aS0Q2400<<H`Q224800`Q20PaS00@@Q0Q22488@P<<H`03248<H`aS
008<H`03248<H`aS008<H`04248<H`aS36<2248436<00`Q236<@Q00236<3
248236<324800`aS48@8@P02248336<01PQ236<8@PQ236<8@PD<H`03248<
H`Q200D<H`88@PH<H`0348@<H`aS00D<H`05248<H`aS36<8@P0236<248@2
36<00a2436<<H`0436<4248236<3248236<01@Q236<<H`Q236<00`Q20PaS
0PQ200<<H`Q236<00`aS0`Q210aS0PQ200<<H`Q224800PaS00<@Q0aS36<0
0`Q210aS0PQ20PaS0PQ200<@Q0aS24800PQ20PaS0`Q20PaS00@8@P@Q2484
8@<<H`88@P8<H`@8@P0336<8@PQ20088@P@<H`L8@P0436<8@PQ2248436<<
248010aS2488@PQ20PaS10Q200<48@Q224800`aS10Q200<<H`Q236<00PaS
0`Q20`aS0`Q20@aS0@Q20000100012448@0010@Q00T000@Q12448ABU6<H@
Q0@Q24800PaS00D8@PaS36<<H`Q200D<H`06248<H`Q236<@Q0aS0`Q20`aS
0PQ200@<Ha2436<<H`88@PH<H`0424848@Q2248236<00a2436<8@P022482
36<4248236<01`Q236<@Q0aS24848@aS008@Q00636<8@PQ236<8@PaS0`Q2
1PaS00<8@PaS36<00Q240PaS00<8@PaS36<00PaS0`Q20`aS00@8@PaS36<<
H`<8@P0536<@Q0aS36<8@P0236<324801@aS248<H`Q236<00PQ20PaS0PQ2
10aS0PQ20PaS00@@Q0aS36<8@PH<H`<@Q0@<H`0448@8@PaS36<248@236<0
1a2436<<H`aS48@DYA2400@<H`0548@<H`aS36<@Q00436<01A2436<<Ha24
36<00`Q210aS00D@Q0aS36<<H`Q2008<H`03248<Ha2400H<H`@@Q00436<8
@PQ236<248@01@Q236<<H`aS48@00`Q200<@Q1BU48@00`aS0Q2400<<H`Q2
36<00Q2410aS0Q240PaS0PQ20PaS0Q2400D<H`Q236<<HaBU008<H`03248<
H`aS00@<H`<@Q0L<H`04248<Ha2436<348@02@aS48@DYABU48@8@PaS48@D
Y@0448@00`aS48@<H`0348@00`aS48@<H`0248@236<00a2436<@Q00236<3
48@436<010Q236<<H`Q20PaS00<@Q0aS36<00`aS00<8@PaS48@00Q2400<<
H`Q248@00Q2400<<H`Q236<00Q2400D<H`Q236<<H`Q200<<H`0448@<H`aS
248236<00a2436<<H`0324800`aS48@<H`03248010aS2488@PQ21@aS0PQ2
00<<H`Q224800`aS10Q20`aS00<8@PaS36<00`aS00<8@PaS24800PaS0`Q2
0PaS0PQ20PaS00@8@PaS36<<H`<8@P8<H`<8@P@<H`88@P8<H`<@Q08<H`<8
@PH<H`04248<H`aS36<2248236<248@236<00`Q236<<H`03248336<42489
36<224801P@Q2488@PQ236<8@P@<H`88@PH<H`@8@P<<H`<8@P0436<8@PaS
248336<010Q236<<H`aS0`Q200D<H`Q236<8@P@Q00<8@P0336<8@PQ20088
@P0336<8@PQ20088@P8<H`03248<H`Q200<8@P0336<8@PQ20088@P031248
@PQ200<8@P8<H`0424848@Q2248336<224800`aS2488@P0236<224800`@Q
2488@P0236<524800`aS24848@0224800`aS2488@P02248336<3248236<3
248536<1248000@48@0300048@0000D48@0448@Lia24248236<010Q236<<
Ha240PaS0PQ200<@Q0aS24800PQ200@<Ha2436<8@P<<H`88@P@<H`04248<
H`Q2248336<010Q236<<H`aS0PQ200<<H`Q2248010aS2PQ20PaS0PQ20PaS
0`Q20PaS10Q20PaS00<8@PaS24801`aS1PQ20PaS0PQ200<<H`Q224800`aS
00<8@PaS36<01`aS00@8@PaS2488@P@<H`03248<H`aS00@<H`03248<H`aS
008<H`<8@P8<H`8@Q08<H`06248<Ha2436<8@PaS0a240PaS0Q240`aS0a24
00L<Ha2448@@Q0aS48@<H`0248@236<00a2436<<H`0248@636<010Q236<<
H`aS0a240PQ200@<Ha2448@<H`88@P8<H`0548@<Ha2436<@Q00236<00a24
36<<H`0536<448@536<01PQ21248@PaS5:D@Q0<<H`<@Q00336<8@PaS00<@
Q0D<H`03248<H`aS008@Q004248<H`aS36<248@00aBU48@<H`0248@236<0
0`Q236<@Q00248@436<0112436<<H`aS0PQ20Q240PaS00H8@PaS48@@Q0aS
48@236<00a2436<@Q00236<448@00`aS48@@Q00336<0112436<<H`aS0a24
10aS00<@Q1BU48@00PaS00<8@PaS48@01@aS00H@Q0aS36<8@PaS248236<2
48@030aS2488@PaS48@DY@aS248<HaBU36<8@P8<H`0348@<H`aS00<<H`88
@PD<H`03248<H`aS00<<H`<8@PL<H`05248<H`aS36<@Q003248436<01@Q2
36<<H`aS24800PaS00<8@PaS24800PQ210aS0PQ20`aS0`Q20PaS0PQ20`aS
00<8@PaS36<010Q200@<H`Q236<<H`88@P0836<@Q12436<8@PaS48@<H`88
@P<<H`88@PL<H`04248<H`aS48@536<324800a2436<<H`02248436<00`Q2
36<8@P0236<224800`aS248<H`05248010aS2488@PQ220aS00<8@PaS36<0
0`aS00D8@PaS36<<H`@Q0088@P<<H`88@P@<H`88@P8<H`88@P8<H`032484
8@Q200H8@P0336<8@PQ20088@P0336<8@P@Q00L8@P8<H`031248@PaS00@8
@P<<H`03248<H`aS00@<H`03248<H`Q200d8@P051248@PQ21248@P0236<4
248336<2248336<5248236<12480000300048@0000H48@0700048@@Q48@L
iaS6248010aS0`Q200P<Ha2436<8@PaS24848@aS0Q2400D<H`Q2248@Q0aS
00<8@P8<H`09248<H`Q236<@Q0aS48@<Ha24008<H`88@P0336<8@PQ20088
@P8<H`<8@P0536<8@PQ21248@P0336<01PQ236<@Q1BU48@<H`88@P0336<@
Q124008<H`04248<H`aS36<224800`aS48@<H`02248836<224800`aS48@<
H`0736<010Q236<8@PQ210aS00<8@PaS36<00PaS00H8@PaS2488@PaS2483
36<00`Q236<<H`0936<448@00`aS248@Q00248@436<00aBU36<<H`0248@3
36<248@236<248@236<548@536<00a2436<@Q00248@436<248@436<248@3
36<248@010aS248<H`aS0a242`aS1A240PaS0PQ210aS00@8@PaS48@@Q08<
H`8@Q0D<H`04248<H`aS248936<248@736<01`Q236<8@PQ248@DYA2400<<
H`0448@<H`Q2248636<248@010aS48@<Ha240PaS0Q2400<<Ha2436<01Q24
0`aS112400<DYA2436<00Q2400@DYA2436<<H`<@Q08<H`03248<H`aS00@<
H`8@Q00336<8@PaS008<H`8@Q0055:D<H`Q2248<H`0248@336<01A245:D@
Q0aS248020aS00/8@PaS36<@Q0aS248<H`Q236<8@PaS00<8@P0536<8@PaS
36<8@P0236<00`Q21248@P0336<2248836<00`Q236<<H`0336<2248236<0
1@Q236<8@PaS24800`aS0`Q20`aS00D8@PaS36<<H`Q200<<H`88@PD<H`<8
@P0636<@Q12448@<H`Q210aS0PQ21@aS00<8@PaS48@010aS0`Q200<<H`Q2
36<01PaS10Q200@<H`Q236<8@P<<H`04248<H`aS248236<424801Q2436<<
H`Q236<8@P8<H`03248<H`aS00<<H`<8@P0336<8@PaS00<<H`<8@P8<H`03
248<H`aS00<<H`0348@8@PQ20088@P8<H`0324848@Q200<<H`P8@P0336<8
@PQ20088@P0336<8@PQ2008<H`@8@P0436<8@PQ236<3248336<01@Q236<8
@PaS24800`aS0PQ20`aS00<8@P@Q24800`Q200@<H`Q224848@88@P0336<8
@PQ200<8@P031248@PQ2008<H`<8@P8<H`03248<H`aS00<8@P0010@Q00<0
00@Q12400`@Q00L000@Q6<HQ2124124<H`0248@336<2248336<00`Q236<<
H`0236<2248436<3248236<011242488@PQ20Q2400@<Ha2436<8@P<<H`88
@P@<H`@8@P@<H`88@P<<H`0448@DYA2436<224800a2436<<H`0236<32482
36<3248236<00a2436<<H`02248236<00`Q236<8@P0336<010Q236<<H`Q2
3@aS00<@Q0aS36<010Q20PaS00<8@PaS24801@aS00L8@PaS36<<H`Q236<8
@P0336<0112436<8@PQ21PaS1Q2400H<Ha2448@<H`Q236<248@336<00a24
36<@Q00548@010aS248<H`Q20PaS0a2400D<H`Q236<<Ha2400<<H`@@Q08<
H`0448@<Ha2448@336<0112436<@Q0Q20PaS0Q240`aS0Q240`aS00<DYA24
36<00`Q21@aS00<8@Q2448@00a240`aS00D@Q0aS36<<H`Q2008<H`0548@<
H`aS248<H`0348@336<01Q2436<<H`aS48@<H`88@P@<H`0448@<H`aS36<2
48@3248236<010Q236<<Ha2410aS0Q2400<<Ha2436<00Q2400L<Ha2448@@
Q0aS48@<H`0348@236<248@236<248@011BU48@<H`aS0a241PaS00@8@PaS
36<@Q08<H`03248<H`aS008@Q00336<8@PQ2008@Q08<H`8@Q0@<H`8@Q005
36<@Q0aS36<@Q00536<00`Q236<<H`0436<01PQ236<<H`Q236<8@P8<H`05
248<H`aS248<H`02248336<00`Q236<<H`0436<2248236<00a2436<8@P02
24801`aS2488@PQ236<8@PaS00@8@P0336<8@PQ2008<H`03248<H`Q2008<
H`0448@<H`Q2248236<00`Q21248@P0236<00`Q236<8@P02248236<01124
36<@Q1240PaS0PQ20PaS00<8@PaS248010aS0PQ200<<H`Q248@01@aS0`Q2
2@aS0PQ20`aS0PQ200<<H`Q236<01`Q20PaS00<8@PaS24800`aS00@8@PaS
2488@PP<H`<8@P0336<8@PaS008<H`03248<Ha24008<H`<8@P@<H`032484
8@Q200@8@P031248@PQ200D8@P<<H`0624848@aS36<8@P@Q0PQ200<<H`Q2
24800PQ200<<H`Q224800`Q210aS00D8@PaS36<<H`Q2008<H`0348@8@PQ2
0088@P<<H`848@88@P8<H`L8@P031248@PaS008<H`<8@P8<H`<8@P031248
@PQ20088@P0000<000@Q12400`@Q00<000@Q12400`@Q00@<HaBU48@<H`8@
Q00336<8@PaS00<<H`88@P0536<8@PQ236<8@P0636<00`Q236<8@P022480
0`aS2488@P0236<02Q2436<DYAS67>LDY@aS248<Ha240PaS00D8@PaS36<@
Q0aS0088@P0336<8@PaS00<8@P0436<@Q0Q248@25:D00a242488@P022484
36<3248736<01Q2436<<H`aS24848@8<H`0648@<H`Q2124<H`Q20PaS00<8
@PaS24802@aS0PQ200D<H`Q236<<H`Q200X<H`03248<H`Q200<8@P0336<@
Q12400<<H`8@Q0<<H`8@Q0@<H`8@Q08<H`0348@<H`aS00L<H`0348@<Ha24
008<H`<@Q0@<H`0348@<H`aS00<@Q00336<@Q0aS008<H`0348@<H`aS00<<
H`8@Q00436<8@PaS36<348@011BU48@@Q0Q220aS00<@Q0aS36<00Q241@aS
00@8@PaS36<<H`<@Q0`<H`03248<H`aS00@<H`0348@<H`aS00D<H`0548@<
H`aS36<8@P0336<00a2436<<H`0336<248@436<010Q248@<Ha240PaS00<@
Q0aS36<00PaS0Q240PaS00D@Q0aS36<<HaBU008@Q00736<DYABU48@<Ha24
5:D00a2400<<HaBU5:D00Q242PaS00<8@Q2448@00`aS0Q240PaS00<8@PaS
36<00Q2420aS00<8@PaS36<00Q2400P<Ha2436<<H`Q236<@Q0aS0PQ20Q24
0PaS00<8@PaS36<01PaS00<8@PaS24800`aS00<8@PaS24800PaS00<@Q0Q2
36<00PQ21`aS00<8@PaS36<00`aS0PQ210aS00<8@PaS36<00PaS0`Q200D<
H`Q22488@PaS0088@P8<H`04248<H`aS36<2248236<010Q236<8@PaS0`Q2
0PaS00D8@PaS5:D@Q0aS0088@P0336<8@PaS00@<H`88@P0336<@Q0aS0088
@P8<H`05248<H`aS36<8@P0736<224800`aS248<H`0336<01@Q236<8@PaS
24800`aS00<8@PaS24801PaS0Q240`aS00P8@PaS36<8@PaS248<H`Q21@aS
0`Q22PaS00<8@PaS24801PQ20PaS10Q20`aS00<8@PaS24800PQ200<<H`Q2
24801@Q20PaS0`Q210aS0`Q20`aS00<8@PaS24800`aS0`Q20PaS00P8@P@Q
1248@PaS48@<H`@Q2@Q200H<H`Q22488@PaS48@336<224800`aS2488@P01
36<00006124000@Q00048@000P@Q00L000@Q12448@aS6<H@Q00536<00`Q2
36<<H`0236<2248236<00`Q236<<H`0636<01@Q236<8@PaS248010aS00<@
Q0aS48@00QcW00<@Q0Q224800`aS0PQ200<<Ha2436<00PaS0PQ20`aS00H8
@PaS36<<H`Q248@25:D011242488@PaS0`Q200<<H`Q236<01`Q200<<Ha24
48@00PaS00<8@PaS36<00`aS00@8@PaS36<<H`88@P@<H`88@P@<H`03248<
H`aS008<H`06248<H`aS248<H`Q21PaS00D8@PaS36<<H`Q2008<H`88@P8<
H`0348@<H`aS008@Q0@<H`0448@<Ha2448@236<00a2436<@Q00236<00a24
36<<H`0536<00a2436<@Q00736<01A2436<<H`Q236<0112400<<H`Q248@0
0PaS0Q2400D<H`Q236<8@Q2400D<H`8@Q0@<H`8@Q0D<H`04248<H`aS36<2
48@00aBU48@<H`03248236<01A245:D@Q0aS24800`aS0a240PQ20`aS00D8
@PaS36<<Ha2400@<H`035:D@Q12400<<H`0348@<H`aS00D<H`88@P8<H`04
48@<H`aS248436<00`Q248@<H`0836<348@536<448@436<248@25:D00a24
36<@Q00448@236<348@00`aS248<H`0248@00`aS2488@P0?36<348@010aS
248<Ha242@aS0PQ200<<Ha2436<00`aS00@8@PaS2488@P@<H`<8@P8<H`03
248<H`aS008<H`03248<H`Q200@<H`<8@PD<H`88@P8<H`88@P<<H`041248
@PaS248436<324801PaS2488@PQ236<@Q0<<H`<8@P<<H`04248<H`Q22482
36<01@Q236<<H`Q236<00Q240PaS0PQ21@aS00<8@PaS24800PQ200@<Ha24
36<8@P8<H`<8@PH<H`8@Q088@PH<H`03248<H`aS00<<H`05248<H`Q236<8
@P0636<00a2436<<H`0236<010Q236<<H`aS0PQ20`aS0PQ20PaS00<8@P@Q
36<01@aS0`Q20PaS00@8@PaS36<<H`X8@P0336<8@PQ200D8@P0636<8@PaS
36<8@PaS2PQ20PaS0`Q20`aS00<8@PaS24800PQ200H<Ha2424848@Q236<2
248010@Q2488@PaS10Q200<<H`Q212400`Q200<48@Q224800`Q210aS1`Q2
000912401`0012448@Q26<H@Q0aS00@@Q00336<8@PaS00D<H`<8@P0536<@
Q0aS36<8@P0336<010@Q24848@aS0PQ200<<Ha2448@00`aS0aBU00<@Q0aS
36<01`aS10Q21PaS00L@Q0aS36<<H`Q236<8@P0236<01`Q236<8@PaS248<
H`Q200@<H`03248<Ha24008<H`06248<H`aS248<H`Q20PaS00@8@PaS248<
H`88@P8<H`0348@<H`Q20088@P@<H`88@PL<H`03248<H`aS0088@PD<H`88
@P<<H`@@Q0P<H`04248<H`aS48@336<248@236<00a2436<<H`0248@010aS
48@<Ha2410aS00<@Q1BU5:D00`aS0Q2400<<Ha245:D00Q240PaS0a2400<<
Ha2436<00PaS00D@Q0aS36<<Ha2400@<H`0848@<Ha2436<@Q0aS48@<H`<@
Q0@<H`8@Q08<H`0648@8@PQ236<8@Q2410aS0Q241@aS00@@Q0aS36<8@P8<
H`06248@Q1245:D<H`Q21@aS0a2400<<Ha2436<010aS0Q242PaS00<8@PaS
36<020aS00<@Q0aS36<00QBU00D@Q0aS36<@Q1BU00H@Q08<H`0648@DYA24
48@<Ha240PaS112400D<Ha2436<<H`Q200<@Q00336<@Q124008@Q0h<H`04
48@<Ha2436<224800`aS48@@Q00336<348@336<248@010aS48@<H`aS0PQ2
00<<Ha2436<01@aS00@8@PaS36<<H`88@P0336<@Q0aS00<8@PD<H`04248<
H`Q236<2248436<324800`aS48@8@P03248436<224801@aS248<Ha2436<0
0`Q20PaS0PQ20`aS0`Q20PaS00<@Q0aS24800PQ20PaS00P8@PaS36<@Q0aS
248<H`Q20`aS00<8@PaS36<00PaS00<8@PaS36<010aS00<8@PaS24800`aS
00<@Q0aS36<00PaS00D@Q0aS36<8@PaS008@Q088@P0336<8@PQ200<<H`<8
@P0836<8@PaS248<Ha2436<@Q0D<H`88@P8<H`0348@<H`aS00@8@P0348@<
Ha2400@8@P8<H`88@P0336<@Q0Q20088@P8<H`P8@P<<H`@8@P<<H`88@P03
36<8@PaS0088@P8<H`88@P848@88@P0336<@Q0aS00<8@P<<H`D8@P0436<8
@PaS36<3248236<4248010@Q2488@PaS1PQ200<<H`Q224801@Q200D<H`Q2
36<8@PaS0048@P000P@Q00D000@Q00048@0000<48@0500048@aS6<HDY@03
36<00a2436<<H`0436<010Q236<@Q0aS0PQ200@<Ha2448@8@P@<H`@8@PL<
H`0448@DYAS65:D236<010Q236<@Q1240PaS0PQ200<<H`Q236<010Q210aS
0PQ200T<H`Q22488@PaS248<H`Q236<01PQ210aS00@8@PaS36<<H`<8@P<<
H`03248<H`Q2008<H`0748@8@PQ2248<Ha2436<00PQ21@aS00<@Q0aS36<0
0`Q200@<H`Q236<8@P8<H`<8@P0436<@Q0aS36<2248236<248@436<00a24
36<<H`0436<348@236<0112436<<H`aS11241PaS0Q240`aS0a241@aS00<@
Q0aS48@00Q2400<<H`Q236<00Q240PaS0Q2400@8@PaS36<@Q0D<H`0348@<
H`aS00<@Q0<<H`8@Q0D<H`03248<Ha2400<<H`03248<Ha2400H@Q0@<H`03
48@<H`aS00D<H`03248<H`aS008@Q08<H`0348@<Ha2400<<H`0548@<Ha24
36<@Q00436<010Q236<<H`aS0Q240`aS00<8@PaS36<00PaS00<@Q0aS36<0
0PaS00L@Q0aS36<@Q1BU48@DY@0248@236<548@01ABU48@<H`aS48@00QBU
0PaS00<@Q1BU48@00`aS0Q240PaS00<8@Q2436<00a2400<<Ha2436<00PaS
00<@Q0aS36<00PaS0a2410aS00<@Q0aS36<00a2400@<H`Q236<<H`8@Q0`<
H`88@P0336<8@PaS00<<H`<8@P<<H`03248<H`aS0088@P<<H`88@P8<H`<8
@P8<H`<8@PD<H`@8@P<<H`<8@P@<H`@8@P@<H`03248<H`Q2008<H`03248<
H`aS0088@P<<H`04248<H`Q236<3248336<248@2248436<2248336<22483
36<00`Q236<@Q00236<00`Q236<<H`0236<010Q248@<Ha240PaS00<8@PaS
36<01@aS20Q21@aS00<@Q0aS36<01PaS00<8@PaS24800`Q210aS00D8@PaS
2488@PaS00H8@P8<H`D8@P@<H`05248<H`Q2248<H`06248236<010Q236<8
@PQ20P@Q0PQ200<<H`Q224800PQ200<<H`Q224800PQ200@48@Q236<<H`88
@P@<H`03248<H`Q200<8@P0336<8@PQ200<8@P0336<8@PQ200H8@P0336<8
@PaS00D8@P031248@PQ200<<H`48@P448@0000<000@Q12401@@Q00H000@Q
12448@Q25:D248@25:D010aS248<Ha240PaS00@8@PaS36<8@PD<H`04248@
Q0aS36<4248436<030Q236<<H`Q236<@Q1BU6<HDYA2436<@Q0<<H`<8@P03
1248@PaS008@Q003248<H`Q200H<H`04248<H`aS248436<01@Q236<<H`Q2
36<00PQ200@<Ha2448@<H`D8@P<<H`07248<H`aS36<8@PaS24800PaS00<8
@PaS36<00PaS0PQ21@aS0PQ20`aS00D@Q0Q2248<H`Q2008<H`88@PX<H`8@
Q08<H`0348@<H`aS00D<H`8@Q0@<H`0748@<Ha2448@DY@aS24800PaS00D@
Q0aS36<<H`Q2008<H`@@Q0<<H`055:D@Q0aS36<@Q0045:D00a2436<@Q002
36<0112436<@Q0aS0Q2410aS00<@Q0aS36<00Q2400<<Ha2436<00`aS0a24
00D<H`Q2248<Ha24008<H`0348@<H`aS008<H`8@Q0<<H`<@Q006248<H`aS
36<@Q0aS0PQ200D<Ha2448@<H`Q2008<H`8@Q08<H`8@Q0H<H`8@Q0@<H`04
48@<H`aS36<248@236<22480112436<<H`aS0Q240PaS0Q240`aS0Q2400<D
YA2448@00a240`aS00<@Q1BU48@00PaS00D@Q1BU48@@Q0aS00L@Q08<H`03
48@<H`aS008@Q00836<8@PaS36<DYA2436<@Q0<<H`<@Q08<H`04248<Ha24
48@536<348@536<2248248@236<348@236<2248536<00`Q236<<H`032482
48@236<2248336<00`Q236<<H`02248936<00a242488@P02248536<01PQ2
36<8@PQ236<8@PD<H`05248<H`aS36<8@P0436<3248336<00`Q236<8@P03
36<3248010aS48@<H`aS0Q240PaS00<8@PaS36<00PaS00D8@PaS248<H`Q2
00<<H`88@P<<H`03248<H`Q2008@Q00336<@Q0aS008@Q08<H`03248<H`aS
0088@P0336<8@PQ200@<H`03248<H`aS0088@P0436<@Q12448@336<01@Q2
36<@Q12436<00`Q20PaS0`Q21`aS1@Q21`aS0`Q210aS0PQ200@<H`Q236<8
@P<<H`<8@P<<H`0324848@Q200@8@P0436<8@PaS36<3248336<424800`aS
2488@P03248236<4248010aS2488@PaS0PQ200@48@Q236<<H`<8@P8<H`88
@P848@0436<8@PQ236<424800007124000@Q124000@Q00000`@Q00@000@Q
36<DY@8@Q0035:D@Q0aS008<H`0348@<H`Q200<<H`04248<H`aS48@236<0
0a2436<8@P02248010aS24848@Q20PaS0PQ200<<Ha2436<01Q2400<DY@aS
36<010aS10Q20`aS00@8@PaS2488@P<<H`<8@P0436<8@PQ2248336<62482
36<0112436<<H`Q210aS0PQ20`aS00<8@PaS24800PaS0PQ20`aS0PQ220aS
0PQ200@<H`Q236<<H`@8@P0536<@Q0aS36<8@P0336<00`Q236<<H`0236<3
48@00`aS2488@P02248336<248@00`aS48@<H`0536<00a2436<<H`0636<0
1A2436<<Ha245:D00Q2400<<Ha2436<00`aS0Q2400@DYA2436<<H`D@Q0<<
H`0748@<Ha2436<8@PaS248011240`aS0Q2400@<H`Q2248<H`8@Q08<H`03
48@<H`aS008@Q0@<H`03248<H`aS00<<H`0348@8@PaS00<@Q00336<8@PaS
008<H`88@P0336<@Q124008<H`03248<H`aS00<@Q0@<H`0348@<H`aS008<
H`04248<H`aS248448@;36<248@436<348@25:D248@236<01A2436<@Q124
5:D00PaS00P@Q1BU48@8@PaS48@DYA240PaS11240PaS0Q2400@<Ha2448@@
Q08<H`8@Q08<H`03248@Q12400<@Q005248<H`aS36<@Q00736<00a245:D@
Q00248@536<00a2436<<H`0236<00a2436<<H`0336<010Q236<<H`aS0`Q2
0PaS0PQ21@aS0PQ200<<H`Q236<010aS0`Q20`aS00L@Q0Q236<8@PaS248<
H`03248336<01@Q236<8@PQ236<00PQ200L<H`Q236<8@PaS248@Q00236<0
10Q21248@PaS0PQ200H<H`Q236<<H`Q236<2248=36<2248336<0112436<8
@PQ20`aS00<8@PaS36<00PaS00<8@PaS36<00`aS0Q240PaS00<8@PaS36<0
1PaS0PQ200<<H`Q224800`aS0PQ200<<Ha2436<01`aS00@@Q0aS2488@P8<
H`0648@<H`Q2248<H`Q20PaS00<8@PaS36<010Q200<<H`Q236<01@Q200<<
H`Q236<01PQ210aS0PQ20`aS0PQ200<48@Q224801@Q200<48@Q224800PaS
00<8@P@Q24800PaS0`Q200L<H`Q22488@PaS248<H`04248236<224800`@Q
2488@P0424800`aS2488@P0;248236<2248000848@0300048@@Q00H48@03
000<HaS600@@Q08<H`8@Q088@P8<H`8@Q0<8@P0436<@Q0aS248436<42480
0`aS48@@Q00236<01QBU48@@Q0aS248<H`8@Q00336<8@PQ2008@Q00336<8
@PQ200<<H`88@P<<H`06248<H`aS48@<H`Q210aS00T@Q0aS36<8@PaS48@<
H`Q212401@aS00<8@PaS36<00PaS00<8@PaS36<00PaS00D8@PaS248<H`Q2
008<H`04248<H`aS248236<00`Q236<<H`04248336<4248736<00`Q236<<
H`0236<010Q236<@Q1240PaS0a241@aS0a240`aS00<@Q0aS48@00Q241@aS
00D@Q0aS2488@PaS008@Q00636<@Q0aS36<8@PaS0a2400D<Ha2448@@Q0aS
00H@Q0D<H`03248<H`aS008@Q00536<@Q12436<@Q00236<248@01PaS2488
@Q245:D@Q0@<H`88@P<<H`8@Q0@<H`8@Q00536<@Q0aS48@<H`02248010aS
48@<H`aS0PQ20`aS0a240`aS00DDYA2448@<H`Q2008@Q0`<H`8@Q0<<H`8@
Q0D<H`0448@<H`aS248336<248@01@aS48@@Q12436<0112400<<Ha2436<0
0`aS00D@Q0aS48@<H`Q200@@Q00336<@Q0aS00<<H`D@Q0<<H`0348@<H`aS
00D<H`055:D@Q0aS36<8@P0236<00a2436<<H`0236<348@636<00a2436<<
H`0636<00a2436<8@P0636<010Q236<<H`aS10Q20`aS00<8@PaS24800Q24
0`Q210aS00H8@PaS36<<H`Q236<5248336<2248736<020Q236<<H`Q236<8
@PaS248436<2248236<010Q236<<H`aS0`Q200<<H`Q224800`Q200H<Ha24
36<8@PaS48@236<2248936<3248536<01@Q236<<H`Q248@00QBU0PaS00<8
@PaS36<00`aS00@8@P@Q248<H`@@Q00636<@Q0aS36<8@PaS0Q2400@<H`Q2
36<@Q08<H`03248<H`aS00<<H`03248<H`Q20088@P<<H`88@PD<H`04248<
H`Q236<2248236<3248236<010Q236<<H`aS30Q200<<H`Q212400PQ200<<
H`Q2248020Q200<<H`Q2248010Q20P@Q0PQ20PaS0`Q200<<H`Q224800PQ2
00D<H`Q22488@PaS0088@P041248@PQ236<5248636<12480000500048@@Q
124000041240100012448@aS0QBU00D<Ha2436<<Ha2400T<H`06248<Ha24
36<@Q0aS0`Q20PaS0PQ210aS00@@Q1BU48@@Q0@<H`04248<H`aS36<248@3
248336<00`Q236<@Q00236<2248236<0112436<8@PQ20PaS00<@Q0aS36<0
0PQ20PaS00<@Q0aS36<00PQ20PaS10Q210aS00H8@PaS36<<H`Q236<22480
10@Q248<H`aS1@Q210aS0PQ21@aS00@8@P@Q2488@P8@Q0@<H`0348@<H`aS
0088@P8<H`0348@<H`aS00@<H`03248<H`aS00P<H`<@Q00336<@Q0aS00<<
H`03248<H`aS00H<H`0548@<H`aS36<@Q00236<0112436<<H`aS0Q2400<D
YA245:D00Q241@aS0Q2400@<Ha2448@@Q08<H`@@Q00536<@Q0Q2248<H`03
48@736<00a2436<@Q00236<01Q2436<<H`aS248@Q0<<H`0348@<H`aS0088
@P@<H`88@P0348@<Ha24008@Q0<<H`045:D@Q12436<248@00`aS248<H`02
48@00`aS248<H`0536<00a2436<<H`0336<00a2436<<H`0236<00`Q236<<
H`0436<448@00aBU48@@Q00348@00aBU48@@Q00236<0112436<<Ha240PaS
00<@Q0aS48@00Q240`aS00P8@PaS36<@Q1BU48@<Ha240PaS00<@Q0aS36<0
10aS0Q2400<<Ha2436<00PaS00L8@PaS36<<H`Q236<8@P0348@436<011BU
48@<H`Q21PaS00<@Q0aS36<00PaS00<@Q0aS36<00PQ200<<Ha2436<010Q2
20aS00<8@PaS36<01PaS00<8@PaS36<00Q2410Q200H<H`Q22488@PaS2482
36<01PQ236<@Q0aS248<H`H8@P8<H`0348@<H`Q200@8@P0336<8@PaS008<
H`03248<H`aS008<H`88@PH<H`0348@<Ha24008<H`88@P@<H`@8@PH<H`<8
@P8<H`0648@DYA245:D<H`Q21@aS00<8@PaS48@00a240PaS00D@Q0aS36<<
H`Q2008@Q08<H`03248<Ha2400<@Q00336<8@PaS00X<H`@8@P8<H`04248<
H`aS36<6248336<00`Q236<<H`03248236<324800`aS248<H`0224800`aS
248<H`0224800`@Q2488@P02248336<9248020aS2488@P@Q248<H`Q236<:
248010aS1248@PQ20PaS0PQ200<48@Q224802@Q20@@Q00000`@Q00048@03
1240200012448@@Q00048@aS5:D236<248@536<00a2436<<H`0236<00`Q2
36<<H`0236<00`Q236<8@P0348@336<248@236<00a2436<<H`03248336<3
248236<01A2436<8@PaS48@00PaS0PQ210aS00<8@PaS36<00`aS0PQ210aS
00<8@PaS248010Q210aS0PQ21`aS00<8@PaS24800`Q21@aS0`Q20PaS0PQ2
0`aS00<8@PaS36<00PaS00<8@PaS24800PaS00<8@PaS36<00PaS0PQ20PaS
0PQ200@<Ha2448@@Q0<<H`035:D<H`aS00<<H`04248<H`aS48@736<01124
36<<H`Q20PaS00<@Q0aS36<01PaS0Q2400<<Ha2448@010aS0Q240QBU00<@
Q0aS36<00a2400<<Ha2436<00PaS0Q2410aS0a241PaS00@@Q0aS36<@Q0@<
H`0348@<H`aS00<@Q0@<H`0448@<H`aS48@336<01A2436<<H`aS24800PaS
00<@Q0aS36<00PaS00<@Q0aS36<00Q2400<<Ha2448@00Q241`aS00<@Q0aS
36<00`aS0a240`aS00@@Q0Q236<8@P<<H`03248<H`aS008@Q0D<H`P@Q0D<
H`0348@<Ha24008<H`@@Q0H<H`0348@<Ha2400H<H`<@Q0<<H`<@Q0@<H`8@
Q00336<@Q0aS00@<H`0348@<Ha24008@Q00336<8@PQ200X<H`0348@8@PQ2
008<H`0648@<H`Q2248<H`Q21PaS00<@Q0aS36<00`aS0`Q20PaS00<8@PaS
48@010aS0`Q20`aS1@Q20PaS0PQ20PaS00<8@PaS24800PQ21@aS00<8@PaS
24800PaS0PQ210aS00<8@P@Q24800PQ20`aS0PQ200@<Ha242488@PX<H`04
248<H`Q2248536<00`Q236<<H`0224800`aS48@@Q00248@00`aS248<H`04
36<2248536<348@236<01A2436<@Q0aS24800PaS00<@Q0aS36<00a2400X<
H`Q236<<Ha2436<8@P@Q248<H`88@P0336<8@PQ20088@P8<H`88@P8<H`<8
@P0636<8@PaS248<H`Q20PaS2PQ200<48@Q2248010Q200L48@Q2248<Ha24
248<H`04248010aS2488@PQ20PaS10Q200@<H`Q224848@88@P8<H`P8@P04
36<8@PQ236<524800`aS2488@P0236<3248136<1248000<48@0300048@00
00848@0900048@@Q124<HaS65:D<Ha2400`<H`03248<H`Q2008@Q08<H`03
248<Ha2400@<H`<@Q0@<H`@8@P8<H`88@P0336<@Q12400<8@P<<H`03248<
H`Q200@<H`0348@<H`aS00P<H`88@P<<H`88@P0436<@Q0aS36<2248236<2
248236<00`Q236<<H`0424800`aS248<H`02248010aS248<H`aS0`Q20`aS
0PQ200@<H`Q236<<H`<8@P8@Q08<H`88@P<<H`04248<H`aS48@536<00a24
36<<H`0536<010Q236<@Q0Q20PaS00<@Q0aS36<02PaS00D8@Q2448@<H`Q2
00@<H`<@Q0@<H`H@Q0<<H`0348@<Ha2400@<H`<@Q00436<@Q12448@536<0
0`Q236<<H`0348@636<010Q236<@Q1240`aS00@8@PaS36<DY@<@Q0H<H`06
48@<H`aS248<HaBU0Q2410aS00@@Q1BU48@@Q08<H`0848@<H`aS248<H`Q2
36<@Q08<H`04248<H`aS48@436<348@236<02PQ236<<Ha2436<@Q0aS48@<
Ha240PaS1Q2400<<Ha2436<010aS00L@Q0aS48@<Ha2436<@Q00236<248@4
36<00a2436<<H`0;36<00a2436<<H`0236<00a2436<<H`0336<00a2436<<
H`0>36<010Q236<@Q12410aS00<8@PaS24800PaS00@8@Q2436<<H`D8@P8<
H`0748@<H`aS248<H`Q236<00`Q21PaS0PQ200H<H`Q2248<H`Q236<32482
36<4248236<01@@Q248<Ha2436<00PQ20PaS00@@Q0aS36<8@P<<H`03248<
H`aS00@8@P0336<8@PaS0088@P0748@8@P@Q1248@Q245:D01`aS10Q200<<
H`Q236<00`aS00/8@PaS248<H`Q236<8@PaS48@DYA2400<<H`88@P0336<8
@PaS00<<H`0448@<Ha2448@636<010Q236<<Ha240`aS00<@Q0aS36<00PQ2
00@<Ha2436<8@P<<H`<8@P0348@8@PaS0088@P0636<@Q0Q224848@Q20PaS
0PQ210aS0`Q200<48@Q224800PaS0`Q200<<H`Q224801`Q20PaS0`Q200<<
H`Q224800PQ200<<H`Q2248010Q20P@Q00<8@PaS24800PQ200@<H`Q2248<
H`88@P031248@PQ200<8@P0536<8@PQ224848@0724801@aS248<H`Q236<0
0`Q200000`0012448@0612401`0012448@Q26<HDYA24008<H`8DY@0348@<
H`Q200<<H`0348@<H`aS008<H`0348@<H`aS008<H`<DY@0548@<H`Q236<@
Q00336<010Q236<8@PaS0PQ20`aS0`Q20`aS00<8@PaS36<00PQ20`aS0PQ2
0PaS0PQ21@aS00<8@PaS248010aS00<8@P@Q24800PaS0`Q200H<H`Q2248<
Ha2436<2248336<324800`@Q248<H`0236<3248336<3248336<010Q236<<
H`aS0PQ20PaS10Q20PaS00@@Q0aS2488@P8<H`03248<H`Q2008<H`0548@<
H`aS36<@Q00636<010Q236<<H`aS0a241PaS00@@Q0aS36<<H`@@Q0@<H`<@
Q0<<H`<@Q00336<@Q0aS008<H`05248<Ha2436<@Q00536<348@236<00a24
5:D@Q00736<248@00`aS48@@Q00236<00`Q236<@Q00236<2248248@536<2
24800`aS48@<H`0248@01@aS2488@PaS48@00PaS0Q240PaS0Q2400<HaQ24
36<010aS0Q2400D<H`Q236<<Ha2400H<H`0448@<H`aS48@<36<2248236<4
48@236<01ABU48@<H`aS24800a2400@8@PaS248<H`8@Q0<<H`0648@<H`aS
248<Ha243@aS00<8@PaS36<00Q241PaS0PQ21PaS0Q2400D<Ha24248<H`Q2
00P<H`03248<H`aS0088@PP<H`03248<H`Q200<<H`8@Q00436<8@PQ22484
36<3248436<2248336<224800`@Q2488@P0224800`aS2488@P0324800`aS
2488@P02248436<5248236<348@236<2248010aS248<H`aS1PQ20`aS0a24
0PQ20`aS00<8@P@Q24800PaS0`Q200@<H`Q22488@P8<H`04248<H`aS48@2
36<01@Q21248@PQ236<00`Q20`aS00<@Q0aS36<00a2400<<H`Q224800PaS
00<8@PaS48@00Q240PaS1@Q20PaS00T8@PaS248<H`Q236<8@PaS24800PaS
0`Q200<48@aS24800PQ200@48@Q236<<H`88@P0336<8@PQ20088@P8<H`H8
@P0336<8@PQ200@8@P<<H`H8@P8<H`88@P0736<8@PaS24848@Q236<02`Q2
00<<H`Q224801PQ200<<H`Q224800PQ200<<H`Q224800PQ200H<H`Q22488
@P@Q248112400004124000@Q000212400`0012448@0312401A245:D<H`Q2
48@00QBU00<@Q0aS36<01@aS00<@Q0aS36<00PaS0a240PaS00<@Q1BU48@0
0`aS1@Q20`aS0`Q20`aS00<8@PaS36<00PaS0PQ200<<H`Q236<01@aS00<8
@PaS248010aS0PQ20PaS00<@Q0Q224800PQ20PaS10Q20`aS10Q200@<H`Q2
248<H`L8@P8<H`<8@P<<H`03248<H`aS008<H`0324848@aS008@Q0@8@P04
36<@Q0aS248336<2248436<01PQ236<<Ha2436<8@P8<H`<@Q0@<H`04248<
H`aS48@236<248@336<01Q2436<<H`Q236<@Q08<H`05248@Q1BU5:D@Q003
36<248@436<348@236<348@00`aS2488@P0236<648@00`aS2488@P035:D0
10aS248<Ha240PaS1A2410aS00L@Q0aS36<<H`Q236<@Q00236<224800`aS
248<H`0236<2248236<348@236<448@236<01Q245:DDYA2436<@Q08<H`<@
Q0L<H`04248@Q1245:D336<548@00`aS48@<H`0936<01Q2436<<Ha2436<D
Y@<@Q08<H`03248<H`aS0088@P8@Q0055:D<Ha2436<@Q00536<00a2436<<
H`0436<00`Q236<<H`0236<00`Q236<<H`0236<00a2436<<H`0236<248@0
10aS48@<Ha240`aS00D8@PaS36<<Ha2400@<H`03248<H`aS00<<H`88@P8<
H`03248<H`aS00@<H`03248<H`aS00@<H`05248<H`Q236<@Q00236<00`@Q
36<<H`04248336<00`Q236<<H`03248236<3248436<3248336<224800`aS
48@<H`03248236<010Q236<8@PQ20PaS0Q240`aS10Q210aS0`Q200<<H`Q2
24802PaS0`Q21PaS0PQ200D@Q0aS2488@PaS008@Q08<H`0348@8@PQ200@8
@P0436<8@Q2436<348@010aS48@<Ha240PQ200H<Ha2448@@Q0aS48@236<2
24801PaS248<H`Q236<@Q08<H`<8@P0336<8@PaS008<H`88@P8<H`05248<
H`aS248<H`02248336<00`Q236<<H`0236<5248236<624801PaS248<H`Q2
36<8@P8<H`D8@P0336<8@PQ200<<H`88@P848@h8@P0336<8@PQ200<8@P06
36<8@PQ236<8@PaS0`Q200D<H`Q236<8@P@Q0088@P0010@Q00D000@Q1244
8@0000<48@0336<HaPaS0088@P0548@DYAS66<H@Q00236<01`Q236<@Q124
36<@Q0aS00@@Q00336<@Q124008@Q00336<8@PaS00<8@P8<H`<8@P0448@<
H`Q2248336<010Q236<8@Q240PaS00<8@PaS36<00`Q20`aS00<8@PaS36<0
1`aS00<8@PaS24800PQ20PaS00<8@PaS24800`aS10Q20`aS0`Q210aS0`Q2
0PaS0PQ210aS0PQ210aS00<8@PaS48@00Q2440aS00<8@PaS36<00PaS0Q24
0`aS00D@Q0aS36<<Ha2400<<H`T@Q0@<H`0748@<H`aS36<@Q1BU48@00`aS
0Q2400<DYA2448@00PaS00<@Q0aS36<00PaS00@@Q0aS36<8@P/<H`0848@<
H`aS48@<Ha2436<8@PX<H`0548@<H`aS36<8@P0236<01@Q236<<Ha242480
0PaS0Q2410aS00D@Q0aS36<8@PaS00<@Q0@<H`P@Q0X<H`<@Q0h<H`D@Q003
36<@Q12400<<H`8@Q00436<8@PaS36<248@236<248@01@aS48@@Q1BU48@0
2@aS00<@Q0aS36<02@aS0Q2400D<H`Q236<@Q0aS0088@P8@Q0<<H`8@Q0D<
H`0348@<Ha2400<<H`03248<H`aS00D<H`03248<H`Q200<<H`03248<H`Q2
00@<H`03248<H`aS008<H`0348@<H`aS008<H`03248<H`aS008<H`88@P03
124<H`aS008<H`03248<H`aS0088@P8<H`88@P8<H`0924848@Q236<@Q0aS
24848@Q200<<H`<8@P<<H`07248<H`aS36<48@Q236<00Q241@Q200<<Ha24
36<00`Q200@<H`Q22488@PD<H`0448@<H`aS48@236<224801PaS2488@PaS
48@<H`<8@PH<H`<8@P<<H`03248<H`Q200<<H`0648@<Ha2448@<H`Q21@aS
00<@Q1BU5:D00PaS0PQ200T<H`Q2248<H`Q236<8@PaS48@00PaS00@8@PaS
36<<H`88@P8<H`0424848@Q236<524800`aS248<H`0236<01@@Q24848@@Q
24800PaS00<8@PaS36<00PaS3@Q20PaS1@Q200@<H`Q236<<H`@8@P0336<8
@PQ200H8@P0536<48@Q2248<H`0224800`aS48@8@P0212400`Q236<8@P02
248236<4248236<2248000848@0300048@@Q00@48@0<00048@@Q48@HaQ24
1248@Q245:DHaQBU0PaS00<@Q0aS24800PaS00<@Q0aS48@00a2400@<Ha24
5:D@Q08<H`<8@P0436<8@PaS36<424801@aS2488@PQ236<010Q200@<H`Q2
36<8@P<<H`<8@P@<H`88@P8<H`<8@P0748@<H`aS248<H`Q236<00PQ200H<
H`Q236<8@PaS248236<3248336<3248010aS2488@PQ20PaS0PQ20PaS0`Q2
1@aS0`Q20`aS00<@Q0aS36<00`aS0`Q200@<Ha2436<8@PP<H`<@Q0P<H`04
48@<Ha2436<348@236<248@236<2248536<448@00`aS48@<H`0236<00a24
36<<H`0448@736<00a2436<@Q00736<248@536<00a2436<<H`0336<00a24
36<<H`0536<00`Q236<<H`0236<01@Q236<<H`aS24800`aS00P8@PaS48@@
Q0aS48@<Ha241`aS00@@Q0aS36<@Q08DY@0548@<H`aS36<8@P0236<00a24
36<<H`0236<0112436<<Ha241`aS00<@Q0aS36<00PaS00@8@PaS36<<H`8@
Q0@<H`0348@<H`aS008<H`8@Q0<<H`<@Q0@<H`8@Q0/<H`03248<Ha24008@
Q004248<H`aS48@336<00a2436<<H`0536<010Q236<@Q1240`aS00<@Q0aS
36<010aS0Q2400@<H`Q22488@PD<H`03248<H`Q20088@P0448@<H`aS2484
36<010Q236<8@PQ220aS0PQ200@<H`Q236<8@P8<H`<8@P0336<8@PQ200<8
@P8<H`@8@P8<H`88@P0336<8@P@Q0088@P0336<8@PQ20088@P0436<8@PaS
36<3248636<00`Q236<<H`0236<00`Q236<<H`0236<724801`aS48@<H`Q2
36<@Q1BU008<H`03248<H`Q200D<H`0424848@Q2248336<2248336<00`Q2
1248@P0536<00`Q236<<H`0336<01@Q236<<H`aS48@00PaS0Q240PaS00@8
@PaS36<<H`88@P<<H`88@P<<H`04248<H`aS36<2248236<524801@@Q2488
@PQ236<00`Q200@48@Q236<<H`88@P0336<8@PQ20088@P0336<8@PQ200/8
@P<<H`D8@P03124<H`aS00L8@P0336<8@PQ200<8@P8<H`@8@P0336<8@PQ2
00848@T8@P031248@PQ200<8@P0000H000@Q124000@Q000612400`aS6<H@
Q00436<01a246<HLiaBU48@<Ha2400<DY@0348@<H`aS00<@Q00436<8@PaS
48@236<00`Q21248@P0236<3248236<00`Q236<<H`02248236<00a2436<<
H`0324800`aS248<H`0236<4248336<00`@Q2488@P0236<010Q236<<H`aS
0`Q20PaS00<8@PaS24800PQ210aS0PQ200<<H`Q236<00PQ20PaS00<@Q0aS
36<00PQ200<<H`Q2248010aS0PQ20PaS00<8@PaS36<010aS00@@Q0aS36<8
@PX<H`0748@<H`Q2248<Ha2436<00Q2410aS0a2400<<H`Q236<00`aS00D@
Q0aS36<@Q1BU008@Q08<H`8@Q08<H`06248<Ha2448@<Ha240`aS0Q240`aS
0Q240PaS00<@Q1BU36<00PaS00@@Q0aS2488@P@<H`0448@<H`Q236<448@4
36<248@01@aS2488@PaS48@00PaS0Q240`aS00H8@Q2448@@Q0aS248536<2
48@00`aS2488@P0348@336<348@020aS48@<H`aS48@<Ha245:D336<00`Q2
48@<H`0348@25:D0112436<<H`Q20PaS00TDYA2436<<Ha2436<@Q0aS48@0
0PaS00@8@PaS36<<H`8@Q08<H`@@Q0<<H`<@Q0D<H`0648@<Ha2436<@Q0aS
0a240`aS00<@Q0aS36<010aS00D8@PaS48@<Ha240088@P0436<@Q1BU48@5
36<248@336<248@336<00a2436<<H`0448@336<00a2436<<H`0636<010Q2
36<<H`aS0`Q20`aS0PQ200<<Ha2436<00PQ20`aS0`Q21PaS0`Q20`aS00<4
8@Q224800`aS0PQ20`aS0`Q20`aS10Q200@<H`Q22488@PH<H`88@P8<H`@8
@P0336<8@PQ200D8@P<<H`03248<H`Q200<8@PT<H`03248<H`Q200<8@P<<
H`03248<H`aS008<H`88@P<<H`88@P<<H`06248<H`aS48@<H`Q20PaS00D8
@PaS36<<Ha24008<H`0348@DYA2400D<H`<8@P8<H`04248<H`aS48@436<0
10Q236<8@PaS0`Q20`aS1@Q20PaS0`Q20PaS0PQ21@aS00@8@P@Q1248@P8<
H`0324848@Q20088@P0436<8@PQ2248336<2248236<424801`aS2488@PQ2
36<8@PaS0088@P@<H`H8@P0336<8@PaS00L8@P04124<H`Q236<324800`aS
2488@P0112400003124000@Q00<48@0400048@@Q000212400`aS6<HDY@02
24803PaS248DYAS67>LDYA2436<@Q1BU6<H@Q0aS248236<348@336<32480
0`aS2488@P02248236<00`Q236<8@P02248336<3248536<010Q236<8@PQ2
0`aS0PQ20`aS00@8@PaS2488@P8<H`0448@8@PQ2248236<2248236<32482
36<4248636<2248236<4248336<00`Q236<<H`0536<2248336<2248836<2
248336<00`Q236<<H`0248@00`aS48@<H`0236<010Q236<@Q0aS0Q240`aS
11240PaS00<@Q1BU36<00`aS00D@Q0aS36<@Q0aS008@Q0D<H`04248<H`aS
48@236<248@010aS248<H`aS0Q241@aS00D8@PaS36<DYA24008<H`@@Q0<<
H`03248<H`aS00@<H`8@Q00336<@Q0aS00<<H`8@Q0D<H`04248<H`aS48@5
36<248@010aS248@Q1240`aS00D@Q0aS2488@PaS00<@Q0035:D<H`aS008<
H`<@Q0065:D@Q1BU48@<H`Q20PaS00<@Q0aS36<00Q2400<<H`Q236<00Q24
0PaS00@8@PaS36<<H`8@Q08<H`0348@<H`aS008<H`<@Q0<<H`<@Q0@<H`03
48@DYA2400<<H`03248<H`aS008@Q00436<8@PaS248336<00a2436<<H`02
36<348@00`aS48@<H`0936<348@01PaS248<H`aS48@DY@8<H`03248@Q0aS
008@Q08<H`04248<H`aS36<224800`@Q36<<H`0248@636<00`Q236<<H`02
36<01@Q2124<H`aS48@020aS0`Q200<48@Q224800`aS00<8@PaS24800`Q2
00<<H`Q224801`Q21PaS0PQ200H@Q0aS2488@PaS48@236<00`Q236<8@P02
36<6248010aS248<H`Q20PaS0`Q200D<Ha2448@<Ha2400H<H`03248<H`aS
0088@P<<H`<8@P8<H`<8@P@<H`88@P0636<@Q12424848@Q20PaS00<8@PaS
36<010aS00L@Q1BU48@@Q0Q236<8@P0236<2248436<00`Q236<<H`0336<:
248336<224801@aS2488@PQ236<00PQ21PaS00<48@Q224800PQ20P@Q0PQ2
0PaS2`Q200<<H`Q236<02`Q20PaS1PQ200<48@Q224800PQ200@48@Q2248<
H`<8@P031248@PQ20088@P041248@PQ2248136<000<48@0300048@@Q00@4
8@0500048@Q25:D@Q00536<01Q245:DLiacW6<HDY@<@Q08<H`8@Q088@P03
36<@Q124008<H`03248<H`Q200<8@P<<H`88@P0436<8@PQ2248=36<32483
36<00`Q236<<H`03248010@Q248<H`aS0`Q20PaS0PQ20`aS00L48@aS36<8
@PaS248<H`02248010aS248@Q0aS0Q2400@<H`Q22488@P8<H`88@P<<H`88
@P8<H`8@Q00436<8@PaS248436<010Q236<<H`aS0`Q21`aS0Q2410aS00<@
Q0aS36<00Q240`Q20Q2400<<Ha2448@00Q2400<8@Q245:D00a240`aS0a24
00<<Ha2436<0112400D<Ha2448@@Q0aS00<@Q005248<Ha245:D@Q00636<3
48@536<448@336<248@236<00a2436<<H`0236<0212436<<H`aS248<Ha24
248236<348@00`Q236<<H`0336<00`Q236<<H`0248@436<248@636<25:D0
0aS648@<H`0236<348@010aS48@<H`aS0a240PaS0Q240`aS00@@Q0aS248<
H`8@Q0H<H`<@Q00436<@Q1BU48@236<01A245:D@Q0aS48@010aS0a2410aS
0Q2400<<Ha2424800`aS00D@Q0aS36<<H`Q200H<H`88@P<@Q0@<H`@@Q0H<
H`0348@<H`aS008@Q0H<H`8@Q0<<H`07248<H`aS36<8@PaS24800PaS00<8
@PaS36<00PaS0PQ200D<H`Q236<<H`Q200D<H`03248<H`aS00@<H`03248<
H`aS00<8@P0336<8@PQ20088@P8<H`04248<H`aS36<2248236<4248336<2
248236<01@Q236<<H`Q236<00PQ210aS00<8@PaS36<00`aS00@8@PaS248<
H`88@P8<H`<8@P0336<8@PQ20088@P0548@<Ha245:D@Q00236<224800`aS
48@<H`03248236<00`Q236<<H`0236<3248A36<00`Q236<<H`0336<010Q2
36<<H`aS0PQ20`aS0`Q20Q240`aS00<8@PaS248010aS0PQ20PaS00L@Q0Q2
2488@PaS48@<H`0324800a2436<<H`0236<424800`@Q248<H`0824800`@Q
2488@P0536<01@Q21248@PQ236<00PQ200@<H`Q236<<H`<8@P<<H`L8@P05
36<8@PQ236<8@P0336<424800`aS2488@P0336<00`Q236<<H`0124800084
8@0300048@0000<48@0500048@@Q124<H`025:D010aS48@<H`Q20PaS00DH
aR487>LHaQBU00@@Q0L<H`0448@<H`aS36<2248236<5248236<424800a24
36<<H`02248436<424800`aS248<H`0236<324800`aS2488@P0236<42480
1@aS248<H`Q236<00`Q200@<H`Q236<<H`<8@P<<H`88@P0436<@Q0Q22483
36<324800`aS248<H`0236<010Q236<<Ha241@aS00<8@PaS48@010aS00T@
Q0aS2488@PaS248<H`Q236<00a240PaS00T8@PaS36<@Q0aS248<Ha245:D0
0PaS00<8@PaS48@00Q240PaS00HDYA2436<@Q0aS248236<248@236<748@3
36<448@336<348@236<01Q2436<<H`Q236<8@PD<H`@@Q0@<H`06248<H`aS
48@<H`Q210aS0Q2410aS00D@Q0aS36<<Ha2400@<H`06248<H`aS36<@Q0aS
0a240PaS0Q240`aS00L@Q0aS36<@Q0aS5:DHaP0248@236<00a2436<@Q003
48@236<0112436<<H`aS0Q240PaS0Q240`aS0a240PaS1a2400HDYA2436<<
Ha2436<248@436<248@336<248@01PaS48@<Ha2436<8@P8<H`<@Q00336<@
Q0aS008<H`05248<H`Q236<8@P0336<011245:D@Q0aS0Q240`aS0Q240`aS
00D@Q0aS36<8@PaS00<@Q00436<8@PQ248@436<01a2436<<H`aS248<H`Q2
008<H`04248<H`aS248436<010Q236<<H`Q22@aS00H8@PaS36<<H`Q236<2
48@010aS2488@P@Q0`aS0`Q20`aS10Q20`aS00@8@PaS2488@P<<H`<8@PL<
H`88@P8<H`@8@P8<H`88@P0436<8@PQ2248236<2248236<3248236<25:D0
1a2436<<H`Q236<8@P@Q0088@P8<H`88@P8<H`0448@8@PQ2248236<00`Q2
36<<H`0236<2248236<00a2436<<H`0336<01A2436<<H`Q236<00Q240PaS
0PQ20PaS0PQ200H<H`Q2248<H`Q236<248@00`aS2488@P0236<4248236<3
248336<224800`aS48@8@P03248236<00`Q236<8@P0324800`aS2488@P03
24801@@Q248<H`Q212400PQ20PaS10Q200@<H`Q224848@88@P031248@PQ2
0088@P0336<8@PQ20088@P0336<8@PQ200/8@P051248@P@Q24848@0336<7
2480000300048@@Q00<48@0400048@@Q0002124010aS6<H@Q0Q20`aS00P@
Q0aS36<DYAS67>LDYA241@aS00<8@PaS36<00PaS00<8@PaS24800PaS0PQ2
1PaS00<@Q0aS24800PQ200<<H`Q236<00`aS00<8@PaS36<00PaS10Q210aS
0`Q20PaS0PQ200<48@Q2248010Q200D<Ha2436<<H`Q200<<H`<8@P8<H`@8
@P0636<@Q0aS48@<H`Q210aS0PQ200<<Ha2436<02PaS00<8@PaS36<01PaS
00<@Q0aS36<00PaS0a240PaS00H8@PaS36<@Q1BU48@636<0112436<@Q124
10aS00X@Q1BU48@8@PaS248@Q1BU48@<H`<@Q0035:D@Q124008@Q00336<@
Q124008<H`<@Q0<<H`<@Q0<<H`0348@<Ha24008<H`8@Q0@<H`<@Q0<<H`03
248<H`aS00<@Q0@<H`<@Q0@<H`H@Q0L<H`0648@DYA2448@<H`Q210aS00H@
Q0aS36<8@PaS48@35:D0112436<<H`aS1A240aBU0PaS00@@Q0aS36<<H`8@
Q0D<H`0648@DY@aS36<@Q0aS1A2400@<Ha2448@@Q08<H`8@Q0<<H`D@Q0@<
H`0348@<H`aS008<H`<@Q14<H`03248<H`aS00T<H`0448@DYA2448@736<0
0a2436<<H`0348@236<00a245:D<H`0336<00a2436<8@P0236<00`Q236<<
H`0236<2248236<00a2436<<H`04248336<2248636<4248236<2248336<0
0`Q236<8@P06248336<01@Q236<<H`aS24800`aS0PQ20`aS0PQ20PaS00D8
@PaS36<<H`Q2008<H`03248<H`Q200<8@P@<H`88@PD<H`0648@DYABU48@<
H`Q20`aS0`Q20`aS00<8@PaS36<00`Q20PaS00D8@PaS248<Ha2400L<H`88
@P0336<8@PaS00D<H`<8@P0636<@Q0Q21248@PaS0Q2410Q200<<H`Q236<0
1@aS0`Q210aS00<8@PaS36<010Q20a240`aS1PQ20PaS1@Q200<<H`Q22480
0PaS0`Q20PaS10Q200<48@Q224800PaS00<8@PaS24800`Q200@48@Q2248<
H`<8@P0436<8@PQ2248336<010Q236<48@Q20PaS1@Q210aS0@@Q00000`@Q
00048@0212400`0012448@0412401Q246<H@Q0Q236<@Q0<<H`8@Q08HaP03
5:D@Q12400L<H`0348@<Ha24008<H`88@P8<H`88@P@<H`04248<H`Q236<2
248336<00`Q236<<H`0248@236<2248436<01PQ236<<H`Q236<8@P8<H`@8
@P0336<8@PQ200<<H`@8@P<<H`<8@P0536<@Q12436<8@P0236<021BU48@8
@PQ236<8@PaS248736<01@Q236<@Q0aS24801PaS0Q2400<<H`Q236<00`aS
00<8@PaS48@00`aS0a2400<<Ha2436<02PaS00<@Q1BU48@00PaS0a2400<<
Ha2436<00a2400@<Ha2448@@Q0<<H`8@Q00436<@Q12448@436<00a2436<<
H`0836<00a2436<8@P0236<00aBU48@<H`0336<00a2436<@Q00336<00`Q2
36<<H`0248@00`aS248<H`0248@<36<01A2436<<H`aS48@00PaS112400<<
Ha2448@00PaS0Q2410aS0QBU00@HaQBU48@@Q08<H`0348@<Ha2400<@Q08<
H`D@Q00336<@Q1240088@P0336<@Q124008<H`8@Q0D<H`045:D@Q12436<3
48@336<00a245:D<H`0236<348@236<011245:D@Q0Q20PaS00@@Q0aS2488
@P<@Q0045:D<H`aS248236<01@Q236<<H`Q236<00a2420aS00<@Q0aS36<0
0PaS0Q2400<<Ha2448@010aS00<@Q0aS24800PaS0Q2400<<Ha2436<04`aS
00<8@PaS36<00PaS00<8@PaS248010Q20PaS00<@Q0aS24800`Q20PaS10Q2
00<<H`Q224800`Q200H<H`Q22488@PaS48@236<3248236<2248436<010Q2
36<<H`Q20`aS00@@Q0Q22488@P@<H`04248<H`Q2248336<2248436<00`Q2
36<@Q0025:D00a2436<<H`0336<5248010aS248<H`aS0`Q210aS00@8@PaS
36<8@P8<H`8@Q00336<8@PaS00<<H`03248<H`aS00L<H`<8@PD<H`0348@8
@PQ200<<H`04248<H`aS48@3248236<010Q236<<H`Q21PaS00H@Q0aS36<<
H`Q236<248@010aS1248@PaS1`Q200D48@Q236<8@PaS0088@P041248@PQ2
36<9248236<010Q21248@PQ20PaS0PQ200@<H`Q224848@L8@P031248@PQ2
00@8@P<<H`D8@P000`@Q00<000@Q12400P@Q00P000@Q00048@aS6<H@Q0aS
11240PaS11241@aS00<8@PaS36<00`aS0Q2400@<H`Q22488@P@<H`05248<
H`Q236<8@P0336<2248436<00`Q236<8@P02248336<00`Q236<<H`0436<3
24800`aS2488@P0236<00`Q236<8@P03248336<2248336<2248536<00`Q2
36<<H`0336<2248236<00`Q236<<H`0336<348@436<348@736<248@:36<0
1A2436<<H`aS48@00PaS00D@Q0aS36<<H`Q200<<H`0348@DYA2400<<H`03
5:D<H`aS00<@Q0<<H`0348@DYA2400@@Q08<H`0748@<Ha2436<@Q0aS48@0
0PaS00<@Q0aS48@00`aS11241PaS0Q2400<<Ha2436<010aS00H@Q0aS36<@
Q0aS248236<248@2248336<00a2436<<H`0536<348@236<00a245:D@Q007
36<00a2436<<H`0236<011245:DDYABU0Q2400<<Ha245:D00QBU00<@Q0aS
48@00a2400@<Ha2448@<H`8@Q08<H`03248<Ha2400<<H`8@Q0<<H`8@Q0L<
H`8@Q0055:D@Q12448@<H`0448@236<348@236<00a2436<<H`0836<32482
36<248@236<00a2436<<H`0436<00a2436<@Q00236<00a2436<@Q00436<0
1A2436<<H`aS48@010aS00<@Q0aS36<011240`aS0Q2400<DY@aS36<010Q2
0PaS00<8@PaS36<01@aS0`Q20`aS00<8@PaS36<00`aS00@8@PaS248<H`88
@P@<H`05248<H`aS36<8@P0236<4248236<2248536<3248336<224801PaS
2488@PaS248@Q08<H`03248<H`aS008<H`03248<H`aS00<<H`03248<H`aS
00<8@P0336<@Q124008@Q00736<@Q1BU48@<H`Q236<00PQ200@<H`Q236<@
Q0<<H`03248<H`Q2008<H`<8@PD<H`04248<H`aS48@236<2248448@22484
36<010Q236<<H`aS0PQ20PaS00<@Q0aS36<00`Q200<<H`Q224800`aS0`Q2
10aS0`Q20`aS00H@Q0aS248<H`Q236<224800`aS2488@P06248236<00`Q2
36<<H`0424800`aS2488@P0624800`aS248<H`02248236<224800`@Q248<
H`06248010@Q2488@PaS10Q20PaS10Q20PaS10Q20@aS000212401@001244
8@@Q000010@Q00@000aS5:DDY@8<H`8@Q0@<H`0548@<H`aS36<@Q00236<0
0`Q236<<H`0236<248@010aS248<H`aS0`Q22PaS10Q200@<H`Q2248<H`<8
@P0336<8@PaS008<H`03248<H`aS008<H`88@P8<H`03248<H`aS00<8@P03
36<8@PQ20088@P@<H`03248<H`Q20088@P0336<8@PaS00H<H`03248<H`aS
008<H`88@P0336<@Q0aS00D<H`03248<H`aS00@<H`8@Q00536<@Q12448@8
@P0236<00a2436<<H`02248536<0112436<<H`Q22PaS1Q2410aS00@@Q0aS
248@Q08DY@0648@<Ha2448@DYA240PaS0Q2410aS00<@Q1BU36<00`aS00<@
Q0aS36<00`aS0Q2400@<Ha2436<@Q0@<H`8@Q08<H`03248<H`aS00@<H`<@
Q00336<@Q124008@Q00336<8@PaS00D<H`0548@<H`aS36<@Q00236<01124
5:DDYA240PaS00H8@PaS48@<Ha2436<248@236<348@35:D248@00`aS48@<
H`0448@00aBU48@@Q00336<00a2436<<H`0536<00a2436<@Q00248@336<0
0a2436<@Q00236<548@011BU48@@Q0aS1Q240`aS00@@Q0aS36<<H`8@Q005
36<8@PaS5:D<H`02248336<224800a2436<<H`0348@00`aS48@@Q0022480
10aS48@@Q0Q20PaS00H@Q0aS36<<Ha2436<348@236<348@836<248@336<2
48@836<00`Q236<<H`0536<6248736<4248836<224800`aS2488@P022482
36<2248336<00`Q236<8@P03248436<00`Q236<<H`0236<01PQ236<<H`aS
248<H`<8@P8<H`@8@P0336<@Q0aS0088@PD<H`0448@<Ha245:D348@336<2
248436<010Q236<8@PQ210aS00D8@PaS36<8@PaS00<@Q088@PL<H`0348@<
H`aS0088@P<<H`05248<H`aS36<8@P0236<0212436<<H`Q236<8@PaS2482
36<3248336<010Q236<<H`Q20PaS0PQ21`aS00<48@Q224800PaS0PQ200<<
H`Q224800PQ200<<H`Q224802@Q200<<H`Q212400PQ200@<H`Q22488@P<<
H`88@P041248@PQ236<7248236<010Q21248@P@Q1PQ200D<H`Q22488@PaS
0088@P448@0000D000@Q12448@0000<48@0900048@@Q124<HaS648@<Ha24
00<<H`8@Q0@<H`<@Q004248<H`aS48@336<00a2436<<H`0536<00`Q236<<
H`02248236<00a2436<<H`02248436<2248336<3248010aS48@<H`Q20PaS
00<8@PaS36<00`aS10Q200<<H`Q236<01PaS0`Q200@<H`Q22488@P8<H`<8
@P8<H`<8@P0336<@Q0Q20088@P@<H`05248@Q1245:D@Q00936<010Q248@@
Q1241@aS00@8@PaS36<<H`@@Q0<<H`8@Q08<H`04248<Ha2448@436<00a24
5:D@Q00448@00`aS248<H`0336<448@336<248@436<248@236<010Q236<@
Q0aS0a240PaS00@8@PaS48@<H`8@Q0@<H`0448@<H`aS248236<00a2436<<
H`0236<00a2436<<H`0236<010Q236<<Ha242@aS0a240PaS00P@Q0aS36<@
Q1BU48@<H`Q21@aS0a240PaS0Q240QBU112400<DYA2448@00a240PaS00<@
Q0aS48@00`aS00<@Q0aS24800PaS00D@Q0aS36<@Q0aS00T@Q08<H`0348@<
Ha2400@@Q08<H`<@Q0035:D<H`aS008<H`0348@<H`aS00D<H`0348@<H`aS
008@Q00436<8@PaS36<248@010aS248<H`Q20`aS00@@Q0aS36<<H`8@Q0D<
H`0348@<H`aS008<H`8@Q0H<H`0348@<H`Q20088@P0348@<Ha24008<H`8D
Y@8@Q088@PP<H`05248<H`aS36<8@P0336<4248536<00`Q236<<H`0336<0
0`Q236<<H`0236<3248336<2248436<224801@@Q248<H`aS48@00`Q20`aS
0`Q20`aS0PQ20PaS00<@Q0aS248010aS0PQ20`aS00@8@PaS36<<H`<8@P8<
H`88@P8<H`0348@<H`aS008<H`0448@<H`aS248536<324800`aS2488@P04
36<224800`aS248<H`02248336<00a2436<@Q00536<010Q236<<H`aS10Q2
00<DYA2436<00PQ200<<Ha2436<00PaS0PQ200<<H`Q236<01@aS0PQ200<<
HaBU48@00PQ20`aS0`Q20PaS00<@Q0aS24800`Q200<<H`Q236<00PaS0PQ2
00@48@Q2248<H`@8@P0336<8@PQ200D8@P0336<8@PaS00X8@P031248@PaS
008<H`<8@P<<H`<8@P<<H`03248<H`Q20088@P4<H`48@P48@P0000@48@00
124000D48@0700048@@Q36<DYA2424802PaS00<@Q0aS36<00PaS0Q240PQ2
00@<Ha2448@@Q0H<H`88@PL<H`03248<H`aS008<H`04248<H`aS36<32480
1@aS248<H`Q236<00Q240PaS00<8@PaS36<00PQ20PaS0`Q20PaS0PQ20`aS
1PQ200<<H`Q236<00PaS0PQ210aS0PQ20PaS00D8@PaS36<<H`Q2008<H`8@
Q00336<@Q0aS00<<H`<@Q08<H`8@Q0@<H`0448@<H`aS48@836<00`Q236<<
H`0236<224801A2436<<Ha2436<0112400<<Ha2448@00`aS00<DYA2436<0
0PaS0Q2400<DYA2448@00a240`aS11240PaS00P@Q0aS36<@Q0aS48@<Ha24
10aS0Q242`aS00<8@PaS36<010aS0Q240`aS00<8@PaS36<00PaS00@8@PaS
36<@Q08<H`0348@DYA24008@Q00336<@Q0aS00<@Q0<<H`<@Q00436<8@PQ2
48@25:D00a2436<<H`0348@00`aS48@@Q00448@236<00a2436<@Q00336<0
0a2436<<H`0236<00`Q236<<H`0448@336<748@00`aS48@DY@025:D00a24
36<<H`0848@736<248@436<00a2436<@Q00936<3248348@336<00a2436<<
H`0736<248@01@aS48@8@PaS248010aS0Q2410aS0a241@aS00@@Q0aS36<8
@P8<H`0448@<H`aS248236<010Q236<<H`aS0PQ20`aS0PQ210aS00<8@PaS
36<00`aS00<8@PaS24800`aS0PQ200<<H`Q236<00PaS0PQ210aS10Q20`aS
00<8@PaS248010aS00<8@PaS36<00`aS00<8@PaS36<00`aS00<8@PaS36<0
0`aS00@8@PaS36<<H`88@P8<H`8@Q00336<@Q0aS008@Q003248<H`Q200<<
H`05248<H`aS36<8@P0336<224801`aS48@8@PQ236<8@Q24008<H`<8@P04
48@<Ha2448@336<324800`aS248<H`03248536<010Q236<<H`aS0PQ200<<
H`Q2248010aS10Q200H<H`Q2248<Ha2436<224800`aS48@8@P0436<22480
1@aS248<H`Q236<02@Q200<<H`Q2248010Q200L<H`Q22488@PaS248<H`07
24801@aS248<H`Q236<00PQ200<<H`Q224801@Q20PaS10Q20`aS0PQ20PaS
0@Q2000412400`001240000512400`Q25:D<H`0536<2248936<01@Q236<<
H`aS24800PaS0a2400@8@PaS36<<H`8@Q00536<8@PQ236<@Q00236<22484
36<3248236<4248236<010Q236<8@PQ20PaS0Q240PaS00<8@PaS36<010Q2
0PaS10Q20`aS00@8@PaS2488@P@<H`D8@Pl<H`<@Q0D<H`88@P8<H`8@Q0<<
H`03248<H`aS008<H`04248@Q12448@236<00`Q236<<H`0636<00a2436<@
Q00236<548@336<0112436<<H`aS0Q2400DDYA2448@@Q0aS008@Q0085:D@
Q12448@<Ha2436<@Q0<<H`0448@<H`aS248636<348@00`aS48@<H`0736<0
1A2436<8@PQ248@010aS00@@Q0aS2488@PD<H`05248<H`aS36<@Q00336<0
0a2436<<H`0236<248@010aS2488@PQ20`aS0Q2410aS0Q2400@DYA2448@<
H`8@Q0035:D@Q124008@Q0<<H`<@Q0D<H`0348@<H`aS008<H`8@Q08<H`<@
Q00336<@Q12400<<H`<DY@<<H`8@Q08<H`D@Q00:5:D@Q0aS36<@Q0aS248<
Ha245:D336<248@636<01A2436<<H`aS248010aS0PQ20PaS00@@Q0Q236<8
@P<@Q0L<H`0548@<H`aS36<8@P0236<00`Q236<<H`0236<00`Q236<@Q002
48@436<2248336<0112436<<H`aS0PQ21@aS0`Q210aS0PQ200@<H`Q236<8
@P@<H`88@P0336<8@PaS008<H`88@P8<H`88@P8<H`0424848@Q236<42484
36<424800`aS2488@P02124236<0112436<<H`Q20`aS0`Q20PaS00@8@PaS
36<<H`88@P<<H`031248@Q24008<H`05248<Ha2436<@Q00336<348@00`aS
1248@P0236<324800`aS48@@Q00236<3248010aS248<Ha2420aS10Q20`aS
00<8@PaS36<02`aS0PQ200D<H`Q236<@Q0aS00<8@PD<H`<8@P8<H`<8@P8<
H`0424848@Q2248336<8248236<224800`aS2488@P0424800`aS248<H`02
24801@@Q2488@PQ236<00`Q20PaS0PQ200<<H`Q236<00`Q200<<H`Q21240
0`Q200<<H`Q224800PQ200<<H`Q236<00@Q2000212400`0012448@051240
1@00124@Q1S636<00PQ20`aS00<8@Q2436<01`aS00<8@PaS36<010aS1124
10aS0Q2400<<H`Q236<010aS10Q200<<H`Q224801@Q21`aS0PQ200@<Ha24
5:DDY@88@P<<H`88@P@<H`@8@P<<H`88@P<<H`88@P8<H`05248<H`Q248@<
H`02248636<00`Q248@<H`0248@836<01PQ248@@Q12436<8@P8<H`8@Q0D<
H`0348@<H`aS00H<H`8@Q00336<8@PaS008<H`<@Q0<<H`<@Q0@<H`@@Q0<D
Y@0548@<H`aS48@DY@0448@00aBU48@@Q00236<00a2436<<H`0236<00a24
36<<H`0336<248@536<00a2436<<H`0236<248@336<00a2436<<H`0636<0
0`Q236<<H`0236<00`Q236<@Q00236<010Q236<@Q1240`aS00<@Q0aS48@0
20aS0Q2400D<Ha2436<@Q1BU008@Q0055:D@Q12448@DY@0248@00`aS48@@
Q00436<01Q2436<<Ha2436<8@P8<H`8@Q00336<@Q12400D@Q00536<@Q0aS
36<DY@0248@236<248@236<348@01@aS48@HaQ2436<00a241PaS00<@Q0aS
36<00PaS0Q2400@<Ha2448@@Q0@<H`<8@P8<H`0348@<Ha2400@<H`0348@<
Ha2400<@Q0D<H`0448@<Ha2448@336<224800`aS248<H`0536<01ABU48@<
Ha24248010aS00<@Q0aS36<02@aS0`Q200D<Ha2436<<H`Q2008<H`D8@P03
36<8@PQ2008<H`03248<H`Q20088@P<<H`03248<H`Q200<8@P@<H`88@P8<
H`04248<H`aS36<3248236<3248236<00a2436<8@P0436<224800`aS48@<
H`0236<00`Q236<<H`0536<0112436<<H`Q20PaS00<@Q0aS36<00Q2400<<
H`Q224800PQ200P<H`Q2248<H`Q236<8@PaS0Q2400@<H`Q2248<H`88@P@<
H`0448@<H`aS36<224800`aS248<H`0336<00`Q236<<H`0248@536<00`Q2
36<8@P0336<2248336<3248436<01@Q236<8@PaS248010aS00<8@PaS36<0
0PQ20`aS0`Q200D<H`Q22488@PaS00D8@P0336<8@PQ200@8@P0436<8@PQ2
36<3248010@Q2488@PaS2@Q200<<H`Q2248010Q200<<H`Q224800PQ20`aS
0`Q20PaS00001P0012448@00124000848@0500048@@Q124<H`025:D636<0
0`Q236<8@P0236<3248336<01`Q236<<H`aS48@<Ha24008<H`@DY@8<H`@@
Q0/<H`@8@P@<H`L8@P8<H`0348@<H`Q20088@PL<H`H8@P0336<8@PaS00<8
@P0436<8@PaS248236<00`Q236<<H`0236<324801@aS48@@Q0aS48@010aS
0a241PaS00<8@PaS36<01A2420aS0Q240PaS0PQ200<<Ha2448@00`aS00<@
Q0aS48@01A2400H<Ha2436<@Q0aS5:D248@01ABU36<<H`aS48@00QBU00<@
Q0aS48@00Q240`aS0Q2400<DY@aS36<01`aS0a240`aS00L@Q0aS36<<Ha24
36<@Q00236<248@010aS48@<Ha240PaS00<@Q0aS48@01PaS00<8@PaS36<0
0`aS00<@Q0aS48@00Q241`aS0Q240`aS00XDYA2436<@Q0aS5:D@Q1BU48@<
H`8@Q08<H`0348@DYA2400<<H`0348@<H`aS00D<H`8@Q08<H`0448@<H`aS
48@25:D00a2436<<H`0248@436<011245:DDYABU0Q240PaS00D@Q0aS36<<
Ha2400<DY@L@Q00336<8@Q24008@Q00336<8@PaS008@Q0D<H`0348@<Ha24
00L<H`0348@<H`aS008@Q08<H`<@Q0H<H`0348@<Ha24008<H`05248<H`aS
36<@Q00436<348@536<2248336<0112436<<H`aS0PQ20`aS00<8@PaS2480
10aS00<8@PaS36<00PaS1@Q20PaS00L8@PaS36<<Ha24248<H`02248236<0
1@Q236<<H`aS24800PaS00<8@PaS36<00`Q20PaS00@8@PaS2488@PP<H`03
248<H`aS00<8@P0436<8@PaS248736<2248236<0112436<<H`Q21@aS0Q24
00<<Ha2436<00`Q20PaS00@8@PaS48@<H`<8@PD<H`<8@P0536<@Q12436<@
Q00336<2248236<2248236<00a2436<<H`0336<224801a2436<<H`aS248<
H`Q2008<H`03248<H`aS008<H`03248<H`Q200<<H`<8@P<<H`03248<H`aS
00<<H`<8@P031248@PQ2008<H`@8@P0536<8@PQ224848@0224801@aS2488
@PQ236<01`Q20`aS1@Q20`aS0PQ200<<Ha2436<00`Q200<<H`Q236<02`Q2
00000`@Q00048@09124011246<H<H`Q220aS0`Q20PaS00<8@PaS36<00PaS
00D8@PaS36<@Q0aS008@Q0036<HDYABU00H@Q0X<H`04248<H`Q2248236<0
0`Q236<<H`0236<4248236<548@2248436<324800`aS2488@P02248010aS
248<H`Q20`aS0`Q200@<H`Q2248<H`88@P<<H`03248<H`aS008@Q0@<H`<@
Q00336<@Q0aS00L<H`<@Q0<<H`8@Q0<<H`0348@<H`aS00@8@P0436<@Q124
48@236<448@436<01Q2436<@Q0aS48@<H`@@Q00436<@Q1245:D248@25:D5
48@00`aS48@@Q0025:D636<0112436<<H`aS1A240PaS00<@Q0aS36<00Q24
2PaS00@8@PaS36<8@P@<H`05248<H`aS36<8@P0236<0212436<<H`aS5:D@
Q0Q236<248@336<0112436<<H`aS1A240QBU10aS00D@Q1BU48@@Q0aS00@@
Q0<<H`0348@<H`aS00D<H`0448@<H`aS36<448@00`aS48@@Q00336<348@0
11BU48@DYA240PaS00D@Q0aS48@@Q1BU008@Q08DY@<<H`<@Q00536<8@PaS
36<@Q00336<448@00`aS2488@P0236<01Q2436<<H`aS48@<H`88@PH<H`H@
Q00336<@Q0aS008@Q08<H`0548@<H`aS36<8@P0836<01A2436<<H`aS48@0
10aS1@Q211240PQ200<<H`Q236<00`Q20PaS00<@Q0aS36<010Q200H<H`Q2
36<<H`Q236<4248236<01@Q236<<H`Q236<00`Q20PaS0PQ200<<H`Q236<0
0`Q200@<Ha2436<<H`<8@P8<H`0448@<H`Q236<248@236<01@Q236<<H`aS
248010aS0PQ210aS0`Q20`aS00<8@PaS24800PaS0Q240PaS00@8@PaS36<<
H`88@P@<H`88@P<<H`<8@P8<H`071248@PaS48@DY@aS24800`aS0`Q20`aS
00D8@PaS36<<Ha2400@<H`06248<H`aS248<H`Q20PaS00@8@PaS248<H`88
@P8<H`0348@<H`aS008<H`D8@P<<H`04248<H`aS36<7248010aS24848@Q2
0PaS10Q200H<H`Q236<<H`Q2124324801PaS24848@Q21248@P<<H`L8@P8<
H`0548@8@PQ2248<H`0424800`aS248<H`04248136<12481124000848@05
00048@001240000312401P001248@QBU48@<H`8@Q0@<H`03248<H`aS00<<
H`88@P03124<H`aS0088@PL<H`@@Q0056<HDY@aS248<H`0348@336<22480
10aS48@<H`aS0PQ200D<Ha2436<<H`Q200<<H`<8@P<<H`88@P8<H`0748@<
H`aS36<8@PaS24801`aS10Q200H<H`Q22488@PaS248236<00`Q236<<H`08
36<548@236<348@336<2248636<00aBU48@DY@0336<0112436<<H`aS0Q24
00<<Ha2436<00`aS1A240`aS1A2400<<Ha2448@01A2400<<Ha2448@00QBU
2A2400@DYA2436<<H`8@Q00436<8@PaS36<548@:36<248@436<00a2436<<
H`0736<00a2436<<H`0336<348@536<0112436<<Ha241@aS1A2400DDYA24
48@@Q1BU00<@Q00336<@Q0aS00L@Q00336<@Q0aS008<H`0348@<H`aS00<<
H`0448@DYA2448@336<011245:DDYA240PaS00<@Q1BU48@00Q240aBU0Q24
0PaS1Q2400<<Ha2448@00`aS0Q240`aS00<@Q0aS24800PaS00<@Q0aS48@0
0Q2400<<H`Q236<00a240`aS00P@Q0aS36<<Ha2436<@Q0aS11240PaS00<@
Q0aS48@00PaS00<@Q0aS48@00a241@aS0PQ20`aS00<@Q0aS36<00PaS00@4
8@Q236<@Q0@<H`8@Q08<H`03248<H`aS00@<H`8@Q0<8@P0436<@Q0aS2482
36<324800`aS248<H`0436<3248436<3248336<424800a2436<8@P032480
10aS248<H`aS0PQ200@<H`Q22488@P8<H`03248<H`aS00@<H`8@Q0@<H`07
248<H`aS36<8@PaS24800`aS0`Q20`aS0Q240`aS00@8@PaS36<8@P@<H`88
@PD<H`03248<H`aS00<<H`03248<H`aS008<H`04248<H`aS48@224800`@Q
36<@Q00236<010Q236<@Q0aS0`Q20PaS00<8@PaS36<010aS00<8@PaS36<0
1@aS0PQ200@<H`Q2248<H`8@Q00336<8@PaS00@8@P0436<8@PQ236<;2480
10@Q248<H`aS0PQ20`aS1@Q200@48@Q236<8@P8<H`D8@P0336<@Q12400L<
H`03248<H`Q20088@P0336<8@PQ20088@P4<H`48@P0000<000@Q12401@@Q
00L000@Q12448@aS5:D@Q00636<0112436<8@PQ20`aS0PQ200<<H`Q236<0
0`aS00D@Q0aS36<8@PaS008@Q0065:D@Q1BU6<HDYA240PaS00<@Q0aS36<0
1@aS00L@Q0aS2488@PaS48@<H`02248236<2248236<3248=36<3248236<0
0`Q236<8@P0236<224800`aS2488@P02248336<3248536<011245:D@Q124
0PaS00@@Q0aS48@@Q0D<H`0448@<H`Q2248336<25:D0112436<<H`aS0Q24
0PaS00<8@PaS48@00a2400TDYA2436<<Ha245:D@Q0aS48@010aS1A240PaS
0Q2400HDYA2448@@Q1BU48@25:D648@00`aS48@@Q00248@00`aS48@<H`04
36<648@536<248@236<011245:D@Q0aS0PQ20a240`aS0Q240PaS00@8@PaS
36<@Q0@<H`0548@<H`aS248<H`0248@010aS48@@Q1240PaS00H8@PaS36<<
Ha2436<248@00aBU48@@Q00348@010aS48@<H`aS1A2400@<Ha2448@@Q0@<
H`0348@<H`aS008<H`<@Q0<<H`0348@<H`aS008<H`8@Q00436<@Q0aS5:D4
48@00aBU48@@Q00348@236<248@011BU36<<H`aS0a2400<<Ha2436<00PaS
0Q240`aS0a241`aS00<@Q0aS36<00PQ200<<Ha2436<00a2400L<Ha2436<@
Q0aS48@<H`0448@00`aS48@@Q00248@<36<248@010aS248<H`Q210aS00<@
Q0aS36<010aS0`Q200<<H`Q236<00`aS00<8@PaS36<00PaS10Q200<<Ha24
36<00PaS00<8@PaS36<00PaS00<8@PaS36<00PaS1PQ200<<H`Q2248010aS
00<8@PaS24800PQ20`aS00@8@PaS2488@P8<H`0548@<H`aS36<8@P0236<0
112436<8@PQ21@aS0`Q21@aS00<8@PaS36<00`aS0a2400<8@PaS36<00PQ2
00<<Ha2436<00PQ20`aS0PQ210aS00<8@PaS36<00`aS00<8@PaS24800`aS
10Q21@aS00<@Q0aS36<01@aS00<8@PaS24800`Q200<<H`Q236<00PaS0PQ2
0`aS0PQ20PaS00@8@PaS36<@Q08<H`03248<H`aS008<H`D8@P0336<8@PQ2
0108@P<<H`0424848@Q236<4248236<4248010aS48@@Q0aS0PQ20PaS0`Q2
00<<H`Q224801`Q200001@@Q00048@@Q00001@@Q00<000@Q24801A241`aS
00<8@PaS24800PaS00H8@PaS36<<Ha2436<3248336<2248236<00a2436<<
H`02248236<248@236<2248836<2248836<00a2436<<H`02248536<22482
36<2248336<4248336<3248;36<224800`aS48@<H`0236<748@236<00`Q2
36<<H`0336<448@00`aS48@DY@0248@236<00a2436<<H`0448@336<248@0
0`aS48@@Q00348@436<0112436<@Q12411BU0a2400<<Ha2436<00Q2400D<
Ha245:D@Q0aS008@Q0045:D@Q124248236<00aBU48@@Q00236<348@00`aS
48@@Q00248@010aS248<H`aS0Q243PaS0PQ200H<Ha2436<<H`Q236<248@3
36<010Q236<<Ha241@aS00<@Q0aS36<00Q2400dDYA2448@@Q1BU48@<Ha24
5:D@Q0Q236<@Q0025:D236<448@636<00a2436<<H`0236<00a245:DDY@02
48@00`aS48@@Q00348@00aBU48@@Q00248@00aBU48@DY@035:D00`aS48@@
Q00448@436<248@00aBU48@<H`0236<248@336<00a245:D@Q0045:D00a24
36<<H`0336<00a24248<H`0236<0112436<@Q0aS0Q2400<<Ha2436<010aS
00<@Q0aS48@00`aS112400<<Ha2436<00PQ20PaS00@@Q0aS36<<H`8@Q0<<
H`05248@Q0aS48@<H`0248@436<3248010aS248<H`aS0Q2400<<H`Q22480
1PaS0PQ21PaS00<8@PaS36<01`aS0PQ200@<H`Q236<<H`@8@PD<H`88@P<<
H`03248<H`Q200T<H`07248<H`aS36<8@PaS248010aS0PQ20PaS00@8@PaS
2488@PD<H`0848@DYA2448@8@PaS248@Q08<H`05248<H`Q236<8@P0236<2
248436<00`Q236<<H`0236<2248236<00`Q236<<H`0436<00a2436<<H`02
24801@aS48@@Q12436<010Q210aS00@8@PaS248@Q08<H`88@P0336<@Q124
008<H`05248<H`aS36<8@P0236<01PQ236<8@PaS248<H`88@P8<H`04248<
H`Q2248236<524800`aS248<H`0524800`@Q2488@P0236<010Q236<8@PaS
0`Q200D<HaBU5:DDY@aS0088@P<<H`@8@P8<H`<8@P031248@PQ20088@P00
0P@Q00D000@Q12448@0000848@0900048@@Q48@DY@aS248<Ha2400@<H`05
248<H`Q236<8@P0236<020Q236<<H`aS48@<H`Q236<224800`aS48@8@P02
248010aS48@<H`Q220aS00@8@PaS36<8@P8<H`0348@<H`aS008<H`88@P8<
H`0448@<H`Q236<348@00`aS2488@P0236<01A2436<<H`Q236<00PQ200<<
H`Q236<010aS0PQ20`aS0PQ210aS00<8@PaS36<01`aS00<@Q0aS48@00a24
00@<Ha2448@@Q08<H`0348@8@PaS00<<H`05248<H`aS48@DY@0248@236<3
48@00`aS48@<H`0336<348@436<00a245:D@Q00336<00a2436<<H`0248@0
10aS48@@Q1240QS600HLiaBU48@@Q0aS48@336<01A245:DDYA2436<01A24
0PaS00<@Q0aS48@010aS11240PaS00<@Q0aS36<00`aS00<@Q0aS36<00`aS
00H@Q0aS36<8@PaS48@236<00`Q236<<H`0536<00a2436<<H`0636<01124
36<<H`aS0Q240`aS0Q2400@<Ha2448@DY@<@Q00336<@Q0aS00@<H`D@Q004
36<@Q0aS248236<248@236<00a2436<<H`0236<748@336<248@35:D248@0
0aBU6<HDY@0248@011BU48@<H`aS0a240PaS0Q240`aS00<@Q0aS36<01@aS
00<@Q1BU5:D00QBU0Q2410aS00<@Q0aS36<01PaS00@8@PaS48@@Q0H<H`04
248<H`aS5:D248@236<248@636<010Q236<<H`aS0Q240PaS00D8@PaS248<
Ha2400@<H`0548@<Ha2448@<H`04248236<00a2436<<H`02248336<32484
36<01@Q236<8@P@Q24800PaS0`Q200D<Ha2436<8@P@Q00<8@P0336<8@PaS
00@8@P<<H`<8@P<<H`@8@P<<H`88@P0336<@Q1BU00<<H`06248<H`aS2484
8@Q20PaS00@@Q0aS36<8@P8<H`07248<H`Q236<8@PaS24800PaS11240`aS
00<8@PaS24800PaS00<8@PaS36<00PaS0PQ20`aS00D@Q0aS36<<H`Q200/<
H`@8@P@<H`03248<H`Q2008<H`03248<H`aS00<<H`03248<H`Q2008<H`06
248<H`aS48@<Ha240PaS00<@Q0aS48@00PaS00<8@PaS24801@Q200H<H`Q2
2488@P@Q36<2248236<624800`@Q248<H`0336<224800`aS2488@P032484
36<01@Q236<DYAS65:D010Q200@<H`Q22488@P8<H`0324848@Q200D8@P44
8@0000@000@Q124000@48@0600048@@Q1248@QBU10aS0a2400<<Ha2436<0
0`aS00H8@Q2448@@Q0aS248636<2248:36<00a2436<<H`02248010aS248<
H`Q20PaS00<8@Q2436<02@aS00D8@PaS36<<Ha2400@<H`8@Q00336<8@PQ2
008@Q006248<H`Q2248@Q0aS0PQ210aS00@@Q0Q22488@P@<H`03248<H`aS
008<H`03248<Ha24008@Q0@<H`8@Q00636<8@PaS36<@Q1BU10aS0a240PaS
00L@Q0aS36<<Ha245:D<H`0348@236<348@00`Q236<@Q00236<248@01ABU
48@DYA2436<011240`aS00<DYA2448@02a2400<<Ha2448@01A240`aS0a24
0`aS1a2400@<Ha2436<<H`<@Q08<H`03248@Q12400@<H`8@Q08<H`03248<
Ha2400@<H`0348@<H`aS008@Q0<<H`0348@<Ha24008@Q0<<H`0448@DYA24
36<248@25:D748@236<00a245:D@Q00348@25:D248@010aS248<H`aS0Q24
0PaS31240QBU112400<DYA245:D00QBU0a240`aS00H@Q1BU48@8@PaS48@3
36<348@236<01A2436<@Q1246<H00QcW0R480QcW00DDYAS648@@Q0aS00@@
Q0H<H`<@Q0P<H`<@Q08<H`0348@<H`aS008<H`8@Q00536<8@PQ236<@Q003
36<248@236<348@236<00`Q236<<H`0436<01PQ236<<H`Q236<8@PH<H`07
248<H`Q236<8@PaS24800PaS00D8@PaS36<<H`Q200<<H`05248<H`aS48@<
H`02248236<424800`@Q36<<H`0236<01@@Q248<H`Q236<01@Q20PaS00<@
Q0aS36<00PQ20PaS00<@Q0aS36<00PaS00<8@PaS36<00`aS00@8@PaS36<<
H`88@P0336<8@PaS008<H`@8@P@@Q0<<H`8@Q0<<H`03248<H`aS00@<H`06
248<H`aS36<@Q0aS0PQ200<<Ha2436<01@aS00@@Q0aS48@@Q0@<H`06248<
H`aS36<8@PaS0`Q20PaS00<@Q0aS36<00`aS10Q20PaS00D@Q0aS36<<H`Q2
00<<H`0348@<H`Q200@8@P04124<H`aS36<2248010aS248<H`aS1PQ20`aS
0`Q20`aS0PQ200<<H`Q236<00PaS00D8@QBU6<HDYA240088@P@<H`<8@P04
36<8@PQ236<7248136<12481248000@48@0300048@@Q00<48@0700048A24
5:D@Q0Q236<00Q242PaS00<@Q0aS24800PQ20`aS00<8@PaS48@00PaS00P8
@PaS36<<H`Q236<8@Q240`aS00<8@PaS36<00PQ230aS00<8@PaS24800PaS
0Q240`aS0PQ200D<Ha2448@<H`Q200<<H`0348@8@PaS008<H`03248<Ha24
008<H`88@P8<H`88@P@<H`88@PT<H`8@Q0035:D@Q12400@<H`8@Q0D<H`03
48@<Ha24008<H`@@Q00336<@Q1BU008@Q0<<H`<@Q0@<H`8DY@8@Q00336<@
Q12400H@Q08<H`8DY@8@Q00436<@Q1BU5:D648@00`aS48@@Q00348@00aBU
48@@Q00236<0112436<<H`aS0Q2400P<Ha2448@<Ha2436<@Q0aS112400@<
Ha2436<<H`@@Q088@P0336<@Q124008<H`05248<H`aS36<8@P0236<248@3
36<00a2436<<H`0436<00a2436<<H`0348@00aBU48@DY@0248@35:D248@3
36<35:D248@01@aS48@DYABU48@010aS0Q2400<<Ha2448@00Q2400@<Ha24
5:D@Q08<H`0348@DYA2400@DY@8@Q08DY@0348@DYA24008DY@T@Q0@<H`L@
Q00436<@Q1BU6<H27>L012DY8@PQ21S60aBU00@@Q0aS48@@Q0<<H`<@Q0D<
H`0448@<Ha2448@336<01A245:D@Q0aS48@00`aS00<@Q0aS48@02`aS00@@
Q0aS36<<H`<@Q0<<H`0348@<H`aS00<8@P@<H`03248<H`aS00<<H`88@PL<
H`88@P8<H`0448@<H`aS36<324801PaS48@<H`aS248<H`88@P8<H`@8@P05
36<8@PaS36<8@P0236<424800`aS248<H`0436<010Q236<<H`Q20PaS00D@
Q0aS36<<H`Q200T<H`88@P031248@PaS008<H`03248<H`aS00@@Q0H<H`03
248<H`aS008<H`03248<H`Q200<<H`0348@<H`aS00`<H`<@Q0@<H`03248<
H`Q200@<H`<8@P0536<@Q12436<8@P0736<248@00`aS248<H`0336<22483
36<2248010aS2488@PQ20PaS1`Q200<<H`Q224800`aS1PQ220aS0QBU00DH
aQBU36<<Ha24008<H`@8@P0336<8@PaS0088@P0336<8@PQ200H8@P0000<0
00@Q00000`@Q00<000@Q12400`@Q00D<HaBU36<8@Q24008<H`03248@Q124
008@Q0D<H`0648@<H`aS36<8@PaS0PQ20PaS0PQ20`aS00D@Q0aS36<8@PaS
00@8@P0436<8@PQ2248336<2248236<01A2436<8@PQ236<00Q240PaS00<8
@PaS36<00`aS10Q20Q240PaS00<8@PaS48@00Q2400T8@PaS48@@Q0aS248<
H`Q236<00Q240PaS0PQ21PaS00<@Q0aS48@020aS00D@Q0aS48@@Q0aS0088
@P0336<DYA2400P<H`<@Q0<<H`D@Q00436<@Q0aS48@636<248@25:D01124
36<<H`aS0Q2400HDYA2436<<Ha245:D248@010aS48@@Q1BU3a2400@<Ha24
48@@Q08<H`D@Q00536<@Q1BU5:D@Q00236<01Q2436<@Q0aS48@8@P<<H`03
48@<Ha2400D<H`04248<Ha2448@736<248@236<010Q248@@Q1240`aS00@D
YA2436<@Q0<DY@@@Q00336<@Q0aS008<H`0348@DYABU00<DY@<@Q08<H`04
48@<H`aS36<248@25:D01A245:D@Q12424800PaS00<@Q1BU5:D00QS600DD
YA2448@@Q1BU008@Q00336<@Q1BU00<DY@<@Q0<<H`<@Q0<<H`<@Q08<H`07
48@<HaBU7>LQ22e[:DX00SF]00DaS2e[7>LHaQ24008<H`8@Q08<H`<@Q0D<
H`0348@<Ha24008@Q0<<H`05248<H`aS48@8@P0236<01A2436<<H`aS48@0
0`aS00<@Q0aS36<00PaS0Q240PaS00<@Q0aS48@0112400<<Ha2448@00PaS
1@Q21PaS00<8@PaS48@00PaS00<8@PaS24800PQ200<<H`Q236<01@Q21PaS
00@8@PaS36<<H`88@P0436<8@PQ2248236<3248436<3248436<3248236<3
24800a2436<<H`02248236<2248536<00`Q236<<H`0236<3248236<22483
36<00a2436<<H`0536<2248536<324800`aS48@@Q00636<00a2436<<H`04
36<248@236<4248236<00`Q236<<H`03248336<2248336<010Q236<<H`Q2
10aS00@8@PaS248<H`T8@P0336<8@PQ2008<H`88@P8<H`<8@P0336<8@PQ2
0088@P0336<8@PaS008<H`<8@P8<H`05248@Q1245:DHaP03248336<010Q2
1248@PQ210aS2`Q200051240100012448@000`@Q00<<HaBU48@010aS00<@
Q0aS48@00Q2400P<H`Q236<<Ha2436<8@PaS0`Q200P<Ha2436<<H`Q236<8
@PaS0Q240PaS0PQ200L<H`Q21248@PaS48@<H`03248336<00`Q236<<H`09
36<3248636<00a2436<<H`0236<01A245:D<H`Q236<00Q2400<<H`Q22480
0`aS0a2400<<H`Q236<01PaS0a2400@<Ha2436<@Q0D<H`8@Q0<<H`0348@<
H`aS008<H`8@Q08<H`03248<Ha24008<H`8@Q0035:D@Q0aS00<<H`D@Q08<
H`04248@Q12436<248@25:D348@336<00a2436<<H`0248@25:D436<00a24
5:D@Q00248@00`aS48@@Q00548@336<01A245:D@Q12436<01A240PaS1A24
00L<Ha2436<<Ha2436<@Q00636<248@236<00`Q236<<H`0436<248@00`aS
248<H`0548@010aS48@<H`Q20Q2400@DY@aS48@@Q08HaP035:D@Q12400<<
H`8@Q00836<@Q1245:D@Q0aS48@DY@8@Q00336<@Q124008<H`@@Q00536<@
Q1BU5:D@Q00336<348@25:D26<H448@00`aS48@DY@035:D448@00aBU48@@
Q00348@436<00`Q236<@Q00248@236<25:D00b48:DXYBP02=Jd012e[9BTH
aQcW0QBU00<@Q0aS36<00PaS0Q240`aS0a240PaS00@@Q0aS48@@Q0<<H`03
48@<H`aS00<<H`0348@<H`aS008<H`8@Q00536<8@PaS36<@Q00436<01Q24
36<@Q0aS48@<H`@@Q0H<H`<8@P<<H`88@P0348@<H`@Q0088@P0736<8@PQ2
248<H`Q236<00`Q20PaS0PQ210aS00<8@PaS24800PQ20`aS10Q20PaS1PQ2
00<48@Q236<01@aS0PQ200<<H`Q236<00PaS00<8@PaS36<00PaS0PQ20`aS
00L8@PaS36<8@PaS248<H`0324801PaS2488@PQ236<8@P8<H`@@Q0<<H`05
48@<Ha2436<8@P0236<00`Q236<8@P0236<00`Q248@<H`0248@01@aS48@@
Q0aS24800Q2430aS0PQ200D<H`Q236<<H`Q200@<H`03248<H`aS00<8@P03
36<8@PaS00<@Q004248<H`aS36<324800`aS248<H`0236<01@Q236<8@PQ2
36<02@Q20PaS00@8@P@Q2488@P8<H`<8@P<@Q088@P8@Q0066<HDY@aS2484
8@Q20`aS0`Q20PaS0PQ20`aS00<8@PaS24801@Q200001@00124000@Q0000
1@@Q00P000@Q36<HaPaS248<Ha241@aS00<DYA2436<00`aS0PQ200<<Ha24
36<00PQ20`aS00<@Q0aS36<00PQ210aS0PQ200D<Ha2448@<H`Q2008<H`03
248<H`aS00P<H`0348@<H`aS00<8@P8<H`<8@P8<H`06248<H`Q2248<H`Q2
0`aS00<@Q0aS36<01@aS00D@Q0aS48@@Q1BU008@Q0@<H`@@Q0035:D<H`Q2
008<H`035:D<H`aS00H<H`8@Q08<H`@@Q00336<@Q0aS008<H`07248@Q124
48@<Ha2436<02A2400@8@PaS36<@Q08<H`0348@<H`aS008@Q08DY@D@Q08<
H`0348@DYA24008<H`<@Q00536<@Q12448@<H`0248@01ABU48@@Q1245:D0
0Q2400<<Ha2448@01@aS1Q2400@<Ha2448@<H`8@Q0035:D@Q0aS00T<H`8@
Q00336<8@PaS008@Q00336<8@PaS008@Q0@<H`0348@<H`aS00@<H`8@Q003
36<@Q0aS008@Q08DY@056<HDYABU48@<H`0548@00`aS48@@Q00248@35:D6
36<348@00`aS48@@Q00348@01PaS48@DYA2436<@Q08HaP095:D@Q1245:D@
Q1BU48@<Ha24008DY@0348@<H`aS00@DY@0348@<H`aS00D@Q00536<@Q124
48@<H`0248@04AS67>LU:C6<>Li6<D8@?NlicR487>L@Q0aS48@<Ha2436<0
11240`aS0a2400<DYA2436<00PaS0Q2400<<H`Q236<00PQ200D<Ha2448@<
H`Q2008<H`88@P0336<@Q0aS008<H`<@Q0@<H`0448@<H`aS36<348@636<2
248236<00a2436<<H`02248436<00`Q236<8@P0336<02@Q236<8@PaS248<
H`Q236<8@P0236<324802`aS48@<H`@Q248<Ha2436<8@PaS24800PaS0`Q2
00@<H`Q236<8@P8<H`<8@P0336<8@PaS008<H`<8@P@<H`88@P03124<Ha24
008@Q00324848@aS008<H`<8@P0:36<8@PQ2248<Ha2436<8@PaS48@336<0
112436<<H`Q220aS0PQ20PaS0a240PaS00D8@PaS36<@Q0aS00<@Q0<<H`<@
Q088@P0436<8@PQ2248236<010Q236<<Ha240PaS00<8@PaS36<00`aS0PQ2
1`aS00<DY@aS24800PQ20`aS0PQ200<<H`Q236<00PQ200D<H`Q22488@P@Q
00<8@P<<H`<8@P0336<8@PaS008<H`<8@P@<H`0348@DY@aS00<<H`<8@P03
36<@Q0aS00@8@P@<H`H8@P4<H`48@P0020@Q00P000@Q12448@aS5:D<H`Q2
0`aS00@8@PaS36<@Q08<H`0348@<H`aS00<8@P0436<@Q12436<248@236<0
1PQ236<<H`aS48@8@P<<H`88@P8<H`03248<H`aS008<H`88@P0436<@Q0aS
248436<00a2436<@Q00836<2248536<020Q236<<H`aS48@<Ha2436<248@2
36<2248248@011BU48@@Q1240PaS1Q2400@DY@aS36<<H`8@Q00336<8@PQ2
008<H`0748@<H`aS48@DYA2436<00PQ20PaS112410aS0Q240PaS0Q2400<<
Ha2436<01A2400D<H`Q236<@Q1BU008@Q08<H`8@Q08<H`0348@DYA2400<@
Q08<H`0448@DYA2448@236<00aBU48@@Q00248@236<348@00aBU48@@Q002
48@236<348@336<348@00`aS48@@Q00248@25:D01Q2436<<Ha2436<@Q0D<
H`03248<H`aS00<<H`04248<H`aS248436<00a2436<<H`0236<0112436<<
H`aS0a2400D<Ha245:DDY@aS008@Q08HaP055:D@Q12448@<H`0:48@00aBU
48@@Q00248@00`aS48@@Q00236<348@010aS48@@Q1240PaS00PDYA2436<@
Q1S67>LHaPaS0a2400DDYA2448@@Q1BU00@@Q0045:D@Q1245:D248@336<3
48@00aBU48@<H`0236<248@031S67>LU:C6<>Li6<D8@>LhaS2487>LDY@8@
Q00336<@Q0aS008<H`8@Q0<<H`035:D@Q12400D<H`8@Q0@<H`88@P0448@<
H`aS248636<00a2436<<H`0348@336<00a2436<@Q00248@010aS48@DYA24
0PQ210aS00<8@PaS48@00Q240PQ20PaS0PQ20PaS0PQ200D<Ha2436<<H`Q2
00D<H`<8@P0336<8@PaS0088@P0336<8@PaS008<H`<8@P8<H`0324848@Q2
008<H`04248<H`aS36<3248010aS248<Ha240PaS0PQ20PaS00@8@PaS36<<
H`88@P@<H`03248<H`aS008<H`0448@<H`Q2248336<3248436<00a245:D@
Q00536<00`Q236<<H`0936<348@00`Q236<<H`0236<348@010Q236<<Ha24
1PaS0`Q22@aS0PQ21@aS00@8@PaS2488@P8<H`8@Q0@8@P8<H`@8@P<<H`03
248<H`Q20088@P0336<@Q0Q20088@P<<H`<8@P0336<8@PaS00<8@P8<H`06
248<H`aS36<@Q1BU1PaS0PQ20PaS0`Q20`aS00<8@PaS24800`Q20`aS0000
0`001240000212401@0012448@@Q00000P@Q00@@Q1S648@8@PD<H`0348@<
H`aS008<H`0548@<H`aS36<@Q00436<01A2436<<H`aS24800PaS00D8@PaS
48@@Q0aS0088@P@<H`05248<H`Q236<8@P0536<324800a2436<<H`022480
10aS48@@Q0aS0`Q20PaS0`Q20PaS00@8@PaS36<@Q0<<H`0348@<H`aS008<
H`05248<Ha246<HDY@0336<248@236<00a2436<@Q00348@01ABU48@<H`Q2
36<00a240PaS0`Q200<<Ha2436<00Q240`aS0a2400<<Ha2448@00Q2410aS
0Q240QBU00<@Q1BU48@00Q241`aS00<DYA2448@00PaS0Q2400<DYA2436<0
0PaS1Q240PaS0Q2400DDYA2436<8@PaS00D@Q08<H`8@Q0<<H`8@Q08DY@8<
H`@@Q0<<H`H@Q0P<H`05248<H`aS48@<H`02248336<00a245:D@Q00336<5
48@536<01aBU48@<Ha245:DHaQBU00P@Q00636<@Q0aS5:D@Q1BU0Q240aBU
00@@Q0aS36<<H`<@Q08<H`0448@<H`aS36<248@00`aS48@DY@0348@010aS
5:DDYABU1a2400<<Ha2448@00QBU00D@Q0aS48@@Q1BU008<H`0648@<H`aS
48@<Ha2410aS00D@Q1S69BTe[C6<0092408icP8Li`0548@<H`aS36<@Q002
36<00a245:D@Q00236<348@236<348@:36<248@00`aS248<H`0436<22483
48@00`aS248<H`0448@236<248@00`aS48@<H`0436<00`Q236<@Q00236<2
248236<00a2436<<H`0436<00`Q236<8@P0436<3248336<01@Q236<8@PaS
24800`aS10Q200<<H`Q236<00PaS0`Q20PaS00<8@PaS36<00`Q200<<H`Q2
24800PQ200<@Q0aS24800`aS0PQ20PaS10Q21@aS00@8@PaS248<H`<8@PD<
H`04248<H`aS36<348@010aS48@<H`aS0`Q220aS00L@Q0Q22488@PaS5:D<
H`02248;36<224800`aS2488@P02248436<00`Q236<<H`02248236<00a24
36<<H`04248636<00`Q236<8@P0236<00`Q236<48@0224800`aS2488@P04
24800`aS2488@P02248236<324800`aS2488@P03248336<00`Q236<@Q002
48@00`aS248<H`0336<4248236<3248336<3248236<1248000<48@030004
8@@Q00H48@0336<DYA240088@P<<H`0448@<H`aS48@636<2248236<22482
36<00a2436<<H`02248236<0112436<<H`Q20PaS00@@Q0aS2488@P8<H`03
248<Ha24008<H`88@P0348@<H`Q2008<H`04248<H`aS248336<3248336<2
248436<00`Q236<@Q00736<01Q245:DDYABU48@8@PD@Q0<<H`<@Q00636<@
Q1BU48@<H`Q20PaS00L@Q0aS248<Ha245:D@Q00236<248@336<0112436<<
H`aS0Q240PaS112400<DYA2448@00Q2400<DYA2448@00Q2400<<Ha242480
0PaS0a2400<<Ha2436<00a240`aS11240PaS0a2400<DYA2436<010aS00@@
Q1BU48@<H`8DY@0448@<H`aS48@336<448@011BU36<<H`aS0a2400D<Ha24
48@HaQ24008<H`03248<Ha2400D<H`0648@<H`aS36<@Q0aS0PQ200D<Ha24
48@<H`Q2008<H`8@Q0@<H`T@Q0<DY@8@Q00336<@Q124008<H`T@Q0055:D@
Q12436<@Q00236<348@436<348@336<45:D248@25:D00a2436<<H`0248@2
5:D0112436<@Q1240QBU1A240PaS0a240PaS0Q2400@<HaBU5:DU:@8e[@8m
k`8icP079BTLi`aS248<Ha245:D00Q240PaS00D@Q0aS48@@Q0aS00@@Q0<<
H`0348@<H`aS00`<H`0348@<Ha24008<H`8@Q00536<8@PaS36<@Q00236<2
48@011BU48@@Q1241@aS00D8@PaS48@@Q0aS0088@P8<H`05248<H`aS36<8
@P0536<01@Q236<<Ha2436<00PQ20`aS00<48@Q236<00`aS00P8@PaS248<
H`Q236<8@PaS0PQ210aS1PQ20PaS0PQ21@aS00@8@PaS2488@P@<H`88@P<<
H`88@P<<H`88@P8<H`D8@P@<H`05248<H`aS48@<H`0248@536<224800`aS
48@@Q00236<01@Q236<<H`aS24801@aS00H8@PaS36<<Ha2436<248@236<0
0`Q236<<H`0236<010Q236<<H`Q21PaS0PQ200L<H`Q236<8@PaS248<H`02
248836<424801@aS2488@PQ236<010Q200@<H`Q22488@P8<H`03248<H`aS
00D<H`04248<H`Q2248236<2248236<348@236<00`Q236<<H`05248236<8
24800`aS24848@012480000900048@@Q124000@Q00048@0000848@060008
@Q2448@<Ha240PaS00<@Q0aS36<00PaS00D@Q0aS36<@Q0aS0088@P0536<@
Q0aS36<8@P0636<2248336<01PQ236<<H`Q236<8@PD<H`88@P0536<@Q124
36<8@P0236<00`Q236<<H`0336<2248236<3248236<0112436<<H`aS0PQ2
2`aS112400@DYA2448@@Q0@<H`0448@<H`aS36<748@00aBU48@@Q00248@2
36<2248236<0112436<@Q1BU0Q2400<<H`Q236<00Q2400DDYA2448@@Q0aS
008@Q00436<DYABU48@336<011245:D@Q1240`aS00@@Q0aS36<<H`<@Q08D
Y@8<H`03248<Ha24008@Q08<H`<@Q0@<H`0748@<H`aS36<@Q1BU48@00`aS
0a240`aS00L@Q0aS48@@Q1BU48@<H`0248@336<00aBU48@@Q00436<248@0
0`aS48@<H`02248236<248@2248236<00a2436<<H`0336<548@436<01124
5:DDYABU112400<DYA2448@00PaS00<@Q1BU48@00a240aBU0Q2400<DYA24
48@010aS00<@Q0aS36<00PaS00D@Q0aS48@@Q1BU008@Q08<H`8@Q0065:D@
Q1245:D@Q1BU0Q2400<<Ha245:D00Q2400@<HaBU5:D@Q08<H`D@Q00336<@
Q0aS008@Q0<<H`<@Q0086<HLibDY:DXicSF]<H`YBP8HaP0348@<H`aS008<
H`075:D@Q1S65:D<Ha2436<01A2400<DYA2448@00Q241@aS00@@Q0aS2488
@PH<H`0448@<Ha2436<848@236<248@010aS48@@Q1240`aS00@@Q0aS36<8
@P8<H`0348@<H`aS00D<H`88@P0336<@Q0aS008<H`03248<H`aS00H<H`04
48@<H`aS248336<010Q236<<H`Q22`aS00<8@P@Q36<00PaS0`Q210aS00@8
@PaS36<<H`88@P8<H`<8@P0336<8@PQ2008<H`03248<H`Q200D<H`88@P8<
H`@8@PD<H`D@Q0<<H`0448@<H`Q2248436<248@00`aS248<H`0248@010aS
2488@PQ20`aS0Q240PaS0PQ20PaS0`Q20PaS0PQ20`aS00@@Q0aS2488@P<<
H`04248<H`aS36<2248636<010Q236<<H`aS0PQ200<<H`Q236<02@Q200@<
H`Q21248@P8<H`<8@P0348@<H`Q2008<H`03248<H`aS008<H`03248<H`aS
00D<H`07248<H`Q2248<Ha2436<00PQ200<<H`Q224800PQ21@aS0@@Q0002
12400`0012448@0512401P00124<HaBU36<8@P8<H`<@Q00336<8@PaS0088
@P<@Q00336<48@aS00D<H`03248<H`aS0088@P<<H`88@P0436<8@PaS48@3
36<2248336<3248336<00`Q236<<H`0336<324800`aS248<H`04248336<2
248236<248@236<2248020aS248<H`aS248<Ha245:D548@336<348@00`aS
48@@Q00248@236<011245:DDYA240PaS0a240`aS00<@Q0aS36<00Q240QBU
00<@Q0aS36<00PaS1A240`aS00@@Q1BU5:D@Q08<H`055:D@Q0aS36<8@P03
36<548@011BU48@@Q1240`aS0a240PaS00<@Q1BU36<00PaS00<@Q0aS36<0
0PaS1a240`aS00D@Q0aS36<@Q0aS008@Q0035:D@Q12400L@Q0<<H`0?48@<
Ha2448@<Ha2436<@Q0aS248<Ha2436<@Q0aS0088@P0436<@Q12448@236<3
48@536<01A245:DDYA245:D00Q2400<DYA2448@00Q2400<DYA2436<00`aS
0a240QBU00@HaQBU48@@Q0@<H`@@Q0@<H`L@Q08<H`0848@DYABU48@DY@aS
48@<H`<@Q0035:D@Q124008@Q00336<@Q124008@Q00436<@Q0aS5:D348@0
0`aS48@<H`0336<00aBU6<HQ2002:DX01S6<=Jd]Jbe[6<HLi`8@Q00536<8
@Q2448@DY@0348@00`aS48@DY@0248@00`aS48@@Q00448@>36<248@236<2
5:D00a2436<@Q00248@00aBU48@<H`0336<248@00aBU48@<H`0236<248@0
0`aS2488@P0336<224800`aS48@<H`0236<00a2436<8@P0336<0112436<8
@PQ20PaS0PQ20`aS00<8@PaS48@00PQ21`aS00D8@PaS36<@Q0aS0088@P04
36<8@PaS248336<00`Q236<<H`0236<224800`aS48@@Q00236<01@Q236<<
H`Q236<00PQ20PaS00D8@PaS36<<H`Q200H<H`03248<H`aS008<H`03248<
H`Q200<<H`8@Q0035:D<H`Q2008<H`03248<H`aS00<<H`03248<H`aS008@
Q08<H`0348@<H`Q20088@P@<H`<@Q00436<8@PQ2248536<00`Q236<<H`07
36<2248536<4248010aS48@<Ha240PaS10Q200<<H`Q236<00`Q20PaS10Q2
00H<H`Q22488@PaS48@236<3248336<2248336<00`Q2124<H`025:D010aS
1248@PaS0`Q200@<H`Q2248<H`<8@P0436<8@PaS248336<3248000<48@03
00048@0000H48@0:248DY@aS248<Ha24248<H`Q248@836<0212436<<H`aS
248<H`Q248@736<324800`aS48@<H`0236<00`Q236<<H`0336<4248436<0
0a2436<<H`0224800`aS2488@P02248010aS2488@PQ20`aS0PQ20PaS00D@
Q0Q236<<Ha24008<H`8@Q00536<8@PQ236<@Q00436<248@336<01A2436<<
H`aS48@010aS00H@Q1BU48@<H`Q236<248@336<00aBU48@@Q00236<00a24
5:DDY@0248@010aS48@DY@aS0a2400D<Ha2436<<Ha2400<DY@<@Q00436<@
Q0aS48@236<00a2436<<H`0336<548@236<448@01@aS48@@Q12436<00a24
0PaS11240`aS00D@Q0aS36<8@PaS008@Q0<<H`0348@DYA2400@<H`8@Q0P<
H`0348@DYA24008<H`0348@<H`aS008<H`03248<H`aS00D<H`0348@<H`aS
00<@Q00336<@Q124008DY@@@Q0035:D@Q0aS00<@Q00536<@Q1BU5:D@Q002
36<00a2436<@Q0025:D248@010aS48@@Q1241@aS00H8@PaS48@DYA2436<2
48@01QBU48@<H`aS48@<H`8@Q08DY@0448@DYA245:D648@25:D548@00aBU
48@@Q00236<548@00`aS48@@Q0025:D00aS67>LQ20039BT01AcW5:D@Q124
36<011240`aS00<@Q1BU48@00PaS00<@Q1BU36<00a2400<DY@aS36<010aS
00<@Q0aS36<00PaS00<@Q0aS48@01@aS00@8@PaS48@HaP8@Q0046<H@Q124
36<248@01PaS2488@PaS48@<H`<@Q0045:D@Q0aS248236<0112436<<Ha24
1@aS00<8@PaS36<01PaS00<8@PaS36<01@aS00<8@PaS36<010aS00<8@PaS
36<00PaS0PQ20PaS00<@Q0aS24800PQ20PaS10Q21@aS00<8@PaS36<00PaS
0`Q200<<H`Q236<00`aS0`Q22@aS00@8@PaS36<<H`<8@PH<H`8@Q0H<H`04
248@Q0aS36<248@01`aS2488@PaS5:D<H`Q2008<H`0348@<H`aS008<H`03
48@<H`Q20088@P<<H`88@P0336<8@PQ200<8@P<<H`88@P8<H`0448@<H`Q2
36<4248436<224801`aS248<H`aS248<H`Q200<<H`88@P041248@PaS36<2
24800`@Q248<H`0236<3248236<00a2436<8@P0424800`aS248<H`022480
10aS2488@PQ20`aS00<8@PaS248010aS10Q210aS0@Q20@@Q00000`@Q0004
8@0612401`0012448@aS5:D@Q0Q200<<H`03248<H`aS008<H`03248<H`aS
00D<H`0648@<H`aS248<H`Q20`aS0PQ21@aS00D8@PaS36<<H`Q200D<H`03
248<H`aS008<H`88@P0536<@Q0aS36<8@P0236<2248336<424800a2436<8
@P0224800`aS248<H`0236<00a2436<<H`0236<00a2436<<H`0636<010Q2
36<<Ha2410aS00<@Q0aS36<010aS00@@Q0aS36<@Q08<H`05248<H`aS48@<
H`0348@01@aS48@DYA245:D00PaS00@DYA2448@@Q0<<H`035:D@Q124008<
H`0448@HaQBU48@436<00a2436<<H`0236<00a2436<@Q00436<448@236<2
48@236<348@236<0112436<8@Q240QBU00P@Q0aS36<<Ha2436<@Q0aS0Q24
10aS11240`aS0a240PaS00D@Q0aS36<@Q0aS00@@Q08<H`0348@<H`aS00@8
@P<<H`03248<H`aS00@@Q08<H`0348@<H`aS008@Q0<DY@8@Q08DY@8@Q004
36<DYA245:D336<01A2436<<H`aS48@00QBU00D<Ha2448@@Q0aS0088@PD<
H`8@Q08<H`0848@HaQBU36<8@Q245:D<H`8@Q08DY@0348@<HaBU008@Q08D
Y@H@Q00336<@Q124008@Q0<<H`8@Q0055:D<H`aS36<@Q0025:D248@031BU
7>LLibDY8@PLibDY5:D@Q0aS48@DY@<<H`065:D@Q0aS48@DYAS6112400<D
Y@aS36<00PaS0Q2400<<H`Q236<01@aS00<@Q0aS36<00PaS00<@Q0aS36<0
0PaS11240aBU0PaS00@8@PaS36<<H`<@Q003248<H`aS008@Q00336<8@PaS
008<H`0348@<H`aS00@<H`0448@<Ha2436<2248436<00`Q236<<H`0336<0
1@Q236<8@PaS24801PaS00@8@PaS2488@P<<H`<8@P@<H`H8@P<<H`04248<
Ha2436<424801`aS2488@PQ236<8@P@Q0088@P8@Q0H8@P0436<8@PaS2484
36<2248236<00a2436<<H`0236<00a2436<<H`0336<00a2436<<H`0436<0
0a2436<<H`0336<00`@Q2488@P0248@236<248@00`aS2488@P0436<32480
0`aS2488@P05248336<00`@Q2488@P0536<00`Q236<<H`0236<00`Q236<4
8@02248236<2248336<7248010aS248<H`Q20PaS00<8@PaS24800PQ20PaS
1@Q200<<H`Q224800PQ20`aS0`Q200@<H`Q22488@P<<H`04248<H`Q22484
36<112412480000700048@00124000@Q00000`@Q00@000@Q36<DY@<<H`03
248<H`aS0088@P0336<@Q12400<<H`03248<H`aS00P<H`03248<H`aS00D<
H`03248<H`aS00@<H`88@P<<H`<8@P<<H`<8@P0436<@Q0aS36<224800`aS
2488@P02248236<2248010aS248<H`Q210aS0`Q200<<Ha2436<010aS00<@
Q0aS24800PaS0`Q200D<Ha2448@<H`Q200P<H`0348@<H`aS008@Q08<H`04
248<H`aS36<648@00aBU48@@Q0025:D00aS65:D<H`0236<248@00aBU48@H
aP025:D236<548@436<00a2436<<H`0336<01A2436<<Ha2436<01A2400@<
Ha2448@DY@8@Q00736<@Q0aS36<@Q1BU48@00`aS00@@Q0aS36<<H`@@Q003
36<@Q0aS008<H`0448@<Ha2436<248@336<348@536<00a2436<<H`0348@3
36<00a2436<@Q00736<00a2436<<H`0248@00aBU48@DY@025:D011S65:DD
YABU112400@HaQBU5:DDY@@@Q0035:D@Q12400@@Q00436<@Q0aS48@236<2
48@336<011245:D@Q0aS0Q2400<HaQ2436<00PaS0QBU00@@Q0aS48@DY@8@
Q00436<@Q1BU48@25:D00a2436<<H`0336<348@236<00a2436<@Q00248@0
0aBU48@DY@025:D011245:DDYAS60QBU00H@Q1BU6<HDYA2436<348@01PaS
48@@Q12436<@Q08DY@0348@<H`aS008@Q0D<H`0448@<H`aS48@236<02PQ2
48@@Q0aS248<Ha2436<@Q0aS11240`aS00@DYA2448@@Q0@<H`0548@<H`aS
248<H`0248@336<00`Q248@<H`0436<00`Q236<8@P0236<248@236<22483
36<00`Q236<<H`0636<01@Q236<<Ha2436<00PQ20`aS00@8@PaS36<<H`D8
@P0436<8@PQ2248236<224801PaS2488@PaS48@<H`<8@P0336<8@PQ20088
@P@<H`@8@P0436<8@PaS248536<3248336<3248336<348@436<2248236<0
112436<8@PaS0Q240`aS00H8@PaS48@@Q0aS248236<0112436<8@PQ20`aS
0`Q20PaS00D8@PaS36<<H`Q200D<H`0524848@Q2248<H`02248436<00`Q2
36<8@P02248010aS2488@PQ20`aS10Q20`aS00@8@PaS248<H`@8@P0536<8
@Q2448@<H`03248236<00`Q236<<H`0424800`aS2488@P0236<02`Q2124<
H`Q248@8@PaS248<H`Q236<00`Q20`aS0@Q2000812402P0012448@0036<@
Q0aS248<Ha241`aS0Q2410aS0Q240`aS00@@Q0aS36<8@PD<H`88@P8<H`07
48@<H`aS248<H`Q236<00`Q20PaS0PQ20PaS00D8@PaS36<@Q0aS0088@P03
48@<H`Q20088@P0336<8@PaS00<<H`03248<H`Q200<<H`03248<Ha2400@<
H`0348@<H`aS00P<H`88@P<<H`0448@<H`aS48@436<248@236<348@236<0
10Q236<<Ha240PaS00@@Q1BU5:DDY@<@Q0035:DHaQBU00<@Q08<H`065:D@
Q1BU48@<Ha240QBU0Q2410aS0a2410aS0Q2410aS0a240`aS0Q240`aS1124
00D<Ha2448@DYA24008<H`0348@<H`aS008<H`0548@<H`aS48@<H`0348@3
36<011245:D@Q1240PaS00@8@PaS36<@Q0H<H`0448@<H`aS36<248@00`Q2
36<@Q00236<010Q236<@Q12410aS00D@Q1BU5:D@Q1BU008@Q0035:DHaQS6
00@@Q08DY@<HaP035:D@Q12400<@Q08<H`0448@DYABU36<248@01@aS248<
H`aS48@00`aS0a2400HDYA2448@@Q0aS48@336<348@01QBU48@<H`aS48@D
Y@8@Q0065:D@Q12448@<Ha240PaS00@@Q1BU48@@Q0@<H`<DY@8@Q0035:DH
aQBU008@Q0<HaP0448@DYA245:D248@236<0112436<@Q0aS0a2400LDYAS6
5:D@Q0aS48@DY@0336<348@00`Q236<<H`0236<248@336<00a2436<<H`03
48@536<548@010aS48@<H`aS0Q241@aS0a240PaS00<@Q0aS36<010aS00<8
@PaS36<00a2420aS0`Q200<<Ha2436<010Q200@<H`Q236<@Q08<H`88@P04
36<8@PaS248536<3248236<2248236<2248236<3248336<2248236<00`Q2
36<8@P0436<2248336<010Q236<<Ha240`aS00<8@PaS36<00`aS0PQ200D<
Ha2448@<H`Q200P<H`04248<Ha2448@;36<01@Q236<@Q0aS48@00`Q20PaS
10Q20PaS10Q21@aS0`Q200<<H`Q224800`Q200<<H`Q2248010Q21`aS10Q2
00D<H`Q22488@PaS00@8@P0336<@Q0aS0088@P<<H`<8@P0636<8@PaS48@<
H`Q20P@Q00<<Ha2436<00PaS00<48@Q224800`aS0`Q20PaS0`Q20PaS0000
1@0012448@@Q00001`@Q00@<Ha2436<8@P<<H`03248<H`aS00D<H`0348@<
H`aS008<H`0348@<H`aS008<H`03248@Q0aS008<H`06248<Ha2448@<H`Q2
0`aS00@8@PaS36<<H`<8@P@<H`03248<H`aS00<<H`05248<H`Q236<8@P02
36<0112436<<H`aS0`Q210aS0`Q20`aS00<8@PaS48@01`aS00<8@PaS2480
0`aS11240`Q200<<Ha2448@010aS00<@Q0aS36<010aS0Q240PaS00@8@PaS
36<<H`<@Q08DY@<@Q0035:D<H`aS00<@Q0045:D@Q1BU5:D648@011BU36<@
Q0aS0Q240PaS00@@Q0aS36<<H`8@Q08<H`8@Q0@<H`8@Q0055:D@Q12448@<
H`0548@010aS48@@Q0aS0Q2400<DYA2436<00PaS00H@Q0aS48@<Ha2436<4
48@010aS48@@Q1240`aS112400<8@PaS48@0112400D<Ha2436<<H`Q2008<
H`8@Q0D<H`0448@HaQBU5:D348@011BU48@DYA240QBU0a2400P<Ha2448@@
Q1S65:DHaQBU11240PaS0Q2400HDYA2448@<Ha2436<224800`aS48@@Q003
48@00`aS48@@Q00348@01PaS48@<H`aS48@<H`8@Q0065:D@Q0aS36<@Q1BU
112400@<Ha2436<DY@@@Q00336<8@Q24008DY@8@Q00336<DYABU008@Q003
5:D@Q1S600HDY@8@Q00336<@Q12400@<H`D@Q0045:D@Q12436<348@00`aS
2488@P0236<248@00`aS248<H`0248@;36<01Q2436<@Q12436<@Q0D<H`03
248<Ha24008@Q0D<H`0448@<Ha2448@236<00`Q236<@Q00936<00a2436<8
@P0236<248@436<3248436<00`Q236<<H`0436<00`Q236<8@P0636<01@Q2
36<<H`Q236<00PQ200<<H`Q236<00PQ200@<H`Q236<8@P<<H`04248<H`Q2
48@236<2248436<00`Q248@<H`0248@01@aS2488@PaS24800`aS0PQ21PaS
00<DY@aS36<01PaS0`Q200<<Ha2436<00PaS00D@Q0aS36<<H`Q2008@Q005
36<8@PQ2248<H`03248936<00`Q236<<H`0236<00`Q236<8@P0236<32480
1@aS248<H`Q236<00`Q20`aS0`Q210aS00L8@PaS36<<H`Q21248@P0336<0
1P@Q36<<H`aS248<H`88@P0336<8@PQ2008<H`88@P0336<8@PaS00<<H`88
@P0336<8@PQ200<<H`<8@P0536<@Q0aS36<8@P0236<2248136<000848@05
00048@@Q1240000212401@0012448@Q25:D02PaS00@@Q0aS36<8@P8<H`03
48@<H`aS00D<H`@8@P<<H`88@PH<H`03248<H`Q200D<H`04248<H`aS36<3
24801Q2436<<H`Q236<8@PH<H`<8@P0336<@Q0aS008<H`88@P8<H`0448@<
H`aS36<248@01@aS248<H`aS48@00PaS0PQ20`aS0Q2400D<H`Q236<<Ha24
00H<H`8@Q088@P0436<DYABU48@536<448@00`aS48@@Q0035:D00a2436<@
Q0025:D00a2436<@Q00948@25:D01Q2436<<H`aS48@<H`8@Q08<H`0348@<
H`aS008<H`D@Q00336<@Q0aS008@Q00336<@Q1BU008@Q08<H`D@Q0<<H`04
48@<H`aS36<248@236<00a245:DDY@0348@00`aS48@<H`0336<01Q2436<@
Q0aS48@<H`<@Q0035:D@Q0aS00L<H`0548@<H`aS36<@Q0035:D248@01QBU
6<H@Q1245:DHaP<@Q0045:D@Q12436<65:D011S648@@Q1240PaS00<@Q1BU
5:D01`aS0Q2400DDYA245:D@Q0aS00@@Q00436<@Q12436<548@00`aS48@D
Y@0248@00`aS48@@Q00436<248@00`aS48@@Q00336<01A245:DDYA245:D0
0Q2411BU00H@Q1BU48@HaQBU6<H25:D248@536<548@00aBU48@DY@0248@3
36<00a2436<<H`0C36<00a2436<@Q00348@336<348@336<00a2436<<H`02
36<248@536<2248010aS48@<H`aS0Q240PaS00@8@PaS48@@Q08<H`03248<
Ha2400L<H`88@P0336<8@PaS00H<H`04248<H`aS48@236<224800`aS2488
@P02248236<00`Q236<<H`0436<010Q236<<H`aS1@Q200<<H`Q236<00`aS
0PQ200@<H`Q248@<H`8@Q0<<H`88@P@<H`<8@P0536<@Q0aS36<@Q00236<0
10Q236<<Ha240PaS00<8@PaS36<00Q240PaS0`Q220aS00<8@PaS36<01PaS
00H8@PaS2488@PaS248236<00`Q236<<H`0336<00`Q236<<H`0524801`aS
2488@PQ236<8@PaS00<8@P8<H`03248<H`aS00<<H`88@P@<H`03248<H`Q2
0088@P@<H`88@P0336<8@PaS008<H`04248<H`aS248436<2248010aS248<
H`Q20`aS00<8@PaS36<01PaS0@Q20000100012448@001P@Q00D000@Q36<D
YA240088@P0336<8@PaS00L<H`0548@<H`Q2248<H`0348@436<2248236<0
0a24248<H`0;36<3248436<2248636<010Q236<<H`Q20`aS0PQ20`aS0PQ2
0PaS0`Q20PaS00<@Q0aS24800PQ200<<Ha2448@00Q2410Q21@aS0Q2400D<
Ha2436<8@PaS00<@Q003248<H`aS00<<H`0448@<H`Q236<248@336<948@0
2ABU48@<H`Q236<@Q1BU48@<H`0248@336<248@011BU48@DYA241`aS0Q24
00@<Ha2436<<H`8@Q0045:D@Q0aS36<348@00`aS48@@Q00248@236<01124
36<DYABU0Q240PaS112410aS0Q2400<<Ha2448@00Q2400@<Ha2448@@Q08<
H`<@Q0<<H`0448@DYA2448@836<348@436<248@00aBU48@DY@035:D:48@3
36<00a245:DDY@0548@236<348@636<448@01PaS48@@Q0aS48@<H`8@Q08<
H`0:48@<H`aS36<8@PaS48@DYA245:D348@01QBU48@@Q0aS248<H`8DY@8@
Q08<H`<@Q0035:D@Q124008@Q0035:D@Q124008DY@<@Q0<DY@D@Q00336<@
Q0aS008@Q00636<DYABU48@DY@aS0a2400@<Ha2448@@Q0<<H`8@Q00436<@
Q0aS36<548@236<01@Q236<8@PQ236<00Q240`aS00@@Q0aS36<<H`<@Q0L<
H`<@Q0D<H`0348@<H`aS008@Q0X<H`<8@P0336<@Q12400<<H`03248<H`aS
008<H`05248<H`Q236<8@P0436<00a2436<<H`0348@00`aS248<H`032483
36<7248336<2248436<2248010@Q248<H`Q21`aS0Q2400<<H`Q224800PaS
00<8@PaS36<00PaS00@8@PaS36<<H`@@Q00336<8@PaS00@<H`0648@<H`Q2
248<H`Q20`aS00<8@PaS24800PaS00D@Q0aS24848@Q200<<H`04248<H`Q2
248336<3248436<00`Q236<<H`0336<00`@Q2488@P0436<2248010aS248<
H`aS0PQ20PaS0PQ200@<H`Q2248<H`88@P8<H`<8@P8<H`88@P8<H`88@P<<
H`03248<H`aS008<H`@8@P0336<8@PQ2008<H`@8@P<<H`<8@P0336<8@PaS
00<<H`0010@Q00D000@Q12448@0000<48@03248DY@aS0088@P0536<@Q0aS
36<8@P0336<324801PaS248<H`aS5:D@Q08<H`03248<H`aS00D<H`0548@<
H`aS36<8@P0736<00`Q236<8@P02248436<224801`aS48@<H`aS248<Ha24
00<<H`<8@P8<H`88@P0336<@Q0aS0088@P@<H`03248<H`aS00@<H`0348@<
H`Q2008<H`03248<H`Q20088@P8@Q00336<8@PaS00<<H`0448@<Ha2436<3
48@:36<01`Q236<<Ha245:D@Q0aS008@Q0<DY@8<H`<@Q08<H`0848@<Ha24
36<@Q1BU6<HDY@<@Q08DY@0548@<Ha2436<@Q00336<348@010aS48@<H`aS
0a240PaS0a240PaS00D@Q0aS36<<Ha2400<DY@<@Q0<<H`0348@<H`aS008<
H`P@Q0<<H`0348@<H`aS008<H`0348@<H`aS00H@Q0L<H`0548@DYA24248<
H`035:D348@35:D448@00aBU48@@Q00448@010aS48@@Q1S60QBU0a2400D<
Ha2448@<Ha2400P<H`L@Q0<<H`0348@<Ha24008@Q08<H`X@Q0@<H`8@Q004
5:D@Q12436<648@25:D01A2436<<H`aS48@00QBU0Q2411BU0Q240QBU00D<
H`Q236<@Q1BU00<@Q0045:D@Q1245:D648@336<548@?36<00a2436<<H`05
36<448@336<00`Q236<<H`0348@236<010Q236<@Q1241@aS00<@Q0aS2480
0`Q21PaS0a2400@<H`Q22488@P@<H`<8@P0436<@Q12436<2248836<22483
36<01@Q236<<Ha2436<010Q200<<H`Q224800`Q220aS00H8@PaS36<@Q0aS
48@=36<2248236<348@436<2248236<0112436<<H`Q210aS00D8@PaS36<@
Q0aS00@8@P<<H`88@PD<H`88@P<<H`03248<H`aS00@<H`88@P051248@PaS
48@<H`0324801@aS2488@PQ236<00`Q20PaS0`Q21PaS0`Q200@<H`Q236<8
@P<<H`<8@P8<H`88@PL<H`0424848@Q2248336<4248836<2248000031240
00@Q00<48@0400048@@Q000212400`Q248@@Q00436<00a2436<<H`022482
36<248@536<01A2436<<H`aS48@00PaS0PQ20PaS00<8@PaS48@00PaS0PQ2
0`aS0`Q20`aS00<8@PaS36<010aS00D8@PaS36<@Q0aS00<8@P0336<8@PQ2
008<H`04248<H`aS48@436<424800`aS48@@Q00236<00`Q236<<H`0348@7
36<348@736<248@536<448@00`aS48@<H`0336<0112436<<H`aS0Q2400HD
YA2448@@Q1BU48@436<00a2436<<H`0236<248@010aS48@@Q1BU11240`aS
0Q2400<DYA2448@00a240`aS0Q2400<<Ha2436<01@aS0Q2400<<Ha2448@0
0QBU0Q240PaS00@@Q0aS36<<H`8@Q0<<H`<@Q00336<@Q0aS008@Q00436<@
Q0aS48@336<010Q236<@Q0aS0Q240`aS00@@Q0aS36<<H`8@Q0055:D<H`aS
36<@Q00436<011BU48@DYABU0`aS00<@Q1S65:D00a2400<<Ha245:D00QBU
00@<Ha2448@DY@8@Q00436<@Q1BU48@836<248@00aBU48@<H`0348@010aS
48@@Q12410aS00H@Q0aS36<<H`Q236<35:D00a24248<H`0336<00a2436<@
Q00548@236<011BU48@HaQS60Q2400<<Ha2448@00PaS00<DYAS68@P01AS6
0aBU00@@Q1BU36<<H`8@Q0045:D@Q0aS48@236<00aBU48@@Q00648@536<2
48@00aBU48@<H`0A36<248@010aS48@DYA240PaS00<8@PaS48@01A241PaS
00<@Q0aS36<010aS00<8@PaS36<00Q2400@<H`Q236<<H`88@P<<H`04248<
H`aS248236<00`Q236<@Q00236<010Q236<@Q0aS0PQ200@<H`Q2248<H`8@
Q00336<8@PQ20088@P8<H`0348@<H`Q20088@PD<H`<8@P<<H`<8@P8<H`04
248<H`aS48@336<00a24248<H`0236<00a2436<<H`0248@236<0112436<<
H`Q210aS0Q2400DDYA2436<<H`Q2008@Q088@P0436<@Q12436<4248336<2
248010aS48@<H`Q21@aS0PQ210aS00D8@PaS36<8@PaS0088@P<<H`D8@P8<
H`<8@P8<H`03248<H`Q2008<H`03248<H`Q200@<H`04248<H`Q236<32482
36<3248836<01@Q236<<H`Q236<00`Q200@<H`Q236<<H`88@P@<H`88@P<<
H`88@P8<H`48@P0000<000@Q00000P@Q00<000@Q124010@Q00D<HaBU36<8
@PaS008@Q08<H`03248<H`aS008<H`0348@<H`aS008<H`<@Q0D<H`88@P03
36<@Q0aS0088@P0436<@Q0aS248236<02PQ236<8@PQ236<8@PaS248<H`Q2
0`aS0`Q200@@Q0aS36<8@P<<H`D8@P<<H`03248<H`aS00@<H`03248<H`aS
00D<H`8@Q00336<@Q124008<H`04248<Ha2436<248@336<00`Q236<8@P05
36<348@336<00a2436<<H`0236<01A2436<<H`aS48@00`aS00<@Q1BU5:D0
112400@DYA2436<8@P8<H`0648@<H`aS36<@Q0aS0Q2400<DYA245:D01@aS
0Q2400@<Ha2448@DY@8@Q08<H`0348@DYABU00<<H`8@Q0@<H`045:D@Q0aS
48@25:D00a2436<<H`0448@736<011245:D@Q1240PaS11241@aS0Q240PaS
00<@Q0aS48@00Q241`aS00<DYA2448@00PaS00<@Q1BU5:D00Q2400<DYA24
5:D011240QBU00@@Q0aS36<@Q08DY@<@Q0065:D@Q12436<@Q1BU0a2400<<
Ha2436<01@aS0Q240`aS00<@Q1BU48@00PaS00D@Q1BU48@<H`Q200@<H`03
248<Ha24008@Q0L<H`055:D@Q1BU5:D@Q00236<00a2436<DY@026<H02ABU
48@@Q12436<@Q0aS48@HaP027>L56<H011245:D@Q1BU1A2400@DYA2436<<
H`<@Q0035:D@Q1BU008@Q0035:D<H`aS008<H`0448@<Ha2436<348@>36<0
0a24248<H`0236<248@010aS2488@PaS0Q240PaS00D@Q0aS48@@Q1BU00<<
H`8@Q08<H`8@Q0<<H`0448@<H`Q2248236<0112436<<H`Q21@aS00<@Q0aS
36<00PaS0PQ20PaS0Q240`aS00T8@PaS36<8@PaS248<Ha2436<00`Q210aS
0PQ21PaS0`Q210aS0PQ20`aS0PQ20`aS00<8@PaS48@00Q241@aS00@@Q0Q2
36<8@PD<H`0:248<H`Q236<DYA245:D@Q0aS1242248436<00a2436<<H`04
248:36<2248010aS248<H`Q20`aS0`Q200D<Ha2424848@Q200D<H`88@P06
36<8@PQ236<8@PaS0PQ200<<H`Q224800`aS00<48@Q236<00PaS0PQ20`aS
0`Q20`aS0`Q20PaS10Q200<<H`Q236<00PaS0`Q200<<H`Q236<00`Q200<<
H`Q212400PQ20PaS00L8@PaS36<8@PaS248<H`01248000@48@0<00048@@Q
124000@Q00048A245:D<H`Q20PaS0Q240PaS0PQ20PaS00<@Q0aS36<00PaS
0Q240`aS00D@Q0aS48@<H`Q200<<H`04248<Ha2448@236<00`Q248@<H`04
36<324800`aS48@@Q00336<248@936<2248010aS248<H`Q20`aS0Q2400@<
H`Q236<<H`8@Q003248<H`Q2008<H`8@Q08<H`03248<H`aS00X<H`<@Q08<
H`<@Q0<<H`<@Q00>36<8@PQ236<@Q1BU48@8@PaS48@8@PaS48@DY@8@Q003
36<@Q12400<@Q0D<H`8@Q08<H`0348@DYAS6008@Q08<H`8@Q00336<@Q124
00P@Q0T<H`8@Q00336<@Q12400@@Q0045:D@Q12448@736<448@01ABU36<<
H`aS48@010aS00<@Q1BU48@00`aS0Q2400<<Ha2436<00Q2410aS0a240`aS
0a2400<<Ha2448@04A2400<DYA2448@01A240QBU00D@Q0aS36<<Ha2400@<
H`P@Q00436<@Q0aS248236<0112436<<H`aS0Q240PaS00<@Q0aS36<00a24
0`aS00D@Q0aS36<@Q1BU008@Q00336<@Q124008<H`@@Q00336<@Q124008@
Q0075:D@Q12436<@Q1S65:D0124800<HaQBU48@0112400@DY@aS48@DY@<@
Q00336<DYABU008@Q08<H`<@Q00336<@Q124008@Q0<<H`0348@<H`aS008<
H`8@Q08<H`88@P0436<@Q0aS48@936<00a2436<<H`0336<248@236<348@4
36<00a242488@P0236<01Q2436<<H`Q236<8@PT<H`03248<H`Q200<<H`8@
Q0<<H`88@P@<H`<8@PP<H`88@P031248@PQ20088@PD<H`88@P@<H`<8@PD<
H`05248<H`aS36<@Q00236<2248236<248@936<00a245:DDY@0236<010Q2
36<<Ha240PaS00<8@PaS36<00`aS0`Q200<<H`Q224802`aS0`Q20PaS10Q2
00<<H`Q236<00PaS0PQ200<<H`Q236<00PaS0`Q210aS0`Q20PaS0`Q20`aS
0PQ20PaS00<8@PaS36<00PaS00D8@PaS36<<H`Q2008<H`04248<H`Q22484
36<3248336<4248536<5248236<1248000848@0500048@@Q124000051240
0`aS6<H@Q00<36<00a2436<8@P0236<248@336<248@436<0112436<<Ha24
0PaS00@8@PaS36<@Q0<<H`88@P8<H`0348@<H`aS008@Q0<<H`8@Q08<H`04
248<H`aS48@836<2248248@236<2248236<0112436<<H`Q20PaS0Q2400P8
@PaS36<@Q0aS248<Ha241@aS00<@Q0aS48@00PaS11240`aS0a2400@<H`Q2
36<<H`8@Q08<H`<@Q00436<@Q1245:D348@011BU48@@Q12410aS00<@Q0aS
36<00PaS0Q240QBU0Q240`aS2a2400<DYA2448@01@aS1A2400<<Ha2448@0
0Q2400<<Ha2448@00Q2400<<Ha2436<01PaS0a2400DDYA2448@<Ha24008<
H`<@Q0<<H`D@Q00336<@Q0aS00<<H`H@Q08<H`<@Q00436<@Q0aS36<248@2
5:D236<348@02`aS248@Q1245:D@Q0aS48@DYA245:D00Q2400PDYA2436<<
H`Q236<@Q0aS0a240`aS0Q2400<DYA2448@010aS0Q240`aS00<8@PaS36<0
0Q2400<<Ha2436<00Q240PaS0PQ200<<Ha245:D00Q240`aS21240PaS0Q24
21BU00THaQcW8@PQ21cW5:D@Q0aS48@00QBU11240QBU0Q240PaS0a2400<D
YA2436<00`aS00@DYA2436<@Q0H<H`0348@<H`Q20088@P<<H`8@Q0<<H`03
48@<H`Q2008<H`8@Q0<<H`04248<Ha2448@536<00a2436<8@P0:36<01a24
36<8@PQ236<@Q0aS00<8@PH<H`0548@DYABU5:D<H`03248836<01@Q236<<
H`aS24802`aS10Q22@aS00<8@PaS24800PaS00<@Q0aS48@00`aS00D8@PaS
36<8@PaS00<@Q0@8@P<<H`0448@DYABU48@>36<00`Q236<<H`03248436<0
1@Q236<<Ha2436<00PQ20`aS0PQ200@<H`Q236<<H`<8@P8<H`0348@<H`aS
00<8@P0336<8@PQ20088@P<<H`88@P0436<8@PQ2248336<010Q236<<H`aS
0PQ20PaS00<8@PaS36<00`aS00<8@PaS36<00PaS00<8@P@Q24800`aS0`Q2
00@<H`Q236<8@P@<H`03248<H`aS008<H`03248<H`aS00<<H`88@P0000@0
00@Q124000@48@0700048@@Q124<HaS648@00PaS112400<<Ha2448@00`aS
0QBU00P<Ha245:DHaQ2436<@Q1BU0Q240`aS0a2400<<Ha2448@010aS00@8
@PaS36<8@PL<H`8@Q0@<H`X@Q0035:D@Q0aS0088@PH<H`0348@<H`aS00<<
H`8@Q0L<H`88@P8<H`0348@<H`aS00D<H`03248<Ha24008@Q0<<H`0348@<
H`aS008<H`8@Q0D<H`8@Q08<H`0548@<Ha2448@DY@0248@010aS5:DDYA24
10aS0a240`aS0a240`aS0Q240PaS112400<<Ha2448@0112400H<Ha2436<@
Q0aS48@236<00a2436<DY@0348@00`aS48@@Q00648@436<548@00`aS48@@
Q00648@236<0112436<<Ha240QBU00<@Q0aS36<01`aS0a2400@<Ha2436<@
Q08<H`<@Q00336<@Q12400L@Q0<<H`0448@DYA2448@236<448@010aS48@8
@PQ20PaS00<@Q0aS36<00a240PaS00H@Q1BU5:D@Q0aS48@25:D00a2436<<
H`0248@00`aS48@<H`0436<248@436<248@01@aS48@@Q1245:D00a2400@<
Ha2448@@Q0<<H`8@Q00436<@Q1BU48@336<548@00aBU6<H@Q00248@35:D4
6<H00aBU48@@Q00548@35:D348@00`aS48@@Q00548@00`aS48@<H`0248@0
0`aS248<H`0536<010Q236<<Ha2410aS0PQ20PaS00<@Q0aS48@011240`aS
0Q2410aS00D8@PaS36<<H`Q2008<H`0448@<H`aS248336<01PQ236<<H`Q2
36<8@P8<H`03248<H`aS008<H`03248<H`aS00@<H`04248<H`aS248436<0
0`Q236<<H`0236<010Q236<<H`aS10Q20PaS0`Q21PaS00<8@PaS36<010aS
00<8@PaS36<01PaS0PQ200<<Ha245:D00`aS00<8@PaS48@00PaS00<8@PaS
24800Q2400@DYA2436<8@P@<H`88@P@<H`88@PH<H`06248<H`aS248<H`Q2
0`aS00<8@PaS36<010aS0PQ200D<H`Q2248<Ha24008<H`04248<H`aS36<6
248236<6248236<324800`aS248<H`02248010aS2488@P@Q0PaS00H@Q0aS
36<8@PaS248336<2248436<01@Q236<8@PaS24800PaS0PQ200<<H`Q236<0
0PaS00<48@Q236<00PaS0@Q20@@Q00001@@Q00048@@Q00001@@Q00D000@Q
48@HaQBU008<H`<@Q08<H`03248<H`Q200D@Q08<H`0348@DYABU008@Q0<<
H`8@Q0@<H`0348@<H`aS008<H`0448@<H`aS248336<00`Q236<<H`0236<0
0a2436<<H`0236<00a2436<<H`0448@336<00aBU48@@Q00336<00`Q236<<
H`0336<010Q236<<H`Q20PaS00<@Q0aS36<00PaS00<@Q0aS24800PQ20`aS
00<8@PaS36<01@aS00<8@PaS48@00Q2410aS00D@Q0aS36<8@PaS00<@Q0<<
H`8@Q08<H`07248<H`aS48@DYA2436<011242@aS0Q2400LDYA2448@@Q1BU
48@DY@0348@25:D00a2436<<H`0248@00aBU48@<H`0236<348@336<00a24
5:DDY@0248@00aBU48@@Q00248@00aBU48@@Q00:36<448@00aBU48@@Q004
36<548@236<011245:D@Q0aS0PQ20PaS0Q2400<<Ha2436<00a240`aS1124
0PaS00<DYA2448@00`aS00<@Q0aS36<00PaS0Q240`aS0Q2400HDYA2448@@
Q0aS248536<248@336<248@65:D01Q24248<Ha2436<@Q08<H`8@Q08DY@P<
H`L@Q08<H`@@Q008248<H`aS36<@Q1BU48@DY@8<H`D@Q08DY@0348@DYABU
008@Q0055:D@Q1BU5:DHaP025:D248@25:D248@35:D236<648@00`aS48@@
Q00248@01@Q236<<Ha2436<00Q2400@<H`Q236<<H`8@Q00336<8@PQ2008<
H`0448@8@PaS48@236<010Q248@<H`aS0a240`aS0Q2410aS00<@Q0aS2480
0PaS0Q2400<<H`Q236<01PaS00<8@PaS36<00PaS00<8@PaS36<02PaS0Q24
0`Q21@aS00<8@PaS36<02@aS00@8@PaS248<H`D8@P0336<8@PQ200P<H`03
48@8@PQ2008<H`8@Q0H<H`03248<H`aS008<H`04248<H`Q236<448@336<0
1A2436<<H`aS24800`aS00@8@P@Q248@Q08<H`88@P0536<8@PQ2248@Q006
36<2248236<3248010aS2488@PQ20PaS00<@Q0Q236<00`aS0PQ200<<H`Q2
36<010Q200@<H`Q22488@P8<H`03248<H`@Q0088@P0436<8@PaS36<32482
36<6248636<4248336<010Q236<8@PQ210aS0`Q20PaS00<8@PaS24800PQ2
000512400`0012448@0412400`aS5:D<H`0236<348@236<348@336<01a24
5:DDYABU48@<Ha24008<H`8@Q0<<H`03248<H`aS008<H`05248<H`Q236<8
@P0236<4248436<00`Q236<<H`0324800`aS2488@P0348@02PaS248@Q124
248<Ha246<HDY@aS0Q240QBU0Q2420aS00@8@PaS36<@Q08<H`03248<H`Q2
00<<H`88@P8<H`0448@<H`aS48@336<348@336<348@00`aS248<H`0448@0
10aS48@@Q1240PaS00<@Q0aS36<01Q240PaS00<@Q0aS48@00PaS0a240`aS
00D@Q1BU48@@Q0aS008DY@8@Q00336<DYABU00<@Q08DY@0448@<H`aS36<3
48@010aS48@@Q1240aBU00@@Q1BU5:D@Q0<<H`H@Q00336<@Q12400@@Q003
5:D@Q0aS008DY@0548@<H`aS36<DY@0448@020aS5:D@Q1245:D@Q0aS2482
36<448@00aBU48@<H`0248@336<00a245:D@Q00248@010aS48@@Q1241@aS
1Q2400@<Ha2448@<H`D@Q08<H`0348@<HaBU00D@Q00:7>LQ22e[:DXLic6<
?Nle[BDY48@55:D26<H01AcW6<HHaQBU48@00QBU0Q240PaS0Q2400<DYAS6
5:D011240aBU00<@Q0aS36<00PQ200@@Q0aS48@<H`@@Q00436<@Q12448@2
36<02A245:D@Q12436<@Q1BU48@DY@0248@011BU6<H@Q1S60b4800@HaQBU
5:D@Q08DY@8@Q0035:D@Q0aS008<H`0448@<H`aS248436<01a2436<@Q0aS
248<Ha24008DY@<@Q0<<H`03248<H`aS008<H`8@Q08<H`8@Q0035:D@Q0aS
00<<H`0348@<H`aS008@Q00336<@Q1240088@P@<H`88@P@<H`0448@8@PaS
248236<00a2436<<H`02248436<3248336<010Q236<<Ha240PaS00D8@PaS
248<H`Q2008<H`03248<H`Q200<<H`<8@PT<H`8@Q00536<8@PaS248<H`02
48@436<01A2436<<H`Q236<00a2400<<H`Q236<01PaS00D@Q0aS48@@Q0aS
0088@P0336<@Q124008<H`04248<H`aS36<324800`aS48@<H`0236<32480
0`aS48@<H`0236<2248236<01Q2436<8@PaS248<H`88@P<<H`03248<H`aS
008<H`<8@P8<H`08248<H`aS248<H`Q236<8@P8<H`03248<H`Q200<8@P<<
H`03248<H`Q2008<H`04248<H`aS36<3248336<3248236<02@Q236<<H`aS
248<H`Q236<8@P0536<010Q236<<H`Q20PaS0@Q20000100012448@000P@Q
00@000@Q124000848@0648@HaPaS248<Ha240PaS0Q240`aS00L@Q0aS36<<
Ha245:DHaP0248@236<248@236<2248:36<01PQ236<8@PQ236<8@P<<H`03
248<H`Q200@<H`05248<H`aS36<@Q00236<2248236<348@01@aS48@@Q1BU
6<H00Q2400<DY@aS48@02@aS0`Q210aS0Q240`aS00<@Q0aS36<01@aS00<@
Q1BU36<00PaS0Q241PaS112400@DYA2448@@Q0<<H`@@Q08DY@0348@<H`aS
00H<H`8@Q00336<@Q124008@Q08<H`0448@DYABU48@236<248@35:D248@2
36<010Q236<<H`aS0Q2400<<Ha2448@00a2400@DYA2436<<H`@@Q00436<@
Q12448@336<25:D00a2436<<H`0248@00aBU48@@Q00348@01PaS48@DYABU
48@<H`8@Q0045:D@Q0aS248436<248@25:D00a2436<@Q00336<548@236<4
48@436<01A2436<@Q0aS48@00PaS0Q2400XDYA2436<<Ha2436<@Q0aS248<
H`D@Q00;6<H@Q1BU8@P]JbU:9BT]JcW><H`YBP0248@011BU48@DYAS60QcW
00LHaQBU5:DDYA245:D@Q00436<00a245:DDY@0348@00aBU48@@Q0025:D2
48@536<348@010aS48@@Q1240PaS0a2400D<Ha2448@DYA24008<H`0448@D
YABU5:D348@00aBU6<HQ20029BT01b485:DDYA245:D@Q0aS008@Q08DY@D@
Q0`<H`065:D@Q12448@<Ha240`aS00<8@PaS36<00`aS1a2410aS0Q2410aS
00@8@PaS48@<H`88@PL<H`03248<H`Q200D<H`03248<H`aS008<H`88@P03
36<8@PaS00<<H`88@P0336<@Q0aS00@<H`88@P<<H`88@P<<H`88@P8@Q003
36<8@PQ2008<H`05248<H`aS36<8@P0636<01A2436<<H`aS48@00`aS0Q24
00@<H`Q236<8@P8<H`03248<H`Q200D<H`8@Q00636<8@PaS36<@Q0aS0PQ2
0PaS0`Q20PaS0PQ20PaS00<8@PaS36<01@aS00<48@Q224801@aS00@8@PaS
2488@PL<H`<8@P8<H`@8@P8<H`88@P041248@PaS36<3248236<3248236<0
0`Q236<8@P05248236<4248010aS2488@PQ210aS00D8@PaS248<H`Q2008<
H`05248<H`aS248<H`0224800`aS2488@P01124000848@0300048@@Q00D4
8@0800048@aS5:D<H`Q236<@Q08<H`0348@<H`aS00<<H`0948@<HaBU48@Q
22DY7>LHaPaS00@@Q0T<H`03248<H`aS008<H`<8@P<<H`03248<H`aS00<<
H`<8@P8<H`03248<H`Q200@<H`@8@PL<H`8DY@076<H@Q1245:DHaQBU48@0
0PaS0a2410aS00<8@PaS36<00Q241@aS0Q240`aS0Q2400@DYA2448@DY@8@
Q0@<H`@@Q08<H`0348@<Ha2400@<H`8@Q08DY@<@Q08DY@8@Q00536<DYA24
5:D@Q00236<248@336<25:D011S648@@Q1240QBU1A2400<<Ha2448@00PaS
0Q2400@<Ha2436<<H`D@Q00336<@Q124008DY@0336<@Q124008@Q08<H`<@
Q08<H`0648@DYA2448@<Ha2411BU1Q2400<<Ha2448@00Q2410aS0Q2400<D
Y@aS36<00Q240`aS00@@Q0aS36<@Q08DY@0448@<Ha2448@236<00`Q248@<
H`0336<35:D00a245:DQ20029BT35:D548@00aS65:D@Q00236<02aBU6<HL
iacW8@Pe[CW>?Nle[B487>L011BU00HHaR48:DXaS2e[9BT28@P012U:8@PQ
21cW0R480QcW0R480QcW0aS60QBU00HHaQBU48@<Ha245:D336<248@00`aS
248<H`0348@236<248@00`aS48@<H`0648@01ABU48@@Q12436<00Q2400<L
ib48:DX00S6<00@]JbDY6<HHaP<DY@0348@DYA24008<H`0348@<H`aS008<
H`8@Q08<H`03248<Ha24008@Q0035:D@Q12400<<H`0348@<H`aS00<<H`@@
Q0035:D@Q124008@Q0@<H`0348@<H`aS00@<H`0448@<H`aS36<2248236<0
1A2436<<H`aS48@02PaS00@8@PaS36<8@P<<H`@8@P@<H`03248<H`aS00@<
H`03248<H`Q2008<H`05248<H`Q236<8@P0536<00`Q236<<H`0236<01A24
36<@Q0aS24800PaS00<DY@aS24800PaS00D@Q0aS36<8@PaS008@Q0<<H`06
48@<H`Q2248<Ha240`aS00<@Q0aS48@00PaS0`Q20`aS0`Q200<<H`Q236<0
0`aS00@8@PaS2488@P@<H`041248@PQ2124336<00a2436<8@P02248236<0
0`Q236<8@P0236<00a2436<<H`0236<4248336<00a242488@P0224801@aS
2488@PQ236<00`Q20PaS00<8@PaS36<00PaS10Q20PaS00D8@PaS36<<H`@Q
0088@P0536<48@Q2248<H`02248336<010Q236<@Q1240`aS00@@Q0aS2488
@P8<H`0000D000@Q12448@0000<48@0800048@@Q124<Ha2436<8@P<@Q004
36<@Q12448@236<00a2436<<H`0248@28@P011cW5:D@Q0aS0Q241PaS00<8
@PaS24801@aS00<8@PaS36<00PQ200<<H`Q2248010aS00<8@PaS36<010aS
00<8@PaS24800PaS00@@Q0aS36<<H`88@P0336<@Q12400<<H`8@Q08DY@09
48@DYA2448@DY@aS48@<HaBU008<H`03248<H`aS00@<H`03248<H`aS00@<
H`8@Q0<<H`0348@<Ha2400<@Q0L<H`@@Q00336<@Q12400@<H`0448@DYABU
5:D448@00`aS48@@Q00236<448@236<00a2436<@Q00248@25:D248@01@aS
48@DYABU48@00`aS0Q2400<<Ha2436<010aS0Q2400<DYA2448@00Q2400T<
Ha245:DDYA2436<@Q1BU48@01@aS0Q240QBU1Q2400@DYA245:D@Q0<<H`03
5:D@Q12400<@Q0D<H`0448@DYA2448@336<248@236<448@00`aS48@@Q002
48@536<02A2436<@Q1246<HDYA245:DLi`028@P25:D348@00aBU48@DY@03
48@02aBU48@DYABU6<HLibDY=JdicSg_<H`00QcW0aBU00D@Q1S67>LYBRe[
00@YBP048@PU:BDY8@P27>L00b489BTU:@028@P00acW5:DHaP055:D00a24
36<<H`0436<00a2436<<H`0448@00`aS48@@Q00236<248@336<348@25:D2
48@02`aS48@HaQ246<HLibU:<H`]JbU:9BT01QBU00<@Q0aS36<00`aS00<@
Q0aS36<01PaS0a2400D<Ha2436<<H`Q200@<H`04248<Ha2448@336<348@7
36<348@236<01a2436<<H`aS248<H`Q200@<H`88@P@<H`03248<H`Q200<<
H`03248<H`aS00<<H`03248<H`aS00<<H`03248<H`Q200T<H`04248<H`Q2
36<224800a2436<<H`02248336<0112436<<H`Q20PaS00<@Q0aS24800PaS
00@@Q0aS36<<H`8@Q0<<H`8@Q088@P<<H`0348@<H`aS00L<H`<@Q0L<H`03
24848@Q2008<H`<8@P8<H`03248<H`aS00<<H`06248<H`Q2248<H`Q20PaS
0PQ20`aS00@8@PaS36<<H`88@P@<H`<8@P0336<8@PQ20088@P0436<8@PaS
248436<5248436<224800`aS2488@P0236<2248636<3248636<224801@aS
248<H`aS48@01`aS0PQ200000`@Q00048@0212401@0012448@@Q00000P@Q
00<8@Q2436<00PaS00<@Q0aS36<00`aS00`@Q0aS36<<H`Q248@DYAcW8@PL
iaS648@736<010Q236<<H`aS0PQ20`aS00<8@PaS248010Q20PaS00H8@PaS
2488@PaS248436<00`Q236<<H`0236<5248;36<0112436<<Ha240QS600<L
iaBU5:D00QBU00<@Q0aS36<00PaS00@@Q0aS36<<H`8@Q0<<H`0348@<Ha24
00<<H`0348@DYABU008@Q0<<H`0548@<H`aS36<@Q0025:D248@236<00a24
36<<H`0248@00aBU48@@Q00748@01@aS48@@Q12436<00Q2400<DYA242480
0`aS212400H<Ha245:DDY@aS248536<00a2436<<H`0236<00a2436<@Q002
36<948@336<448@01QBU48@DY@aS48@<H`<@Q08DY@0348@DYA2400<@Q08<
H`0548@<H`aS248<H`0248@336<01A245:D@Q0aS24801A240PaS0a240`aS
00<@Q0aS36<00Q2400HDYA245:DDYAcW6<H28@P011cW6<HDYA240QBU0a24
11BU00@@Q1BU6<HHaP8Li`048@PU:B488@P37>L46<H01acW8@PYBRDY8@PY
BRe[00<YBP0<<H`]JbDY;F/e[DicDYA>Lf<HIcUBU3W>0R4800@LiaS636<<
H`<@Q0D<H`04248<H`aS48@336<448@336<448@00`aS48@@Q00336<01Q24
6<HHaQBU48@DY@<HaP068@PYBRe[;F/LiaS60QBU00<HaQBU48@00a240PaS
00<@Q0aS36<00`aS0a240PaS0Q241PaS00<@Q1BU48@00`aS00<@Q0aS48@0
0PaS00<@Q0aS36<00PaS0a2400@<H`Q236<@Q08<H`04248<Ha2436<22486
36<0112436<8@PQ210aS00<8@PaS248010aS00<8@PaS36<02PaS0PQ200@<
H`Q236<8@P8<H`04248<H`aS48@236<00`Q236<8@P0436<2248236<00a24
36<8@P0536<248@436<00a2436<<H`0236<248@020aS2488@PaS48@<H`Q2
36<248@011BU48@<H`aS0PQ20PaS00/8@PaS48@@Q0aS1248@PaS248<H`Q2
008<H`88@P0336<8@PaS0088@P8<H`07248<H`aS248<H`Q236<00`Q20`aS
00<@Q1BU48@00PaS0`Q200H48@aS36<<H`Q2124336<224800`aS2488@P02
248436<00`Q236<<H`0236<2248436<2248336<324800`aS248<H`0236<3
24801@aS48@@Q12436<00PQ20PaS00<@Q0Q224800@Q2000212401@001244
8@@Q00001@@Q00@<HaBU36<8@P8@Q00536<8@PaS48@<H`02248336<248@0
1R487>LLiacW48@<H`<8@P<<H`03248<H`aS00<<H`03248<H`Q200<<H`07
248<H`Q2248<H`Q236<00PQ200@<H`Q236<8@P8<H`04248<H`Q2248436<2
24800`aS248<H`0248@01@aS2488@PaS48@00`aS0Q240QBU0QS611BU1`aS
0Q240PaS00D@Q0aS36<<Ha2400@<H`0348@<H`aS008@Q0<<H`<@Q0<<H`04
48@DYA2448@236<248@336<248@01ABU48@<Ha2436<01A240PaS11BU0`aS
0a2400<<Ha2448@00QBU0PaS00@@Q1BU48@<H`88@P045:D@Q12448@236<3
48@436<448@011BU36<<Ha240QBU00<@Q0aS36<00Q2400@DYA2436<<H`H@
Q00436<DYABU5:D348@00aBU48@@Q00236<01PQ236<@Q12436<8@P8<H`03
5:D@Q0aS00P<H`<@Q08<H`0348@DY@aS008<H`0448@<Ha2448@35:D01AS6
8@PQ22486<H00QBU0a240QBU00L@Q1BU5:D@Q1BU48@DY@026<H27>L38@P0
1BDY8@PLiaS65:D00aS600DQ22DY9BTU:BU:008]J`08:DXQ22DY<H`]JbDY
:DXe[@9>L`05DYAW>F<HCW<icP029BT26<H248@<36<00a2436<<H`0236<2
48@01QBU36<<H`Q248@DY@<@Q00536<@Q12448@DY@026<H35:D36<H01R48
9BTYBRU:7>LHaP8@Q0035:D@Q1BU00@@Q08<H`0448@<H`aS36<848@22484
36<348@236<548@436<00a2436<<H`0248@436<01A2436<<H`aS24801`aS
00<@Q0aS36<010aS00<8@PaS24800PQ21`aS00<8@P@Q24800`aS00<8@PaS
36<01PaS00<8@PaS36<00PaS00<8@PaS36<00PaS00@8@PaS36<8@P8<H`04
248<H`aS248336<00a2436<<H`0436<01@Q236<<H`aS48@02@aS00<@Q0aS
36<00PaS00<@Q0aS48@00PaS00D8@P@Q248<Ha2400<8@P0336<@Q124008<
H`<8@P<<H`04248<H`aS36<2248236<3248436<324801@aS248@Q0aS48@0
0PaS0`Q20PaS0PQ200<<H`Q224800PQ200<<H`Q224800PaS00<8@PaS1240
0PQ20`aS0PQ21@aS00<8@PaS248010aS0`Q20PaS10Q20PaS00<8@PaS2480
11240PQ20`aS0A240@aS0@Q20000100012448@0010@Q00L000@Q12448@Q2
5:D@Q00636<00`Q236<<H`0436<020Q236<@Q1S68@PU:AcW5:D2248336<2
248010aS48@<H`aS0PQ200@<Ha2436<<H`H8@P0436<8@PaS248236<00`Q2
36<<H`0236<010Q236<<Ha240PaS00<8@PaS36<00PaS00H8@PaS36<<Ha24
36<2248236<00`Q236<@Q00248@236<00a245:DDY@026<H00aBU48@@Q002
48@236<00a245:D@Q00236<248@010aS48@@Q1240`aS00H@Q0aS36<@Q1BU
48@236<648@336<948@536<248@00aBU48@@Q0035:D248@836<548@25:D2
48@00`aS48@@Q00648@336<248@01PaS48@@Q1245:D@Q0@<H`H@Q0@DY@8@
Q0035:D@Q124008<H`0348@<HaBU00<DY@8@Q0035:D<H`aS00<<H`0348@<
H`aS008<H`8@Q0035:D@Q0aS00@<H`D@Q0065:D@Q12436<@Q0aS11240QBU
00@@Q1BU5:D@Q08DY@077>LHaQBU7>LU:B487>L011S600DDY@aS36<<Ha24
008DY@P@Q0046<HDYAS65:D26<H38@P01BDY:DXaS3F]<H`013F]00`aS3F]
?Nm:DUJeCW=BU4YBDYAF]DYB@Q029BT00acW6<HDY@0448@436<25:D436<2
48@236<448@236<748@35:D248@00aS67>LHaP025:D02AS67>LDYAS68@PY
BRDY7>LHaP035:D248@236<248@236<00a2436<@Q00336<00a2436<<H`02
36<248@236<00a2436<@Q00548@00`aS48@<H`0648@236<01@Q236<@Q0aS
24800PaS00<@Q0aS36<00`aS00<8@PaS36<010aS00<8@PaS36<00PaS00<8
@PaS36<00`aS00D8@PaS36<<H`Q200@<H`03248<H`Q200<<H`07248<H`aS
248<H`Q236<00`Q200P<Ha2436<<H`@Q248<Ha240PQ200<<Ha2436<00PaS
0Q2400<<Ha2448@010aS00<@Q0aS36<00Q240`aS0Q241@aS00<@Q0aS48@0
2@aS0PQ200@<Ha2448@<H`88@P<<H`<8@P<<H`<8@P0336<8@PQ200<8@P<<
H`05248<H`Q236<8@P0236<00a2436<8@P0536<00`Q236<<H`0724800`aS
2488@P0424801@aS248<H`aS24800PaS0PQ20`aS00<@Q0Q2248010aS00@8
@PaS36<<H`88@P03124<H`Q2008<H`04248<H`aS248336<00a2436<<H`02
248000@48@0300048@@Q00848@0500048@@Q248@Q00336<01a2436<<H`aS
48@<H`Q200<<H`0548@8@PQ25:DHaP029BT011BU48@<H`Q21@aS0PQ200<<
H`Q236<010aS00D8@PaS36<8@PaS00<8@P@<H`88@P<<H`<8@P0436<8@PaS
248236<00a2436<<H`02248236<00`Q236<<H`0636<00a2436<@Q00348@2
5:D00aS65:DDY@0348@236<348@236<00a2436<<H`0348@336<0112436<@
Q0aS0Q240`aS0Q2400HDYA24248<Ha2436<348@35:D00a2436<<H`0236<4
48@00aBU48@@Q00248@01ABU6<HDY@aS24800Q2400@<H`Q236<DY@L@Q08D
Y@0348@<H`aS00D@Q00636<8@PaS48@DYA240PaS2Q2400<<Ha2448@01124
00LDYA2448@@Q1BU36<@Q00236<248@25:D248@00`aS48@@Q00236<010Q2
48@@Q1240`aS0Q2400DDYA2448@@Q0aS00P@Q00436<DYA245:D248@336<0
0a245:D@Q0035:D248@01ABU6<HDYAS67>L00R480QS61ABU00<@Q0aS48@0
0Q2400<DYA2436<00PaS0Q2400<DYA245:D00aBU0QcW0R4800LU:BU:=Jde
[CW><H`]J`02=Jd012e[=Jdmkdic0e:D00E>Le:DE[E6<CW>008YBP038@PL
ia2400<<H`0348@<Ha2400@<H`L@Q08<H`@@Q00636<@Q12448@DYA240aBU
0Q240QBU0QS611BU00<HaQBU6<H00R4800HU:AcW7>LLia2436<448@236<4
48@00`aS48@<H`0336<00`Q236<<H`0248@00`aS48@<H`0236<01A245:DD
Y@aS24800PaS1A240PaS00<@Q0Q236<00PaS00<@Q0aS36<01@aS00<@Q0aS
36<00`aS00@8@PaS36<@Q0<8@P@<H`0348@<H`Q200@<H`88@P@<H`03248<
H`aS00H<H`03248<H`aS00<8@P<<H`03248<H`Q20088@PL<H`0348@<H`aS
008<H`8@Q0D<H`0348@<H`aS00@<H`0348@<H`Q200@<H`03248<Ha2400H<
H`0524848@aS36<@Q00536<00`Q236<8@P0436<4248336<5248336<22483
36<00a2436<<H`02248236<6248336<524800`aS2488@P02248336<00`Q2
36<<H`0436<0112436<<H`aS1@Q200<<H`Q224800PQ200@<H`Q236<@Q0<<
H`03248<H`aS00<<H`@8@P0000<000@Q00000P@Q00<000@Q12400`@Q00D0
00aS48@<H`Q200@<H`04248<H`aS36<2248248@00aBU36<8@P0248@00aBU
36<<H`0836<4248236<01@Q236<@Q12424800P@Q0Q240PQ200<<Ha2436<0
2PaS00H8@PaS36<<Ha2436<3248336<2248736<248@00`aS48@@Q00248@3
36<25:D03AS67>LDYAS65:D@Q0aS48@DYA24248<HaBU008@Q003248<Ha24
008<H`@@Q0@<H`<@Q08<H`8@Q00336<@Q0aS00<@Q0H<H`0348@DYA2400@@
Q0035:D@Q124008@Q0<<H`0448@<H`aS36<548@01ABU48@<H`aS48@00QBU
0a2400<DYA2436<00PaS00<@Q1BU48@00`aS0Q2400<DYA2436<00a240`aS
0a240QBU0Q2400<DYA2448@00PaS112400<DYA2448@01A242PaS0a2410aS
0aS600<@Q0aS48@00a2400@<Ha2436<@Q08DY@8HaP<DY@036<HDYA24008<
H`<@Q00336<8@P@Q00848@<8@P<<H`88@P0536<@Q12424848@0324800`@Q
24848@03248236<01ABU48@@Q1246<H011cW00HU:Be[=JdaS3F]?Nl2AS40
0d8@?Nlmk`02@Q001dYBE[E6<Cg_9BTLib4800<DY@8@Q08<H`0348@DYA24
00h@Q0035:D@Q0aS008<H`035:D@Q0aS008@Q08HaP045:D@Q12448@26<H0
1QBU48@DYAS69BTYBP8Q20047>LHaQS65:D248@00`aS48@@Q00348@836<0
0a2436<@Q00336<248@236<00a2436<<H`0236<348@01`aS48@<H`aS48@<
Ha2400<<H`<@Q00336<8@PaS00T<H`03248<H`Q201T<H`8@Q08<H`03248<
H`aS00@<H`<8@PD<H`0348@<H`Q2008<H`0348@<H`aS00D<H`0348@<H`aS
00d<H`8@Q08<H`06248<Ha2448@<H`Q210aS10Q20PaS0PQ200<<H`Q236<0
0`Q200<<H`Q224800`Q210aS0`Q20PaS00@8@PaS36<@Q0D<H`04248<H`aS
36<424800`@Q2488@P0236<5248336<00`Q236<8@P0336<424800`aS248<
H`0336<3248010aS48@<H`aS0PQ20`aS0`Q210aS10Q20@aS0@Q200061240
100012448@000P@Q00<<HaBU36<00PQ20PaS00<@Q0aS36<00`aS00L@Q0aS
36<8@PaS48@<H`0248@236<00a2436<<H`0424800a2436<<H`03248010aS
48@@Q0aS0PQ200D<H`Q212448@Q2008<H`<8@P0836<@Q0aS36<8@PaS248<
H`<8@P<<H`88@P0336<8@PQ200<<H`03248<H`aS00@<H`0348@<H`aS008<
H`<@Q08<H`0348@DYABU008HaP057>LHaQ2436<@Q00236<248@01PaS248@
Q1245:D@Q088@P<<H`0348@<H`aS00<<H`0348@DYA24008@Q08<H`0348@<
HaBU008@Q0<<H`0648@<Ha2436<@Q0aS0a2400<<Ha245:D00QBU00<@Q0aS
36<00a240`aS0Q2400@<Ha245:D@Q0D<H`0348@DYABU008DY@8@Q00436<@
Q12448@236<00aBU48@@Q00448@236<848@011BU6<HDYA240`aS0Q2400<D
YAS65:D01A2400L<Ha2448@@Q0aS48@<H`0348@00`aS48@<H`0548@010aS
48@DYAS60QBU0Q240QBU10aS0a240QS600@LiaS65:DDY@8@Q0D<H`88@P05
1248@PQ2248<H`05248236<011242488@P@Q0`Q200@<H`Q212448@88@P<<
H`0548@<HaBU6<HLi`036<H00bDY:DXe[@02>Lh4@Q0023g_@Q16<Cg_BU9F
]DYB?Nl28@P00acW6<HDY@0448@25:D948@00aBU48@<H`0236<011245:DD
YA240PaS1A240aBU0a240aBU00DHaQBU6<HHaR48008U:@8Q20046<HDY@aS
36<248@00aBU48@<H`0248@336<248@236<248@00aBU36<<H`0236<00a24
36<<H`0448@236<011245:DDYA2420aS00<@Q0aS36<00PaS00<@Q0aS36<0
10aS0PQ20PaS00<@Q0aS36<00PaS0PQ210aS0PQ21@aS00<8@PaS36<02`aS
00<8@PaS36<00PQ200@<Ha2448@<H`@8@P@<H`09248<H`aS36<@Q0aS48@<
H`Q200@<H`0348@<H`aS008<H`05248<H`aS48@<H`02248236<01@Q236<<
H`aS48@00`aS00<8@PaS36<00PaS10Q200@<H`Q2248<H`88@P0336<8@PaS
0088@P04124<H`aS36<3248010aS2488@PQ20PaS0PQ20`aS00<8@PaS36<0
1@aS0Q240`Q210aS0`Q200<<H`Q224800PQ200<<H`Q236<00PQ20PaS10Q2
00<<H`Q2248010Q21@aS00D48@Q22488@PaS0088@P0436<8@PaS248536<0
0`Q236<<H`011240000500048@001240000512401`001248@QBU48@<Ha24
008<H`03248<H`aS008<H`88@P0436<@Q12448@236<00`Q236<<H`0936<0
1Q2436<<H`Q21248@P<<H`88@PD<H`88@P0636<8@PaS36<@Q0aS0`Q200<<
H`Q236<01PaS0`Q210aS0PQ200@<Ha2436<<H`8@Q0@<H`<@Q0<<H`H@Q08D
Y@046<HDYABU36<248@00aBU48@@Q00236<00a2436<<H`0336<00a2436<<
H`0236<00a2436<@Q00448@010aS5:D@Q1BU1A240PaS112400@<Ha2448@<
H`8@Q0035:D@Q12400@@Q00336<@Q0aS00<@Q0@DY@0336<@Q12400h@Q08<
H`<@Q00336<@Q0aS00<@Q08<H`8@Q0036<HDYABU00P@Q0045:D@Q12448@2
36<01Q2436<@Q0aS48@<H`<@Q00436<8@PaS36<348@236<00`Q248@DY@02
6<H35:D01A2436<<Ha246<H011BU0Q2400@<Ha2448@@Q088@P<48@<<H`03
24848@Q200D48@<8@P061248@PaS36<8@PaS0PQ200<48@Q2248010@Q1PQ2
00@<H`Q236<8@PD<H`8@Q00>5:DHaR48:DX]JcW>@Q16<D8@>LhmkcW>?Nli
cP8aS006=JdicSF];F/LiaS60Q2400@DYA245:DDY@<@Q00736<@Q12448@D
YA245:D011240`aS11240`aS00@DYA245:D@Q08DY@<@Q0HDY@<HaP035:DH
aQcW008HaP0348@DYA2400<<H`0348@<H`aS00@<H`0448@<Ha2448@336<0
112436<@Q1BU0Q240PQ20PaS0Q240`aS00@@Q0aS48@@Q0d<H`06248<H`Q2
36<8@PaS0PQ210aS00<8@PaS36<00Q2400D<Ha2436<@Q0aS0088@P0436<@
Q0aS248236<00a2436<<H`0436<010Q236<<Ha240PaS0PQ23@aS0Q241@aS
00D@Q0aS36<<H`Q200@<H`06248<H`aS48@<H`Q21@aS00<@Q0aS48@00PQ2
00@<Ha2436<<H`88@P0336<8@PQ20088@P@<H`08248<H`aS36<8@PaS248<
H`D8@P<<H`88@P0336<@Q0aS008<H`0548@<H`aS36<8@P0436<020Q236<8
@PQ236<8@PaS248336<424800`aS2488@P0336<224800`aS2488@P022480
1@aS1248@PQ236<00PQ20PaS00H8@PaS248@Q0aS248236<0112436<48@Q2
0PaS10Q2000812401`0012448@@Q36<DYA24008<H`0348@<H`aS008<H`03
248<H`aS00<<H`@@Q00524848@Q236<@Q00536<2248336<2248236<01Q24
36<<H`aS248@Q08<H`<8@P0336<8@PaS00H<H`06248<H`aS248<H`Q22@aS
00<8@PaS36<00PaS00<8@PaS36<00a241PaS1A240PaS00L@Q1S66<H@Q1BU
48@<H`0648@236<00a245:D@Q00448@736<848@00aBU48@@Q00436<348@2
5:D548@236<00a245:D@Q00436<548@00aBU48@@Q00336<648@00`aS48@@
Q00248@336<848@236<00a2436<@Q00348@45:D648@00`aS48@@Q0025:D0
1PaS48@@Q12436<@Q0D<H`0348@<H`aS008<H`8@Q00636<8@Q246<HLiaBU
0Q240PaS00<@Q1BU6<H00a240QBU00<@Q0aS24800PQ200<<H`Q2248010Q2
20@Q00@8@P@Q24848@H8@P0336<8@P@Q00<8@P848@<8@P031248@PQ20088
@P<<H`0324848@@Q008<H`8@Q08HaP057>LU:Be[?Nm24002AS400cg_>Lhi
cP02?Nl023F]<H`icSg_=JdYBQS65:D248@021BU6<H@Q12436<@Q1BU48@2
36<25:D248@00aBU48@DY@0348@00`aS48@@Q00348@010aS48@@Q1240aBU
00H@Q1BU48@DYA245:D248@011BU6<HLiacW0QS600<DYAS66<H00QBU00<@
Q1BU48@01PaS00<@Q1BU48@00PaS00<@Q0aS48@00Q2400@<Ha2448@<H`8@
Q0D<H`8@Q08<H`03248<Ha24008<H`8@Q08<H`8@Q00336<8@PaS00<<H`88
@P8<H`0448@<H`aS36<224800`aS248<H`0936<010Q236<<Ha240PaS00<8
@PaS36<00PQ21PaS00<8@PaS36<00`aS0PQ200D<Ha2436<@Q0aS0088@P03
36<@Q12400D<H`<8@P8<H`05248<Ha2448@<H`0224800`aS48@@Q00336<0
0a2436<8@P0224800`aS48@<H`0236<324800`aS248<H`05248336<22484
36<00`Q236<8@P07248336<2248536<00`Q236<<H`0236<2248010aS248<
H`Q20`aS0PQ20`aS0PQ200H<H`Q236<<H`Q236<4248436<01P@Q2488@PQ2
36<@Q08<H`08248<H`Q236<8@PaS248<H`<8@P8<H`88@P8<H`48@P448@00
00L000@Q00048@001240000212401`0012448@aS5:D@Q0Q200X<H`045:D@
Q1245:D236<00`Q236<<H`0236<01@Q2124<Ha2436<010Q200<<H`Q22480
0PQ210aS00@@Q0aS36<8@P@<H`08248<H`aS48@DYA2436<8@P8<H`0448@<
H`Q2248336<00`Q236<8@P02248236<01PQ236<<H`aS248<H`8@Q0035:D<
H`aS00<<H`0748@<H`aS36<@Q1BU48@00PaS0Q2400D<Ha2448@HaQcW00<D
Y@0548@<H`aS36<@Q00436<248@436<00aBU48@@Q00248@236<248@00aBU
48@DY@0236<00a2436<@Q00;48@00`aS48@<H`0648@336<00a245:D@Q002
48@236<00a2436<@Q00448@336<548@236<448@336<248@336<01A245:DH
aQ245:D00Q2400<DYA2448@00a2400<DYA2448@00PaS0a240QBU0Q2400<<
Ha2436<00PaS00<@Q0aS48@00PaS00<@Q0aS48@00a2400HDYA2436<<Ha24
5:D236<3248336<4248236<3248010@Q2488@P@Q0PQ21@@Q00D8@P@Q2488
@P@Q0088@P8<H`@8@P051248@PQ224848@032483124324800`aS2488@P02
36<3248236<00`Q236<<H`0236<01AS68@PaS36<>Lh00cg_00DicSg_@Q0m
kcW>008e[@07>Lhe[BDY8@PDYA245:D00Q240PaS00<@Q1BU5:D00`aS00DD
YA2448@@Q0aS008@Q0<<H`8@Q00436<@Q1245:D236<248@00aBU48@@Q005
5:D448@25:D011cW6<HHaQS60QBU00<HaQBU5:D00Q2400@DYA2448@DY@8@
Q00536<@Q12436<@Q00236<248@836<248@236<248@336<348@336<00a24
2488@P0336<2248336<00`Q236<@Q00236<2248336<224800`aS48@<H`02
36<448@010aS48@@Q1241PaS00<@Q0aS48@00PaS00<@Q0aS48@010aS00@@
Q0aS36<<H`8@Q0<<H`05248<H`aS36<@Q00?36<01A242488@PQ236<00Q24
0`aS00<@Q0aS36<010aS00@8@PaS36<<H`<8@P8<H`88@P0436<8@PQ22482
36<324800`aS2488@P0236<010Q236<<H`Q210aS0PQ200<<H`Q236<00PQ2
0`aS10Q20`aS00@8@PaS36<<H`<8@P0736<8@PQ236<8@PaS24800PaS10Q2
00<<H`Q224800`Q210aS00@@Q0Q22488@P<<H`88@PD<H`88@P448@0030@Q
00<<HaS648@00PQ20PaS00<@Q0aS36<010aS0Q2400TDYA2436<@Q0aS248<
H`Q236<00Q2400<<H`Q2248010aS0`Q22@aS00D8@PaS36<<H`Q2008<H`8@
Q00536<@Q0Q236<8@P0436<00`Q236<8@P0636<00`Q236<<H`0436<02124
5:DDYA2436<8@PaS248336<348@536<548@26<H25:D00`aS48@<H`0336<0
112436<<H`aS0Q240PaS0a2400<<Ha2436<00Q2400<<Ha2448@00a2400HD
YA2448@<H`Q236<348@00`aS48@@Q00248@00aBU48@8@P0236<248@01@aS
48@@Q0aS48@00PaS00D@Q1BU5:D@Q0aS008@Q0<<H`D@Q08<H`0348@<Ha24
00<@Q08<H`<@Q0<<H`8DY@0348@<Ha2400<DY@0348@DYA24008DY@<@Q005
5:D@Q12448@<H`0248@01`aS48@@Q1BU48@8@PaS008@Q00336<8@PQ200<@
Q00336<8@PaS008@Q00336<@Q1BU00H@Q0D8@P0336<8@PaS0088@P8<H`D8
@P031248@PQ200848@0324848@@Q00@48@0324848@@Q00@8@P031248@P@Q
0088@P051248@P@Q24848@0224841242248212400`Q21248@P03248436<2
48@00`aS5:DLi`02<H`00cF]?Nm24002>Lh2@Q0023g_<H`e[CF]>LhaS2DY
8@P35:D748@00`aS48@DY@0248@236<548@00`aS48@8@P0436<011245:DD
YABU1A2400DDYA2436<@Q1BU00@@Q0<HaP8DY@<HaPL@Q0055:D@Q12436<@
Q00236<348@236<00a2436<@Q00736<01a2436<<H`aS48@<Ha2400P<H`03
248<H`aS00@<H`03248<H`aS00H<H`06124<Ha245:D<H`Q20PaS00L8@PaS
48@DYA2436<8@P0436<010Q236<<Ha240PaS0PQ220aS00<@Q0aS36<010aS
00<8@PaS48@010aS00<@Q0aS36<010aS00@@Q0aS2488@P8@Q00436<8@PQ2
248;36<3248336<00`Q236<<H`0236<2248436<2248236<4248536<22483
36<00`Q236<<H`04248236<0112436<8@PaS1PQ21@aS0`Q200@<H`Q236<<
H`88@P<<H`88@P0336<8@PQ200@<H`88@P@<H`03248<H`aS00<8@P8<H`04
248<H`Q248@236<12480000700048@00124000@Q00000`@Q00D000@Q248D
YA2400D<H`03248<Ha24008HaP045:D@Q1BU6<H25:D00a242488@P022484
36<00`Q236<<H`03248:36<2248448@00`aS2488@P0336<010Q236<<H`aS
0`Q200@<Ha2436<<H`88@P8<H`03248<H`aS0088@P8<H`0448@<H`aS48@2
36<01@Q236<<H`aS24800PaS00<@Q0aS36<020aS112400@DYA246<HDY@8@
Q0D<H`8@Q00336<@Q0aS00<@Q08<H`<@Q0075:D@Q12448@<Ha2436<01A24
00@<Ha2448@@Q0@<H`<@Q08<H`@@Q00436<@Q12448@536<348@011BU48@D
YA240PaS0Q2400@DYA2436<DY@<@Q08DY@0548@<HaBU5:D@Q00336<248@3
36<00a245:DDY@0348@00`aS48@@Q00448@01@aS48@<Ha2436<01A2410aS
00@@Q0aS48@<H`88@P8<H`0548@DYABU6<H@Q00236<010Q236<8@PQ20`@Q
00<8@PaS24800`Q20Q2400D<Ha2436<<Ha240088@P051248@PQ21248@P04
12432482124324800`@Q24848@02124324800`@Q2488@P04124224841242
2484124224800`aS2488@P0624801PaS48@Lib48;F/mk`96<@06?Nle[CW>
;F/YBRe[0cW>00@Q21BU48@@Q08DY@0536<@Q1BU5:D@Q00436<348@010aS
48@<H`aS0a2410aS1A2400<DYA2448@00Q2411BU0a2400<DYA2448@00a24
00<HaQcW7>L00QS600<LiaS66<H0112400DDY@aS36<8@PaS008@Q00536<@
Q12436<@Q00436<248@00`aS48@<H`0236<348@00`aS48@@Q00248@010aS
248<H`Q20Q240PaS00@8@PaS36<<H`@8@PD<H`8@Q0L<H`0448@<H`aS2482
36<00a2436<<H`0236<01PQ236<<Ha2436<8@P8<H`8@Q00436<8@PQ236<3
48@436<00`Q2124<H`0336<00`Q236<<H`02248636<248@936<224800`aS
48@<H`0536<01`Q236<<H`aS248<H`Q200<<H`03248<H`aS00@<H`082484
8@Q2248<H`Q21248@P8<H`051248@PaS48@<H`03248236<00`Q236<8@P05
36<224800`aS1248@P0236<01@Q21248@PaS48@010aS0`Q20PaS0`Q200@<
H`Q224848@88@PH<H`P8@P8<H`0348@<H`Q20088@P002@@Q00H000@Q1248
@QBU48@236<00`Q236<@Q00236<00a246<HHaP045:D01AS65:D<H`@Q2480
0PaS00<@Q0aS36<01PaS0PQ20`aS00<@Q0aS36<00PaS00<8@PaS24800Q24
0PaS0PQ20Q240`aS00<8@PaS36<00PaS0`Q20`aS00@@Q0aS248<H`88@P@<
H`07248<H`aS36<@Q0aS48@00PaS0PQ200<<H`Q236<00PaS00@8@PaS36<@
Q0D<H`@@Q0<DY@0548@<H`aS36<@Q00436<00aBU48@<H`0236<348@010Q2
36<DYA240QBU00<@Q0aS36<00PaS00D@Q0aS48@@Q1BU00D@Q00336<@Q0aS
00H@Q0055:D<Ha2448@DY@0248@336<348@01@aS48@@Q12436<01A240QBU
0Q2400D<Ha2448@DYA2400<DY@0548@<H`aS48@DY@0236<01Q245:DDYABU
48@DY@8<H`0348@DYABU008<H`8@Q08<H`0648@DYABU48@<Ha240`aS00<@
Q0aS48@00Q240PaS00D@Q0aS36<8@PaS008HaP045:D@Q0aS36<2248010@Q
24848@@Q0PQ200@<H`@Q1248@P8@Q0<<H`8@Q088@P<48@88@P061248@P@Q
24848@Q20P@Q0PQ20`@Q00D8@P@Q2488@P@Q0088@P@48@<8@P848@032484
8@Q200@48@<8@P051248@PQ224848@03248236<2248236<011cW8@P]Jcg_
0T8@0SW>00@mkc6<:DX]J`<icP057>LHaQBU48@HaP0448@25:D336<01124
5:D@Q0aS0Q240PaS00D@Q0aS48@@Q0aS00L@Q00536<@Q12448@DY@0248@0
0aBU48@DY@025:D348@25:D00a246<HLi`027>L01AS67>LHaQS65:D00Q24
00<<Ha2448@011241`aS00H@Q0Q236<<H`Q248@236<01a2436<<Ha2436<@
Q0Q200@<H`0748@<H`aS48@DYA2436<00PQ22`aS0Q240PaS00D8@PaS48@@
Q1BU00<<H`0448@<H`aS248236<00a2436<<H`0224800a2436<<H`0336<0
0a2436<<H`0224800`aS48@<H`0736<248@2248336<00`Q236<@Q00248@6
36<01@Q236<<H`aS24801PaS0Q240PaS0`Q20PaS00<8@PaS24800`Q20PaS
0`Q200<<H`Q224800`Q20PaS1`Q21`aS10Q200D<H`Q236<<H`Q2008<H`03
248<H`Q200@8@P<<H`<8@P0536<8@PQ2248<H`03248236<3248736<22480
1@@Q248<H`Q236<00PQ20`aS00<8@PaS36<00@Q200001@00124000@Q0000
0`@Q00X000@Q12448@aS5:D<H`@Q36<@Q0@<H`035:DHaQcW008DY@036<HD
YABU00<<H`88@P0336<8@PaS00<<H`<8@P0336<8@PQ20088@P8<H`8@Q004
36<8@PaS36<348@236<2248010aS48@@Q0aS0`Q210aS00@8@PaS36<<H`88
@P0436<8@PaS248236<00a24248<H`0236<01A2436<8@PQ236<00PQ20`aS
0`Q20`aS00@8@PaS36<@Q0@<H`0348@<Ha24008@Q0035:D@Q124008@Q0P<
H`8@Q00636<@Q1245:D@Q0aS112400H<Ha2436<<Ha2436<248@536<348@2
36<011BU48@<H`aS0Q240PaS00<DYAS65:D00PaS00<@Q1BU48@00PaS00@D
YAS65:D@Q08<H`8DY@8<H`8@Q08<H`045:DHaQBU48@25:D01A245:D8@PaS
48@00QBU00H@Q0aS48@DYA2436<248@00aBU48@@Q00336<348@436<01@Q2
36<<H`aS48@00`aS00<@Q0aS36<00PaS00@@Q0aS48@DY@8@Q00336<8@PQ2
0088@P<48@<8@P061248@PQ21248@P@Q0PQ200@@Q0aS48@@Q08HaP035:D<
H`Q200<48@88@P031248@PQ200848@88@P8<H`88@PD48@0424848@@Q2486
124224800`@Q24848@041242248010@Q24848@@Q1@Q20P@Q00<8@P@Q2480
0PQ20`aS00<@Q1cW9BT00Sg_00]6<D8@=JdicSF]<H`icSg_>LhaS248008D
Y@@@Q0@<H`<@Q00536<@Q12448@<H`0248@01@aS48@@Q12436<011241PaS
1A2400HDYA2448@<Ha2436<348@01ABU48@HaQBU7>L00QS60QBU00@HaQBU
6<H@Q08DY@<@Q00336<@Q0aS00H<H`0348@<H`aS008<H`0448@DYA245:D5
36<01A2436<<H`aS48@01PaS00H8@PaS36<@Q0aS248336<00a2436<@Q005
36<00a2436<<H`02248236<00`Q236<<H`0336<00`Q236<<H`0436<248@3
36<01A2436<8@PaS48@00PaS00<8@PaS36<00PaS00@8@PaS48@@Q0D<H`8@
Q0<<H`03248<H`aS008<H`07248<H`aS36<8@PaS24800`aS00H@Q1BU36<<
H`@Q248236<020Q236<8@PaS248<H`Q236<524801@aS2488@PQ236<00PQ2
0P@Q00@8@PaS48@<H`88@P0536<8@PaS36<8@P0336<324801A2436<8@PaS
24800PaS00<8@PaS36<00PaS10Q200T<H`Q236<8@PaS248<H`Q236<00PQ2
0PaS00<48@Q224802PaS00D8@PaS36<8@PaS00@8@P@<H`001@@Q00<000@Q
12400P@Q00@000@Q36<DY@<<H`0>48@<H`aS248@Q1S67>LHaQBU48@DYAS6
5:D@Q08<H`<8@P<<H`88@P0336<8@PaS00<8@P0536<8@PaS36<@Q00436<0
112436<<Ha242PaS10Q20`aS0`Q20`aS00H8@PaS36<<H`Q236<2248536<2
248836<2248336<010Q236<@Q1240PaS0Q2400H<Ha245:DHaQBU36<22480
10aS48@@Q0aS0a240PaS00<@Q0aS36<00PaS11240`aS00D@Q0aS36<<Ha24
00<<H`0448@<H`aS36<E48@01PaS48@@Q1BU48@<H`<@Q00336<@Q12400P@
Q08DY@0336<@Q124008@Q0<<H`8@Q0035:D@Q124008@Q0045:D@Q0aS36<2
48@336<248@236<2248248@636<248@00`aS48@DY@0248@00`aS2488@P02
248212432484124324800`@Q2488@P0236<348@00aS65:D<H`0312432480
0`aS12448@02124224801@aS2488@P@Q24800`@Q0`Q200<48@Q212400`@Q
0PQ210@Q0PQ20P@Q0PQ20`@Q00D8@PaS2488@P@Q00@8@P848@03248<H`aS
0088@P0936<DYAS68@PicT8@BU9243F]008icP06<H`e[D8@@Q0aS2481124
0QBU00@@Q0aS36<<H`D@Q0<<H`8@Q0035:D@Q12400@@Q0045:D<H`aS36<2
48@236<548@25:D348@236<548@00aBU6<HLi`026<H25:D00aS65:DDY@04
48@536<01A2436<<H`Q236<00Q2410aS0Q240PaS0PQ200@<Ha2436<@Q0<<
H`8@Q00436<8@PaS36<248@236<01`Q2124<H`aS5:D@Q0Q200<<H`0548@<
H`aS36<@Q00?36<01@Q236<<H`aS48@00PaS00<@Q0aS24800PaS0Q2410aS
0PQ21@aS00D@Q0aS36<<Ha2400@<H`0348@<H`aS0088@P0536<@Q0aS36<8
@P0236<00`Q236<<H`0248@336<324801@aS248<H`Q236<00`Q20`aS0`Q2
0PaS0`Q20PaS0PQ200<<H`Q224800`Q200@<H`Q2248<H`<8@P08124<H`aS
248<H`Q236<@Q0@8@P@<H`@8@P@<H`88@P8<H`08248<H`Q2248<H`Q236<8
@P8<H`88@P8<H`0324848@Q200H<H`03248<H`aS00<<H`48@P0000<000@Q
00000`@Q00<000@Q12400`@Q00H<HaBU36<8@PaS48@336<348@26<H01QBU
36<8@PaS48@<H`88@P0336<8@PaS00<8@P0436<8@PaS36<2248236<22484
36<348@00aBU48@<H`0224800`aS248<H`0336<2248336<3248236<00`Q2
36<8@P0336<2248636<00a2436<<H`0436<324800`aS48@@Q00236<00`Q2
36<@Q00348@236<00`Q248@@Q0025:D336<25:D336<248@336<248@01PaS
48@@Q0aS48@<H`D@Q0<<H`8@Q0035:D<H`aS008<H`<DY@D@Q00336<@Q0aS
00D@Q00436<@Q12448@25:D448@55:D011245:D@Q1BU0PaS0a2400<DYA24
48@00Q2400<DYA2448@00PaS0Q2400<DYA2436<0112400HDYA2436<@Q0aS
48@936<00`Q236<<H`0336<00a2436<8@P0236<00a245:DDY@0336<00`@Q
24848@03248236<010@Q24848@@Q0PQ200<@Q0aS36<010@Q0PQ200H@Q1BU
5:DDY@aS248212400`Q21248@P04248010@Q2488@PQ20PaS0a2400@<H`Q2
124000848@0324848@@Q00<48@H8@PD48@88@PD48@88@P0336<8@PQ200<4
8@03248<H`Q200<48@8<H`88@P0448@Q22DY?Nl2BU802THa=Je244YBAS4m
kcF];F/Q21cW112400H<Ha2436<<H`Q236<348@236<00a2436<@Q00248@2
36<348@536<00aBU48@@Q00436<01a245:D<H`aS48@DYA2400<<H`045:D@
Q1245:D348@021BU6<H@Q0aS48@HaQcW6<H25:D348@02PaS48@<H`aS48@<
Ha2436<@Q0aS0a2400@<H`Q236<@Q0L<H`0348@<H`aS00X<H`0348@<H`aS
00<<H`0348@<H`aS00@<H`0348@<H`aS008<H`0348@<H`aS00D<H`8@Q0P<
H`0348@<H`aS00@<H`0348@<H`Q2008<H`0548@<H`aS48@<H`0248@010aS
2488@PaS0Q240PaS00<8@PaS36<00PQ200@<Ha2448@<H`@8@P0336<8@Q24
008@Q0D<H`<8@P0336<@Q0aS0088@P<<H`88@P0436<8@P@Q248236<22480
10@Q2488@PaS0`Q200<@Q0Q224801@Q200@<Ha2436<<H`88@P8<H`03248<
H`Q200<<H`<8@P05124<H`aS36<8@P0236<00`Q236<<H`0224800`@Q248<
H`0936<2248236<3248010aS2488@PaS10Q2000412401@0012448@@Q0000
0`@Q00H<HaS648@8@PaS248336<00a245:DDY@025:D248@936<010Q236<<
H`Q20PaS1@Q200D<Ha2436<<H`Q2008<H`8@Q0D<H`03248<H`Q200P<H`88
@P@<H`04248<H`aS48@336<2248336<248@236<2248236<00`Q236<8@P02
36<248@436<00a2436<<H`0336<448@01PaS248<Ha245:D@Q08<H`8@Q003
248<Ha24008DY@0448@<H`aS36<348@010aS48@@Q1240PaS00@@Q0aS5:D@
Q0<<H`<@Q00336<@Q1BU008@Q08<H`<@Q08<H`8@Q0035:D@Q124008@Q005
5:D@Q12448@<H`025:D26<H25:D748@45:D00a245:D@Q00248@010aS48@@
Q1240PaS0Q2400@DYA2448@@Q08DY@8<H`8@Q0@<H`0:48@<Ha2436<8@PaS
248<HaBU48@424802ABU48@@Q1BU48@<H`@Q24848@0224801`aS2488@P@Q
248<H`Q200848@05248<Ha2436<8@P03124224801A245:DDYA2436<00PQ2
0P@Q10Q20`@Q0`Q200H<Ha2448@@Q0aS248412400`Q212448@0212400`Q2
12448@0324821242248312400`Q21248@P02248010@Q24848@Q20P@Q10Q2
00<48@Q224800P@Q00H8@PaS36<8@PaS48@28@P0148@CW=:DT8@0SW>00M:
DTHa?Nle[C6<8@PLi`0348@010aS48@@Q12410aS00@DYA245:D@Q0<<H`8@
Q0<<H`0348@<Ha24008<H`0448@<H`aS48@236<348@236<248@436<01124
5:D@Q1240PaS0Q241aBU00<HaQBU6<H00QBU00D@Q0aS36<<H`Q200<<H`04
48@<Ha245:D248@;36<01A2436<<Ha2436<00`Q200<@Q1BU36<01@aS00D8
@PaS48@DYA24008<H`0348@<H`aS008<H`8@Q08<H`07248<H`aS36<@Q0aS
48@01PaS1A2400@<H`Q236<@Q0H<H`04248<H`aS48@>36<01A2436<<H`Q2
36<00Q240`aS0`Q20PaS00<@Q0aS48@00`aS00@8@PaS248<H`88@P<<H`08
5:D<H`Q224848@aS248<H`88@P8<H`04248<H`aS36<324801PaS248<H`aS
24848@88@P0336<8@PQ200@<H`04248<H`aS248536<2248336<010Q236<8
@PQ210aS1@Q21@aS0`Q20PaS00H8@PaS1248@PaS248236<010@Q2488@PaS
0@Q200000`0012448@0212401@0012448@@Q00000P@Q00@<HaBU48@<H`8@
Q0D<H`0348@<H`aS00H<H`03248<H`aS00<<H`D8@P8<H`03248<H`Q2008<
H`0648@<Ha2448@<H`Q21`aS00<8@PaS36<010aS0`Q20`aS00<@Q0aS2480
0PQ200D@Q0aS48@<Ha2400@<H`0348@<H`aS008@Q088@P05124<Ha2436<@
Q00336<248@01@aS248<H`aS48@00`aS1A240`aS00D8@Q2448@@Q0aS008@
Q0035:D@Q0aS008<H`065:D@Q12448@DY@aS0a2400<DYA2448@00PaS00<@
Q0aS48@00Q2400<<Ha245:D00Q240PaS112400<<Ha2448@00QBU00<@Q1BU
5:D00QBU00H<HaBU5:DDYA2436<248@25:D248@011BU6<HDY@aS0a240PaS
00<@Q1BU5:D00Q240QBU00@HaQ2448@<H`8@Q00336<@Q124008@Q0065:D@
Q1BU48@DYA240`aS0Q241@aS00@@Q0aS36<<H`88@P0536<@Q12448@<H`04
24800`@Q24848@0624801`@Q2488@PaS24848@Q200@48@88@P091248@PQ2
36<8@PaS48@<H`Q200848@@8@P041248@PQ22485124336<424801@@Q0004
8@@Q24800P@Q00<8@P@Q12400`@Q00H8@P@Q1248@P@Q248412400`Q21244
8@03124224801P@Q2488@PaS24848@<8@P031248@PQ2008<H`88@P0748@H
aSW>@Q1:DTic@Q000Sg_0SW>00A6<DYB=JdU:@8<H`@@Q00536<@Q12448@<
H`0548@336<00a2436<@Q00348@636<01a2436<<Ha2436<@Q0aS00H@Q005
36<DYA245:D@Q00236<0112436<<H`aS0Q2400D<Ha245:D@Q1BU008@Q003
5:D@Q12400@@Q00536<@Q12448@DY@0236<00a245:D<H`0236<248@436<0
112436<@Q0Q20PaS00<8@PaS36<00Q240PQ200<<Ha2436<02@aS00@@Q0aS
36<8@P8<H`8@Q0P<H`0448@<H`aS36<348@00`Q236<@Q00<36<348@436<0
1Q2436<<Ha2436<@Q08<H`<8@P0536<@Q0aS36<8@P0336<324801@aS48@<
H`aS248010aS10Q20PaS0PQ20`aS0`Q200D<H`Q22488@PaS0088@P8<H`03
24848@Q2008<H`03248<H`aS0088@P0536<@Q12436<8@P0436<2248010@Q
36<<H`aS0PQ20`aS00<@Q0aS24800PQ20PaS00T8@PaS248<H`Q236<8@PaS
24800PaS0PQ200<<H`Q224800PaS00@8@PaS2488@P@<H`88@P448@48@P00
00@48@00124000H48@0700048@aS6<H@Q0aS48@00PaS00D8@PaS48@<H`Q2
008<H`0548@<H`aS36<8@P0236<01@Q236<@Q12436<00`Q21@aS00L48@Q2
36<@Q0aS248<H`0248@236<00a2436<<H`0936<2248336<010Q236<<H`aS
0`Q20`aS00<@Q0aS36<00PaS0Q241`aS00D8@PaS36<<H`Q200<<H`0348@<
Ha24008<H`0348@<Ha2400H@Q08<H`03248<Ha24008<H`D@Q08DY@0336<8
@Q24008@Q00336<@Q124008@Q0@<H`D@Q08<H`<@Q08<H`@@Q00336<@Q0aS
008@Q08DY@<@Q00336<@Q124008DY@<@Q08DY@@@Q0<DY@0548@<H`aS36<@
Q0035:D348@00aBU48@DY@0248@236<248@011BU48@@Q0aS0a240PaS0Q24
00@<Ha245:D@Q08<H`8@Q08<H`03248<H`Q2008<H`03248@Q124008<H`03
24848@Q200<8@P<48@0324848@Q200<8@P848@88@P0336<8@P@Q00<48@05
24848@Q236<@Q00236<4248312401PaS1248@PaS1248@P848@88@P<<H`H8
@P@48@H8@P<48@<8@P@48@0324848@Q200L48@<8@P0336<8@P@Q00848@<8
@P0?1248@PQ2124@Q1BU=Je244HaBU8mkd8@AS4mkcW>00924003<H`U:@aS
008@Q0<<H`055:D@Q12436<@Q00236<348@236<248@25:D248@00`aS48@@
Q00248@236<00`Q236<<H`0548@336<648@00aBU48@<H`02248236<348@2
36<248@25:D011245:D@Q0aS0a2400@DYA2448@DY@8@Q08DY@0548@<H`aS
248<H`0248@336<248@00`Q236<<H`0736<00a2436<<H`0348@00`aS48@<
H`0336<248@00`aS2488@P0236<248@010aS48@<H`Q20`aS00<@Q0aS48@0
0PaS00@@Q0aS36<@Q0D<H`8@Q0D<H`0348@<Ha2400<@Q08<H`0348@<H`aS
00L<H`03248<H`aS008<H`88@P8<H`04248<H`aS48@236<00a2436<<H`03
36<3248236<2248936<324800`@Q248<H`02248336<010@Q248<H`Q20PaS
0`Q20`aS0PQ20`aS00<8@PaS24800PaS0PQ200@<H`Q248@<H`<8@P<<H`88
@P0436<8@PQ2248236<0112436<8@PaS0`Q200@@Q0aS12448@<<H`<8@P8<
H`88@P448@0010@Q00D000@Q12448@0000<48@0336<DYA24008<H`0448@<
Ha2448@536<00a2436<<H`0236<00`Q236<<H`0236<248@236<3248336<2
248010aS48@<H`Q20`aS0PQ200<<Ha2436<01PaS00<@Q0aS36<00PaS00<8
@PaS36<00`Q20PaS00<8@PaS36<01`aS00@@Q0aS36<<H`8@Q00336<8@PQ2
00D<H`8@Q0035:D@Q0aS00H<H`0348@<Ha24008DY@0348@<H`aS00H<H`@@
Q0045:D<Ha2436<248@336<00a245:DDY@0248@00`aS48@@Q0025:D248@0
10aS48@@Q1BU0PaS00@8@PaS36<<H`<@Q00436<@Q12448@25:D011245:D@
Q1BU0Q2400@<Ha2448@HaP<DY@0348@DYAS6008HaP045:D@Q1245:D348@0
1QBU48@DYA245:D@Q08DY@8@Q0035:D@Q0aS00@@Q00436<@Q12448@636<3
48@736<248@00`aS2488@P0424800`aS2488@P02124724800`@Q2488@P02
12432482124224800`@Q36<8@P0524801@@Q2488@PQ212400PQ200<<H`Q2
124020@Q00@8@PaS36<8@P848@0424848@@Q1243248712400`Q212448@05
12401@Q212448@@Q248010@Q00<8@P@Q12400`Q200<48@Q224800`Q20P@Q
0`Q200/<H`Q25:DLibe[@Q16<DYB?NlicSF]00924003<H`]JaBU008DY@03
48@DYABU00<@Q00336<@Q0aS008<H`@@Q08<H`0348@<H`aS00<<H`8@Q0<<
H`8@Q00<5:D@Q0aS248<Ha245:D<Ha2436<@Q1BU0Q2410aS0a240`aS0a24
0PaS00D@Q0aS48@<Ha2400<DY@0948@HaQS68@PLiaS67>LHaQ24008<H`03
48@<Ha24008<H`0348@<Ha2400<<H`8@Q0D<H`8@Q0T<H`8@Q08<H`0448@<
H`aS48@336<01A2436<<H`aS24800`aS0Q240PaS0Q241@aS0a241@aS00<@
Q0aS48@00Q2400<<Ha2448@00Q240PaS00H8@PaS36<<Ha24248236<00`Q2
36<<H`0248@736<010Q236<@Q1241@aS0PQ20PaS0Q240PaS0PQ21@aS1@Q2
10aS00<8@PaS24800PaS0PQ200H48@Q236<@Q0aS248236<010Q236<<Ha24
0PaS1@Q200<<H`Q224800PaS0PQ220aS0`Q210aS00<8@PaS24800`aS00@8
@PaS248<H`<8@P0336<8@PQ20048@P000P@Q00D000@Q12448@0000<48@07
00048@Q25:D@Q0aS48@010aS00<@Q0aS24801@aS00<@Q0aS36<00PQ20PaS
00@8@PaS36<<H`<8@Ph<H`8@Q0/<H`03248<H`aS00@8@P0436<8@PaS2482
36<248@336<01Q2436<@Q12436<@Q08<H`05248<H`aS36<8@P0236<00a24
5:D<H`0336<248@436<00a246<HDY@0248@010aS248<H`aS0Q240`aS00<@
Q0aS5:D00Q2400<<Ha2448@00`aS2a2400<DYA2436<00PaS0Q240PaS1a24
0PaS0Q240QBU00<@Q1BU5:D00QBU0Q2400<DYA2448@00QBU0Q2400HDYAS6
6<HDYA245:D248@011BU6<H@Q1BU112411BU0a2400<<Ha2448@00Q2400H<
Ha2436<@Q0Q236<348@:36<248@010Q212448@@Q0`aS0PQ200<48@Q21240
0`Q200@<H`Q236<48@@8@P@48@88@P051248@PQ236<8@P0236<224831240
0`Q21248@P021244248312400`0012448@05248010@Q2488@PQ210@Q00H8
@P@Q2488@P@Q000512400`Q21248@P0412401@Q212448@@Q248010@Q00<8
@P@Q12400`Q200<48@Q224800`@Q00T8@PaS2488@PaS5:DHaRe[?Nl00T8@
0SW>0cg_00<]JbDY5:D00aBU00<@Q1BU5:D00Q2410aS00<@Q0aS48@00Q24
10aS00@@Q0aS36<<H`8@Q0@<H`<@Q0@<H`D@Q0<<H`0348@<H`aS00<<H`04
248<H`aS48@336<248@01PaS48@@Q12436<@Q08DY@8HaP<Li`8HaP<DY@07
48@<Ha2448@<Ha2436<00Q240PaS00<@Q0aS36<00PaS00<8@PaS36<02`aS
0Q240PaS00<8@PaS48@01@aS00H@Q0aS2488@PaS48@336<00a2436<<H`02
36<00a2436<<H`0336<00a2436<<H`0236<248@236<348@236<01A2436<<
H`Q248@00PaS0PQ210aS00<8@PaS36<01PaS0PQ20PaS0Q240PaS0`Q210aS
00<8@PaS36<01@aS0PQ20`aS10Q200@<H`Q236<8@PD<H`<8@P@<H`03248<
H`aS00H<H`<8@P8<H`04248<H`aS248636<3248436<00`Q236<8@P052483
36<010Q236<<H`Q21@aS0@@Q00001P0012448@00124000H48@0436<@Q0aS
248248@236<00a2436<8@P02248536<2248010aS248<H`Q20PaS00<@Q0aS
36<00`aS00<8@PaS36<01@aS0PQ200D<Ha2448@<H`Q200H<H`0348@<H`aS
00D<H`05248<H`Q224848@02248736<00`Q236<@Q00448@011BU48@<H`Q2
0PaS00<@Q0aS36<02PaS0a240PaS00H@Q1BU48@@Q0aS248236<01A2436<<
H`aS48@01@aS112400<<Ha2436<00PaS00<@Q0aS48@00QBU0Q241`aS00P8
@PaS48@@Q1BU48@8@PaS0Q2400HDYA2448@<HaBU36<248@25:D248@25:D2
48@55:D01AS65:D@Q12436<00Q240QBU0QS600@DYA245:D@Q0<DY@0748@<
Ha2448@DYA2436<00Q2410aS0Q2400DDYA2448@@Q0aS0088@P0436<@Q124
48@2248010@Q2488@PQ20`@Q0PQ200@<H`@Q12448@D8@P0336<8@PQ200<4
8@H8@P<48@0436<8@PQ212432482124724801@@Q24848@@Q248010@Q00@8
@P@Q2488@P848@0400048@Q236<2248;12400`Q21248@P03248312422484
124224821244248010@Q2488@PQ20P@Q0`Q201<<Ha245:DHaQcW;F/e[DYB
CW<icRe[<H`mkdHa>LhQ21cW6<H@Q0025:D00a2436<@Q00548@336<00a24
36<<H`0448@00`aS48@@Q00236<348@236<01A2436<<H`aS5:D00Q2400D<
Ha2448@@Q0aS0088@P0436<@Q1BU48@836<00a2436<@Q00236<348@010aS
48@@Q1BU0QS600<LiaS65:D00QBU0aS600<DYA2448@00Q2400<DY@aS36<0
0PaS0a2400@<H`Q22488@P8@Q0L<H`03248@Q0aS00D<H`0348@<H`aS00<<
H`0348@<H`aS00D<H`D@Q0@<H`<@Q00336<8@PaS008@Q0<<H`0848@DYABU
48@<H`Q236<@Q0<<H`05248<H`aS36<8@P0936<00a2436<<H`0236<248@6
36<01PQ236<<H`aS248<H`88@P8<H`88@P0336<@Q0aS0088@P<<H`<8@P04
36<@Q0aS36<4248:36<4248236<2248010@Q36<<H`aS0`Q20PaS0PQ21PaS
00<8@PaS36<00`aS00<8@PaS36<00PaS00<8@PaS24800PaS00<8@PaS2480
0PaS0@Q200000`@Q00048@0612401@0012448@Q25:D00PaS0a240`aS00@8
@PaS2488@P8<H`<8@P<<H`03248<H`aS00@<H`<8@PP<H`07248<H`aS36<@
Q0aS24801`aS00P@Q0aS36<<H`Q236<8@PaS10Q200<<H`Q224802@aS0Q24
0QBU1PaS00<8@PaS24800`aS00@@Q0aS36<<H`8@Q0D<H`8@Q00436<@Q1BU
48@236<224801a2436<<H`aS48@<Ha2400<<H`@@Q08<H`8@Q00736<@Q124
48@<Ha245:D00Q241`aS00<@Q1BU48@00PaS112400<DYA245:D0112400<<
Ha2448@00aBU0PaS0aBU00<@Q1BU5:D00QBU00<<Ha2448@00QBU0Q2400PD
YAS65:D@Q1BU6<HDYA240PaS1A2400<<Ha2436<00`aS112400HDYA2436<8
@PaS248336<00`Q212448@021242248212400`Q236<8@P03124224800`aS
2488@P0324800`@Q24848@0212400`Q21248@P0524821245248312422483
1242248312400`Q21248@P031243248312400`Q212448@0512401@Q21244
8@@Q24800P@Q10Q20P@Q0PQ200<48@Q2124010@Q00<8@P@Q124010Q200L4
8@Q224848@Q21248@P03124030aS48@HaQS67>L]JcW>AS5243W><H`e[@92
4005?NlU:AcW6<H@Q0025:D248@011BU36<<H`aS0Q240PaS00@@Q1BU48@<
H`88@P0348@<Ha2400D<H`0448@<Ha2448@536<0112436<@Q1240PaS00<8
@PaS36<00Q2410aS0Q241@aS0Q2400H<Ha2436<<Ha2436<248@011BU6<HL
iaS60QBU0aS60QBU0a2400LDYA2436<@Q0aS48@<H`0248@00`aS248<H`03
36<248@00`aS248@Q00236<010Q236<<Ha2410aS0Q241@aS00<8@PaS36<0
1`aS00<@Q0aS24800PQ200P<Ha245:D<Ha24248<Ha240PaS00<8@PaS36<0
1A2410aS0PQ20PaS00D@Q0aS36<<Ha2400D<H`03248<H`aS008<H`06248<
H`aS36<@Q0Q20`aS00<@Q0aS24800PQ20PaS00H8@PaS248<H`Q236<22480
1PaS2488@PaS248<H`88@PD<H`@8@P8<H`08248<H`Q2248<H`Q236<8@P8<
H`D8@P<<H`@8@PL<H`<8@P<<H`03248<H`Q200H8@P0436<8@PaS248236<2
48@22481124000<48@0300048@0000848@0800048@@Q124<HaS648@8@P<<
H`0348@<H`Q200D<H`03248<H`Q200<<H`0548@8@PQ236<8@P0236<00`Q2
36<<H`0736<224801@aS48@<H`aS24801@aS0PQ210aS0PQ200<<H`Q22480
0`aS0PQ200<48@aS36<00`Q21@aS0a2410aS00<@Q0aS36<00PaS00<8@PaS
24801`aS0Q240`aS00@@Q0aS48@@Q0D<H`8@Q0L<H`0348@<H`aS008<H`07
48@<H`aS36<@Q0aS48@00PaS00D@Q1BU48@@Q0aS008@Q0<<H`0348@<H`aS
008<H`<@Q00336<@Q12400<@Q00436<@Q1BU5:D248@436<55:D248@36<H0
1ABU48@@Q1BU36<011BU0Q240QBU0QS600<DYA245:D00Q240QBU0Q240PaS
00<@Q0aS36<01Q240PaS00@8@PaS36<<H`<8@P061248@PQ224848@Q20P@Q
1@Q20`@Q00<8@PaS24800P@Q00<8@P@Q24800`@Q10Q21`@Q00<8@P@Q1240
10@Q00<8@P@Q12400PQ20P@Q00<8@P@Q124010Q200<48@Q224800P@Q0PQ2
0PaS00<8@P@Q248020@Q10Q20P@Q0PQ210@Q00@<H`@Q12448@88@P<48@03
24848@Q200<8@P848@0524848@Q21248@P0236<25:D04aS65:DHaR489BTi
cT8@>LhaS3F]AS5>LdYB:DXDYA24248@Q1BU008@Q08<H`8@Q0<<H`<@Q0<<
H`8@Q0075:D@Q0aS36<@Q1BU48@01@aS1A2400<<Ha2448@00PaS00D8@PaS
48@<H`Q2008<H`0448@<H`aS36<348@336<248@236<00a2436<8@P0236<0
212436<<H`aS48@DYAS65:D648@011BU48@@Q1240QBU0Q240PaS00D8@PaS
36<<Ha2400@<H`88@P0336<@Q0aS00H<H`0648@<H`aS248<Ha240PQ20PaS
00<@Q0aS48@00PaS00<8@PaS24800`aS00<8@PaS48@00Q2400<<Ha245:D0
0Q240PaS00<@Q0aS48@00Q2400<<H`Q224800PaS0PQ200D<Ha2436<<H`Q2
00<<H`04248<H`Q236<3248636<25:D00a2436<8@P0236<2248336<01@Q2
36<<H`aS24800PaS0PQ20`aS0`Q20`aS00@8@PaS2488@P<<H`03248<H`Q2
008<H`03248<H`aS00<8@P0336<@Q0aS008<H`03248<H`Q2008<H`03248<
H`aS00@<H`03248<H`aS00@<H`03248<H`Q200<8@P<<H`06248<H`aS248<
H`Q210aS0PQ2000212400`0012448@0512401@00124<Ha2436<00PQ200H@
Q0aS2488@PaS248636<00`Q236<<H`0436<010Q236<<H`Q20PaS00<8@PaS
36<01`aS0PQ20`aS00<8@PaS36<02@aS0PQ210aS00<48@Q212400PQ21`aS
00<8@Q245:D00Q240PQ220aS00<8@PaS36<010aS00D@Q0aS36<<Ha2400l<
H`88@P8<H`0348@<H`aS00<@Q08<H`0548@<H`aS48@<H`0348@00aBU48@<
H`0236<00a24248<H`0348@336<648@011BU36<@Q1240QBU0Q2400<DYA24
36<00a2400@DYA245:DDY@8@Q0035:DHaQS6008@Q0035:D@Q1BU008@Q003
5:D@Q124008DY@046<HDYABU5:D248@45:D00a2436<@Q00248@436<248@0
10Q236<8@PQ210aS00@48@Q21248@P<48@0324848@@Q0088@P@48@88@P03
36<8@PQ200848@<8@P848@0324848@Q200848@88@PD48@0424848@Q22482
124524821242248312442483124324801`aS2488@P@Q24848@Q200@48@04
24848@@Q124424821243248010@Q24848@Q210@Q0PQ200L48@Q22488@P@Q
24848@042482124010Q236<<Ha2411S600DQ22DY>Li243W>008e[@06@Q1>
LdHa;F/HaQ240PaS0Q240`aS0a2400@8@Q2448@@Q08<H`0348@<H`aS00<@
Q00336<@Q0aS00D@Q088@P0536<@Q1BU48@<H`0348@020aS248<H`aS48@<
H`Q236<25:D010aS248<Ha241PaS00<@Q0aS36<01PaS112400LDYA245:D@
Q1BU6<HDY@0348@01QBU48@DYABU6<HDY@@<H`03248<Ha24008<H`88@P8<
H`05248<H`aS36<8@P0836<02A2436<<H`aS48@<H`Q236<@Q00436<00a24
36<<H`0636<548@236<020Q236<@Q1245:D@Q0aS248436<2248>36<030Q2
36<<Ha24248<Ha245:D@Q0aS248<H`88@PD<H`03248<H`aS008<H`H8@P8<
H`88@PD<H`<8@P<<H`<8@P8<H`03248<H`Q200<<H`<8@P<<H`<8@P0336<8
@PQ200<<H`0548@<H`aS248<H`02248236<01A242488@PQ236<00`Q20`aS
00<8@PaS24800`aS0PQ200001@0012448@@Q00000`@Q00X000@Q12448@Q2
6<H@Q0aS48@8@P<<H`88@P<<H`8@Q08<H`03248<H`aS00L<H`03248<H`aS
00<<H`88@P0336<8@PaS008<H`88@P8<H`06248<H`aS36<@Q0Q21PaS0PQ2
0PaS10Q20`aS0`Q200<@Q0aS36<01PaS0a2400<<H`Q236<00Q2400<<Ha24
36<00`aS00<8@PaS48@00Q240`aS0a2410aS00<@Q0aS24800PaS00<@Q0aS
36<01@aS00<8@PaS36<010aS0Q240PaS00<@Q1BU48@01A241@aS1A2400TD
YA2436<<Ha245:D@Q1BU48@00PaS0Q2400<DYA2448@01Q2400<DYAS65:D0
0Q240QBU00PHaQBU48@@Q1BU6<HDYA240QBU00D@Q1BU48@DYA24008DY@H@
Q08<H`@@Q00436<@Q0aS248236<02Q242488@P@Q248<Ha2436<8@P@Q0PQ2
00<48@Q224800PQ220@Q1@Q210@Q00<8@P@Q124010Q23@@Q0PQ210@Q00<8
@P@Q12400PQ20`@Q00<8@P@Q24801@Q200@48@Q21248@PH48@0324848@@Q
00<48@88@P848@0424848@@Q124224821242248212401@Q212448@Q21240
0PQ20P@Q00<8@P@Q24800P@Q0PQ20Q24014DYA2436<8@PaS5:DHaSF]>Lhm
kd8@?Nm6<Cg_>LhYBQS600<@Q0035:D@Q0aS00<@Q00336<8@PaS00<@Q003
248<Ha24008@Q00336<@Q0aS00@@Q0<<H`0448@<H`aS36<35:D636<22482
36<0112436<<H`Q21PaS00<@Q0aS36<00PaS00@@Q0aS36<<H`8@Q00636<8
@PaS48@<Ha240PaS1A2400DDYA2448@<Ha24008DY@0348@<Ha2400@<H`03
248<H`aS00P<H`03248<H`aS00@<H`0648@8@PaS36<@Q0aS0`Q20PaS0PQ2
00H<Ha2436<<H`Q248@236<011245:D<H`Q20PaS0Q2400D8@PaS36<<Ha24
00<<H`0948@<H`aS36<8@PaS48@<H`Q2008<H`0448@<H`aS248236<22482
36<00a2436<8@P02248010aS48@@Q1BU10aS0PQ20`aS00<8@PaS36<00`Q2
00<<H`Q224801@Q20PaS0`Q200L<H`Q2248<H`Q236<@Q00236<02PQ236<<
H`Q236<8@PaS248<H`Q20PaS0PQ200@<H`Q236<<H`<8@P8<H`03248<H`aS
008<H`05248<Ha2436<8@P0336<2248236<3248536<010Q236<8@PaS0@Q2
000010@Q00048@000P@Q00<000@Q12400P@Q00@000aS5:D@Q0D<H`03248<
H`Q200<8@P0448@<H`aS36<3248236<01@Q236<<Ha2436<00PQ20PaS00<@
Q0aS24800PQ200@<H`Q22488@PH<H`0548@<H`Q236<8@P0536<00`Q236<8
@P0324801@aS248<H`aS48@00PQ200<<Ha2436<00`Q20PaS00H@Q0aS36<@
Q0aS248836<0112436<8@PaS0Q2400<<H`Q224800PaS0Q2410aS00@8@PaS
36<<H`8@Q08<H`03248<Ha24008@Q0T<H`8@Q00436<@Q1245:D348@236<0
0`Q236<<H`0236<348@336<:48@011BU48@<H`aS0Q240QBU0a2400HDYAS6
5:DDYA245:D26<H248@35:D248@55:D01AS65:DDYAS648@00PaS00<@Q1BU
48@00PaS00DDYA2436<<Ha2400<<H`8@Q00336<48@@Q0088@P<<H`032484
8@@Q00<8@P848@0324848@@Q0088@P<48@88@P0=36<8@PQ224848@001248
@PaS24848@Q212400PQ22P@Q00<8@P@Q24800PQ210@Q0PQ210@Q00<8@P@Q
24800P@Q00D8@PaS36<48@Q200848@88@P@48@<8@P@48@0324848@@Q00@4
8@0424848@Q2248412401@Q212448@Q212400`Q20`@Q00@8@P@Q2488@P<<
H`0648@DY@aS36<8@Q240QS600D]JcF]AS5243W>00924005>Lh]JaS65:D<
H`0348@00`aS48@@Q00236<010Q236<<HaBU0`aS0a240`aS0a241@aS00@@
Q0aS48@<H`<@Q0<<H`0348@<H`aS00<<H`0448@<H`aS248436<00`Q236<<
H`0248@736<00a2436<@Q00248@236<748@01ABU48@<H`aS48@00QS600@D
Y@Q22488@P8@Q088@P<<H`03248<Ha24008@Q0D<H`04248<Ha2448@236<0
0`Q236<8@P0436<3248236<00`Q236<8@P0236<0112436<@Q0aS0Q241PaS
0PQ200P<Ha2448@@Q0aS248<H`Q21PaS0PQ20PaS0Q240PaS00<8@PaS36<0
0PQ200D<Ha2436<8@Q24008DY@D<H`88@P@<H`<8@P0536<8@PaS24848@02
24800`aS2488@P03248336<3248336<00`Q236<8@P0336<010Q236<<H`Q2
0PaS00@8@P@Q2488@P8<H`<8@P0436<8@PaS48@2248236<0112436<8@PQ2
0PaS1@Q200D<H`Q236<<H`Q2008<H`<8@P8<H`48@P448@001@@Q00<000@Q
12400P@Q00@000@Q248DY@8<H`04248<H`Q236<2248636<00a2436<<H`02
36<00`Q236<<H`0536<01PQ236<<H`aS248<H`88@PD<H`88@P8<H`0348@8
@PQ200@<H`0748@<H`Q236<8@PaS48@00`aS00D8@P@Q36<<Ha2400H<H`03
248<H`aS00P<H`04248<H`aS36<248@336<348@836<00`Q236<<H`0236<0
1@Q236<@Q12436<00Q2400<<H`Q236<00Q2410aS0Q240PaS00<8@PaS36<0
31240`aS1Q240PaS00H@Q1BU48@@Q0Q236<35:D236<01Q245:D@Q0aS48@H
aP@DY@0=48@DYA2448@DYAS65:D@Q1BU6<HLiaS65:D00a2400<HaQBU5:D0
0Q2411BU00<@Q0aS36<00PaS00D@Q1BU48@<H`Q200<<H`031248@PQ200@8
@P0536<@Q0Q224848@0324831242248412401PQ2124<H`Q236<8@P848@04
24848@@Q1244248010@Q24848@Q20P@Q00<8@P@Q12400P@Q00<8@P@Q1240
10@Q00P8@P@Q24848@Q21248@P@Q1`Q20P@Q00@8@P@Q2488@P848@042484
8@Q22486124324821247248612400`Q212448@031248248212400`Q236<<
H`03248248@27>L01CF]>Lhmkcg_>Lh00THa00A243F]7>LLi`8@Q0045:D@
Q12448@936<0112436<@Q1BU0Q240`aS0a2400<8@PaS36<00Q240`aS00@@
Q0aS2488@Ph<H`<@Q0<<H`8@Q08<H`8@Q0<<H`8@Q0035:D@Q0aS00L@Q08<
H`03248<H`aS00@@Q0L<H`03248<H`aS00H<H`88@PD<H`05248<H`aS36<@
Q00236<00`Q236<<H`0236<010Q236<@Q1240PaS00@@Q0aS36<8@PH<H`03
48@<H`aS00@<H`03248<H`aS008<H`04248<H`Q2248536<00`Q236<<H`0<
36<448@00`Q236<<H`0436<010Q236<8@PQ20`aS00<8@PaS24800PQ200@<
H`Q22488@PD<H`03248<H`aS008<H`<8@P0636<8@PQ236<8@PaS0`Q21@aS
00<8@PaS36<01PaS0`Q210aS00<8@PaS36<010Q200@<Ha2436<<H`88@P@<
H`03248<H`aS0048@P0000@000@Q124000D48@0800048@@Q36<DYA24248@
Q08<H`88@P0436<8@PaS248236<0112436<<H`Q20`aS00@8@PaS36<@Q0@<
H`03248<H`Q200<<H`<8@P8<H`03248<H`aS00D<H`88@P0336<@Q0aS008<
H`05248<H`Q224848@0336<224800`aS48@@Q00536<224800`aS48@DY@05
36<224801@aS48@@Q12436<00Q2400H<H`Q236<@Q1BU48@336<00a2436<<
H`02248236<00a2436<@Q00236<0112436<<H`aS0a2410aS00@@Q0aS36<8
@P8<H`<@Q08<H`0448@DYA2448@436<648@00aBU48@@Q00448@010aS48@@
Q0aS112400<DY@aS48@00Q2400<DYA2448@01ABU0a2411BU00@@Q1BU6<HH
aP8DY@0348@DYABU008DY@0348@DYA2400H@Q08<H`<@Q08<H`0:248<H`aS
24848@Q2124<H`Q236<248@00`aS24848@03248312422483124010Q21244
8@Q20PaS00<8@P@Q12400`@Q10Q220@Q00<8@P@Q12400P@Q00<8@P@Q1240
10@Q00D8@P@Q24848@Q200<48@88@P041248@PQ2124424800`@Q2488@P04
12422484124724801P@Q2488@P@Q24848@88@P031248@P@Q00<48@032484
8@@Q0088@P0436<8@P@Q1243248212400`Q236<<H`0224802PaS48@<HaS6
7>LaS3g_AS5243g_0d8@00@icR486<HDY@8@Q0<<H`D@Q0<<H`H@Q0<<H`8@
Q00436<8@PaS36<248@236<01A2436<8@PQ236<00Q240PaS00D8@PaS48@<
H`Q2008<H`0748@<Ha2436<@Q0aS24802`aS0Q2410aS0a2400<DYA2436<0
0PaS00<@Q0aS48@00Q242@aS00<8@PaS36<01PaS0`Q20PaS00D@Q0aS248<
H`Q2008<H`0348@<H`aS00@<H`03248<H`aS00L<H`055:D@Q0aS36<8@P02
48@336<00a2436<<H`02248436<00`Q236<<H`02248010aS48@8@PQ21`aS
00@@Q0aS36<8@PD<H`0448@DYABU48@2248336<224801@aS248<H`aS2480
0PaS10Q200<<H`Q236<00`aS00@@Q0aS248<H`8@Q088@P8<H`<8@P0736<8
@PaS248<H`Q212400PaS00<@Q0aS248010Q20`aS10Q220aS0`Q200@<Ha24
36<8@PT<H`88@P000P@Q00@000@Q124000848@0800048@@Q124<Ha2436<8
@PH<H`@8@P8<H`0348@<H`aS00@<H`04248<H`aS36<3248236<00a2436<<
H`03248336<010Q236<<Ha2430aS00<8@PaS36<00`aS00<8@PaS24800PQ2
00D<Ha2436<8@PaS008@Q005248<Ha245:D@Q00236<00a2436<<H`0236<2
48@336<648@436<01PQ236<<Ha2436<8@P8<H`0348@<Ha24008@Q0@<H`04
5:D@Q12448@336<00a2436<<H`0336<0112436<@Q1240PaS00<@Q0aS48@0
0QBU00D@Q0Q2248@Q0aS00D@Q00336<DYA24008@Q0@<H`0448@DYA2436<2
48@25:D448@00aBU48@DY@075:D36<H25:D00aS65:DHaP0248@011BU48@@
Q0aS0Q2400<DYA2436<02PaS0P@Q00<8@P@Q12400P@Q00H8@PaS48@@Q0aS
248212400`Q21248@P0212401@001248@PaS24800`@Q0`aS00<8@P@Q1240
0`Q200<48@Q224800`Q210@Q0PQ20P@Q00<8@P@Q24800P@Q00@8@P@Q2488
@P@48@88@P0336<8@PQ200848@<8@P<48@88@P<48@88@P<48@0524848@@Q
1248@P0212400`001248@P0236<00a2436<<H`0324800`@Q2488@P031240
0`Q21248@P0212400`Q236<8@P02124424800`@Q24848@0224801@aS2488
@PQ236<00Q240QBU00`U:C6<>Li:DTicBU9243g_@Q0]JbU:48@736<00`Q2
48@<H`0248@436<248@236<00a2436<<H`0236<01124248<Ha240PaS00<8
@PaS36<00PaS00@8@PaS36<@Q10<H`0348@<H`aS008<H`0548@<H`aS248<
H`0248@236<248@011BU48@8@PaS1A240PaS11243PaS00H8@PaS36<@Q0aS
248236<00`Q236<@Q0025:D00a2436<<H`0636<2248236<010Q236<<H`aS
0Q2400<<Ha2436<01`aS0Q2400@<H`Q236<8@P8@Q0D<H`0348@<H`aS008<
H`05248<H`aS36<@Q00736<00`Q236<@Q0025:D00a24248<H`0236<52482
36<2248336<2248236<2248236<00a2436<<H`02248236<2248010aS248<
H`Q210aS0`Q200<@Q0aS36<00PQ21@aS0`Q20PaS00H48@aS48@@Q0aS2483
36<324800`aS48@<H`0236<010Q236<<H`aS0`Q20@aS0@@Q00001@001244
8@@Q00001@@Q00@000@Q248@Q08<H`04248<H`aS48@@36<00a2436<8@P02
248336<01@Q236<8@PaS24800`aS00<8@PaS248020aS00<8@PaS36<00`aS
0`Q21PaS0`Q21PaS00D8@PaS48@DYA24008<H`05248<H`aS36<@Q00336<0
1A2436<<Ha245:D00Q240PaS00<@Q0aS36<010aS00<8@PaS36<00a240PaS
0a240`aS0Q2400<<Ha2436<01@aS0a240`aS1Q240`aS00@@Q0aS48@<H`8@
Q0035:D@Q12400@@Q00436<@Q1245:D548@25:D248@010aS48@DYABU0a24
1ABU0QS60QBU0aS600<DYA245:D01Q2400<<Ha2448@00Q2420aS0P@Q00<8
@P@Q24800P@Q0`Q200<<Ha2436<01@Q210@Q0PQ200<48@Q212400P@Q00@8
@Q242488@P848@0424848@@Q124324800`aS24848@0;124010Q212448@00
1@@Q00@8@PaS36<8@P848@<8@P848@D8@P@48@0524848@Q21248@P051243
248010aS48@@Q0aS0`Q200<48@Q212400PQ20`@Q0PQ20P@Q10Q20`@Q00<8
@P@Q24801PQ200X48@Q236<@Q0aS5:DHaRU:;F/e[@96<@07BU96<D8@@Q0Y
BQcW36<00a240`aS00<8@PaS36<00a240`aS0Q2400@<Ha2448@@Q0D<H`03
48@<H`aS00@<H`05248<H`aS36<8@P0236<0112436<<H`aS0PQ20PaS00@@
Q0aS36<<H`8@Q08<H`04248<H`aS48@736<748@236<348@236<248@336<0
0a2436<<H`0336<448@236<00`Q236<8@P0336<00`Q236<<H`0436<348@9
36<01Q2436<<H`Q236<8@P<<H`0448@<H`aS36<748@00`aS248<H`0536<0
0a2436<<H`0336<00`Q236<<H`0936<010Q236<8@Q240PaS0Q2400HHaQ24
36<<H`Q2124224800a2436<<H`02248436<2248236<0112436<<H`Q20`aS
00@8@PaS36<<H`@8@P<<H`04248<H`Q236<2248010aS248@Q1240PaS0`Q2
00D<Ha2436<8@P@Q0088@P<<H`03248<H`Q200<8@P0536<8@PaS36<8@P03
36<00a2436<<H`0224800`aS2488@P0124800003124000@Q00<48@030004
8@@Q00<48@0436<DY@aS248336<00`Q236<<H`0336<324800`aS248<H`05
36<2248436<00`Q236<@Q00236<2248336<01a2436<@Q12436<8@PaS008@
Q0035:D<H`aS00L<H`88@P8<H`0348@<H`Q200<<H`03248<Ha24008@Q0<<
H`0348@<H`aS00@<H`0348@<H`aS00<@Q0<<H`8@Q0035:D<H`aS008@Q0D<
H`03248<H`aS008<H`<@Q00436<@Q12448@436<248@<36<01Q2436<@Q124
5:D@Q0<<H`045:D@Q12436<248@00aBU48@<H`0248@00aBU48@@Q00448@0
2ABU48@@Q0aS48@DYAS65:D<H`0648@25:D00a245:DHaP026<H00acW6<HD
Y@025:D26<H25:D36<H011BU48@@Q1BU0Q2400<<H`Q248@01@aS0P@Q0`Q2
00@48@0024848@D8@P<<H`@8@P@48@03248<H`@Q00<48@<8@P<48@032484
8@Q20088@P0336<8@PQ200<8@P<48@88@P<48@0424848@@Q124324851240
1@aS2488@PQ212400PQ20P@Q00@8@P@Q24848@88@P<48@0324848@@Q00X4
8@0436<@Q1BU36<2248236<00`Q21248@P0412400`Q212448@0524800`@Q
2488@P022482124224800`aS2488@P0224801@aS248<Ha245:D00`aS00<L
ibDY=Jd00THa00UBU4ic@Q0mkb486<HDYA245:D00`aS00D@Q0aS248<Ha24
008DY@0536<@Q0aS36<8@P0836<01A2436<<H`aS24800PaS00L8@PaS248<
Ha2436<@Q00436<00a2436<<H`0736<0112436<<Ha240`aS00@@Q1BU48@<
H`88@P8<H`8@Q0@<H`0348@<H`aS00@@Q00536<8@PaS36<@Q00536<00a24
36<<H`0348@00`Q236<<H`04248336<00a245:D@Q00448@336<224800`aS
248<H`0248@236<010Q236<@Q0aS0a240PaS0Q2410aS00@@Q0aS2488@P<<
H`04248<H`aS48@236<00`Q236<8@P0336<224802@aS48@<H`aS248<Ha24
36<8@P0236<448@536<2248010aS2488@PaS0`Q20`aS00D8@PaS248<H`Q2
008<H`@8@P@<H`@8@P@<H`88@P/<H`04248<H`aS36<2248236<2248236<3
248836<224801@aS248<H`Q236<00PQ200021240100012448@000P@Q00L0
00@Q00048@Q25:D@Q00436<0112436<<H`Q20PaS00<8@PaS36<00`aS00@8
@PaS36<<H`88@P0336<@Q0aS00@<H`03248<H`aS00<<H`03248<H`aS00H<
H`8@Q0<<H`0348@<H`aS00@8@P0536<8@PaS36<8@P0436<01@Q236<<H`aS
48@00`aS00@@Q0aS36<@Q0L<H`<@Q0<<H`8@Q08<H`0348@<Ha2400<<H`03
248<H`aS00@<H`8@Q0@<H`8@Q08<H`<@Q08<H`03248<Ha2400<<H`8@Q0@<
H`<@Q00336<@Q0aS00<<H`<@Q0035:D@Q0aS008@Q00536<@Q12448@<H`02
48@00aBU48@<H`0248@00aBU48@DY@025:D348@35:D248@25:D46<H35:D0
0aS67>LDY@035:D00aS65:DDY@045:D0112436<@Q0aS0PQ20`aS00@8@P@Q
2488@P848@0424848@@Q1242248010aS248<H`aS0PQ20`@Q00D8@P@Q1248
@P@Q00@8@P051248@P@Q1248@P04124424800`aS2488@P0;12400`Q21248
@P0412400`0012448@02248236<42482124224821245248010@Q24848@@Q
0PQ21`@Q00P8@PaS48@DYA2436<8@P@Q0`Q20P@Q0PQ200<48@Q224800P@Q
10Q210@Q00L<H`@Q1248@PaS24848@02248336<03Q2436<<Ha2436<LibDY
=Je>LdHaDYA:DSW>?Nl27>L01A2436<<H`aS24801@aS00@@Q1BU48@@Q0<<
H`0348@8@PaS00D<H`0448@<H`aS248436<00a2436<<H`0436<01A2436<8
@PaS24801`aS00<8@PaS24800`aS00@@Q0aS36<@Q08<H`03248<Ha24008<
H`8@Q0035:D<H`aS008<H`<@Q0<<H`@@Q08<H`@@Q08<H`0448@<H`aS2483
36<3248536<548@00aBU48@<H`0;36<01a2436<@Q0aS48@<Ha2400@<H`88
@P@<H`88@P8@Q00436<8@PaS48@224800`aS48@<H`02248236<3248010aS
2488@PQ21@aS0Q2400HDYA2448@@Q0Q21242248010aS248<H`aS0`Q210aS
10Q20PaS00<8@PaS36<00PQ20`aS0PQ20`aS00D8@PaS2488@PaS0088@P04
36<@Q0aS36<2248236<01A2436<<H`Q236<00PQ200H<Ha2436<8@P@Q2482
36<224800`aS2488@P0436<010Q236<<H`Q20PaS00<@Q0aS24800@@Q0000
100012448@0020@Q00<<HaBU48@00PQ200D<Ha2448@<H`Q200@<H`03248<
H`Q2008<H`03248<H`aS008<H`0348@<H`Q20088@P0536<@Q0aS36<8@P05
36<01@Q236<<Ha2436<00a2420aS10Q22@aS00<8@PaS24800Q242`aS00@@
Q0Q236<<H`8@Q0<<H`0448@DYA2448@336<448@236<224800`aS48@<H`03
36<248@636<348@536<224800`aS48@@Q00236<01PQ236<<Ha245:DHaP<@
Q0035:D@Q124008<H`045:D@Q1245:D236<348@00aBU48@@Q00248@00aBU
48@@Q00236<00a245:DDY@0448@25:D01Q2436<@Q1246<HDY@HHaP8DY@03
6<HDYABU008Li`036<HDY@Q2008<H`88@P<<H`@8@P031248@PQ200D48@<8
@P031248@PQ200@8@P848@0324848@@Q00848@0624848@Q21248@PaS0PQ2
0P@Q00<8@P@Q12400P@Q0PQ200<<H`Q224800PQ200<48@Q212400`@Q00<8
@P@Q12401@@Q00H000@Q12448@Q2124524800`@Q2488@P02124224831240
10Q21248@P@Q0PQ20P@Q0PQ200D48@Q21248@P@Q0088@P8@Q00336<8@PaS
008<H`<8@P<48@0324848@@Q00<8@PD48@88@P031248@PQ200848@@<H`88
@P@<H`09248<H`aS48@DYBU:=Je6<D8@0096<@08>Lhe[BDY7>LHaPaS48@<
H`8@Q0@<H`8@Q0D<H`04248<H`aS48@236<00a2436<8@P0236<00a2436<8
@P0536<248@536<00a2436<<H`0536<224801@aS48@<H`aS48@00`aS0Q24
1@aS00D@Q0aS36<<H`Q200D@Q0<<H`0348@8@PQ200H<H`035:D@Q1BU008@
Q00336<8@PaS00L<H`D@Q00336<@Q0aS00L<H`0548@<H`aS248<H`022482
36<00a2436<<H`0236<0112436<<H`aS0`Q20PaS0Q240`aS0PQ200@<Ha24
48@<H`<8@P0348@<H`aS008<H`04248<H`aS36<324800a2436<<H`0336<0
0a2436<@Q00236<224800`aS2488@P0336<4248010aS48@<H`aS0`Q20PaS
00D8@PaS248<H`Q2008<H`@8@P0436<8@PaS248236<00`Q236<<H`0236<0
20Q236<@Q12436<8@PaS248236<010Q236<<H`aS0PQ200@48@aS36<<H`88
@P<<H`88@P8<H`88@P0336<8@PQ20088@P8<H`0010@Q00<000@Q12400P@Q
00H000@Q124<HaBU36<2248336<00`Q236<<H`0236<010Q236<<H`aS0PQ2
1`aS00<8@PaS24800`aS00<8@PaS36<00Q240PQ200@<H`Q2248<H`8@Q08<
H`8@Q00336<8@PQ20088@P<<H`<8@PH<H`04248<H`aS36<3248010aS48@<
H`aS0Q2400@<H`Q236<@Q0@<H`<@Q0`<H`8@Q00436<8@PaS36<248@336<2
48@436<548@236<3248236<01@Q236<<H`aS48@00PaS2A2400DDYA2448@<
Ha24008DY@<<H`L@Q0<DY@0348@<H`aS00DDY@0348@DYA24008@Q0DDY@05
6<HDYABU6<HLi`045:D01QcW6<HLib486<H@Q088@P0348@8@PQ200<<H`03
24848@@Q00848@88@P@48@0324848@Q200X8@P848@88@P041248@PQ21245
2483124724800`aS24848@02124224800`@Q24848@0:12400`Q212448@03
24800`aS1248@P0324800`@Q24848@031243248412422484124020Q21244
8@@Q36<DY@aS248336<00`Q21248@P02248010@Q2488@PQ210@Q00<8@P@Q
24800P@Q00D8@P@Q2488@P@Q0088@P0636<@Q0aS24848@Q20PaS0a2400L8
@PaS36<HaRe[<Ha6<@02@Q001THa>LhicR487>LDY@@@Q0@<H`8@Q00436<@
Q0aS48@336<010Q236<@Q1245PaS0Q240PaS0PQ250aS00@@Q0aS36<<H`8@
Q0@<H`0348@<H`aS008<H`8@Q08<H`8@Q0065:D@Q12448@<Ha242@aS00@@
Q1BU48@@Q0P<H`0548@<H`Q236<@Q00436<0112436<<Ha241`aS00@@Q0aS
36<8@P8<H`8@Q0<<H`<8@PD<H`05248<H`Q236<48@02248236<2248436<0
1`Q236<@Q0aS48@DYA240088@P<<H`88@P0836<8@PQ224848@aS48@<H`<8
@P<<H`05248<H`Q236<8@P0536<324800`aS248<H`0236<2248236<010Q2
36<<Ha240PaS00<8@PaS24800`Q200<<H`Q224800PQ200@<H`Q22488@P@<
H`88@P@<H`88@P<<H`48@P448@448@0000<000@Q00000`@Q00<000@Q1240
0P@Q00H000aS5:D@Q0aS48@736<00`Q236<<H`0236<3248236<01`Q236<<
H`Q236<8@PaS0088@P0336<@Q12400<<H`0448@<H`aS36<348@236<00`Q2
36<<H`0236<0112436<8@PQ20`aS0`Q200<@Q0aS36<00PaS00<@Q0aS48@0
3`aS00D8@PaS36<<Ha2400@<H`8@Q0<<H`03248<H`aS00D<H`0448@<H`aS
48@236<010Q236<@Q12410aS0Q240PaS0a2400@<H`Q22488@PT<H`8DY@D@
Q0045:DHaQBU5:D348@01QBU48@@Q12436<@Q08DY@@@Q0045:DHaQ2436<2
48@35:D021245:D@Q1245:D@Q1BU48@45:D248@00aBU6<HHaP035:D01aS6
7>LQ212436<48@Q2008<H`T8@P041248@PQ22484124224800`aS2488@P02
12401@Q236<8@PQ212401`Q200@48@Q2248<H`<8@P@48@H8@P<48@88@P84
8@0524848@@Q1248@P0412400`Q212448@0224801@aS12448@@Q248010@Q
00<8@P@Q24800P@Q0PQ200<48@Q212400`@Q0`Q21`@Q0PQ200@<H`Q21244
8@88@P0336<8@PQ200<8@P041248@PQ2248312400`Q212448@0212432480
0`aS2488@P0436<010Q21248@PQ20PaS0`Q200l48A245:DLicF]@Q16<Cg_
=JdicT8@AS4aS2DY5:D00`aS00D8@PaS48@<Ha2400<8@P0336<@Q0aS00X<
H`88@P0336<@Q0aS008<H`0348@<H`aS00<<H`0348@<H`aS00L<H`05248<
Ha2436<@Q00236<00a2436<<H`0336<00`Q236<<H`0236<00a2436<<H`02
36<00a2436<@Q00>36<448@00`aS2488@P0336<010Q236<<Ha240PaS0a24
00<8@PaS36<010aS00<@Q0aS24800PQ20`aS00D8@PaS36<<H`Q2008<H`03
48@<H`aS00@<H`03248<H`aS00L<H`03248<H`aS00<<H`0348@<H`Q200@8
@P<<H`88@P051248@PQ236<8@P0436<00`Q236<DY@025:D2248010aS248<
Ha240PaS0`Q20PaS00<@Q0aS24800PaS10Q20Q2400D<H`Q22488@PaS0088
@P8<H`03248<H`Q200<<H`0424848@Q236<248@236<00`Q236<8@P042480
0`aS2488@P0636<00`Q236<<H`0324800`@Q36<<H`02248010aS48@@Q0aS
0`Q2000512402P0012448@00124000@Q248DYA241@aS00D8@PaS248<Ha24
00D<H`8@Q00336<8@PaS00<<H`<8@P0336<8@PaS008<H`0348@<H`aS0088
@P<<H`0448@<H`Q236<2248236<248@236<224800`aS2488@P03248236<0
10Q236<@Q1240PaS00<8@PaS36<00`aS0a240`aS00@@Q0aS36<8@P<<H`06
48@<H`aS48@<Ha241PaS0Q241@aS00<@Q0aS36<010aS0Q240`aS0Q2400HD
YA2436<<Ha2436<2248236<01A2436<<H`Q236<00Q240`aS0Q2400@DYA24
48@HaP8Li`055:D<Ha2448@<H`0448@020aS48@DYA2436<@Q1BU6<H448@3
5:D02A245:DDYAS65:D@Q1BU48@DY@0248@25:D011S65:DDYABU0QS600TD
YAS66<HQ21cW5:D@Q0aS24800`aS0PQ200H<H`Q224848@Q2124324831242
248236<6248236<224800`@Q2488@P0212400`Q21248@P02248236<22482
12400`Q21248@P0324800`@Q2488@P05248212400`Q21248@P0412401PQ2
12448@@Q248<H`@8@P031248@PQ200<48@<8@P<48@03248<H`Q200848@<8
@P848@@8@P031248@P@Q0088@P0336<8@PQ200<8@P051248@PQ224848@03
24831243248412400`Q236<8@P0324801@aS48@<H`@Q248010aS0PQ200P<
H`Q236<DYAcW>Li244Ha0SW>00Y244HaAS4]JacW6<H@Q1BU48@<H`88@P03
48@<H`aS008<H`0348@<H`Q20088@P<<H`8@Q00436<@Q0aS248236<01124
36<<H`aS0Q240PaS00<@Q0aS36<010aS0Q241@aS0PQ200<<Ha2448@00PaS
00<@Q0aS36<01`aS00@@Q0aS36<<H`8@Q08<H`0348@<Ha2400P<H`0348@<
Ha24008@Q0<<H`0448@<H`aS36<224801PaS48@<H`aS48@DY@8<H`05248<
H`aS36<8@P0236<00a2436<<H`0536<2248636<00`Q236<<H`0336<01@Q2
36<<H`aS24800PaS0Q2400H<H`Q236<<Ha2436<224800`aS48@<H`0236<0
10Q236<8@PQ21@aS0`Q20`aS0Q241`aS0`Q21@aS00<8@PaS36<010aS00<8
@PaS24800PQ20`aS0PQ200<<H`Q236<00PQ200@<H`Q22488@P8<H`0348@<
Ha2400@<H`03248<H`aS00H<H`0424848@aS36<324800`aS248<H`0236<3
248248@010aS2488@Q240PQ20@@Q00000`001240000912400`Q25:D@Q002
36<00a2436<@Q00236<00`Q236<<H`0248@=36<2248536<248@011BU36<<
H`Q210aS00<8@PaS36<02PaS00<8@PaS248010aS00<8@PaS48@030aS0`Q2
00@<Ha2436<8@PH<H`8@Q00436<@Q0Q236<348@010aS48@<H`aS0a241@aS
0a2400@<H`Q236<<H`8DY@8@Q08<H`0348@<H`Q200@<H`06248<Ha2448@D
YA240PaS1a2400@DYAS66<HDY@@@Q08<H`0448@<Ha2448@25:D248@00aBU
48@@Q00248@25:D0112436<<Ha240QS611240QBU00<@Q1BU5:D00aBU0Q24
00@Q22U:8@PHaP848@0736<@Q12436<8@P@Q24800`@Q2`Q200<48@Q22480
0`Q200<48@Q2248030Q200D48@Q236<<H`Q200848@0324848@Q200/8@P03
36<8@P@Q00848@03248<H`Q200<48@03248@Q0Q200<8@P031248@PQ200<8
@P031248@P@Q00<48@L8@P041248@P@Q12432482124324801@@Q24848@Q2
124010Q200<48@Q224800`Q20`@Q00@8@P@Q2488@P@48@88@P848@L8@P04
1248@PaS36<4248236<00a246<HLi`02;F/01DHaDYA>LdHa<H`00SW>00DY
BQS636<@Q1BU00<@Q0L<H`03248<H`aS00@<H`0348@<Ha240088@P8<H`03
48@<H`aS00D<H`0348@<H`aS008<H`8@Q0D<H`0448@<H`aS48@436<348@0
1@Q236<<H`aS48@00PQ200@<Ha2448@@Q0@<H`0648@<H`aS48@<H`Q21PaS
00H@Q0aS36<<Ha2436<2248336<00`Q236<<H`0248@436<00a2436<<H`04
36<00`Q236<8@P0336<2248336<01@Q236<@Q12436<00PQ21@aS00<8@PaS
36<00PaS00D@Q0aS248<H`Q200<<H`88@P<<H`07248<H`Q236<8@PaS2480
0`aS00P8@PaS24848@Q236<@Q0aS0PQ20PaS00<@Q0aS36<00`aS00D8@PaS
248<H`Q200@<H`<8@P<<H`03248<H`aS00`<H`0348@<H`aS0088@P0336<@
Q124008@Q0D<H`H8@P8<H`03248<H`aS008<H`03248<H`Q20088@P0636<8
@PaS248<H`Q21PaS000412400`001240000312401@00124<HaBU48@01PaS
00<@Q0aS36<00`aS00@@Q0aS36<8@P<<H`03248<H`aS008<H`07248<H`Q2
248<H`Q236<00a240PaS00<@Q0aS36<02`aS00<8@PaS36<00PaS0PQ20PaS
0`Q20`aS00D@Q0aS36<<H`Q200<<H`<@Q0@<H`04248<H`aS48@436<348@2
36<010Q248@@Q1241@aS00<@Q0aS24800PaS00<@Q0aS36<01`aS0Q2400D<
Ha2448@@Q1BU00<<H`88@P<<H`04248<Ha245:D248@336<00a245:DDY@03
48@00aBU6<HDY@025:D248@336<01A245:D@Q12436<00aBU0Q2400D<Ha24
5:D@Q1BU008@Q08DY@<@Q00336<DYA2400<DY@0:48@DYABU6<H@Q0aS7>LY
BRDY6<H2124010aS48@@Q0aS0P@Q00<8@P@Q24800P@Q0PQ20`aS0PQ200@4
8@Q212448@88@P0336<48@Q20088@P061248@PQ2248<H`Q20`@Q00<8@PaS
24800`Q20`aS00D48@Q21248@P@Q00d8@PD48@0424848@@Q124248@00`aS
12448@0824831242248212442483124010Q21248@PaS0PQ20P@Q1@Q20P@Q
00<8@P@Q24800PQ200<<H`Q224800P@Q0PQ21`@Q20Q200<<H`Q224800PQ2
00<<H`Q2248010Q20`aS00<@Q1S68@P00SF]00Y6<EJeCW=243F]?Nle[BDY
5:D<H`8@Q08<H`8@Q0<<H`0348@<H`aS008<H`88@P0348@<Ha24008<H`03
248<Ha24008@Q0/<H`@@Q0T<H`<@Q0D<H`88@P0448@<H`aS248636<248@2
36<0112436<<H`aS0PQ200<<H`Q236<00Q2400D<H`Q236<<Ha24008<H`03
248<H`Q200D<H`0748@<H`aS36<8@PaS24801`aS00<8@PaS36<010aS0`Q2
1`aS0Q2400<8@PaS36<01PaS00D8@PaS48@<H`Q2008<H`<8@PL<H`<8@P03
36<8@PQ200<8@P<<H`05248<H`aS36<@Q00736<00`Q236<8@P03248336<0
10Q236<<H`aS0PQ22@aS00D8@PaS36<<Ha24008<H`03248<H`aS008@Q0<<
H`03248<H`Q200@<H`04248<H`aS36<224800`aS48@8@P03248236<22483
36<01124248<H`Q20PaS0@Q200000`@Q00048@0512401P0012448@@Q48@D
Y@8<H`8@Q00536<8@PQ236<@Q00736<00a2436<<H`0436<010Q236<8@PQ2
10aS0Q2400H<Ha2436<<H`Q236<348@00`aS2488@P0236<0112436<8@PQ2
0`aS00<@Q0aS36<00`aS0PQ200@<Ha2436<<H`88@PH<H`0448@<H`aS48@2
36<02@Q236<@Q0aS248<H`Q248@<H`0248@736<448@336<00a2436<<H`05
36<248@236<01@Q236<DYAS65:D0112400@<H`Q2248<H`8@Q00536<8@PaS
48@DY@0236<348@00`Q236<DY@0348@00`aS48@DY@025:D348@00`aS48@@
Q00348@45:D248@01QBU48@DYABU48@DY@8@Q00636<DYABU48@DY@aS0a24
0aBU112400HDYA2448@<H`Q236<2248312400`Q21248@P051242248236<4
24801PaS2488@P@Q24848@/8@P031248@PQ20088@P<48@04248<H`Q22484
12400`Q21248@P0524800`aS2488@P0248@01@aS248<H`Q236<010Q200<4
8@Q224800Q2400D<H`Q22488@PaS00H8@P<48@0324848@@Q00D48@032484
8@Q200<8@P848@88@P0436<8@PQ2124724800`@Q24848@03124224821240
1`Q21248@PQ21248@P@Q0088@P031248@PQ200@8@P848@88@P0536<8@PQ2
48@DY@0448@01S6<=Je6<DHa>LhaS0<]J`037>LHaQ2400<@Q08<H`03248<
H`aS00<<H`0348@<H`aS008<H`8@Q0<<H`<@Q0@<H`8@Q0X<H`8@Q0<<H`07
48@DY@aS36<@Q0aS48@01@aS00<8@PaS36<00`aS00D8@PaS36<<Ha2400<<
H`0348@<H`aS008<H`8@Q0<<H`04248<H`aS48@B36<00a2436<<H`032480
0`aS48@<H`0236<0112436<<H`Q20`aS0PQ20PaS00@@Q0aS36<@Q0<<H`03
248<H`aS00H<H`<8@P0336<8@PaS00@<H`88@P0436<8@PQ236<424800`aS
2488@P02248336<224801PaS48@<H`aS248<H`<8@P8<H`03248<H`Q200H<
H`<8@PH<H`03248<H`aS00<8@PH<H`88@P@<H`88@P<<H`@8@P0336<8@PQ2
00<<H`03248<H`aS008<H`<8@P8<H`04248<H`aS36<348@136<124812480
000500048@@Q124000041240200012448@aS5:D@Q0Q248@336<248@01@aS
248<H`aS48@01`aS00<8@PaS36<00PaS00@8@PaS2488@P8<H`<@Q0<<H`8@
Q0<<H`04248<H`aS248:36<010Q236<<H`aS0PQ200<<Ha2436<00PQ21PaS
00D@Q0aS36<<H`Q2008<H`0548@<H`Q236<@Q00236<01@Q236<<H`Q236<0
0Q240`aS1a242`aS0PQ20PaS0QBU00@HaQBU48@@Q0H<H`0548@<H`Q248@D
Y@0248@01@Q236<@Q0aS48@00PaS1A2400L<HaBU7>LHaQ24248<H`0448@0
1@aS5:DDYAS65:D01Q2400<DYA2448@00Q2400<DYA245:D00Q2400<<Ha24
5:D01A2411BU00<<H`Q224800`aS00D8@P@Q12448@Q200848@0524848@Q2
1248@P0336<00`Q236<<H`022483124224800`@Q2488@P03248312452484
124236<010Q212448@@Q0`Q20`@Q00@8@PaS2488@P8<H`03248<H`aS008<
H`<8@P8<H`88@P848@07248<Ha2448@<H`Q236<00PQ20`@Q0PQ20`@Q00<8
@P@Q24800`@Q0PQ20`@Q1PQ200T48@Q21248@P@Q24848@Q212400`Q200<4
8@Q212400PQ21@@Q00<8@P@Q248010Q200L48@Q22488@PaS24848@022480
0`@Q248<H`02248010@Q248<H`aS0a2400@DYAS6;F/aS092408aS009:DX]
Jbe[6<H@Q0aS48@DYA2400<<H`03248<H`aS00@<H`0348@<H`Q2008<H`<@
Q0D<H`0348@<H`aS008@Q0035:D@Q0aS00H<H`0548@<H`aS36<@Q00336<4
48@236<01@Q236<<Ha2436<00PQ200<<Ha2448@00PaS0Q240`aS1A2410aS
00<@Q0aS36<00PaS0PQ20PaS00<@Q0aS36<00`aS0a241@aS00<8@PaS36<0
0`aS0`Q20PaS00L@Q0aS36<<H`Q236<8@P0836<00a2436<<H`0224800`aS
5:D@Q00224800`aS48@<H`02248236<5248336<3248236<7248236<42480
0`aS48@@Q00236<00`Q236<8@P0924800`aS248<H`02248010aS248<H`aS
0PQ20`aS0`Q20PaS00@@Q0aS36<8@P8<H`03248<H`aS00<<H`03248<H`Q2
0088@P<<H`03248<H`Q200L<H`D8@P0336<8@PaS008@Q08<H`<8@P000P@Q
00D000@Q12448@0000D48@0636<HaQ24248<Ha241@aS00P@Q0aS36<@Q0aS
5:D@Q0aS0PQ20PaS0PQ210aS0PQ20PaS0a2400@DYA2436<@Q0<<H`06248<
H`Q236<@Q0aS0`Q20PaS0Q2410aS00<@Q0aS36<00PaS0Q240`aS00<8@PaS
36<00`aS00<@Q0aS36<00PaS00<@Q0aS36<010aS0Q2400@<Ha2436<<H`8@
Q00636<8@PaS5:D@Q0aS0a2400<<Ha2436<01`aS00<@Q0aS48@00`aS0QBU
0Q2400@<Ha245:DDY@@<H`0648@<H`aS248<HaBU1Q2400<<Ha2436<01A24
00<<Ha245:D00QS600<DYA2436<00Q2400<DYAS65:D00QBU0a240aBU0Q24
00<DYA2448@02Q2400<DYA245:D010aS00<@Q0aS24800`Q21P@Q00@8@P@Q
12448@88@P031248@PQ200@<H`@8@P031248@PQ200<48@@8@P<48@@8@P84
8@H8@P848@@8@P031248@PQ200T8@P8<H`<8@P0:36<48@Q236<@Q1BU48@<
H`Q2124224800`@Q2488@P0312432483124224800`@Q24848@0212422480
0`@Q24848@03248010@Q24848@@Q10Q20PaS00<8@P@Q12401PQ210@Q00@8
@P@Q12448@T8@P041248@PQ2124224800`aS248<H`0336<224803`aS5:DH
aRe[<H`icSF]<Ha244YBCW<mkacW6<H<H`0248@336<448@336<348@336<5
48@00`aS48@<H`0536<248@436<01a2436<<H`aS48@<Ha240088@P0536<@
Q1BU48@<H`0248@236<00`Q236<@Q00436<00`Q236<<H`0336<00a2436<<
H`0336<248@00aBU48@<H`0436<248@436<00a2436<<H`0236<248@236<0
0`Q236<<H`0@36<224800`aS248<H`0248@00`aS248<H`0636<2248236<0
0`Q236<<H`0236<4248436<5248336<3248336<5248010aS48@<H`aS0`Q2
00<<H`Q224800PQ20`aS00<8@PaS248020aS0`Q21@aS10Q21PaS00<8@PaS
24800PQ200@<H`Q22488@P8<H`0348@<H`aS008<H`03248<H`aS008<H`03
248<H`Q200@<H`04248<H`aS248236<00`Q236<8@P0124800003124000@Q
00848@0300048@@Q00848@0700048@aS6<H@Q0aS24800PaS00@@Q0aS36<<
H`<@Q00336<@Q0aS00D<H`<@Q0D<H`03248<H`Q2008<H`8@Q00336<@Q0aS
008<H`@8@P@<H`03248<H`aS00<<H`0848@<H`aS248<Ha2436<8@PD<H`03
48@<H`aS008<H`8@Q0h<H`0448@<H`Q2248236<348@236<348@336<00a24
36<<H`0236<01Q2436<@Q0aS48@8@P8<H`@@Q0<<H`<@Q0<<H`0648@<H`Q2
36<DYA240PaS00<@Q1BU48@00PaS1a2400<DYA2448@00aBU00@@Q0aS48@@
Q08DY@076<HDYA2436<@Q1BU48@00aBU00@@Q0aS48@@Q08DY@8@Q08<H`03
48@DYA2400<<H`0448@DYA2448@336<00`Q236<8@P0812400`0024848@02
12400`Q236<8@P02248336<324821247248312432482124224800`@Q2484
8@06248010@Q2488@PQ20`@Q0`Q200H<H`Q212448@Q236<2248010@Q2488
@PQ20PaS0Q2400D<H`Q22488@P@Q00<8@P848@0324848@@Q00848@042484
8@@Q124224851242248010@Q2488@P@Q0PQ200<48@Q212400P@Q0PQ20PaS
0PQ20P@Q0`Q20P@Q0PQ210@Q0PQ20`@Q0`Q200<<H`Q2248010@Q1@Q200@<
Ha2436<@Q088@P0348@DYBU:008icP0:<H`]Jcg_BU9>Lcg_7>LHaPaS48@2
36<2248236<00a2436<@Q00236<348@236<0112436<<Ha240PaS00D@Q0aS
36<@Q0aS00D@Q0D<H`0348@<Ha2400<<H`0548@<H`aS48@<H`0248@536<3
248010aS48@<H`aS0PQ210aS1A2400<<Ha2436<01@aS00<@Q0aS48@00PaS
00<8@PaS36<00a2400<8@PaS24800PaS00<8@PaS36<02@aS00<@Q0aS36<0
1PaS00H8@PaS36<@Q0aS48@236<224800`aS248<H`0436<00`Q236<8@P02
36<324800`aS48@@Q00224800`@Q248<H`0336<:248010@Q2488@PaS0PQ2
0a2400<<H`Q224800`Q200@<H`Q22488@P@<H`03248<H`Q200@<H`0448@8
@PaS248336<3248736<4248236<00`Q236<<H`0224800`aS248<H`0536<0
10Q236<<H`aS0PQ20`aS00<8@PaS24800PaS00<8@PaS24800`Q200001@00
12448@@Q000010@Q00D000@Q124@Q1cW008@Q0035:D@Q12400H<H`0348@<
H`aS008@Q0X<H`03248<H`aS008<H`<8@P0336<@Q124008<H`04248<H`aS
36<2248236<00a2436<<H`0236<00a2436<<H`02248336<00a2436<<H`06
36<0112436<@Q0aS0a2400D<H`Q236<<HaBU00@@Q0<<H`<@Q00336<8@Q24
00<@Q0@<H`0348@DYA2400L<H`0348@<H`aS00<<H`0648@<Ha2436<@Q0aS
1A241PaS00<@Q0aS36<01@aS00@@Q0aS36<<H`<@Q08<H`8@Q0045:D@Q0aS
48@36<H;5:D248@010aS48@DYABU0a2400D<Ha245:DDYA2400<<H`8@Q003
36<@Q0Q200D8@P848@0324848@@Q00@48@0324848@Q200<8@P848@88@P8<
H`<8@P051248@P@Q248<H`0324801@@Q2488@P@Q24800P@Q0`Q20`@Q00<8
@P@Q24800`Q20P@Q20Q20P@Q00<8@PaS24800P@Q10Q200D48@Q248@@Q0aS
00<8@P<48@88@P0336<48@@Q00848@0424848@@Q248512400`Q21248@P06
124324821245248536<62488124424801`@Q2488@PQ21248@P@Q00P8@P05
36<8@PQ21248@P0336<00a247>LU:@03=Jd01Sg_@Q1Nme[FBU8e[@8HaP<<
H`03248<H`aS008<H`03248<Ha24008@Q0@<H`8@Q0@<H`0448@DYA2448@3
36<348@010aS2488@Q240`aS0Q2400<<Ha2436<00PaS00<@Q0aS36<00Q24
0`aS00@8@PaS36<@Q0<<H`03248<H`aS008<H`03248<H`aS008@Q00436<@
Q12448@224800`aS48@<H`0536<2248236<01a2436<<H`aS48@<H`Q200D<
H`03248@Q124008<H`88@PL<H`04248<H`Q2248236<00aBU48@<H`0236<2
248436<3248236<010Q236<<H`aS0`Q200<<H`Q224800PaS00<@Q0aS1240
2PQ20`aS20Q20PaS0PQ20P@Q00<8@PaS36<00PaS00h8@PaS36<8@PaS248<
H`Q236<8@PaS248<H`Q20`aS00<8@PaS36<00PaS00@8@PaS36<<H`88@P03
36<@Q0Q20088@P0336<8@PaS008<H`0448@<H`aS36<2248336<00`Q236<<
H`0736<010Q236<<H`Q20PaS0@Q20@aS000212401@0012448@@Q00001@@Q
00H<HaS66<H@Q0aS48@25:D248@010aS48@@Q0aS0Q240PaS00@8@Q2448@<
H`88@P<@Q0L<H`03248<H`aS008<H`0348@<H`aS00<<H`04248<H`aS36<2
24800`aS48@@Q00336<00`Q236<@Q00348@536<00`Q236<<H`0336<248@4
36<0112436<<Ha241@aS0Q240`aS00<@Q0aS48@010aS1a2410aS00<@Q0aS
36<010aS00D@Q1BU48@<H`Q2008<H`0348@<Ha2400<<H`8@Q0@<H`035:D@
Q0aS00@<H`H@Q00336<@Q0aS00@@Q0035:DHaQBU008@Q0HDY@0348@DYA24
00<DY@D@Q0035:D@Q124008@Q0055:D@Q12436<@Q00236<0112436<<H`aS
0`Q21P@Q00<8@P@Q12400P@Q00<000Q224800PQ200D48@Q22488@PaS00<8
@P041248@P@Q248212400`Q212448@05248412432483124324800`@Q2484
8@052484124624800`aS2488@P0212401@aS48@DYA2424800P@Q0PQ210@Q
00@8@P@Q1248@P@48@0324848@Q200848@<8@P<48@0624848@Q21248@P@Q
10Q200D<H`Q22488@PaS008@Q00324848@Q200848@<8@P@48@0324848@@Q
00848@0324848@@Q00<8@P848@<8@P031248@PQ20088@P051248@PQ2124<
H`0524828@P01C6<>LhicSg_@Q000U[F00A>LcW>6<HDY@D<H`8@Q0@<H`03
48@<H`aS008<H`8@Q08<H`03248<H`aS008@Q0D<H`<@Q08<H`0348@<H`aS
00<<H`8@Q00336<@Q12400P@Q0@<H`0448@DY@aS36<2248236<00a2436<<
H`0336<00a2436<@Q00436<248@336<2248536<01`Q248@DYA2436<8@PaS
008@Q08<H`0548@8@PQ2248<H`0248@:36<01a2436<8@PQ236<@Q0aS0088
@P0336<8@PQ200@<H`L8@P8<H`@8@P8<H`88@P0436<8@PQ236<724801`aS
2488@PQ21248@PaS0088@P<<H`88@P0336<8@PQ20088@P@<H`03248<Ha24
008<H`04248<H`Q236<3248336<00`Q236<<H`0436<248@3248336<010Q2
36<8@PaS1@Q210aS0PQ210aS0PQ22@aS00<8@PaS48@00@Q2000010001244
8@0010@Q00T000@Q12448@aS6<H<H`Q236<00a2400<<Ha2448@00a240PaS
11242@aS0PQ20`aS00<@Q0aS36<020aS0`Q20`aS00D8@PaS48@@Q0aS00<8
@P<@Q00336<8@PaS00<<H`0348@<H`aS00<@Q0<<H`0448@<H`Q2248348@0
0`aS248<H`0348@236<00a2436<<H`0336<248@236<011245:D@Q1240PaS
00D@Q0aS36<<Ha2400<<H`8@Q08<H`0548@<Ha2436<8@P0336<00`Q236<@
Q00448@436<01Q2436<@Q0aS248<H`<DY@0436<@Q1BU5:D236<011245:D@
Q0aS0a240QBU0aS611cW0QBU00<HaQBU6<H00Q2400@<Ha245:D@Q08DY@8H
aP0648@<H`aS5:DLiaBU1PQ200<48@Q212400P@Q00<8@P@Q12401@@Q0PQ2
0PaS1@Q200P<Ha2436<8@PaS1248@P@Q1@Q200D48@aS36<8@P@Q00D8@P03
1248@PQ200D8@P848@0324848@@Q00848@<8@P061248@PQ21248@P@Q10Q2
00<48@Q224800PaS1PQ200<<H`Q2124010Q20`@Q00<8@P@Q12400`@Q00<8
@P@Q12400PQ200<48@Q224800PQ20P@Q0PQ200P<H`@Q1248@P@Q36<8@PaS
10Q20P@Q0PQ200@<H`Q22488@P@48@0324848@@Q00P8@P031248@PaS00@8
@P071248@PQ2248<H`Q212400`Q20PaS014@Q1BU7>LQ236<@Q16<DYB@Q1N
mfLiBU8e[@aS248@Q0aS008@Q08<H`0348@<H`aS00@<H`8@Q08<H`88@P03
48@<Ha2400@@Q0@<H`<@Q0@<H`0848@<H`aS36<@Q0aS48@DY@8@Q0H<H`8@
Q00636<@Q0aS48@<Ha240`aS00D8@PaS36<<H`Q200@<H`<@Q0<<H`0448@<
H`Q2248436<2248636<011245:D@Q0Q20PaS0Q2400D<H`Q22488@Q2400P<
H`88@PP<H`03248<H`aS008<H`<8@P8<H`<8@P0336<8@PQ200H8@P8<H`88
@P031248@PaS00<8@P8<H`0324848@Q200/8@P0336<8@PaS00L8@P8@Q003
36<8@PQ20088@P0336<8@PQ20088@P8<H`88@P8<H`0348@<Ha2400<@Q0@8
@P<<H`<8@P0336<@Q0aS008<H`03248<H`Q20088@P<<H`88@PX<H`03248<
H`Q20088@P0010@Q00<000@Q00000`@Q00/000@Q36<DYA2436<@Q0aS48@<
Ha24008<H`<@Q00336<@Q124008DY@0348@<H`aS00L<H`03248<H`aS00L<
H`0648@<H`aS248<H`Q20PaS00<8@PaS36<00PaS00<8@PaS36<010aS0a24
0PaS00D8@PaS36<<H`Q200<<H`0348@<H`aS00H<H`8@Q0<<H`@@Q0@<H`03
48@<H`aS008<H`0348@8@PaS00<DY@0536<8@PaS48@8@P0236<00a2436<<
H`0436<01A245:D@Q0aS24800PaS00<@Q0aS36<00PaS0a240PaS0a240`aS
0a2400<<Ha2448@00a240PaS1Q2400PDYA245:DHaQBU6<HDYAS60acW00<D
YAS648@00a240aBU00H@Q1BU48@DYA245:D336<02QBU6<HDY@Q21248@PaS
24848@Q22@@Q0`Q200<48@Q224800PaS00@8@P@Q2488@PD<H`0324848@Q2
008<H`<8@P0548@8@P@Q248<H`0224800`@Q24848@0212401PQ21248@PQ2
1248@P@48@04248<H`aS24821242248312400`Q21248@P0212400`Q236<<
H`0336<01@Q21248@PQ236<01`Q20P@Q00<8@P@Q12400`@Q00@8@P@Q1244
8@<8@P031248@P@Q00848@<8@P031248@PQ200<8@P0336<8@PQ200@8@P84
8@04248<H`Q2248312422484124224800`@Q2488@P0>248010aS2488@P@Q
1@aS00/Lib48<H`icT8@BU96<E[FIcU6<C6<0088@P0448@<HaBU48@:36<4
48@336<00a2436<<H`0348@00`aS248<H`0248@236<00a2436<<H`0536<4
48@336<248@236<0112436<8@PaS0Q2400@<H`Q236<@Q0P<H`0448@<H`aS
48@536<020Q236<<H`aS48@8@PaS248436<0112436<<H`aS0a241`aS0`Q2
00@<Ha2436<<H`<8@PT<H`03248<H`Q20088@P8<H`<8@P<<H`08248<H`aS
36<8@P@Q24848@8<H`03248<H`Q200<8@P0336<8@PQ200@8@P8<H`052484
8@Q2248<H`0524800`aS2488@P03248236<2248536<2248436<4248236<2
24801@aS48@DYA2424800`aS0PQ200@<H`Q22488@P<<H`03248<H`aS00@<
H`03248<H`Q200D8@P0336<8@PaS00<<H`03248<H`aS00<<H`48@P448@00
00<48@0012401P@Q00H000@Q124<HaS648@236<01A2436<<H`aS48@00`aS
0a2400<DYA2448@00PaS0Q240PaS0Q240`aS0Q241@aS0PQ21PaS0PQ20`aS
00<@Q0aS48@01PaS0PQ21@aS00D8@Q2448@@Q0aS0088@P8@Q0<<H`0348@<
H`aS00<<H`0348@8@PaS008<H`0348@<H`aS00<<H`<8@P8<H`0348@<H`aS
008@Q00736<@Q12436<@Q0aS48@01@aS0Q2400@DYA2448@@Q0<<H`03248<
Ha2400<<H`H@Q0@<H`8@Q00436<@Q0aS36<248@00`aS48@@Q0025:D01124
36<<Ha240QBU00<@Q0aS48@00Q240aBU00<HaQBU5:D01aBU00<@Q0aS48@0
0QBU00D<Ha245:DDYA240088@P<<H`88@P@48@0324848@Q20088@PL48@03
248<H`aS00<8@P8<H`@8@P0636<8@PQ2248@Q0aS0Q240`aS1@Q200@48@Q2
24848@H8@P<48@0424848@@Q1243248020@Q24848@@Q24848@Q212422480
20@Q36<DYABU36<48@Q248@236<4248236<224800`@Q24848@0224831240
0`Q21248@P0212400`Q2124<H`0236<01PQ212448@aS248<H`88@P848@88
@P0336<8@PaS008<H`051248@PQ2248<H`0324800`aS2488@P0424800`@Q
2488@P0524800`aS24848@0424800`aS2488@P0424800`@Q2488@P0236<0
4`Q236<DYAS67>L]JcF]>Lhe[D8@AS5BU5[F<H`Q20aS48@DYA2400P<H`03
48@<H`aS00<<H`<@Q0<<H`0448@<H`aS36<248@436<00a2436<@Q00236<2
48@236<00a245:DDY@0236<011245:D<H`aS0PQ200@@Q0aS48@@Q08<H`08
248<H`aS36<8@PaS48@<H`88@P0336<@Q12400@@Q0L<H`04248<H`aS48@7
36<00a245:D@Q00336<348@636<224800`aS48@<H`02248010aS48@<H`Q2
0PaS00@8@PaS36<<H`88@P<<H`88@P<<H`<8@P<<H`03248<H`aS00d8@P8<
H`D8@P0336<8@PQ200@8@P0336<8@PQ200H8@P0736<8@PaS248<H`Q236<0
0`Q20PaS0`Q200<<H`Q224800PaS0Q240`aS0PQ20`aS00<8@PaS36<010Q2
0PaS00L@Q0aS248<H`Q236<8@P0436<00`Q236<8@P0324800`aS48@<H`02
36<2248236<12480000300048@0000848@0300048@0000@48@0436<HaQ24
248336<248@436<348@01PaS48@<Ha2436<@Q0@<H`8@Q08<H`0548@<H`aS
36<8@P0436<2248336<01@Q236<8@PaS24801@aS00<@Q0aS36<00`aS00@8
@PaS36<<H`88@P<<H`05248<H`aS48@<H`0248@736<01PQ236<<H`aS48@<
H`8@Q08<H`88@P8<H`0448@<Ha2436<548@236<248@01@aS48@<H`aS48@0
10aS0a2400<<Ha2448@010aS00@@Q0aS36<<H`8DY@0348@<H`aS00<<H`8@
Q08<H`03248@Q124008@Q0065:D<H`aS36<@Q1BU0Q2400<HaQBU48@00PaS
0QBU0Q2400<DYAS65:D011BU0Q2400LDYA245:D@Q0aS48@DY@0448@011BU
48@<H`Q210aS1P@Q00<8@P@Q124010@Q10Q200@48@Q22488@P848@04248<
H`Q2248336<2248436<00a2436<<H`0336<2248412400`Q212448@022483
1242248010@Q24848@Q20`@Q00P8@P@Q24848@Q2124000Q20PaS00D48@aS
48@DY@aS0088@P<<H`03248<H`aS00@8@P031248@P@Q00<8@P<48@03248<
H`@Q00848@X8@P041248@PQ2124224800`aS2488@P02124236<424800`@Q
2488@P022482124424800`aS2488@P0224800`aS2488@P022483124010Q2
1248@P@Q0PQ200<48@Q2248010Q2018<H`Q248@@Q248<H`e[CW>=Je244YB
F]IF]C6<9BT<H`Q25:D236<248@436<00a2436<<H`0336<00`Q236<@Q003
36<00a2436<<H`0248@436<00a2436<8@P0336<01PQ236<<HaBU48@<H`<@
Q0`<H`03248<H`aS00@<H`0348@<H`aS008<H`8@Q0<<H`8@Q00336<8@PaS
00L<H`03248<H`aS008<H`0448@<Ha2448@436<00a2436<<H`0=36<010Q2
36<<Ha240PQ210aS0PQ20PaS00<8@PaS24800PaS30Q200@<H`Q224848@88
@P0436<8@PQ2248236<624800`aS2488@P05248236<4248436<00`Q236<<
H`0224800`aS248<H`04248336<00`Q236<8@P0236<01A2436<<Ha2436<0
10Q21@aS00D8@PaS36<<H`Q200<<H`@8@P<<H`88@P@<H`03248<H`Q2008<
H`0348@<H`Q200448@0010@Q00D000@Q12448@0000<48@0336<DYA24008<
H`0348@<H`aS00H<H`<@Q0h<H`0348@<Ha24008DY@<<H`0448@<H`aS2486
36<010Q236<@Q1240PaS00D8@PaS36<<Ha2400`<H`8@Q0<<H`0848@<H`Q2
248<Ha2436<8@PP<H`<@Q0<<H`<@Q0<<H`<@Q00336<@Q0aS008<H`0348@<
H`aS008<H`8@Q00336<@Q1BU008DY@0636<8@PaS248<Ha240`aS00@@Q0aS
5:DDY@8@Q0<<H`0448@<Ha2436<348@02QBU48@<H`aS48@DYA2436<@Q1BU
1A2400<<Ha2448@00aBU00@@Q1BU5:DHaP<DY@L@Q088@P<<H`L8@PD48@88
@PT48@@<H`@8@P071248@PaS36<8@PaS24800Q240`aS2PQ210@Q1@Q200@4
8@Q21248@P<48@88@P@48@<8@P0436<8@P@Q36<26<H01A2436<@Q1cW9BT0
0R4800<DYA2436<00PaS00<8@PaS24800PQ22@@Q2PQ200D48@Q22488@PaS
00<8@P@<H`88@P0336<8@PQ200h8@P0336<8@PaS00<8@P0336<8@PQ20088
@P0336<8@P@Q00@8@P848@05248<H`Q236<48@0224803@aS5:DHaR48:DX]
JcW>?NmJeVLiBU8mkaS6008@Q00336<@Q0aS008@Q0H<H`0348@<H`aS00<<
H`0348@<H`aS00@<H`8@Q0<<H`L@Q00536<8@PQ236<DY@0548@00`aS48@@
Q00336<248@010aS248<H`Q210aS00D@Q0aS36<<Ha2400<<H`0748@<Ha24
36<@Q0aS48@010aS00<@Q0Q236<00PaS00@8@PaS36<@Q0@<H`0348@<Ha24
008<H`88@P0336<@Q0aS00<<H`88@P0436<@Q0aS36<224801@aS248<Ha24
36<00PQ20`aS00H8@P@Q248<H`Q236<324800`aS2488@P04248436<42480
10aS2488@PaS0PQ200<48@Q224800PaS0`Q200<48@Q224800`Q200@<H`Q2
24848@<8@P0336<8@PQ20088@P0536<8@PaS36<@Q00236<010Q21248@PQ2
0PaS00@8@PaS36<8@P8<H`<@Q00336<8@PaS008<H`05248<H`Q236<8@P02
36<248@00`Q236<<H`0236<00`Q236<<H`0436<2248236<00a2436<<H`08
36<1248000848@0300048@@Q00D48@0600048@aS6<HDY@Q21@aS00<@Q0aS
36<00PaS0QBU00D@Q0aS36<<Ha2400D<H`0348@<H`aS008<H`@@Q00336<@
Q12400<<H`8@Q003248<H`aS00@<H`8@Q00336<@Q0aS00@<H`0348@<H`aS
00@<H`88@P8<H`03248<H`aS008@Q0@<H`04248<H`aS48@336<248@436<0
112436<<H`Q20`aS00D@Q0aS36<<Ha24008<H`0348@<Ha2400@@Q00436<@
Q12448@336<00a245:D@Q00248@336<348@01`aS2488@PaS48@HaQBU008@
Q08<H`0448@<Ha2436<348@00aBU48@@Q00336<848@011BU48@<Ha240aBU
00<@Q1BU6<H00QS600@DYA2448@@Q08<H`<@Q08<H`0348@<H`Q20088@P8<
H`P8@P<48@88@P<48@D8@P8<H`0824848@@Q24848@Q21248@PD<H`8@Q003
36<8@PQ200<8@P0436<8@PQ2124324800`@Q2488@P022483124224831242
248512400`Q212448@02248236<348@010Q236<@Q2480RDY00<LiaBU2480
1@aS00<48@Q224800P@Q0PQ20`@Q0PQ210@Q0`Q200@48@Q2248<H`D8@P<<
H`<8@P0436<8@PQ236<524800`aS2488@P08248336<2248010aS2488@P@Q
10Q200@48@Q212448@88@P0436<8@PaS36<224803PaS248DYAS68@PYBS6<
@Q0mkeJeHaQ:DSg_6<H248@00`aS48@@Q00;36<348@336<00a2436<<H`02
36<348@536<248@336<00a2436<@Q00648@236<248@536<00`Q236<<H`07
36<248@436<248@010aS48@<Ha240PaS00@@Q0Q236<8@P@<H`88@P0336<@
Q0aS008<H`0548@<H`aS36<@Q00<36<01`Q236<8@PaS48@<Ha2400<8@P03
1248@PQ20088@P8<H`0424848@Q2248236<2248010@Q2488@PaS0PQ200<<
H`Q236<00PQ20P@Q00D8@PaS36<8@P@Q0088@P0636<8@PaS1248@P@Q30Q2
00D<H`Q22488@PaS0088@P<<H`03248<H`Q200@8@P@<H`88@P<<H`8@Q004
248<H`Q2248436<010Q236<<H`aS0PQ20PaS0`Q210aS1@Q210aS00@8@PaS
248<H`H8@P0000H000@Q124000@Q000612400`aS6<H@Q00336<248@436<0
1Q2436<@Q1245:D@Q0@<H`0348@<H`aS008<H`0548@<H`aS248<H`0248@0
1@Q236<@Q1BU48@010aS00<@Q0aS48@00a240`aS00<@Q0aS36<01PaS1124
10aS0Q2410aS00<8@PaS36<00Q241PaS00@8@PaS48@@Q0X<H`<@Q0065:D<
H`aS248<HaBU0Q2400<DYA2436<00PaS0a240QBU0`aS00<@Q1BU48@00`aS
00D8@PaS248<HaBU00@@Q08DY@0348@<H`aS00D@Q0035:D@Q124008<H`8@
Q00436<@Q1245:D448@25:D01a2436<@Q1BU6<HDYA2400<DY@0348@<Ha24
00<@Q00336<@Q124008<H`<8@P0736<8@PQ2248<H`Q236<00`Q200<48@Q2
24800`@Q00<8@P@Q12400P@Q0PQ20PaS00<8@P@Q12400`Q200d48@Q22488
@P@Q248<HaBU48@<Ha245:D<H`0224800`aS2488@P0424801`@Q24848@@Q
24848@Q200848@0524848@Q21248@P0212400`Q212448@06248236<010Q2
36<DYABU0Q2400X<HbU:DYAJeU:D<H`LibDY7>LDY@8@Q00536<48@Q2248<
H`021243248212400`Q236<8@P04124224800`aS248<H`0324801PaS48@@
Q0aS248<H`8@Q00436<48@@Q248236<2248212401@Q21248@P@Q24800PaS
0`Q200D<H`Q224848@Q2008<H`<8@P031248@PQ200D48@@8@P8<H`88@P08
36<8@Q246<HU:Cg_@Q1>L`9:DP06F]Hmkc6<5:D<Ha240PaS112400<<H`Q2
36<01PaS0Q240`aS00H@Q1BU48@@Q1BU48@236<448@236<02Q245:D@Q0aS
248@Q1BU36<8@Q240QBU0`aS00<@Q0aS36<00`aS00L8@PaS36<8@PaS248<
H`0448@236<00a2436<@Q00336<00a2436<<H`0248@011BU48@8@PQ220aS
00<@Q0aS36<01A240`aS00<@Q0aS36<02@aS00@8@PaS36<@Q08<H`04248<
H`Q2248236<010Q236<8@PaS0`Q20PaS00<8@P@Q24800PaS0PQ200<@Q0Q2
24800PQ200<<H`Q2248010Q200<<H`Q236<00`Q200<<H`Q236<030Q20PaS
00@8@PaS2488@P8<H`88@P0336<8@PQ20088@PD<H`88@P<@Q003248<H`aS
008<H`03248<H`aS00<<H`03248<H`Q200L<H`<8@P<<H`05248<H`Q236<@
Q00836<324800003124000@Q00<48@0400048@@Q0002124010aS5:D<H`aS
0Q240PaS00<8@PaS36<00PaS00@@Q0aS48@@Q0D<H`03248<H`aS00/<H`8@
Q0<<H`8@Q08<H`D@Q0X<H`04248<Ha2448@536<01A2436<<H`aS48@00PaS
00<8@PaS36<020aS0a2400<<H`Q236<00Q240PaS00@8@PaS48@<H`@@Q08<
H`@@Q08<H`8@Q0<<H`0348@DYA2400<<H`0548@<H`aS36<8@P0436<00a24
36<<H`0248@35:D0112436<<H`aS0Q2400@DYA2448@DY@8@Q00536<@Q124
48@<H`0648@00aBU48@DY@0548@00aBU6<HDY@0248@01PaS48@@Q0aS48@D
Y@8@Q00636<8@PQ2248<H`Q20PaS0PQ200D<H`Q22488@P@Q00@8@P<48@88
@P<48@03248<H`Q200H8@P071248@PQ224848@Q236<00QBU00<@Q1BU36<0
10aS10Q200@<H`Q224848@88@P051248@P@Q1248@P051242248412422482
12401@Q248@<H`Q236<00QS60a2400XaS5:DF]I>Lbe[7>LU:AcW6<H@Q0<<
H`L8@P848@88@P<48@<8@P041248@PQ236<324801@aS248<Ha2436<00PQ2
00D@Q1BU36<8@P@Q0088@P041248@P@Q2482124424801@@Q248<H`Q236<0
0PQ200L48@Q224848@Q2124<H`0324800`@Q2488@P021244248236<22482
36<03`Q236<HaRU:@Q16<DYBAS5:DUJe?NlaS12436<@Q00:36<348@336<2
48@436<648@01`aS48@@Q0aS48@<Ha2400D<H`0348@<Ha24008@Q08<H`03
248<H`aS008@Q0P<H`0448@<H`aS48@536<00a2436<<H`0936<01A2436<<
H`aS24800PaS00<8@PaS36<00PaS00@@Q0aS248<H`8@Q00336<8@PaS00<@
Q00336<8@PQ200P<H`<8@P8<H`<8@P0636<8@PaS248<H`Q20`aS0`Q20PaS
0`Q200<<H`Q236<00`Q20`aS00<48@Q2248020Q20PaS0PQ200<48@Q22480
0PQ20PaS00@8@PaS36<<H`<8@P8<H`88@P8<H`L8@PL<H`8@Q08<H`04248<
H`aS248236<01A2436<<H`Q236<00PQ21@aS00@8@PaS2488@P<<H`88@P@<
H`03248<H`aS00<<H`88@P448@000`@Q00<000@Q12400P@Q00L000@Q1244
8@Q26<H@Q00236<548@010aS48@<H`aS0a2400PDY@aS36<8@PaS48@<Ha24
0`aS00<@Q0aS36<01PaS00@@Q0aS2488@P8<H`8@Q0H<H`<@Q0<<H`<@Q003
36<8@PaS008<H`03248@Q12400X<H`05248<H`aS36<8@P0236<01PQ236<<
H`aS48@<H`8@Q0L<H`0348@<Ha2400@<H`0348@DYABU00<@Q00436<@Q0aS
36<248@236<01Q2436<@Q0Q248@<H`8@Q0D<H`8@Q00536<@Q12436<@Q002
5:D00a2436<<H`035:D248@336<648@336<448@011S65:D@Q1240QS600@D
YA2448@DY@8@Q00336<8@Q24008DY@0348@8@P@Q00H8@P0336<8@PQ2008<
H`<48@03248@Q0aS00<8@P031248@P@Q00D8@PH48@0524848@Q2248<H`02
248236<011BU48@@Q0aS0a2400<<H`Q212400PQ200D48@Q224848@Q20084
8@0324848@@Q00848@0424848@@Q24851246248212403`aS5:DHaQBU7>LY
BTYBE[EJeV<HF]INme[F@Q0aS0026<H01PaS2488@PQ236<8@PD48@@8@P84
8@<8@P848@03248<H`aS00H8@P0536<@Q1BU48@<H`041244248312432480
0`aS24848@02248248@020aS2488@PQ21248@P@Q2482124424800`@Q2488
@P06248236<01PQ236<<HaBU:DXaS096<@07BU9BU4YBBU8aS1cW48@030aS
0a2410aS00L@Q0aS48@@Q1BU48@<H`0448@00`aS48@@Q00236<248@010aS
48@@Q1240PaS11240PaS00<@Q0aS36<01PaS00<8@PaS36<00Q240`aS0Q24
10aS0a240PaS0PQ20a2400D<H`Q236<@Q0aS008@Q0L<H`03248<H`aS008@
Q00336<8@PaS008<H`88@P0336<@Q0aS0088@P@<H`<8@P0436<8@PQ22482
36<010Q236<8@PaS20Q20PaS0PQ200P@Q0aS12448@Q236<8@P@Q1@Q200<4
8@Q224800`Q200<48@Q224800`Q200<48@Q224801@Q200L<H`Q22488@PaS
24848@02248736<010Q236<<H`aS0PQ200<<Ha2448@01`aS00H8@PaS48@@
Q0aS248536<01@Q236<<H`Q2124010aS10Q210aS10Q20PaS0PQ200021240
0`001240000512401@00124@Q1BU48@00PaS112400<<Ha2436<0112400<<
Ha2448@010aS00<@Q0aS36<00`aS0a241PaS00<8@PaS36<00Q2400<<Ha24
48@00`aS0Q240PQ200<<HaBU5:D01PaS00<@Q0aS24800PaS0Q240PaS00@8
@PaS48@@Q0@<H`04248<H`aS36<224800`aS48@@Q00248@436<2248536<0
212436<<H`aS48@DYA2436<348@436<548@010aS48@<Ha240PaS0a2410aS
0a240`aS00h@Q1BU6<H@Q0aS248<HaBU6<HDYA24248<HaBU11240QBU00<@
Q0aS36<01A2400<DYA245:D011BU00@@Q1BU48@@Q08<H`0748@HaQ242484
8@Q236<01PQ20`aS10Q20PaS00<8@P@Q24800`Q20`@Q0`Q210@Q0PQ200<4
8@Q2248010Q200D<Ha245:D@Q0aS008@Q00436<8@PQ2248236<01@Q236<8
@PaS248010@Q0PQ200<48@Q212400PQ210@Q0PQ20P@Q00<8@PaS24800`Q2
00L<Ha245:D@Q248;F]:DP02F]H036<HF]INme[F@Q0aS1S65:D@Q0aS248<
H`88@P848@@8@P041248@P@Q2483124424800`aS24848@0224801@aS2488
@PQ236<00QBU00<<H`@Q12400PQ21P@Q00D8@P@Q1248@P@Q0088@PD<H`03
1248@PQ200L8@P0336<8@P@Q00<8@P041248@PQ236<5248236<01Q24;F/e
[Dic@Q16<@=>L`04<H`Lia24124336<01a2436<<Ha24248<H`Q2008<H`8@
Q00336<@Q0aS00d@Q08<H`8@Q00436<@Q12448@536<248@@36<00a2436<<
H`0336<01A2436<<H`aS48@010aS0a2400<<H`Q236<01@aS0PQ20a240PaS
0Q2400@<H`Q2248<H`<@Q088@P0336<@Q0aS00<8@P8<H`0348@<H`aS00<<
H`05248<H`Q2248<H`0224800`aS2488@P0324800`@Q2488@P0236<010@Q
2488@PaS0PQ200<<H`Q236<01@Q200P<H`Q2248<H`Q236<8@P@Q1`Q200D<
H`Q224848@Q200<<H`H8@P@<H`031248@PQ2008<H`88@P8<H`0448@<H`Q2
36<248@00`aS2488@P0336<010Q236<<Ha240`aS00@8@PaS36<<H`<8@P<<
H`88@P0336<8@PaS008<H`03248<H`Q2008<H`04248<H`aS36<2248136<1
1240000300048@@Q00<48@0300048@@Q00<48@0448@LiaBU248336<348@0
1@aS48@DYABU48@00PaS00<8@Q2436<00a241PaS00@8@PaS36<@Q0@8@P8<
H`07248<H`aS36<@Q0aS24800PaS00D@Q0aS36<<Ha2400P<H`<@Q0035:D@
Q0aS00<<H`8@Q00336<8@PaS008@Q0D<H`0548@<H`aS248<H`025:D01124
36<8@PaS0Q2400D<H`Q236<<Ha2400<<H`0448@<H`aS36<25:D02A2436<<
Ha245:D@Q0aS248@Q0025:D00a2436<@Q00248@436<01A2436<<H`aS48@0
10aS0a240PaS00LDYAS65:D@Q0aS48@DY@0348@00`aS48@@Q00948@00`aS
48@@Q0025:D248@55:D448@25:D236<6248236<2248010@Q248<H`Q20P@Q
10Q210@Q00<8@P@Q248030@Q1@Q200<48@Q236<00PaS00@8@PaS36<<H`<8
@P0336<8@PaS00H8@P@48@0824848@@Q24848@Q21248@P<48@88@P0>36<8
@P@Q124<Ha246<HDYBDY<HaJeVmkMkekgP9_N`0;LiakgW_N>LhU:@Q2124<
H`Q21248@P02124010001248@PQ210@Q0PQ20`@Q00@<H`Q224848@88@P<<
H`88@P0736<@Q12436<8@P@Q24801@@Q00D8@P@Q1248@P@Q00<8@P0436<8
@PaS36<4248010aS24848@Q210@Q0PQ200<48@Q212400`aS2@Q200`<HaS6
8@PaS2e[?Nm6<DicDY@e[Be[7>L436<01A2436<<H`aS48@00PaS11240PaS
00<@Q1BU5:D01A2400D<Ha2448@@Q0aS00<@Q00336<8@PQ2008<H`0;48@<
H`aS48@DY@aS248<HaBU48@<H`0448@2248010aS48@@Q12410aS00<@Q0aS
36<01PaS0a2400@8@PaS36<@Q08<H`<@Q00336<@Q0aS00@<H`0348@<H`aS
00D<H`04248<H`aS48@636<2248236<01a2436<<H`aS248<Ha240088@P<<
H`<8@P0536<8@PQ2248<H`0324800`aS2488@P02248336<010Q236<8@PaS
0PQ200<<H`Q224800`Q20P@Q0PQ200L<H`Q22488@PaS24848@0824800`@Q
2488@P0236<324800`aS248<H`0336<2248836<01a2436<<H`aS248<H`Q2
008<H`8@Q0<<H`0748@<H`Q2248<Ha2436<00PQ21PaS00L@Q0aS2488@PaS
48@<H`0824800003124000@Q00848@0400048@@Q000312401A247>L@Q0aS
48@00PaS0Q2400@DYA2448@<H`8@Q0095:D<H`aS248@Q1BU48@<Ha24008<
H`04248<H`aS5:D248@636<010Q236<<H`aS0Q2410aS00@@Q0aS36<<H`D@
Q0<<H`8@Q00336<@Q1BU008@Q00336<@Q1BU008@Q08<H`03248<H`aS00<<
H`8@Q0<<H`03248<H`aS008@Q00736<@Q0aS36<8@PaS24800PaS00L@Q1BU
48@@Q0aS248<H`0348@010aS48@@Q1240`aS1A240aBU00<@Q0aS24800PaS
0a2400@<H`Q236<<H`8@Q0@<H`045:DHaQS65:D548@010aS248@Q1240QBU
00H@Q0aS36<@Q1BU48@236<248@01QBU48@@Q1245:DHaP8DY@046<HDYA24
36<248@01ABU48@<H`Q212402@Q20PaS10Q200<48@Q224800`Q21@@Q00<8
@P@Q12400`@Q0PQ200@48@Q224848@P8@P0336<@Q124008<H`04248<H`aS
36<72485124010Q21248@P@Q0PQ200<48@Q212401@Q20`aS0PQ200L@Q1S6
5:DYBS6<G_McW002Mkd01f]JLiacW7ooNmhicR4800848@0324848@@Q00D4
8@88@P03124000@Q00D48@88@P8<H`<8@P8<H`03248<H`Q200<<H`88@P03
1248@P@Q00<48@0524848@Q224848@0224800`@Q2488@P0224800`aS2484
8@03248010aS1248@PQ210@Q00@8@PaS2488@P848@0H248<H`Q236<48@Q2
36<8@PaS1248@QBU8@PicSF]@Q16<DYBDY@icRU:6<H<Ha241`aS0Q2400<D
YA2436<00Q2400@DYA2436<<H`<@Q00436<@Q1245:D248@536<0112436<<
Ha242@aS00@@Q1BU48@@Q0D<H`03248<H`aS00D<H`8@Q0D<H`<@Q00336<@
Q0aS00<<H`0348@<H`aS00<<H`8@Q0<<H`0348@<H`aS008<H`0848@<Ha24
36<@Q0aS48@8@P<<H`03248<H`aS008<H`0348@<H`aS00@<H`07248<H`aS
36<8@PaS248010aS00<8@PaS36<00`Q20PaS0`Q200<<H`Q2248020Q20PaS
20Q200H<H`Q224848@Q2124624800`@Q36<<H`0236<2248236<3248536<0
1@Q236<<H`aS248020aS00<8@PaS24802PaS00@8@PaS36<<H`<8@P0436<8
@PQ2248236<00`Q236<<H`0236<4248336<1248000<48@0300048@@Q00@4
8@0700048@aS5:D<H`@Q36<00a240QBU00P@Q0aS248<Ha2436<@Q0aS0Q24
00<DYA2436<00PaS00P8@Q2436<8@PaS48@DY@aS0PQ200<<H`Q236<010aS
00<@Q0aS48@00Q2400<<H`Q224800PaS0Q240`aS00L@Q0aS36<@Q0aS248<
H`0348@636<248@01@Q236<<HaBU48@00PaS00<@Q0aS36<01`aS00@@Q0aS
36<8@P<<H`0448@<H`aS248236<348@636<848@00aBU36<<H`0236<248@2
36<010Q236<@Q1240`aS00L@Q0aS36<<Ha2436<@Q0035:D;48@00`aS48@D
Y@0248@010aS48@@Q12411BU00<@Q1BU5:D0112400DDYA2448@@Q0aS00<8
@P0436<8@P@Q124324801@aS248<H`aS24800`@Q1@Q20P@Q0`Q210@Q00<8
@P@Q12400`@Q1PQ200<48@Q224800PQ200<48@aS36<00`aS0`Q200D<H`Q2
2488@P@Q00@8@P<48@D8@P848@0324848@@Q0088@P0336<8@PQ20088@P8<
H`8@Q009:DXaS4icIcU[FWNmLia_Nf]J009oo`07JeYBU1S636<8@P@Q2480
1@@Q00@000@Q1248@P<48@88@PD@Q00336<8@PQ200<8@P848@04248<Ha24
36<224800`@Q2488@P031242248010@Q2488@PaS0`Q20PaS1PQ20`@Q10Q2
00<48@Q236<01`Q200<48@aS24800PQ200<48@Q224800QBU00HQ21cW:DXa
S48@CW<2BU8023F]8@PDY@Q236<@Q0aS48@236<448@236<00a245:DDY@02
48@00`aS5:DDY@0248@436<248@236<0112436<<H`aS0a2400<8@PaS36<0
11240PaS0a2400<8@PaS48@00PaS00@8@PaS48@@Q0<<H`<@Q0D<H`0548@<
Ha2436<@Q00636<348@536<248@236<00`Q236<<H`0436<248@336<00a24
36<<H`0224800`aS48@@Q00436<4248236<00`Q236<<H`0236<8248236<8
248236<224801@@Q2488@PQ236<00PQ200L48@Q22488@PaS248<H`022480
1@aS2488@PQ212400`aS10Q200H<H`Q22488@PaS248248@00`aS248<H`02
36<3248336<2248010aS48@<H`aS0`Q200H<Ha2436<8@PaS248636<22483
36<224800`aS48@@Q00236<0112436<8@PQ20`aS10Q2000212401@001244
8@@Q00000P@Q00D000@Q124<HaBU00<<H`P@Q08<H`H@Q0045:D<H`aS2485
36<00a2436<<H`0236<5248436<448@00`Q236<<H`02248248@01@aS2488
@PaS48@010aS0a240PaS0a2410aS00@@Q0aS36<@Q08<H`03248<Ha2400@<
H`0548@<H`Q236<8@P0236<00a2436<<H`0336<348@436<0112436<@Q124
0`aS00<DYA2448@00PaS11241@aS0`Q200<<Ha2448@010aS1Q2400<DYA24
48@00Q2400<DYA2448@00Q2400HDYA2436<@Q0aS48@25:D00a2436<@Q002
5:D00aS648@@Q0035:D00a2436<@Q00248@01QBU36<@Q0Q236<8@P8<H`<4
8@88@P<<H`88@P051248@PQ21248@P021244248312400`Q212448@021240
1PQ212448@@Q24848@T8@P848@06248<H`aS48@<H`Q20PaS00<8@P@Q1240
0P@Q0PQ21@@Q00<8@P@Q248010Q200<48@Q212401PQ200`<H`Q236<@Q1BU
;F/e[E:DHaQ_NgNmLi`2JeX2Ool01f<HCW<@Q0aS124000Q200H48@88@P@4
8@05248<H`aS248<H`0248@00`aS24848@0324801P@Q0008@Q245:D<H`84
8@0324848@@Q00848@0424848@Q21242248236<010Q236<@Q0Q20P@Q0`Q2
00<48@Q224800P@Q10Q20P@Q00<8@P@Q124010@Q00<8@P@Q24800`Q200@4
8@Q236<DY@8Li`8]J`08@Q1>LdYBBU8aS2486<H8@P<<H`0448@<Ha2436<3
48@00`aS48@DY@035:D01PaS48@<H`aS48@DY@H@Q0/<H`<@Q0@<H`0448@<
H`aS48@436<0112436<<H`aS0Q2400<<Ha2436<00Q241@aS00<@Q0aS36<0
0PaS00X@Q0aS248<HaBU48@<H`Q236<@Q0<<H`0348@<H`aS0088@P0336<@
Q12400D<H`8@Q00336<8@PaS0088@P0436<8@Q2448@236<2248336<32482
36<3248436<020Q236<<H`Q21248@PaS48@324800`aS2488@P0224800`@Q
2488@P0?24800`@Q36<<H`0424801@aS2488@PQ236<01@Q21@aS0`Q210aS
0PQ210aS10Q21@aS00L8@PaS2488@PaS48@<H`03248336<2248010aS48@<
H`Q20PaS00D@Q0aS2488@PaS00<8@P4<H`48@P0000D000@Q12448@0000<4
8@0700048@@Q0008@QBU36<00PQ20PaS0Q2400<<Ha2448@00PaS0a2400<<
Ha2448@00QBU00D@Q0aS36<<Ha24008<H`<@Q00336<8@PaS00@<H`0448@D
YA2448@436<01`Q236<<H`aS248<H`Q200@<H`8@Q08<H`88@P0336<@Q0aS
008<H`0348@<H`aS008@Q00436<8@PQ236<248@236<348@01ABU48@@Q124
36<00Q2400<<Ha2436<02`aS0a2400@<Ha2448@@Q0@<H`8@Q0@<H`0348@<
H`aS008<H`03248<H`aS00@<H`8@Q0<<H`8@Q0@<H`0448@DYA245:D448@0
0`aS48@@Q00=48@02ABU36<@Q1BU6<HDYA2436<@Q0025:D00a242488@P03
24801`@Q2488@PQ21248@P@Q00D8@P@48@88@P0336<8@P0000D48@032484
8@Q200H48@0424848A2448@236<00`001248@P0324800`@Q248<H`042482
36<010@Q24848@Q210@Q00<8@P@Q12400P@Q0PQ200<48@Q224801PQ200T<
H`Q236<@Q0aS124@Q2DY>Lh00RU:01<e[E:DF]IF]F<HG_MJeU:D>Lhe[AcW
5:D<H`Q236<8@Q245:D@Q00224801@001248@PQ212400`Q20a240PaS00H8
@P@Q2488@PaS2482124010Q236<@Q0aS0`@Q10Q200@48@Q22488@P8<H`8@
Q08<H`0524848@@Q248<H`02248212401@Q21248@PQ236<00P@Q10Q200<4
8@Q224800PQ200<48@Q224800PQ200@48@Q236<8@P8<H`0:48@U:BDY@Q1:
DUJeHaQ>LcF]9BT248@536<248@236<25:D248@00`aS48@@Q00348@236<2
48@00aBU48@@Q00236<248@336<010Q248@@Q1240`aS112400<DYA2436<0
0PaS00T@Q0aS36<<Ha2436<@Q0aS48@00`aS0a2410aS00@@Q0aS36<8@P8<
H`8@Q08<H`8@Q00336<8@PaS00<@Q00336<8@PaS00@<H`08248<Ha2448@<
H`Q236<@Q08<H`88@P0436<8@PaS36<248@00`aS48@<H`03248010aS248<
H`Q20PaS0PQ20PaS0`Q200<<H`Q212400PQ200@<H`@Q248<H`88@P848@88
@P0336<8@P@Q00848@04248<H`aS248212400`aS248<H`07248236<010Q2
1248@PaS0PQ200<48@aS24800PQ20PaS0PQ20`aS00<8@PaS36<010Q20PaS
00@8@PaS36<8@P@<H`03248<H`Q2008<H`@8@P<<H`0548@<H`aS36<8@P04
36<00`Q236<<H`0248@236<224800`aS2488@P0236<124800004124000@Q
0008124010aS5:D@Q0Q20`aS0a240`aS00<@Q1BU48@00Q2400<<Ha2448@0
11240`aS0Q240PaS00DDY@aS36<8@P@Q008<H`035:D@Q0aS008@Q0H<H`03
48@DY@aS008<H`03248@Q0aS0088@PD<H`0448@<H`aS248336<248@236<0
0`Q236<@Q00348@00`aS48@DY@0248@01@aS48@@Q0Q236<00Q240PQ20PaS
00@@Q0aS36<8@P8<H`0548@<H`aS36<@Q00536<00a2436<<H`0348@010aS
48@@Q1242`aS0a240`aS0a240PaS0a2400<DYA2436<011240aBU0PaS0Q24
0QBU1Q2400@DYAS65:DDY@8@Q00636<@Q1BU6<H@Q0aS0P@Q00@<H`Q22488
@P848@0324848@Q20088@P031248@P@Q00@48@<8@P031248@PQ200<48@03
24848@@Q00848@0824848@@Q1248@P@Q248<H`8@Q00324848@Q200848@<8
@P848@03248<H`aS00@8@P@48@88@PH48@88@P051248@P@Q1248@P031243
248248@02`aS248@Q2DY=JdYBRDY=JeBU5kgDY@00V<H00UF]DYB<H`aS1cW
6<H<H`Q236<00a2400<<H`Q212401P@Q00@8@Q245:D<H`88@P0336<8@PQ2
0088@P0336<8@P@Q0088@P<<H`<8@P848@0324848@Q200@8@P0436<@Q0aS
36<524800`@Q2488@P0324800`@Q2488@P02124524800`@Q24848@02124:
24802a245:DQ2248@Q1:DUJeHaQ>LcW>8@P00Q240`aS00<8@Q2448@01a24
00<<Ha2448@00Q2400<<Ha2448@00Q240PaS00HDYA2448@<Ha2436<22480
0`aS48@@Q00236<448@00`aS48@@Q00336<0112436<<H`Q20PaS00D@Q0aS
48@@Q0aS00<8@P<@Q0T<H`0448@<H`aS36<248@336<248@436<0112436<<
H`Q210aS0PQ20PaS0`Q21`aS00<@Q0aS36<00PaS10Q20PaS00<8@PaS2480
0`aS00L8@PaS2488@PaS248<H`0<24800`aS2488@P0424800`aS2488@P03
24800`aS2488@P0;24800`aS2488@P0224801`aS2488@PaS48@DY@aS0088
@P0436<8@PaS248436<2248236<324801@aS248<H`aS24800`aS00<8@PaS
24800`aS00D8@PaS248<H`Q200<<H`0448@<H`aS36<2248536<3248000@4
8@0300048@0000<48@0700048@aS5:D@Q0Q236<00a240`aS00@@Q0aS36<<
H`8@Q00436<@Q1245:D248@436<00a2436<@Q00248@436<00a2436<<H`02
36<0112436<@Q1241PaS0Q241`aS0PQ20`aS00<8@PaS36<010aS00<@Q0aS
36<00`aS1Q2400L<Ha2448@DYA2436<@Q00236<548@236<00`Q236<8@P03
36<448@236<00a2436<<H`0348@236<348@;36<00a245:D@Q00236<00a24
36<<H`0336<00a2436<@Q00448@00`aS48@<H`0248@011BU36<<H`aS0a24
00@DYA2448@DY@8@Q00336<@Q1BU008HaP8Li`035:D@Q0aS00<<H`88@P04
1248@PQ224851243248212422483124224800`aS24848@04124224841240
0`Q21248@P0336<01@Q212448@Q212400`Q200<48@Q224800PQ200@48@Q2
248<H`@8@P031248@P@Q00<48@@8@P848@0324848@@Q00D8@P0836<8@PQ2
48@DYAS65:D@Q08DY@0348@HaQcW00<YBP06<H`e[Be[9BTDYAS60Q2400<<
H`Q236<00Q2400<<H`Q2124010Q20P@Q00@8@PaS36<<H`D8@P8<H`88@P04
36<8@P@Q248236<224800`@Q2488@P06248436<010Q236<<H`aS0`Q200@<
Ha2436<8@P848@/8@P031248@PQ200848@88@P0636<8@PQ21248@P@Q0`aS
0Q2400TaS3g_E[ES64icAS4aS1S65:D02A2400<<Ha2448@00Q2410aS00<@
Q0aS48@011240PaS00DDYA2436<<H`Q2008<H`8@Q0@<H`8@Q08<H`@@Q08<
H`<@Q08<H`<@Q00536<@Q0aS36<8@P0636<0112436<<H`Q210aS00<8@PaS
48@00Q2400@<Ha2436<@Q0T<H`06248<Ha2448@<H`Q20`aS00<8@PaS36<0
0`aS00<8@PaS48@00PaS0`Q200D<H`Q236<8@PaS00D8@P@<H`03248<H`Q2
008<H`D8@P0336<8@PQ200848@L8@P051248@PQ2248<H`07248010aS248<
H`Q20PaS0`Q20`aS10Q20Q240PaS00D8@PaS36<8@PaS0088@P8<H`0448@<
H`Q236<324801PaS48@@Q0aS248@Q0D<H`0348@<H`aS0088@P@<H`88@P08
36<8@PQ2248<Ha2436<8@P8<H`88@P4<H`48@P48@P000P@Q00<000@Q1240
10@Q00D000@Q124@Q1BU0088@P0336<DYA2400<<H`<@Q0@<H`<@Q0045:D@
Q12448@236<01A2436<<Ha2436<00a240`aS00@@Q0aS48@@Q0<<H`03248@
Q0aS0088@P0436<@Q12448@436<0112436<<H`Q21`aS00<@Q0aS36<00PaS
00<8@Q2448@00Q240PaS1A2400<<Ha2448@00Q240PaS00L@Q1BU48@@Q0aS
48@8@P0336<0112436<<H`Q20PaS00D@Q1BU36<@Q0Q2008<H`0448@DYA24
48@336<0112436<<H`aS0Q240PaS00@8@PaS2488@P8<H`8@Q08<H`0648@<
H`aS36<@Q0aS0Q2400L<Ha2448@@Q1BU48@<H`0348@336<0212436<<H`aS
48@DYA245:D248@01@aS48@DYAS67>L00QS60a240PaS00L8@P@Q12448@Q2
1248@P051242248212400`Q21248@P02248212400`Q212448@0212400`Q2
1248@P0312400`Q212448@02124336<324800`@Q24848@0424800`@Q2484
8@0724801@aS24848@@Q24800`@Q0PQ200P48@Q22488@P@Q24848@Q20P@Q
0`Q200<<Ha245:D00QBU0Q240QBU00<Lib489BT00RU:00@e[C6<:DXQ208H
aP0348@<H`Q20088@P8<H`03248<H`Q200<8@P848@88@PD<H`L8@P8<H`88
@P<<H`0524848@Q2248<H`0324800`aS2488@P0536<00`Q236<<H`022483
36<00`Q212448@0424800`@Q2488@P0224800`@Q2488@P02124224800`@Q
36<8@P0724803@aS5:D@Q2U:@Q1F]F<HBU96<CW>7>L@Q0aS00<@Q08<H`@@
Q00336<@Q12400D@Q0<<H`@@Q00336<@Q124008@Q0D<H`8@Q00436<@Q0aS
48@336<248@336<00a2436<@Q00436<01QBU48@DY@aS248<H`8@Q0@<H`05
48@8@PQ2248<H`0348@236<00a2436<<H`0;36<00a2436<<H`0536<01A24
36<<H`Q236<00PQ210aS00<8@PaS36<00PaS0`Q200<<Ha2448@00PaS0PQ2
1@aS0`Q20`aS00@8@P@Q2488@P8<H`H8@P0336<8@PQ200<8@P0536<8@PQ2
1248@P0336<324800`@Q2488@P08248236<01@Q236<<H`aS48@00PaS0PQ2
1PaS0PQ20PaS00D8@PaS36<<H`Q200@<H`88@P8<H`0448@<H`aS248336<0
1@Q236<<Ha2436<00`Q20Q2400H<H`Q236<8@PaS248236<3248000060004
8@@Q00048@000P@Q00T000@Q12448@aS6<H<H`Q236<00a240PaS0a2410aS
00<8@PaS48@00Q2400<8@PaS48@00a240`aS0Q2400@<Ha2436<8@P<<H`8@
Q00336<8@Q24008@Q00336<8@PaS00@@Q08<H`0348@<H`aS00@<H`8@Q0@<
H`<@Q08<H`03248<Ha24008@Q00536<@Q1BU6<H@Q00236<348@01ABU48@@
Q0aS24800Q2400<<H`Q236<00a2400<<Ha2436<00`aS0a2400@<Ha2436<<
H`8@Q08DY@8@Q08<H`<@Q0<<H`<@Q0<<H`0548@<H`aS36<8@P0236<248@4
36<00a245:D@Q00336<348@00`aS48@@Q00448@236<348@00aBU48@@Q002
48@021BU48@@Q1BU6<H@Q0aS1242248212400`Q21248@P0912401PQ21244
8@@Q24848@@8@P061248@P@Q1248@P@Q0PQ20`@Q1`Q20P@Q00<8@P@Q2480
0`@Q1@Q20P@Q0`Q200<<H`@Q24800`@Q00H8@P@Q12448@Q2124424821247
24801PaS248]JcW>@Q0aS08@Q08DY@047>LHaQBU5:D26<H01QBU48@<H`aS
48@<H`D8@P848@H8@P031248@PQ20088@P0336<8@PQ200@8@P0336<8@PQ2
00D8@P<<H`88@P031248@PaS00<8@P031248@PQ200@8@P8<H`035:D<Ha24
00<<H`0324848@@Q00@8@P<48@0336<8@PQ200848@@8@P0336<8@P@Q0088
@P8<H`07248<H`aS48@Q22DY>Lh00T8@00@mkc6<9BTQ208DY@/@Q0<<H`03
48@DYA2400L@Q08<H`<@Q08<H`8@Q08<H`0648@<Ha2448@<Ha240PaS00<@
Q1BU48@00PaS0a240PaS00<@Q0aS48@01`aS0Q2400<DY@aS36<00PQ200@@
Q0aS36<<H`<@Q08<H`03248@Q12400D<H`03248<Ha24008<H`88@P0536<@
Q12436<8@P0236<0112436<8@PQ20PaS00@@Q0Q22488@P@<H`88@P<<H`@8
@P0336<8@PaS00@<H`03248<H`Q20088@P<<H`<8@P031248@PQ200L8@P03
36<8@PQ200/8@P041248@PaS36<3248236<01@Q236<8@PaS24801PaS0PQ2
00<<H`Q224800`aS00<8@PaS248010aS0PQ21PaS00@8@PaS36<@Q0@<H`05
48@<H`Q236<8@P0536<2248336<00`Q236<8@P0224800003124000@Q00L4
8@0400048@aS5:D236<248@336<00a2436<<H`0636<248@836<00aBU48@@
Q00248@00aBU36<<H`0336<00a2436<<H`0236<248@236<00`Q236<@Q002
5:D00`aS48@<H`0448@236<0112436<<H`aS0Q240`aS0Q241`aS00D@Q1BU
5:DDYA24008<H`0448@DYA2448@236<00a2436<<H`0636<0112436<<H`Q2
0PaS112410aS00<@Q0aS48@01Q240`aS00H8@PaS48@DY@aS248236<01aBU
48@<H`aS248<Ha2400@<H`0348@<Ha24008@Q0<<H`8DY@8@Q0<<H`8@Q08D
Y@X@Q00436<DYAS648@424800`aS12448@0212400`Q212448@0512422484
124424801`@Q24848@@Q24848@Q200H48@H8@P<48@<8@P071248@PQ22484
8@Q2124010Q200@<H`Q22488@P848@0324848@Q20088@P061248@PQ21248
@P@Q0`Q20P@Q0`Q200/<H`Q236<YBSW>?NlaS12436<DYAS6008Li`8DY@0>
6<HLiacW48@<H`Q248@<H`Q21248@PaS24848@T8@P041248@PQ2248236<3
248336<324800`@Q2488@P04248336<;248010aS48@@Q1240PaS1@Q20P@Q
0PQ200D<H`@Q24848@Q200@48@03248<H`Q200<8@P0336<8@PQ2008<H`03
248@Q124008U:@09<H`icSg_>LhaS2U:8@PDYA24008<H`0348@<Ha2400H@
Q0<<H`8@Q0<<H`@@Q08<H`@@Q00436<@Q0aS36<248@336<00a2436<<H`05
48@00aBU48@@Q00536<548@436<0112436<<H`aS0PQ200<<Ha2448@010aS
00D@Q0aS248<H`Q200<@Q00336<@Q0Q200d<H`0448@<H`Q2248436<01Q24
36<<H`Q236<@Q0L<H`@8@P0336<8@Q24008<H`88@P8<H`03248<H`Q200<8
@P031248@PaS008<H`88@P0336<8@PQ200D8@P@<H`l8@P0436<8@PQ22482
36<348@010aS2488@PaS0`Q21@aS00@8@PaS36<8@P8<H`8@Q00336<8@PQ2
008<H`0548@<H`Q236<8@P0436<00`Q236<<H`0236<010Q236<<Ha240PaS
00@@Q0aS2488@P<<H`88@P000P@Q00@000@Q124000H48@0448@HaQ242482
48@00`aS248<H`0448@011BU48@<H`Q210aS00<8@PaS248010aS00H8@PaS
36<@Q0aS248336<01A2436<@Q1BU48@01@aS00<8@PaS36<0112410aS00<@
Q0aS36<00PaS112400<<Ha2448@01`aS0Q2400D<Ha2448@@Q1BU00<@Q08<
H`@@Q00336<@Q0aS00D<H`8@Q00436<@Q1BU48@336<548@00`aS48@@Q007
48@936<00a2436<<H`0536<00`Q236<<H`0448@01@aS48@<H`Q236<00Q24
0`aS0Q2400<DYA2448@00Q240QBU0a2400@<Ha2448@<H`<@Q08<H`0348@<
H`Q200<8@P848@88@P03124000@Q00D48@0324848@Q20088@P848@88@PL4
8@0624848@@Q1248@PaS0`@Q0PQ200<48@Q224800`Q200<48@Q212400P@Q
00@8@P@Q24848@<8@P031248@PQ20088@PD48@88@P848@@8@P848@88@P03
1248@PQ200<<H`8Li`09BU9W>EJe@Q0@Q0aS48@<Ha2400<DY@0348@<H`Q2
00D8@P041248@PQ2248236<00`Q212448@05248010@Q24848@@Q0`Q20P@Q
00H8@PaS36<8@P@Q2482124010aS248<H`aS0PQ200@48@Q22488@P848@@8
@P03124<Ha24008@Q08<H`0348@<H`Q200848@88@P051248@PQ21248@P03
124010Q21248@P@Q0PQ200D<H`Q236<8@P@Q0088@P8<H`0>248<H`aS6<HD
YBDY;F/icTHa?Nle[Be[6<HDY@8<H`0348@<H`aS008@Q0<<H`D@Q0<<H`@@
Q00436<@Q1245:D236<01PQ236<<H`aS48@<H`8@Q0H<H`8@Q00336<@Q124
008@Q00536<@Q1245:D@Q00736<00`Q236<<H`0248@336<00`Q236<<H`03
36<248@436<00a2436<<H`0436<348@436<00`Q236<8@P0436<01A2436<8
@PaS48@00PaS0PQ20PaS00<@Q0aS36<010aS0PQ21`aS0`Q200@<H`Q22484
8@<<H`03248<H`Q2008<H`@8@P0436<8@PQ2124224800`aS2488@P062482
36<624801PaS248<H`aS48@<H`<8@P0436<8@PQ236<3248336<00`Q236<<
H`0636<00`Q236<<H`0536<01@Q236<@Q12436<00PQ20PaS00<@Q0aS36<0
1@aS00@8@PaS48@<H`<8@P8<H`0348@<H`aS0048@P0000D000@Q12448@00
00<48@0800048@@Q124<HaBU48@8@PH<H`8@Q0@<H`0348@<H`aS00<@Q08<
H`03248<H`aS00<<H`0448@<H`Q2248436<00a2436<<H`0248@236<01124
36<<H`Q20PaS0a240PaS0Q241@aS0Q240PaS00@@Q0aS36<<H`88@P8@Q08<
H`0848@<H`aS248<HaBU48@DY@8@Q00436<@Q0aS36<448@636<00`Q236<D
Y@025:D010aS248<Ha240QBU00<@Q0aS36<00PaS00<DYA2448@01A240PaS
0PQ20`aS00<@Q0aS36<00Q240`aS00@@Q0aS36<8@P8<H`0748@<H`aS36<@
Q0aS48@00PaS0a240PaS1A2400@DYA245:D@Q0<<H`<@Q00636<@Q12448@D
Y@aS0PQ22P@Q00<000@Q12400PQ210@Q00<8@P@Q12400`Q20`@Q0PQ20`@Q
00<8@P@Q24800P@Q00@8@P@Q12448@88@P848@0324848@Q200848@88@P05
1248@P@Q24848@0324800`@Q2488@P02248212422482124010Q212448@@Q
1@Q200<48@Q224800PQ20PaS00THaQcWCW=W>EJe@Q0DYA245:D00PQ200D@
Q1S65:D<H`Q2008<H`848@@8@P031248@PQ20088@P848@<8@P031248@PQ2
00848@@8@P041248@PQ236<6248010@Q248<H`aS0`Q20P@Q00L8@P@Q2484
8@Q21248@P0236<348@236<00a2436<8@P0524841244248212401PQ21248
@PQ236<48@88@P<<H`04248<H`aS48@25:D01b48;F/mkdYB?NlaS2U:008H
aP8<H`06248<Ha2448@<H`Q20PaS0Q241@aS00<@Q0aS48@00Q240PaS0a24
00X8@PaS48@DY@aS248<Ha2436<@Q0@<H`<@Q0<<H`L@Q0<<H`0548@<H`Q2
248<H`0248@00`aS48@<H`02248336<01@Q236<<HaBU48@00`aS0a2410aS
00<8@PaS36<02@aS00<8@PaS36<00`aS00H8@PaS36<<H`Q236<2248836<3
24801@aS248<H`Q236<00`Q20PaS1@Q200D<H`Q22488@PaS00@8@P8<H`@8
@P0336<8@PQ20088@P051248@PQ2248<H`02248236<7248236<2248236<0
1@Q236<<Ha2436<010Q20PaS00D8@PaS248<Ha24008<H`88@P0548@<H`Q2
36<@Q00436<248@324801PaS48@8@PQ236<@Q08<H`88@P0436<8@PaS48@2
36<224800`aS48@<H`0124800003124000@Q00<48@0900048@@Q124000@Q
48@HaQ24008<H`0448@<H`aS36<248@00`aS48@<H`0436<0112436<@Q124
20aS00@8@Q2448@@Q0D<H`0348@<H`aS008<H`0448@<H`aS48@436<248@2
36<248@236<00`Q236<<H`0236<01Q2436<<H`aS48@<H`8@Q00336<DYA24
00@<H`8DY@8@Q00336<@Q12400<@Q0<<H`8@Q0<<H`8@Q08<H`0:1248@QS6
8@Pe[C6<5:D@Q0Q236<248@00`aS48@DY@0236<011246<HHaQBU1PaS00<8
@Q2448@00`aS0Q2410aS00@@Q0aS36<<H`8@Q00336<@Q0aS00<<H`D@Q003
36<8@PaS00<DY@8@Q08DY@8@Q0<<H`L@Q0065:D<H`Q2124000Q22P@Q00<8
@P@Q12400P@Q0PQ20`@Q0PQ20P@Q10Q200@48@Q21248@PP48@88@P@48@88
@P848@0324848@@Q0088@P031248@PQ20088@P041248@P@Q248212400`Q2
1248@P0324800`@Q2488@P0724800`aS248<H`0248@28@P02Cg_BU9>Lekg
BU8]JaS6124<H`0524800`aS2488@P03248212400`Q21248@P0424800`aS
2488@P0212401`Q212448@Q2124<H`Q200848@@8@P848@88@P051248@PQ2
24848@022484124224821242248336<010Q236<<H`aS0PQ20`aS0PQ20`@Q
0PQ200<<H`Q224800PQ200D<H`Q22488@P@Q0088@P0336<8@PaS00@<H`0<
48@Lib48:DXe[C6<>Lhe[BDY7>L<Ha240PaS00<@Q0aS48@0112400<<Ha24
36<00Q240PaS00<@Q0aS48@00`aS11240`aS00@@Q0aS36<<H`8@Q0P<H`<@
Q0<<H`D@Q00536<8@PaS5:D<H`0224800`aS48@<H`0436<010Q236<<Ha24
0`aS0a241@aS00<@Q0aS36<00PaS00<8@PaS24802`aS00<8@PaS36<01@aS
10Q210aS0PQ21@aS00<8@PaS248010aS0`Q20PaS00<8@PaS24800`Q20PaS
0`Q20PaS10Q20`aS00<8@P@Q24800`aS00<8@P@Q12401PQ20PaS0Q240PaS
1PQ20`aS00<8@PaS36<00`aS00<8@PaS36<00PaS00@@Q0aS36<8@P@<H`03
48@<H`aS008<H`0348@<H`Q200<<H`03248<H`aS00@<H`0448@<H`Q22482
36<00a2436<<H`0236<000<48@0300048@0000<48@0700048@@Q36<HaQ24
24800`aS0a240`aS00<@Q0aS24800PaS0Q240`Q200<<Ha2436<01`aS0Q24
1@aS00D8@PaS36<@Q0aS00<8@P@@Q00636<8@Q2448@DYA240`Q200<<H`Q2
48@00Q240PaS0a240PaS00<@Q0aS36<00PaS1A2400<<Ha2436<0112400@<
Ha2448@@Q08<H`03248<H`aS008<H`0948@8@P@Q6<HQ236<;F/DYA240088
@P<@Q0055:D@Q0aS36<@Q0025:D01QS636<<H`Q236<@Q0<<H`<@Q0H<H`03
48@<H`aS00@<H`045:D<H`aS48@636<01Q2436<@Q1245:D@Q0DDY@0348@<
H`aS008@Q0045:D<H`aS36<248@011BU48@<H`Q20P@Q00<000@Q12400`@Q
00D000@Q12448@Q200@48@D8@P<48@88@P<48@88@P031248@P@Q00848@03
24848@@Q01048@0324848@Q200848@<8@P<48@88@P<48@<8@P<48@<8@P03
1248@PQ200<8@P0<36<@Q1248@PU:Cg_AS5BU5kgAS4]JaS60PQ20PaS00D8
@P@Q24848@Q2008<H`0524848@Q236<8@P031244248010aS2488@P@Q0`Q2
00<48@Q212400`Q200<48@Q224800P@Q0PQ200<48@Q224800`Q20P@Q00D8
@P@Q24848@Q200<48@05248<H`Q236<8@P0236<010Q236<8@PaS10Q200@4
8@Q22488@P<48@D8@P0336<8@P@Q0088@P0436<8@PQ2248236<01PQ236<<
HacW8@PYBP<e[@0:<H`U:BDY6<H@Q0aS248@Q0aS48@336<348@336<448@0
0`aS48@@Q00348@436<00a2436<<H`0236<00a2436<<H`0436<248@010Q2
36<@Q1240`aS1A240PaS00D@Q0aS36<8@PaS008@Q00736<8@PaS36<@Q0aS
24800`aS0Q2410aS0Q241`aS00L@Q0Q236<<Ha2436<8@P0536<00a2436<8
@P0224800a2436<<H`0236<2248736<4248436<2248020aS48@<H`aS248<
H`Q236<4248336<010Q236<8@PaS10Q200<<H`Q236<00PQ200D48@Q22488
@PaS00T8@PH<H`<8@P8<H`88@P041248@PaS248336<00`Q236<<H`0236<0
10Q236<@Q1240PaS00<8@PaS36<01@aS00@@Q0aS36<<H`88@P@<H`03248<
H`aS008<H`05248<H`aS36<@Q00536<0000300048@@Q00T48@03248HaQ24
008@Q08<H`03248<H`aS00<<H`0348@<H`aS00L<H`05248<H`aS36<@Q006
36<548@436<0112436<<H`Q220aS00PDYA2448@@Q0Q236<@Q0aS0a240`aS
0a2400<<Ha2448@00Q2400<DYA2436<00Q240QBU0a240PaS00H@Q1BU5:D@
Q0aS48@436<0212436<<H`Q236<@Q1BU48@236<01ABU48@<H`Q236<00QBU
0Q240`aS00@DYA245:D@Q0@<H`0348@<H`aS0088@P0336<@Q124008<H`8@
Q00336<8@PQ200<@Q004248<H`Q236<448@436<00aBU36<@Q00248@45:D2
48@00`aS48@@Q00248@01PaS48@@Q1BU48@<H`88@PH48@0324848@Q20084
8@0324848@@Q00848@88@P<48@88@PD48@0324848@Q20088@PL48@052484
8@Q21248@P0312432482124010Q212448@@Q0PQ21@@Q0`Q200D48@Q21244
8@Q200<48@P8@PH<H`<@Q0035:DLibU:008]J`05>Lhe[BDY5:D48@0<2482
36<00`Q212448@0924801@@Q2488@PQ212400PQ200<<H`@Q12400`Q200<4
8@Q212400PQ200<48@Q224800`Q200<48@Q224800PQ20`@Q00L8@P@Q2488
@PaS24848@0224835:D00a2436<8@P052482124224801@aS2488@PQ21240
0PQ21`aS00D@Q1BU5:DHaRU:008e[@05;F/aS3W>8@PDY@0224800a2436<<
H`0236<248@436<348@236<648@00`aS48@@Q00248@336<00a2436<@Q002
48@636<010Q236<<Ha2410aS00<@Q1BU48@00PaS00<8@PaS36<02@aS00<@
Q0aS36<010aS00@@Q0aS36<@Q0L<H`8@Q0D<H`0348@<H`Q2008<H`8@Q003
36<8@PaS008<H`03248<H`aS008<H`<8@P<<H`05248<H`aS36<8@P0736<0
10Q236<<H`aS0PQ20PaS0PQ210aS00<8@PaS24802PQ200D<H`Q22488@P@Q
00<8@P0336<8@PQ200<8@P0436<8@P@Q36<248@3248236<3248010aS48@<
H`Q21PaS00<@Q0aS24800PQ200<<Ha2436<00PaS00<@Q0aS36<00PaS00<@
Q0aS36<00PaS00<8@PaS36<00PaS0PQ220aS0`Q200<<Ha2436<00@Q20000
1`@Q00048@@Q00048@0000848@0600048@@Q36<HaQBU0`aS00<8@PaS36<0
0PaS0Q2400<<Ha2448@00PaS00<8@PaS36<01PaS00D8@PaS36<<Ha2400<<
H`@@Q0P<H`88@P8<H`8@Q00536<@Q1245:D@Q00336<2248010aS48@DYA24
0PQ20PaS00@@Q0aS36<<H`8DY@H@Q0045:D@Q12448@236<248@01QS65:D@
Q12436<8@P8<H`8@Q0@<H`<@Q00436<@Q0aS248236<00a245:DDY@0336<3
5:D01@aS48@<H`aS24801PaS00<@Q0aS36<01@aS00@@Q0aS48@@Q0<<H`8@
Q0055:D@Q12436<@Q00436<0112436<@Q1240QS60Q2400@8@PaS48@<H`8@
Q0035:D@Q124008@Q08<Had48@0424848@@Q1243248412400`Q212448@03
124424800`@Q24848@0224800`@Q2488@P0412400`Q21248@P0224831242
2482124224800`@Q2488@P04248236<3248336<248@02`aS5:DDYB489BTY
BSW><H`U:ABU12400PQ20PaS00D8@P@Q2488@PaS0088@P031248@PQ200<8
@P848@<8@P0336<8@PQ200<8@P848@88@P0436<8@PQ21242248312422480
0`@Q2488@P04124824800`@Q24848@0224801@@Q2488@PQ248@00QBU00<@
Q0Q212400PQ200<48@Q212401`Q200<48@Q212400`Q20`aS00h8@PaS48@D
YA246<HU:C6<>Lh]Jc6<>LhU:ABU0PQ200D@Q0aS36<<Ha24008<H`<@Q004
36<@Q12448@336<25:D248@336<0112436<<H`aS0a240PaS0Q241PaS00@@
Q0aS48@@Q0@<H`@@Q0H<H`0348@<H`aS00L<H`0548@<H`aS48@<H`0248@3
36<00a2436<8@P0236<00a2436<<H`0236<248@010aS2488@PQ210aS0PQ2
0PaS00<@Q0aS36<00PQ20PaS1@Q20PaS00H8@PaS48@@Q0aS248236<00`Q2
36<<H`0436<00`Q236<8@P0336<3248236<<248010aS2488@P@Q1PQ20PaS
0`Q20PaS10Q210aS00<8@PaS24800`Q200@<H`Q22488@P8<H`0348@8@PaS
008<H`0348@<H`aS008<H`0348@<H`aS00<<H`8@Q0@<H`03248<H`aS008@
Q00436<8@PQ2248336<00`Q236<8@P0336<1248000848@0300048@@Q00D4
8@0600048@aS6<HDY@Q20`aS00LDYA2448@<Ha2436<@Q00436<00a2436<<
H`0;36<01A2436<8@PaS48@00QBU00<@Q0aS36<00PaS0Q240PaS00<8@PaS
36<010aS0a2410aS00<8@PaS48@00a241PaS0a2400@DYA2448@<H`8@Q003
5:D@Q124008@Q0<DY@0336<@Q124008@Q00336<@Q0aS00<@Q00436<@Q124
48@436<02A2436<<H`Q236<@Q1BU6<H@Q00236<011245:DDYA240`aS00<@
Q0aS24800PQ200<<Ha2448@00`aS00T@Q0aS36<<H`Q236<@Q1BU36<00PQ2
00@<Ha2436<<H`@@Q08<H`0348@DYABU008<H`8@Q00536<@Q1245:D<H`02
48@25:D436<00`Q212448@0712400`Q212448@0<1243248412401@Q21244
8@0012400`Q20P@Q0PQ210@Q00<8@P@Q248010@Q00<8@P@Q124010@Q1`Q2
00D<H`Q212448@Q200<48@88@P03124<H`aS008@Q00336<@Q12400@<H`03
48@<H`Q200<<H`0548@<Ha2436<@Q00236<01PQ21248@PQ236<48@88@P09
48@<H`Q2248<H`Q21248@PaS0088@P051248@PQ224848@03248010@Q2488
@PaS2@Q20`aS0PQ20P@Q00D8@PaS36<<H`@Q00@8@P<48@88@P0336<8@PQ2
0088@P0336<8@PaS008<H`8@Q08<H`88@P051248@PQ224848@0324831242
24800`aS2488@P0236<03PQ236<<HaBU48@DYAcW9BTaS2e[=JdicRU:8@P8
36<00a2436<<H`0448@336<01A2436<<Ha2436<00a2430aS0Q241@aS00D@
Q0aS36<@Q0aS0088@P0436<DYA24248636<01A2436<<H`aS48@010aS0a24
1@aS0a2400<<Ha2436<00PQ200@<Ha2436<<H`8@Q00536<8@PaS5:D<H`02
248236<01PQ236<<Ha2436<8@P8<H`H8@P0348@<H`aS00<8@P0548@<H`aS
36<8@P0336<00`Q236<<H`03248236<4248010aS248<H`aS1@Q20PaS0P@Q
00<8@Q2436<00PQ20PaS00D48@Q22488@PaS00@8@P0336<8@PQ200@8@P03
36<8@PaS008<H`03248<H`aS008<H`88@P0936<@Q0aS36<8@PaS248<Ha24
00<<H`03248<Ha2400T<H`<@Q00436<8@PQ2248336<2248336<3248236<1
2480000500048@@Q1240000312401`0012448@@Q36<HaQBU008@Q0<<H`8@
Q00336<8@PQ200T<H`04248<H`aS36<2248336<35:D236<011BU6<HDY@Q2
0PaS0a240PQ200@<Ha2448@<H`88@P0336<@Q124008<H`8@Q0<<H`0348@<
Ha2400@<H`<8@P8@Q08<H`8@Q0<<H`0348@DYABU008@Q00336<@Q1BU00<@
Q00336<@Q124008<H`<@Q00436<@Q12448@436<00a2436<<H`0236<00a24
5:D@Q00248@236<011245:DDYA240`aS00@8@PaS36<@Q0<<H`04248<Ha24
48@236<00a2436<@Q00736<0212436<@Q1BU48@<H`Q236<248@00aBU48@@
Q00248@25:D248@01PQ236<@Q1S65:D@Q088@P8<H`0324848@@Q00H48@03
24848@@Q00D48@0324848@@Q00848@<8@P@48@0324848@@Q00848@88@P@4
8@0324848@Q200<48@88@P031248@P@Q0088@P<48@88@PD48@0324848@@Q
00<8@P051248@PQ2248000021245248010aS48@@Q12420aS0Q2400L<H`Q2
248<Ha245:D@Q00236<00`Q212448@03248236<224801@@Q2488@PQ236<0
0`Q200H48@Q224848@Q2124424800`@Q248<H`03248212400`Q2124<H`03
24800`aS2488@P04248236<224800`@Q2488@P022484124324801PaS2488
@PQ236<@Q0<<H`0348@8@PQ200848@88@P0436<8@P@Q1248248236<32480
1@aS48@HaQcW9BT00Re[00@icSF]9BTQ208@Q00336<8@PaS00<<H`<@Q004
36<@Q0aS36<348@00`aS48@@Q00548@236<00a2436<<H`0248@336<01124
36<<Ha2410aS00<@Q0aS48@010aS0Q2410aS00<8@PaS24800PaS0Q2410aS
00D@Q0aS2488@Q24008<H`0448@DYABU48@436<2248:36<01A2436<8@PaS
24800PaS00<8@PaS248010aS10Q20PaS0PQ20PaS00<8@PaS36<01@aS0`Q2
0PaS00D8@PaS36<8@PaS0088@P0536<8@PaS248<H`0224801@aS2488@PQ2
36<00`Q200<<H`Q224803PQ20`aS0PQ20`aS00@8@P@Q36<<H`<8@P<<H`<8
@P8<H`88@P<<H`88@P0436<@Q1BU48@;36<01A2436<<H`aS48@00PaS00<8
@PaS36<00`aS00@8@PaS36<<H`88@P0000<48@0012400`@Q00@000@Q1240
00848@0536<HaQ2436<@Q00236<348@236<00`Q248@<H`0336<01A2436<8
@PaS48@00PaS00L8@PaS36<<Ha2436<8@P0436<448@336<248@00aBU36<8
@P0236<0112436<8@PQ21@aS00D@Q1BU48@<H`Q2008<H`0348@<H`aS00<<
H`0348@<H`aS008<H`8@Q00436<@Q12448@236<248@01aBU48@<H`aS48@<
Ha24008DY@0348@<H`aS008@Q0035:D@Q124008<H`0348@<HaBU00<@Q0@<
H`H@Q00336<@Q12400<<H`04248<H`aS36<248@336<01Q245:D@Q12436<@
Q0H<H`<@Q0<<H`8@Q0045:D@Q0aS36<348@236<248@01aBU36<@Q0aS48@D
YA24008<H`@8@P`48@88@P<48@0500048@@Q36<8@P041242248412400`Q2
12448@0312401@Q21248@P@Q248010@Q00<<H`Q212400PQ20`@Q0PQ20`@Q
0`Q200<48@Q224800`Q200H48@Q21248@P@Q24821242248336<011BU6<HD
YABU0Q2400L<H`Q236<@Q1BU48@8@P0236<3248236<00`Q236<8@P072482
124010Q236<<H`Q210aS00P48@Q224848@Q21248@PaS0Q2400@8@P@Q248<
H`<8@P031248@PQ20088@P0336<8@PaS00<8@P<<H`88@P041248@P@Q2482
1244248010@Q2488@P@Q0PQ200<<H`Q224800PQ200H<H`Q22488@P@Q2483
1247248010@Q36<<Ha240PQ20PaS00<8@PaS36<00Q2400THaRDY:DXaS2U:
8@PLiaBU48@010aS0Q2400H<Ha2436<@Q0aS48@236<00a2436<@Q00236<0
0a2436<@Q00436<248@436<248@336<01@Q248@<H`aS24801@aS00/8@PaS
36<<Ha2436<@Q0aS48@<Ha2400@<H`0348@<Ha2400D<H`8@Q00436<8@PQ2
36<248@436<00a2436<<H`0224800`aS48@<H`0636<01@Q236<<H`aS2480
1PaS0PQ200<<H`Q224800PQ200D<H`Q2248<Ha24008<H`88@P@<H`06248<
H`aS36<8@PaS0PQ200@<H`Q236<<H`<8@P0336<8@PQ200H8@P@<H`88@P04
1248@PQ236<3248236<3248336<010Q236<8@PaS0PQ210aS0PQ20PaS00D8
@PaS36<<Ha2400@8@P0348@<H`aS00@<H`8@Q00336<@Q0aS00<8@P0336<@
Q124008<H`03248<H`aS008<H`<8@P0336<8@PQ200@8@P<<H`000P@Q00@0
00@Q124000H48@0548@HaQ24248<H`0248@00`aS48@@Q00436<00a2436<<
H`0248@00`aS248<H`0;36<2248011245:DDYA240`aS0Q240`aS00@8@PaS
48@<H`88@PD<H`0348@DY@aS00P<H`<@Q0@<H`0348@<Ha2400<@Q0045:D@
Q12436<548@336<348@336<348@336<448@536<00a2436<@Q00248@236<2
48@236<01Q2436<8@PaS248@Q0<<H`<@Q0<<H`8@Q0@<H`0348@<H`aS008<
H`0348@<H`aS00P@Q0045:D@Q12436<248@011BU48@@Q0aS0Q2400D<H`Q2
36<@Q0aS00H48@0600048@@Q24848@Q220@Q00@8@P@Q2488@P848@032484
8@@Q00848@0324848@@Q00D48@<8@P848@0424848@Q22483124236<31242
2484124020Q212448@@Q248<H`Q212432483124010Q212448@@Q0PQ200L@
Q1BU5:DHaQ2436<@Q00436<448@01@aS1248@PQ236<00PQ200<48@Q236<0
0`Q200<48@Q224800`Q200@<H`Q22488@P<<H`<8@P031248@PQ2008<H`03
48@<H`aS00@8@P<48@<8@P8<H`0348@<H`Q20088@P8<H`05248<H`Q22484
8@062482124424803@@Q24848@Q236<8@PaS248<H`Q21248@P@Q00@8@P03
36<8@PQ20088@P031248@PQ200<<H`<8@P8<H`04248@Q1BU6<H29BT01Re[
9BTQ22485:D@Q0H<H`0348@<Ha2400<@Q00336<@Q0aS00@@Q00336<@Q124
008@Q00336<@Q0aS008<H`<@Q00336<8@PaS00D<H`8@Q0P<H`<@Q004248<
H`aS48@436<0112436<@Q1240PaS00D8@PaS48@<Ha2400H<H`0948@<H`aS
36<8@PaS48@<Ha24008<H`0348@<H`aS00L<H`88@P8<H`8@Q00436<8@PaS
248236<224801@aS2488@PQ236<00Q240`aS00@8@PaS2488@P8<H`0548@<
H`Q2248<H`0224800`aS2488@P0424800`aS2488@P0336<3248236<22480
0`aS248<H`0236<3248336<010Q236<<H`aS10Q200@<H`Q22488@P<<H`@8
@P8<H`03248<H`aS00@<H`88@P0336<8@PaS00<@Q0@<H`0748@<H`aS36<8
@PaS48@00`aS00D8@PaS2488@PaS00<8@P0336<@Q0aS00<8@P4<H`48@P00
00D000@Q12448@0000<48@0800048@@Q124<HaS648@<H`@@Q00336<@Q0aS
008@Q0@<H`0348@<H`aS00L<H`<@Q08<H`04248<H`aS48@236<448@020aS
48@@Q12436<@Q0aS48@336<010Q236<8@PaS0Q240PaS00@@Q1BU5:D<H`88
@PD<H`<@Q00336<8@Q2400<@Q0035:D@Q12400<<H`<@Q08<H`8@Q0<<H`06
48@<H`aS36<@Q0aS112400<<Ha2448@00Q2410aS0a240PaS0a240`aS00<@
Q0aS36<00PaS00L@Q0aS48@<Ha2436<@Q00236<011245:DDYA240PaS00<8
@Q2448@00PaS0Q240PQ200<<Ha2448@00PaS11BU0PaS0Q240PaS0QBU00<<
H`Q224800PaS00<8@P@Q12402P@Q00<000@Q12401`@Q0PQ20`@Q0PQ200@4
8@Q2248<H`88@P<48@0524848@@Q24848@0924800`@Q24848@0424831244
36<2124010Q236<<H`aS0`@Q00D8@P@Q2488@P@Q0088@P031248@Q24008L
i`8HaP035:D<H`Q20088@P8<H`D8@P<<H`<8@P041248@P@Q248412422480
10@Q24848@aS0`Q200<48@Q212400`@Q00D8@PaS36<<H`Q200848@@8@P84
8@04248<H`aS36<224800`@Q2488@P0236<224800`@Q2488@P0312400`Q2
12448@03124224800`aS24848@0224800`aS24848@021244248010@Q2488
@PaS1`Q200@48@Q2248<H`848@88@P0448@<H`aS48@36<H01b489BTYBR48
6<HDYA2400P<H`8@Q0@<H`0348@<H`aS00<@Q08<H`0348@<H`Q2008@Q003
5:D@Q0aS00@<H`03248<H`aS00@<H`03248<Ha24008<H`88@PD<H`06248<
H`aS48@<Ha241@aS0Q241`aS00<@Q0aS36<00`aS00D@Q0aS36<<H`Q200<<
H`88@P0336<8@Q24008<H`0:48@<H`aS36<8@PaS48@<H`Q236<4248536<2
248336<2248010aS48@@Q0aS0PQ20PaS00@8@P@Q2488@P<<H`D8@P0336<8
@PQ20088@P0336<8@PQ2008<H`<8@P@<H`88@P0336<8@PQ20088@P0336<8
@PaS00@<H`<8@P<<H`88@P<<H`04248<H`Q2248536<010Q21248@PaS0PQ2
00<<Ha2436<00`aS00@@Q0aS36<8@P<<H`03248<H`Q200@<H`<8@P8<H`@8
@P0336<8@PaS008<H`48@P000P@Q00D000@Q12448@0000848@0600048@@Q
248HaQ240`aS0Q241@aS00H@Q0aS36<@Q0aS48@936<00a2436<<H`0236<0
1Q2436<<H`aS48@<H`@@Q00436<@Q12448@536<2248536<248@00aBU48@@
Q00236<010Q236<<Ha240PaS0Q2410aS00<@Q0aS48@00Q2400<<Ha2436<0
11240PaS0Q241`aS0a240PaS0Q2400<DYA245:D00Q240PaS0a240PaS00DD
YA2448@<Ha2400L<H`<@Q08<H`0448@<H`aS36<248@25:D336<248@236<2
48@336<00aBU48@@Q00348@00aBU48@DY@0336<348@536<00`Q212448@05
1242248?12400`Q212448@031243248010@Q24848@Q20P@Q00@8@P@Q1244
8@88@P041248@PQ236<524800`@Q2488@P04124224800a2436<<H`032480
10aS2488@PQ20`@Q00<8@PaS12400`@Q00H8@P@Q36<@Q1S67>L36<H236<2
24800`aS248<H`0224800`@Q2488@P0236<52486124324800`@Q24848@04
248312400`Q21248@P0236<3248212400`Q212448@02124436<312400`Q2
124<H`0236<010Q21248@PQ20`@Q00<8@P@Q124010@Q0`Q200<48@Q22480
1@Q200<48@Q224800PQ20P@Q00H8@PaS24848@Q236<212400`Q236<<H`02
24801`@Q2488@PQ236<@Q1BU008HaP035:DLib48008YBP056<HDY@aS36<@
Q00736<248@336<348@236<00a245:D@Q00336<348@<36<00`Q236<<H`02
36<01@Q236<8@PaS48@00`aS0PQ200@@Q0aS48@@Q0P<H`0548@<Ha2436<@
Q00436<0112436<<H`Q21`aS0`Q20PaS00<@Q0aS24800PaS00<8@PaS2480
2@aS1PQ20PaS0PQ210aS0PQ20PaS00<8@PaS36<00PaS10Q20`aS0PQ200<4
8@Q236<00`aS1PQ20`aS0`Q200@48@aS248<H`88@P@<H`03248<H`Q200@<
H`<8@P0336<8@PaS00P<H`88@P@<H`03248<H`aS008<H`0348@<H`Q200<<
H`<8@P0348@<H`Q20088@P0336<@Q0aS00@8@P0336<8@PQ200<<H`<8@P44
8@0000@000@Q124000P48@0436<DYA2436<248@836<448@936<010Q236<<
H`aS0Q2400@<Ha2436<<H`8@Q0035:D@Q0aS00<@Q00336<@Q0aS008<H`03
24848@Q200D<H`0348@<H`aS008<H`8@Q08<H`03248<H`aS008<H`<@Q0H<
H`<@Q08<H`0348@<H`aS00D<H`0548@<H`aS248<H`0448@02PaS48@@Q124
36<@Q1BU48@DYA240`aS0Q2400@<Ha2448@@Q08<H`0348@DYA2400D<H`<@
Q08<H`8@Q00436<@Q1245:D448@636<548@00aBU48@@Q00348@00aBU48@@
Q00336<011245:DDYA240PQ200<<H`Q2248010@Q00<8@P@Q12401`@Q00<8
@P@Q12403@@Q00@<Ha2448@<H`848@L8@P0536<@Q12436<8@P0236<52480
1@@Q24848@@Q24800P@Q00@<HaBU48@8@P848@<8@P031248@PQ20088@P03
1248@PQ20088@P848@03248<H`aS008<H`045:DHaQS636<21242248236<3
248010aS2488@PQ21@@Q00D8@P@Q24848@Q200<48@<8@P848@<8@P030004
8@@Q0088@P031248@PQ200D48@0424848@@Q124324800`@Q2488@P042480
0`@Q2488@P02248010@Q24848@Q21@@Q0PQ20`@Q0`aS0`Q200<48@Q22480
2PQ20`aS0`Q20PaS10Q200D<H`Q2248<Ha24008DY@049BTYBRU:9BT26<H0
0a2436<<H`0636<248@336<348@01@aS48@@Q0aS48@010aS0a242PaS00<@
Q0aS36<00`aS00@8@PaS36<@Q0D<H`8@Q08<H`0948@DYABU5:D@Q0aS48@<
Ha2400@<H`0348@<Ha2400H<H`8@Q0@<H`0348@<H`aS00L<H`04248<H`aS
36<224800`aS48@@Q00336<2248336<3248436<00`Q236<8@P03248336<4
248236<324801@aS248<H`Q236<01@Q220aS0PQ20`aS0`Q20`aS0PQ20`aS
00<8@PaS24800PaS00@@Q0Q224848@@<H`88@P<<H`03248<H`aS008<H`88
@P0548@<H`aS36<@Q00336<010Q236<<Ha240PaS00<8@PaS36<010Q200@<
H`Q22488@P8<H`@8@P041248@PQ236<1248000D48@0900048@@Q00048@00
124<HaS6008<H`H@Q0<<H`8@Q08<H`0448@<H`aS248236<00`Q236<8@P03
36<00`Q236<<H`0248@336<448@00aBU48@<H`0236<248@>36<348@436<0
1A2436<<H`Q236<00a240PaS0Q241`aS00<@Q0aS36<00PaS00@@Q0aS36<8
@P8<H`<@Q00336<@Q12400<<H`0448@DYAS648@236<648@010aS48@@Q124
0PaS0Q2400H<H`Q2248<Ha2436<348@236<00a2436<<H`0248@00aBU36<<
H`0236<00a2436<@Q00236<00aBU48@@Q00248@25:D248@01ABU48@<H`aS
48@00`aS0QBU00D@Q0Q2248<H`Q200848@0324848@@Q00/48@88@P051240
00@Q1248@P0512401`Q212448@aS48@DY@aS00848@@8@P848@05248<H`Q2
36<@Q00424800`aS24848@031242248212401@0036<DYA2424800P@Q00D<
H`Q22488@P@Q00H8@P848@@8@P8@Q00336<@Q1BU008@Q0P8@P0336<8@PaS
008<H`0524848@@Q1248@P0312400`Q212448@02124324800`@Q24848@03
2483124324800`@Q24848@021242248412401@Q21248@PQ212400PQ200<4
8@Q224801@Q200@48@Q212448@88@P06124000@Q1248@P@Q0PQ200<<H`Q2
24801@Q20P@Q1PQ200@48@Q2248<H`@8@P8<H`0524848@Q2248<H`032480
0a245:DHaP029BT012U:8@PHaQS60Q2400@<Ha2436<@Q0H<H`0448@<H`aS
36<548@236<00a2436<8@P0248@00aBU48@<H`0<36<00`Q236<<H`0<36<0
0a245:D@Q00236<248@01@aS248<H`aS48@00PaS0Q241PaS0PQ20PaS00@@
Q0aS36<8@P<<H`0348@<H`aS00H<H`04248<H`aS48@336<4248336<00`Q2
36<8@P02248436<3248236<020Q236<<H`aS248<Ha2436<224800`aS48@8
@P02248236<2248336<4248436<00`Q236<<H`02248336<2248236<22480
0`aS248@Q00236<010Q236<<H`aS0`Q210aS00<8@PaS36<00`aS00<8@PaS
36<00PaS00<8@PaS36<01@aS00@@Q0aS36<8@PD<H`05248<H`aS248<H`02
24800`aS48@@Q003248236<1248112400003124000@Q00T48@0448@HaQ24
248348@236<0112436<<H`aS0a2400<<Ha2448@00Q241@aS00@8@PaS36<@
Q0L<H`8@Q0@<H`0348@<H`aS008<H`0348@8@PQ200<<H`88@P@<H`04248<
H`aS36<248@010aS48@<H`aS0Q2410aS0a2400D<Ha245:DDYA24008<H`03
48@<H`aS008<H`0348@<Ha24008@Q0@<H`0848@<Ha2448@<H`Q236<@Q08D
Y@8@Q00336<@Q124008@Q0@<H`D@Q08DY@0448@<H`aS36<448@236<00a24
36<DY@0248@011BU48@DYABU0Q2400@<Ha2436<<H`8@Q0055:D@Q12448@D
Y@0648@020aS5:D<H`Q236<@Q1S648@224800`aS24848@0212400`Q21244
8@0<1242248512400`Q212448@0312401ABU7>LU:AcW24800P@Q00<8@PaS
24800P@Q00D<HacW8@PU:AS600D@Q00436<8@PQ2248212432483124236<2
24821244248212452483124010Q212448@Q20`aS0`Q200D48@Q212448@Q2
00H<H`88@P0300048@@Q0088@P@48@0324848@@Q00848@0324848@Q20084
8@@8@P<48@<8@P031248@PQ20088@P@48@0:36<48@@Q48@HaQBU36<48@Q2
36<524801@@Q2488@P@Q24801P@Q00@8@PaS48@@Q0D8@P041248@P@Q1243
24800`aS2488@P0524800`@Q248<H`0324800`@Q24848@0224801PaS48@D
YAS67>LQ208U:@067>LQ212448@<H`Q20a240PaS00@8@PaS48@<H`<@Q003
36<@Q0aS00<@Q00336<@Q0aS008<H`8@Q0<<H`<@Q003248<H`Q2008<H`06
248<Ha2448@<H`Q20`aS00@@Q0aS36<@Q08<H`0448@<H`aS48@25:D248@3
36<00a2436<<H`02248336<0112436<8@PQ23@aS00<8@PaS36<00Q2400<<
Ha2436<010Q20Q240PaS0`Q200D48@aS36<@Q0aS0088@P8<H`<8@P0536<8
@PaS248<H`0248@01@aS2488@PaS48@00`aS0`Q200<<H`Q224800PQ20PaS
0PQ200@<H`Q22488@PX<H`88@P<<H`03248<H`Q200<<H`88@P0336<8@PQ2
008<H`03248<H`aS00L<H`88@P0336<@Q0aS0088@P0436<@Q12436<42480
112436<<H`aS0PQ20`aS00<8@PaS24800PaS00<8@PaS36<00PaS0PQ200@<
H`Q236<<H`88@P0000L000@Q00048@001240000512401PaS7>L@Q0aS5:D<
H`88@P0336<@Q0aS008<H`L@Q0L<H`<@Q0@<H`0448@<Ha2448@536<01Q24
36<8@PaS48@<H`88@P0536<@Q0aS36<8@P0236<00a2436<<H`0236<01124
36<<Ha241PaS00@8@PaS36<@Q0@<H`@@Q00336<@Q0aS008<H`0348@<H`aS
008<H`8@Q0@<H`8@Q08<H`@@Q0035:D@Q124008<H`045:D<Ha2436<248@0
1@aS48@@Q12436<011BU00<<H`Q236<01@aS11240QBU00@@Q1BU48@@Q0H<
H`0448@DYA245:D448@25:D448@436<25:D00a2436<8@P0224821242248;
12400`Q212448@0212400`Q212448@0612401P00124DYAcW9BTLi`@48@03
36<8@PQ20088@P047>LU:BU:7>L25:D00a2436<<H`0236<224801@@Q2484
8@Q212401PQ210@Q10Q20P@Q0`Q20`@Q00<8@P@Q12400PQ20`aS10Q200D4
8@Q2248<H`Q2008<H`0348@<H`Q200<8@P<48@88@P848@0324848@@Q0084
8@0424848@Q2124424801@@Q2488@P@Q248010@Q0`Q210@Q0PQ200<48@Q2
48@00QS600@<H`@Q248<H`88@P8<H`88@P041248@PQ2248412401PQ21248
@PQ236<@Q08<H`88@P051248@PQ21248@P0212400`Q236<<H`0224801@@Q
2488@PaS24800P@Q10Q201048@Q21248@PaS48@DYAS69BTQ22U:9BTQ21cW
5:D@Q0D<H`0348@<H`aS00<<H`@@Q00336<@Q12400<<H`0348@<H`aS008@
Q08DY@8@Q0<<H`0348@<Ha2400X<H`8@Q08<H`04248<Ha2448@336<00a24
5:D@Q00236<00a2436<<H`0236<00a2436<<H`0436<348@01`Q236<<Ha24
36<8@PaS0088@P0336<@Q12400D<H`0348@<H`aS008<H`8@Q00436<8@PQ2
248536<010Q236<<H`aS1@Q20PaS00<8@PaS24800PQ200@<H`Q22488@P8<
H`0348@<H`aS0088@P<<H`88@P031248@PaS00<<H`88@P0536<8@PaS36<@
Q00536<4248336<224800`aS248<H`0236<2248236<00`Q236<8@P0236<2
24800`aS48@@Q00236<010Q236<<H`aS0`Q200<@Q0aS36<00PaS0Q2400<<
H`Q236<010aS00L8@PaS36<<H`@Q248<H`0248@01PaS2488@PaS248<H`88
@P8<H`48@P002@@Q00H000@Q124<HaS65:D236<348@336<00a2436<<H`02
36<26<H248@010Q236<@Q12410aS0Q2400<<Ha2448@01@aS0Q240PaS0a24
10aS00<@Q0Q236<00PQ21@aS0PQ20a240PaS00<@Q1BU48@01`aS21240PaS
0Q241`aS00<@Q0aS36<00a240`aS00L@Q0aS48@@Q0aS48@<H`0548@636<6
48@010aS48@<H`aS0Q2410aS0QBU0a240QBU00<@Q0aS48@00QBU00H@Q0aS
48@@Q1BU48@336<348@336<248@236<00a245:D@Q00336<010@Q24848@Q2
1@@Q00<8@P@Q124020@Q00<000@Q12400P@Q00H8@P@Q24848@Q212442482
36<0112424848@@Q0`Q200L<H`@Q48@]JdYBHaQBU002<H`012489BTHaQBU
2@Q200<48@Q224801PQ210@Q00<8@P@Q12400P@Q00H8@P@Q124000@Q2483
124324800`@Q2488@P03248236<248@010aS248<H`Q20`@Q0PQ20P@Q00<8
@P@Q12401@@Q00<8@P@Q12400P@Q00<8@P@Q24800PQ210@Q00L8@P@Q2488
@P@Q2480000212401@Q236<<H`@Q24801@aS0aBU0Q240PaS0`Q200<48@Q2
124010@Q00T8@P@Q124<HaBU48@<H`@Q24800P@Q00<8@P@Q24800P@Q0PaS
00<8@P@Q24800PQ200<48@Q2248010Q20P@Q0PQ200<<H`Q236<00Q2400XQ
22DY9BTLib48:DXLiaBU36<8@P8@Q00436<@Q12448@736<248@236<22480
0`aS48@<H`0336<248@336<00a2436<@Q00248@00`aS248<H`0436<348@0
0`Q236<<H`0448@236<01A2436<@Q12436<00a240PaS00<@Q0aS36<00`aS
0`Q21@aS0PQ200D<H`Q236<<Ha2400@<H`03248<H`aS008@Q00336<8@PaS
00T<H`0424848@Q2248436<3248010@Q2488@PQ210aS0PQ20PaS00<@Q0aS
24800`aS00@8@PaS36<<H`<8@P<<H`03248<H`Q200D<H`0448@<H`aS2483
36<2248236<2248010aS48@@Q0Q20`aS0`Q20PaS00@@Q0aS36<8@PP<H`06
248<Ha2448@<H`Q20PaS0PQ20PaS0Q2400<8@PaS24800PaS0`Q20PaS0`Q2
0PaS00<@Q0aS248010Q20PaS0@Q2000212401@00124000@Q00000`@Q00L0
00@Q36<HaQ24248@Q00336<348@236<448@25:D00a2436<<H`0236<00a24
36<<H`0336<348@436<0212436<<H`Q236<8@PaS48@336<224802PaS248<
H`aS248<Ha2436<8@PaS0a240`aS0Q2400<<H`Q236<00Q241`aS0a2410aS
0PQ20a240PaS0Q241PaS00<8@PaS48@00Q240PaS00@@Q1BU36<<H`@@Q0<<
H`8@Q08<H`<@Q0D<H`8@Q0@<H`@@Q0<DY@8@Q0<<H`0648@DYA245:D@Q1BU
112400<<Ha2448@00Q240`aS0a2400<DYA2448@00`aS2`@Q00<000@Q1240
1`@Q0PQ200@48@Q212448@<8@P848@88@P8<H`0424848@@Q124336<020@Q
36<aS4HaIcUBU3F]<H`28@P00aS648@<H`03248010aS2488@P@Q0PQ200<4
8@Q224800PQ21@@Q00<8@P@Q24800`Q210@Q00<8@P@Q12400`Q200@48@Q2
2488@P848@03248<H`Q20088@P0336<8@P@Q00<<H`<48@0324848@Q200<4
8@88@P031248@P@Q00<48@<8@P848@0324848@Q20088@P@48@88@P@48@88
@P0436<8@PQ2248248@00`Q236<@Q0045:D236<010Q236<<H`Q20P@Q00@8
@P@Q12448@88@P061248@PaS5:D@Q0aS0`Q20P@Q0PaS00@48@Q2248<H`L8
@P041248@PQ2248312401`Q21248@PQ236<@Q1BU008Q20069BTQ2248;F/Q
21S60PQ200<DYA2448@00`aS00<@Q0aS36<0112410aS0Q2400@<Ha2448@<
H`<@Q08<H`0348@<Ha2400D<H`8@Q00336<8@PaS00@<H`0348@<H`aS008<
H`0548@<H`aS248<H`0248@236<00a245:D@Q00436<0112436<8@PQ210aS
00<8@PaS36<00`aS00@8@PaS36<<H`<8@P<<H`03248<Ha2400D<H`03248<
H`aS008@Q00536<8@PQ2248<H`02248010aS2488@PaS10Q200D<H`Q2248<
Ha2400<<H`88@P<<H`88@PD<H`031248@PQ20088@P0436<8@PQ2248736<0
0a2436<<H`03248236<2248536<011242488@PQ20PaS00<@Q0aS24800PQ2
00@@Q0aS248<H`8@Q0@<H`03248<H`aS008@Q00636<8@PaS36<@Q0aS0`Q2
00<@Q0aS36<00`Q20PaS00D8@PaS248<H`Q2008<H`X8@P0000<000@Q1240
1@@Q00L000@Q12448@aS6<HDY@0436<00a245:D<H`0436<00a2436<<H`02
36<00a2436<<H`0336<00a2436<<H`0336<248@00aBU48@<H`0836<248@9
36<3248336<01A2436<<Ha2436<00PQ200<<Ha2448@01`aS00<@Q0aS48@0
0a240`aS00<8@PaS36<00Q240`aS0a2400<<Ha2436<00Q241@aS0Q2400H<
H`Q236<@Q1S65:D836<00a2436<@Q00748@436<0112436<DYA240QBU0a24
1@aS0a2400<<Ha2436<00QBU0Q2400<<Ha2448@00PaS00H8@PaS5:DHaQ24
36<5248H12422483124010Q21248@PQ210@Q00<8@PaS36<00PaS00H@Q1cW
<Ha246<HG_L2HaP01U[FE[De[Be[5:D<H`88@P8<H`88@P031248@PQ20088
@P031248@P@Q00@8@PP48@<8@P@48@<8@P848@H8@P0336<8@PQ200H8@P04
36<8@PQ21243248212400`Q212448@021244248412401@Q212448@@Q2480
0P@Q00@8@P@Q2488@P<48@0336<@Q0aS00848@0924848@aS5:D@Q48@E[EB
U48@008DY@057>L@Q124248<H`03248212402PQ212448@Q236<HaQBU36<4
8@Q20P@Q00<8@P@Q12400`Q200<48@Q224802`Q20P@Q10Q200D<Ha247>LL
ibDY00<Q20036<HDYA2400H<H`0648@<Ha2448@<H`Q20PaS00<@Q0aS36<0
0a240PaS00<@Q1BU48@00PaS112410aS0Q241@aS1Q2420aS0a2430aS00<@
Q0aS24800PQ20a2400@<H`Q236<8@P8@Q00536<8@PQ236<DY@0936<32484
36<00`Q21248@P02248336<224800`aS248<H`03248436<01@Q236<<H`aS
24801@aS0`Q200<<H`Q224801@Q21`aS0Q2400<<H`Q224800`aS00@8@PaS
36<8@P@<H`<8@PX<H`03248<H`aS008<H`03248<H`Q20088@P8<H`<8@P8<
H`<8@P<<H`@8@P0436<8@PaS36<2248436<424800`aS2488@P0324800005
124000@Q1240000512401@00124@Q1cW5:D01PaS00<@Q0aS36<00Q2400<<
H`Q236<00Q240`aS00<@Q0aS36<010aS00<8@PaS48@00a242PaS0Q240`aS
00@8@PaS36<8@PD<H`<@Q0L<H`8@Q0T<H`8@Q0045:D@Q0aS36<248@636<5
48@01`aS48@DYA2436<8@PaS00<@Q00336<@Q12400<@Q08DY@8<H`03248<
H`aS008@Q0@<H`8@Q0035:D@Q1BU00<@Q00436<8@PaS48@25:D00a245:DD
Y@0248@236<248@00aBU48@@Q00248@00`aS48@<H`0548@436<35:D00a24
1248@P032487124010Q212448@000P@Q0PQ20`@Q0PQ20P@Q00P000Q21248
@P@Q24848@Q210@Q0PQ20P@Q00/8@PaS48@<Ha2436<LicF]BU9W>Ekg009S
6008E[EJeSF]8@P@Q0Q248@<H`88@P0436<48@@Q124336<010Q212448@@Q
0`Q22@@Q00<8@P@Q124010@Q0PQ200L48@Q22488@PaS24848@02248010aS
24848@@Q0PQ200<<H`Q212400PQ20PaS0PQ200<48@Q2124010@Q00<8@P@Q
12400P@Q00<8@P@Q24801@@Q00D8@P@Q24848@Q200@48@8<H`0324848@@Q
00<<H`0648@DYD8@F]IF]Cg_0QBU00@HaQBU36<<H`88@P<48@88@P041240
00Q236<25:D236<00`Q21248@P021245248236<224821244248312452482
36<01A246<HLib489BT00R4800<HaQBU48@00`aS00@@Q0aS36<<H`8@Q08<
H`<@Q005248<H`aS48@DY@0548@236<348@436<00`Q236<<H`0336<010Q2
36<<H`aS0a2410aS0Q240`aS00<@Q0aS36<01`aS0Q2410aS0PQ20`aS00@8
@Q2436<<H`88@P@<H`04248@Q12448@636<00`Q236<<H`0336<00`Q236<<
H`02248336<2248336<424800`aS248<H`05248436<00`Q236<<H`0536<0
1@Q236<8@PQ236<00PQ200D<H`Q22488@PaS008@Q00436<8@PQ2248636<3
24800`aS48@<H`0236<2248436<224800`aS48@<H`0236<00`Q236<<H`03
248736<3248236<010Q236<<H`aS1@Q200@<H`Q22488@P8<H`88@P8<H`L8
@P4<H`48@P000P@Q00D000@Q12448@0000D48@03248DYAS600<@Q00336<@
Q12400@<H`0348@<H`aS008<H`8@Q0H<H`05248<Ha2448@<H`0248@01ABU
48@<HaBU48@00PaS00H8@PaS36<<Ha2436<248@336<3248336<4248236<0
1a2436<<H`aS48@DYA2400<<H`0348@<H`Q2008<H`0348@<H`aS00@@Q007
5:D@Q0aS36<8@PaS48@010aS1Q2410aS0Q2400D<Ha2436<<Ha24008DY@06
48@<H`aS36<@Q1BU0PaS00@8@Q2448@@Q0@<H`<@Q0<<H`0648@<H`aS36<@
Q1BU1A240`aS00<DYA2448@00QBU0Q2400<DYA2448@01PaS00P8@Q245:DD
YA2436<8@PaS0`Q21P@Q00<000@Q12401@@Q00<8@P@Q12400`@Q0PQ200<4
8@Q212400`@Q00<8@P@Q12400P@Q00<8@PaS24800P@Q01<8@PaS48@DYAS6
9BU6<EJeNmig_G>LIcUcW7ooNmiS62U:48@<H`031242248512401@001244
8@@Q24800P@Q00<8@P@Q248010@Q00<8@P@Q12400`@Q0`Q20P@Q0PQ200<4
8@Q236<00PQ200D48@Q22488@PaS00@8@P8<H`<8@P041248@PQ212422480
10@Q24848@Q21@@Q00<8@P@Q12400`@Q0PQ21@@Q00<8@P@Q12400PQ200@<
H`Q2124<H`8DY@0@48@DYAcW@Q1>Le[FHaQ>Le:D?Nl]JbDY48@<H`Q21243
36<020Q212448@@Q5:DLiaS636<2248312400`Q21248@P021242248336<2
124224800a2436<8@P052483124224800aS67>LU:@028@P01bDY8@PQ21BU
48@<H`Q2008@Q08<H`0348@<H`aS008<H`<@Q08<H`04248<Ha2448@336<0
112436<<H`aS0a240PaS00<@Q0aS24800PaS00@@Q0aS36<<H`@@Q00336<8
@PaS0088@P8<H`8@Q0H<H`06248<Ha2448@<H`Q210aS0PQ200D<Ha2448@<
H`Q200D<H`03248<H`aS00<@Q00336<@Q12400/<H`88@P<<H`88@PL<H`<8
@P8<H`05248<H`aS36<@Q00436<3248236<324801@aS2488@PaS24800`aS
0PQ20PaS0Q240`aS10Q20PaS00<8@PaS24800`Q200<<H`Q236<010aS00D8
@PaS36<<H`Q200<<H`<8@P0336<@Q0aS00<8@P0436<@Q0Q236<2248336<3
248336<2248236<7248636<62480000300048@@Q00848@0400048@@Q0003
124010aS6<H@Q0aS0a2410aS00@@Q0aS36<@Q0D<H`8@Q0<<H`03248<H`aS
00D<H`@@Q0<<H`03248<H`aS008<H`<@Q00336<@Q0aS00<8@P8<H`03248<
H`Q20088@P0336<@Q12400<<H`0348@<H`aS008<H`0348@<Ha2400<<H`03
248<Ha2400H@Q0<<H`03248<H`aS008<H`@@Q00436<@Q12448@736<748@4
36<0112436<<Ha241@aS00D@Q0aS36<8@Q2400H<H`8@Q0045:D@Q12448@2
36<01A2436<<Ha245:D00Q2400<DYA2436<00PaS0a2400P<Ha2436<<Ha24
6<HDYA240PQ200<<H`Q224802P@Q00<8@P@Q12401P@Q00<8@P@Q12400`@Q
00@8@P@Q1248@P<48@0424848@aS248312400`Q248@<H`025:D03bU:BU9N
mg_NMke_NfLiLiaoog_NHaPU:A24248000021242248212400`Q212448@05
12422487124224800`@Q24848@02248212400`Q21248@P0424800`@Q36<<
H`0324800`@Q2488@P0224800`@Q2488@P0524800`aS12448@0312401000
1248@PQ22@@Q0PQ20`@Q00<8@P@Q12400P@Q0PQ200`48@Q236<DYA2436<H
aR48CW=BU5[FG_L2CW<01Cg_;F/Lia2436<00`Q20PaS00P8@P@Q124<HaBU
6<HDY@aS0PQ21@@Q0PQ200<48@Q224800PaS00<48@Q224800`Q200<<H`Q2
24801@Q200@48@Q2248<H`8HaP8U:@8Q20047>LQ21S648@:36<248@536<0
0a2436<<H`0236<348@236<01A2436<<H`Q236<00Q2400D<H`Q22488@PaS
008@Q0035:D@Q12400@<H`8@Q0D<H`0348@<H`aS0088@P8@Q08<H`03248@
Q0aS008<H`03248<H`aS00<<H`0348@<H`aS008<H`0348@<H`aS008<H`04
248@Q0aS48@436<0112436<@Q0aS0PQ200@<Ha2436<<H`88@P@<H`03248<
H`aS00<<H`03248<H`Q200@8@P0536<8@PaS36<@Q00236<010Q236<<H`Q2
0`aS0PQ200D48@Q236<8@PaS00<8@P8<H`03248<H`aS008@Q00336<8@PQ2
00<8@P@<H`03248<H`aS008<H`<8@P0336<8@PaS00D<H`03248<H`aS008<
H`<8@P8<H`88@P0336<8@PaS00@<H`03248<H`aS00<8@P@<H`H8@P8<H`88
@P0336<8@PQ20088@P0536<8@PQ2248<H`0124800005124000@Q12400004
12401`0012448@aS7>L@Q0aS008@Q0<<H`0448@<H`Q236<248@00aBU48@<
H`0=36<548@636<010Q236<<H`aS0Q2400@<Ha24248<H`<8@PL<H`04248<
H`aS48@436<010Q236<<H`aS0Q240PaS0Q2400<DYA2436<011241@aS1a24
0PaS1A240PaS00<@Q0aS48@01A2400@DY@aS248<H`8@Q0<<H`0548@<H`aS
36<DY@0248@00`aS48@<H`0248@00`aS48@@Q0025:D648@236<448@011BU
48@@Q1240`aS00<@Q0aS36<01@aS0Q240PaS00@8@PaS36<8@PP48@032484
8@0000@48@0400048@Q2248:1242248412401`aS2488@P@Q248<HaBU008Q
2003:DXicTic009cW009MkecW6]JKg]kgWooIcTe[ABU00@48@88@P031240
00@Q00@48@0400048@@Q1246248912400`Q21248@P0@248436<324821243
24821242248412442484124224800`@Q24848@03124010Q236<<H`Q20P@Q
0a2400dYBS6<HaQcW7_NMke[FW_NOomcW5:D8@PDY@0224800`aS24848@03
12401@Q248@DYABU36<00`Q200D48@Q22488@P@Q0088@P<<H`03248<H`Q2
00L8@P031248@PQ2008<H`0624848@@Q248@Q1BU0QcW00TQ22DY8@PU:AS6
5:D<H`Q236<00a2400@<H`Q236<@Q0H<H`8DY@0348@<H`aS00D@Q08<H`03
48@<Ha2400<<H`0448@<H`Q2248236<0212436<<H`Q236<@Q0aS248236<0
0a2436<<H`0236<00`Q236<<H`0248@236<348@336<00a2436<<H`022482
36<00a2436<<H`02248448@00`Q236<<H`0<36<2248436<00`Q236<8@P04
36<3248436<00`Q236<8@P03248336<01@Q236<<Ha2436<00`Q200<48@Q2
36<00PQ200<<H`Q236<00PQ200@<H`Q236<8@PD<H`03248<H`aS00<<H`03
248<H`aS00D<H`04248<H`aS48@<36<224800`@Q248<H`0236<324800`aS
248<H`02248010aS48@<H`aS0`Q20PaS0`Q200<<H`Q224800PQ210aS1PQ2
0@aS0@Q2000212400`0012448@0712400`aS6<HDY@0436<0112436<<H`aS
112400@8@PaS48@@Q0X<H`0848@<Ha245:D@Q1BU36<8@P8<H`8@Q0H<H`03
48@DY@aS008<H`H8@PD<H`0348@8@PaS008<H`03248<H`Q2008<H`0348@<
H`aS00D<H`8@Q0@<H`0448@<H`aS36<248@436<01A2436<@Q12436<00Q24
0`aS00<DYA2448@00PaS1Q2400<<Ha2436<01PaS1A240PaS0Q240`aS00@@
Q1BU5:D<H`8@Q0@<H`<@Q00336<@Q124008DY@0448@<H`aS36<248@02@Q2
36<<Ha24248<HaBU48@<H`02248236<00`Q212448@0;12400`001248@P0;
1242248312400`Q2124<H`0236<00`Q212448@025:D27>L012DY?NmBU7Nm
0g>L00M[FVmkOomooekg=JdDY@0412400`Q200048@0312401@0012448@@Q
00000`@Q0`Q20`@Q00<8@P@Q24801@@Q30Q200<48@Q224801@Q20`aS0`Q2
2@@Q00@8@P@Q12448@<8@P848@<8@PH48@0324848@@Q00D8@P<<H`049BTe
[F]JLi`2Mkd026LiOomkgW>LCW<LiaBU1242248512401`aS48@DYA2436<4
8@Q200@48@<8@P031248@PQ20088@P031248@PaS0088@P848@<8@P848@0:
248<H`aS24848@Q248@DYB487>L28@P01RDY8@PHaQBU36<8@P8<H`8@Q0`<
H`<@Q00336<@Q124008<H`03248<H`aS008@Q0D<H`08248<Ha2448@<H`Q2
36<@Q08<H`04248<H`aS48@236<010Q236<<H`Q20PaS00D@Q0aS36<<Ha24
00<<H`0348@<H`Q200<<H`03248<H`aS00H<H`8@Q08<H`<@Q0@<H`0348@<
H`aS00<<H`88@P0336<@Q0aS0088@P0436<8@PaS36<4248336<324800`aS
2488@P0236<00`Q236<<H`0636<5248336<2248010aS48@<H`Q20PaS0`Q2
0`aS10Q20PaS00<@Q0aS36<00PQ20`aS00<8@PaS36<00`aS0PQ200H<Ha24
36<<H`Q236<7248010aS248<H`aS10Q21PaS00<8@P@Q24800PaS10Q200<<
H`Q224800`Q200<<H`Q224800PaS0`Q20PaS0000100012448@000P@Q00X0
00@Q12448@00124<HacW5:D<H`<@Q0<<H`<@Q00436<@Q1BU48@336<01A24
36<<H`aS48@010aS0a2400@<Ha2448@@Q0<<H`8@Q08<H`06248<Ha2436<8
@PaS0QBU00<@Q0Q224800`aS10Q20`aS00<@Q0aS36<00`aS0a240`aS00<@
Q0aS36<00a240PaS00<@Q0Q236<01PaS0Q2400DDYA2448@@Q0aS008@Q005
36<@Q0aS248<H`0348@01@aS48@@Q12436<00Q240`aS00<@Q0aS36<010aS
00<8@PaS48@00Q240PaS1Q2400<<Ha245:D00PaS1Q240PaS0Q240aBU00@@
Q0aS36<<H`@@Q08<H`<@Q00624848@aS48@<H`Q21`@Q00<8@P0012401@@Q
00@000@Q1248@P@48@0324848@@Q00848@0724848@@Q24848@Q212400PQ2
0Q240PaS00PDYAcW6<HLibU:=Je>Le:D0V<H00UW>F]JF]I:DSF]:DXQ2124
36<00P@Q00LHaRe[8@P@Q0@Q0008@P021242248010@Q2488@P@Q10Q20`@Q
10Q200@48@Q224848@P8@P051248@PaS248<H`03248236<224800`aS2488
@P062483124424831242248412400`Q21248@P03248010@Q2488@P@Q0PQ2
00T<H`Q236<<Ha24<H`e[FLiLi`00WNm00=_Nf]JJeX00Woo00=JeS6<1240
10@Q00D000@Q124<Ha24008<H`D48@<8@P0336<8@PQ200848@<<H`<8@P03
36<8@PQ200848@04248<H`aS248212400`Q21248@P0236<25:D27>L011S6
8@PDYA240`aS00<@Q0aS36<010aS00H@Q0aS36<@Q0aS48@236<248@00aBU
48@@Q00?36<00`Q236<<H`0536<01PQ236<<H`aS48@8@P@<H`03248<Ha24
008@Q00736<8@PaS36<@Q0aS24801@aS00T8@PaS36<<H`Q236<@Q1BU48@0
0`aS00@8@PaS36<@Q0L<H`@8@P@<H`D8@P<<H`@8@P<<H`03248<H`Q20088
@PD<H`03248<H`aS0088@P8<H`03248<H`Q200L<H`@8@P0636<8@PQ236<8
@PaS0PQ21PaS0PQ20PaS00<@Q0aS36<00`aS00@8@PaS36<8@P@<H`88@P03
36<@Q0aS00@8@P<<H`<8@P<<H`0448@<H`aS48@8248010aS2488@PQ21PaS
10Q20@aS0@Q20@Q2000412401@0012448@@Q00000`@Q00<<HaS65:D010aS
0Q240PaS00<@Q0aS48@00Q240PaS00<8@PaS48@010aS00<@Q0aS36<01`aS
00H@Q0aS36<@Q1BU48@636<01@Q236<@Q12436<00PQ200<@Q0aS36<00PQ2
2`aS0PQ20PaS00<@Q0aS36<00Q2400D<Ha2448@@Q1BU00<<H`03248<H`aS
00<<H`0448@<H`aS36<348@236<0112436<<H`aS0a240`aS0Q240`aS00@@
Q0aS48@@Q0<<H`8@Q0<<H`X@Q00336<@Q12400<@Q00436<@Q0aS36<35:D0
0a2436<@Q0025:D548@236<248@01@aS248<Ha2436<00PQ200<<HaBU36<0
20@Q00<000@Q12403@@Q00L8@P@Q12448@Q21248@P031242248010@Q248@
Q1BU0PaS014@Q1cW7>LQ22U:=Je:DU:DIcUS66LiKg]F]E:D;F/Q21BU008@
Q0848@046<HYBRDY48@2124224861246248010@Q24848@Q21@@Q00<8@PaS
36<00PQ200<48@Q236<00PQ200<48@Q236<01@aS0PQ200<<H`Q236<01PQ2
0`@Q00@8@P@Q12448@88@P848@@8@P041248@PQ22482124424800`@Q248<
H`0324801PaS48@DYC6<>Li[FP9g_@04Nmi[FV]JKg/2Ool01EJe;F/48@@Q
000010@Q00D8@Q2448@<H`Q200D48@0336<8@PQ20088@P031248@PQ200<8
@P031248@PQ200T8@P8<H`0?24848@@Q248<HaS65:DHaQcW8@PU:AcW5:D8
@P@Q008<H`@@Q0L<H`0348@<Ha2400D@Q08<H`<@Q08<H`0348@<Ha24008<
H`03248<H`Q200@<H`03248<H`aS00D<H`03248<H`aS008@Q0@<H`8@Q005
36<8@PaS48@<H`03248010aS48@<H`aS0PQ200D@Q0aS36<<Ha24008<H`03
48@<H`aS008<H`88@P0436<@Q0aS248636<3248436<3248336<3248336<0
0`Q236<<H`0636<0112436<<H`aS0PQ200<<H`Q224800PQ20PaS0`Q20PaS
0PQ20PaS00<8@PaS24800`aS0PQ200<<H`Q236<00PaS00D@Q0aS248<H`Q2
008<H`03248<H`aS00H<H`D8@P8<H`03248<H`aS0088@P0336<8@PQ200<8
@PD<H`03248<H`Q200@8@P0536<8@PQ21248@P0336<010Q236<<H`aS0`Q2
10aS0PQ200000`001240000212401@0012448@@Q00000P@Q00<<HaS648@0
10aS0Q2400<<Ha2448@01PaS00<@Q0aS36<00a240PaS00<@Q0aS48@010aS
0Q2400<<Ha2436<01@aS0Q240PaS1Q240PaS00<8@PaS36<010aS0Q240PaS
00@8@PaS36<@Q0<<H`0748@<H`aS248<Ha245:D00a2400D8@PaS36<<Ha24
008<H`04248<Ha2448@236<01a245:D@Q12436<@Q0aS008@Q00536<8@PaS
48@<H`0248@25:D01A2436<<H`aS48@01PaS00<8@PaS36<010aS00@@Q0aS
48@@Q08DY@@@Q0<<H`8@Q00436<@Q0aS48@25:D448@00aBU48@@Q00348@6
36<00a2436<48@0224800`aS2488@P0212400`0012448@0?12400`Q21244
8@0312400`Q212448@0312400`Q212448@0224802P005:De[D8@:DX<H`Q2
7>LQ21cW0RDY0SW>00Dmkd8@;F/U:AS6008@Q08<H`<8@P8<H`0324848@@Q
00848@0424848@Q21242248010@Q2488@PaS0`Q20PaS1PQ200<48@Q22480
1@Q20P@Q0`Q200<48@Q224801@Q200@<H`Q224848@D8@P<48@<8@P848@07
24848@@Q1248@P@Q24800`@Q00<8@P@Q12400PQ200<<H`Q224800PQ2010@
Q0Q2124HaS6<AS4e[CW>BU9W>F]JKg]g_G_NKg]JeP9>L`0:8@PDY@@Q248<
H`@Q36<HaQcW6<H3248212401PQ236<DY@aS24848@@8@P031248@P@Q00<8
@P0436<8@PQ21242248212442482124020aS48@HaQBU6<HLiaS65:D448@6
36<00a2436<@Q00436<348@236<00a245:D@Q00336<248@00`aS248<H`03
36<01@Q236<8@PaS24800PaS00D@Q0aS248<Ha24014<H`88@P0536<@Q0aS
36<8@P0436<00`Q236<8@P0336<248@636<010Q236<<H`aS0PQ200@@Q0aS
2488@P8<H`<8@PH<H`88@P8<H`03248<H`Q200D<H`<8@P<<H`04248<Ha24
48@236<2248010aS248<H`aS0PQ20`aS00@8@PaS2488@PD<H`88@P`<H`05
248<Ha2448@<H`02248336<248@3248236<00`Q236<8@P0336<00`Q236<<
H`0336<010Q236<<H`Q20PaS1@Q200@<H`Q2248<H`@8@P0436<8@PQ22483
36<324800`aS2488@P01248000L48@0300048@@Q00848@0336<HaQBU00<<
H`<@Q00636<@Q12436<8@PaS0Q2400<<H`Q236<00a2410aS00<@Q1BU48@0
0PaS00@8@PaS36<@Q0<<H`8@Q00336<@Q1BU008@Q0X<H`0348@<Ha240088
@P0436<@Q12448@236<248@436<00a2436<<H`0236<00a2436<@Q0025:D0
0a2436<8@P0236<00a2436<<H`0236<548@00aBU48@@Q00536<648@25:D2
48@00`aS248<H`0436<00`Q236<<H`0248@00`aS248<H`0436<448@00`aS
48@<H`0348@236<248@25:D348@35:D548@010aS48@<H`aS112400P<H`Q2
2488@PaS24848@003@@Q00<000@Q124010@Q00<8@P@Q24800PQ210@Q00@8
@P@Q12448@<8@P07124DYBe[?NlU:@aS24800acW00@Q22U:=Jde[@8mk`8Y
BP056<H@Q0aS36<@Q003248236<01@Q21248@PQ212400`Q200@48@001248
@P8<H`L8@P031248@PQ200L8@P031248@P@Q00<8@P848@05248<H`aS2484
8@03248010aS248<H`aS1`Q210@Q00<8@P@Q12400`Q210@Q00<8@P@Q1240
0PQ200<48@Q224800`Q20PaS01@48@Q26<HYBT8@=JdicTYBJeY_Nf]JNmig
_F]JF]I>LdHa9BTDY@@Q0PQ200P48A247>LQ21BU24848@Q20`@Q0Q2400<<
H`@Q24800PQ200<48@Q224800PQ20P@Q00@<H`Q236<<H`@8@P0336<8@PQ2
00<8@P05124<Ha247>LHaP035:D01QS65:DDY@aS248<H`<8@P<<H`0548@<
Ha2436<@Q00236<348@436<00a2436<<H`0236<248@01@aS2488@PaS2480
1@aS0PQ200D<Ha2448@<Ha2400@<H`8@Q08<H`04248<H`aS48@436<010Q2
36<8@PaS10Q200@<Ha2436<<H`88@P<<H`0348@<H`aS00@<H`05248<H`Q2
36<8@P0736<00`Q236<<H`02248436<224800`aS48@<H`03248010aS2488
@PQ210aS0`Q20PaS00@@Q0aS36<8@P@<H`88@P8<H`06248<H`aS36<8@PaS
0PQ20PaS00<@Q0aS36<00PaS0`Q21PaS0`Q200<<H`Q236<01PaS0`Q20PaS
10Q200<<H`Q224800PQ210aS0`Q20PaS00<@Q0aS36<00`Q200<<H`Q22480
0PaS0`Q200<<H`Q236<01`aS0PQ20PaS0@Q200001@00124000@Q00000`@Q
00L000@Q124000aS6<HDY@0248@236<348@236<00`Q236<<H`0248@236<2
48@010aS48@@Q1241`aS00<@Q0aS36<00PaS0Q241@aS0a240`aS0Q2400<<
Ha245:D010aS00@@Q0aS48@@Q0T<H`<@Q00336<8@PaS008@Q00336<@Q0aS
008@Q08<H`88@P<<H`0348@<H`aS008<H`0348@<Ha2400@<H`8@Q00536<@
Q0aS248<H`0548@00aBU48@@Q00236<0112436<<H`Q20PaS00<@Q1BU48@0
0Q240`aS0Q240PaS00<@Q1BU5:D01a2400<DYA2448@00Q2400L<Ha245:DD
YA2436<@Q0025:D0112436<8@PaS0a2400<8@P@Q24800PaS00<8@P@Q1240
50@Q0`Q20P@Q0PQ200<<H`@Q124010@Q00`8@P@Q124@Q1cW<Ha:DSW>:DXD
Y@aS48@35:D26<H01AcW6<HDY@aS24800PaS00@@Q0aS12448@H8@P848@H8
@P0336<8@PQ20088@P<<H`0424848@Q2124236<01PQ236<8@PQ236<8@P84
8@88@P031248@P@Q0088@P<<H`<8@P031248@PaS0088@P848@0436<8@PQ2
12442488124010Q212448@@Q0PQ210@Q00P<H`Q236<DYAS648@<Ha240aS6
01DQ22DY?Nm6<DicF]I>LdHa>LhLiaS648@HaQBU36<DYAS68@PLiaBU36<0
0PQ20`@Q0PQ20Q2400<8@PaS24800PQ20`@Q00<8@PaS24800PaS00D8@P@Q
12448@aS00D8@P0436<8@PQ2248548@02aS65:DDYABU48@<Ha2436<8@PaS
24800`aS00<@Q0aS36<00PaS00@@Q0aS36<<H`@@Q08<H`0548@<H`aS248<
H`0248@00`aS248<H`0236<248@3248336<00`Q236<<H`0236<00a2436<<
H`0236<348@236<00a2436<<H`0536<00`Q236<@Q00236<3248010aS248<
H`aS0Q240PaS00<8@PaS36<00`Q20PaS10Q210aS0`Q200<<H`Q236<00`Q2
0Q2400<<H`Q224800PQ200<<Ha2436<00`Q20`aS00<8@PaS24800PQ210aS
0`Q200@<Ha2436<<H`<8@P0348@<H`Q200<8@P<<H`<8@PD<H`88@PD<H`04
248<H`aS248336<2248336<00`Q236<<H`04248736<4248436<324801`aS
2488@PQ236<@Q0aS00<8@P0636<8@PQ2248<H`Q20`aS0`Q20@aS0@Q20005
12400`0012448@0212402@00124@Q1BU36<8@Q245:D@Q00236<248@336<2
48@536<348@236<00`Q236<<H`0248@836<348@336<0212436<<H`Q236<@
Q0aS48@236<00a2436<<H`0236<348@00`aS2488@P0336<00a2436<@Q002
48@636<448@436<248@436<348@00`aS48@<H`0636<248@00`aS48@<H`04
36<00a245:D@Q00236<00a2436<<H`0236<448@236<00a2436<<H`0236<0
0a2436<@Q0035:D248@236<348@00`aS48@@Q0065:D00a245:DDY@025:D0
112436<<H`aS0Q240PQ200<<H`Q2248010@Q00<000@Q12401`@Q00<8@P@Q
12400`@Q00<8@P@Q12400`@Q1@Q200L48@Q21248@P@Q24848@0224804P@Q
48@HaSW>BU8icR485:D8@Q246<HDYAS648@HaR487>LHaP88@P8<H`0348@8
@PQ200848@@8@P031248@P@Q00D8@P0336<8@PQ200<8@P@<H`0324848@Q2
00X8@P@48@88@P8<H`03248<H`@Q00848@05248<H`Q224848@0324821242
248236<412400`Q212448@04124224861242248010aS6<HHaPaS0PQ200DH
aR485:DQ22U:0096<@09BU9F]DicAS4e[B487>LDYA24008<H`055:DLiacW
7>L@Q00236<22482124010Q236<DYA240PaS0PQ200<<H`@Q24800`Q200D<
H`Q22488@P@Q00<8@P0336<8@PQ20088@P0336<8@P@Q008<H`035:D@Q1BU
00@DY@<@Q00336<8@PaS008<H`0348@<H`aS00X<H`0348@<Ha24008<H`03
248<H`aS008@Q00536<8@PQ236<8@P0336<00`Q236<<H`0736<01Q2436<<
Ha2436<8@P8<H`8@Q08<H`04248<H`aS48@236<324800a2436<<H`0236<0
0`Q236<8@P0236<224800a2436<<H`03248336<2248536<01@Q236<8@PaS
48@01@aS00<8@PaS24800PaS0`Q200<<Ha2436<00`Q20`aS0`Q20`aS00@8
@PaS36<8@P@<H`D8@P0536<8@PQ236<8@P0436<00a2436<<H`04248010aS
48@<H`aS0PQ210aS00@8@PaS36<@Q0H<H`04248<H`Q236<224800`aS248<
H`0436<324800`aS248<H`02248436<02PQ2124<H`Q236<8@PaS248<H`Q2
0PaS00<8@PaS24800`Q20`aS00<8@PaS36<00@Q200000`00124000031240
0`0012448@0312400`aS6<HDY@0436<448@336<348@236<348@236<248@8
36<01A2436<<H`aS24800Q2400<<Ha2436<00a240PaS00<@Q0aS36<00PaS
0a2400@DY@aS48@@Q08<H`07248<H`aS36<@Q0Q236<011240PaS00@@Q0aS
48@@Q08<H`<@Q00436<8@PaS36<248@336<00`Q236<<H`0348@00`aS48@<
H`0336<0112436<@Q0aS0a2410aS0a240PaS00D@Q0aS36<8@PaS00D@Q004
248<H`aS36<548@01ABU48@8@PaS48@00QS600<DY@aS48@00PaS00D@Q1BU
48@@Q0aS00@@Q00336<DYA24008@Q0035:D<H`aS0088@P0336<8@P@Q01X4
8@03248<Ha24008@Q00324848@@Q00848@0>24848@Q236<@Q0Q248@]Jdic
IcU242485:D48@8<H`09248@Q1cW7>LDY@Q2124<H`@Q00@8@P041248@PQ2
124224800`@Q24848@0324801@aS2488@PQ212400PQ20`aS00@8@PaS36<8
@P<<H`L8@P0336<8@PQ200848@<8@P0636<8@PQ21248@PaS0PQ200@48@Q2
36<<H`88@P031248@PQ20088@P051248@PQ224848@02248010@Q2488@PQ2
2P@Q00D<HaS68@PYBR48008DY@0C36<@Q1S67>LU:B487>LQ22DY8@PDYA24
5:D<H`Q28@Pe[CW>:DX00PaS00<@Q0Q224800P@Q0PQ20P@Q10Q200@48@Q2
248<H`D8@P0336<48@@Q00@8@P031248@PQ2008<H`@8@P0536<DYABU5:D@
Q0025:D26<H00a2436<<H`0236<00a2436<8@P0236<348@836<348@010Q2
36<<H`Q21PaS00@@Q0aS36<8@PP<H`03248<H`aS00L<H`0348@DYA24008<
H`05248@Q0aS36<8@P0236<00a2436<<H`0436<01@Q236<<H`aS24800PaS
00H@Q0aS2488@PaS248436<00`Q236<<H`0636<224801@aS248<H`aS48@0
1@aS0PQ200<<Ha2436<00`aS00@8@PaS248<H`88@P@<H`03248<Ha2400@8
@P0336<8@PaS008<H`03248<H`aS008<H`88@P0936<@Q12424848@Q236<@
Q1BU00X<H`04248<H`aS48@736<00`Q236<8@P0236<224800`aS248<H`03
36<2248236<2248010aS2488@PQ20`aS00<8@PaS36<010Q200<<H`Q248@0
0`aS0`Q210aS0PQ20@@Q000412400`0012448@0312401P00124<HaS648@<
H`8@Q08<H`8@Q08<H`0448@DYA2448@436<00a2436<<H`0348@236<01124
36<8@PaS0Q240`Q20Q240PaS00@DY@aS248@Q08DY@0448@<H`aS48@336<3
48@00`aS48@<H`0248@536<3248010aS48@@Q1240`aS0Q240`aS0a240PaS
00<8@PaS48@00Q2400L8@PaS36<<Ha2436<@Q00436<00`Q236<@Q00248@2
36<448@236<0112436<8@PaS0Q240`aS00D@Q0aS36<<Ha24008<H`<@Q08<
H`0348@DYA2400H@Q08DY@036<H@Q0aS008<H`035:D@Q12400@@Q0035:D@
Q1BU008@Q00836<@Q1BU48@<H`Q2124<H`<8@P`48@030008@P@Q00@48@03
24848@@Q00848@88@P0436<@Q12436<32483124224803a2436<48A24<Ha:
DV<HAS4LiaBU248@Q1BU248@Q0027>L00a2412448@0224800`@Q24848@02
24801@aS2488@PQ2124030Q200<<H`Q224800PaS00<8@PaS36<00PaS0PQ2
00D<H`Q22488@PaS0088@P848@@8@P031248@PQ20088@P031248@PQ200L8
@P<48@D8@P051248@PQ21248@P051242248312402PQ236<48@Q248@LibU:
9BTHaQBU0PaS00TLib488@PLiaS68@PU:B487>L00Q2400H<H`Q29BTicSg_
;F/336<224800`@Q24848@031243248010@Q2488@PaS0PQ200D48@aS2488
@P@Q00<8@P<48@88@P8<H`88@P041248@PaS36<348@35:D00a245:D@Q003
36<248@336<548@01@aS248<H`aS48@00PaS00D8@PaS48@@Q0aS0088@P8<
H`8@Q08<H`03248<H`aS00<<H`8@Q003248<H`Q2008@Q0@<H`03248<H`aS
00@<H`0748@<H`Q236<@Q0aS24802PaS0`Q20PaS0PQ200@<Ha2448@<H`88
@P0736<8@PaS248<H`Q236<00PQ200@<Ha2436<@Q0<8@P0436<@Q0aS2484
36<2248236<0112436<<H`Q20PaS00L8@PaS36<<H`Q236<@Q00236<32483
36<5248436<2248736<2248336<010Q236<<H`aS0`Q20PaS00<8@PaS48@0
0`aS00/@Q0aS36<<H`Q236<8@PaS248<H`Q200@<H`<8@P8<H`88@P<<H`@8
@P8<H`88@PD<H`06248<H`Q236<8@PaS0PQ20PaS00D8@PaS36<8@PaS0048
@P0000<000@Q12400P@Q00@000@Q124000<48@0436<HaQBU36<248@236<3
48@336<00aBU48@@Q00336<248@336<00`Q236<<H`0236<00a2436<<H`06
36<0112436<8@PaS112410aS0Q2400H<H`Q236<@Q1BU48@25:D236<22486
36<348@436<448@436<248@02@aS48@@Q0aS48@<HaBU48@8@P0236<01QBU
48@<H`aS48@DY@<@Q0<<H`<@Q0X<H`<@Q0<<H`<@Q00436<@Q12448@636<2
48@00aBU36<@Q00448@00`aS48@@Q00448@00aBU36<<H`0348@236<01aBU
36<8@P@Q248<H`Q200d48@0324848@@Q00D48@0300048@Q20088@P<48@@8
@P@<H`03248<H`aS008<H`0:248@Q1BU;F/e[CW>DYAF]Dic>Lh248@22480
0`aS2488@P02124010Q236<8@PQ20P@Q0`Q200<48@Q236<00PaS10Q200L4
8@Q22488@P@Q24848@0436<3248236<01@Q21248@PQ236<00`Q200D<H`Q2
36<8@PaS00D8@P031248@P@Q0088@P8<H`<8@P848@<8@P031248@PQ20088
@P051248@PQ21248@P0212400`Q212448@07124224800a24=Jdmk`02IcT0
2SF]8@P8@PaS5:D8@PaS8@P]JacW0PQ200DDYBU::DXU:B48008<H`042484
8@Q224821242248312432482124:24800`@Q24848@031242248336<22482
36<248@011BU6<HLiacW0aBU0Q241@aS00<@Q0aS24800PaS00<@Q0aS48@0
10aS00@@Q0aS36<@Q0<<H`04248<H`aS48@236<010Q236<<H`Q23@aS00<8
@PaS36<010aS0Q240`aS00@@Q0aS2488@P8<H`D8@P0736<8@PaS248<H`Q2
36<00`Q200<<H`Q236<00PQ200<<H`Q224800PaS00<@Q0aS48@01PaS0PQ2
0`aS0PQ20Q240PaS00<8@PaS248010aS0PQ210aS00@8@PaS36<<H`<8@P06
48@<H`aS248<H`Q20PaS0`Q200<<H`Q236<02@aS00<8@PaS24800PaS00<8
@PaS36<00`aS00<8@PaS36<00PaS00<@Q0aS36<00PaS0PQ20PaS00D@Q0aS
36<8@PaS0088@P0336<8@PaS00<8@P@<H`<8@PH<H`<8@P<<H`88@P8<H`04
48@8@PQ2248436<00`Q236<8@P0112400004124000@Q000812400a248@P@
Q00236<248@00`aS48@@Q00336<00a245:D@Q00248@436<348@236<248@0
0`aS2488@P0336<2248736<248@436<01Q2436<<H`aS48@<H`<@Q0065:D@
Q0aS48@<Ha240`aS00<8@PaS36<00a240PaS00@@Q0aS48@@Q08<H`8@Q005
36<@Q0aS36<@Q00336<00`Q236<@Q00248@336<00a245:D<H`0236<01124
36<<H`aS1Q2410aS00<@Q0aS36<00`aS0a240`aS00D@Q0aS36<8@PaS00D@
Q08<H`0348@DYA24008@Q00336<@Q0aS00D@Q00336<@Q12400<@Q00;36<@
Q0aS248@Q1S65:D8@P@Q248<H`02248512400`001248@P04124224821240
0`0012448@02248010@Q24848@@Q0PQ200@<H`@Q248<H`8@Q00336<8@PQ2
008<H`0448@<H`aS36<25:D02B48<H`icU[FE[E6<CW>5:D@Q00336<22480
1@@Q2488@PaS24800`@Q00<8@P@Q24801PQ200D48@Q224848@aS00<8@P84
8@88@P0436<8@PaS248336<312400`Q236<8@P02248010aS2488@PaS2`Q2
0P@Q1@Q20P@Q0PQ200<<H`Q224800`@Q0PQ20P@Q00<8@P@Q12400P@Q0PQ2
0P@Q00L8@P@Q2488@QBU>Li24002IcT02Re[8@P48@Q25:D8@Q24:DX]JaS6
0PQ200<HaRe[9BT00QcW0PaS0`Q200@48@Q21248@P848@0524848@Q22484
8@0;2483124424821243248010aS2488@PQ20PaS0aS60aBU00<HaQBU48@0
1`aS00@@Q0aS36<<H`8@Q08<H`88@P0436<@Q12448@236<248@00`aS48@<
H`0636<00`Q236<<H`0336<010Q236<<H`Q20`aS0a240PaS0Q241PaS00<8
@PaS24800PaS00<@Q0aS36<00`Q200<<H`Q236<00PaS00<8@PaS248010Q2
00D<H`Q2248<Ha24008<H`05248<Ha2436<@Q00236<00`Q236<<H`0336<0
0`Q236<@Q00336<00`Q236<<H`0236<01@Q236<8@Q2436<00PQ20PaS0PQ2
0Q2400<<H`Q236<010aS00L8@PaS2488@PaS248<H`04248736<00`Q236<<
H`0636<00`Q236<8@P0636<00a2436<<H`02248836<00`Q236<8@P022480
10aS248<H`Q20PaS00@8@PaS36<@Q0<<H`88@P8<H`@8@PD<H`<8@P<<H`88
@P0336<8@PQ20048@P0010@Q00<000@Q00000P@Q00L000@Q124@Q1cW5:D8
@P0248@010aS48@@Q1BU0a2400<<Ha2448@00`aS0a241PaS00<@Q0aS2480
10aS0PQ200H<Ha2448@@Q0aS48@536<01@Q236<<H`aS48@01PaS0a240`aS
00@@Q0aS2488@P<<H`0348@<Ha24008@Q0035:D<H`Q2008<H`0648@<H`aS
248@Q0aS0Q240PaS00`8@PaS48@DY@aS248@Q1S648@<H`Q236<348@01@aS
248@Q1245:D01@aS00H@Q0aS48@@Q0aS48@>36<348@00`aS48@DY@0248@3
36<548@01@aS48@<Ha2436<011240PaS00@@Q0aS36<@Q08<H`0424848@Q2
248=12400`0012448@0;12400`Q212448@021243248010@Q2488@PQ20`aS
00@8@PaS5:DQ208Li`0;6<HLic6<<H`icS6<7>LDY@Q21248@P0236<00`Q2
1248@P022482124324801@aS48@@Q0aS24800`@Q10Q20`@Q00<8@P@Q2480
0PaS00@@Q0aS2488@P848@04248<H`Q21242248248@00`aS1248@P021244
248312400`Q236<8@P0324831242248212401@Q21248@P@Q24801@@Q10Q2
00/000@Q12448@Q21248@P@Q36<@Q1cW00924004IcU[FT8@<H`236<00aBU
36<<H`0324801`@Q36<<Ha2436<8@P@Q00<8@P0336<8@P@Q00<48@T8@P03
1248@PQ20088@P8<H`<8@P@48@<8@P8<H`04248<H`Q236<248@011S648@D
YA240QS600DDYA2436<8@PaS008@Q0H<H`@@Q08<H`8@Q08<H`03248<Ha24
00<<H`03248@Q0aS00@<H`03248<H`aS00X<H`8@Q08<H`<@Q00336<@Q124
00@<H`88@P0436<8@PaS248436<224801`aS2488@PQ236<8@PaS00<8@P8<
H`<8@P8<H`8@Q00536<8@PaS36<@Q00424800`aS2488@P0236<248@010aS
2488@PQ210aS00@8@PaS36<8@P8<H`03248<H`Q200L<H`88@P@<H`88@P8<
H`88@PH<H`03248<H`Q20088@P0436<@Q12436<2248336<2248236<00a24
36<<H`0236<2248236<3248536<00`Q236<8@P0:36<248@236<5248336<0
1@Q236<<H`aS24800PaS00@@Q0aS2488@P8<H`@8@P0000@48@00124000P4
8@0548@Q21BU48@DY@0248@236<248@00aBU48@@Q00436<448@336<00`Q2
36<<H`0436<00a2436<8@P0224801@aS248<H`aS48@010aS00L@Q0aS36<@
Q0aS48@8@P0436<648@236<010Q236<<H`Q21@aS0a240PaS0Q240`aS00<@
Q0aS24800PaS00<@Q1BU36<00PaS0Q240PQ200D<HaBU48@8@PaS00<@Q006
248<Ha2448@DYA240`aS00D8@Q2448@@Q1BU008@Q08<H`<@Q00336<@Q0aS
00<<H`03248<H`aS008<H`0448@DYABU5:D236<01A2436<@Q12436<00Q24
00H<H`Q248@@Q1BU48@236<248@336<020Q2124@Q1S65:D8@P@Q248236<0
1@@Q00048@@Q00003P@Q00<8@P@Q12400P@Q00@8@P@Q12448@H8@P051248
@PaS36<8@P0236<03a24248@Q1S67>LQ21cW6<HLibe[<H`icSF]7>LHaP07
24821243248212400`Q248@@Q00236<01PQ212448@@Q248<H`P8@P<<H`03
248<H`Q20088@P@48@88@P8<H`<8@P848@0436<8@PaS2483124524801`aS
24848@Q21248@P@Q00@8@P848@<8@P@48@0324848@Q200D48@88@P0948@D
YAcW?Nm246LiKg/mkcF]00D<H`88@P0:124<H`aS248<Ha2436<8@P@Q2482
36<00`Q212448@0212400`Q21248@P031242248010aS2488@P@Q1PQ200@4
8@Q22488@P<48@05248<H`aS36<8@P0236<348@01aBU48@@Q1245:DLia24
00<<H`0548@<H`aS36<8@P0236<348@00`aS248<H`0236<010Q236<@Q124
1@aS00<@Q0aS36<040aS00L8@PaS36<<Ha2436<@Q00236<348@536<22480
10aS248<H`aS0`Q200T48@Q22488@PaS248<H`Q236<00PQ20`aS0PQ21PaS
00<8@PaS36<00PaS00<8@PaS36<00PaS00<8@PaS24800`aS00<8@PaS36<0
1@aS00H8@PaS36<8@PaS248236<01PQ236<8@PQ236<@Q08<H`88@P@<H`88
@P<<H`03248<H`aS00<<H`@8@P/<H`06248<H`Q2248<Ha240PaS0PQ21`aS
10Q20`aS00<8@PaS36<00PaS00<8@PaS36<01@aS0`Q200@<H`Q22488@P@<
H`03248<H`aS008@Q00436<8@PaS248236<22480000300048@@Q00848@0:
00048@@Q00048@00124<HacW5:D=48@436<011245:D<H`aS0PQ220aS0PQ2
0PaS0PQ200D<Ha2448@8@PaS00<@Q0<<H`04248<H`aS36<348@00`aS48@<
H`0348@436<00a2436<<H`0236<25:D0112436<@Q1242@aS0Q242@aS00<@
Q0aS36<00PaS00<DYA245:D00Q2400H<Ha2448@@Q0aS248236<00a2436<<
H`0336<01@Q236<<H`aS48@01@aS0Q240`aS0Q2400<DYA2436<00PaS1124
00@<Ha2436<@Q08<H`0448@<Ha2436<448@020aS2488@PaS5:D@Q0aS1242
248912400`0012448@071240100012448@Q20`@Q00<8@P@Q12400P@Q00D8
@P@Q24848@Q200848@88@P031248@PQ20088@P0336<@Q0aS008<H`<@Q08<
H`0548@LiaS648@48@0324800`@Q2488@P0224800`@Q2488@P02248236<0
0`Q212448@0224801@@Q2488@PQ212400PQ20P@Q00<8@P@Q36<00PaS0`Q2
0`@Q00<8@P@Q24800`Q20P@Q00@8@P@Q124<H`<DY@<48@03248@Q0aS0088
@P0836<8@PQ21248@P@Q24848@<8@P051248@P@Q1248@P02124424861240
2PQ21248@PQ236<DYAcW9BTQ23g_0TYB00DmkaS648@<H`@Q00D8@P031248
@PQ2008<H`08248<H`aS36<48@Q2124<H`88@P071248@PQ224848@Q21240
1@Q200<48@Q224800PQ20P@Q00<8@P@Q24800`Q200<<H`Q224800PQ211BU
00@<Ha245:DHaP8DY@P<H`<@Q08<H`<@Q0<<H`03248<H`aS00d<H`0348@<
Ha2400@<H`03248<H`Q200X<H`8@Q08<H`03248<H`aS008<H`88@P8<H`<8
@P0648@<H`Q2248<H`Q20PaS0Q2400H<H`Q2248<H`Q236<2248010aS48@@
Q0aS10Q21@aS00D8@PaS36<<Ha2400<8@P0336<8@PaS008<H`88@P0836<@
Q0aS36<8@PaS24848@8<H`0348@<H`aS00<8@P0436<8@PaS248436<22483
36<348@3248236<2248236<2248336<2248436<00a2436<<H`0236<00a24
36<<H`0436<224800`aS248<H`0236<2248010aS48@@Q1240PaS00<8@PaS
36<00PaS0PQ20`aS00<8@PaS36<00PaS00@8@PaS36<8@P<<H`04248<H`aS
36<3248136<1248000@48@0300048@@Q00D48@0336<HaQBU00@@Q0035:D@
Q12400<@Q00436<@Q1BU5:D236<01QBU48@<H`Q236<@Q0L<H`<8@P<<H`88
@P0336<DYA24008<H`03248<H`aS00<<H`03248<H`Q2008<H`H@Q08<H`09
48@<H`aS248<Ha24248<Ha24008DY@0436<8@PaS36<348@336<00`Q248@@
Q00248@336<248@01`aS48@<H`aS48@<Ha2400<<H`@@Q0035:D@Q1240088
@P<<H`<@Q0<<H`0448@<H`aS36<348@836<448@336<248@236<011245:DD
YA240`aS0a240`aS0Q240`aS0Q2400<8@P@Q24800`Q20P@Q00<000@Q1240
1P@Q00<000@Q12401`@Q00H8@P@Q124000@Q248512401@Q21248@PQ21240
1@Q20PaS00H@Q0aS36<<Ha245:D348@35:D00a2424848@0424800`@Q2484
8@02248212400`Q236<<H`022483124010aS24848@@Q1@Q20P@Q00D8@PaS
36<<H`Q200<48@0324848@0000848@0<24848@@Q1248@P00124<Ha247>L@
Q0Q20P@Q0PQ20`aS00@8@P@Q24848@@8@P031248@P@Q00@8@PD48@03248<
H`Q200H48@<8@P0<36<DYAcW:DXQ23g_CW=:DSW>6<H@Q0aS0PQ20`@Q10Q2
0`aS00@8@PaS36<8@P848@D8@P@48@88@P0736<8@P@Q248<Ha2436<00PQ2
00<48@Q212400PQ200<48@Q224800`Q200<<H`Q248@00aBU0Q2400HDYAS6
6<H@Q0aS248:36<248@236<00`Q236<<H`0236<00a24248<H`0336<248@4
36<01A2436<<Ha2424801`aS00<@Q0aS36<010aS0a2410aS00@@Q0aS248<
H`<8@P@<H`88@P0336<@Q0aS00<8@P8<H`04248<H`aS36<248@00`aS248<
H`0336<348@01`aS248<H`aS48@<H`Q200@<H`<8@P0336<8@PQ2008<H`03
48@<H`Q200T8@P<<H`03248<H`Q200@<H`88@P031248@PQ2008<H`05248<
H`aS36<@Q00236<2248011242488@P@Q0`aS0PQ200<<H`Q236<00Q2400<<
H`Q236<00PaS0PQ20a240`aS00<8@PaS24800`aS0PQ20`aS0PQ20`aS00<8
@PaS36<00Q2400<8@PaS36<00Q240PQ200P48@aS36<<Ha2436<8@PaS10Q2
1`aS0@@Q00000`00124000031240100012448@000P@Q00D8@QcW6<H<Ha24
008<H`DDY@8@Q0045:D@Q1245:D348@01@Q236<<H`aS48@02PaS00@8@PaS
248@Q08<H`0548@<H`aS36<8@P0536<348@336<00a2436<<H`0336<00a24
36<<H`0536<01ABU48@@Q12436<00Q240PaS00@@Q1BU36<<H`88@P0336<@
Q12400<<H`<@Q0H<H`<@Q00336<@Q12400@@Q0@<H`0448@<Ha2436<348@0
10aS48@<Ha240PaS00<@Q0aS36<00PaS00<@Q0aS36<00PaS0a2400D<Ha24
48@@Q1BU008<H`0348@<Ha2400<<H`0348@<Ha2400<@Q0T<H`04248<H`Q2
248212400`0012448@0912400`0012448@0812400`Q212448@0212422482
124010Q212448@Q20`aS0PQ20PaS00@8@P@Q2488@P8<H`<8@P0448@<H`aS
36<4248010aS2488@P@Q0PQ200<<H`Q212401`@Q00@8@P@Q12448@88@P03
36<48@Q200D8@P8<H`0524848@@Q24848@02248212400`Q21248@P021243
248010aS2488@P@Q0`Q21PaS20Q210aS0PQ210@Q00H8@P@Q2488@P@Q2482
124010Q212448@@Q0PQ20`aS00D@Q1BU5:DDYA24008<H`88@P848@032484
8@Q200D8@P8<H`@8@P@48@<8@P051248@P@Q24848@0324800`@Q2488@P02
48@010aS24848@@Q10Q200<48@Q236<00`Q200D@Q1BU48@<Ha2400<DY@03
48@<H`Q2008<H`0348@<H`Q2008<H`8@Q0<<H`<@Q0@<H`04248<H`aS48@2
36<248@336<00a2436<8@P0236<0112436<8@PQ210aS00L8@PaS48@@Q0Q2
36<8@P0336<00a2436<<H`0324800`aS248<H`0236<00`Q236<<H`0236<0
0`Q236<@Q00236<3248236<00`Q236<<H`03248436<2248236<00`Q236<8
@P0636<3248336<2248336<011242488@PaS10Q20`aS00<@Q0aS24800PaS
00H@Q0aS36<8@PaS248636<2248736<324800`aS248<H`0336<00`Q236<<
H`0236<2248336<01A2436<<H`aS48@00`aS0PQ21@aS00<8@PaS36<00PaS
00<8@Q2448@00PaS00<8@PaS36<00PaS0PQ20`aS0PQ20PaS00<@Q0aS2480
20aS0PQ20PaS0@Q20@aS000512400`0012448@0412401@aS7>LDYA2436<0
0Q240QS60QBU0a240aBU0a240PaS0Q2400@DY@aS36<8@PD<H`03248<H`aS
00D<H`<@Q00336<8@PQ200/<H`<@Q0D<H`0348@<H`aS00@<H`8@Q08<H`05
48@<H`aS36<@Q00436<01Q2436<<H`aS48@DY@8<H`0348@<H`aS008<H`04
48@<Ha2436<248@236<00a245:DDY@0348@636<248@436<00a2436<<H`02
36<01@Q236<<Ha2436<00Q2400D<Ha2448@@Q0aS00@@Q0X<H`@@Q0<<H`03
5:D<H`aS00<<H`<8@P8<H`h48@0424848@@Q000:12400`Q21248@P032483
124224800`aS2488@P07248336<3248336<2248010@Q248<H`Q20P@Q00<8
@PaS36<00PQ20P@Q00@8@P@Q12448@L8@P031248@P@Q00<48@<8@P8<H`03
24848@@Q0088@P848@88@P<48@88@P03124<H`aS008<H`848@0524848@aS
248@Q00336<2248010@Q2488@PaS0`Q20PaS0PQ200@48@Q22488@P848@@8
@PH48@<8@P0436<8@PQ248@35:D424800`aS2488@P042483124010Q236<8
@PQ20PaS00@8@P@Q12448@<8@P848@@8@P031248@P@Q008<H`04248<Ha24
36<524801P@Q2488@PQ236<8@P<<H`8@Q0DDY@<<H`06248<H`aS36<8@PaS
0Q240`aS00<@Q0aS36<00PaS0a240`Q20PaS00<@Q0aS36<00`aS00<@Q0aS
36<00`aS0PQ21@aS00H@Q0aS36<8@PaS248536<224800`aS248<H`0536<2
248536<01@Q236<8@PaS24800`aS0PQ20`aS0PQ20`aS0Q2400H<H`Q236<8
@PaS248436<010Q236<<Ha240PaS0`Q200@<Ha2436<8@PD<H`<8@P<<H`@8
@P8<H`0448@<H`aS248536<00`Q236<<H`0236<248@01@aS2488@PQ236<0
0`Q20PaS00D@Q0Q236<8@Q24008<H`07248<H`Q236<@Q0aS48@01`aS0PQ2
0PaS00<8@PaS36<00`aS00<8@PaS36<00Q2400T<H`Q236<<H`Q236<8@PaS
24802@aS00<8@PaS36<010aS0PQ210aS0@@Q0000100012448@001@@Q00H0
00@Q124<HaS65:D336<448@55:D00a245:D@Q00548@00`aS48@<H`0248@2
36<248@010Q236<<Ha240`aS00<@Q0aS36<010aS00<8@PaS36<01PaS0a24
00<<H`Q236<00PaS1A240`aS0Q240`aS00<@Q0aS48@010aS00<8@PaS36<0
10aS00<@Q0aS36<01@aS00D8@Q245:D@Q1BU00<<H`D@Q00336<@Q12400D<
H`0348@<H`aS00D<H`@@Q0<<H`0448@<Ha2448@236<248@00aBU36<<H`02
36<348@236<010Q248@<Ha2410aS0Q240`aS00<8@Q2448@00PaS00H48@Q2
2488@P@Q000412400`0012448@0>12400`Q212448@021243248412422480
0`@Q2488@P0224801A2436<<H`Q2124010Q200<<H`Q224800`Q200H<H`Q2
248<H`@Q248336<2248236<00`Q21248@P02248512422485124324821245
24800`@Q2488@P04124324800`@Q248<H`02248212422485124010aS48@<
H`Q20P@Q10Q20PaS0Q240`aS1PQ20`@Q0`Q20P@Q00<8@P@Q124010Q200<<
H`Q236<00PaS2`Q20`@Q0`Q20PaS0PQ20`@Q00<8@P@Q248010@Q00<8@P@Q
12400`Q20P@Q0`aS00D8@P@Q24848@Q200<<H`0324848@@Q0088@P<@Q005
5:DHaQS65:D@Q00236<248@010Q236<<H`aS0PQ20Q2400D<H`Q248@DYA24
0088@PD<H`8@Q0@<H`0548@<H`Q236<@Q00236<00`Q236<<H`0436<22483
36<3248536<01@Q236<8@PaS24800`aS00<8@PaS36<010aS00<8@PaS36<0
2PaS0`Q200L<Ha2436<<H`Q236<@Q00236<010Q236<@Q1240`aS20Q200<<
H`Q236<010aS10Q20`aS00H8@PaS36<@Q0aS248436<2248236<00a2436<<
H`0936<00`Q236<<H`0236<3248336<5248836<00a2436<<H`0236<22482
36<00a2436<<H`0248@236<01@Q248@<Ha2436<00PQ20PaS0`Q200<<H`Q2
36<00`aS00<8@PaS36<00PQ20PaS00<@Q0aS24800PQ20PaS0`Q200021240
1`0012448@@Q00048@0000<48@0736<HaQBU36<@Q0aS48@00QBU00T@Q0aS
36<DYAS65:D@Q0aS5:D00Q2400H<Ha2448@DYA245:D636<01@Q236<<H`aS
48@010aS00<@Q0aS36<02PaS00P@Q0aS36<<Ha2436<8@PaS0a2400<<HaBU
48@00`aS0Q2400<<Ha2436<00Q240`aS00H8@PaS248<H`Q248@636<00`Q2
36<<H`0336<248@01aS648@<H`aS48@DYA2400<<H`<@Q0@<H`8@Q004248<
H`aS48@336<248@736<00a2436<@Q00248@011BU36<@Q1240`aS0Q2400<<
H`Q236<010aS0a2410aS0PQ20a240PQ200<<H`Q224800P@Q00<8@P@Q1240
3P@Q00D8@P@Q124000@Q0088@P031248@P@Q00<48@0324848@@Q00848@04
36<8@P@Q124436<010Q21248@P@Q0PQ200<48@Q2248010Q200<<H`Q21240
0`Q200@<H`Q22488@P8<H`0424848@Q22484124324851242248312401PQ2
36<<H`aS24848@88@P@48@88@P848@0324848@Q200<8@P0336<48@@Q0084
8@88@P031248@PaS0088@P031248@PQ200<8@P0436<@Q12448@436<22480
10@Q2488@PQ20P@Q0PQ20P@Q0`Q20P@Q0PQ200D48@Q236<@Q0aS00<8@P8<
H`88@P848@@8@P848@H8@P<48@0424848@Q2124424821242248212462480
0`aS2488@P02248236<00`@Q2488@P0236<248@021BU48@@Q1BU6<HDYA24
248436<00a2436<8@P0236<00a2436<<H`0236<248@336<3248336<00a24
36<@Q00336<2248010aS248<H`Q20`aS00<@Q0Q224801@aS00<8@PaS36<0
0PQ200@<Ha2436<8@P8<H`0448@<H`aS248336<248@436<3248336<32484
36<00`Q236<8@P0336<00`Q236<<H`0736<2248436<22480112436<8@PQ2
0`aS0PQ20`aS00<8@PaS36<00`aS0PQ200D<Ha2448@<H`@Q00@8@P<<H`03
248<H`aS00<<H`<8@P0336<8@PQ20088@P@<H`03248<H`aS00H<H`8@Q003
248<H`Q200L<H`04248<H`aS248236<348@010aS48@<H`aS1PQ200@<H`Q2
36<8@P@<H`03248<H`aS008<H`<8@P@<H`04248<H`aS36<2248000050004
8@@Q1240000512401P00248@Q2DY6<H8@P<<H`8@Q0045:D<H`aS48@26<H2
48@00aBU48@<H`0236<01QBU48@@Q0aS48@<H`8@Q08<H`0348@<H`aS008<
H`0348@<Ha24008<H`0648@<H`aS36<8@PaS0Q2410aS0Q241@aS1A2400<<
Ha2448@00a2400@<Ha2448@<H`@@Q003248<H`aS00D<H`03248<Ha24008<
H`04248<Ha2436<348@25:D00a2436<<H`0248@436<448@536<01A2436<<
H`aS24800PaS0Q2400<<H`Q236<00PaS0Q2400<<Ha2436<00Q2400P<Ha24
36<<Ha2436<@Q0aS0Q2400@<H`Q236<<H`8@Q0<<H`0448@DYABU48@236<0
1`Q236<@Q0aS248<H`Q200H48@0300048@@Q0088@PX48@0324848@@Q00<4
8@88@P848@0524848@@Q1248@P02124010001248@PQ20P@Q0PQ20PaS1PQ2
00@48@Q2248<H`848@03248<H`Q200@8@P031248@PQ200@8@P848@<8@P@4
8@88@P031248@P@Q00L48@05248<H`aS248<H`02124224800`aS24848@02
24801@aS2488@PQ212400PQ20P@Q0PQ200<48@Q212401@Q20PaS0PQ20PaS
00L@Q1S66<HDY@aS1248@P021242248312400`Q236<8@P03248812422485
36<010Q21248@PQ20`@Q0PQ20`@Q0PQ20`@Q00<8@P@Q24801@@Q00@8@P@Q
1248@P848@0424848@Q2248212400`Q212448@02248236<00`Q2124<H`02
24800`@Q248DY@035:D01A245:DHaQBU48@00`aS00D8@Q2448@@Q1BU00H<
H`0348@<H`aS00/<H`03248<H`aS00D<H`<8@P0536<@Q0aS36<8@P0536<2
248436<2248336<224800`aS48@<H`0536<00`Q236<<H`0224801@aS48@<
H`aS248010aS0`Q20PaS00<@Q0aS36<02@aS00@8@PaS248<H`88@P041248
@PQ2248436<00a2436<8@P0536<00`Q236<@Q004248536<2248436<00`Q2
36<@Q00236<010Q236<<H`Q20`aS00<8@PaS36<00PQ200<48@aS36<00`Q2
0PaS00L8@PaS36<<Ha2436<8@P0236<01A2436<<H`Q236<00a240`aS00L@
Q0aS36<8@PaS48@DY@0236<01P@Q248<H`aS48@<H`88@P@<H`8@Q08<H`04
48@8@PQ2248248@00`aS2488@P0636<000<48@0300048@@Q00<48@060004
8@@Q5:DU:AS610aS0a240PaS00<@Q1BU5:D00Q240QBU0PaS00@@Q1BU48@@
Q0<<H`<@Q08<H`88@P0736<@Q1245:D@Q0aS48@030aS00<@Q0aS48@00`aS
00X8@PaS48@DYA2436<@Q0aS48@DY@8@Q0<<H`@@Q08<H`03248<H`aS00@<
H`0348@<H`aS00D<H`8@Q00536<@Q1245:D@Q00536<01A2436<@Q0aS48@0
1@aS0Q240PaS00@@Q0aS36<<H`<@Q08<H`03248<H`aS00<<H`<@Q00336<@
Q0aS008<H`03248@Q0aS00H<H`8@Q0@<H`0448@DYA2436<224800`aS48@<
H`0324800`aS2480000912400`Q212448@0:12400`0012448@0212422480
0`@Q24848@03124224800`@Q2488@P0224800`@Q2488@P0224801@aS2488
@PQ212400`Q200<48@Q236<02@Q200@48@Q22488@P<48@0436<48@@Q1243
24800`001248@P08124224800`aS2488@P02248010@Q2488@PQ20`@Q1@Q2
00H<H`Q22488@P@Q2487124020Q236<8@PQ21248@PaS48@26<H25:D01PaS
2488@P@Q24848@88@P041248@PQ2124424800`@Q24848@0212401PQ21248
@PQ236<8@P8<H`<8@P0536<48@@Q1248@P0412442483124224800`@Q2484
8@0212400`Q212448@0312400`Q212448@03124424800`@Q248<H`062482
36<00a245:DDY@055:D0112436<<H`aS112400<<Ha2436<02`aS00<8@PaS
36<00`aS00<@Q0aS24800PaS00<@Q0aS24800PaS0PQ21@aS0PQ20PaS00D8
@PaS248<H`Q2008<H`03248<H`aS00D<H`07248<H`aS36<@Q0Q236<00PQ2
00<<H`Q236<01PaS00<8@PaS248010aS00@8@PaS36<@Q08<H`88@PP<H`88
@P03124<H`Q200H<H`0448@<H`aS248636<00`Q236<<H`0G36<00`Q236<<
H`04248236<248@00`aS2488@P0236<248@936<248@536<00a2436<<H`02
36<011BU48@<H`Q21PaS00<8@PaS36<00PaS00D@Q0Q236<8@PaS008@Q003
36<8@PQ200<<H`88@P0536<8@PaS48@<H`0124800003124000@Q00848@04
00048@@Q0003124011247>L@Q0aS0a240`aS00<@Q0aS48@01a240PaS00<@
Q0aS36<00PaS0a240`aS1A2400<<Ha2448@0112400D<Ha2436<<Ha2400<<
H`<@Q08<H`8@Q00336<8@PaS00@@Q0045:D@Q1245:D248@336<011245:D@
Q0aS0PQ210aS00<@Q0aS36<01@aS00<@Q0aS36<00`aS1Q240`aS00DDYA24
48@8@PaS00@@Q08<H`8@Q0<<H`0548@<H`aS36<@Q00236<348@236<25:D0
10aS248<Ha2410aS00@@Q0aS36<<H`8@Q00436<8@PaS36<348@011BU6<HD
YA240PaS00D@Q1BU48@<H`@Q00@8@P848@0300048@@Q00<48@0300048@@Q
00848@88@P<48@0324848@@Q00<48@<8@PD48@0424848@@Q124224841245
24801@@Q2488@P@Q24800P@Q0`Q200<48@Q224800PQ200<48@Q224801@Q2
00<48@Q224800PQ21P@Q0PQ210@Q0PQ21@@Q0PQ210@Q00H<HacW8@PDY@@Q
248236<2248236<2248010@Q2488@PQ20`@Q0`Q200@<Ha2436<<H`@48@05
48@U:BDY8@P<H`0212401PQ21248@P@Q24848@88@P0336<8@PQ200848@03
24848@Q20088@P061248@P@Q1248@PaS0PQ20`aS0P@Q1@Q21P@Q00<8@P@Q
12401@@Q0PQ200@48@Q21248@P@48@0324848@Q200<48@0324848@Q20084
8@<8@P<48@8<H`<DY@8@Q0035:DHaQBU008<H`8@Q08<H`0448@<H`aS36<3
48@336<010Q236<<Ha242PaS0PQ20PaS00<8@PaS24800`aS00<8@PaS36<0
0Q2400<<H`Q224800`aS00<@Q0Q224800PQ200<@Q0aS36<01PaS0a240`aS
00@@Q0aS248<H`8@Q00336<8@PQ2008<H`0348@<H`aS00@<H`<8@P<<H`<8
@P0;36<@Q12436<8@PaS248<H`Q236<8@P0436<00a2436<<H`0636<22487
36<0112436<<H`Q210aS00D8@PaS248<H`Q200<<H`03248<H`Q2008<H`88
@P0536<@Q12436<8@P0236<01A2436<<H`aS48@01@aS00<8@PaS36<01@aS
00@8@PaS36<<H`@@Q08<H`@@Q0@<H`03248<H`aS008<H`88@P<<H`0448@<
H`aS248436<2248010aS48@@Q0aS0PQ20`aS0@Q200001@0012448@@Q0000
1`@Q00<@Q1cW5:D00PaS00H@Q0aS36<<Ha2436<348@00aBU48@DY@0248@3
36<00a2436<<H`0448@436<548@00`aS48@@Q0025:D00a2436<<H`0236<0
112436<<H`aS0a242@aS00<@Q1BU48@00PaS212410aS00<@Q0aS36<01PaS
00<@Q0aS24800PaS00D@Q0aS36<<Ha2400@<H`@@Q00336<@Q12400@<H`<@
Q00436<@Q12448@636<00a2436<<H`0236<248@236<00a2436<<H`0536<2
48@336<00a2436<<H`03248010aS5:D@Q12411BU00<<H`Q236<00Q2400<8
@P@Q12400PQ280@Q00<8@P@Q12400P@Q00D8@P@Q1248@P@Q0088@P091248
@PQ2248<H`Q21248@P@Q00<8@P0436<8@PQ2124224800`aS2488@P021240
10Q236<8@PQ20`@Q00L8@P@Q12448@Q21248@P0312442482124224800`@Q
2488@P0524801@0036<LiacW5:D00P@Q0PaS00<8@PaS36<00PQ200@48@Q2
2488@P@48@88@P0?124<Ha2436<8@P@Q248<H`Q236<Libe[7>L<H`@Q0088
@P031248@PQ200H8@P848@0324848@@Q00<48@0324848@Q200<8@P<<H`@8
@PD48@0524848@@Q1248@P02124224831242248412400`Q212448@061240
10Q21248@P@Q0PQ20P@Q0`Q20P@Q0PQ200D<HaBU5:DDYA24008DY@036<H<
H`Q2008<H`0448@<H`aS36<348@010aS48@<Ha241@aS00@8@PaS36<<H`88
@P<<H`0324848@Q200<<H`03248<Ha24008<H`88@P0336<@Q0aS008<H`88
@PH<H`<8@P0336<@Q0aS00H<H`8@Q0@<H`03248<H`Q200P<H`03248<H`aS
00<<H`04248<H`aS36<424800`aS48@<H`03248236<00`Q236<8@P022480
10aS248<H`aS0Q2400<<Ha2436<00`Q20PaS0PQ200<<Ha2436<040aS00@8
@PaS36<8@PL<H`88@P<<H`03248<H`aS008<H`03248<H`aS0088@P0436<8
@PQ236<348@010Q236<<H`aS0Q241PaS00<@Q0aS48@00PaS10Q20`aS0`Q2
00@<Ha2448@@Q0D<H`04248@Q0aS48@336<01A2436<8@PQ236<00@Q20002
12401@0012448@@Q00000P@Q00T000@Q124@Q1cW48@8@Q245:D00`aS1Q24
0PaS0Q2400D<Ha2448@@Q1BU008<H`03248<H`aS008@Q00536<8@PQ236<@
Q00236<01A2436<<Ha245:D00a240PaS0Q2400@DY@aS36<<H`8@Q0L<H`8@
Q00336<@Q12400<@Q0035:D@Q124008DY@056<HDY@aS36<8@P0536<248@0
10aS48@<Ha241PaS0a241`aS00D@Q0aS48@<Ha24008<H`03248<H`aS00<@
Q0H<H`0348@<Ha2400D<H`08248<Ha245:D@Q0aS48@<H`88@P0336<@Q1BU
00<<H`0348@<H`aS008<H`05248@Q1245:DHaP025:D0112436<<H`aS0PQ2
00<<H`Q224805`@Q00<000@Q12401`@Q00<8@PaS24800`Q200D48@Q21244
8@Q200848@<8@P0436<8@P@Q12422482124324800`@Q2488@P0324800`@Q
2488@P02248010@Q24848@Q20P@Q00<8@P@Q24800`@Q00<8@P@Q248010@Q
00L8@P@Q12448@Q21248@P021242248236<224800a2436<@Q0045:D010aS
48@<Ha240PaS00<48@Q212400`Q20`@Q0`Q20`@Q00<8@P@Q36<00aBU0`Q2
00H48@Q2248<H`Q236<7248212400`Q21248@P0512400`Q21248@P0236<0
1@Q212448@@Q24800P@Q00D8@P@Q12448@Q200848@0824848@@Q24848@Q2
1248@PD48@0324848@@Q00P48@88@P848@0424848@Q21242248010@Q2488
@PaS0Q2400LDYA246<HHaQ2436<8@P0336<00a2436<@Q00436<248@636<0
0`Q236<@Q00<36<01@Q236<<H`aS24800PaS00@8@PaS36<@Q0<<H`03248<
H`aS00H<H`04248<H`aS248236<248@936<00`Q236<@Q00736<010Q236<<
H`aS0`Q200H<Ha24248<H`Q236<524800`aS48@@Q004248?36<010Q236<<
Ha2410aS00<@Q0Q224800PQ20`aS0a240PaS00<8@PaS36<00`aS0PQ22@aS
00D8@PaS48@@Q0aS0088@P8<H`0348@<H`aS00H<H`0448@<H`aS36<448@3
36<010Q236<<Ha2410aS0`Q200<<Ha2436<00PaS00<8@PaS36<00`aS00<@
Q0aS36<00PaS00H@Q0aS36<8@Q2436<224800003124000@Q00848@030004
8@@Q00@48@045:DLia2436<348@236<00a2436<<H`0348@336<01Q245:D@
Q1BU48@8@P8<H`<@Q006248<H`aS48@DYA240PaS00<@Q0aS48@00Q240QBU
0Q2400<<Ha2448@00PaS0a240PaS00<@Q0aS36<00PaS00<@Q0aS48@02Q24
0QBU0Q240`aS00<8@PaS36<010aS0Q2400@DY@aS36<8@P<<H`0348@<Ha24
008@Q0@<H`@@Q0D<H`8@Q00736<8@PaS48@DYA2436<00a2400<<Ha2448@0
10aS00D@Q0aS36<<Ha24008<H`0548@<H`aS36<8@P0248@00`aS48@<H`03
36<2248010aS48@DYABU0QS60QBU0`aS00<8@PaS24800PQ22`@Q00D000@Q
12448@0000848@0324848@@Q00848@0324848@0000D48@0400048@@Q1243
2483124224821242248336<42482124424800`@Q2488@P02248236<00`Q2
12448@06248212400`Q21248@P03124224800`@Q24848@03124224831243
248736<011246<HLiaS6112400L<H`Q22488@P@Q24848@02248312442482
12401`Q2124<HaBU7>LHaQ2400848@0424848@aS248336<010@Q24848@Q2
0PaS0PQ20P@Q00<8@P@Q24800`@Q0`Q20PaS00<8@P@Q12400`Q20P@Q0`Q2
10@Q0PQ20`@Q10Q200<48@Q212401`@Q00@8@P@Q12448@@8@P041248@PQ2
2483124236<248@35:D01AS65:D@Q12436<00Q2400<<Ha2448@010aS0Q24
00<8@PaS36<00Q241@aS00D@Q0aS36<<H`Q200@<H`<8@PD<H`88@P8<H`04
48@<H`aS36<2248010aS248<H`Q210aS00<@Q0aS36<00PaS00<@Q0aS36<0
10aS00<@Q0aS36<010Q20PaS00X8@PaS36<@Q0aS248<Ha2436<8@P@<H`04
248<H`Q236<2248436<010Q236<<H`aS0PQ200@<Ha2436<<H`8@Q0<<H`08
48@<H`aS36<@Q0aS248<H`8@Q0H<H`03248<H`aS008@Q0P<H`03248<H`aS
00l<H`0348@<H`aS00/<H`04248<H`Q248@236<348@336<00a2436<<H`07
36<00`Q236<8@P0936<0112436<<H`aS0Q2400<<H`Q2248010aS0@Q20000
100012448@0010@Q00P000@Q1248@QBU8@P@Q0aS0QBU00<@Q0aS48@00Q24
0PaS0Q2400<<Ha2448@00`aS0a241@aS00<@Q0aS48@00PaS00P@Q0aS36<<
Ha245:D@Q0Q20PaS0Q240PaS00@@Q1BU48@@Q08<H`8@Q00836<8@PaS36<@
Q1BU48@<H`@@Q00336<@Q0aS00<@Q0<DY@0348@<H`Q200D<H`04248<H`aS
36<348@01PaS248<H`aS248<H`<@Q00436<@Q0aS48@436<648@236<00`Q2
36<DY@0248@636<0112436<<H`aS0Q240PaS1A240PaS00<8@PaS36<00PaS
00D@Q0aS36<<Ha24008<H`04248<H`aS36<35:D0112436<<H`aS0Q240`Q2
00@48@Q21248@P<48@0300048@@Q00H48@<8@P<48@0324848@@Q00@48@03
24848@@Q00<48@88@P031248@PQ200D8@P848@03248<H`Q200848@88@P03
1248@PQ20088@P848@@8@P031248@PQ200<8@P848@0424848@@Q12422480
0`@Q24848@031242248512400`Q212448@0212400`Q212448@06248010aS
124DYD8@0U[F00De[AS69BTLiaBU008@Q00336<8@P@Q0088@P031248@P@Q
00P48@05248<Ha2436<8@P041243248436<2124424821243248212462480
0`aS24848@021247248512400`Q21248@P081240100012448@Q20P@Q00<8
@P@Q12400P@Q0`Q200<48@Q224800`Q20P@Q00<8@PaS5:D00QBU0Q2400DH
aQcW6<H@Q0Q200@<H`<@Q00536<@Q0aS36<@Q00436<348@436<2248348@0
1@aS248<H`aS24801@aS0Q2400D8@PaS36<<Ha24008<H`88@P8<H`0348@<
H`aS008<H`0648@<Ha2436<@Q0aS0Q240PaS00<8@PaS36<00PaS00<8@PaS
36<010aS0Q2410aS00@8@PaS36<<H`<8@P0336<8@PaS008<H`88@P<<H`88
@P0336<8@PaS00P<H`03248<H`aS008@Q0<<H`06248<Ha2448@<H`Q20`aS
0`Q20PaS0PQ22`aS0PQ20`aS00<@Q0aS24801@aS00H8@PaS48@@Q0aS2483
36<224800`aS48@<H`0336<0112436<@Q0aS0Q240PaS00H8@PaS36<@Q0aS
248536<00a2436<<H`0336<00`Q236<<H`0324800`aS48@<H`0236<010Q2
36<@Q0aS0PQ200<<H`Q224800@Q2000412400`0012400005124011BU9BTH
aPaS112400<<Ha2436<01A2410aS0Q2400LDYA2448@<Ha24248<H`0448@6
36<0112436<@Q0aS0Q2400<<Ha2448@00a2400@<Ha2436<@Q0<<H`04248@
Q1BU5:D236<348@00`aS48@@Q00548@35:D436<00a2436<<H`0236<010Q2
36<@Q1BU0Q2410aS00<@Q0aS36<00`aS00/@Q1BU48@<H`Q236<@Q1S65:D<
Ha2400H<H`045:D@Q12436<248@236<01PQ236<@Q12436<8@P<<H`0348@<
H`aS0088@PH<H`03248@Q124008@Q0<<H`06248<H`aS36<DYAS60Q2400<8
@PaS36<00`aS00@48@Q21248@PH48@0300048@@Q00d48@0324848@@Q00H4
8@0324848@Q20088@P051248@PQ236<8@P02124020Q21248@PQ21248@P@Q
248212422483124724801P@Q24848@@Q24848@H8@PL48@<8@P<48@032484
8@Q200848@P8@P0;48@8@Q24?NmJeUkg=JdLibDY8@PHaP0236<00`Q21248
@P03248412400`Q212448@02124224800`aS2488@P0224801P@Q24848@@Q
24848@8<H`03248<H`Q200848@<8@P@48@0424848@@Q1246248236<01PQ2
12448@@Q24848@<8@PH48@88@P041248@P@Q000612400`Q212448@021242
248212472484124236<021BU6<H@Q0aS48@HaQcW6<H236<248@336<748@=
36<01@Q236<8@PaS48@00`aS00<8@PaS36<00`aS00<8@PaS24801@aS00<@
Q0aS24800PaS00<@Q0aS36<0112400<<Ha2448@00PaS00<@Q0aS36<01@aS
00<8@PaS36<00PaS00<8@PaS36<00PaS0PQ20PaS1`Q200T<H`Q2248<H`Q2
36<8@PaS24800`aS0PQ200<<H`Q224801PaS00<@Q0aS36<03@aS10Q200<<
H`Q224800`aS00<8@PaS36<010aS00<8@PaS248010aS00<@Q0aS36<010aS
00<@Q0aS248010aS00@8@PaS36<@Q0<<H`03248<Ha24008@Q004248<HaBU
48@224800`aS48@<H`0236<00`Q236<<H`0236<224800`aS48@@Q00236<0
10Q236<<H`aS0PQ200@<Ha2448@@Q08<H`03248<Ha2400<<H`88@P0000<0
00@Q00001P@Q00/000@Q124HaRDY5:D8@Q245:D@Q0aS00@@Q00336<@Q124
00@<H`<@Q00336<@Q124008@Q00336<8@Q24008@Q0D<H`0448@DYA2448@2
36<011245:D@Q1242`aS0Q2410aS21240PaS0aBU00<@Q0aS36<00PaS0a24
0PQ20Q2400@DY@Q236<<H`8@Q0@<H`<@Q0L<H`8@Q00536<@Q0aS36<@Q003
36<01A2436<@Q0aS48@010aS11240`aS0a240PaS0Q240PaS00<8@PaS36<0
0Q240PQ20PaS00<@Q1BU36<01@aS00<@Q0aS24800PaS00@@Q0aS2488@P84
8@0424848@@Q248:12400`Q212448@0A12402PQ212448@@Q248<H`Q21248
@P@Q0PQ200<<H`Q224800P@Q0PQ20`@Q1`Q200L48@Q212448@Q21248@P02
12400`Q21248@P031242248512400`Q212448@0212400`Q21248@P041240
0`Q21248@P0224804@aS2488@PaS48@U:CW>CW=S65JeF]IF]DYBAS4YBR48
48@00PQ200@<Ha2436<8@P@48@88@P848@88@P8<H`0324848@@Q00<8@P03
1248@PQ200X8@P<48@0324848@Q200<48@@8@P<48@D8@P848@<8@PT48@88
@P848@0424848@002484124324821242248020aS2488@P@Q24848@Q21242
24800`aS48@@Q0065:D01A2436<<H`aS48@00`aS00<@Q1BU36<00PaS0Q24
1@aS00<@Q0aS48@010aS0`Q200<<Ha245:D00Q240PaS0Q241PaS00D8@PaS
36<<H`Q200d<H`8@Q08<H`04248<H`aS248536<01PQ236<8@PQ236<@Q08<
H`88@P8<H`0348@<H`aS008<H`<8@P@<H`<8@P0336<8@PaS00<8@P8<H`88
@P0336<@Q0aS00H<H`8@Q0P<H`05248<H`Q236<8@P0436<2248010aS48@<
H`Q20`aS0PQ20PaS00D8@PaS48@<H`Q2008<H`0648@<H`aS248<H`Q20`aS
0Q240PaS00<8@PaS36<03@aS00<8@Q2436<01`aS00<@Q0aS36<00PaS00<8
@PaS36<00`aS0PQ200<<Ha2436<00PQ200<<Ha2436<00PQ210aS00051240
0`0012448@03124020Q27>LYBQ24248@Q1BU48@236<448@336<00a2436<@
Q00248@010aS48@@Q12410aS0a240`aS00<@Q0aS36<00Q2400L<H`Q236<<
HaBU48@DY@0248@336<00a2436<<H`0336<01@Q236<<Ha245:D00Q2400<<
Ha2448@00a2400@DYA2436<<H`8@Q0055:D@Q0aS248<H`0248@436<748@2
36<00`Q236<@Q00248@436<248@00`aS248<H`0448@2248236<00aBU48@<
H`0436<00a2436<<H`0348@436<248@736<010Q236<8@PaS0Q2410aS00L@
Q0aS36<<Ha2436<@Q00436<01A2436<8@PQ212400`Q200<48@00124010@Q
00<000@Q12400`@Q00<000@Q124040@Q10Q200H48@Q21248@P@Q24821243
2484124010Q212448@@Q10Q20`@Q0PQ20P@Q10Q200<48@Q212400`@Q0PQ2
2@@Q00<8@P@Q24800P@Q00<8@P@Q12400P@Q0PQ200@<H`Q2248<H`8DY@05
8@PmkdYBG_MF]@02F]H2AS400bDY7>L<H`0224800`aS48@<H`0512400`Q2
12448@03124010Q212448@@Q0`Q210@Q00D8@PaS2488@P@Q0088@P041248
@P@Q248312400`Q212448@0212400`aS24848@03124524801@@Q2488@PQ2
12400PQ210@Q00@8@P@Q12448@<8@P04124000@Q248512400`Q212448@02
12401@Q236<8@PQ212400PQ210@Q0PQ200<@Q1BU5:D00Q240QS600@@Q0aS
2488@P<@Q08<H`@@Q0@<H`0648@<H`aS248<Ha240PaS00<8@PaS248010aS
00DDYA2448@<H`Q200P<H`88@P0636<@Q0aS36<8@PaS0Q2410aS00@@Q0aS
36<@Q0@<H`0448@<H`Q2248336<01@@Q36<<Ha2436<00PQ200<<H`Q236<0
0PaS00<@Q0aS36<010Q200<48@Q224800PQ21@aS00D8@PaS24848@Q200<<
H`88@P0436<@Q0aS36<2248536<00a2436<@Q00348@636<01@Q236<<H`aS
248010aS0PQ21PaS00<8@PaS36<010aS00<8@PaS36<01PaS11241`aS0PQ2
10aS00<8@PaS36<00PaS00D@Q0aS2488@PaS008@Q08<H`05248<H`aS36<8
@P0536<324800`aS48@<H`0636<00a2436<8@P0236<12480000300048@00
00<48@0<00048@@Q124000Q25:DLia24248<HaBU0Q2400<<Ha2448@00a24
00<<Ha2436<00Q2400<<Ha2448@011240aBU10aS0Q240PaS0a240PaS1A24
00<DYA2436<03@aS0Q2400DDYA2448@@Q1BU008@Q0@<H`0448@<H`aS36<3
48@336<348@236<01Q2436<@Q12436<@Q08<H`0348@<H`aS00<@Q0D<H`03
248<Ha2400@<H`@@Q00536<8@PQ236<@Q00536<548@836<00a2436<<H`04
36<248@336<248@236<248@336<01@Q248@DYA2424800P@Q00<8@P@Q1240
0`@Q00D8@P@Q12448@0000848@0324848@Q200l48@<8@P848@0724848@Q2
248<H`@Q24800P@Q1@Q20`@Q0PQ20`@Q0PQ200<48@Q212400PQ21`@Q00@8
@P@Q12448@88@PH48@0324848@Q20088@P@48@0324848@@Q00848@032484
8@@Q0088@P0936<8@QBU7>Le[E:DIcUoog>L009_N`05Nmiooe[F?Nl<H`02
248212400`Q236<48@0612401@0012448@@Q24801@@Q0`Q200H48@Q21248
@P@Q248212400`Q212448@0212400`Q212448@02124224831242248010@Q
2488@P@Q0`Q200<<H`Q224800`aS10Q21P@Q0`Q20`@Q00<8@P@Q124010@Q
10Q20`@Q00@8@PaS2488@P848@88@P0;5:DHaQ245:D@Q1S67>L@Q0aS248<
H`0248@336<00a245:D@Q00236<01a2436<8@PaS48@<H`Q200<<H`<8@P03
48@<H`aS00D<H`05248<H`aS48@DY@0236<2248A36<00a2436<@Q00636<0
1`Q236<<H`Q236<8@PaS0088@P0536<8@PaS48@<H`0324800`aS48@<H`02
36<00`Q248@8@P02248636<00a242488@P03248236<3248020aS48@<H`Q2
36<@Q0aS248236<248@00`aS248<H`0336<010Q236<<H`aS0PQ200<48@aS
36<01@aS00D@Q0aS36<<H`Q200@<H`0348@<H`aS0088@P0536<8@PaS36<@
Q00636<248@010aS2488@PQ21@aS00<8@PaS36<010aS0PQ20`aS00<@Q0aS
36<00PaS00<@Q0aS36<010aS00H8@PaS36<<Ha2436<2248236<248@010aS
2488@PQ20PaS00<@Q0aS24800@Q2000412400`0012448@0212401`001244
8ABU8@PDY@Q200<<H`035:D@Q12400<@Q00436<@Q12448@336<448@236<2
48@01QBU48@<H`Q236<DY@<@Q08<H`0348@<H`aS00<@Q0<<H`8@Q0H<H`09
48@<H`aS248<Ha2436<@Q1BU008@Q00436<@Q1BU48@236<348@00`aS48@<
H`0336<448@00`aS48@@Q00248@00`Q236<<H`0248@536<0112436<<H`aS
0Q241`aS0Q2400D<Ha2448@<Ha24008<H`<@Q0<<H`0548@<H`aS48@<H`03
48@236<01PQ236<@Q12436<8@P8<H`0448@<H`aS48@236<00a2436<@Q003
36<248@336<2248011245:D<H`Q20P@Q0PQ210@Q00<000@Q12401P@Q00<0
00@Q124010@Q00<8@P@Q12400P@Q00<8@PaS12400P@Q00D8@P@Q1248@P@Q
0088@P061248@PQ21248@P@Q1@Q20`@Q00<8@P@Q12400`@Q1@Q200<48@Q2
248010@Q00<8@P@Q124010@Q00D8@P@Q24848@Q200H48@0324848@Q20088
@P848@0424848@@Q1243248236<01QS67>Le[EJeJeYkgP9cW006Kg]kgWoo
E[Dmka240PQ200<48@Q224802@@Q00<8@P@Q12401@@Q0PQ20P@Q00@8@P@Q
24848@<8@P031248@PQ200<48@88@PL48@0524848@@Q24848@0324801@@Q
248<H`Q236<00`Q20PaS00<8@P@Q12401P@Q00<8@P@Q12400P@Q00<8@P@Q
12400`@Q00D8@P@Q1248@PaS00<8@P041248@PQ2124224801PaS248@Q1BU
6<H@Q0<DY@046<HDY@aS248236<00aBU48@<H`0236<348@:36<2248436<0
20Q236<<Ha2436<8@PaS248248@236<010Q2124<H`Q20PaS0Q2400<8@Q24
48@00PaS00D48@aS36<<Ha24008<H`0548@<H`aS36<8@P0236<00`Q236<<
H`0736<01@Q236<@Q0aS24801PaS0PQ200D<H`Q224848@Q200<<H`88@P04
36<8@PaS36<424801PaS2488@PQ236<@Q0H<H`88@P<<H`035:D<H`Q20088
@P0648@<H`aS248<H`Q21`aS00<@Q0aS36<00PaS0`Q20PaS0PQ20PaS00<@
Q0aS36<01PaS0Q240PaS0Q2400L<H`Q236<<H`Q236<8@P0236<00`Q236<@
Q00236<00`Q236<<H`0536<00`Q236<@Q00336<00a2436<8@P02248936<0
0a2436<<H`0636<32480000300048@@Q00848@0400048@@Q000312400`aS
6<H@Q00236<248@336<248@00aBU48@@Q00236<248@00`aS248<H`0348@2
36<248@00aBU48@@Q00248@01ABU48@@Q12436<00Q2400@DY@aS48@<H`@@
Q00336<@Q1BU008@Q08<H`0348@<H`aS00D<H`8@Q00536<@Q1245:D@Q002
36<248@436<010Q236<@Q1S60QBU0`aS00<@Q0aS36<00`aS00@@Q0aS36<<
H`8@Q0<<H`8@Q08<H`8@Q00736<@Q12448@<H`Q236<00Q2400@<Ha2448@<
H`<8@P<@Q00336<@Q0aS008<H`<@Q0<<H`<@Q0@<H`0448@<Ha2436<648@0
3QBU48@<H`aS48@DYA2436<8@P@Q5:DQ21cW248212400`aS248000051240
0`Q212448@0=1242248010@Q24848@Q20`@Q0PQ20P@Q00@8@P@Q2488@P<4
8@D8@P<48@0424848@Q212432482124424800`@Q24848@0412401@Q21248
@P@Q24801@@Q0PQ220@Q10Q200@48@Q2248<H`@8@P0836<Q2248>LiF]F]J
NmicW0=_N`05LiaoogooBU8U:@0212400`0012448@0212400`0012448@06
12400`Q212448@021243248010@Q2488@P@Q0PQ20`@Q0PQ200@48@Q21244
8@<8@PH48@03248<H`Q200<8@P0336<8@P@Q00848@@8@P041248@PQ22483
12400`Q212448@0212400`Q212448@0712422483124224801P@Q24848@@Q
24848@<8@P0:48@DYABU48@<HaS68@PDY@aS248536<0112436<<Ha243`aS
0PQ21@aS00<@Q0aS36<01PaS0PQ210aS00H8@PaS48@DYA2436<224800`aS
48@<H`0248@336<01Q2436<8@PQ236<@Q0<<H`0348@<H`Q20088@P0636<8
@PaS36<@Q0aS10Q20PaS0PQ200<<H`Q236<01`aS00D8@P@Q36<@Q0aS00<8
@P0436<8@PaS48@236<2248636<00`Q236<<H`0236<010Q236<<H`aS0PQ2
0PaS00@8@P@Q2488@PT<H`<8@P<<H`88@P0436<8@PaS36<248@636<248@0
1PaS2488@PQ236<@Q08<H`06248<H`aS48@<Ha2410aS00<8@PaS36<00`aS
00D8@PaS36<<H`Q200<<H`03248<H`aS00H<H`03248<H`aS00D<H`05248<
H`aS248<H`0124800004124000@Q000212400`0012448@03124011246<H@
Q0aS0a2400@<Ha2448@<H`@@Q00336<@Q0aS008<H`8@Q0035:D@Q124008<
H`0348@DYABU008<H`8DY@8<H`8@Q0<<H`0348@DY@aS00<<H`H@Q0<<H`8@
Q08<H`0348@<H`aS00<<H`L@Q08<H`0748@<H`Q236<8@Q2436<011240PaS
0Q240PaS00<8@PaS36<00Q241@aS0a241@aS00<@Q0aS36<010aS0a2410aS
00@@Q0aS36<8@P<<H`8@Q00336<@Q124008<H`0448@<H`aS48@436<01124
36<8@PaS0a2400<<Ha2448@00Q2400H<Ha2436<<H`Q236<2248011BU7>LD
Y@aS0P@Q10Q21`@Q00<000@Q12400P@Q00D8@P@Q12448@0000<8@PL48@04
24848@Q22483124324800`@Q2488@P02124324821242248412400`Q21244
8@02248412400`Q212448@0212400`Q212448@0224841242248412422485
124224800`@Q24848@02124324803@aS248LibDY?NmJeVLiNmicW6mkJeYc
W6mk009oo`03BU8Q200000@48@0300048@@Q00<48@0300048@0000L48@88
@P051248@PQ21248@P04124010Q236<8@PQ21P@Q00<8@P@Q12400P@Q00<8
@P@Q12400PQ200@<H`Q22488@P848@88@P8<H`03248<H`Q200T48@042484
8@@Q2486124010Q212448@@Q0`Q200<48@Q212400PQ200H48@Q22488@PaS
48@25:D02PaS48@LiacW6<H<H`Q236<@Q0aS0Q2400P<Ha2448@<Ha2436<@
Q0Q20`aS0Q241@aS0`Q20PaS00@@Q0aS36<8@PP<H`<8@PP<H`04248<H`aS
36<224800`aS48@<H`0<36<010Q236<8@PaS0PQ200@<Ha2436<<H`88@P03
36<8@PQ200<<H`07248<H`aS36<8@P@Q24800`aS10Q200@<H`Q2248<H`@8
@P8<H`03248<H`Q2008<H`<8@PP<H`05248<H`aS36<8@P0636<0112436<<
H`Q20PaS0`Q200<<H`Q236<00`aS00<8@PaS36<02@aS00@@Q0aS36<8@P@<
H`88@PD<H`04248<H`aS248236<00a2436<8@P02248336<030Q236<<H`aS
48@8@PaS248<Ha2436<@Q0<<H`04248<H`aS48@236<01@Q236<<H`Q236<0
0PQ2000412400`0012448@0212402@0012448@aS7>LDY@aS48@<H`0348@0
1PaS48@@Q1245:D@Q08<H`<@Q00336<@Q124008@Q0065:D@Q1BU6<HDYA24
11BU0a240PaS11240PaS0Q240QBU00@@Q1BU5:D@Q0H<H`04248<Ha2448@4
36<248@336<00a2436<<H`0348@011BU48@@Q0aS1A2400DDYA2436<<Ha24
008<H`88@P8<H`8@Q08<H`8@Q00836<@Q1245:D<H`Q236<@Q0<<H`<@Q004
36<@Q0aS48@436<00a2436<@Q00336<01a2436<<Ha2436<@Q1BU008@Q0@<
H`0348@<H`aS008<H`035:D@Q1BU008@Q0035:D@Q124008<H`0948@<H`aS
36<8@Q246<H@Q0aS00<8@Q<48@0424848@@Q124424831240100012448@@Q
0PQ200<48@Q224800`@Q00<8@P@Q36<00PQ210@Q0PQ200@48@Q212448@<8
@P<48@88@PL48@0324848@@Q00H48@0624848@Q21248@P@Q0PQ210@Q10Q2
00h48@Q236<8@P@Q36<HaRU:9BTYBSW>DYAS65kg0Vmk00McW7NmG_MF]C6<
;F/HaP0224800`@Q36<<H`0512400`Q212448@04124224821242248236<0
1`Q212448@@Q24848@Q200T48@88@P@48@06248<H`Q21248@PaS0PQ200H4
8@Q212448@Q21244248912401@Q212448@@Q248010@Q00<8@P@Q12400P@Q
0PQ200<<H`Q224800P@Q00<8@P@Q12400PaS00TDYA2436<@Q1BU6<HDYA24
36<00PQ200@<Ha2436<<H`8@Q0035:D@Q0aS008@Q00336<8@PQ200<<H`<8
@P<<H`88@P<<H`0548@<Ha2448@<H`02248736<0112436<8@PQ20PaS00<@
Q0aS36<00PaS00<@Q0aS36<01@aS00<@Q0aS36<00PQ21PaS00<8@PaS36<0
0`Q200<<Ha2448@00PaS00<8@PaS36<00`Q21PaS0PQ20PaS00@8@PaS248<
H`<8@P03124<H`aS00<<H`05248<H`aS48@<H`05248336<01124248<H`Q2
0PaS00<8@PaS36<01@aS00H@Q0aS36<8@PaS248836<324800`aS248<H`03
48@236<00`Q236<<H`0248@236<00`Q236<<H`0836<248@324800`aS48@<
H`0224800`aS48@<H`0536<01@Q236<@Q12436<00PQ21`aS00<8@PaS36<0
1PaS0@Q2000212400`0012448@0312402@0012448@@Q36<HaQBU36<@Q004
36<01Q2436<<Ha245:D@Q08<H`<@Q0065:D<Ha2448@DYA240aBU00<@Q0aS
48@00aBU00@@Q0aS36<<H`D@Q0<<H`0548@DYABU48@DY@0348@336<01124
36<<H`Q210aS0Q2400<<H`Q236<01Q2400<<Ha2448@00a240PaS0QBU00<H
aQ2436<010aS00<8@PaS24800a240`aS0Q2400<<Ha245:D00Q2410aS00<@
Q0aS48@00PaS0Q2400D<H`Q236<<Ha2400T<H`0448@<H`aS36<248@01@aS
248@Q12436<00PQ200H<HaBU5:DDYA2436<248@336<248@536<011BU6<HD
YA240`@Q00<8@P@Q12401@@Q00D8@P@Q12448@0000H48@0300048@@Q0088
@P0336<8@P@Q00848@H8@P@48@0524848@Q21248@P021245248212432483
12400`Q212448@0424841244248212400`Q212448@02248312400`Q21248
@P031242248212401@Q236<8@PQ212400PaS00P48@aS5:DYBR48:DXicTic
0V<H0Vmk00QcW7NmF]IBU36<9BTHaPaS1@Q20`@Q00@000@Q2488@P<48@04
24848@@Q124724801@@Q24848@@Q24800P@Q00<8@P@Q12401P@Q00D8@P@Q
24848@Q200848@0336<8@PQ200<8@P<48@P8@PX48@0324848@@Q00<48@88
@P@48@D8@P071248@PQ21248@PaS5:D00Q2400L<HaBU5:DDYA2436<8@P03
36<248@00`aS48@<H`0348@236<00a2436<<H`0236<021242488@PQ236<8
@PaS248436<00a2436<<H`0336<00a2436<8@P0536<224801@aS248<H`aS
48@020aS00<@Q0aS36<03@aS00@8@PaS248<H`88@P8<H`<8@P0336<8@PaS
00<<H`03248<H`aS00<<H`03248<H`aS00L8@P@<H`88@P<<H`<8@P0736<8
@PQ2248@Q1BU36<00PQ20PaS00L8@PaS36<<H`Q236<8@P0236<248@236<2
248436<4248736<0112436<<H`Q20PaS00D@Q0aS36<<H`Q200<<H`<8@P<<
H`0548@<H`aS36<8@P0436<2248836<2248636<021242488@PQ236<@Q0aS
248536<00`Q236<<H`011240000600048@@Q00048@0010@Q00H000@Q48@L
iaBU36<248@010aS48@@Q1240PaS0a240PaS00H@Q1BU48@8@PaS48@35:D0
11245:DDYABU1a2410aS00D@Q0aS36<<Ha2400DDY@8@Q08<H`0348@<H`aS
00<<H`<@Q0<<H`0348@<Ha2400<<H`<@Q0035:DHaPaS008<H`0548@DYABU
48@<H`0548@4248336<248@736<348@236<02PQ236<@Q0aS248<HaBU48@<
H`Q20PaS00<@Q0aS48@010aS00@8@PaS36<<H`<@Q00336<@Q12400<<H`04
48@<H`aS36<248@00`aS48@<H`025:D00a245:D@Q00336<00aBU48@<H`02
36<011245:D@Q0aS0P@Q00<8@P@Q24801@@Q00D000@Q00048@Q200@48@88
@PD48@88@P/48@0524848@Q21248@P03124824801@@Q248@Q0aS24801P@Q
00H8@P@Q124000@Q248312400`Q21248@P0512400`Q212448@0212422482
12400`Q21248@P04248010aS248<H`aS112400dDYA245:DLibU:=JdicTYB
AS5>Le:D>LhaS00248@336<01`@Q248@Q1S65:D8@P0000<48@0436<8@P@Q
1243248020aS48@@Q12436<DY@aS2482124010aS2488@PQ20`@Q00<8@P@Q
124010@Q00D8@PaS2488@P@Q0088@P031248@PQ20088@P061248@P@Q2484
8@Q22@@Q00H000@Q2488@P@Q248212401@Q212448@@Q24801P@Q1`Q20P@Q
0PaS1a241@aS00@8@PaS48@@Q08<H`0348@DYA24008@Q0@<H`0448@<H`aS
248336<2248336<00a2436<<H`0:36<3248636<00a2436<<H`02248336<0
0`Q236<<H`0936<4248336<00`Q236<<H`0248@00`aS248<H`0236<22486
36<01`Q236<<H`aS24848@Q2008<H`0324848@Q200<<H`<8@P0536<@Q124
36<8@P0236<3248636<00`Q236<<H`0336<3248010aS48@<H`Q210aS00H@
Q0aS36<<H`Q236<3248536<00a2436<<H`0436<0112436<<H`aS0`Q200H@
Q0aS2488@PaS48@436<0112436<8@PQ20PaS00D8@PaS48@<H`Q2008<H`8@
Q08<H`88@P0336<8@PaS00<<H`03248<H`aS00@<H`06248<H`aS248<H`Q2
0PaS00000`@Q00048@0612401`0012448@aS7>LDY@aS00L@Q08<H`D@Q08<
H`@@Q00336<@Q12400<DY@0348@<Ha24008@Q08<H`8@Q08<H`0348@<H`aS
00@@Q08DY@066<H@Q0aS36<@Q0Q20`aS00<@Q0aS36<00`aS112400X<Ha24
5:D@Q0aS248<Ha2436<DY@8@Q0045:D@Q12436<548@436<01@Q236<8@Q24
36<00a2400<<Ha2448@00Q2410aS00<8@PaS36<01@aS0Q240PaS0a2420aS
00<@Q0aS48@00Q240PaS0a2400D8@PaS36<@Q0aS00<@Q00336<@Q124008D
Y@8<H`03248@Q124008@Q00636<8@QBU6<HDY@Q20P@Q0PQ23@@Q00<000@Q
12401P@Q10Q21P@Q00<8@P@Q12400`@Q00<8@P@Q24800PQ20P@Q00D8@P@Q
1248@PaS00848@07248@Q12436<48@00248010@Q00<8@P@Q248010@Q00H8
@P@Q2488@P@Q248512400`Q212448@02124224800`@Q24848@0324800`@Q
2488@P0436<448@26<H02R48=JdmkdicAS5:DU:D>LhYBQBU0Q240PaS00D8
@PaS5:DLia2400<48@<8@P0:1248@P@Q24848@Q236<@Q1BU36<248@00`aS
24848@03248612400`Q212448@02124324800`aS24848@0312401`Q21248
@P@Q24848@Q200@48@88@Pl48@0424848@@Q000212422484124824801@aS
48@<Ha245:D00Q240PaS0`Q20PaS0a240PaS0Q2400HDY@aS36<@Q0aS2485
36<01Q2436<8@PQ236<@Q0D<H`03248<H`aS008<H`04248<H`Q2248436<0
0`Q236<<H`0236<248@010aS48@<H`Q22@aS0`Q200<<Ha2436<00`Q200D<
H`Q22488@PaS0088@P<<H`03248<H`aS0088@PP<H`04248<H`aS248336<4
248236<0112436<8@PQ210aS0PQ200<<H`Q224800PQ200P<Ha242488@P@Q
36<@Q0aS0`Q200<<H`Q236<02`aS00D8@PaS36<<H`Q2008<H`0348@<H`Q2
00<<H`0348@8@PQ2008<H`0348@<H`aS0088@P8<H`88@PP<H`@8@P0336<8
@PaS010<H`0348@<H`aS008<H`0348@<H`aS008<H`88@P@<H`48@P000P@Q
00D000@Q12448@0000D48@0448@HaQBU248648@336<248@236<011245:D@
Q0aS0QBU0Q240aBU00<@Q0aS36<00a240PaS11240PaS0Q2400/DY@aS48@D
YAS65:D@Q1S65:D@Q0aS00@@Q0L<H`8@Q0<<H`@@Q08<H`@@Q00436<@Q0aS
48@336<348@010aS48@@Q1BU0PaS00<8@PaS48@00PaS11240PaS0Q240PaS
00<8@PaS36<010aS00H8@PaS48@<Ha245:D248@536<010Q236<<Ha2410aS
00<@Q0aS36<01PaS112410aS0Q2400<DY@aS36<00PaS00@@Q0aS48@@Q08<
H`031248@PQ200P48@0300048@@Q00848@0400048@@Q248?12400`Q21244
8@0312400`Q21248@P0312401@Q212448@Q236<00`Q200H48@aS48@DY@aS
1242248912401`0012448@aS24848@Q200848@0324848@@Q00<48@042484
8@@Q124824801@@Q2488@PQ28@P00Re[00DYBQ2448@DY@aS008DY@036<HL
iacW008Q20036<HDY@Q20088@P041248@PQ212422482124010Q21248@P@Q
1@Q200DDYAcW6<H<H`@Q00P8@P848@88@PL48@0500048A246<H<H`021240
0`Q212448@04248412400`Q21248@P0>12400`Q212448@02124224831240
0`Q21248@P0412401@Q236<8@P@Q24800PaS1a240PaS00H8@PaS48@8@PaS
48@436<00a2436<<H`0348@01@aS248<H`aS24800`aS00<8@PaS24800PaS
0`Q20`aS0`Q210aS0PQ200@<H`Q22488@P<<H`03248<Ha2400<<H`04248<
H`aS36<2248436<010Q236<<H`aS0PQ200<<Ha2424800PQ21`aS1@Q22`aS
0PQ20`aS0`Q200P<H`Q22488@PaS248<Ha240PaS0PQ200<<Ha2436<010Q2
10aS0PQ200<<H`Q236<00`Q20PaS0PQ20Q2400<<H`Q236<010aS00<8@PaS
36<01PaS00<@Q0aS36<00PaS00@@Q0aS36<8@PD<H`03248<H`aS008<H`04
248@Q12448@436<2248336<010Q236<<Ha240PaS00<8@PaS36<00`aS00D8
@PaS36<<Ha24008<H`04248<H`aS36<4248436<12480000500048@@Q1240
000412401`0012448@aS7>LDYA24008<H`8@Q0045:D@Q0aS36<348@336<2
48@25:D01a2436<@Q0aS5:D@Q1BU00<@Q08DY@0636<8@Q2448@DY@aS0Q24
0`aS0Q240aBU00<HaQBU48@00Q2400@<Ha2448@@Q0D<H`<@Q08<H`8@Q003
36<@Q12400L@Q00336<@Q124008@Q0<<H`0348@<Ha24008@Q0L<H`<@Q08<
H`@@Q00436<8@PaS36<248@236<248@436<00a2436<@Q00236<224800`aS
248<H`0348@236<348@336<01@Q248@@Q1245:D00PaS00<@Q0aS36<01124
0PaS00<@Q0aS36<00PaS00D@Q0aS36<@Q0aS00<48@0424848@@Q00031240
0`Q21248@P0812400`0012448@021244248712400`Q212448@0312400`Q2
12448@02124224801@@Q2488@PQ212400PaS0Q2400<8@PaS24800`@Q00<8
@P@Q24800`@Q0`Q21@@Q0PQ210@Q00<8@P@Q12400P@Q0PQ20P@Q0`Q200T4
8@Q2248<H`@Q7>LYBS6<9BT00Q2400<DYA2448@00QBU0R480RDY0QBU00L<
H`Q236<<H`Q21248@P0212400`Q212448@0624802P@Q36<HaR486<H<H`@Q
248<H`@Q0PQ200D<H`Q212448@Q200H48@88@P<48@0436<HaQBU12422483
1243248212400`0012448@08124010Q21248@PQ22`@Q0PQ21`@Q00L8@PaS
24848@Q236<@Q00236<248@00aBU48@@Q00436<224800`aS48@<H`0436<3
48@536<00`Q236<<H`0236<324801@aS48@<H`Q236<00`Q20`aS0`Q200<@
Q0aS36<00PaS0PQ200D<H`Q236<<Ha2400D<H`0748@<H`aS36<8@PaS2480
0`aS00@8@PaS36<<H`88@P8<H`04248<H`Q2248336<2248436<01@Q236<<
Ha2436<00PQ20PaS00<@Q0aS36<00PaS0PQ200<<H`Q236<00`Q20`aS0PQ2
1PaS0`Q21@aS00H8@PaS2488@PaS248236<2248010aS48@<H`Q21PaS00D@
Q0aS2488@Q24008<H`88@P8<H`8@Q0<<H`04248<H`aS36<248@010aS48@<
H`aS10Q22`aS00L8@PaS36<<Ha2436<8@P0236<0112436<8@PQ20PaS00<8
@PaS36<00`aS00<8@PaS36<00PaS0`Q20`aS00<8@PaS36<00@aS00000`@Q
00048@0212400`0012448@0212401P00124<HaS648@<H`8@Q00436<@Q124
5:D336<648@00aBU48@@Q00548@00aBU48@@Q00548@236<01A2436<@Q0aS
48@00QBU11240QBU00<@Q1BU48@00Q2400<DYA2448@020aS0Q2400<DYA24
36<00Q2400DDYA2448@<Ha24008<H`@@Q0H<H`8@Q00336<@Q1BU008DY@06
36<8@Q245:D@Q1BU0a2400<DYA2448@00PaS0Q240`aS0Q240PaS00<@Q0Q2
24800PaS00HDYA2448@<Ha2436<248@01@aS48@@Q1BU48@00`aS0Q2400D<
Ha2448@@Q1BU008@Q0035:D<H`aS008<H`L@Q08<H`88@P0436<DYABU5:D2
36<2248H1240100012448@Q21P@Q00@8@P@Q12448@T8@P0436<8@PQ21242
248336<2248512400`Q21248@P0312400`Q212448@04248512400`Q21244
8@0212401@Q212448@Q236<00PQ200l48@Q236<<H`Q248@DYA24=JeJeV<H
CW<Li`aS5:D00PQ200@HaRDY9BTHaP@8@P848@0324848@@Q0088@P041248
@P@Q12422483124010Q248@<H`@Q10Q20P@Q00<8@PaS24800PQ200<48@Q2
24801`@Q00L000@Q2488@PaS48@8@P0312401@Q236<48@@Q24800P@Q00<8
@P@Q24801`@Q00@8@P@Q124000D48@0324848@@Q00848@0324848@@Q0088
@P031248@P@Q00D48@04248<H`Q2248548@26<H00a2436<<H`0436<348@0
1@aS2488@PaS48@00`aS00D@Q0aS36<<Ha24008<H`88@P0536<8@PaS36<@
Q00236<010Q236<<H`Q210aS00@8@PaS36<<H`88@P@<H`03248<H`aS00@<
H`0548@<H`aS36<8@P0436<030Q236<<H`aS248<Ha2436<8@PaS48@<H`88
@P<<H`04248<H`Q21242248236<00`Q236<<H`0236<00`Q236<8@P032482
36<011242488@PQ20PaS00@8@PaS36<<H`88@P<<H`88@PD<H`<8@PD<H`88
@PD<H`<8@PH<H`03248<H`aS008<H`05248<H`aS36<8@P0448@336<22482
36<248@00`aS248<H`0248@00`aS248<H`0236<01A2436<@Q0aS248010aS
0PQ20`aS0PQ200D<Ha2436<<H`Q200@<H`03248<H`aS008<H`0448@<H`aS
48@536<00a2436<<H`0236<1248000<48@0300048@@Q00848@0800048@@Q
124<HaS648@<H`<@Q00336<@Q12400@@Q00336<@Q124008@Q0<DY@8@Q003
5:D@Q124008<H`8@Q0035:D<H`aS008@Q0<<H`0548@DYAS648@<H`0348@0
10aS48@DYABU0a2400DDYA2448@<Ha24008<H`0348@<Ha24008@Q0<<H`03
48@<H`aS008@Q08DY@D@Q0035:D@Q12400T<H`0448@DYABU48@336<01124
5:D@Q0aS11240PaS0a240`aS00<@Q0aS24800PaS00@DYA2436<@Q08<H`03
48@<H`aS008@Q00336<8@PaS00P@Q00536<8@Q246<H@Q00336<248@336<3
48@336<248@336<00a245:DDY@02248312400`Q212448@0412400`001244
8@08124010001248@PQ21@@Q0PQ22@@Q00<8@P@Q24800P@Q1@Q200H48@Q2
248<H`Q21244248512401`Q212448@@Q24848@Q200@48@0724848@Q21248
@P@Q00001@@Q2PQ200/<H`Q25:D@Q3g_G_MS64YB6<H<Ha240088@P047>LU
:BDY6<H224800`aS2488@P04248412401@Q212448@@Q24800P@Q0`aS00D8
@P@Q2488@P@Q00H8@P031248@PQ200D48@03248000@Q00848@88@P<<H`<4
8@H8@P03124000@Q00848@88@PL48@0824848@Q224848@Q2124000D48@05
248<H`Q224848@022483124224801@@Q248<H`aS48@00PaS00LDYAcW7>LD
Y@Q21248@P0236<01Q245:D@Q124248<H`88@P0536<@Q12436<8@P0236<0
112436<<H`aS0PQ200<<H`Q224800`aS00L@Q0Q22488@PaS48@<H`032480
0`aS2488@P0736<01Q2436<<H`aS248<H`8@Q0<<H`88@P8<H`0748@<H`Q2
248<H`Q236<00Q2400<<H`Q224800PaS00<8@PaS36<01PaS10Q20PaS00<8
@PaS36<00PaS00@8@PaS36<<H`D8@P8<H`D8@P8<H`03248<H`Q200@<H`<8
@P@<H`88@P8<H`<8@Ph<H`88@PT<H`0548@<H`aS36<8@P0236<0112436<<
H`aS0`Q20PaS00D8@PaS36<<Ha2400L<H`@8@P8<H`03248<Ha24008<H`03
248<H`aS0088@P<<H`03248<H`aS00<<H`0448@<H`aS248336<00a2436<8
@P012480000700048@@Q124000@Q00000P@Q00L000@Q124@Q1S65:D<H`02
48@00`aS48@<H`0948@25:D00a245:D@Q00248@25:D248@336<448@436<2
48@25:D011245:D@Q1BU21240QBU00@@Q0aS36<<H`<@Q08<H`0348@DYABU
008@Q00436<@Q12436<348@236<011245:D@Q12410aS00@@Q0aS48@DY@8@
Q08<H`D@Q0035:D@Q0aS00<<H`8@Q0@<H`<@Q0@<H`8@Q00436<@Q12436<4
48@236<248@020aS48@HaQBU48@<Ha245:D548@236<448@00`aS48@@Q004
48@01@aS48@@Q12436<00PQ200@@Q1S648@<H`848@0324848@@Q00848@06
00048@@Q24848@000P@Q00<8@P@Q12400`@Q00<8@P@Q00001P@Q00<000@Q
12402`@Q1@Q20P@Q0PQ200D48@Q22488@P@Q0088@P848@0824848@@Q2484
8@Q21248@P@48@0324848@@Q00<48@0324848@Q200<48@0624848@Q21248
@P@Q10Q20PaS00@8@PaS5:D@Q08<H`0;5:DaS4YBDYAW>Dic9BTDY@@Q248<
H`02248312401@Q212448@@Q24800P@Q0PQ21@@Q00<8@P@Q24800`Q20`@Q
00H8@P@Q12448@Q236<2248312400`Q212448@0812400`aS248<H`062482
36<41242248812400`Q21248@P041242248312400`0012448@0412400`Q2
12448@031242248436<248@01QBU6<HDYABU36<8@P<<H`0348@<Ha24008<
H`05248<H`aS36<8@P0836<00a2436<<H`02248436<2248236<3248236<2
24800`aS248<H`0536<00a242488@P0236<0112436<8@PQ20`aS00<8@PaS
24800`aS00<8@PaS24802PaS0PQ210aS00<8@PaS36<00PQ200D<Ha2436<<
H`Q2008<H`@8@P<<H`88@P041248@PaS36<2248336<3248436<2248010aS
248<H`Q210aS0PQ20`aS10Q210aS00H8@PaS36<8@PaS248436<010Q236<<
H`aS0a2400<<H`Q224801@aS00<@Q0aS36<00PQ20PaS00<@Q0aS36<01PaS
0`Q22`aS00D48@aS36<@Q0aS0088@P8<H`8@Q0D<H`0648@<H`aS36<@Q0aS
0PQ20A240@aS000010@Q00048@0020@Q00D<HaBU48@<HaBU008@Q08<H`03
48@<Ha24008@Q08DY@0548@DYA2448@DY@0248@011BU48@@Q1BU0Q2400<<
Ha2436<010aS00<@Q0aS48@00aBU112400HHaQ245:DDYA2436<348@00aS6
5:D<H`0236<00a245:D@Q00336<00`Q236<@Q00248@236<348@436<448@3
36<348@01PaS48@@Q12436<@Q08DY@@@Q08<H`0448@<Ha2436<248@436<3
48@336<248@236<248@336<02a2436<<H`aS48@<H`Q248@DYAS648@00PaS
0Q240PaS0Q241PaS00@@Q1BU48@<H`<@Q00336<@Q12400<<H`05248@Q1S6
48@<H`021242248712400`0012448@0412400`0012448@05124224841240
0`Q212448@08124010Q236<8@PQ21@@Q00<8@PaS12400P@Q00<8@PaS2480
0PQ20P@Q00<8@P@Q12400`@Q00<8@P@Q12400`Q20`@Q00<8@P@Q12400P@Q
00<8@P@Q12400P@Q10Q200@48@Q2248<H`<8@P0336<@Q124008DY@09<Ha:
DUJeHaQ6<BDY5:D48@Q2008<H`061248@P@Q1248@P@Q0`Q220@Q0`Q200@4
8@Q22488@P@48@0424848@aS248236<00`@Q24848@0312400`001248@P04
12400`Q212448@0336<00`Q212448@0424800`@Q24848@0712400`Q21244
8@0412400`Q212448@0:124010Q212448@Q210@Q0`Q200@<H`Q236<<H`8@
Q0065:DLiaS65:D<H`Q20`aS00<@Q0aS36<01PaS00@@Q0aS36<@Q08<H`04
248<H`aS48@236<2248436<2248336<3248336<21242248236<00a2436<<
H`0348@010aS248<Ha241@aS0`Q210aS0PQ200<<H`Q248@00PaS00@8@PaS
36<<H`88@P@<H`03248<H`aS00D<H`03248<H`Q200<<H`03248<H`aS00<<
H`P8@P<<H`0324848@Q2008<H`88@P8<H`88@P@<H`88@P8<H`<8@P8<H`88
@P<<H`<8@P<<H`<8@P0336<@Q0aS00@<H`0848@<H`aS36<8@PaS48@8@P8<
H`03248<H`Q200/<H`0348@<H`aS0088@PH<H`03248<H`aS00H<H`03248<
H`aS00<<H`0548@<H`aS36<@Q00336<248@536<000D48@0300048@@Q0084
8@0400048A246<H236<00a245:DDY@0348@00`aS48@@Q0035:D448@011BU
48@@Q1240aBU00H@Q0aS36<@Q1BU48@336<01Q245:D@Q12436<@Q0@DY@03
36<@Q12400<DY@0348@DYABU00D@Q0035:D@Q0aS008@Q0035:D@Q0aS008<
H`0648@DYABU48@<Ha240QBU10aS00D@Q0aS248<HaBU008@Q00636<@Q124
48@<Ha240`aS00@@Q1BU5:DDY@<<H`8@Q0@<H`03248<Ha24008@Q00436<@
Q0aS48@25:D248@01ABU48@@Q12436<00Q2400DDYA2448@@Q0aS008DY@8@
Q00336<@Q1BU008@Q00336<@Q124008@Q08<H`0348@DYA2400D@Q00436<@
Q12448@436<011BU6<HHaQ2410@Q00<8@P@Q12402@@Q00H000@Q2488@P@Q
000412400`0012448@0;12401`Q212448@@Q248<H`Q200848@0324848@@Q
00848@88@P848@05248@Q12436<8@P041243248212400`Q212448@031243
248212422484124324800`@Q2488@P0224800`@Q36<<H`0436<02PQ248@<
Hb48=JdicTHa?NlLia240P@Q00D8@P@Q1248@P@Q00<8@P<48@0324848@@Q
00D48@05248<H`Q224848@052482124424800`@Q24848@05124010Q21244
8@@Q0`Q200@48@Q212448@D8@P<48@0524848@@Q1248@P0212400`Q21244
8@031242248412400`Q212448@0712401@Q212448@@Q00000PQ200<<H`Q2
24800PQ20Q240aBU00@HaQBU48@<H`88@PH<H`8@Q0@<H`035:D@Q0aS00D<
H`<@Q00936<8@PQ236<@Q0aS248<H`Q200T<H`03248<H`aS008<H`04248<
Ha2448@436<2248348@236<01@Q236<8@PaS24801PaS0PQ20`aS00<@Q0aS
36<00PaS0`Q200<@Q0aS36<00`Q21`aS1@Q200@<H`Q22488@P8<H`@8@P8<
H`88@P0436<8@PaS248236<00`Q248@@Q00236<01PQ21248@PQ236<8@P8<
H`06248<H`Q236<8@PaS1@Q200<<Ha2448@00PaS0`Q200D<Ha2436<<Ha24
00D<H`07248<H`aS5:D@Q0aS24800PaS00<8@PaS36<00`aS00<8@PaS36<0
1`aS00<@Q0aS36<00PaS00<@Q0aS36<020aS00<8@PaS36<00`aS0Q2400@<
Ha2436<8@P8<H`0448@<H`Q2248236<000848@0300048@0000<48@060004
8@@Q124<HaBU0`aS00<DYA2448@00Q2400<<Ha2448@00Q2400DDYA2448@@
Q0aS008@Q0035:D@Q124008DY@<<H`<@Q08<H`8@Q0045:D@Q12436<248@0
0aBU48@DY@0348@25:D348@25:D248@00`aS48@<H`035:D0112436<@Q1BU
0PaS00<@Q1BU48@00PaS00@@Q1BU36<<H`<@Q0@<H`0448@<H`aS36<348@0
0`aS48@<H`0236<448@00aBU48@@Q00636<548@011BU36<<H`aS0a240PaS
1a240`aS0QBU00@@Q0aS36<<H`<@Q00336<@Q0aS008@Q0<<H`H@Q08DY@03
48@<H`aS00<@Q088@P0548@HaQS648@48@02248:12400`Q2124000031240
0`0012448@0?12400`Q212448@03124524800`@Q24848@0412401`Q21244
8@Q236<DY@aS00<48@<8@P031248@PQ200@48@0324848@@Q00L48@042484
8@@Q124524800`@Q2488@P0236<2248236<0312436<<Ha248@Pe[CW>AS4e
[ABU48@48@@8@P848@0324848@@Q00848@0324848@@Q00H48@88@P0336<8
@PQ200L48@@8@P031248@P@Q00L48@0324848@@Q00848@P8@P031248@P@Q
00L48@0424848@@Q1242248712401@Q212448@@Q000010@Q00<8@P@Q2480
1@@Q10Q200<<Ha245:D00QBU0QS600@DYA2436<8@P8<H`03248<H`aS00<@
Q08<H`03248<H`aS008@Q00336<8@PaS00<@Q00436<8@PQ2248:36<00`Q2
36<8@P0236<2248936<01a2436<8@PQ236<@Q0aS008@Q0D<H`03248<H`Q2
0088@P0336<8@PaS00@<H`<@Q00636<8@PQ236<@Q0aS0PQ20PaS00<8@PaS
36<00PaS0`Q20`aS0PQ200<<H`Q2248010Q200H<H`Q22488@PaS248336<3
24800`aS248<H`0324801@aS248<H`Q236<00`Q20`aS0`Q20PaS00H@Q0Q2
36<8@Q2436<5248236<01A2436<<H`aS48@01@aS00@8@PaS36<@Q08<H`03
248<H`aS00@<H`03248<H`aS0088@P8<H`0348@<H`aS00H<H`88@P8<H`03
48@<H`Q200@<H`03248<H`aS008<H`0348@<H`Q200<@Q00436<8@Q2448@2
248236<12480000300048@@Q00<48@0400048@@Q0002124010aS7>LDY@aS
1A240PaS0a240QBU00H@Q0aS36<DYAS648@236<011245:DDYABU0`aS1124
0`aS1a2400@<HaBU48@@Q08<H`<DY@8@Q0035:D@Q0aS00@@Q0<<H`8@Q0<D
Y@0348@DYA24008DY@0336<@Q0aS008@Q0<<H`0648@<H`aS36<@Q1BU0`aS
00<@Q0aS48@00PaS0Q240PaS00<@Q1BU5:D011240`aS00@@Q0aS36<8@P8<
H`X@Q08DY@8@Q00436<@Q1BU48@25:D01A2436<<Ha245:D00`aS00@DYA24
36<8@P8<H`<@Q08<H`8@Q0055:D@Q0aS36<@Q00236<2248011246<HDYA24
0P@Q0PQ21`@Q00@000@Q124000<48@0300048@@Q00L48@0300048@Q200H4
8@0300048@@Q00L48@88@P<48@<8@P<48@04248@Q0aS2482124524800`@Q
24848@0?124224821242248010@Q24848@@Q0`Q20P@Q00<8@PaS24800PaS
00<@Q1BU6<H00QcW00<DY@aS24800PaS0P@Q10Q20P@Q00<8@P@Q24801@@Q
00@8@P@Q00048@88@P848@0324848@Q200848@0624848@Q224848@Q22@@Q
00@8@P@Q24848@88@P0336<48@@Q00D48@88@P@48@0324848@@Q00848@88
@P@48@88@P@48@0324848@Q20088@P051248@P@Q1248@P03124324800`@Q
2488@P0236<248@02QBU6<HDYAS636<@Q0aS248<H`Q210aS0Q2400H<H`Q2
36<@Q0aS248236<00a2436<<H`0436<00a2436<<H`0336<01@Q236<8@PQ2
36<00Q2400<<H`Q224800`aS00D8@PaS36<<H`Q200P<H`03248<H`aS008<
H`D@Q08<H`88@P8<H`0448@<H`aS248236<0112436<<H`Q23@aS0PQ210aS
0`Q200<<H`Q212400PQ20PaS10Q200@<H`Q236<8@PH<H`041248@PaS36<3
24800`aS248<H`0236<4248436<010Q236<<H`aS0PQ21@aS0`Q200<<H`Q2
36<010aS00H8@Q2448@@Q0aS248<36<00a2436<<H`0236<00`Q236<8@P08
36<224800`aS248<H`0636<01@Q236<<H`aS48@02PaS0A240@aS00001@@Q
00048@@Q00001`@Q00@<HaBU48@8@P@@Q00336<@Q124008@Q08<H`045:D@
Q0aS48@26<H00aBU36<<H`0248@00aBU48@<H`0236<01A245:D@Q0aS2480
0Q2400@DYA2448@@Q0<<H`035:D@Q0aS008<H`0448@<Ha2448@25:D00aS6
48@@Q00236<248@236<01A2436<@Q0aS5:D00Q240aBU0Q2400<<Ha2448@0
0PaS00<8@PaS36<00`aS1A2400<<Ha2448@00PaS00<@Q1BU36<00PaS0QBU
0PaS0a240PaS00H8@PaS48@@Q0aS48@236<748@011BU48@@Q1240PaS00D@
Q1BU48@@Q1BU00@<H`D@Q00436<@Q0aS248248@01aBU36<<Ha245:D@Q0aS
00@@Q08<H`88@P0748@DYABU36<8@P@Q24805P@Q00<000@Q12401P@Q00<0
00@Q124010@Q00<8@P@Q12400P@Q0PQ20P@Q0PQ20`@Q0PQ200D48@Q236<@
Q0aS00848@@8@P031248@P@Q00<8@Q048@88@P848@0324848@Q20088@P04
1248@PQ2124536<01A246<HLiaBU48@00`aS0PQ20P@Q00<8@P@Q248010@Q
0PQ20`@Q00H8@P@Q12448@Q236<4124010Q212448@Q20`@Q0`Q200D000@Q
12448@Q200D48@88@P0336<8@PQ200<8@P031248@P@Q00<48@0324848@@Q
00848@0600048@@Q1248@P@Q0PQ24@@Q00<8@P@Q12401@@Q1@Q200@@Q1BU
5:DDY@<@Q0<<H`03248<H`aS00<<H`0348@<H`aS008<H`03248<Ha2400D<
H`03248<H`aS00D<H`<8@PD<H`0448@<H`aS248536<00`Q236<<H`0236<0
1PQ236<@Q12436<8@P8<H`04248<Ha2448@236<010Q236<<H`Q21`aS00<8
@PaS36<00`aS00<8@PaS36<00PaS0`Q200<<H`Q2248010aS10Q200@<H`Q2
36<<H`H8@P071248@PaS36<8@P@Q24801@aS0PQ200<48@Q236<00`aS00<8
@PaS24800`Q20`aS0`Q20PaS0`Q200<<H`Q236<00PaS0PQ200<<H`Q236<0
0PaS00@8@PaS36<@Q0<<H`0348@<H`aS00P<H`88@P@<H`<8@PT<H`03248<
H`aS0088@P8<H`88@P<<H`08248<H`Q2248<H`Q236<@Q08<H`0348@<H`aS
00@<H`03248<H`aS0048@P000P@Q00@000@Q124000848@0600048@001248
@QS62a2400@DYA2436<<H`H@Q0@<H`0448@DYABU5:D248@436<00a2436<<
H`0248@011BU48@@Q0aS0Q2410aS1A240`aS00<@Q1BU48@01A2400<DYA24
48@00Q2400@DYA2448@DY@@@Q00336<@Q0aS00P@Q0035:D@Q124008<H`03
48@DYA2400<<H`0348@DYABU00D@Q0@<H`0548@<H`aS48@DY@0348@01`aS
48@@Q1BU48@HaQBU008@Q00436<@Q1BU5:D348@236<00a245:D<H`0236<2
48@436<00`Q236<<H`0248@010aS48@@Q12410aS00L@Q0aS248@Q1S65:D@
Q002124010Q212448@Q22`@Q00<8@P@Q12400P@Q00L8@P@Q12448@001248
@P0>12400`Q212448@06124010Q21248@P@Q1`Q20P@Q00D8@P@Q12448@Q2
008<H`0424848@@Q2488124010Q212448@@Q1PQ20`@Q20Q200<<H`@Q36<0
0PaS0Q240PaS1@Q20P@Q00X8@P@Q124000@Q24848@Q21248@PL48@042484
8@@Q124224851242248712402`Q212448@Q236<8@P@Q248DYB485:D010@Q
0PQ20P@Q00<8@P@Q248010@Q0PQ20PaS00@8@P@Q12448@88@P<48@032484
8@Q200H48@0324848@Q20088@P<48@0424848@Q236<248@00`aS5:DDY@02
5:D01PaS2488@PQ248@<H`88@P@<H`0448@<H`aS48@336<01PQ236<8@PaS
248<H`<8@P<<H`05248<H`aS36<@Q00336<2248836<2248236<010Q236<<
H`Q20`aS00<@Q0aS36<00PaS00<@Q0aS36<00PaS00<8@PaS48@00Q240PaS
00<@Q0aS36<00`aS00H8@PaS2488@PaS248236<00`Q236<<H`0348@236<0
10Q236<8@PaS0`Q20`aS0`Q20`aS0PQ210aS00<8@PaS248010aS0PQ20PaS
00<8@PaS24800PaS0PQ200@<H`Q22488@P<<H`06248<H`aS36<8@PaS0PQ2
1@aS0PQ210aS0PQ200<<Ha2436<00`aS0Q241@aS00H@Q0aS36<<Ha2436<2
48@436<00a2436<<H`0:36<3248536<22480112436<@Q1240`Q20`aS00@8
@PaS48@@Q088@P0000<000@Q12400`@Q00<000@Q12400`@Q00@<HaS65:D<
H`H@Q00336<@Q124008@Q0035:D<H`aS008@Q08DY@<@Q08<H`<@Q08<H`8@
Q0<<H`0448@<Ha2448@25:D248@010aS48@<Ha240`aS00<@Q0aS5:D00Q24
0PaS00<@Q1BU48@0112400<DYA2448@00PaS00<DYA245:D00QBU0a2400<D
YA2448@00PaS1a2400<DYA2436<00`aS0a2410aS00<DYA2448@0112400@<
Ha2436<@Q08<H`D@Q08DY@<@Q0<DY@<@Q0075:D@Q12448@DYA2436<01124
00@<Ha2448@@Q0<<H`0448@<Ha2448@236<248@00aBU48@@Q00336<01124
2488@PaS0QS600<DY@Q212400`@Q00@8@P@Q124000L48@0724848@@Q1240
00@Q00001@@Q00D000@Q124000@Q0088@P848@0300048@@Q00<48@040004
8@Q22482124010Q212448@Q20P@Q00@8@P@Q12448@<8@P031248@PQ200@4
8@<8@P848@<8@PD48@88@P@48@0336<8@P@Q00P8@P0736<8@P@Q24848@Q2
12400PQ20PaS0Q2400@<H`Q2124<H`88@P031248@PQ200<48@0324848@@Q
00848@0324848@@Q00@48@88@P@48@0324848@@Q00848@03248<H`Q200D4
8@0324848@Q200@48@8<H`848@035:DQ21BU00<48@88@P848@0400048@Q2
00041243248236<00`Q212400002248512400`0012448@0312401@Q21248
@P@Q24801P@Q00<8@PaS48@00aBU00@@Q1BU5:D@Q0L<H`03248<H`aS008@
Q0X<H`0448@<H`Q2248236<00`Q236<<H`0336<224800`aS48@@Q00536<2
24800`aS2488@P02248636<324800a2436<<H`0224800`aS48@<H`0636<3
48@F36<4248236<6248010aS2488@PaS0PQ200<<H`Q236<01PaS00<8@PaS
248010Q20`aS00D8@PaS248<H`Q200H<H`88@P0636<8@PaS36<@Q0aS0`Q2
00<@Q0aS36<00PaS0PQ21@aS00D8@PaS48@<H`Q2008<H`0548@<H`aS36<@
Q00236<00a2436<<H`0836<00`Q236<8@P0636<00`Q236<<H`0336<00a24
36<8@P02248336<2248536<00`Q236<<H`0236<00005124000@Q12400005
12402000124@Q1S648@<Ha245:D248@25:D00a2436<@Q00348@236<00a24
5:DDY@0348@236<00a2436<<H`0448@336<848@336<011BU48@@Q0Q20PaS
0Q2400@DYA2448@DY@@@Q08<H`0348@DYABU00<@Q08DY@0448@DYABU5:D3
48@00aBU48@@Q00436<348@01@aS48@HaQBU48@01`aS00<@Q0aS36<01124
00<DYA2436<00`aS00@@Q1BU48@@Q0@<H`0348@DYA24008@Q00436<@Q124
48@36<H01ABU48@@Q1245:D00Q2410aS00<@Q0aS48@010aS00<@Q1BU36<0
0`aS00<@Q1BU48@00Q2400@8@PaS36<8@P8<H`0448@DY@Q2248212400`Q2
12448@0312400`0024848@0E12400`Q212448@0512400`002488@P021240
0`Q212448@03124324800`@Q2488@P04248010@Q2488@PQ210@Q0PQ200<4
8@Q224801`@Q00P8@P@Q1248@P@Q248<H`Q20`@Q00<8@P@Q12400PQ200<<
H`Q236<00PQ200D48@Q22488@P@Q0088@P8<H`051248@PQ236<8@P031240
0`Q212448@02124224821242248212400`Q212448@04124010001248@PQ2
0`@Q0PQ20P@Q00<8@P@Q124010@Q0PQ20PaS00H8@P@Q1248@PaS24871240
0`Q212400004124020Q21248@P@Q248<H`Q236<<124224801P@Q2488@P@Q
24848@88@P@48@8<H`8DY@0348@DY@aS00H<H`05248<H`Q236<8@P0;36<0
0`Q236<<H`0236<5248436<2248336<22480112436<<H`Q210aS00<8@PaS
36<00PQ200D<H`Q236<<H`Q2008<H`8@Q00336<8@PQ2008<H`0348@<H`aS
00d<H`03248<H`aS008<H`88@P8<H`04248<H`aS36<2248336<01PQ236<<
H`Q236<8@P<<H`04248<H`Q2248236<010Q236<8@PQ20PaS00@@Q0aS1248
@P8<H`<8@P0436<8@PaS248236<01a2436<8@PQ236<@Q0aS0088@P0636<8
@PaS248<Ha240`aS10Q21@aS00<8@PaS36<00a2400<<H`Q236<010aS0Q24
0PaS11240PaS00<8@PaS36<010aS00@@Q0aS36<<H`88@P8<H`8@Q0<8@PD<
H`07248<Ha2436<8@PaS248010aS00D@Q0aS36<<Ha240048@P000P@Q00<0
00@Q12400`@Q00L000@Q12448A246<H@Q00236<00a2436<@Q00648@00aBU
48@<H`0236<348@336<348@236<00a2436<@Q00236<248@01aBU48@<H`aS
48@<Ha24008<H`035:D@Q12400<<H`@@Q08DY@0336<@Q1BU00D@Q08DY@L@
Q0<DY@<@Q0065:D@Q12436<@Q1BU0`aS00H@Q1S65:DDYA2436<348@236<0
0a2436<<H`0236<011245:DDYABU112400<DYA2448@00a2400<<H`Q236<0
0a2400DDYA245:DDYA24008DY@036<HDYABU00<DY@@@Q00436<@Q12448@<
36<348@00`aS248<H`0436<011245:D@Q0aS2@@Q00<8@P@Q00003@@Q00<8
@P@Q124040@Q0PQ200<48@Q2124010@Q20Q200@48@Q22488@P<48@88@P03
1248@PQ200<8@P`48@@8@P051248@PQ224848@0424800`aS2488@P052482
36<7248312400`Q212448@0312400`Q212448@0212401@Q212448@@Q2480
0`@Q0`Q20`@Q00D8@P@Q24848@Q200@48@0424848@@Q248236<00`Q21244
8@0236<01@Q212448@@Q24802P@Q00<8@P@Q24801@Q20`@Q00<<H`Q21240
1P@Q00D8@P@Q1248@P@Q0088@PD48@0324848@@Q008<H`0348@<Ha2400<@
Q0<<H`03248<H`aS008<H`09248<H`aS5:D@Q0aS48@<Ha2400@<H`03248<
H`aS00@8@P0436<8@PaS248436<01@Q236<8@PaS24800PaS00<@Q0aS2480
10Q200<<H`Q236<00PaS0PQ200D<H`Q22488@PaS008@Q0<<H`0448@<H`aS
36<2248336<348@536<00`Q236<<H`0436<01@Q236<8@PaS248010aS0`Q2
0PaS00<8@PaS24800PaS10Q20`aS0`Q200D<H`Q2248<Ha24008<H`88@P@<
H`88@P0336<8@PaS00<<H`06248<H`aS36<8@PaS0`Q210aS00@@Q0Q22488
@P<<H`03248<H`Q200@<H`8@Q00336<8@PaS008@Q08<H`04248<H`aS36<4
48@00`aS48@8@P0836<01PQ236<<Ha2436<8@P<<H`0424848@Q248@536<0
0a2436<<H`0236<00`Q236<8@P0336<00`Q236<<H`0236<1248000040004
8@@Q00021240100012448@000P@Q00L@Q1S648@<Ha245:D@Q0035:D336<0
11BU48@<H`aS0Q2400<DYA2448@00PaS00<@Q0aS48@00a2400@<Ha2448@@
Q0<<H`<DY@8@Q00336<@Q1BU00<@Q00436<@Q12448@336<348@02QBU48@<
Ha245:D@Q0aS248<Ha240`aS0QBU00<@Q1BU48@00Q2400@<Ha2436<<H`<@
Q08<H`D@Q00736<@Q1245:D<H`Q236<00Q240`aS0a2410aS00<@Q1BU48@0
0Q2410aS0a240PaS0a240PaS00@@Q1S68@PQ20<YBP03;F/U:B48008DY@8@
Q00536<@Q12436<8@P0236<0112436<<Ha2410aS0a240`aS0Q240PaS00D8
@Q245:DDY@aS00848@88@Q048@0300048@@Q00H48@0324848@@Q00D48@03
24848@@Q00<48@88@P031248@PQ200H8@P0336<8@PQ200@8@P0336<8@PQ2
00848@0<24848@0036<U:C6<6<H48@0024848@Q21@@Q00@8@P@Q1248@P8<
H`0324848@@Q00<48@88@P<48@<8@P031248@PQ200@8@P848@04248<Ha24
36<2124424800`@Q00048@032482124010Q21248@PQ220@Q0PQ210@Q00<8
@P@Q248010@Q00<8@P@Q24802PQ21`@Q0PQ20`@Q0`Q200@<H`Q22488@P<<
H`0424848@Q2248312401@002488@PQ212400PQ200<<H`Q224800PQ200@4
8@Q22488@P848@0536<DYAS648@<H`025:D01Q2436<8@PaS248@Q08<H`03
248<H`aS00@<H`05248<H`Q236<8@P0336<2248236<010Q236<<H`Q21@aS
0`Q210aS00<8@PaS36<01`aS00<8@PaS36<00PaS00@8@PaS36<@Q0H<H`05
248<H`aS36<@Q00236<00a2436<<H`0336<00a2436<<H`0236<2248336<0
0`Q236<<H`03248236<324800`aS2488@P0336<00`Q21248@P0236<42480
10aS48@<H`aS0PQ210aS0`Q24@aS00<8@PaS36<01`aS00<8@PaS24800PaS
0`Q210aS0Q2400`<H`Q2248<Ha2436<8@PaS48@<HaBU6<H27>L01AS648@<
H`aS24801`aS00<8@PaS48@00Q241PaS0PQ200D<Ha2436<<H`Q200L<H`05
48@8@PaS36<@Q00236<248@136<000@48@0300048@@Q00D48@0336<LiaBU
00<<H`@DY@0448@<H`aS36<348@236<248@00aBU48@<H`0336<648@336<0
1a245:D@Q0aS48@<Ha24008<H`<@Q0035:D@Q0aS008<H`8@Q00336<@Q124
00<@Q08DY@<@Q00436<@Q0aS48@45:D348@00aBU48@<H`0336<648@01QBU
48@@Q0aS48@DY@<@Q0<<H`0348@<Ha24008@Q0<<H`0348@DYABU00@<H`06
5:D<H`aS36<@Q1BU0PaS1Q2400D<HaBU7>LU:Be[00<YBP039BTQ21S6008@
Q00636<@Q12448@<H`Q20PaS00H@Q1BU48@@Q0aS248448@010aS248<H`aS
0Q2400@<H`Q2248@Q08HaP0536<48@@Q1248@P0212400`0012448@022487
12400`0012448@0312400`001248@P0312400`Q21248@P0312401PQ21244
8@@Q24848@88@P031248@P@Q0088@P848@03248<H`Q200<<H`<8@P0436<8
@P@Q1243248212401124:DX]JaS60P@Q00L8@P@Q12448@Q21248@P031242
24801@aS2488@PQ212402@Q200<48@Q212400P@Q1@Q200<48@Q236<00PaS
00<48@Q212400P@Q0`Q21@@Q10Q200<48@Q212400P@Q00@8@P@Q1248@P84
8@0424848@@Q124224800`@Q24848@022483124324800`@Q2488@P031242
24800`@Q2488@P081244248336<424800`@Q24848@0312400`Q21248@P03
124624801PaS24848@Q21248@P8@Q0045:D@Q0aS5:D248@00`aS248<H`06
36<2248236<248@010aS48@@Q1241PaS00@8@PaS36<8@PD<H`88@PL<H`03
248<Ha24008<H`03248<H`aS00<<H`07248<H`aS36<8@PaS24800`aS00<@
Q0aS36<00PaS00<@Q0aS36<00`aS0Q240`aS00@8@PaS36<<H`88@P<<H`88
@P0436<@Q0Q2248436<00`Q236<8@P02248336<3248010aS248<H`aS0`Q2
00@<Ha242488@PL<H`88@P0336<8@PaS00@8@Q0<H`03248<H`aS008<H`88
@P@<H`88@P8<H`035:D@Q12400H<H`04248<Ha246<H27>L00aS65:D<H`02
36<348@00`Q236<<H`0636<02Q2436<<H`aS248<H`Q236<@Q1BU0PaS0PQ2
1PaS00<8@P@Q36<01@aS0A240@aS0@Q200000`001240000212400`001244
8@0212401000124<HaS60Q240QBU00@@Q1BU5:DDY@@@Q0045:D@Q12448@4
36<00a245:DDY@0248@236<45:D336<25:D01A2436<<Ha2436<011240PaS
0a240`aS00@@Q1BU5:D@Q08<H`@@Q00336<@Q124008@Q00336<@Q124008@
Q0065:D@Q0aS36<@Q1BU0Q240PaS0Q2400<<Ha2448@00QBU0a2400<DY@aS
36<00QBU00<@Q0Q236<00a2400<<Ha2448@00Q240`aS00@@Q1BU48@@Q0@<
H`0348@DYA2400<@Q00<36<@Q0aS48@Q22e[?Nle[CW>?NlaS2U:0QBU00<@
Q0aS48@01@aS00<@Q1BU36<00a2400<<H`Q236<00a240PaS0a2400T<H`Q2
248@Q1S65:D@Q0Q212400`Q25`@Q00<8@P@Q24800P@Q00@8@PaS2488@P84
8@0300048@@Q00848@@8@P031248@PaS008@Q0035:D@Q124008@Q00336<8
@PQ200<<H`0324848@Q200848@04248<H`aS248212401@Q212448@Q21240
0`Q20`@Q00@8@PaS36<<H`88@P041248@PQ224831243248010@Q24848@Q2
0P@Q00<8@P@Q36<00PQ200D<H`Q22488@P@Q00<8@P@48@<8@P<48@052484
8@Q21248@P0412400`Q212448@0612401@Q212448@@Q24800PaS00<8@P@Q
12400`Q200D48@Q2248<H`Q200/48@0324848@@Q00848@8<H`0348@<H`aS
00<<H`88@P<48@<8@P031248@PQ200848@88@P0336<@Q0Q20088@P848@88
@P0336<@Q12400D@Q0X<H`05248<Ha2448@<H`02248436<00`Q236<<H`02
36<01PQ236<<H`Q236<8@P@<H`05248<H`aS48@<H`02248336<2248236<0
0a2436<<H`0236<00`Q236<<H`0336<00`Q236<<H`0636<0112436<@Q0aS
0Q241@aS00@8@PaS248@Q0H<H`88@P0536<@Q0aS36<8@P0236<324800a24
36<8@P02248236<00`Q236<<H`06248636<2248536<3248336<00`Q236<<
H`0836<224801`aS48@<H`aS248<H`Q2008<H`03248<H`aS00@8@P<<H`05
48@<H`Q236<8@P0636<248@01AS65:D@Q0aS24800PaS00<8@PaS36<01PaS
0Q2410aS00<8@PaS36<00`aS00<8@PaS24800PaS00P8@PaS36<<H`Q236<8
@PaS0PQ21@aS00061240100012448@000P@Q00<@Q1cW5:D00PaS00<@Q1BU
5:D00aBU00<@Q0aS48@011240`aS0Q240QBU00@@Q0aS36<<H`@@Q00436<8
@PaS48@25:D336<348@010aS48@DYA240`aS00<@Q0aS36<00Q2400<DYA24
48@011240PaS0a2400<<Ha2436<00PaS0Q2400<DYA2448@00Q240PaS0Q24
10aS00D@Q1BU5:D@Q0aS00<@Q00536<@Q12436<@Q00236<248@021BU48@@
Q1BU48@8@PaS48@25:D548@336<011245:D@Q0aS0QBU0PaS00TQ23F]@Q0e
[C6<?NlaS2e[6<H00Q241`aS0Q240`aS00<@Q0aS36<00PaS0Q2400<<H`Q2
48@00Q2400P<H`Q2124@Q1BU7>LDY@Q24@@Q00@000@Q1248@P@48@032484
8@@Q00H48@0524848@@Q1248@P0512400`Q236<8@P0224800`aS48@HaP02
48@00aBU48@<H`0524800`aS24848@031243248212400`Q212448@031240
1PQ212448@@Q24848@8<H`8@Q00436<8@P@Q1245248612400`001248@P02
24800`@Q24848@0224800`aS2488@P0312400`Q212448@0212401`Q21248
@P@Q24848@Q200H48@0324848@@Q00@48@0324848@@Q00<48@@8@P848@H8
@P0436<8@PQ22487124224801@@Q00048@Q212400`Q210aS0`Q200@48@Q2
1248@P@48@@8@P031248@PaS008<H`0424848@@Q248212400`aS48@@Q002
48@00aBU48@@Q00336<3248236<00`Q236<<H`0336<224800`aS48@<H`04
36<01@Q236<8@PaS24801@aS00<8@PaS24800PaS0PQ200P@Q1BU36<8@PaS
48@<H`Q20PaS0`Q20`aS00<8@PaS36<00PQ200<<Ha2436<00PQ21@aS0a24
0`aS00<@Q0aS36<01PaS00<8@PaS24800PaS00@8@PaS36<8@P<<H`<8@P8<
H`06248<H`Q2248<H`Q20`aS0PQ20`aS10Q20PaS0`Q200H@Q0aS248<Ha24
36<3248436<010Q236<<H`Q20PaS00<8@PaS36<010aS00@@Q0aS36<8@P8<
H`88@P8<H`88@P8<H`88@P0436<@Q12436<224800`aS248<H`0236<248@0
11BU48@@Q1240`aS00<8@PaS48@010aS00<@Q0aS36<00PaS0Q2400<<H`Q2
24800PaS0PQ200<<Ha2436<00PQ210aS0PQ20`aS00<8@PaS48@010aS0@Q2
00001@00124000@Q00000`@Q00/000@Q12448@aS7>LDYA245:D@Q0aS008D
Y@036<H@Q0aS008<H`8@Q00436<@Q12436<648@00aBU48@DY@0248@00aBU
48@@Q00236<348@236<01A2436<<Ha2436<0112400<<Ha2436<00Q2400<D
YA2436<00`aS0a240PaS0Q240QBU0PaS0a240PaS0Q2400<DYA2448@00a24
0`aS00@@Q1BU48@@Q08<H`035:D@Q124008@Q0065:D@Q0aS36<DYA240PaS
0Q2410aS00P8@PaS5:DDYA2436<8@PaS0Q2400<DYA2436<00Q240`aS0Q24
00PDYBDY9BTe[CW>:DXQ21240QBU00<@Q0aS36<010aS0a2400<<Ha2436<0
20aS00<@Q1BU48@00PaS00D8@Q247>LHaPaS00848@88@P@48@0300048@@Q
00@48@03248000@Q00H48@0300048@@Q00@48@88@P031248@P@Q00848@03
24848@@Q00@48@88@P0936<8@PaS6<HQ23g_BU8e[Be[008DY@066<HDYA24
36<8@P@Q0`Q200<<H`Q212400`@Q00<8@P@Q248010Q200D48@Q21248@P@Q
0088@P8<H`0524848@Q236<8@P051244248512400`Q236<8@P0212432482
12400`Q212448@0212400`Q212448@0512400`Q212448@02124224831240
10001248@PQ20`@Q00T8@PaS36<000@Q6<H]JbDY36<00P@Q00@@Q0Q2248<
H`88@P848@88@PD48@08248000@Q1248@P@Q00048@88@P<<H`<@Q00336<8
@PQ200<8@P031248@P@Q00T8@P0536<8@PQ21248@P0636<021246<HDYA24
1248@PaS248236<348@00`Q236<<H`0348@00`aS248<H`0336<010Q236<<
H`aS0PQ200<<H`Q236<01@Q200<<H`Q224800`aS0`Q21PaS00@@Q0aS36<<
H`<8@P8<H`88@P@<H`88@P@<H`@@Q0<<H`0348@<H`aS008<H`88@P8<H`03
48@8@PQ20088@P0336<8@PaS00<<H`88@P0336<8@PQ200@<H`06248<H`Q2
36<8@PaS1@Q20`aS0PQ20`aS00D48@Q236<<Ha24008<H`05248<H`Q236<8
@P0236<2248536<0112436<<H`Q20`aS00L8@PaS36<<H`Q236<8@P0236<0
20Q236<8@PQ236<8@PaS248:36<248@536<00a2436<8@P02248236<00a24
36<<H`0:36<3248236<3248736<3248236<148@136<1248000X48@0:0004
8@aS7>LHaQ245:D@Q1BU48@26<H236<010Q248@@Q0aS0Q2400@<Ha2436<<
H`X@Q0<<H`D@Q00336<@Q0aS00<<H`8@Q0045:D@Q0aS36<548@436<248@4
36<00aBU48@@Q00336<011245:D<H`aS0Q2400D<Ha2448@DYA2400@<H`<@
Q00536<@Q12436<@Q0025:D248@236<0112436<<H`aS0a2400L<H`Q236<@
Q0aS248@Q0025:D236<348@236<648@236<01aBU8@PU:CF]>LhU:AcW008@
Q0055:D@Q12448@<H`02248448@00`Q236<<H`0236<010Q236<@Q1240`aS
0Q2400L<H`Q2248@Q1cW6<HDY@021242248F124224800`@Q2488@P021240
0`Q21248@P0412400`Q21248@P0724801aS67>M244Ha>LhaS1BU008HaP03
48@<H`Q2008<H`<8@P031248@P@Q00@48@88@P<48@03248<H`Q200848@04
24848@Q2248336<212400`Q236<8@P0312400`Q21248@P03124324821243
24800`@Q2488@P02248412400`Q212448@061242248512400`Q212448@06
124010Q21248@PQ20P@Q00HDYBU:8@P<H`@Q248236<62483124010Q21248
@PQ21P@Q00D8@P@Q1248@PaS00<@Q0@<H`88@P<48@0324848@@Q00848@88
@P8<H`03248<H`Q200H8@P<<H`05248@Q1BU6<H@Q004248436<00`Q236<8
@P0448@00`aS48@<H`0236<2248236<010Q236<8@PQ21@aS0`Q200<@Q0aS
24801`aS00@8@PaS36<@Q0<<H`04248<H`aS36<3248536<01PQ236<<H`Q2
36<@Q08DY@8@Q0<<H`03248<H`aS008<H`05248<H`aS36<8@P0836<32484
36<2248736<4248236<4248436<00a242488@P0236<01Q2436<8@PQ236<8
@PH<H`88@Ph<H`88@P<<H`D8@P8<H`05248<H`aS36<@Q00436<00a24248<
H`0236<00a2436<<H`02248C36<2248336<01`Q236<<Ha2436<8@PaS0088
@P<<H`04248<H`aS36<12480000700048@00124000@Q00001@@Q00L<HaS6
48@<Ha245:D@Q0025:D01A245:D@Q1245:D010aS1A2400<<HaBU5:D00QBU
0Q2400<<Ha245:D0112400@DY@aS36<<H`8@Q00836<@Q0aS48@<Ha246<HD
Y@8@Q0<DY@8<H`0548@<H`aS36<@Q00436<348@011BU48@@Q0aS1A2400@D
YA2436<<H`8@Q00336<8@Q24008DY@0348@<H`aS00<@Q0@<H`8@Q08DY@8@
Q08<H`<@Q0<<H`H@Q0035:D@Q124008<H`8@Q0055:D@Q12436<DY@0248@0
0aBU48@HaP027>L01ABU48@DYABU48@00PaS00@@Q0aS248<H`8@Q00536<@
Q12436<@Q00236<00a2436<@Q00236<25:D248@01`aS248@Q1BU6<HDY@aS
00<48@88@P848@0324848@@Q01448@0324848@@Q00<48@0324848@@Q0084
8@0424848@Q21243248336<00aBU8@PYBP02BU802EJeF]I:DTYB=JdYBQcW
48@<H`02248010aS48@<H`Q20P@Q00@8@P@Q2488@P848@D8@P051248@P@Q
24848@04248010aS2488@PQ20P@Q00T8@P@Q2488@P@Q24848@Q212400PQ2
0`@Q0PQ20P@Q0PQ20P@Q0PQ21@@Q00<8@P@Q124010@Q0PQ210@Q00<8@P@Q
12400P@Q00D8@P@Q24848@Q200<<H`031248@PQ2008<H`8@Q08HaP035:D@
Q0aS008@Q088@P031248@P@Q00848@<8@PP48@03248@Q124008DY@0348@D
Y@aS0088@P04124<H`Q22484124424800`aS2488@P0236<224800`aS48@<
H`0336<248@236<010Q21248@PQ21@aS0PQ200<<Ha2448@00PaS00<8@PaS
36<00PaS0PQ20PaS00<48@Q236<00PaS0PQ200L<H`Q236<<H`Q236<8@P03
36<2248336<3248236<00a2436<<H`0224800`aS48@<H`0236<00a2436<<
H`0736<0212436<<H`aS48@DYA2436<2248436<00a2436<8@P03248010aS
48@<H`aS0PQ200@<H`Q224848@88@P8<H`88@P<<H`L8@P0336<8@PaS00H<
H`0348@<H`aS00<8@P0336<8@PaS00H<H`88@P/<H`8@Q08<H`06248<H`aS
36<8@PaS0PQ21@aS0PQ210aS00D8@Q2448@@Q0aS00<8@P8<H`0348@<H`aS
008<H`@@Q0<<H`88@P@<H`88@P8<H`88@P0536<8@PaS248<H`02248336<3
248236<00`Q236<<H`01248000P48@0700048@@Q124<HacW5:D0112400<D
YA2448@00a241@aS112400<<Ha2448@00QBU0Q240PaS00L@Q1BU5:D@Q0aS
5:D@Q00536<00a2436<<H`0848@25:D248@836<448@01@aS48@@Q1BU48@0
0PaS00<@Q1BU48@00a240`aS00<@Q1BU5:D00QBU00<<Ha2436<00`aS0Q24
00@DYA245:D@Q0<<H`8DY@0648@<H`Q236<@Q0Q20PaS0aBU00D@Q0aS48@@
Q1BU008<H`0448@DYA2448@336<348@01AcW8@PLiaS636<00Q240PaS00LD
YA2436<8@PaS48@DY@0236<248@00`Q236<<H`0348@00`aS48@@Q00248@2
36<01PQ248@LiaS648@8@P`48@0300048@@Q00D48@88@PT48@88@PH48@07
24848@@Q1248@PaS24800PaS00DDYBDY:DY6<DYB009JeP96<@06<H`U:AcW
48@<H`Q210aS1@Q20P@Q0PQ20`@Q0PQ200@<H`Q224848@<8@P8<H`88@P84
8@0524848@Q21248@P021242248010@Q24848@Q20P@Q10Q200<48@Q21240
0`@Q00<8@P@Q12400P@Q00P8@P@Q12448@0024848@Q20P@Q00D8@P@Q1244
8@Q200D48@0424848@@Q248236<2248010@Q36<@Q0aS0QBU00@HaQBU5:DD
Y@8@Q00336<8@PQ200848@<8@PH48@0524848@@Q1248@P0336<01Q245:D@
Q124248<H`88@P031248@P@Q00<48@88@P041248@PQ2248236<010Q236<8
@P@Q0PaS00<@Q0aS36<00PaS00<@Q0aS36<010Q21@aS0PQ200@<Ha245:D@
Q0P<H`03248<H`aS00<<H`@8@P0336<@Q0aS00@<H`0348@<H`aS00<<H`04
248<H`aS48@636<4248636<00`Q236<<H`0336<01a245:D@Q0aS48@<Ha24
00<<H`88@P<<H`05248<H`aS48@<H`0224800`aS248<H`02248536<22483
36<424801PaS248<H`Q236<8@P8<H`09248<H`aS36<@Q0aS248<H`Q200D<
H`03248@Q124008<H`04248<H`aS248536<2248010aS48@@Q0Q210aS00D8
@PaS36<<H`Q200<<H`88@P@<H`04248<H`aS48@236<010Q248@@Q1240`Q2
0Q240PaS00<@Q0aS24800PQ20Q242PaS0`Q200<<H`Q236<00PQ210aS00H8
@PaS36<<H`Q236<2248236<148@136<00006124000@Q00048@0010@Q00T0
00@Q48@Q21BU36<DYA245:D0112400<DYA2448@01PaS0Q2400<DYA2448@0
0Q240QBU00D@Q1BU36<@Q0aS00@@Q08<H`04248@Q0aS36<448@25:D01Q24
36<<HaBU6<HDY@<@Q08<H`<@Q08<H`<@Q0@<H`8@Q0045:D<Ha2436<248@0
0aBU48@@Q00236<748@236<00a2436<@Q00248@00aBU48@<H`0248@25:D5
48@236<348@00aBU48@@Q00248@35:D248@25:D01QS648@<H`aS48@DY@@@
Q00336<@Q124008@Q08<H`0548@<H`aS48@DY@0248@00`aS248@Q00448@4
36<248@236<348@01PaS5:DDYABU48@8@PP48@88@P03124000@Q00T48@03
24848@@Q00<48@0724848@@Q1248@P@Q24801`@Q0PQ200L<Ha246<HaS3g_
JeYcW002Nmh026mkMkeS65Je>LhLiaS636<5248212422484124324831243
24800`@Q248<H`0436<2248212400`Q236<8@P02248336<2248412422483
124224841243248H12401@Q236<8@PQ212400PaS00D8@RU:>LiJeUJe008a
S0058@PHaQS648@<H`03248010@Q2488@PQ20`@Q00<8@P@Q124010@Q00@8
@PaS36<8@P8<H`D8@P<48@<8@P041248@P@Q12442482124324800`aS248<
H`0248@536<224800`aS1248@P0336<01@Q236<<Ha2436<00PQ210aS0PQ2
00<<H`Q224800PQ20`aS00<8@PaS24801`aS00<8@PaS36<00PQ200<<H`Q2
36<00`aS00H8@PaS2488@PaS48@236<2248236<0112436<<H`Q21@aS00<@
Q0aS36<00Q240PaS0PQ200<<H`Q248@00PaS00<@Q0aS36<00PaS00@@Q0Q2
36<8@P8<H`@8@P0436<8@PQ236<248@01`aS2488@PQ236<8@PaS00<8@P@<
H`05248<H`Q236<@Q00236<00`Q236<<H`0236<00`Q236<8@P0236<248@4
36<248@010aS248<Ha240PaS00@8@PaS248<H`88@P@<H`0524848@Q2248@
Q00736<224801PaS248<H`Q236<@Q08<H`03248<Ha2400<<H`03248<Ha24
00<<H`0348@<H`aS00@<H`<8@P0436<8@PQ2248236<3248236<01@Q236<<
H`aS24800`aS0PQ20PaS0@Q200000`0012448@0612401P0012448ABU8@PH
aP8<H`8@Q0035:D@Q1BU00@@Q08<H`88@P0448@DYABU48@236<00aBU48@@
Q00248@01QBU48@@Q0aS48@<H`8@Q00336<@Q0aS00<<H`L@Q0035:D@Q1BU
00<DY@0348@<Ha24008<H`0748@<H`aS48@<Ha2436<00Q240PaS0a2400D<
Ha2436<@Q0aS00D@Q00536<8@Q2448@DY@0336<848@35:D248@45:D336<0
0a2436<<H`0548@011BU48@@Q1240`aS0QS600<DY@aS24800a240QBU0Q24
00<<Ha2448@00`aS0Q2400P<Ha2448@@Q0aS248<Ha241@aS00<@Q0aS48@0
0Q2400<<Ha2436<00`aS00@@Q1S66<H<H`X48@0300048@@Q00H48@032484
8@@Q00848@0324848@@Q0088@P<48@<8@P848@0424848@@Q124224802@aS
248<H`aS6<HaS3g_JeY_N`02Nmh026mkMkeW>E:D=JdLiaBU36<424800`@Q
2488@P04124224802@aS2488@PQ21248@P@Q24848@0224801@aS48@@Q0aS
24800P@Q1`Q20PaS00<8@P@Q12400PQ21@@Q0`Q22@@Q00<000@Q12401P@Q
00<8@P@Q12400P@Q00<8@P@Q12400P@Q00<8@P@Q12401PQ200X<H`Q2248Y
BSW>G_MF]Be[:DXLi`8HaP055:D<H`Q224848@03248412400`Q21248@P02
124224800`aS248<H`0236<62484124010Q212448@@Q0PQ200<48@Q22480
0PaS00<8@P@Q24800PaS0PQ20`aS0PQ210aS00<8@PaS36<01`aS00<@Q0aS
24800PQ200<<Ha2436<01@Q20`aS0PQ20`aS00D8@PaS36<<Ha24008<H`06
248<H`Q236<8@PaS0PQ20PaS00@@Q0Q22488@PD<H`04248<H`aS36<42482
36<548@00`aS48@<H`0248@336<00`Q236<<H`0336<00`Q236<<H`0636<0
0`Q236<<H`0224800a2436<8@P02248336<01PQ236<8@PQ236<@Q08<H`88
@P0336<8@PaS00<<H`03248<H`aS008<H`03248<H`aS00D<H`8@Q08<H`04
48@<H`aS248536<010Q236<<H`aS0PQ20PaS0PQ20`aS00<8@PaS36<02@aS
0PQ220aS112400@<Ha2448@@Q0P<H`03248<H`Q200@<H`88@P8<H`03248<
H`aS00@8@P0336<8@PaS00@<H`48@P000P@Q00@000@Q124000H48@0436<L
iaBU36<348@00aS648@<H`0348@236<00`Q236<<H`0348@00aBU48@DY@03
48@00`aS48@<H`0248@00aBU48@@Q00248@010aS2488@PaS0Q2400<8@PaS
48@00Q2400<<Ha245:D00aBU00<@Q0aS48@00PaS00<@Q0aS36<00`aS00@@
Q0aS48@<H`H@Q0045:D@Q12436<348@236<01a2436<DYA245:D@Q1BU00<<
H`0848@DYA2448@<Ha2436<@Q0<<H`0348@DYAS600@@Q0035:D@Q12400D@
Q0055:D@Q1BU48@<H`0248@00aBU48@@Q00248@236<01QBU48@DYABU48@<
H`8@Q0055:D@Q0aS36<@Q00236<021245:DDY@aS248<Ha245:D348@236<3
48@00`aS48@@Q00248@336<25:D00`aS24848@0224800`@Q00048@061240
1`0012448@@Q00048@0000P48@88@PD48@0524848@@Q1248@P0212432482
48@01AcW>Li6<FmkLi`00WNm0V]J00Mg_GooNmhmkaS60008@P0312401@Q2
12448@@Q000020@Q0`Q200H48@Q2248<Ha245:D248@00`aS24848@021244
248336<00a2424848@03124010Q212448@@Q10Q220@Q00<8@P@Q12404@@Q
00@8@P@Q1248@P@<H`8@Q0035:DYBSF]00=JeP06HaQ>LdYB>LhYBQcW0PaS
0PQ20PaS00D8@P@Q12448@Q200H48@<8@P031248@PQ200<8@P031248@P@Q
00H8@P<48@88@P8<H`0324848@Q200<<H`04248<H`aS48@336<00`Q21248
@P02248836<010Q236<<Ha240`Q200<<Ha2448@00`Q20`aS0PQ20`aS00<8
@PaS36<01`aS0`Q22`aS00L8@PaS248<H`Q236<8@P0336<010Q236<<Ha24
0`aS00@@Q0aS36<<H`8@Q08<H`03248<H`aS008@Q0<<H`03248@Q0aS008<
H`03248<H`Q2008<H`@8@P<<H`04248<H`Q236<4248336<324801PaS48@<
H`Q236<8@PH<H`03248<H`Q200@@Q0X<H`0448@<H`aS36<2248;36<62480
0a2436<<H`03248236<00a2436<<H`0536<248@>36<010Q248@@Q0aS0PQ2
0`aS00@8@PaS36<8@P@<H`04248<H`Q2248436<00005124000@Q12400004
12401P0012448A247>LDY@8<H`0648@DYABU5:D@Q0aS11240`aS0Q2400XD
YA2448@@Q1BU48@<Ha2436<@Q0<<H`0448@DYA2448@436<0212436<@Q124
36<@Q0aS5:D448@35:D01A2436<@Q0aS48@00PaS00@@Q0aS48@@Q08<H`03
48@<H`aS008@Q08DY@0636<@Q0aS48@<Ha241@aS0QBU00D@Q0aS36<<Ha24
008<H`L@Q00336<@Q12400<DY@0448@<HaBU48@336<00aBU48@<H`0348@0
10aS48@DYA240PaS00@DYAS648@<H`<@Q00336<@Q1BU008@Q00336<@Q124
00<<H`0548@<H`aS48@HaP0248@2248236<348@336<348@736<00aBU48@@
Q00212401@Q212448@@Q00002P@Q00<8@P@Q124010@Q00<8@P@Q12402@@Q
00<8@P@Q24800P@Q0PQ200T<H`Q248@@Q1cW?Nm:DVmkLi`00WNm0V]J00Mg
_GooMkdmkaBU1248@P0=124010Q212448@@Q0`Q200<48@Q224800QBU0Q24
00D8@P@Q2488@P@Q0088@P0336<8@PQ2008<H`88@P04124000@Q24841242
248212400`Q21248@P0=12400`Q212448@0312400`Q21248@P0212401PQ2
12448@@Q248<H`<8@P0548@DYABU<H`icP03F]H01UkgDYA>LcW>9BTLi`@8
@P0336<8@P@Q00@48@0324848@@Q00@48@0324848@Q200848@88@P0536<8
@PQ21248@P0212442482124224801@aS248<H`Q236<010Q210aS0PQ20PaS
0PQ20PaS00<8@PaS36<00`Q20`aS0PQ200<@Q0aS36<00`Q200<<H`Q22480
0PQ210aS0PQ22@aS00@8@PaS36<8@P8<H`0548@8@PQ21248@P0936<010Q2
36<<H`Q20`aS0PQ200@<Ha2448@<H`88@P0436<DYA2436<2248336<01@Q2
36<8@PaS48@00`aS10Q200P<H`Q236<8@PaS248<H`Q20PaS0`Q200H<H`Q2
36<<H`Q236<424800`aS248<H`0836<3248236<0112436<<Ha2420aS00<@
Q0aS36<01@aS00<8@PaS24800PaS10Q20`aS00@8@PaS248<H`88@P/<H`03
48@<H`aS008@Q0/<H`03248<H`aS008<H`88@P8<H`88@P<<H`07248<H`aS
36<8@PaS24800PaS0`Q20PaS00000`0012448@0312400`0012448@031240
0`aS8@PLi`025:D848@00aBU36<<H`0448@01@aS48@@Q12436<00Q240`aS
1A2400<DY@aS36<00`aS00<@Q0aS36<0112400@8@PaS48@@Q08DY@8@Q0<<
H`0348@<HaBU00<@Q08<H`H@Q0055:D@Q12448@<H`0248@35:D236<00a24
5:DHaP025:D248@236<248@236<248@25:D348@25:D0212436<@Q12436<D
YA245:D;48@236<01Q245:DHaQ2436<@Q08<H`065:D@Q1BU36<@Q0aS1A24
00<<Ha2448@00Q2400D<HaBU5:DDYA2400@<H`8@Q0035:D@Q124008@Q004
5:D@Q0aS36<248@011BU48@@Q0Q20P@Q0PQ200L48@0012448@Q212400002
12400`0012448@0212400`0012448@061243248512401PQ21248@P@Q2484
8@88@P8@Q0036<HYBSF]009JeP0=JeY_Ng>LNmig_FmkF]I:DSW>6<H<H`@Q
248010aS10@Q00L8@P@Q124000@Q24848@0224801@@Q2488@PQ236<00aBU
00<<H`Q224800`@Q00<8@PaS36<00`Q20PaS00@8@P@Q12448@88@P<48@04
248<H`Q2000612400`Q212448@0312401P0012448@@Q248000L48@072484
8@@Q1248@P@Q24800`aS00L@Q1BU7>M244icLiag_@03Kg/02GooNmiJeS6<
5:D@Q0Q21248@P031240100012448@001`@Q00<8@P@Q12400`@Q10Q20P@Q
1@Q200@48@Q212448@88@P0436<@Q0aS36<3248010aS5:D@Q0aS0PQ200@<
H`Q21248@P<<H`88@P0336<8@Q24008<H`88@P@<H`05248<H`aS36<@Q002
36<010Q236<<H`aS0`Q20PaS00<@Q0Q224800PQ21`aS00<8@PaS36<00`aS
00<8@PaS36<010aS0`Q20PaS00@@Q0aS36<8@P<<H`03248<H`aS008<H`<@
Q0@<H`03248<H`aS00@<H`0448@<H`Q2248336<2248010aS48@<H`aS0PQ2
00P<H`Q236<<H`Q236<@Q0aS0PQ20PaS10Q200@<H`Q236<<H`8@Q08<H`88
@P8<H`8@Q0H<H`<@Q0@<H`03248<H`aS00<8@P8<H`03248<Ha24008<H`09
1248@PaS248<H`Q236<8@PaS0088@PL<H`0448@<H`aS36<224800`aS48@@
Q00236<00a2436<<H`0324801@aS248<H`Q248@00`aS0PQ20PaS00@@Q0aS
36<8@P@<H`88@P8<H`04248<H`aS48@236<1248136<136<000<48@030004
8@@Q00848@0800048@@Q124DYB486<H<H`X@Q00336<@Q124008@Q00436<@
Q1246<H248@336<348@236<548@00`aS48@@Q00436<248@336<348@25:D0
0a2436<@Q00248@236<548@01`aS48@@Q0aS48@<Ha24008DY@@@Q00336<@
Q0aS00<DY@8@Q0085:DHaQBU48@<H`Q236<@Q08DY@0348@<H`aS008@Q005
36<@Q1BU5:D@Q00236<011245:D@Q1BU0Q2400@DYA2436<@Q08DY@8@Q08D
Y@8<H`0348@DYA2400<@Q0045:D@Q1245:D248@00`aS48@@Q00248@010aS
48@<H`aS0aBU0PaS0QBU00@@Q0aS48@@Q0<<H`<@Q00336<@Q124008@Q003
36<@Q1BU008DY@0348@8@PQ200L48@0300048@@Q01848@@8@P848@042484
8@@Q1244248248@041BU:DXicU[FG_MW>G>LKg]kgWNmKg]F]DHa>LhHaQ24
0P@Q0PaS0PQ210@Q00<8@P@Q12401P@Q10Q200D<HaBU6<HHaPaS0088@P84
8@D8@P0636<@Q0aS24848@Q20P@Q0`Q20P@Q00D8@P@Q12448@Q200h48@06
24848@Q224848@Q20`@Q0PQ200<48@Q212400`Q200/<Ha2436<@Q1S67>M6
<E:DLiag_Fmk009cW006OomkgU[F=JdDYA242P@Q00@000@Q12448@<8@PD4
8@<8@P051248@PQ224848@0224800`aS24848@0312400`aS248<H`0336<3
24801PaS48@@Q0aS248<H`88@P@<H`03248<H`aS008<H`03248<H`aS00@<
H`03248<H`aS008@Q088@P<<H`88@P0436<8@PQ2248236<00`Q236<<H`05
36<2248336<00`Q236<<H`0536<01PQ236<<Ha2436<8@P8<H`0348@<H`Q2
00@<H`<8@P0336<@Q12400<<H`0448@<H`aS248336<00`Q236<<H`0248@0
0`aS2488@P0236<01A2436<8@PQ236<00Q2400D<H`Q22488@PaS0088@P@<
H`88@P0436<8@PQ2248:36<00a2436<<H`0324800`aS48@@Q00536<00a24
36<<H`02248010aS2488@PQ21`aS0PQ200<<H`Q212400PQ20PaS00<8@PaS
24800Q2410aS0Q240`aS00@8@PaS2488@P8<H`8@Q0<<H`03248<H`Q200@<
H`07248<H`aS36<@Q0Q236<00PQ200<<H`Q2248010aS0PQ200<<H`Q236<0
0PaS00<8@PaS36<00PaS00000`001240000212401@0012448@@Q00000P@Q
00<<HacW5:D00a240QBU112400<DYA2448@00PaS0Q2400@<Ha2448@@Q08D
Y@8@Q0@<H`8@Q08DY@0348@HaQ2400<<H`8@Q0@<H`8@Q08<H`8@Q0035:D@
Q124008@Q0<<H`@@Q00436<@Q1BU36<448@00`aS48@@Q00248@236<00a24
36<@Q00348@02QBU6<HDYA2436<8@Q245:D@Q0aS1A2400<HaQ2448@00Q24
0QBU112400@DYA245:DDY@8HaP8DY@8@Q00436<@Q1BU5:D348@25:D448@0
1QBU48@@Q1245:D@Q0<<H`0448@<Ha2448@35:D248@236<00a2436<<H`03
36<0112436<<HaBU0QcW00<DY@Q236<00Q2400LDY@aS48@DYAS65:D8@P02
1242248512401@Q212448@@Q000010@Q00<8@P@Q12402`@Q0PQ21@@Q00<8
@PaS36<00PaS0QBU00XHaRe[<Ha>LdYBDYAJeTYB@Q0]J`8Li`0548@<H`Q2
124@Q0027>L0112412448@Q21P@Q10Q200@48@Q224848@88@PD<H`88@P03
1248@PQ200<<H`88@P/48@0324848@Q201048@0324848@@Q00848@032484
8@@Q00848@0424848@Q2248436<021245:DLib48?Nm:DW>LMkd2Li`01f]J
Kg]cW7ooNmhicQBU00P48@0700048@@Q124000@Q00000P@Q00@8@P@Q1240
00@48@0424848@@Q1243248010@Q2488@P@Q0PQ20PaS00<8@PaS24800PQ2
0PaS00D@Q0aS36<@Q0aS00D8@P<<H`03248<H`Q20088@PH<H`88@PT<H`04
248<H`aS36<5248536<2248836<00`Q236<<H`0336<00a2436<<H`022480
0`aS2488@P0436<224800`aS48@@Q00236<01`Q236<<H`aS48@<Ha2400<<
H`88@PH<H`0648@8@PQ2248<Ha240`aS00<@Q0Q224800PaS0PQ200<48@Q2
36<00PaS0`Q20PaS0`Q200D<Ha2448@<H`Q200<<H`05248<H`aS36<@Q005
36<00`Q236<<H`0236<010Q236<<H`Q20`aS00H8@PaS36<<H`Q236<22482
36<01Q2436<8@PaS48@<H`88@Q<<H`03248<H`aS00<<H`07248<H`aS36<8
@PaS248010aS0PQ20`aS00<8@PaS48@010Q20Q2410aS00<8@PaS36<00@aS
000412400`0012448@0312401P00124@Q1cW6<H<H`8@Q08DY@D@Q00336<@
Q12400@@Q0035:D@Q1BU008@Q00336<@Q124008<H`@@Q0035:D@Q0aS008<
H`@@Q00436<@Q12448@336<02QBU48@DYA2436<@Q1BU36<8@PaS0a2410aS
0a2410aS00<@Q0aS36<01@aS00P@Q0aS48@DYA245:DHaQBU0`aS0a240`aS
0QBU00<@Q0aS36<0112400<DYA2448@0112411BU0a2411BU00<HaQBU5:D0
112400<<HaBU48@01Q241@aS0Q240QBU0Q2400<<Ha2448@010aS0Q240PaS
00@DYAcW6<HDY@8<H`0348@DYABU008<H`046<HLiaBU248212401@Q21244
8@@Q00007`@Q10Q20PaS00h@Q1S67>LYBS6<AS5:DU:DF]I>Ld8@;F/LiaS6
0Q2400<8@P@Q48@00QcW00<DY@@Q12401@@Q00H8@P@Q12448@Q212422480
0`@Q2488@P0236<248@00`aS24848@06248236<224800`@Q24848@021243
248010@Q24848@Q20P@Q00<8@P@Q12400P@Q0PQ20`@Q00@8@P@Q12448@88
@PP48@0324848@@Q00@8@P0436<@Q1246<H27>L0148@CW=cW7Nm0W>L00M[
FVmkMkeoog_N>LhDY@0612401@0012448@@Q00001`@Q00<8@P@Q12400`@Q
10Q200L48@Q224848@Q236<8@P02124524800`aS2488@P03248536<32483
36<00`Q236<8@P0336<324800`aS248<H`0336<0112436<8@PQ20`aS10Q2
0PaS0PQ20PaS1@Q20PaS0`Q210aS00@8@P@Q248<H`8@Q005248<H`aS36<@
Q00436<01A2436<<H`aS24800`aS00<@Q0aS36<01@aS00<@Q0aS36<01PaS
00<@Q0aS24800`aS0PQ21@aS0PQ20`aS10Q20PaS1@Q20`aS00@8@PaS36<@
Q0@<H`03248<H`aS00X<H`0348@<H`Q20088@P8<H`05248<H`aS36<8@P04
36<01@Q236<<H`aS24800`aS0`Q200L<Ha2436<<H`Q236<@Q00336<01124
2488@PaS0Q240PQ200@<Ha2448@<H`88@P<<H`88@P8<H`03248<H`aS008<
H`88@P@<H`05248<H`Q236<8@P0336<00`Q236<<H`0336<2248136<00003
00048@0000<48@0300048@@Q00<48@065:DLia24248@Q1BU0PaS00<@Q1BU
5:D00a240PaS1Q2400@<Ha2448@@Q08<H`0848@DYA245:D@Q1BU48@DY@<@
Q00336<@Q12400@@Q00336<@Q0aS008@Q0055:D@Q1245:D@Q00336<00a24
5:DDY@0336<00a2436<@Q00348@236<010Q236<@Q1241`aS00<@Q0aS48@0
1Q2410aS00<@Q1BU5:D00QBU00D@Q0aS36<@Q1BU00@@Q0035:D@Q12400<@
Q0DDY@0548@HaQS66<HDY@0248@00aBU48@@Q00248@010aS48@DYABU0Q24
0PaS00D@Q0aS36<8@PaS008@Q0066<H@Q12448@<Ha240PaS00<@Q0aS48@0
10aS0Q2400@HaQBU6<HLi`8DY@0;48@<H`aS5:DLiaS648@48@Q21248@P0;
12400`001248@P0<12422484124224800`@Q2488@P0536<01a245:DDYAcW
8@PU:BU:008Li`035:D<H`aS008<H`88@P031248@PQ200<8@PH48@042484
8@@Q124224800`@Q2488@P04248236<00`Q236<<H`02248236<01a2436<4
8@@Q24848@Q200@48@88@P<48@030008@PQ200/48@0324848@0000<48@<8
@P<48@0324848@Q200848@88@P0548@8@PaS48@HaP027>L01Be[>LiF]EJe
IcT00V]J00]cW6]JG_M:DSF];F/@Q0aS24848@aS0088@P@48@0300048@00
00848@<8@P<48@0324848@Q200<48@0324848@Q20088@P848@0324848@@Q
0088@P0336<8@PQ20088@P8<H`0348@<H`aS008<H`05248<H`Q236<8@P05
36<3248336<00`Q236<<H`0236<2248436<2248236<4248236<2248010aS
248<H`Q20`aS0PQ210aS00<8@PaS36<010aS00<@Q0aS36<00PQ20PaS00@@
Q0aS2488@PT<H`07248<H`aS48@<H`Q236<00Q240PaS00<8@PaS36<00PaS
0PQ20`aS00L8@PaS36<<H`Q236<8@P0336<01`Q236<8@PQ236<8@PaS00@8
@PL<H`0448@<H`Q2248536<00`Q236<<H`0936<324800`aS48@8@P022482
48@2248336<01PQ236<<H`Q236<8@PT<H`05248<H`aS36<8@P0336<22480
10aS48@@Q0aS0PQ20`aS0PQ210aS00D48@Q248@@Q0aS0088@P0336<8@PaS
008<H`03248<H`aS0088@P0336<8@PQ200L<H`48@P001@@Q00@000@Q1240
00<48@0436<LiaBU36<848@01ABU48@@Q12436<00a240PaS00@@Q1BU48@@
Q08<H`8@Q08<H`0448@DYABU5:D348@011BU48@<Ha240QBU0Q2400<<Ha24
36<00Q240QBU0a240`aS0aBU00<<Ha2436<00`aS00<@Q0aS36<00`aS00@8
@PaS48@@Q0<<H`<@Q08<H`8@Q0036<H@Q1BU008@Q0<<H`<@Q0035:DHaQ24
008<H`8@Q08<H`0548@DYA2448@DY@0248@00aBU48@@Q00248@011BU6<HH
aQBU1A2400`<Ha2448@@Q1BU48@<Ha2436<@Q0aS48@536<548@00aBU48@<
H`0236<448@00`aS248<H`0248@36<H45:D236<011BU7>LLia241`@Q00<0
00@Q12400P@Q00<000@Q12400P@Q00<000Q2124020@Q00<8@P@Q12401`@Q
00L8@P@Q36<8@PaS248<H`025:D011S65:DLiacW0RU:00DQ21cW5:D@Q0aS
00H8@P031248@PQ200<8@P848@0324848@@Q00@48@<8@P041248@P@Q2483
36<424800`@Q2488@P0236<224861243248312400`Q212448@02248=1242
248412400`Q21248@P021243248436<051247>LLiacW:DXaS5:DF]IS66mk
JeYcW6]JF]I6<CF];F/HaPaS1244248<12401@Q212448@@Q24800P@Q00@8
@PaS124000848@88@P848@88@P8<H`<8@P041248@PaS48@236<010Q236<<
H`aS1PQ20PaS1@Q21@aS00@8@PaS36<<H`@8@P0548@<H`Q2248<H`022483
36<010Q236<<Ha240PQ210aS0`Q21PaS00<8@PaS48@00Q2400<8@PaS36<0
0PaS00<8@PaS36<00PaS00<8@PaS36<01`aS0Q240PaS00<@Q0aS36<00PaS
00@8@PaS36<@Q0L<H`<8@P<<H`<8@P0348@<H`Q20088@P8<H`<8@P<<H`88
@P@<H`0348@<H`aS00L<H`03248<H`aS00H<H`03248<H`aS008<H`88@P8<
H`88@P8<H`<8@P0348@<H`Q200<8@P8<H`04248<H`@Q248236<02@Q236<@
Q1BU48@<H`Q236<8@P0336<00a2436<<H`0236<00`Q236<8@P0436<010Q2
36<<H`aS0`Q20`aS00L@Q0aS2488@PaS48@<H`02248010aS48@@Q0Q20`aS
00<8@PaS36<00@Q200001@0012448@@Q00001@@Q00L000@Q36<HaQBU48@<
H`0248@01ABU36<<H`aS5:D0112400@DYA2436<@Q08DY@066<H@Q12436<@
Q1BU0a2400DDYA245:DHaQ2400<<H`035:D@Q12400D<H`8@Q08DY@<@Q0<D
Y@0548@<HaBU48@DY@0236<248@236<348@636<00a2436<<H`0236<248@0
0`aS48@@Q00248@00`aS48@@Q00448@00`aS48@@Q00348@011BU48@<Ha24
0PaS0Q240PaS0Q2400<HaQBU48@01A2400DDYA245:DDYA2400<DY@0748@<
H`aS48@DYA245:D00Q2400@<Ha2436<@Q08<H`03248@Q124008DY@8@Q0D<
H`<@Q00536<@Q12448@DY@0348@011BU6<HHaQS60Q2400<DYA2448@00QS6
00<DY@Q212400`@Q0PQ200<48@0012405P@Q0PQ20`@Q00P8@P@Q124@Q1S6
7>L@Q0Q20PaS112410aS1`Q200<48@Q212400`Q20`@Q00<8@P@Q12400P@Q
0PQ210@Q0PQ200L<H`Q22488@PaS24848@0236<25:D236<2248412442483
124010Q212448@Q20P@Q00<8@P@Q12400PQ220@Q00D8@P@Q12448@Q200@4
8@88@P848@0336<8@Q24008Li`0448@<H`aS5:D27>L2:DX01cg_AS5:DTYB
>Lh]Jb48008DY@8<H`03248<H`Q200<48@0524848@@Q1248@P0312401@Q2
36<48@0012400PQ20P@Q00<000@Q12400PQ210@Q00D8@P@Q1248@P@Q00<8
@P051248@PaS36<8@P0536<2248336<010Q236<<H`aS0PQ20PaS0PQ21`aS
0`Q220aS0PQ200<<H`Q236<00PaS00<8@PaS24800Q240PQ20PaS00@@Q0Q2
36<8@P8@Q08<H`08248<H`aS36<@Q0Q236<8@P@<H`88@PD<H`0448@<H`aS
36<248@336<030Q236<<Ha2436<@Q0aS248<H`Q236<@Q0<<H`03248<H`Q2
0088@P0336<@Q0aS00<<H`88@P<<H`88@P0636<@Q0aS36<8@PaS0PQ200H<
Ha2448@<H`Q248@236<00`Q236<@Q00836<00a2436<<H`0336<010Q236<@
Q1241@aS00<8@PaS24800PaS00@8@PaS36<@Q08<H`03248<H`aS008@Q0P<
H`08248<H`aS36<8@PaS248<H`88@P0436<@Q12448@224802@aS248<H`aS
248<H`Q236<8@P0936<3248010aS48@<H`aS0PQ200@<Ha2436<<H`48@P00
0P@Q00<000@Q124010@Q00L000@Q124<HacW5:D<H`0548@00aBU48@@Q002
48@00aBU6<H@Q00236<01Q246<HDYA2436<@Q08<H`0448@DYA2448@25:D0
11S65:D<H`aS0Q240QBU1Q2400P<Ha2448@@Q1BU48@DYA240QBU0a240QBU
00H@Q0aS36<<Ha2436<248@836<248@010aS48@@Q0aS112400@DYA2436<<
H`<@Q08<H`0948@DYAS65:D@Q0aS48@DY@aS00D@Q00736<@Q1BU6<HDYA24
36<00a2400DDYA245:DDYA2400<DY@@@Q00336<@Q124008@Q00636<@Q124
48@<Ha240PaS0Q2400<<Ha2448@00a2400@8@PaS48@DY@8<H`<@Q00B36<@
Q1BU5:D@Q1BU6<HLiaBU36<@Q1BU48@DYAS67>L<H`Q21`@Q0PQ200<48@00
12402@@Q00<8@P@Q12400`@Q00<000@Q12401P@Q00T8@P@Q248@Q1S65:D@
Q0Q236<0112400@<Ha2448@@Q088@P0336<8@PQ20088@P031248@P@Q0088
@PD48@0524848@Q21248@P041248248010aS2488@PQ20a2400<<Ha242480
0PQ200<48@Q212400`@Q0PQ210@Q00<8@P@Q12401`@Q00<8@P@Q12400P@Q
00D8@P@Q12448@Q200848@@8@P848@0824848@Q236<DYAcW6<HDY@<<H`8H
aP0:;F/aS3g_AS5244Ha>Lh]Jb485:D348@236<224801@aS2488@P@Q0000
1@@Q00<8@P@Q12401P@Q00@8@P@Q2488@P<48@88@P@48@0336<8@PQ200@8
@P0536<@Q0aS248<H`0248@424801PaS248<H`aS248<H`88@P8<H`03248<
H`aS008<H`88@P8<H`<8@P<<H`88@P<<H`88@P8<H`0448@<H`aS248336<3
248=36<00`Q236<<H`0236<00`Q236<<H`0636<224800`aS48@@Q00236<0
2`Q236<<H`aS248<Ha245:D@Q0aS24802@aS0PQ20PaS00<8@PaS36<00PQ2
0`aS0`Q200D<H`Q2248<H`Q200L<H`03248@Q0aS00<<H`88@P<<H`0448@<
H`aS248236<00a2436<<H`0224800`aS248<H`0248@236<010Q236<<H`Q2
10aS0PQ23PaS00<@Q0aS36<00`Q20`aS00<8@PaS36<00PaS00@8@PaS36<<
H`88@P<<H`04248<H`aS36<2248836<01@@Q36<<HaBU48@01@aS0A240@aS
0@aS0000100012448@000P@Q00<000@Q12400`@Q00D<HacW5:D@Q0aS00@@
Q00736<@Q1BU6<HDYAS65:D00Q2400@<Ha245:DDY@<@Q00336<@Q124008@
Q00536<@Q1BU6<HDY@0348@45:D348@25:D236<00a245:D@Q00548@436<3
48@936<0112436<8@PaS0Q240`aS1A240`aS0a2410aS00<@Q1BU5:D00Q24
00@<Ha2436<@Q08<H`<@Q08<H`0348@DYABU00<@Q0035:D@Q12400<DY@<@
Q08DY@<@Q0035:D@Q124008@Q0036<HDYA2400<<H`8@Q08<H`@@Q08<H`8@
Q08<H`0348@DYA2400D@Q08DY@@HaP<DY@0648@<HaBU6<HDY@aS10Q21`@Q
00<000@Q12400P@Q0PQ22P@Q0`Q20P@Q00<8@P@Q24800PQ20P@Q00L8@QBU
7>L]JbDY5:D@Q00224801A24248<H`Q236<00PQ200<48@Q224800PQ200D4
8@Q236<8@PaS00@8@P061248@P@Q24848@Q20`@Q10Q200<48@Q236<00PQ2
0P@Q00D<H`Q248@@Q0aS0088@P<48@0524848@@Q248<H`0224800`@Q2484
8@02124010Q212448@Q22`@Q0`Q21`@Q00<8@P@Q12400PQ200`48@Q27>La
S4Ha=JdHaQBU248@Q2487>L28@P27>L35:D0112436<8@PaS10Q210@Q00<8
@P@Q000010@Q00@8@P@Q2488@P@48@88@PH48@0424848@Q2124224801`aS
2488@P@Q248<Ha240088@P8<H`88@P0336<8@PQ200H<H`03248<H`aS00<<
H`03248@Q124008<H`88@PD<H`03248<H`Q20088@P8<H`0348@<H`Q20088
@P<<H`04248<H`aS36<224801a2436<<H`aS48@<H`Q2008<H`0348@<H`aS
00P<H`0448@<Ha2448@236<00`Q236<<H`0224800`aS48@<H`0336<248@3
36<00aBU48@@Q00736<00`Q236<<H`0436<01PQ236<8@PaS248<H`88@P8<
H`03248<H`aS008<H`88@PX<H`8@Q0L<H`0348@<H`aS008<H`03248<H`Q2
00P<H`<8@P8<H`0348@<H`aS00H<H`0348@<Ha2400<@Q08<H`88@P8<H`05
48@<H`Q2248<H`0248@010aS48@<Ha240PaS00<@Q0Q236<00`aS0`Q23@aS
00<8@PaS36<00PQ21PaS0@Q2000412401@0012448@@Q00000`@Q00@@Q1S6
48@<H`8DY@8@Q00336<@Q124008DY@0448@DYABU5:D248@00aBU48@DY@02
5:D01A245:DDYA2436<00Q240aBU00XHaQBU36<<Ha246<HDYA2436<@Q08D
Y@0448@DYA245:D348@236<00a245:D@Q00236<348@010aS48@<H`Q21`aS
0Q2400H<H`Q236<@Q1BU48@336<00a245:D@Q00236<248@236<01A2436<<
H`aS48@00QBU00D@Q0aS36<@Q0aS00@@Q08<H`<@Q0035:D@Q124008@Q005
5:D<H`aS36<@Q0045:D248@25:D011245:DHaQBU0Q240QBU00<@Q0aS36<0
0Q240`aS0a2400LDYA2448@@Q0aS48@DY@0348@01@aS48@<H`aS48@00QS6
0aBU00<LiaS66<H00Q2400DDYAS65:D<H`@Q00<8@P<48@0300048@@Q0084
8@0324848@@Q01448@0324848@Q200<48@0724848@Q26<HQ22e[9BT00Q24
00@8@PaS36<<H`P8@P0736<8@P@Q1248@PaS248010@Q00L8@P@Q12448@Q2
1248@P03124224800`@Q2488@P06248236<00`Q2124<H`02248212400`Q2
1248@P0324821240100024848@Q21`@Q0PQ200<000@Q12400`Q20P@Q0`Q2
10@Q00<8@P@Q12400P@Q00d8@P@Q48@Q22e[AS4icQS636<8@Q249BTQ2005
7>L011S65:D<H`aS0`Q200<<H`@Q12401@@Q00D000@Q12448@Q200848@03
24848@Q200@48@0324848@@Q00848@@8@P848@0524848@Q2248<H`032480
112436<8@PQ20`aS1`Q21@aS00@@Q0aS2488@P8<H`06248<H`Q2248<H`Q2
1@aS00<8@PaS248010aS00D8@PaS36<<H`Q2008<H`0648@<H`aS36<8@PaS
0PQ21PaS00<8@PaS48@00PaS00<8@PaS48@00Q2400@<H`Q22488@PD<H`88
@PD<H`0448@<H`aS248236<020Q236<@Q1BU48@8@P@Q36<348@;36<00`Q2
36<<H`0236<2248336<00`Q236<<H`0336<2248236<248@236<00`Q236<@
Q00536<00a2436<<H`0436<00`Q236<<H`0236<248@436<3248936<248@2
36<248@3248236<00`Q236<<H`03248936<01@Q236<<H`aS24800`aS0`Q2
1@aS0PQ22PaS0PQ210aS00000`@Q00048@0212401@0012448@@Q00000P@Q
00@DYAcW5:D8@P8@Q0055:D@Q0aS36<DY@026<H00aBU48@DY@0448@00aS6
48@@Q00548@00aBU48@@Q0045:D248@00`aS48@DY@0:48@00aBU48@@Q002
36<011245:D@Q1240PaS00<@Q0aS48@00PaS00@@Q0aS36<@Q088@PD<H`8@
Q08<H`8@Q0@<H`8@Q0<<H`0448@<H`aS36<248@00aBU48@@Q00348@00`aS
48@@Q00248@35:D248@236<548@35:D01A245:DDYABU48@00QBU00<HaQBU
5:D01A2400<<HaBU5:D00QBU00<@Q0aS48@00a2400P<Ha2448@@Q0aS248@
Q1BU0Q2400@<Ha2448@<H`8@Q08HaP057>LHaQ2448@DY@036<H35:D27>L0
0aBU24848@0212400`Q21248@P0312400`Q212448@0=12401@Q212448@@Q
24800`@Q0PQ200<48@Q212400`Q20PaS00LLib48<H`e[BDY8@P<H`022485
124324800`aS248<H`0336<01PQ21248@PQ21248@P<48@88@P051248@PQ2
24848@0224800`@Q2488@P0536<010Q212448@@Q0`Q200H48@005:DYBR48
36<2124224800`@Q24848@0512400`0012448@0612401`Q212448@@Q2484
8@Q200<48@8<H`0;24848@@Q36<48A24@Q1JeVLi@Q0@Q00236<02`Q26<HL
iaS65:D@Q1BU6<HDYA2436<00PQ200<48@Q2124020@Q00D8@P@Q24848@Q2
00@48@0324848@Q200D48@0324848@@Q00@8@P848@88@P0448@<H`aS2482
36<3248010aS248<H`Q20PaS00@@Q0aS2488@P<<H`88@P0536<8@PaS36<8
@P0236<4248936<00`Q236<8@P0236<00`Q236<<H`0536<00`Q236<<H`03
36<2248236<0112436<<H`Q20PaS0Q240PaS00<@Q0aS36<00PQ20a240PaS
00@8@PaS248<H`88@P8<H`8@Q005248<H`aS36<@Q00236<248@436<01a24
36<<H`Q236<@Q0aS00<8@P8<H`06248<H`Q236<8@Q240PaS0PQ22PaS00D@
Q0aS48@<Ha2400H<H`8@Q0D<H`04248<H`aS36<3248236<00`Q236<<H`03
36<248@336<248@336<448@00`Q236<<H`0436<0112436<<H`Q20a240PQ2
00D<Ha2436<<H`Q200@<H`88@P0436<8@PQ2248236<00a2436<<H`0436<2
248236<2248336<00`Q236<<H`012480000500048@001240000712400`aS
7>L@Q00348@00aBU48@@Q0025:D021S65:DDYABU6<HDY@aS48@35:D00a24
5:D@Q00248@25:D0112436<<Ha240QS600<@Q0aS48@00a2400L<Ha2448@D
YA245:D@Q0025:D02Q245:D<H`Q236<@Q1S65:D@Q0aS0a2400<<Ha245:D0
0PaS00<@Q0aS36<00PQ200D<Ha2448@DYA2400<<H`0348@<H`aS00D<H`<@
Q0@<H`0448@DYA2448@25:D01A2436<@Q1245:D01Q2400H<Ha2448@DYA24
36<248@00aBU48@@Q00948@01ABU48@@Q1245:D00Q2400<<Ha245:D01124
00<<Ha2436<00Q2400<DYA2436<01a2400H<HaBU48@@Q1BU6<H27>L448@0
0aS65:DDY@026<H01AcW6<H@Q0Q212400`Q20P@Q00<8@P@Q12401@@Q00D0
00@Q12448@Q200L48@0500048@@Q1248@P0412400`Q21248@P02248336<0
1QcW8@P]Jbe[7>LHaP<8@P041248@P@Q124324800`aS248<H`0236<22482
12401`Q21248@P@Q24848@Q200848@0524848@@Q248<H`0424800`aS2488
@P0236<010Q212448@Q20P@Q00P8@P@Q12448ABU9BTQ20aS0P@Q0`Q21`@Q
0PQ20P@Q0`Q210@Q00<8@P@Q12401P@Q10Q200T<H`Q248A6<E[FG_LicPQ2
48@00PaS11S60QBU00<HaQBU48@01@Q22P@Q00<8@P@Q124020@Q0PQ20`@Q
0PQ20`@Q0`Q200<48@Q236<00Q2400<8@PaS24800`Q200<<H`Q236<00`Q2
00D<Ha2448@<H`Q200D<H`88@P0336<8@PaS0088@P8<H`88@P0636<8@PaS
36<8@Q240PaS0`Q210aS00<8@PaS24801PaS00@8@PaS2488@PP<H`05248<
H`aS36<@Q00236<2248348@00`aS2488@P0236<01@Q236<8@PaS24800PaS
0Q2400H<H`Q2248<Ha245:D236<010Q236<<Ha240PaS00<@Q0aS36<00PaS
00<@Q0aS24800PaS00@8@PaS2488@P@<H`88@P8<H`0348@<H`aS00D<H`<@
Q00536<8@PaS36<@Q00236<01PQ236<<H`aS48@<H`88@PX<H`0348@<H`Q2
008<H`0448@<H`aS248348@236<010Q248@DYA240PaS0PQ20Q240`aS00<8
@PaS48@03PaS00H8@PaS36<8@PaS248236<0112436<<H`Q20`aS00@@Q0aS
36<8@P8<H`0348@<H`Q20088@P8<H`48@P001P@Q00T000@Q12448@00124@
Q1cW5:D0112400<DYA2448@00Q240QBU00@HaQBU48@<H`8@Q0056<HDYA24
48@DY@0248@25:D0112436<<Ha240QBU0Q2400@<Ha2448@@Q08<H`@@Q003
5:D@Q12400<@Q08<H`<@Q08<H`03248@Q0aS008@Q00336<@Q12400P<H`05
248<Ha245:D@Q00736<020Q236<<Ha2436<8@PaS48@536<748@25:D00a24
5:DDY@0248@011BU48@@Q1240PaS00<DYA245:D00QBU1A240QBU00<@Q1S6
5:D00Q240PaS1Q2411BU00<@Q1BU48@00Q2400<<Ha245:D00PaS00<8@Q24
48@0112400<DYAS66<H00QBU00@@Q1BU5:DDY@<@Q0057>LQ21S65:D48@02
248512400`Q212448@0:1242248@12400`Q21248@P02248736<224801@aS
12448@@Q24800`aS1`Q200<<H`Q212400P@Q00<8@PaS24800P@Q00<8@PaS
24800`@Q10Q20PaS0PQ200L48@Q2248<H`Q21248@P02124010aS2488@PQ2
0P@Q00@8@Q2436<<H`L48@03248<H`Q200<48@0324848@@Q00<8@PL48@D8
@P0:124<H`Q248@aS3W>F]IBU2U:7>L2248336<324801@aS2488@P001240
0`Q210@Q00<000@Q12400PQ200<<H`Q2124010@Q00<8@P@Q12401P@Q1`Q2
0P@Q0PaS00<@Q0aS24801PaS0`Q210aS00<8@PaS24800PaS0`Q20`aS10Q2
0`aS00<8@PaS36<010aS0`Q21@aS00D@Q0aS36<<H`Q200<<H`0548@<H`aS
36<8@P0236<0112436<<H`Q20PaS00L@Q0aS48@<Ha2436<8@P0436<01@Q2
36<<H`aS248010aS0PQ230aS0a240PaS00<@Q0aS36<00`aS00@8@PaS2488
@PD<H`@8@P<<H`0348@<H`aS008<H`8@Q004248<H`aS48@236<248@01@aS
248<H`aS48@01`aS00<8@PaS24801@aS00@8@PaS248<H`8@Q0D<H`03248<
H`aS008<H`D@Q00636<8@PQ2248<Ha240PaS00<8@PaS36<010aS00D@Q0aS
36<<H`Q200P<H`<8@P<<H`<@Q00336<8@PaS0088@P@<H`041248@PaS2483
36<1248000848@0400048@@Q000312401@0012448A247>L00Q2400DHaQBU
48@<Ha2400TDY@8<H`085:D@Q1BU5:D@Q1BU48@DY@@@Q0<DY@0348@<H`aS
008DY@0848@<H`aS48@DYA245:D@Q08DY@0348@<H`aS00H@Q0<<H`0648@D
YA2448@DYA240PaS00<8@Q2436<00PaS0Q240PaS0a240PaS00<@Q0aS36<0
0`aS00D@Q0aS36<<H`Q2008<H`H@Q0035:D@Q124008<H`D@Q08DY@P@Q08D
Y@L@Q0045:DHaQBU5:D348@010aS48@@Q1BU1a2400<DYA245:D00Q2400@<
Ha2436<<H`<@Q0085:D@Q12448@DYA245:DLi`8DY@8@Q0055:D@Q12448@D
Y@027>L011S648@8@PQ20P@Q00<8@P@Q12400`@Q00<8@P@Q000020@Q00<8
@P@Q00000P@Q00<8@P@Q12400`@Q00<8@P@Q24800`@Q00<8@P@Q24800P@Q
0PaS0Q240`Q220@Q00<<H`Q224800PQ200<<H`Q2124010Q20`@Q00<8@P@Q
24800PaS00<8@P@Q248020Q200H<H`@Q24848@00248336<824801@@Q248<
Ha2436<00P@Q00<8@P@Q12400P@Q00@<H`Q22488@P<48@0324848@@Q0084
8@0424848@@Q124324821244248236<01a24=Je245[FE[DQ21cW0088@P@<
H`@8@P051248@PQ21248@P0712401@Q2124<H`Q236<01P@Q0`Q20`@Q00<8
@P@Q24801@Q20P@Q0PQ20Q2400<<H`Q224800PaS0Q2410Q20PaS00@@Q0aS
36<8@PD<H`88@P@<H`88@PD<H`0348@<Ha2400@<H`03248<H`aS00<<H`05
248<H`aS36<@Q00236<00`Q236<<H`0636<248@336<00a2436<<H`0536<0
0a2436<<H`02248436<2248<36<348@236<00a2436<@Q00336<00a2436<<
H`0336<2248010@Q36<<H`Q210aS00<8@PaS36<020aS00<@Q0aS36<00PaS
0Q240PaS0Q2400D<H`Q236<<Ha2400@<H`<8@P8<H`88@P0336<@Q0aS00@<
H`0348@<Ha2400<<H`0348@<H`aS00<@Q00336<8@PaS00@<H`0448@<H`aS
248236<0112436<8@PQ21PaS0Q2400<<H`Q236<00`aS00<8@PaS36<020aS
0PQ200@<Ha2436<<H`@8@P8@Q04<H`48@P0000D000@Q12448@0000<48@0:
00048@@Q124@Q1S65:D<HaBU48@236<45:D011S65:DHaQBU1A2411BU00@@
Q1BU48@DY@8@Q0@DY@0536<@Q0aS36<@Q00236<25:D00aS65:D@Q0025:D3
48@336<00a2436<@Q00248@236<748@436<0112436<<H`Q21Q240`aS00<@
Q0aS24800PaS00<@Q0aS36<00`aS0a2400<DYA2436<00Q240aBU00<@Q0aS
48@01QBU0Q240PaS0Q240QBU112400LDYA2448@<Ha245:D@Q0035:D448@0
0`aS48@@Q00348@011S65:DHaQBU0a2400@<Ha2436<<H`H@Q0035:DHaQBU
008DY@0348@DYA2400L@Q0047>LQ21BU36<21243248@12400`Q212448@06
12401@Q212448@@Q24800`@Q00<8@P@Q124010@Q0`Q20`@Q00<8@P@Q1240
10Q20P@Q00@8@P@Q2488@P848@0524848@@Q1248@P0236<224801@@Q2488
@P@Q24800P@Q0PQ200<<H`Q224800`@Q00<8@PaS24800P@Q1PQ200<48@Q2
12400P@Q0PQ20`@Q00<8@P@Q12400`Q23P@Q00<8@P@Q24800P@Q1@Q200<<
H`Q236<00PaS0Q2400HU:BU:;F/YBQBU36<2124010Q212448@@Q10Q20`@Q
00<8@P@Q124010@Q10Q21@@Q00@000@Q12448@<8@P0300048@@Q00<8@P04
1248@PQ2248248@01@aS1248@PaS48@010aS0`Q200<<H`Q224800PQ200<<
H`Q236<00`aS0`Q21@aS00<8@PaS48@00PaS00@8@PaS36<@Q0D<H`04248<
H`aS248236<0112436<<H`Q210aS00<@Q0Q236<00`aS00@8@PaS36<@Q0<<
H`0448@<H`Q236<248@00`aS248<H`0636<2248436<01@Q236<<H`aS48@0
0PaS0PQ200@@Q0aS36<<H`@@Q0<<H`0348@<H`aS00<8@P8<H`88@P0436<8
@PQ2248236<010Q236<<Ha240`aS00<@Q0aS36<020aS00D@Q0aS36<<Ha24
00H<H`07248<H`Q2248<H`Q236<00Q2410aS00<@Q1BU36<00`aS00<@Q0aS
36<00PaS00@@Q0aS36<@Q08<H`06248<H`aS36<8@PaS0PQ20PaS00<8@PaS
36<00PaS00D8@PaS248<Ha2400@<H`04248<H`aS248<36<010Q236<8@Q24
0PaS00<8@PaS36<010aS00031240100012448@001@@Q00@@Q1cW48@<H`8D
Y@8@Q00536<@Q1BU5:DHaP045:D448@65:D348@25:D348@00aBU48@<H`02
48@236<00a246<HDY@0248@011BU48@@Q0aS0a240PaS00<@Q1BU48@00a24
00@<Ha245:D@Q08<H`03248@Q12400<<H`0348@<Ha2400<<H`8@Q0035:D<
H`aS008<H`0448@<H`aS48@2248236<01A2436<<Ha245:D0112400DDYA24
48@@Q0aS00@@Q0<DY@<@Q0035:D@Q0aS008<H`0348@DYABU00L@Q00536<@
Q1BU5:D@Q00236<25:D00a2436<<H`035:D348@35:D00`aS48@@Q00336<0
0a2436<@Q00248@35:D00a245:DDY@025:D00a245:DDY@0448@01AS67>LD
Y@aS12400PQ200@48@Q21248@P@48@0300048@@Q0088@PH48@0324848@@Q
00H48@0324848@0000848@88@PD48@@8@P031248@P@Q00<48@88@P031248
@P@Q00@8@PH48@/8@P848@<8@P0636<8@P@Q1248@P@Q1@Q200<48@Q22480
10@Q0`Q200@48@Q22488@PP48@0324848@@Q00@48@0324848@Q200848@88
@P051248@P@Q1248@P03124324800`aS248@Q0035:D02248:DXYBRU:48@<
H`Q21244248212432484124010Q212448@@Q0PQ200D<H`@Q12448@Q20084
8@030008@PQ200D48@88@P848@0324848@Q200D8@P<<H`04248<Ha2436<2
248336<00`Q236<<H`0436<224800`aS248<H`02248736<3248736<00`Q2
36<<H`0236<01A2436<<H`aS24801PaS00<8@PaS36<00PaS00<@Q0aS36<0
0PaS00<8@PaS36<00`aS0PQ20PaS00D@Q0aS36<<Ha2400@<H`88@P@<H`03
248<H`aS00<<H`04248<H`aS36<248@00aBU48@@Q00336<00a2436<<H`02
248536<224801PaS48@<H`aS1248@P<<H`@@Q0@<H`8@Q0T<H`035:D@Q0aS
00<8@P0348@<H`aS00D<H`0748@<H`aS36<@Q1BU48@01@aS00<@Q0aS36<0
0PaS00H8@PaS48@@Q0aS248236<00`Q236<8@P0236<00`Q236<<H`0336<0
0`Q236<<H`0436<248@236<01@Q236<8@PaS24801@aS00D8@PaS36<@Q0aS
0088@PD<H`<8@P8<H`48@P0000<48@0012401`@Q00D000@Q5:DLiaS6008<
H`045:D@Q1S65:D248@25:D26<H25:D248@010aS48@<HaBU0QS60QBU0a24
00DDYA2448@@Q0aS008@Q0045:D@Q0aS36<348@00aBU36<@Q0025:D248@0
1QBU6<H@Q12436<DY@8@Q0<<H`0348@DYA2400@@Q08<H`8@Q00536<@Q0aS
48@<H`0448@436<00a2436<<H`0236<248@336<348@336<01Q2436<<H`aS
48@<H`H@Q0045:D@Q12436<248@25:D548@011BU48@@Q1BU0a240PaS0Q24
00DDYAS65:D@Q0aS008@Q0055:D@Q0aS36<@Q0055:D00a2436<@Q0025:D0
0a2436<<H`045:D00a245:D@Q0025:D011S65:D@Q1240aBU00<@Q0aS6<H0
0RDY00<Li`Q224800PQ220@Q00<000@Q12403`@Q00<8@P@Q124020@Q00<8
@P@Q12400PQ20`@Q0PQ200<48@Q2124010Q200<48@Q224800PQ200<48@Q2
12401@@Q0PQ20PaS0PQ200@48@Q22488@P848@0324848@@Q00@8@P041248
@PQ2124236<724800`@Q24848@03124224841242248612400`Q21248@P05
12401`Q212448@Q21248@P@Q00@8@P051248@PQ2248<H`03248336<00`Q2
12448@0224801@@Q2488@P@Q24800`@Q00<8@P@Q12401@@Q00<8@P@Q2480
1P@Q00<000@Q12401@@Q0PQ20P@Q00<8@P@Q248010aS10Q210aS0PQ200@<
H`Q236<8@P<<H`0348@<H`Q20088@P<<H`88@P0736<8@PaS36<@Q0aS2480
0`aS0`Q200<@Q0aS24800PaS00D@Q0aS36<<Ha24008<H`0448@<H`aS2489
36<00a2436<<H`0236<0112436<<H`Q20PaS00D8@PaS36<<H`Q200<<H`04
48@<H`aS36<2248336<00`Q236<<H`0436<0112436<<H`aS0Q240PaS00<8
@PaS48@00Q2410aS00@@Q0aS36<8@P8<H`03248<H`Q200P<H`0748@<Ha24
48@<Ha2436<01A240PaS00T8@Q2436<<Ha245:D@Q0aS248010aS00<8@PaS
48@010aS00@@Q0aS36<<H`8@Q00336<8@PaS008<H`0348@<H`aS00X<H`03
248<H`Q200T<H`04248<H`aS36<3248336<3248?36<2248236<248@136<1
24812480000300048@0000848@0500048@@Q1240000212401Q248@PHaQ24
5:D@Q08DY@0548@DYA2448@DY@026<H248@02QBU48@<H`aS48@DYAS65:DH
aQBU11240QBU112400LDYA245:D@Q1BU48@DY@0248@35:D00a2436<@Q006
48@00aBU36<<H`0236<00aBU48@@Q00648@010aS48@@Q1BU0Q240PaS00<@
Q0aS48@00`aS00<@Q0aS36<010aS00D8@PaS48@@Q1BU00<<H`D@Q00436<@
Q0aS36<<48@25:D00a245:DDY@0448@01ABU36<<H`aS48@00QBU00@@Q1BU
48@<H`<@Q08DY@8<H`8@Q0046<HDYA245:D448@01ABU48@@Q0aS48@011BU
0Q241ABU0Q240QBU00P@Q0aS6<HQ22DY8@P<H`Q21P@Q00L000@Q12448@Q2
1240000=1242248<12400`Q212448@071242248312400`Q236<<H`061242
2482124324800`@Q2488@P02248612422483124324800`@Q2488@P072484
12400`Q21248@P0224800`@Q24848@0212400`Q212448@02124010001244
8@Q21`@Q00L8@PaS2488@P@Q24848@03248236<224801P@Q248<H`aS248<
H`<8@P@48@<8@PL48@0300048@Q200@48@0324848@@Q00L48@0324848@00
00848@0436<8@P@Q124224800`aS248<H`0336<01`Q236<<Ha2436<8@P@Q
00<8@P0336<8@PaS00<<H`04248<H`Q236<2248436<2248010aS2488@PQ2
1PaS00@@Q0aS36<8@P@<H`0348@<H`aS008<H`03248<H`Q200H<H`03248<
H`aS00<@Q0H<H`<8@P0336<@Q0aS00H<H`04248<Ha2436<224803@aS48@<
H`Q236<@Q0Q236<@Q0aS248<H`Q200D<H`0748@DYA2436<8@PaS48@01@aS
0PQ24PaS112400<8@PaS36<00Q240PaS00@8@PaS36<<H`88@P<<H`8@Q003
36<@Q0aS00<<H`0348@<H`aS008@Q0@<H`0348@<Ha2400@<H`03248<H`Q2
0088@PD<H`05248<H`aS36<@Q00336<324800`aS248<H`0336<01PQ236<8
@PQ236<8@PD<H`03248<H`aS00H<H`03248<H`aS008@Q00336<8@PQ20048
@P0010@Q00D000@Q12448@0000<48@0748@Q21BU36<@Q1BU48@00QBU00@@
Q1BU5:DHaP8DY@0348@<Ha24008@Q00436<@Q1BU6<H35:D248@00aBU36<@
Q00348@236<248@011BU48@<H`aS0Q2400<<Ha245:D00Q2400<<Ha245:D0
0QBU00<@Q0aS36<00Q2400<<Ha2448@00Q2400<<Ha2448@00`aS112400@<
Ha2448@@Q08<H`0348@DYA2400D@Q0<<H`8@Q003248<H`aS00<@Q08<H`03
48@DYA24008<H`0348@DYA24008<H`<DY@@@Q0045:D@Q1BU5:D26<H25:D0
11245:DDYA240PaS0Q2400<DYA245:D00Q240QBU00DHaQBU48@@Q1BU00@@
Q0<DY@0448@DYABU6<H248@010Q248@@Q1240QBU112400@DYAS66<HHaPDD
Y@0548@DYA2448@DY@027>L011BU2488@PaS1@@Q00<8@P@Q12401@@Q00<0
00@Q124010@Q00H8@P@Q124000@Q248:12400`Q212448@0512400`Q21244
8@0412400`Q212448@0336<00`@Q24848@0224841242248236<224841240
0`Q212448@0212402@Q2000@Q1cW6<H@Q0@Q248<H`0424800`aS2488@P03
12400`Q212448@04124011249BTLi`Q20P@Q0PQ200<48@Q212400`@Q0`Q2
0P@Q10Q200<48@Q212400`@Q0PQ200<48@Q224800`@Q00@8@PaS2488@P8<
H`0324848@@Q008<H`H48@0300048@@Q00P48@0624848@@Q24848@Q21@@Q
00H8@P@Q24848@Q21243248336<010Q236<<Ha240PaS00D8@PaS36<<H`Q2
008<H`06248<H`aS48@<H`Q20`aS0`Q20PaS0`Q200<<H`Q236<00`aS0`Q2
00<<Ha2448@01@aS00H@Q0aS36<<H`Q236<248@936<224801`aS48@@Q0aS
248<Ha2400<<H`0348@<H`aS00P<H`0448@<H`Q2248336<00`Q236<<H`02
36<00a2436<<H`0336<248@010aS248<H`aS0a241PaS0PQ20`aS00D48@aS
36<@Q0aS0088@P0348@<H`aS00@<H`<@Q08<H`0548@<H`aS36<8@P0336<0
1A2436<<H`Q236<00Q2400@<H`Q236<@Q0H<H`0448@<H`aS48@636<348@0
0`aS248<H`0336<3248436<2248236<00a2436<<H`0236<00a2436<<H`02
24801Q2436<<H`aS248<H`88@P@<H`88@P0436<@Q0aS248536<00a2436<@
Q00236<2248236<2248000848@0500048@@Q12400005124011248@PDY@aS
0QBU00DHaQBU48@DYA24008DY@036<HDYA2400<@Q00736<@Q0aS48@DYAS6
5:D00Q2400DHaQBU48@@Q1BU008@Q0<<H`045:D@Q1BU48@336<948@01ABU
36<<H`aS48@00`aS00D@Q1BU48@@Q1BU00<@Q08<H`<@Q0<<H`<@Q08DY@8@
Q00336<@Q0aS008<H`0648@<Ha2436<@Q0aS1Q2410aS0Q2400<DYA2448@0
0a2400@DYA2448@@Q08DY@8@Q0045:DHaQS66<H45:D548@01@aS48@@Q1BU
48@00QBU00@HaQ245:D@Q0<DY@0348@<HaBU00<HaP0748@DYABU48@<Ha24
5:D011240QBU0a2400@HaQcW5:D@Q0<DY@<@Q0075:D@Q1S68@PDYA241240
0PQ20`@Q0PQ21`@Q0PQ20`@Q00<8@P@Q24800`@Q00<8@P@Q12400P@Q0PQ2
1`@Q00<8@P@Q12400P@Q00H8@P@Q12448@aS2485124010Q236<<H`Q20P@Q
00<8@P@Q24800P@Q00D8@P@Q24848@Q2008<H`<48@0324848@0000848@88
@P848@0448@HaR4848@224800a2436<8@P03248010aS1248@P@Q0PQ20P@Q
0PQ200H000@Q5:DQ21cW248212400`Q212448@0612432486124324841245
24821243248010aS2488@P@Q1@Q21`@Q00<8@P@Q124010@Q00<8@P@Q1240
0`@Q0PQ21@@Q00@8@P@Q2488@P<48@03248@Q124008<H`04248<H`aS36<3
248010aS248<H`Q210aS00D@Q0aS36<<Ha24008<H`88@P0336<8@PaS00<8
@P@<H`05248<H`aS36<8@P0936<00a2436<<H`0236<248@536<2248936<0
0a2436<<H`0236<248@236<01PQ236<<Ha2436<@Q08<H`88@PD<H`03248<
H`aS00D<H`0548@<H`aS36<@Q00436<348@010aS48@@Q1BU0PQ200@48@aS
36<<H`88@P0536<@Q12448@8@P0436<348@336<248@236<00a2436<<H`03
36<00a242488@P0236<00a2436<<H`0436<0112436<@Q1241PaS00<8@PaS
48@00a240`aS0PQ21`aS0`Q20`aS00@@Q0aS36<<H`8@Q00436<8@PQ22482
36<2248436<3248736<01@Q236<<H`aS48@010aS00<8@PaS36<00PaS0PQ2
0000100012448@001P@Q00L000@Q36<LiaBU48@DY@0348@45:D00aS65:DD
Y@0248@01ABU48@<H`Q236<00Q2400<DYA2448@00Q2400HDYAS65:DDYA24
36<448@01ABU48@DYA245:D0112400<DYA2448@01A2400<DY@aS36<00PaS
00@@Q0aS48@DY@H@Q08<H`0448@<H`aS36<348@00`aS48@@Q00248@00`aS
48@@Q00236<010Q236<<Ha241@aS00<@Q0aS48@00Q2400<<Ha2436<00PaS
00<@Q1BU48@00Q240PaS1A2400HDYA246<HHaQBU6<H25:D011S648@<H`aS
11240QBU0a240aS600<DYA2448@00a2400/<HaBU6<HDYAS67>LHaQBU48@<
Ha2400@DY@0348@DYA24008DY@0648@DYAcW7>LHaQBU0a2400<DYA2436<0
0QS600@Q21cW48@8@P848@0524848@@Q1248@P0512400`Q212448@0:1240
1@Q212448@0012400PQ21`@Q00@8@P@Q00048@88@P031248@P@Q00<48@03
24848@@Q00848@04248<H`Q236<412400`Q21248@P02124010Q236<<H`Q2
1`@Q0`Q200H<H`Q22488@Q246<H35:D248@536<00`Q212448@0324801P@Q
24848@Q236<8@P<48@<8@P@48@H8@P031248@PQ20088@P031248@P@Q00L8
@P031248@PQ200848@0436<8@PQ22482124010Q2124<H`Q20`@Q00<000Q2
12400P@Q00<000@Q12401@@Q0PQ21@@Q00@8@P@Q24848@<8@P848@042484
8@aS248436<3248010aS248@Q1240PaS00<8@PaS36<00PaS0PQ200LDYAS6
48@8@P@Q248<H`02248936<224801@aS48@@Q0aS24800PaS00L@Q0aS248<
Ha2436<8@P0;36<01PQ236<<Ha2436<@Q0<<H`0448@<Ha2448@336<00a24
36<<H`0736<00`Q236<8@P0=36<00`Q236<<H`0236<00a2436<<H`0336<0
0`Q236<<H`0248@01@aS2488@PaS48@00PaS00D8@PaS36<<H`Q200H<H`8@
Q00436<@Q12436<224801@aS48@<H`aS48@00PaS00L8@PaS36<<H`Q236<@
Q00236<224800a2436<@Q00436<00a24248<H`0336<010Q248@@Q1240PaS
0PQ20PaS00@8@PaS36<8@P@<H`<8@P0936<8@PQ248@DY@aS24848@Q200<<
H`05248<H`Q2248<H`04248336<00`Q236<<H`0536<2248336<00a2436<<
H`0336<1248136<00003124000@Q00<48@0400048@@Q000212401@aS7>LH
aQ245:D00Q241QBU00@HaQBU5:D<H`D@Q0035:D@Q12400@@Q08HaP075:D@
Q0aS36<@Q0aS48@00QBU00D@Q0aS48@@Q1BU008<H`0548@DYA2448@DY@07
48@236<448@25:D348@00`aS48@@Q00648@236<648@336<248@236<01`Q2
36<<H`aS48@<Ha2400<<H`8@Q0<<H`0348@DYABU008<H`L@Q00436<@Q1S6
5:D26<H25:D00a2436<@Q00348@02@aS48@HaQBU48@<Ha245:DHaP065:D0
0a245:D@Q0026<H011cW6<HHaQBU0Q240aBU00@HaQBU48@<H`8@Q0<DY@@H
aP0=5:D@Q1245:D@Q0aS48@LibDY7>L@Q0aS24800P@Q00<8@P@Q12403@@Q
00<8@P@Q12400P@Q00<8@P@Q124010@Q00<8@P@Q12400P@Q00<000@Q2480
10@Q00<8@P@Q12401`@Q0PQ200@48@Q2248<H`88@P848@0324848@@Q00<4
8@8<H`88@PD48@D8@P<<H`0348@<HaBU008HaP8DY@0548@<H`aS248<H`03
248412400`Q21248@P0224801@aS12448@0012400`Q20`@Q00@8@P@Q1244
8@<8@P031248@PQ20088@P848@03248000@Q00<8@P031248@PQ200L8@P84
8@@8@P@48@0300048@@Q00T48@0324848@Q200D48@0424848@Q212472482
36<010Q236<8@PaS0`Q200@<H`Q236<8@PH<H`06248<Ha2448@DYA2410Q2
00L<H`Q236<<Ha2436<8@P0436<00`Q236<@Q00248@?36<01A2436<<H`aS
24801`aS0Q240PaS00<@Q0aS36<02`aS00D8@PaS36<<Ha2400@<H`88@P03
36<@Q0aS00L<H`0348@<H`aS008<H`0348@<H`aS008<H`8@Q0<<H`88@P06
36<@Q0aS248<Ha240PaS00@8@PaS48@@Q08<H`<8@P8<H`045:D@Q0aS2482
36<00a2436<8@P0736<01PQ236<<Ha2436<8@P8<H`8@Q08<H`03248@Q124
008<H`05248<H`aS36<@Q00436<00`Q248@@Q00336<00`Q236<8@P0236<0
0`Q236<8@P0236<00`Q236<<H`0336<0112436<<H`aS1@Q200<<H`Q236<0
0PaS0PQ200<<Ha2436<020aS00<@Q0aS36<010Q20@aS0@Q2000212400`00
1240000712400a249BTLi`0248@236<248@25:D00a245:DDY@0448@00aBU
48@DY@0448@010aS48@@Q1BU0Q240aBU00<@Q0aS36<00QBU00@HaQ2448@<
H`L@Q08<H`D@Q08<H`D@Q0045:D@Q12448@25:D336<248@00`aS48@<H`03
48@00`aS48@@Q00248@336<248@336<348@236<0112436<@Q1240PaS00<@
Q0aS36<00PaS00<DYA2448@00a2400<DYA2436<00Q240QS60aBU11240PaS
00H@Q1BU5:D@Q0Q236<448@011BU6<HLiaBU0Q2400DDYA2448@@Q0aS008D
Y@8HaP055:DHaQcW5:D@Q0025:D548@00aBU48@DY@025:D00aS67>LLi`02
5:D248@02AS65:DHaQBU6<HU:AcW5:D<H`04248212400`Q212448@0B1242
248212400`Q212448@0312400`Q212448@0212401@Q21248@P@Q24801@@Q
00@000@Q12448@88@P<<H`H48@06248<H`aS36<48@Q21P@Q0`Q200L48@Q2
248@Q0Q26<I24002F]H01CF]7>LQ21S65:D00Q2400<<H`Q224800PQ210@Q
00<8@P@Q12400`@Q0`Q20`@Q10Q200D48@Q21248@PaS00<48@<8@P031248
@P@Q00848@<8@P051248@P@Q248<H`022484124236<01`Q21248@P@Q2484
8@0001848@030008@PaS00<<H`848@03248<H`aS00H<H`@8@P8@Q08<H`03
248<Ha24008<H`03248<H`aS008DY@0448@<H`aS36<2248836<00a2436<<
H`0436<00a2436<@Q00536<00`Q236<<H`0236<00`Q236<<H`0348@336<0
112436<<H`Q22@aS00<@Q0aS36<01PaS0`Q21`aS00D@Q0aS36<<H`Q2008<
H`0348@<H`aS00<8@P0348@<H`aS00D<H`<@Q0L<H`8@Q0@<H`0348@<H`aS
00T<H`0448@<H`Q236<2248836<010Q236<<Ha240PaS00<8@PaS48@00Q24
0`aS00@8@PaS48@<H`<8@P<@Q00436<8@PaS48@336<010Q236<<H`aS0`Q2
0PaS00<@Q0aS248010aS00@8@PaS36<<H`@8@P@<H`05248<H`aS36<48@02
2480212436<<H`Q236<8@PaS248236<00`Q236<<H`0336<3248000030004
8@@Q00848@0400048@@Q000312400`aS8@PLi`0248@00`aS48@@Q00248@0
0aBU6<HDY@0348@236<448@01PaS48@DYA2436<@Q0<DY@0448@HaQBU48@2
36<45:D248@00aBU48@<H`0448@236<00a2436<@Q0025:D548@00aBU48@<
H`0248@00aBU48@@Q00548@336<248@236<02A2436<DY@aS48@<Ha2436<8
@P0236<00a2436<<H`0248@836<448@01PaS248<H`aS48@DY@D@Q00>6<H@
Q1S66<HDYA2436<@Q1BU48@<Ha245:D@Q08<H`0348@DYA24008DY@<HaP04
5:D@Q1245:D26<H348@00aBU7>LLi`026<H00aBU48@@Q00248@25:D248@2
5:D26<H00aBU6<HLi`026<H25:D011245:D@Q1BU0Q2400HHaRDY8@PHaPQ2
124224841242248312400`Q212448@07124224881242248412400`Q21248
@P0312400`0012448@08124010Q2124<H`Q20`aS00P48@Q212448@Q21248
@PaS0PQ20P@Q00<8@P@Q12400P@Q0PQ200P48@Q236<<Ha2436<Lid8@0U[F
00DaS1cW8@PDYAS6008<H`@8@P848@0324848@@Q00<48@0324848@@Q0084
8@04248<H`@Q248212400`Q212448@0224800`aS24848@0212401PQ21248
@PQ21248@P@48@<8@P0436<8@P@Q2484124010Q236<<H`Q220@Q0PQ21@@Q
00<8@P@Q12401P@Q00<8@P@Q24800PaS1@Q20PaS0PQ210aS00<8@PaS36<0
0Q240PaS00D8@PaS36<@Q0aS0088@P0836<@Q1S65:D@Q0aS1248@PD<H`88
@P0648@DY@aS36<8@PaS0Q2400@<Ha2448@8@P@<H`03248<H`aS008@Q0H<
H`03248<H`aS008@Q0<<H`03248<H`aS008@Q0H<H`03248<H`aS008@Q0`<
H`03248<H`aS00D<H`03248<H`aS00<<H`0348@<H`aS008<H`03248<H`Q2
008<H`8@Q0<<H`03248<H`aS00<<H`0348@<H`aS00H<H`88@P0336<@Q124
00<<H`88@P@<H`04248<H`aS48@536<0112436<<H`aS0Q2400<<Ha2436<0
0`aS00D8@PaS36<<Ha24008<H`04248<H`aS48@336<4248336<2248236<0
0a2436<<H`0236<4248236<00`Q236<8@P03248:36<010Q236<8@PaS10Q2
10aS0`Q20@aS0@Q200000`@Q00048@0612401P0012448ABU8@PDY@H@Q0<D
Y@8@Q00836<@Q12436<@Q1S65:D@Q08<H`D@Q0045:D@Q1BU5:D448@45:D3
48@01ABU48@DYABU48@00`aS1A2400@DYA2448@@Q08<H`0548@DYAS65:D<
H`0248@236<348@236<248@336<248@01@aS48@<H`aS24800PaS0a240`aS
00<DYA2448@00Q240PaS00@@Q1BU48@@Q08<H`0548@DYABU48@<H`0448@0
0`aS48@@Q0035:D348@336<248@00aBU48@DY@0236<01A245:DHaQS65:D0
0aS60QBU1a240QBU00@HaQcW7>LHaP<DY@<@Q08DY@8@Q0035:DHaQS600<D
Y@048@PU:BDY7>L36<H011BU6<H@Q1cW0Re[00<HaPQ212400PQ200@000@Q
2488@PX48@0324848@@Q00848@0324848@@Q00T48@0300048@@Q00848@04
24848@Q22488124424800`@Q2488@P03248412401`Q236<<H`Q236<48@Q2
00848@<8@P848@88@P0@36<@Q1BU48@YBSg_DYANmeJeF]IF]DHa>LhQ21cW
36<224801PaS5:D<H`Q21248@P@48@0424848@001243248312400`Q21244
8@0224800`@Q24848@0312401PQ212448@Q21248@P848@0324848@@Q0088
@P8<H`031248@P@Q00848@0400048@Q236<224800`@Q24848@0812400`Q2
1240000412400`Q212448@0212401PQ25:DDYA2436<48@<<H`<8@P<<H`03
248<Ha24008@Q0X<H`8@Q00836<@Q1BU48@<H`Q236<@Q0<<H`<@Q0<<H`03
48@<H`Q20088@P@<H`88@PH<H`0548@<H`aS48@<H`0248@336<00`Q236<<
H`0636<348@00`Q236<<H`0248@:36<01@Q236<@Q0aS48@00`aS0Q2400<<
H`Q224801@aS0Q240`aS0a2400@8@PaS2488@P8<H`0348@<H`aS00D<H`88
@P0436<@Q0aS36<2248236<00a2436<<H`0736<224800`aS248<H`0236<0
0a2436<<H`0636<00`Q236<<H`0436<224801@aS48@@Q0aS48@00PaS0PQ2
10aS0PQ200@<Ha2436<8@P<<H`88@P0536<@Q0aS36<8@P0536<3248336<2
48@236<00`Q236<<H`0336<00`Q236<8@P0736<00`Q236<<H`0536<12480
00848@0500048@0012400005124011248@PLi`aS0Q2400D<HaBU48@DYAS6
00X@Q00336<@Q124008@Q00336<@Q12400<DY@H@Q08HaP8DY@0348@DYA24
008@Q08DY@0436<8@PaS48@236<01A245:D@Q12436<01Q240QBU00<@Q0aS
36<00a2400<DYA2448@021240PaS00P@Q0aS36<8@PaS48@DYA240PaS1124
00DDYA2436<@Q0aS00@@Q0045:D@Q12436<548@236<00a245:D@Q00548@2
36<348@25:D01Q2436<@Q1246<HLi`DHaP8DY@@@Q0055:D@Q1BU5:DHaP02
7>L00aS65:D@Q0025:D00a245:DDY@025:D00a245:DHaP0348@01QS68@PQ
22487>LDY@<HaP085:DHaQcW9BTQ21S636<48@<8@P07124000@Q1248@P@Q
000010@Q0PQ210@Q00<8@P@Q124010@Q00<8@P@Q12400`@Q00<8@P@Q2480
4P@Q00D8@P@Q1248@PaS00@48@0336<8@PQ2008<H`88@P041248@PQ22482
12400`Q21248@P0324804Q245:D]Jcg_DYANmeJeF]IBU4Ha>LhLiaS636<8
@PaS248<H`88@PD48@0300048@@Q00@8@P848@88@P081248@PQ224848@Q2
1248@P<48@0524848@Q21248@P0212400`Q212448@03124424800`@Q0004
8@02124524800`@Q24848@0212400`Q212448@0:12401@Q212448@@Q36<0
0Q2400D<H`Q22488@PaS0088@P0436<@Q0aS48@536<010Q248@@Q1240PaS
00<8@PaS24800PaS0Q2400D<Ha2448@<H`Q200<<H`05248<Ha245:D@Q005
36<00`Q236<8@P0236<0112436<<H`aS0PQ200<<H`Q236<01@aS00<8@PaS
36<040aS00<@Q0aS36<01`aS0Q243PaS00@@Q0aS36<@Q0D<H`0448@<H`aS
248536<010Q236<@Q1241@aS00<8@PaS24800Q241PaS00@8@PaS36<@Q0L<
H`0548@<H`aS36<8@P0536<0112436<<H`Q21@aS00<@Q0aS48@010aS0Q24
00@<H`Q236<8@PD<H`88@P0336<@Q0aS008<H`88@PH<H`03248<H`Q20088
@P@<H`03248<H`aS00<@Q0L<H`03248<H`Q200<<H`<8@P@<H`04248<H`Q2
36<224811240000300048@@Q00L48@0700048A248@PHaQ2436<00Q2400DD
YAS65:D@Q1BU00@@Q0035:D@Q12400<@Q0035:D@Q1BU008@Q08<H`0348@D
YABU00@@Q00336<@Q0aS00P@Q0035:D@Q12400<@Q0<<H`8DY@<@Q0035:D@
Q124008@Q0035:D@Q12400<<H`0448@<H`aS48@336<248@336<248@236<4
48@236<348@01PaS48@DYA2436<@Q08DY@8@Q00736<@Q0aS36<@Q1BU48@0
0PaS00@@Q0aS36<<H`<@Q0035:D@Q0aS008@Q00336<@Q12400@@Q00;36<D
YABU5:D@Q1BU48@DYAS67>LHaP065:D248@35:D248@25:D26<H00aBU48@@
Q00348@011BU48@@Q1240aBU00H@Q1BU7>LHaQBU48@35:D02AS65:DHaRDY
:DXLi`aS248<H`0424800`@Q24848@0812400`Q212448@03124010Q21244
8@@Q0PQ22P@Q00@000@Q1248@P848@0400048@@Q248412400`Q212448@02
12400`Q21248@P0224801P@Q248<H`aS24848@88@P<48@88@P031248@PQ2
0088@P8<H`097>LQ248@F]IW>GNmKg]cW6mk009oo`03DY@icPaS0088@P03
1248@PQ200L48@0400048@@Q1242248212400`Q212448@04124224861243
248212400`001248@P0312432482124224801@@Q00048@@Q24800P@Q00<8
@P@Q24802@@Q00<8@P@Q12401@@Q00D<HaBU5:DDY@aS00@8@P8<H`8@Q08<
H`88@P8<H`0348@DYA24008<H`0348@8@PaS008<H`8@Q0D<H`8@Q08<H`8@
Q00436<8@PaS48@236<00`Q236<@Q00236<00`Q236<<H`0736<00`Q236<@
Q00348@00`aS248<H`0336<01@Q236<<H`aS24801`aS00<8@PaS24801`aS
00@@Q0aS36<<H`8@Q00436<@Q0aS248336<348@224800`aS48@<H`0336<2
48@536<00a2436<8@P0236<0112436<<H`Q20PaS00P8@PaS48@DYA24248<
H`Q21@aS00<@Q0aS36<00PaS0Q241@aS0`Q20`aS00<@Q0aS36<01@aS00<@
Q0aS36<010aS00<@Q0aS36<00PaS00<8@PaS36<00`aS00@8@PaS36<8@P@<
H`03248<Ha2400<<H`0348@<H`Q20088@P@<H`88@P0336<8@PQ200<<H`03
248<H`aS008@Q08<H`88@PH<H`05248<H`Q236<8@P0736<3248136<12480
00@48@0500048@@Q1240000312401A248@PDY@aS5:D01A2400HDYA2448@<
Ha245:D948@436<35:D248@00aBU48@@Q00236<348@25:D01Q2436<@Q1S6
5:D@Q08<H`0848@<H`aS48@DYA2436<@Q0<DY@8<H`0448@DYABU48@236<3
48@02ABU48@@Q12436<@Q1BU48@8@P0636<348@236<011245:D@Q1240QBU
1Q2400L<Ha2436<<Ha245:D@Q00336<25:D236<011245:DDY@aS0Q240PaS
0Q2400<<Ha2448@00a240`aS0a2400DHaQcW7>LHaQBU008@Q0<DY@0448@D
YAS66<H25:D011245:DDYAS60a240QBU0a2400LDYA2448@DYAS65:D@Q003
6<H00aBU48@DY@035:D01Q247>L]Jbe[8@P@Q0<8@PL48@0324848@@Q0084
8@0324848@@Q00848@@8@P/48@0324848@Q200@48@0324848@@Q00h48@88
@P<48@L8@PL48@<8@P8<H`066<HLicg_F]I[FWoo0fmk00AkgWooCW<mk`8<
H`0324848@@Q0088@PX48@0424848@Q22488124224861242248512400`Q2
1248@P02248010@Q2488@PQ21`@Q0`Q23P@Q00D8@P@Q24848@aS00<@Q0l<
H`0348@<H`aS00<<H`0548@<H`aS36<@Q00836<248@336<348@2248020aS
48@@Q0aS248<H`Q236<4248236<01124248<H`Q20Q240PaS00@8@PaS48@@
Q0@<H`8@Q0<<H`88@P0336<@Q12400L<H`03248<H`aS00`<H`8@Q0H<H`88
@PL<H`8@Q08<H`04248<H`aS48@336<2248348@236<010Q236<<Ha2430aS
00D8@PaS36<<H`Q200<<H`0448@8@PQ236<348@336<248@536<324800`aS
48@@Q00836<248@436<248@336<00`Q236<<H`0436<010Q236<8@PaS0`Q2
2`aS00D8@PaS36<@Q0aS00<8@P@<H`<8@PD<H`8@Q048@P0000<000@Q0000
0`@Q00@000@Q124000848@055:DLiaBU248@Q0025:D348@00`aS48@@Q002
6<H35:D011245:DDYABU0a2400H<Ha2448@@Q1BU6<H248@010aS48@DYA24
0PaS00H@Q1S66<HDYA2436<35:D248@336<011245:D@Q1240aBU0Q2400<D
YA2448@01@aS1a2400<<Ha2448@00Q2400<<Ha2448@010aS00<@Q0aS36<0
0PaS0aBU21240PaS0Q240`aS00@@Q0aS36<<H`@@Q00636<@Q12448@<Ha24
0aBU00@<Ha2448@@Q08<H`D@Q0<HaP@DY@036<HDYABU00<@Q0@DY@0648@<
Ha2448@DYAS60aBU00<@Q1BU5:D00Q241aBU11S60Q2400/DYA245:D@Q0aS
5:DU:BU:7>L@Q0@Q0088@P031248@P@Q00H48@0324848@@Q00d48@032484
8@@Q00H48@88@P05124000@Q1248@P03124224801@0012448@@Q24801`@Q
00<8@P@Q24800P@Q00H8@P@Q24848@Q2124424801@@Q2488@PaS24800QcW
00Dmke[FJeYkgWNm00=_N`05LiaoogooAS4Q200312401P0012448@001240
00<48@0700048@@Q1248@P@Q00001@@Q00H000@Q1248@P@Q248412422480
10@Q2488@PQ20`@Q00<8@P@Q12400PQ20P@Q00<8@P@Q12401P@Q00D8@P@Q
12448@Q200L48@0400048@@Q000212401@aS6<HLib485:D00PaS00<8@PaS
36<01@aS0Q240PaS00H8@PaS48@@Q0aS248936<00a2436<<H`0236<248@4
36<00a2436<<H`0236<0112436<@Q0aS0PQ20PaS00<@Q0aS36<00PaS00D@
Q0aS48@<Ha2400<<H`@8@P<@Q0@<H`0348@<H`aS008<H`03248<H`aS00D<
H`88@P0336<8@Q24008@Q00336<8@PQ2008<H`0348@<H`aS008<H`0448@<
H`aS248336<00a2436<<H`0;36<248@236<3248236<01A2436<<Ha2436<0
0Q2400<8@PaS36<01@aS0PQ211240`aS0Q240PaS0PQ200H<H`Q236<<Ha24
248236<348@436<248@00`aS248<H`0248@01@aS248<Ha2436<00PQ200L@
Q0Q2248<Ha246<HDY@0436<01Q2436<8@PaS248@Q0<<H`<8@P0336<@Q0aS
0088@P8<H`03248<H`Q2008<H`03248<H`aS00@<H`88@P@<H`03248<H`aS
00<<H`H8@P001@@Q00<000@Q12400P@Q00D000Q248@Q21BU008<H`0348@D
YA24008@Q00436<@Q1BU6<H45:D00aS65:D@Q0025:D00a2436<<H`0348@0
1ABU6<HDY@aS24800QBU00<@Q0aS36<00Q240aBU00L@Q0aS48@@Q1BU48@<
H`0348@00`aS48@DY@0248@35:D648@00`aS48@<H`0448@00`aS48@@Q002
48@00`aS48@@Q00336<248@00`aS48@@Q00236<01Q245:DDYA2436<@Q08D
Y@0336<@Q1BU00<@Q00336<@Q124008<H`0348@<H`aS00D@Q0055:D@Q1BU
48@<H`0248@011BU48@@Q1240QBU0`aS0Q2400<DYA2448@00QBU00<HaQBU
5:D00aBU00<HaQBU48@00PaS00@@Q1S65:D@Q08DY@<@Q08DY@8@Q0<DY@8@
Q08DY@8@Q08DY@0348@HaQcW008Li`<@Q00436<@Q1246<H29BT00b4836<8
@P0324861242248>12400`0024848@0412400`Q212448@0512400`Q21244
8@0=12401@0012448@Q212400PQ20`@Q0`Q21P@Q00<<H`Q236<00PaS00/L
ib48?NmJeV]JNmicW6mkJeYcW6mk009oo`03?NlQ200000T48@0300048@@Q
00848@0324848@@Q00/48@0324848@@Q00@48@88@P031248@P@Q00<48@04
24848@Q2248312400`Q212448@021242248412400`Q212448@0<12402@Q2
6<HU:AcW48@<Ha2436<8@P0236<00a2436<@Q00248@636<00a24248<H`04
36<00`Q236<<H`0248@236<00a2436<<H`0236<0112436<<H`Q20PaS00<@
Q0aS36<00`aS00@@Q0aS36<<H`88@P8<H`0848@<H`aS48@<Ha2436<8@PX<
H`0348@<H`Q2008<H`88@P@<H`03248<H`aS00L<H`<@Q0L<H`<@Q0@<H`04
48@<H`aS248536<00a2436<8@P0436<00`Q236<<H`0836<0112436<@Q124
0PaS00D8@PaS48@<H`Q200@<H`03248<H`aS00<<H`0348@<Ha2400@<H`04
248<H`aS48@436<00a2436<<H`0336<01A2436<<H`Q236<0112400<8@PaS
36<00PaS10Q200@@Q1S67>LDY@8<H`0348@<H`aS008<H`04248<H`aS2482
36<010Q236<8@PQ20`aS0PQ210aS0PQ200<<H`Q236<020aS00L8@PaS36<8
@PaS248<H`02248336<124811240000400048@@Q000812400aBU8@PHaP02
36<248@02QS648@@Q0aS48@DYA245:D@Q1BU0QS600@DYA245:DDY@8@Q08D
Y@8@Q00=5:DHaQS65:D@Q0aS48@<Ha245:D@Q1BU48@00PaS00<@Q1BU5:D0
11240PaS00<@Q1BU48@00Q240QBU00<@Q0aS48@00Q240`aS0a2410aS0Q24
00<DYA2448@00PaS0Q2400DDY@aS36<8@Q2400@<H`0448@<Ha2448@35:D0
0a245:D@Q00648@00aBU48@<H`0236<00a2436<<H`0248@00aBU48@@Q002
48@00`aS48@<H`045:D236<00a2436<<H`0236<55:D348@01QBU48@DYABU
6<HDY@8@Q00336<DYA2400@@Q0046<HDYABU5:D548@01aBU48@DYABU6<H@
Q1BU008@Q0065:D@Q1cW6<HLiaS60a2400@<Ha245:DHaP8Li`065:D@Q0Q2
36<48@Q20P@Q00@8@P@Q1248@PT48@0424848@@Q124224800`@Q24848@04
1242248412400`Q21248@P0412400`Q212448@0512400`Q212448@021240
10Q212448@@Q10Q210@Q00@8@P@Q124@Q08Q200;48@48@aS6<HDYBDY>LiB
U6<HG_M_N`02Li`01VmkG_MF]C6<9BTDY@8<H`@8@PX48@0300048@@Q00@4
8@0624848@@Q1248@P@Q0PQ21@@Q00HDYAcW6<H<H`@Q000212400`Q21244
8@0412400`Q212448@0612400`Q212448@0512422484124236<01acW;F/]
Jb4836<48@Q2008<H`<@Q003248<H`aS00<@Q00436<@Q0aS36<248@836<2
48@336<248@236<224800`aS48@@Q00436<248@00`aS2488@P0@36<010Q2
36<<Ha240`aS00@8@PaS36<@Q0@<H`03248<H`aS00T<H`04248@Q12448@2
36<01A2436<8@PQ236<00Q240PaS0a240PaS0PQ200<<Ha2448@00PaS00<8
@PaS36<00PaS0Q240PaS00<8@PaS36<00Q240`aS0a240PaS00<8@PaS48@0
0a2410aS00@@Q0aS36<@Q0<<H`04248<Ha2448@236<010Q236<<Ha240`aS
0QBU00<@Q0aS36<01Q241`aS0a2410aS0PQ200PDYAS6;F/aS1cW5:D<H`Q2
20aS00<8@PaS24800PQ210aS00<8@PaS36<00PaS00<8@PaS36<01PaS00<8
@PaS36<00PaS00<8@PaS248010aS00<8@PaS36<00`Q2000212401@001244
8@@Q00000P@Q00H000@Q124@Q2DY7>L236<011245:DDYABU0PaS0Q240QBU
00HHaQBU5:D@Q1BU6<H25:D348@00aBU48@<H`025:D26<H248@01`aS48@D
YA245:D@Q1BU00L@Q0095:D@Q0aS36<@Q1BU48@<HaBU008HaP045:D@Q124
48@236<348@236<448@00`aS48@DY@025:D348@00`aS48@<H`0336<01A24
36<<Ha2436<0112400<<Ha2448@0112400<<Ha245:D00Q240PaS1A2400<<
Ha2448@00aBU00L<Ha2436<@Q1BU48@DY@0248@236<0112436<@Q1240aBU
00<HaQBU5:D00a2400@DYA245:DDY@<@Q08DY@8@Q0035:DHaQBU008@Q004
5:D@Q1BU48@65:D01QS65:D@Q0aS48@HaP<DY@037>LHaQS6008@Q08<H`05
48@DYAS67>LHaP0248@4248412400`Q212448@0712400`Q212448@0<1240
0`Q212448@0812400`Q21248@P0212400`0012448@09124010Q21248@P@Q
0PQ200L48@Q22488@P00124<H`027>L021241248@QS65:D]Jcg_CW<2HaP2
Kg/02G>LKg]JeU:D=Jd]JaBU48@8@P0212401@Q236<8@P@Q00000P@Q00<0
00@Q12403@@Q0PQ21`@Q00@DYAcW6<H<H`X48@0424848@@Q000>12400`Q2
12448@0212402P0036<@Q248<H`YBQcW36<48@Q20PaS00<@Q1BU24800PQ2
00@<HaBU48@@Q0<<H`8@Q08<H`0348@<H`aS008<H`8@Q00336<@Q1BU00<<
H`8@Q00336<8@PaS008@Q0@<H`8@Q0@<H`0<248<H`aS36<8@PaS248<Ha24
36<8@PaS0PQ200@<Ha2436<<H`88@PL<H`8@Q00336<8@PQ200H<H`8@Q0@<
H`055:D@Q0aS48@<H`0248@336<0112436<<H`aS0Q240`aS0Q240PaS00<8
@PaS36<00PaS00<8@PaS36<00PaS00H@Q0aS36<<H`Q248@436<021245:D@
Q0aS248<Ha2436<348@236<424800`aS48@<H`0236<01a2436<<H`Q236<@
Q0aS0088@P0336<@Q0aS008<H`0348@<H`aS008@Q08<H`<@Q0<<H`0348@<
H`aS00P<H`88@P0648@Libe[<H`LiaS60PQ20Q240PaS0PQ20`aS00@8@PaS
36<<H`88@P0336<8@PQ200<<H`03248<H`aS00@<H`07248<H`Q236<@Q0aS
24800PaS00T8@PaS2488@PaS248<H`Q236<00`Q200001@0012448@@Q0000
1`@Q00DDYAcW5:D8@PaS008@Q0035:D@Q0aS008@Q0045:D@Q1BU48@36<H2
5:D021S65:DDYA245:DHaQBU6<H248@00aBU48@DY@0648@45:D248@00aBU
48@DY@0248@336<00a245:DDY@0248@45:D00a2436<@Q00336<00a2436<@
Q00248@236<00aBU48@DY@0248@236<00a2436<<H`0236<448@336<00a24
36<@Q00348@45:D01A2436<<Ha245:D00Q240PaS0a240PaS00@@Q1BU5:D@
Q08<H`<@Q08DY@<@Q0055:D@Q12448@DY@0848@25:D46<H01A245:DHaQBU
6<H00Q240aBU00<HaQBU5:D00QBU00<@Q1S66<H00QBU00<@Q0aS48@00Q24
0aBU00<@Q1BU6<H00QS600DDY@aS48@@Q1S6008@Q0066<HQ22486<H8@PaS
0`Q210@Q0PQ220@Q00<8@P@Q12401@@Q00<8@P@Q24802@@Q00<8@P@Q1240
0`@Q00<8@P@Q248030@Q00<8@P@Q124010@Q00<8@P@Q12400`@Q00P@Q1S6
9BTU:ABU48@<Ha240QS600TU:C6<?Nm:DTHaBU96<Be[:DX00Q240PQ200<<
H`Q224804@@Q00@8@P@Q12448@88@PX48@88@P848@0524848@Q212400002
12400`Q212448@0212400`Q212448@0812400`0012448@05124030Q2124H
aSW>BU8e[@aS000<H`Q236<@Q08<H`8@Q08<H`0348@DYA2400@<H`0348@<
H`aS00@<H`03248<Ha24008@Q08<H`0348@<Ha2400@<H`03248<H`aS00<<
H`06248<H`aS48@<H`Q20`aS0PQ20PaS00<@Q0aS24800PaS00<8@PaS36<0
10Q20a2400D<H`Q2248<Ha2400<<H`88@P0736<@Q0aS36<8@PaS48@00`aS
0a240`aS00<8@PaS36<030aS00D@Q0aS36<<H`Q2008<H`0448@<H`Q236<2
48@00`aS248<H`0636<0112436<<H`aS0Q2400<<H`Q224801PaS00<@Q0aS
36<00`aS0PQ21@aS0Q241`aS0QBU0Q2400@<Ha2448@@Q08<H`0348@<H`aS
00<@Q0<<H`0348@<H`aS00D<H`0:248<H`Q27>L]JbU:8@P<H`Q236<42482
36<4248010aS2488@PQ210aS00@8@PaS48@<H`<8@P0436<8@PaS248536<0
0`Q236<<H`02248010aS248<H`aS0PQ20PaS0@Q2000312400`0012448@02
12401`00124000Q25:DQ21BU008<H`@@Q0035:D@Q1BU00<@Q0<HaP<DY@03
6<HDYABU008@Q0095:DHaQBU48@DYA245:D@Q1BU00@@Q0@DY@0436<@Q124
5:D548@00`aS48@DY@0448@35:D0112436<@Q1240`aS00<@Q0aS48@01A24
00LDYA2448@<Ha245:D@Q00536<448@436<848@00aBU48@<H`0448@00`aS
48@DY@0248@236<00a245:DDY@0236<748@25:D748@00aBU48@DY@025:D2
48@26<H25:D00a245:DDY@025:D348@25:D00aS65:DDY@035:D00aS65:DD
Y@0548@25:D01A245:D@Q1245:D00aS600h@Q0aS48@@Q1S636<@Q1S69BTQ
21S636<@Q0aS0P@Q0PQ20`@Q00<8@P@Q124020@Q00<000@Q12403P@Q00<8
@P@Q12401@@Q00<8@P0012400`@Q0PQ200D000@Q12448@Q200848@030004
8@Q20088@PL48@0448@HaRU:9BT248@236<03AcW6<HU:C6<>Li>LdHaBU92
436<:DXDY@aS0088@P0336<8@PQ20088@Q048@88@P848@03248<H`@Q00L4
8@0324848@Q20088@P`48@0324848@@Q00T48@0324848@@Q00<48@0:2484
8@@Q6<HicTHa=Jd<H`Q236<224800`aS48@<H`0236<348@236<00a2436<@
Q00436<248@436<348@010aS48@<H`aS0a240PaS0Q240PaS0PQ20PaS00L@
Q0aS36<<H`Q236<@Q00236<248@01@Q236<8@PaS48@010aS00H@Q0aS2488
@PaS48@536<00a2436<8@P0336<2248010aS48@<H`Q20Q2410aS00<@Q0aS
36<00`aS00D@Q0aS48@<Ha2400L<H`0848@<H`aS248<Ha2436<8@P8<H`05
48@<H`aS36<@Q00636<00a2436<@Q00248@436<01A242488@PaS24801124
1PaS00<@Q0aS24800PaS0a240`aS00@8@Q245:DDY@D@Q0@<H`8@Q0<<H`@@
Q0X<H`05248Q22e[;F/Li`0224801Q24248<H`aS248<H`8@Q00336<8@PQ2
0088@P0436<8@PaS248236<010Q248@@Q0aS0PQ200<<Ha2436<01@aS00@8
@PaS36<8@P<<H`88@PD<H`88@P0000<48@0012400P@Q00<000@Q124010@Q
00@DYBDY6<H8@P<@Q08DY@8@Q08DY@8HaP8DY@036<HLiaS6008HaP035:D@
Q12400<DY@0748@DYABU6<HDYA245:D00a240QBU0Q2400D<HaBU5:D@Q0aS
00@@Q00336<@Q12400<DY@L@Q0055:D<H`aS48@<H`0248@01@aS48@DYAS6
5:D00Q240PaS0Q2400@DYA2448@<H`8@Q00336<@Q12400<<H`<@Q08<H`03
48@<Ha2400<@Q00536<@Q1BU48@DY@0236<00a2436<@Q00848@00aBU48@@
Q00336<348@00aBU48@@Q0065:D00aS65:D@Q00248@01AS65:DHaQS67>L0
0aS60QBU00@HaQBU5:DDY@<HaP8DY@036<HLiaS6008DY@0336<@Q12400<@
Q08DY@0348@DYABU00<@Q00336<HaQcW008Li`0348@DYABU008@Q0057>LQ
22485:D8@P0236<212401@Q236<8@P@Q00000P@Q0PQ200<48@Q212400P@Q
00<8@P@Q12400`@Q0PQ20`@Q00<000@Q12400`Q220@Q0PQ21P@Q00<8@P@Q
124010@Q00@8@P@Q124000<48@H8@P08124Q23W>=JdLi`00248DY@8@Q08D
Y@086<HLiacW6<HDYA24248<H`<8@P<48@0324848@@Q00`48@0300048@Q2
00D48@0324848@@Q00848@0300048@Q200`48@0424848@@Q248512400`00
12448@0<124020aS48@LiacW5:D@Q0Q236<248@336<01A2436<@Q1245:D0
1Q240`aS00L@Q0aS36<8@PaS5:D@Q00436<00a2436<@Q00248@536<01Q24
36<<H`aS248@Q0@<H`0348@<H`aS00H<H`8@Q00436<@Q0aS248436<01`Q2
36<@Q12436<8@PaS0088@P0836<8@PaS48@<H`Q236<8@P<<H`03248<Ha24
00<@Q00336<@Q0aS00<<H`0348@<H`Q200H<H`<@Q0T<H`0348@<H`aS00<<
H`0348@<H`aS008<H`@@Q08<H`0348@<H`aS008<H`8@Q0<<H`06248<Ha24
48@<H`Q22`aS0Q240`aS00@@Q1BU48@DY@8@Q00336<@Q0aS00@@Q08<H`04
48@<H`Q236<248@224802@aS48@<H`Q236<@Q0aS248<H`035:D436<32480
10aS248<H`Q20`aS0PQ200L<H`Q236<<H`Q236<8@P0336<00`Q236<8@P03
36<00a2436<<H`0336<010Q236<<Ha240`Q200<<H`Q236<00PaS0@Q20002
12400`001240000512401@00248DYBDY5:D00PaS1a2400DDYAS65:D@Q1BU
00<HaP0348@HaQBU008@Q00436<DYABU48@26<H01ABU48@@Q1245:D00a24
0QBU1Q2400@<Ha245:D@Q0<<H`0648@DYABU5:D@Q0aS0a2400<DYA2448@0
112400@<HaBU5:DHaP8DY@8@Q0<<H`8@Q0<<H`@@Q0<<H`<@Q0@<H`8@Q003
5:D@Q124008@Q00436<@Q1245:D248@25:D01A2436<@Q1245:D00Q2400hD
YA2448@@Q0aS48@DYA245:D@Q0aS48@DYA241QBU00LHaQ2448@@Q1BU6<HD
Y@036<H011BU48@@Q1S611BU0QS600<DYA2448@00QS60aBU0Q2400D<Ha24
48@DYA24008DY@0448@<Ha2448@35:D46<H25:D248@01acW8@PHaQ24248@
Q0aS00<48@88@P031248@PQ200848@0300048@@Q00D48@0324848@@Q0084
8@0500048@@Q1248@P0312400`0012448@0I12400`Q212448@0512402@Q2
124001cW>Lhe[B481248@P0248@00aBU6<HHaP046<H248@336<3248D1240
0`Q21248@P02248212400`Q212448@0312400`Q212448@0;12401@Q21244
8@@Q248010@Q00<000@Q12400`@Q00<000@Q12400P@Q0PQ200P<Ha247>LL
iaBU36<8@PaS0Q2400<<H`Q236<00`aS00<DYA2436<00PaS0Q240PaS00@8
@PaS48@@Q0@<H`8@Q08<H`88@P8@Q08DY@T<H`0348@<H`aS00P<H`0548@<
H`aS248<H`0248@536<2248436<00`Q236<@Q00636<010Q236<8@PQ20PaS
00<@Q0aS36<00a240PaS0Q2420aS0Q2400<<Ha2436<011242@aS00@@Q0aS
36<<H`8@Q0<<H`<@Q08<H`0448@<H`aS36<2248536<01A245:D<H`aS2480
20aS0Q240PaS00D8@PaS48@DYA24008<H`8DY@0348@<Ha24008@Q00336<@
Q1BU008@Q00336<@Q0aS00D<H`03248<H`aS0088@P8<H`0648@<H`aS48@D
YA240PaS0PQ210aS00<8@PaS36<00PaS00<8@PaS36<00PQ21@aS00<@Q0aS
24800PQ20`aS0PQ210aS0`Q20`aS0`Q210aS0@Q200000`0012448@031240
0`0012448@0312401A247>LDY@aS5:D00a2400@<Ha245:DDY@8HaP087>LH
aQBU48@DYAS67>LHaPDDY@046<HDYA2448@25:D021S648@@Q1BU6<HDYA24
36<548@236<00a2436<@Q00548@35:D348@01@aS48@DYABU48@00PaS1A24
00<DYAS65:D01A2400D<Ha2448@@Q1BU008@Q00536<@Q1BU5:D@Q00236<2
48@236<00a245:D@Q00348@00`aS48@@Q00248@00aBU48@@Q00448@25:D0
31S648@<H`aS48@DYA2436<@Q1BU48@<H`8@Q0035:D@Q1BU008HaP055:DH
aQBU5:DHaP035:D011245:DDYABU11S600@@Q1BU5:DDY@<HaP035:DHaQBU
00HDY@0648@DYA2448@<HaBU0Q2400<DYAS648@00PaS00L@Q1S65:DHaR48
7>LHaP0248@02aBU48@<HacW:DXU:ABU124<Ha2424800P@Q00<8@P@Q1240
0P@Q00@8@P@Q1248@P@48@0324848@@Q00848@0424848@00248412400`Q2
12448@0712400`Q21248@P03124224831242248312400`Q212448@031240
0`Q21248@P02124020Q236<<H`@Q7>LaS2U:7>L2124336<00a2436<<H`03
36<224800`@Q24848@0512400`0012448@0712401@0012448@@Q00000P@Q
0`Q21`@Q00<8@P@Q12401`@Q00<000@Q12405P@Q0`Q20PaS00H8@PaS36<<
Ha2436<2248536<00a2436<<H`0336<01ABU48@@Q0aS48@00`aS0a240PaS
00P@Q0aS36<8@Q2436<@Q0aS0PQ200@<Ha2436<@Q08<H`04248<H`Q248@3
36<248@=36<248@336<00`Q236<<H`0236<2248236<00a2436<<H`0;36<0
1Q2436<8@PQ236<@Q0D<H`0348@<H`aS008<H`0348@<Ha2400@<H`0348@<
H`aS008<H`0348@<H`aS008<H`<@Q00436<@Q1245:D236<010Q236<<H`aS
0Q2410aS00@@Q0aS248<H`8@Q08<H`0348@<H`aS008<H`8@Q00336<@Q124
008<H`8@Q08<H`0448@DYABU5:D236<00aBU48@DY@0248@010aS48@@Q124
1@aS00<8@PaS36<00PaS00L8@PaS36<<H`Q236<@Q00336<00`Q236<@Q003
36<010Q236<<Ha240PaS0PQ20`aS0`Q200L<H`Q236<<H`Q236<8@P0336<0
0`Q236<<H`0336<00`Q236<8@P0236<00`Q236<<H`0336<00`Q236<<H`02
36<2248000<48@0300048@0000848@0900048@@Q124@Q2485:D<Ha24008D
Y@0448@<Ha2448@26<H00aBU6<HLi`026<H35:D00a245:D@Q00248@01QBU
6<HHaQBU48@<H`8DY@0748@DYAS66<HDY@aS48@00QBU00<@Q0aS36<00Q24
00<DYA2448@00Q2411BU1A2400DDYA2448@@Q0aS00@@Q00736<DYABU6<HD
YA245:D0112400DDY@aS48@@Q1BU00H@Q00336<@Q12400<<H`P@Q0<<H`03
5:D@Q124008@Q00336<@Q124008DY@D@Q00336<@Q124008@Q00336<@Q124
008@Q0035:DHaQBU008Li`036<HDYAS6008DY@<@Q0<DY@036<HLiaBU00<D
Y@8HaP035:DHaQBU008@Q08HaP067>LDYABU5:D@Q1BU1A2400<DYA245:D0
0Q240PaS00<@Q1S65:D00acW00/HaQ2448@DYA2436<Q22U:9BTHaP@Q0088
@P031248@P@Q00D48@0324848@@Q00`48@88@P03124000@Q00`48@030004
8@@Q00`48@0324848@@Q00@48@0624848@@Q24848@Q20PaS00@Q236<:DXD
Y@848@0348@<H`aS00H<H`88@P848@0324848@@Q00/48@0300048@@Q00@4
8@050008@PaS36<8@P0312400`0012448@0312400`0012448@0812402@00
12448@00124000Q21248@P05124010Q212448@000`@Q1@Q20PaS0PQ200@<
Ha2448@<H`<8@P8@Q00A36<8@Q2448@<H`Q236<@Q1BU48@<Ha2436<@Q0aS
248<H`025:D00a24248<H`0248@536<01a2436<<Ha24248<H`Q200H<H`<@
Q0D<H`03248<Ha24008@Q00636<@Q12448@<Ha240PaS00<@Q0aS24800PaS
0PQ20PaS00<@Q0aS36<00PaS00<@Q0aS36<01@aS0Q2410aS0Q240`aS00L@
Q0aS48@@Q0aS48@<H`0248@236<0112436<<H`Q210aS00D@Q0aS48@<Ha24
00d<H`8@Q0L<H`88@P@<H`0348@<H`Q2008<H`055:D@Q0aS36<@Q00436<0
0a245:DHaP0248@00aBU48@@Q00236<348@00`aS48@<H`0<36<01PQ236<<
H`aS48@<H`88@P<<H`0448@<H`Q2248236<00a2436<<H`02248236<00`Q2
1248@P0236<2248236<3248236<010Q236<<H`Q20PaS0Q2400D<H`Q2248<
H`Q200@<H`04248<H`aS36<22480000300048@@Q00H48@0700048@@Q5:DQ
21S636<01A2400@DYA245:DLi`8Q20@HaP8DY@036<HDYA2400<@Q08DY@8@
Q0@DY@0448@DYAS65:D648@236<348@00`aS48@@Q0025:D348@25:D248@0
10aS48@@Q1BU1Q240PaS00@@Q1BU48@@Q08<H`065:D@Q12448@<Ha240aBU
11240QBU0a2400<<Ha2436<00Q2400<DYA2448@00Q240QBU00<@Q0aS36<0
0Q2400@DYA2436<<H`8@Q08DY@<@Q0045:D@Q0aS36<248@25:D348@35:D0
0aS65:DDY@037>L00aBU48@DY@045:D01AcW6<HHaQcW6<H00QBU00@@Q1S6
6<HHaP<DY@037>LDYABU008@Q0035:D@Q124008@Q0035:D@Q12400<<H`<@
Q0<DY@056<HLiacW6<HDY@0248@25:D012487>LHaQBU0PaS0`Q20P@Q0PQ2
10@Q00<8@P@Q124020@Q00<8@P@Q00000`@Q00D8@P@Q12448@0000848@03
24848@@Q00@48@0324848@@Q00848@0324848@@Q00848@0324848@@Q00L4
8@D8@P848@0724848ABU7>LQ21cW48@00`Q20PaS0PQ200<48@Q212400PQ2
20@Q00<8@P@Q12401P@Q00<8@P@Q124010@Q00<8@P@Q124010@Q00<000@Q
12401`@Q00<000@Q124040@Q00<000@Q12400`@Q00D8@PaS36<<Ha24008<
H`88@PD<H`88@P<<H`<@Q00336<@Q0aS008@Q0@<H`<@Q0<<H`8@Q0L<H`<@
Q00436<8@PaS36<324800`aS48@<H`0236<248@336<248@236<448@01PaS
248<H`aS5:D@Q0@<H`<@Q08<H`04248<H`aS36<2248A36<01a2436<<H`aS
48@<H`Q200D<H`8@Q08<H`8@Q08<H`04124<H`aS5:D248@01PaS48@@Q124
36<@Q08<H`0348@<H`aS008<H`0348@<Ha2400@<H`04248<H`aS48@836<4
48@00`aS48@@Q00336<248@01PaS48@DYABU48@<H`<DY@0448@8@PQ236<2
48@536<248@010aS2488@PQ20`aS00H@Q0aS248<H`Q236<2248336<248@0
0`Q236<8@P02248436<3248010aS248<H`aS0`Q22@aS00@8@PaS36<@Q08<
H`05248<H`aS36<8@P0236<010Q236<<H`aS0@@Q00001`@Q00048@@Q0004
8@0000D48@0848@Q21BU36<@Q1BU48@DY@<@Q0095:DLiacW8@PLiaBU6<HD
YAS6008DY@@@Q0045:D@Q12448@45:D248@25:D248@00aBU48@@Q00448@2
36<00a245:D@Q00548@25:D00a2436<@Q0025:D236<011245:D@Q1BU1a24
0PaS0Q240QBU11240QBU0Q2400@<Ha2448@DY@8@Q0<<H`0348@<HaBU008@
Q08<H`0348@DYABU00<@Q00336<@Q12400@@Q0045:D@Q12448@25:D01124
5:D@Q1BU0PaS0Q240QBU00<@Q1BU48@00QS60QBU0QcW00PHaQBU48@DYA24
36<@Q1BU0QcW00<HaQcW6<H01ABU0QS60QBU00PHaQBU36<<Ha246<HDY@aS
1A240PaS00<@Q1BU48@01ABU00@HaQcW6<HHaP@DY@047>LU:AcW5:D42480
1@@Q2488@P@Q24800`@Q00<8@P@Q12403@@Q00<8@P@Q12400`@Q00<8@P@Q
12400`@Q00<000@Q124010@Q00D8@P@Q12448@Q200H48@0524848@@Q1248
@P03124010Q212448@@Q0PQ200P48A247>LU:B4836<8@PaS0P@Q0PQ200@<
H`Q21248@PD48@0300048@@Q00@48@0300048@@Q00848@0300048@@Q00@4
8@<8@PP48@0300048@@Q00@48@0300048@@Q00848@0300048@@Q00P48@05
00048@@Q1248@P041242248236<248@010Q21248@PQ22@aS00L@Q0aS48@<
Ha2436<@Q00636<248@536<248@236<00`Q248@@Q00248@00`aS2488@P02
36<00a2436<8@P0236<00`Q236<<H`0236<248@636<348@336<00a2436<<
H`0248@236<248@736<00`Q236<<H`0236<00a2436<<H`0536<00a2436<8
@P0236<248@636<00a2436<<H`0636<348@636<348@236<00aBU48@<H`02
248236<248@336<01a2436<@Q0aS248<H`Q2008<H`03248<H`aS008@Q007
36<8@PaS48@<Ha2436<00a2400DDYA2448@@Q0aS008@Q0035:D@Q12400@@
Q08<H`0548@<H`aS36<@Q00536<01@Q236<8@PaS24801PaS0PQ20PaS0`Q2
00@<Ha2436<<H`88@P8<H`@8@P<<H`03248<H`aS00<8@P8<H`@8@PX<H`88
@P@<H`05248<H`aS248<H`01248000<48@0300048@@Q00@48@0600048@aS
7>LDYA2411BU00@@Q1BU5:DLi`8Q20049BTQ21cW6<H35:D00a245:DDY@02
5:D01a245:D@Q1BU48@DYAS6008DY@0448@DYABU5:D248@011BU48@<H`aS
112400HDYA2448@@Q0aS5:D26<H00aBU48@@Q00648@00`aS48@DY@0348@2
36<00aBU48@@Q00348@01QBU48@@Q0aS5:D@Q0<DY@0348@DYA2400T@Q004
5:D@Q1245:D448@00`aS48@@Q00348@336<011245:D<Ha240QBU00<@Q0aS
48@00a240PaS0Q2400hDYA2448@@Q1BU48@DYA245:D@Q1BU48@DYB480RDY
00DLiaBU5:DHaQBU008HaP037>LHaQcW00<HaP8DY@036<HDYABU00@@Q004
5:DHaQBU48@236<248@01@aS48@@Q1245:D00a2400TDYAS648@DYAcW9BTQ
21BU36<00QBU00P@Q1cW;F/]JacW24848@aS0PQ20`@Q00D8@P@Q12448@Q2
00P48@0324848@@Q00H48@0300048@@Q00d48@0324848@@Q00L48@042484
8@@Q24891244248236<25:D00a2436<8@P0E12400`Q212448@0312400`00
12448@0=12400`0012448@0B12400`Q21240000412400`Q236<<H`022482
36<3248236<00a2436<<H`0336<00`Q236<<H`0436<548@436<01QBU48@@
Q12436<8@P8<H`0448@<H`aS36<248@236<01Q2436<8@PQ236<@Q0<8@P8@
Q08<H`03248<H`aS00<<H`03248<Ha24008@Q08<H`D@Q0H<H`0448@<H`aS
36<248@436<0112436<<H`Q20PaS0Q240`aS00DDY@aS36<8@PaS008@Q003
36<@Q124008<H`<@Q0<<H`0448@<Ha2448@236<00`Q236<<H`0436<01A24
36<<H`aS48@00PaS00<@Q0aS36<00PaS00@@Q0aS36<<H`8@Q00836<8@PaS
36<8@PaS248<H`<@Q00336<8@PaS00<<H`<@Q00336<@Q0aS008<H`@@Q003
5:D@Q1BU00@@Q0H<H`0348@<H`aS00<8@P8<H`03248<H`aS00<<H`0348@<
H`Q200P<H`03248<H`aS008<H`04248<H`Q2248336<2248736<00`Q236<<
H`0336<224801@aS48@<H`aS48@00PaS0PQ200<<H`Q236<010aS00<8@PaS
24800@Q200000`001240000512402P0012448@@Q5:DQ21BU36<@Q1S60QBU
00T@Q1BU5:DHaQcW8@PU:B486<H01QBU112400DDYAS65:D<Ha24008DY@8@
Q08DY@0548@<Ha2448@DY@0448@25:D248@01@aS48@@Q1246<H00QBU1Q24
00@<Ha245:DDY@8@Q00436<@Q1245:D348@01QBU48@DYA245:D@Q0<DY@<@
Q0035:D@Q1BU008@Q0035:D@Q124008@Q08DY@0348@DYA2400D@Q08DY@07
48@<Ha245:D@Q0aS48@00QBU0Q2400TDYA2448@@Q0aS48@DYA245:D00Q24
00<DY@aS48@00PaS11BU0Q240aBU00DLib488@PHaQBU008HaP035:DHaQBU
00<Li`8HaP035:DHaQcW008HaP035:D@Q124008@Q0<DY@0336<@Q124008D
Y@8@Q08DY@0448@<Ha246<H25:D01QS65:DQ22487>LDY@8@Q0086<H@Q248
;F/U:ABU24848@8<H`041248@P@Q248312400`Q212448@0312400`Q21244
8@061242248:12400`Q212448@0;124224851240100012448@Q220@Q0`Q2
0PaS0QBU00<8@P@Q12400`Q200<000@Q12400PQ22@@Q00@000@Q12448@88
@P848@0500048@001248@P0;12401@0012448@@Q00000P@Q00<000@Q1240
20@Q00<000@Q124020@Q00L8@PaS2488@PaS248<H`03248436<00`Q236<<
H`0636<448@636<0212436<@Q0aS48@<H`Q236<448@236<00a2436<@Q005
36<2248436<01@Q236<<H`aS24800`aS00T@Q0aS36<@Q0Q248@<HaBU48@0
0`aS00@@Q0aS36<<H`8@Q0H<H`0348@<H`aS00P<H`0348@<H`aS008<H`8@
Q00436<@Q12448@236<01a2436<@Q1245:D<H`Q2008<H`045:D@Q0aS48@6
36<00a2436<@Q00736<248@636<448@01@aS248<H`aS48@00`aS00<@Q0aS
36<01@aS0a2400DDYA2448@<Ha24008<H`0348@DYABU008@Q0035:DHaQ24
008<H`0448@<Ha2448@336<00a2436<<H`03248636<3248436<02`Q236<@
Q0aS48@8@PaS248<Ha2436<010Q21@aS00@8@PaS248<H`<8@P8<H`03248<
H`Q200`<H`0524848@Q236<8@P0236<1248136<000@48@0300048@000084
8@0800048@@Q48@Q21cW48@DY@8@Q08DY@076<HDYAS68@PU:BU:9BT00QS6
212411BU0Q240aBU0Q2400<DYA2448@01Q2400HDYA2448@@Q1BU6<H35:D0
1A245:D@Q12436<00Q2400<DYA245:D00Q2400@DYA2448@@Q0@DY@D@Q08<
H`045:D@Q1BU5:D548@35:D236<00a245:D@Q00248@01aBU48@@Q1BU6<HD
YA24008<H`<@Q08<H`035:DHaQBU008@Q0045:D@Q12448@25:D348@00aS6
48@@Q00248@01ABU48@@Q1245:D00QS600<DYA2448@00Q2400<DYAS65:D0
0QS60QBU00@HaR488@PHaP8DY@097>LHaQS68@PU:B486<H@Q1S600<@Q08H
aP065:D@Q1BU5:D@Q0aS0Q2400XHaQBU48@@Q1BU36<@Q1BU6<HDY@<HaP8Q
208HaP0548@DYABU5:DHaP027>L011S648@<Ha240PQ200T000@Q12448@00
1248@P@Q24800P@Q00<8@P@Q12400P@Q00@8@P@Q248000d48@0324848@@Q
00848@0324848@@Q00848@88@Ph48@0400048@Q2248312401PQ21248@PQ2
36<8@P848@88@P041248@PQ2248412400`001240000C12400`0012400008
12401@0012448@@Q00001@@Q00<000@Q124020@Q00H8@P@Q12448@Q236<5
248010aS2488@PQ20a240PaS00<DY@aS36<00`aS0Q2400<<Ha2448@010aS
0Q240`aS0a240PaS00D@Q0aS36<<H`Q2008<H`<@Q0@8@P0736<@Q0aS36<8
@PaS48@02@aS00<8@PaS36<00Q2400<8@PaS36<00PaS0Q2400<DYA2448@0
0PaS0a241@aS0a240`aS00<@Q0aS48@00Q2400<<H`Q236<00Q2400<<Ha24
5:D00PaS0PQ20a241`aS00@8@PaS36<@Q0D<H`03248<H`aS00<@Q0<<H`03
48@<H`aS00<<H`0348@<H`aS00d<H`8@Q08<H`03248<Ha24008<H`/@Q08D
Y@8<H`0348@DYA24008<H`0348@<H`aS00@<H`04248<H`aS248436<01A24
36<<Ha2436<010Q20`aS00<@Q0aS36<00PaS0`Q210aS00<8@PaS36<00`aS
00<8@PaS24800PaS0PQ220aS0PQ20PaS0PQ20PaS0`Q20PaS00<8@PaS48@0
0@Q2000010@Q00048@0020@Q00DDYB486<H<Ha24008DY@8@Q00:5:D@Q1cW
8@PU:Be[:DXLiaS648@45:D248@011BU48@DYABU112411BU0Q240aBU0Q24
00<<Ha2448@00Q240QBU0a2400DDYAS65:DDY@aS008@Q0035:D@Q124008@
Q08<H`0348@DYA24008@Q0<DY@0548@<Ha2448@DY@0248@00aBU6<HHaP02
5:D248@00`aS48@DY@025:D448@00`aS48@@Q00348@35:D03Q2436<<Ha24
5:D@Q0aS48@DYAS648@DYA245:D248@011BU48@@Q1240aBU00<@Q1BU5:D0
11240QBU00<@Q1BU48@00QBU0a240QS60QcW00<HaQcW7>L00QcW00THaQBU
6<HHaQcW9BTQ21cW6<H00QBU0QS611BU0Q2400@DYA2448@<H`@@Q0055:D@
Q1BU5:D@Q0046<H01AcW8@PLiacW6<H00aBU00L@Q1S68@PQ21cW36<8@P02
36<00`@Q24848@03248712400`Q212448@0212400`Q21248@P0:12400`Q2
1248@P0B12400`0012448@0:1248248212400`Q236<48@0212400`Q236<4
8@081240100012448@002`@Q00<000@Q124010@Q00@000@Q1248@PX48@03
00048@@Q00X48@0624848@Q21248@P@Q1PQ200@48@aS36<DY@8@Q0H<H`04
48@<H`aS48@436<648@00`aS48@<H`0348@00`aS248<H`0248@236<00a24
36<<H`0336<01@Q236<@Q0aS48@00`aS00@@Q0aS36<<H`88@P0336<@Q0aS
008<H`03248@Q0aS008@Q08<H`8@Q08<H`@@Q00336<8@PaS00H<H`0448@<
H`aS248336<248@536<348@010aS48@<Ha241`aS00D@Q0aS48@<Ha2400@<
H`8@Q0@<H`8@Q0<<H`0648@<H`aS48@<H`Q20PaS0Q2400<<Ha2448@01@aS
00<8@PaS36<00a2400<8@PaS36<00Q2400H<H`Q236<<Ha245:D548@01`aS
48@@Q1245:D@Q1BU00H@Q08<H`8@Q0@<H`03248<H`aS00<<H`0348@<H`aS
008<H`0448@<H`aS248236<00`Q236<@Q00536<01A2436<<H`aS24801@aS
0PQ200D<H`Q236<<H`Q200<<H`04248<H`aS248248@236<010Q236<8@PQ2
1@aS00<8@PaS36<00`aS0@Q200000`0012448@0212400`0012448@041240
0a248@PHaP0348@00aBU6<HHaP035:D01R489BT]JbDY7>LHaP@DY@@@Q003
5:D@Q0aS008@Q0PDY@0448@DYA245:D348@25:D548@45:D00a2436<@Q002
5:D00a2436<<H`025:D00aS648@@Q00236<01Q245:D@Q0aS248@Q08DY@03
36<@Q12400<DY@0348@<HaBU00<@Q00436<@Q1BU5:D236<021246<H@Q124
5:DLiaS648@236<248@01ABU48@@Q1245:D00a2400@DYA2436<<H`D@Q003
5:D@Q1BU008DY@<@Q08DY@<@Q0046<HDYABU5:D348@00aBU48@DY@0248@3
5:D26<H00acW8@PLi`026<H25:D47>L01QBU48@DYAS67>LDY@8@Q0035:D@
Q124008@Q08DY@<@Q00436<@Q1BU5:D348@00aBU6<HHaP027>L011S67>LD
YABU0QS600LQ236<<H`U:A24124<H`02248212400`Q212448@02248A1240
0`Q212448@0H12400`Q212448@091242248312400`Q212448@0412400`00
24848@051240100012448@001@@Q00D000@Q12448@0000@48@0300048@@Q
00<48@0500048@@Q1240000912400`0012448@0212400`0012448@081249
248236<011245:D@Q1240`Q210aS00D8@PaS36<<Ha2400<<H`0848@8@Q24
5:DLiaBU36<8@P8@Q08<H`8@Q0@<H`04248<H`aS248236<00a2436<8@P02
24800`aS48@<H`0436<01A2436<<H`aS24801`aS00<@Q0aS36<00a2400H<
Ha2436<@Q0aS48@436<00a242488@P0236<00a2436<<H`0336<01Q2436<<
H`aS5:D@Q0<<H`0448@<Ha2448@236<00`Q236<<H`0236<00`Q236<<H`02
48@010Q236<@Q1241PaS00D8@PaS36<<Ha24008<H`0648@<H`aS48@<Ha24
1@aS00L@Q0aS36<<Ha2436<8@P0236<248@436<00`Q236<<H`0336<01PQ2
48@@Q1245:D@Q0<<H`8@Q00736<@Q12448@8@PaS48@00QBU00@@Q0aS36<8
@P@<H`03248<Ha2400<<H`03248@Q0aS00@<H`05248<H`Q236<8@P0536<3
248236<00a2436<<H`0336<424800`aS248<H`02248010aS2488@PQ20PaS
00<8@PaS24800PaS00@8@PaS36<<H`<8@P@<H`03248<H`aS008<H`48@P00
10@Q00<000@Q12400P@Q00/000@Q124@Q2486<H<Ha245:DHaQcW008HaP0:
5:DHaR48:DXU:B486<HLiaS65:D248@01ABU48@@Q1245:D00a2400<DYAS6
5:D00QBU00H@Q1BU5:D@Q1BU48@45:D348@011BU48@@Q1241ABU00L<Ha24
48@@Q1BU6<H@Q00236<35:D0112436<@Q1BU0Q240`aS0Q2400DDYA2448@@
Q1BU008@Q0045:D@Q1BU48@236<00a245:D@Q00236<01A245:D@Q0aS5:D0
0QS600@DYA2448@DY@8@Q0<DY@<@Q0<DY@@@Q0035:DHaQ24008@Q0<DY@@@
Q0<DY@036<H@Q124008@Q08DY@8@Q08DY@0348@DYABU00@HaP077>LQ2248
6<HDYA245:D00acW00@Q21BU5:D@Q0@DY@@@Q08DY@<@Q08DY@0448@<HaBU
6<H25:D011245:DHaQS60R4800@LiaS65:DDY@8HaP068@PaS3F]9BT@Q0Q2
0`aS0PQ210@Q0PQ20P@Q00@8@P@Q12448@88@PD48@0300048@Q200`48@06
24848@@Q124000Q20`@Q00@000@Q1248@PH48@0300048@@Q0088@P@48@03
24848@@Q00@48@88@PD48@0300048@@Q00H48@040008@P@Q000H12400`00
12448@0A12400`Q212448@08248236<548@00`aS2488@P0836<00a2436<<
H`0236<01ABU6<HHaQ2436<00Q2400<DYA2436<00Q241PaS00<8@PaS36<0
0PQ21PaS0Q240PaS00<8@Q2424800PQ200@<Ha2436<8@P8<H`0348@<H`aS
00@<H`8@Q00436<@Q0aS48@736<01A2436<<H`aS24802PaS0a2410aS00L@
Q0aS36<<Ha245:D@Q00436<0112436<@Q12410aS0Q2400D8@PaS36<<Ha24
00@<H`0348@<H`aS008@Q08<H`03248<H`aS008<H`8@Q0X<H`04248<H`aS
36<248@336<348@010aS48@@Q1240`aS00<DYA2448@00a2400HDYA2448@@
Q0aS48@236<00`Q236<<H`0236<010Q236<@Q1241@aS00<8@PaS36<02PaS
0a240`Q200<<H`Q236<00PaS0`Q200<<H`Q2248010aS0PQ20PaS00<8@PaS
36<00`Q21@aS0`Q200@<Ha2436<8@P8<H`48@P0000@48@00124000848@0:
00048@@Q124000Q25:DU:AS636<348@00aS65:DHaP035:D011S68@PLiaBU
0a240QBU00@@Q1BU48@DY@@@Q08DY@0548@DYA245:D@Q0045:D00aS648@D
Y@0448@75:D26<H01A2436<<Ha245:D00a2400<DY@aS48@00Q240`aS00<D
YA245:D01a2400<DYAS65:D00Q2400<DYA2448@00a240PaS0a2400<<Ha24
5:D00QS60Q240PaS00D@Q1BU5:DHaQBU008@Q00436<@Q1BU5:D248@010aS
48@DYAS60QBU00H@Q0aS5:DDYAS65:D248@00aBU48@@Q00248@35:D01124
5:DDYABU0Q240aBU0a2411BU0QS60QBU00@HaQBU48@Li`8Q20036<H@Q124
00@HaP<DY@8@Q08<H`8DY@@@Q08DY@0348@DYABU008HaP065:D@Q1S68@PU
:AcW0QBU0acW0RDY00@YBRDY5:D<H`D8@PL48@88@P848@0324848@@Q0084
8@0324848@@Q01848@0324848@@Q00<48@0400048@@Q000312400`Q21244
8@0:12400`Q212448@0;12400`0012448@0312400`001248@P0212401000
12448@Q21@@Q00<000@Q00001@@Q00<8@P@Q12403P@Q00<000@Q248010@Q
00D8@Q2448@@Q0aS00<8@P848@03248<Ha24008@Q0/<H`05248<H`aS36<@
Q00236<00`Q236<@Q0026<H01A2436<8@Q245:D00Q2400@<Ha2448@@Q0H<
H`<8@P8<H`0348@<H`aS00D<H`0348@<H`aS0088@P8<H`03248<Ha2400<@
Q00436<@Q0aS36<348@236<021BU48@@Q0Q236<@Q0aS248236<348@00`aS
248<H`0348@00aBU48@<H`0;36<348@:36<448@236<00a2436<8@P0736<3
48@736<00a2436<<H`0636<248@336<348@436<748@01@aS48@@Q1245:D0
0Q240QBU1Q2400<<Ha2436<00PaS00<@Q0aS24800PaS00@@Q0aS36<<H`8@
Q00336<@Q124008<H`88@P8<H`8@Q08<H`0448@<H`aS248336<5248236<5
248436<3248236<224801@aS248<H`aS48@00`aS00<8@PaS48@00PaS10Q2
00000`0012448@0512402P0012448@@Q48@Q21BU36<DYAS60QBU0QS60aBU
00<Lib487>L00QBU1Q2400@DYA245:DDY@8@Q0035:D@Q124008@Q0HDY@05
48@DYA245:D<H`0448@45:D00a245:DDY@025:D00`aS48@@Q00348@00`aS
48@DY@0348@011BU48@@Q1240PaS00@8@Q245:DDY@<@Q0035:D@Q0aS008@
Q0035:D@Q0aS008@Q00436<@Q1245:D236<00a246<HDY@0648@00`aS5:DD
Y@025:D0112436<<Ha240QBU00<@Q0aS36<00QBU00LHaQBU48@DYA245:D@
Q0025:D00a2436<<H`0348@45:D648@011BU48@@Q1240QBU0Q2400@DYAS6
7>LHaP@DY@@Li`045:D@Q1BU5:D36<H348@25:D348@45:D248@25:D00acW
6<HHaP025:D01acW8@PU:AS648@DYAcW008HaP04:DX]Jbe[8@P236<00`@Q
24848@0812400`Q212448@0512400`Q212448@0212400`0012448@0@1240
0`Q212448@0512401PQ212448@001248@P/48@0324848@@Q00X48@030004
8@@Q00L48@0300048@@Q00X48@0424848@@Q000312400`00124000021240
1PQ212448@001248@Pd48@0436<DYA2436<2124020Q21248@PQ248@DYA24
248436<00`Q236<<H`0;36<00a2436<@Q0025:D01A2436<<HaBU48@00PaS
00<DYA2436<00PaS0a2400<<H`Q236<00PaS0`Q20Q240PaS0PQ20`aS0PQ2
10aS00@8@PaS36<<H`8@Q0<<H`<@Q00436<@Q12448@536<01A2436<<H`aS
48@00PaS00@8@PaS36<@Q0P<H`0348@<H`aS00@<H`05248<Ha2436<8@P0;
36<248@336<00a2436<8@P0236<248@336<548@836<00`Q236<<H`0436<0
112436<<H`Q21`aS0a2400@<Ha2448@<H`@@Q08DY@8@Q00336<@Q124008@
Q0X<H`8@Q0D<H`0348@<H`aS008<H`04248<H`aS36<348@436<0112436<8
@PQ20PaS0PQ200<48@aS36<00PaS00@8@PaS36<<H`<8@PL<H`@8@P8<H`03
248<H`aS008<H`04248<H`aS36<1248000848@0400048@@Q000612402QBU
8@PHaPaS48@DYA246<HDYAS61QBU0Q2400DDYA245:DDYA2400@DY@0336<@
Q1BU008HaP055:D@Q1BU5:D@Q0025:D36<H25:D01@aS48@DYAS65:D00PaS
00DDYAS66<H@Q1BU00`@Q0036<HDYA24008<H`H@Q0095:D@Q12436<@Q1BU
48@<Ha24008DY@D@Q00636<@Q12448@DYA240aBU0a2400<DYA2448@00PaS
00L@Q1BU5:DDYA24248<H`0248@00aBU48@DY@025:D248@00aBU7>LDY@03
48@01ABU48@DYA245:D00Q2400<DYA2448@00Q2400@DYA2448@@Q08DY@L@
Q0<DY@0=48@DYA245:DLiaS67>LU:AcW6<H@Q1BU6<H00QBU00<HaQBU5:D0
11241QBU00D@Q1BU5:DDYAS600@DY@8HaP067>LQ21cW6<HDYAcW0QBU00Da
S3g_=JdQ20Q2008<H`0324848@Q200<8@P/48@0324848@0000/48@032484
8@@Q00<48@0300048@@Q00@48@0424848@001242248312400`0012400009
12400`0012448@05124010Q212448@004@@Q00<000@Q12403P@Q00<000@Q
12400P@Q00<8@P@Q12400`@Q00<000@Q12400P@Q00<8@P@Q12400PaS00Ha
S4Ha;F/DY@@Q000336<448@010aS248<H`aS0Q240`aS00<8@PaS36<00PaS
00<8@PaS36<00`aS0a241@aS00<@Q0aS48@00a240`aS0Q240PaS00D8@PaS
36<8@PaS008@Q088@P0536<@Q0aS36<8@P0636<00`Q236<<H`0248@436<0
112436<<Ha240`aS00<@Q0aS36<02Q2400<<Ha2436<00PaS00DDYA2436<8
@PaS008@Q00536<@Q12448@<H`02248248@00`aS48@<H`02248636<00a24
5:D@Q00236<00`Q236<<H`0236<01A2436<@Q0aS48@00PaS00<8@PaS48@0
0PaS00<8@PaS36<01@aS0Q2400@8@PaS2488@PD<H`0348@<Ha24008@Q003
36<@Q12400<@Q0<<H`0648@<H`aS36<@Q1BU11240`aS0Q241`aS00<@Q0aS
36<00PaS0Q2400@<H`Q22488@PL<H`03248<H`aS00@<H`03248<H`Q200H8
@P@<H`88@P8<H`<8@P0336<@Q0aS008<H`88@PX<H`88@P<<H`48@P0000D4
8@0012448@0000@48@0600048@@Q5:DQ21S60Q240aBU00@HaQBU6<HHaP@D
Y@0848@<Ha246<HDYA2436<@Q0<DY@0348@<HaBU008HaP065:D@Q1245:DH
aQBU0Q2400<HaQcW5:D00PaS00<@Q1S65:D00a2400HDYAS65:DDYA245:D2
48@011BU48@@Q0aS0a2400<DYA2448@00aBU00D@Q0aS48@@Q1BU00<@Q009
5:D@Q12436<@Q0aS48@DYA24008DY@8@Q00336<DYA24008<H`0548@DYABU
48@DY@0448@010aS48@DYA240PaS00DDYAS65:D@Q0aS008@Q0085:D@Q0aS
36<DYAS65:D@Q08DY@8HaP8DY@0348@DYA24008@Q08DY@056<HDYA2436<@
Q0025:D248@25:D348@01QBU48@@Q0aS48@DY@8HaP095:D@Q1BU5:DHaR48
9BTQ21cW008DY@046<H@Q12448@26<H0112436<@Q1BU0Q2400<DYAS648@0
0Q2400<HaQBU48@01QBU00@Lib487>LLi`@HaP055:DaS3W>=JdQ20032480
10@Q24848@Q20P@Q00<8@P@Q12400P@Q00<8@P@Q12400P@Q00<8@P@Q1240
1`@Q00<8@P@Q12400P@Q00D8@P@Q12448@Q201X48@0324848@@Q00d48@03
24848@0000848@0300048@@Q00P48@88@P/48@0300048@@Q00<48@040004
8@@Q00041240100012448@Q21@@Q00H@Q0aS;F]242e[6<H2124336<01124
36<@Q12410aS0Q2400@<H`Q236<8@PP<H`03248<Ha24008@Q00436<8@PQ2
36<348@636<448@00`Q236<<H`0236<00`Q236<<H`0436<00a2436<8@P02
248336<2248010aS48@@Q1240PaS21240`aS00@@Q0aS36<@Q0@<H`8@Q0/<
H`<@Q0D<H`04248<H`aS48@236<00`Q236<<H`0836<00a2436<<H`0336<0
112436<<H`Q20PaS00H@Q0aS36<<Ha2436<248@=36<00a2436<<H`0248@0
0`aS248<H`0336<011245:D@Q1240PaS00D@Q0aS36<8@PaS00<@Q0055:D@
Q12448@8@P0236<011BU48@<H`aS0a2400D8@PaS36<<Ha24008<H`8@Q003
36<8@PQ2008@Q00536<8@PQ2248<H`0248@236<01Q2436<<H`Q236<8@P@<
H`88@P0536<@Q0aS36<8@P0236<00`Q236<8@P0436<00`Q236<8@P0236<0
10Q236<8@PaS0PQ200H<Ha2436<<H`Q236<42480000300048@@Q00<48@03
00048@@Q00<48@045:DU:AS636<55:D011S65:DDYABU0Q240aBU00<@Q1BU
5:D00Q240aBU11241ABU00<HaQBU5:D00Q2400<<HaBU48@00a2400@<Ha24
36<<H`8@Q0@DY@8@Q0045:D@Q1245:D748@00aBU48@DY@025:D236<01@Q2
48@DYA2436<00a240PaS112400<DYA2448@0112400@<Ha245:D@Q08<H`03
48@DYA2400<@Q0035:D@Q0aS008<H`@@Q00536<@Q1BU5:D@Q0035:D01124
5:D@Q1S60Q240aBU00D@Q1BU5:DDYA2400DDY@0348@DYA24008DY@L@Q003
5:D@Q1BU008DY@8@Q0035:DHaQS600<DY@056<HLib487>LHaP045:D26<H0
1aBU6<HDYABU6<HDYA2400HDY@0348@DYA2400<@Q08DY@056<HLiacW8@PL
i`026<H25:D01acW9BTQ21S636<8@PaS00<8@P031248@PQ200@48@88@PP4
8@0524848@@Q1240000212400`Q212448@0812400`0012448@0:12402@Q2
12448@001248@P@Q2480000412400`0012448@0912401`0012448@@Q2484
8@0000h48@0300048@@Q00T48@03248000@Q00<48@0300048@@Q00D48@03
24848@Q2008<H`8DY@0348@DY@Q200<8@P<<H`8@Q0@<H`075:D@Q12436<8
@PaS48@00`aS00H@Q0aS36<<H`Q236<448@25:D01A2436<8@PaS48@01@aS
00@8@PaS36<@Q08<H`0348@<H`aS008<H`0348@<H`aS00@<H`05248<H`aS
36<@Q00;36<248@536<00a2436<<H`0348@00`aS48@@Q00236<448@536<3
48@436<348@01@aS48@<H`aS24802PaS00@@Q0aS36<<H`D@Q0<<H`0648@<
H`Q248@DYA240PaS00<@Q1BU5:D00PaS00@@Q0aS36<@Q0H<H`05248<H`aS
48@<H`0248@010aS48@<H`aS1A240QBU0Q241@aS0Q2400PDYA2448@@Q0aS
48@<Ha2410aS00<DYA2436<00PaS00<@Q0aS36<010aS0a2400H<H`Q236<<
H`Q236<3248236<00a2436<8@P0224800`aS248<H`0236<010Q236<8@PaS
0`Q200@<Ha245:D<H`88@P<<H`D8@P<<H`03248<H`Q200<<H`04248<H`aS
48@236<1248000<48@0300048@0000@48@060008@QS69BTHaPaS1QBU00HH
aQcW6<HDYA245:D348@00aBU48@DY@0648@35:D248@45:D348@00aBU48@D
Y@0648@236<01Q246<HDYABU48@DY@8@Q0<DY@8@Q0<DY@<@Q08DY@8@Q08<
H`8@Q0035:D@Q124008@Q00336<@Q0aS008@Q0035:D@Q124008@Q0085:D@
Q0aS248@Q1BU6<HDY@8@Q0036<HDYABU008DY@8@Q0<<H`<@Q08<H`X@Q0@D
Y@0448@HaQBU5:D248@011BU48@@Q1241ABU00<@Q0aS48@00aBU00<<Ha24
48@011242ABU00L@Q1cW9BTU:B485:D@Q0026<H25:D01A246<HDYAS65:D0
0Q2400@DYA245:DDY@8HaP<DY@@@Q0045:D@Q1S67>L38@P36<H01QBU8@PU
:AcW6<H8@P8<H`@8@PP48@0324848@@Q01d48@0300048@@Q00`48@032484
8@@Q00L48@0300048@0000D48@0400048@@Q000612400`00124000051240
0`0012448@0212400`0012448@0612400`0012448@0<124010Q21248@PaS
11240PaS0PQ200@<Ha2448@@Q08<H`0348@<H`Q2008<H`8@Q0@<H`035:D@
Q0aS00<@Q00336<8@PaS00D@Q0<<H`8@Q08<H`0648@<H`aS36<8@PaS0a24
0PQ20`aS00<@Q1BU36<00PaS00<8@PaS36<01@aS00@@Q0aS36<@Q0L<H`<@
Q0@<H`8@Q00536<@Q1245:D@Q00436<248@336<548@00aBU48@<H`0336<0
112436<@Q1BU10aS00<@Q0aS24801@aS00@@Q0aS36<<H`<@Q0@<H`8@Q003
36<@Q12400@<H`<@Q0@<H`0348@<H`aS00X<H`0348@<H`aS008@Q00436<@
Q1245:D336<00aBU48@@Q00636<248@00aBU36<<H`0248@00`Q236<<H`02
48@436<0112436<<Ha240`aS0Q242@aS00D8@PaS36<<H`Q200D<H`03248<
H`aS008<H`88@P<<H`04248<H`Q2248336<324800`aS48@8@P0324801a24
36<<H`aS248<Ha24008<H`03248<Ha2400@<H`48@P0000<000@Q00001@@Q
00L000@Q12448A249BTHaP045:D00a245:DDY@035:D46<H45:D01PaS48@D
YAS65:D@Q08DY@036<HDYA24008<H`0348@DYA2400@@Q0035:D@Q12400@@
Q08<H`8@Q08DY@<@Q0045:D@Q1BU48@55:D00a245:D@Q0025:D01AS65:D@
Q1245:D00Q2400@<Ha2448@DY@8@Q0D<H`045:D@Q1BU5:D348@35:D00a24
36<@Q0025:D00aS65:DDY@025:D448@01@aS48@<H`aS48@00aBU1Q240QBU
0QS60QBU0a240QBU0Q2400<<Ha2448@00Q240QBU1A2400<<Ha2448@011BU
00@@Q0aS48@@Q0PDY@0948@HaR489BTQ21cW48@DYA2400@DY@8HaP8DY@<H
aPLDY@8@Q0055:DHaQBU5:DHaP025:D01QcW8@PLiaS65:DHaP<Q20057>LH
aQBU48@<H`03248212400`Q21248@P0512400`Q212448@0712400`Q21240
000<1240100012448@Q22`@Q00<000@Q12400P@Q00<000@Q124010@Q00<8
@P@Q12405P@Q00@000@Q124000<48@0324848@@Q01<48@<8@P8@Q0<<H`88
@P8<H`8@Q0<<H`0748@<H`aS48@<H`Q236<00aBU00<<Ha2448@0112400@<
Ha2436<8@P8<H`D@Q08<H`8@Q0@<H`8@Q08<H`03248<Ha2400@<H`045:D<
H`aS248236<011245:D@Q1240PaS00<@Q0aS48@00`aS0a241PaS00<@Q0aS
36<00PaS0Q240`aS00<@Q1BU5:D00a2400<<Ha2436<010aS0Q240`aS00<@
Q0aS36<010aS00<@Q0aS36<02`aS00@8@PaS36<@Q08<H`8@Q08<H`<@Q08<
H`0348@<H`aS008<H`0548@DYABU5:D@Q00236<448@336<00a2436<<H`02
36<448@336<448@00`aS48@@Q00248@236<248@236<648@436<348@010aS
48@<H`aS11240PaS112410aS00H@Q0aS248<H`Q248@436<2248336<32484
36<00`Q236<<H`0;36<2248236<00a2436<8@P02248010aS48@<H`Q21`aS
000612400`0012448@03124011BU8@PHaQ241QBU00<@Q1BU5:D01QBU00XH
aQBU48@DYA246<H@Q1BU48@DY@<@Q08DY@8@Q08DY@0748@<H`aS48@DYAS6
48@00PaS0Q2400<<Ha245:D00QBU00P@Q0aS48@@Q1BU48@DYA240QBU00@H
aQBU5:D@Q0<DY@0548@DYABU48@<H`0448@00`aS48@@Q00248@336<01124
5:DDYA240PaS00<@Q1BU5:D00aBU00H<Ha2448@DYAS648@45:D248@236<2
48@00aBU48@@Q00236<248@011BU48@DYA2411BU0Q240QBU0a2400LDYA24
48@@Q1BU36<@Q0045:D336<00a245:DDY@0348@25:D00a245:D@Q00248@4
5:D248@01aBU6<HLiacW8@PHaQBU008@Q0<DY@8HaP8DY@0448@DYAcW6<H2
5:D011245:DDYABU0Q2400L<HaBU6<HLiaBU48@DY@037>L35:D01AS67>LQ
21cW9BT00QS600L<H`Q236<8@P@Q24848@02248412400`Q2124000091240
0`0012448@0512401@001248@P@Q24800P@Q00D8@P@Q12448@0000@48@04
0008@P@Q248512401@0012448@@Q000010@Q00<000@Q12400P@Q00@000@Q
1248@P848@0300048@@Q00H48@0324848@@Q00H48@0300048@@Q00<48@03
00048@@Q00l48@0324848@@Q008<H`0948@<H`Q2248<H`Q248@<Ha24008<
H`03248@Q0aS00<<H`8@Q08<H`<@Q08<H`0348@<H`aS00L<H`0448@DYABU
48@436<348@2248336<3248236<00`Q236<<H`0736<00`Q236<<H`0348@4
36<548@010aS48@<Ha241@aS0Q240`aS1A240`aS0Q240PQ20a2400<8@PaS
36<01PaS00<@Q0aS36<01`aS00<@Q0aS48@01@aS00<8@PaS36<010aS1A24
0PaS0Q2400<<Ha2448@00Q2400<<H`Q236<01PaS0Q240`aS0Q240PaS00<@
Q0aS48@00Q240`aS1Q2400<<Ha2436<00`aS11240`aS00<8@PaS48@00QBU
0PaS1A2400<<Ha2436<00`aS00<@Q0aS36<00`aS00@8@PaS36<8@P8<H`03
248<H`aS008<H`88@P<<H`88@P0336<8@PQ2008<H`@8@P0436<@Q0aS2484
36<2248236<010Q236<<H`aS0PQ21`aS00<8@Q2436<00@aS00000`001240
000212401@0012448@@Q00000P@Q00D@Q2486<H@Q1BU008HaP<DY@<HaP8D
Y@0348@DYAS6008HaP8DY@0548@HaQS66<H@Q0035:D01Q245:DHaQS65:D@
Q0<DY@<@Q0065:D@Q12448@<Ha240QBU0Q241ABU00H@Q1BU5:D@Q1BU48@3
5:D348@01QBU6<HDYABU48@DY@@@Q00336<@Q12400<@Q0045:D@Q1245:D2
48@00`aS48@@Q00748@236<248@25:D348@00aBU48@@Q00348@010aS48@D
YA240PaS0a2400<<Ha245:D00Q2411BU1A240QBU0Q240QBU00D@Q1BU48@<
Ha24008DY@<@Q08DY@0448@DYABU5:D348@35:D248@00aBU6<HDY@035:D6
6<H25:D02A245:DDYABU6<HDYAS65:DHaP025:D00a245:DDY@0248@01AS6
7>LHaQS65:D00QS60aBU0QS60QcW00DHaQ245:DDYBDY008e[@05:DXDY@aS
48@<H`02248212400`Q212448@081242248:12400`Q212448@0212401P00
12448@Q2124000<48@0424848@@Q000312400`0012448@0312400`Q20004
8@0<12400`0012448@0512401`0012448@@Q00048@0000d48@0300048@@Q
00l48@04248<H`Q2248336<01@Q236<<H`aS48@01`aS00<@Q0aS36<00PaS
0a240PaS00<@Q0aS48@0112400@<Ha2436<<H`<@Q0035:D@Q0aS00<<H`05
48@<H`aS248<H`0248@010aS2488@PaS0Q240`aS0Q240PaS00@@Q0aS36<<
H`@@Q0D<H`<@Q00336<@Q0aS00@<H`03248<H`aS00<@Q08<H`0348@<H`aS
00<@Q0@<H`<@Q00436<8@PaS36<348@736<00a2436<<H`0236<248@536<0
1A2436<<H`aS24801PaS1A240PaS00<@Q0aS36<02PaS00<@Q0aS48@00`aS
0Q240PaS0Q2400@DYA2448@@Q0@<H`0648@<Ha2448@<Ha240`aS00<@Q0aS
36<00Q2400LDY@aS36<<Ha245:D@Q00236<248@01@aS48@@Q1BU48@01`aS
0a2400<<H`Q236<010aS00<8@PaS36<00PaS00@8@PaS2488@P<<H`88@P03
36<@Q0aS00<8@P8<H`0448@<HaBU48@236<212401PQ236<<H`aS1248@P<<
H`03248<H`aS00@<H`03248<H`Q2008<H`000`@Q00<000@Q12400P@Q00/0
00@Q12448A248@PDYA246<HDYAS6008DY@0648@DYABU5:DHaQ240QBU0QS6
0aBU00<HaQBU5:D00QS60QBU00P@Q1BU5:D@Q1BU48@DYA240aBU0a2400<D
YA2448@01A2411BU112400<DYAS65:D00a241ABU00H@Q1S65:DHaQBU6<H2
48@00`aS48@@Q00248@020aS48@<Ha245:D@Q1BU48@45:D448@00aBU48@D
Y@0248@45:D448@25:D848@010aS48@@Q1BU0a240QBU00@@Q1BU5:D@Q08<
H`0348@DYA2400<DY@`@Q08DY@036<H@Q1BU00@@Q08DY@036<H@Q12400DD
Y@8HaP8Li`<HaP<DY@0548@DYABU5:DHaP025:D00a245:DDY@025:D248@4
6<H45:D46<H00aBU6<HLi`027>L021BU48@Q23F]>LhU:A24248336<21240
10Q21248@PQ22P@Q00L000@Q12448@Q21240000312400`0012448@041240
0`0012448@0712400`Q212448@041240100012448@000`@Q00<000@Q1240
0P@Q00<000@Q00000P@Q0PQ200<48@0012402P@Q00@8@P@Q124000848@03
00048@0000H48@0500048@@Q1248@P03124010002488@P000P@Q00L8@P@Q
24848@Q248@<H`03248436<248@336<348@436<348@236<348@00`aS48@<
H`0236<0112436<<H`aS0Q2400<DYA2436<010aS0Q241@aS00@8@PaS36<@
Q088@P0636<@Q12448@<Ha2410aS11241@aS0Q2400<DYA2436<00`aS00D@
Q0aS36<<H`Q2008<H`0648@<H`aS36<@Q1BU0a2400<<Ha2436<00PaS00<8
@PaS36<00`aS00@@Q0aS48@<H`8@Q088@P8<H`8@Q08<H`0348@<Ha2400@<
H`04248<H`aS36<324800`aS48@<H`0236<00a2436<@Q00248@25:D336<0
0`Q248@@Q00236<00`Q236<@Q00336<0112436<8@PaS0Q240PaS1A240`aS
112400<<Ha2448@00Q241PaS0a2400@<Ha2436<@Q0<<H`@@Q00636<@Q124
48@DYA241@aS11241@aS00<@Q0aS36<00`aS00@8@PaS36<<H`88@P<<H`04
248<H`aS48@336<00`Q236<@Q00348@00`Q236<8@P02248236<010Q236<<
H`Q210aS00D8@PaS36<<H`Q200D<H`0000D000@Q12448@0000D48@080004
8AS68@PHaQ245:DLi`LHaP<DY@@HaPHDY@036<HDYA24008@Q0035:DHaQBU
008<H`035:DHaQBU00DDY@@@Q0065:D@Q1BU48@DYA2411S611BU00L@Q1BU
6<HLiaS65:D@Q0035:D011S65:DDYA240aBU00D@Q0aS48@DYA24008<H`04
48@<H`aS36<248@00`aS48@DY@025:D00`aS48@@Q0025:D448@01ABU48@D
YABU6<H00a2400DDYA245:D@Q0aS00<@Q08<H`8@Q00436<@Q1S66<H248@0
10aS48@DYABU2A2400<DYAS648@00a2400<HaQ2448@00Q240QBU00<HaQ24
48@00a2400DHaQBU48@@Q1BU008HaP075:D@Q1BU5:DHaQBU48@00aBU00<L
iaS66<H011S600DDYAS65:DHaQBU00<HaP035:DHaQBU008DY@@HaP<Li`03
6<HDYAS6008Li`8Q20@DY@079BTYBRU:>Lhe[B486<H01@Q200<48@Q22480
0PQ21P@Q00<8@P@Q12400`@Q00<8@P@Q12401P@Q00<8@P@Q12401P@Q00<0
00@Q124010@Q00<8@P@Q12404@@Q00<000@Q12400`@Q00<000@Q12402P@Q
00<000@Q12404@@Q00<000Q224800PQ20`@Q0PQ200H48@Q236<@Q1BU48@4
36<0112436<<H`Q210aS0a241PaS00@@Q0aS36<<H`<@Q08<H`@@Q0<<H`8@
Q08<H`03248@Q0aS008<H`@@Q0H<H`0348@DYA2400<<H`045:DHaQ2448@2
36<01A2436<<H`aS248010aS00<@Q0aS36<00`aS0Q2410aS00<@Q0aS48@0
10aS0a2400<<Ha2424800`aS00D@Q0aS36<<Ha24008<H`0348@<Ha2400<<
H`0348@<HaBU00H@Q003248<H`aS00<<H`0348@<H`aS008<H`03248<H`aS
008@Q00336<@Q124008@Q00636<@Q12448@<Ha240PaS00<@Q0aS36<00PaS
00P@Q0aS36<<H`Q236<DYA240PaS0Q2400<DYA2448@00PaS1Q241@aS0Q24
0`aS0a240PaS0a240PaS00@@Q1BU48@@Q08<H`<@Q0065:D<Ha2448@DYA24
0PaS00@8@PaS48@@Q08<H`03248<Ha2400D<H`88@P<<H`88@P<<H`<8@P03
36<@Q0aS00H<H`88@P@<H`<8@P<<H`03248<H`Q200<<H`03248<H`Q20088
@P0000<48@0012400P@Q00D000@Q12448@0000848@0648@U:AS648@DYAS6
0QBU1AS600@DYAS66<HHaP8@Q0045:DHaQBU48@25:D00aS65:D@Q00248@2
5:D00aS648@@Q0025:D01aS65:D@Q1245:DHaQBU008@Q00336<@Q124008@
Q08DY@036<HDYABU00@DY@036<HDYABU008@Q0035:DHaQS600DDY@066<HD
YA2448@HaQ240PaS0a240PaS112400dDY@aS36<@Q1BU6<HDYA2436<@Q0aS
48@DY@0248@00aBU48@@Q00648@25:D248@011BU48@@Q0aS0a2400<DYA24
5:D00QBU0a240QBU2A2411BU00<@Q1BU6<H00QBU00<<Ha2448@00QBU0Q24
11BU00@@Q1BU5:D@Q08DY@036<HDYABU00HDY@046<HLiaS66<H25:D26<H0
0aBU6<HHaP035:D00a246<HDY@025:D00a245:DHaP056<H01acW6<HLiaS6
5:DHaR48008U:@<HaP0<5:DLibDY:DXicS6<8@PHaPQ236<8@PaS0PQ20P@Q
00<<H`@Q12403P@Q00<000@Q12401@@Q00<8@P@Q12408`@Q00<000@Q1240
5@@Q00<000@Q12402`@Q00<8@P@Q24801PQ200@@Q0aS5:DDY@8@Q004248<
H`Q2248536<248@336<00`Q248@<H`0248@236<248@236<01Q2436<<Ha24
5:D@Q08<H`03248@Q0aS00@<H`03248<H`aS00P<H`0548@<H`Q248@DY@02
48@236<548@;36<348@236<00a2436<<H`0236<248@00aBU48@<H`0348@2
36<348@436<448@236<0112436<@Q12410aS112400@DYA2448@<H`<@Q0D<
H`0348@<H`aS00<<H`8@Q0065:D@Q12448@<HaBU0Q240PaS00@@Q1BU36<8
@P8<H`0448@<H`aS48@236<248@236<0112436<<H`aS1A240PaS00<@Q0aS
36<00Q2400H<H`Q2248@Q0aS48@236<348@00`aS48@@Q00248@336<648@2
36<00a2436<@Q00248@00`aS48@<H`0236<00`Q236<<H`0248@736<00`Q2
36<<H`03248010aS248<Ha240PaS0`Q21`aS2@Q210aS00@@Q0Q236<<H`88
@P@<H`448@000`@Q00<000@Q12401P@Q00@@Q2486<HDY@8HaP8DY@0748@D
YAS67>LHaQBU48@00QBU00@HaQBU48@@Q0@DY@0348@DYABU008DY@0348@D
YA24008HaP<@Q0045:DHaQBU48@45:D348@01aBU48@@Q0aS48@DYAS600@D
Y@056<HDYA2436<@Q0045:D011245:DHaQBU0Q2400<DYA2448@011240aBU
0a2400<DYA2436<00Q2400DDYA2448@@Q0aS008DY@<@Q08DY@8@Q00436<@
Q1BU5:D348@00aS65:D@Q00348@00`aS5:D@Q0025:D448@00aBU48@@Q00;
48@00`aS48@DY@025:D011S65:DDYA240PaS0Q2400<DYA245:D01QBU00<@
Q1BU5:D011BU00<HaQBU5:D00Q2400<DYA246<H00QS600@@Q1BU5:DDY@8@
Q0<DY@046<HDYAS65:D36<H45:D01acW6<HHaQS67>LHaQcW008Q208U:@05
7>LHaQBU6<HQ20027>L25:D01QcW:DY6<D8@<H`U:@8<H`@8@P041248@PQ2
24871242248@12400`0012448@0312400`0012448@0?12400`0012448@05
1240100012448@002P@Q00<000@Q12400`@Q00@000@Q2488@PX48@032484
8@Q200848@<8@P848@88@P0336<DYABU008DY@@<H`0348@<Ha2400@<H`@@
Q08<H`88@P8<H`8@Q00336<@Q0aS00@<H`8@Q08<H`0348@<Ha24008<H`<@
Q088@P0336<@Q0aS00@@Q0P<H`8@Q00436<@Q1BU5:D248@01@aS48@<H`aS
24801`aS0Q2400@DYA2448@8@P8<H`<@Q0@<H`<@Q00336<@Q12400@@Q0D<
H`D@Q08<H`0348@DYA24008<H`0448@DYA2448@336<248@00`aS48@<H`05
36<01A2436<<H`aS24800PaS1A240PaS0a242PaS00<@Q0aS36<01@aS0aBU
0Q240PaS11240`aS00<@Q0aS36<00`aS1A2400<DYA2448@00Q2400<DY@aS
36<00PaS00<@Q0aS36<00PaS0Q2400HDYA2448@@Q0aS248336<01A2436<@
Q0aS24800Q240`aS00@8@PaS36<<H`<8@P0336<8@PaS0088@P8<H`88@P8<
H`8@Q08<H`0548@8@PQ21248@P0236<3248010aS248<H`aS0PQ200<<H`Q2
36<010aS0A240@aS0@aS000212401@0012448@@Q00000P@Q00L000@Q124@
Q2DY7>L@Q0035:D00aS65:DHaP046<H25:D00aS65:DDY@025:D00a245:DD
Y@025:D011245:DDYA240aBU00DHaQBU5:DDYA2400@DY@0348@DYABU008@
Q0055:D@Q1BU5:D<H`0248@00aBU6<HHaP025:D01Q245:D@Q1BU48@DY@8@
Q0045:D@Q1BU5:D26<H25:D448@010aS48@@Q1BU0a2400@DYA2436<<H`HD
Y@0436<@Q1245:D248@00`aS48@@Q00448@35:D00a245:DDY@0248@236<0
0a245:D@Q00848@00aBU48@@Q00248@011BU48@@Q1240QBU1Q240QS600DD
YA2436<<Ha2400<DY@0448@<Ha245:D36<H00aBU6<HDY@0248@65:D01a24
5:D@Q1245:D@Q1BU00<HaP055:DHaQBU5:DHaP035:D00a245:DDY@036<H0
0a245:DDY@026<H00acW6<HLi`026<H27>L2:DX011cW6<HDYAcW0R4800DL
iaBU7>LQ22U:00924009<H`U:@aS248<H`Q236<8@P@Q0088@P<48@88@PL4
8@0400048@@Q000412400`Q212448@0<12401@Q212448@@Q00004@@Q00<0
00@Q12402@@Q00<000@Q00000P@Q00<000@Q000010@Q00<000@Q12402@@Q
00@8@P@Q12448@88@P041248@PQ2248236<25:D00aS648@<H`0248@436<0
0a2436<<H`0236<248@010aS48@<H`aS0PQ200@<Ha2436<<H`<@Q0P<H`<@
Q08<H`0548@<Ha2436<8@P0236<248@00`aS48@DY@0536<010Q236<@Q1BU
11240PaS00<@Q1BU36<00PaS0Q241@aS00L@Q0aS48@@Q0aS48@<H`0248@0
1@aS48@<H`aS48@00PaS112400<<Ha2436<00PaS00H@Q0aS2488@PaS5:D4
48@010Q248@@Q1BU0Q240`aS21242@aS00<@Q0aS36<00`aS0a240PaS1124
00<<H`Q236<00a240`aS00<@Q0aS48@00PaS00<@Q0aS36<00Q2400<DYA24
48@00Q240PaS00<@Q0aS48@02`aS11240`aS112400<<Ha2436<00`aS0Q24
00@DYA2448@@Q0@<H`04248@Q12436<2248010aS48@<Ha240`aS0PQ20PaS
0`Q200D<H`Q236<<H`Q200@<H`88@P@<H`03248<H`Q200@8@P0736<8@PQ2
248<H`Q236<00`Q20PaS00D8@PaS36<<Ha240048@P0000D000@Q12448@00
00L48@0348@Q21cW00@DY@DHaP<DY@0348@DYABU00@DY@@HaP045:D@Q1BU
5:D248@36<H248@25:D00aS65:DDY@045:D00a2436<@Q0025:D348@46<H0
0aBU48@<H`0248@00aBU36<DY@036<H25:D00aS65:DDY@0348@021BU48@<
H`aS48@DYA2436<45:D00a2436<@Q0035:D00a245:DDY@025:D01A245:DD
YABU48@00PaS0a2411BU00<@Q1BU5:D011240QBU212411BU00D<Ha2448@D
YA2400<DY@0536<@Q1BU7>LHaP0248@011BU48@@Q1240aBU0Q2400<DYA24
5:D00aS60QBU0aS600H@Q1BU48@@Q1BU48@25:D00aS65:DHaP026<H011BU
48@@Q1240QS60QBU0Q2400@DYAS67>LHaP8DY@8HaP035:DHaR48008Q20DH
aP067>LQ22489BTHaQBU0QS60R4800<HaQcW7>L00QS600XLibDY;F/YBRDY
;F/Q21BU36<48@<8@P0636<48@@Q24848@Q22P@Q00<000@Q12400P@Q00<0
00@Q124020@Q00@000@Q124000<48@0324848@@Q00L48@0500048@001240
000212400`0012448@0@12400`0012448@031240100012448@000`@Q00<8
@PaS36<00`Q20`@Q00<8@PaS48@01A240`aS0a2410aS0a240`aS0Q240`aS
00<@Q0aS36<00`aS00<@Q0aS36<00PaS0Q2410aS00<@Q0aS48@00`aS00<@
Q0aS36<00PaS00@@Q0aS48@@Q0<<H`0348@DY@aS00<<H`8@Q0<<H`@@Q003
248<H`aS00P<H`0348@<H`aS008<H`8@Q0<<H`0448@<H`aS48@336<01124
5:D@Q0aS0a240PaS0Q240`aS0a2400<DYA2448@01Q240`aS0a2400H<Ha24
36<<Ha2436<248@436<0112436<<H`aS0Q240PaS0Q2400<<Ha2448@00Q24
0PaS112400@<Ha2448@@Q0@<H`@@Q00336<@Q124008<H`8@Q0<<H`0348@<
H`aS008@Q0@<H`8@Q0035:DHaQ2400<<H`0348@<Ha2400<@Q0D<H`0548@D
YA2448@<H`0248@536<00a2436<<H`02248336<348@236<2248436<010Q2
36<@Q1240`Q200<<Ha2436<00PaS0Q2400@<H`Q22488@P<<H`03248<H`Q2
0088@PX<H`4@Q04<H`48@P0000@48@00124000D48@0800048@@Q48@U:AcW
5:DHaP@DY@037>LHaQBU00DDY@8HaP@DY@<HaP8DY@<@Q0TDY@046<HDYA24
48@25:D448@25:D248@01ABU6<HHaQS65:D00Q2411BU00<@Q1BU6<H011S6
0QBU00<@Q0aS48@00Q2400@<Ha2448@DY@8@Q0<DY@<@Q0HDY@0348@DYABU
00<DY@T@Q0055:D@Q12448@DY@0548@021BU48@DYABU48@DYA245:D548@0
0aBU48@DY@025:D01A245:D@Q1245:D00QS600DDYA2448@HaQBU008<H`03
5:DHaQ24008<H`8DY@0348@HaQS6008HaP055:DHaQS65:DHaP055:D01Q24
5:D@Q1S65:DHaP8DY@0348@DYAS6008HaPDDY@@HaP8DY@066<HDYAS67>LU
:B480aS600@LiaS67>LLi`8Q208Li`066<HLib486<HLiaS60QcW00XHaR48
9BTaS2e[:DX]JacW6<H<H`@8@P031248@P@Q02@48@0300048@@Q01<48@04
24848@@Q00061240100012448@001P@Q00D8@P@Q1248@P@Q0088@P031248
@PQ200<8@P051248@PQ2248<H`0248@00aBU48@<H`0436<348@236<00a24
36<<H`0236<01A245:D@Q124248010aS00<@Q0aS48@01@aS112400<8@PaS
36<00Q241@aS00<8@PaS36<00a2400DDYA2436<@Q0aS00@@Q0<<H`8@Q003
5:D@Q0aS00@<H`0348@<H`aS008<H`03248<H`aS008@Q00336<@Q124008<
H`0348@<H`aS00@<H`0448@<H`aS48@336<348@00`aS48@@Q00336<248@3
36<00a245:D@Q00236<248@00`aS48@@Q00648@010aS48@<Ha242`aS00<@
Q0aS24800Q2400<DY@aS48@00Q240PaS0a2400<<H`Q236<00a240`aS0Q24
1@aS00HDYA2448@<Ha245:D336<248@336<248@236<00a2436<<H`0248@2
5:D0112436<@Q0aS0Q2400<<Ha2448@010aS0Q240QBU0a240PaS00@8@PaS
36<<H`<8@P@<H`03248<H`aS008<H`05248<H`aS36<8@P0436<00`Q236<8
@P0736<2248236<3248236<2248236<2248336<00`Q236<<H`0348@136<1
248000D48@0300048@@Q00848@0<00048A249BTHaQBU6<HDYA245:D@Q1BU
0QS60QBU00@@Q1BU48@@Q08DY@037>LHaQS6008HaP035:DHaQ2400<@Q08H
aP065:D@Q1245:DLiaS60aBU0aS61QBU00<@Q1BU5:D00aS600<DYAS648@0
0Q241ABU00@HaQBU5:DDY@8@Q0035:D@Q124008@Q0035:D@Q124008DY@04
48@DYABU5:D748@35:D00a245:D@Q00248@00`aS48@@Q00448@25:D248@3
5:D448@00aBU48@@Q00348@236<00a245:D@Q00248@25:D011245:DDYAS6
0QBU11241aBU00P<HaBU6<HHaQ2436<@Q1S60aBU0QS600D@Q1BU6<HHaQBU
008@Q0<DY@0348@DYA24008@Q0HDY@0348@HaQS6008Li`036<HDYAS6008H
aP0<5:D@Q1BU7>LQ21cW6<HQ22DY8@PHaQBU11S600<LiaS65:D00QS600HL
ib487>LLiaS65:D37>L02B489BTQ21S69BTaS48@=JdU:@02:DX01Q242484
8@Q236<8@P848@0524848@Q212400004124224800`0012448@0712401@00
124000@Q24800P@Q00<000@Q12402`@Q00<000@Q12401P@Q00@000@Q1248
@P848@0300048@@Q00`48@88@P05124000@Q24848@03248010aS2488@PQ2
0P@Q0PaS00H@Q0aS36<@Q1BU48@:36<01A2436<<H`aS24801PaS00<8@PaS
48@00Q240PaS00<@Q0aS36<010aS0a240`aS0Q2400@<Ha2448@@Q0<<H`03
48@<H`aS00<@Q00536<DYABU5:D@Q00436<448@336<00a2436<<H`0236<0
10Q236<<Ha241@aS0a2400<<Ha2436<00`aS00<@Q0aS48@00`aS00@@Q0aS
36<@Q08DY@8<H`8@Q0<<H`0348@<H`aS00@@Q08<H`@@Q08<H`<@Q00436<@
Q0aS5:D336<011BU48@<H`Q20PaS0Q240PaS1Q2400H<Ha2436<@Q0aS48@8
36<448@02@aS48@@Q12436<@Q0Q248@<H`0448@00`aS48@<H`0548@436<0
112436<@Q1BU1Q240PaS1A2400<<Ha2448@00Q2410aS00<8@PaS36<00Q24
20aS00@@Q0aS48@@Q0L<H`0548@<Ha2436<8@P0436<01PQ236<@Q0aS48@<
H`L8@P8<H`04248<Ha2436<3248248@00aBU48@@Q00336<000848@030004
8@0000<48@0700048@@Q124@Q2486<H00Q242aBU0Q2400@DYA245:DDY@8H
aP035:DHaQBU00@@Q08HaP037>LHaQBU00@HaP8DY@<HaP045:D@Q1BU48@7
5:D02A245:DDYA245:D@Q1BU48@DY@0248@75:D648@45:D00a2436<@Q002
48@25:D248@236<00aBU48@@Q0025:D0112436<@Q1BU0Q2400@<Ha2448@@
Q08DY@8@Q0045:D@Q1BU5:D748@236<01A245:DDYA2436<00a2400<DYA24
48@00a240QBU0Q2400<DYAS66<H01Q240QBU0a2400@HaQ2448@DY@8HaP<D
Y@8HaP0448@DYA2448@35:D248@35:D36<H35:D37>L01AS65:DDYABU6<H0
0QBU00<HaQcW7>L00QS600@Lib489BTQ208HaP045:DHaQcW8@P36<H01QcW
9BTQ21cW6<HLi`8HaP8Li`8U:@047>LHaR48:DX2>Lh01C6<:DXQ21BU36<0
0PQ200@<H`Q22488@P848@030008@PaS00848@0400048@@Q000224800`@Q
00048@0812400`Q212448@021242248512400`0012448@0912400`001244
8@0@12400`0012448@0312401`001248@PQ21248@P@Q0088@P0636<@Q0Q2
24848@Q211240PaS0Q2400<<Ha2436<00`aS00@8@PaS36<<H`8@Q08<H`04
248<Ha2448@436<00aBU48@@Q00536<00a2436<<H`0236<348@;36<01A24
36<<H`aS48@00PaS0Q240QBU00<@Q0aS48@010aS0a240PaS0Q2400<<H`Q2
24800`aS00@8@PaS36<<H`8@Q0<<H`8@Q0D<H`0348@<H`aS008@Q0H<H`05
48@<Ha2448@<H`0448@536<348@236<248@336<248@236<248@010aS48@<
Ha240`aS00<@Q0aS36<01PaS00@@Q0aS48@@Q0@<H`8@Q08<H`8@Q00336<@
Q124008@Q00736<@Q1245:D<Ha2436<00Q240PaS11240PaS00<8@PaS48@0
0PaS0a240`aS00@DYA2448@@Q08<H`0348@<H`aS008@Q0@<H`035:D<Ha24
008@Q0H<H`03248<H`aS008<H`<8@P8<H`8@Q08<H`03248<H`aS00@<H`<@
Q00336<8@PaS00P<H`88@P8<H`<8@P<<H`88@P8<H`0448@<H`Q2248236<0
0a245:D@Q00236<12480000300048@@Q00<48@0300048@@Q00<48@095:DU
:AS636<DYAS67>LDYAS600<DY@0448@DYA2448@25:D248@25:D01AS65:DD
YA246<H00QBU0QS60QBU0Q2400@DYAS66<HLi`8DY@036<HDYABU00<DY@04
48@DYABU6<H35:D36<H00aBU48@DY@025:D248@011BU6<HDYA240QBU00PH
aQBU48@@Q0aS48@DYA240PaS00@@Q1BU5:DDY@8@Q0045:D@Q0aS36<348@0
0`aS48@<H`0336<948@25:D348@36<H348@35:D248@00aBU48@<H`0248@2
6<H01A2436<DYA2436<00Q2400<DYA245:D00aBU00@@Q1BU6<HDY@8@Q08D
Y@8@Q0<DY@0348@DYA24008@Q0@DY@046<HLiaS65:D248@00aBU48@@Q002
48@00aBU48@@Q0035:D00a245:DDY@026<H01ABU6<HLib487>L00aS600DL
iaS65:DHaQcW008Q208U:@<Li`036<HLiacW008HaP045:DHaQBU48@25:D2
8@P00acW8@PU:@028@P011cW6<HHaQS60acW00HHaR48:DX]Jc6<9BT26<H2
48@00`aS248<H`02248010@Q24848@Q20P@Q0`Q24@@Q00<000@Q12401P@Q
00H8@P@Q124000@Q000212400`002488@P0312400`0012448@0512400`00
12448@08124324831243248010@Q248<H`Q20a240`aS00<@Q0aS48@00Q24
00@DYA2448@@Q08<H`05248<H`aS36<@Q00836<348@00`aS248<H`0348@4
36<01Q2436<@Q0aS48@DY@8<H`04248<H`aS48@336<02PQ236<@Q1245:D@
Q0aS248<Ha240QBU00<@Q0aS48@00Q240`aS0Q2400@<H`Q236<@Q0D<H`04
248@Q0aS48@436<0112436<<Ha2410aS0Q2410aS0a240PaS0a2400<<Ha24
36<00PaS1A240PaS212400<<Ha2436<010aS112410aS00<@Q0aS36<01124
0`aS00<@Q0aS36<00PaS00<@Q0aS36<00`aS00@@Q0aS36<<H`@@Q00336<@
Q12400<@Q00636<@Q12436<@Q0aS0a240`aS0a240PaS0Q2410aS0a2400L<
Ha2448@@Q0Q236<8@P0348@336<348@336<00`Q236<<H`0536<00`Q236<8
@P0224800`aS5:D@Q00236<224800`aS248<H`0236<021BU7>LHaQBU36<8
@PaS248336<348@00`aS2488@P0336<8248436<648@236<00005124000@Q
1240000412402P0012448ABU9BTHaQ245:DHaQBU0QS600<DYAS65:D00a24
0QBU00D@Q1BU48@DYAS600<DY@056<HDYABU36<DY@036<H011245:DHaQS6
2ABU00D@Q1BU5:D@Q1BU00<HaP045:DHaQBU48@35:D36<H011BU48@@Q124
11BU1A2400<<Ha2436<00Q2400<DYA2448@00QBU0PaS0Q2400<DY@aS36<0
112400<<Ha2448@00QBU212400D<Ha2448@HaQBU00<@Q0035:D@Q1BU00<@
Q00336<@Q12400@@Q0035:D@Q12400<@Q0DDY@0348@DYABU00<DY@<@Q008
36<DYABU6<HDYA2436<@Q0<DY@0348@HaQBU008HaP8DY@8@Q08DY@8@Q003
5:D@Q124008DY@046<HDYABU48@35:D26<H00b487>LQ20036<H25:D26<H3
7>L28@P29BT27>L01AS67>LLiacW5:D00a240QS600HLib488@PQ21cW8@P3
7>L011S65:DHaQS60QcW00DQ22e[<H`]Jb48008HaP0348@<H`aS008@Q003
24848@Q20088@QX48@0324848@@Q00l48@0600048@@Q00048@Q22P@Q00D8
@P@Q12448@Q200@48@88@P848@@8@P@<H`0548@<H`aS36<@Q0035:D348@2
36<00`Q236<@Q00236<010Q236<@Q1240`aS00<8@PaS36<01@aS0a2410aS
00<8@PaS36<00Q241`aS00@@Q0aS248<H`H@Q00336<@Q1BU008@Q08<H`04
48@DYA2448@236<00a2436<8@P0236<248@636<348@010aS48@<H`Q20PaS
00<@Q0aS36<00PaS00<@Q0aS36<01`aS1A2400D<Ha2448@@Q0aS008@Q003
5:D@Q0aS008<H`0448@<H`aS36<248@436<448@336<248@336<0212436<@
Q0aS48@<Ha2436<248@636<248@00`aS48@<H`0248@336<248@236<248@0
1ABU36<<H`aS5:D00Q2410aS0Q241@aS0a2400<<Ha2448@00`aS00<@Q1BU
5:D01PaS0a242@aS0Q240`Q20Q2400<<H`Q236<00PQ200<<Ha2448@00Q24
00`8@PaS2488@PaS48@<H`Q248@HaQcW6<H224800`aS248<H`0736<42482
36<324800`aS48@@Q00236<00`Q236<@Q00548@136<1248000848@040004
8@@Q0006124011BU:DXQ21240QBU11S60QBU00<@Q1BU6<H00QS600HDYA24
5:D@Q1BU6<H35:D011S65:DDYABU0QS600<DYA2448@00QBU00<HaQBU48@0
11BU00<@Q1BU48@00a240QBU1AS611240aBU0QS60aBU00<HaQBU5:D00Q24
0QBU00@@Q0aS36<@Q08DY@<@Q08<H`8DY@8@Q08<H`<@Q08<H`H@Q08<H`05
48@DYABU5:D@Q0025:D248@45:D:48@00aBU48@@Q00348@00`aS48@@Q00;
5:D0112436<<Ha240QBU0Q240aBU1A2400HDYAS67>LHaQBU48@25:D248@0
0aBU48@HaP045:D00a245:DDY@045:D011S65:DDYABU2aS60R480acW00@Q
21cW7>LLi`8HaP@DY@8HaP037>LQ21cW008Li`8HaP047>LU:BDY8@P26<H2
7>L02BDY7>LHaQS67>L]JbU:8@PLi`0636<7248:1243248712401@Q21244
8@@Q248010@Q00H8@P@Q124000@Q248712400`0012448@0312400`001244
8@02124424800`@Q2488@P0624801PaS48@@Q12436<DY@8@Q0<<H`0648@<
Ha2448@DYAS60aBU0Q241PaS00/@Q0aS36<<H`Q236<8@Q245:D@Q0aS0088
@P8<H`<@Q0D<H`D@Q0H<H`H@Q0<<H`L@Q00336<@Q12400@<H`0348@<H`aS
00<<H`0348@<H`aS00D<H`<@Q0<<H`0448@<H`aS248236<248@01@aS48@@
Q1245:D010aS00D@Q0aS36<<Ha24008<H`<@Q00436<@Q1245:D248@00aBU
48@@Q00236<01Q245:D<H`aS48@DY@<<H`8@Q0<<H`0648@DYA2436<8@PaS
0Q2410aS00@@Q0aS36<<H`8@Q0L<H`8@Q00336<@Q124008@Q00336<@Q124
00D@Q0<<H`0348@<H`aS008<H`8@Q0<<H`8@Q0<<H`0448@<Ha2448@236<3
48@436<348@236<00a2436<<H`0236<248@336<2248336<01`Q236<8@Q24
36<@Q1BU008@Q00436<8@PQ236<248@236<00a245:D@Q00236<01PQ236<8
@PaS248@Q0@<H`04248<H`Q2248336<3248636<248@011BU48@@Q0aS0PQ2
00000`0012448@0312403P0012448@@Q0008@QS69BTHaPaS5:DHaQBU48@2
6<H011BU48@@Q1240QBU00DHaQ245:DDYAS600<DY@066<HLiacW5:D@Q1BU
0aS60a2400<DYAcW5:D011BU00H@Q1BU48@@Q1BU48@45:D00aS65:DDY@02
5:D448@00aBU6<HHaP035:D26<H011BU48@DYABU0a2400DDYA2448@@Q0aS
00L@Q0035:D@Q12400<@Q0@<H`<@Q08DY@0448@<H`aS48@25:D448@25:D0
11S648@@Q1240QBU11240PaS00<@Q1BU48@011240PaS0a2400<DYAS65:D0
0aBU00@HaQ2448@<H`D@Q08DY@0348@DYA2400<@Q0<DY@036<HDYABU008D
Y@8@Q0075:DHaQ245:D@Q1BU6<H00QBU0Q2400@DYAS65:DDY@8@Q0045:DH
aQcW7>L25:D26<H27>L011S65:DHaQS60QcW00<Q21cW7>L00acW00<Q21S6
6<H00QBU00P@Q1BU5:DHaQcW6<HLiaS60QcW00DHaR48:DXU:B48008HaP03
7>LQ224800<Li`058@PYBRe[8@PLi`0336<010Q236<<H`aS2@Q20`@Q0PQ2
0P@Q00D000@Q12448@Q200H48@0324848@@Q01L48@88@P<48@<8@P848@<8
@P041248@PQ21242248336<448@00aBU48@@Q00236<448@011BU6<HDYABU
10aS00<@Q0aS36<01@aS00<@Q0aS36<00a2400<<H`Q236<00Q2400@<Ha24
48@@Q0<<H`0448@<H`aS36<348@336<248@00`aS48@<H`0248@010aS48@<
H`aS0a240QBU0Q240`aS0Q240PaS00P8@PaS36<@Q0Q236<8@Q240PaS00@8
@PaS36<<H`8@Q0035:D@Q0aS008<H`0348@<H`aS00<<H`H@Q00336<@Q0aS
008<H`0648@<Ha2436<@Q0aS112400<<Ha2448@00QBU0Q240PaS00<@Q0aS
48@00a240PaS00<@Q0aS48@010aS00<@Q1BU48@00`aS2A2410aS0Q240PaS
1A2400<<Ha2448@01A2400<DY@aS24800PaS112400<<Ha2448@00Q240PaS
00<@Q1BU36<010aS00@@Q0aS36<<H`8@Q0<<H`0648@<H`aS48@<Ha2410aS
0Q2410aS00@@Q0aS2488@P8<H`8@Q003248<H`Q200<<H`<@Q00336<8@PaS
00<<H`8@Q0035:D@Q0aS008<H`03248<H`aS00D<H`04248<H`Q236<22480
1@aS2488@PaS24801PaS0a2400@<Ha2448@@Q048@P0000D48@0012448@00
00@48@0500048@@Q5:DQ200248@011BU7>LHaQBU0aS62aBU0QS61QBU00<H
aQBU5:D00Q240QBU0a240aBU00<@Q0aS48@00Q240QBU00D@Q1BU48@DYAS6
00@DY@8@Q0<DY@0448@DYABU6<H85:D248@35:D748@01@aS48@@Q1BU48@0
0QBU0a2400<<HaBU5:D00QBU0a2400@DYA245:DDY@@@Q08DY@8HaP035:D@
Q12400@DY@8@Q0035:D@Q124008HaP045:D@Q1245:D548@00`aS48@DY@02
6<H011BU48@DYABU0Q2400D<Ha245:DDYA2400<DY@0348@DYA2400<@Q004
5:DHaQBU5:D248@011BU48@DYAS611BU0QS600@DYA2448@DY@8@Q0<DY@8H
aP035:DHaQS600<HaP8Q20037>LDYABU008HaP045:DLiacW7>L36<H01248
7>LLiacW0aS60QBU0aS600H@Q1BU7>LLiaS65:D26<H00aBU6<HHaP028@P2
9BT28@P01BDY8@PQ22DY8@P00bDY00HLiaS66<HHaQcW5:D236<2248536<2
24801@@Q2488@P@Q248010@Q00@8@P@Q2488@P<48@0424848@@Q24851240
1PQ212448@Q21248@P<48@0424848@Q224821242248010aS24848@@Q0PQ2
00@<H`Q22488@P8<H`<@Q00336<@Q12400H<H`0348@DYA2400D@Q00436<D
YA246<H348@00`aS48@<H`0336<448@336<0212436<<H`aS48@<Ha2436<3
48@236<010Q236<DYABU0Q2400<<Ha2448@00`aS00<@Q0aS36<01Q240PaS
00<@Q0aS48@00a241@aS0Q240`aS00<@Q0aS48@00PaS00L8@PaS36<<Ha24
36<@Q00:36<648@00`aS48@<H`0348@236<448@236<248@25:D348@00aBU
48@DY@0648@010aS48@<Ha240PaS1A2400D<Ha2436<@Q1BU00<@Q0<<H`8@
Q00336<@Q12400<<H`<@Q00336<@Q12400<@Q00436<@Q0aS48@436<248@0
20aS48@@Q0aS48@<Ha2436<25:D248@01@aS248<Ha245:D00Q240PaS0a24
00D<Ha2448@@Q0aS008@Q00336<@Q12400@<H`0348@<H`aS008@Q00336<8
@PQ2008<H`04248<Ha2448@536<01A245:D@Q12436<00PQ200D<Ha2448@<
H`Q200<<H`0348@<H`aS00L<H`88@P8<H`@8@P/<H`<@Q0@<H`000P@Q00<0
00@Q12401`@Q00@DYAcW6<H<H`@DY@8Li`045:D@Q1245:D26<H448@021S6
5:DDYAS67>LHaQBU48@35:D01AcW6<HDYABU48@00aBU00<@Q1BU48@01A24
11BU00<@Q1BU5:D021BU00<@Q1BU5:D02QBU0Q2400<DYA2448@00Q2400HD
YA245:D@Q0aS48@25:D00a2436<@Q0025:D848@011BU48@@Q0aS11240QBU
0a240QS600<@Q1BU5:D00Q2400<<Ha245:D00a2411BU00@@Q1BU48@DY@8@
Q08DY@8@Q0035:DHaQS6008DY@8@Q0045:D@Q12436<548@25:D00a2436<<
H`0248@011BU48@DYABU0Q240QBU00<HaQBU48@00QBU00<HaQBU5:D011BU
00<@Q1BU48@00QBU00DHaQBU6<HDYAcW008HaP8Li`048@PLiaS65:D26<H0
0acW6<HHaP026<H00acW6<HHaP046<H00aBU6<HDY@026<H25:D26<H00aBU
6<HHaP027>L46<H011cW8@PQ21cW0R480RDY0R4800@U:BU::DXQ208HaP07
5:DLiacW6<H@Q1BU36<00PQ20`aS00<8@P@Q12400`Q20P@Q0`Q20P@Q0`Q2
00@48@Q224848@88@P<48@88@PP48@D8@P031248@P@Q00848@D8@P848@88
@P<<H`0348@<H`aS008<H`0348@<H`aS00<<H`T@Q0055:D@Q1BU48@DY@02
48@636<348@836<01A2436<<Ha245:D00Q240PQ20PaS00@@Q0aS48@<H`@@
Q0<<H`0548@<Ha245:D@Q00336<248@01@aS48@@Q1245:D00Q241PaS0a24
0PaS00<8@PaS36<00`aS00<@Q0aS36<00`aS00@@Q0aS36<<H`8@Q00436<@
Q12448@236<00a245:DDY@0636<248@236<348@00`aS48@@Q00348@00aBU
48@@Q00448@236<348@00aBU48@<H`0236<248@336<248@011BU48@@Q124
0`aS00<@Q0aS36<00Q2400<<Ha2436<0212400<<Ha2436<00PaS0a240`aS
0a241@aS0Q240`aS00D@Q0aS48@<Ha24008<H`0448@DYA2448@236<00a24
36<<H`0348@336<01Q2436<<Ha2436<8@P8<H`0448@<H`aS36<324800`aS
248<H`0248@336<00a2436<<H`0336<348@836<010Q236<@Q0aS0PQ200@<
H`Q22488@P@<H`05248<H`aS36<8@P0836<448@336<0000400048@@Q0002
1240100012448@000P@Q00@DYBDY5:D@Q08HaP035:DHaQS6008HaPHDY@03
48@DYABU008DY@036<HLiacW008Li`8DY@036<HDYABU00<@Q0045:D@Q124
48@25:D00aS65:DDY@0348@00aBU48@@Q0025:D26<H:5:D36<H35:D01124
5:D@Q12411BU00<@Q0aS48@00aBU0Q2400<DYA2448@02Q240QBU00LHaQBU
5:D@Q1BU48@DY@0448@25:D00a246<HHaP025:D00a245:DDY@055:D248@2
5:D01AS65:DDYA245:D00a2400D<HaBU48@DYA24008DY@086<HDYABU48@D
YA2436<@Q0<DY@8@Q0035:D@Q1BU008@Q0<DY@036<H@Q124008@Q08DY@8H
aP035:D@Q1BU00HDY@0648@DYABU48@DYA240QBU11S600HDYAS67>LLib48
7>L46<H00acW5:DHaP086<H37>L00aBU48@@Q0025:D26<H011BU6<HDYABU
0aS600<DYA245:D00QS600<DYAS66<H00acW00PQ21cW7>LQ21cW8@PYBRe[
0SW>00@mkd8@:DXQ208DY@047>LHaQ2436<624800`@Q2488@P0736<26<H0
11BU36<48@@Q0PQ200L<H`Q21248@PaS24848@04248212400`Q236<8@P03
24800`aS48@@Q00348@00aBU48@@Q00436<348@336<348@236<448@00aBU
48@@Q00448@00aS65:DDY@0348@436<248@536<248@01@aS2488@PaS5:D0
11241`aS1A2410aS212400<<Ha2436<011241`aS00D@Q0aS36<<Ha2400<<
H`0548@<H`aS48@<H`0348@00`aS248<H`0348@236<01Q2436<<H`aS48@<
H`<@Q00336<@Q124008@Q08<H`8@Q0<<H`055:D@Q1BU48@DY@0448@436<4
48@336<248@336<948@236<0112436<@Q12410aS00H@Q0aS36<<Ha245:D2
48@00`aS48@<H`0236<648@010aS48@@Q0aS0Q242@aS1A2400@<Ha2448@@
Q08<H`@@Q0045:D@Q0aS36<648@436<348@336<00`Q236<<H`0348@00`aS
248@Q00248@636<011242488@PQ22PaS00<8@PaS36<00PaS0`Q220aS00<@
Q0aS48@00PaS0Q241@aS0@Q2000412400`0012448@0512401aBU9BTHaQ24
6<HLiaS6008DY@036<HDYAS600<DY@8@Q08DY@0348@DYAS6008Li`8HaP8D
Y@8@Q0055:D@Q12448@DY@0448@00aBU6<HDY@025:D01A2436<@Q1245:D0
0Q2400<DYAS65:D00Q240aS60QBU00<@Q1BU5:D00QS60aBU00<HaQBU48@0
0aBU0Q240aBU0Q2400<DYA2448@03Q2400@DYA245:D@Q08DY@T@Q0PDY@8@
Q0<DY@0548@DYAS648@<H`025:D00aS65:D@Q00548@35:D01A245:DDYAS6
5:D00a2400<DYA245:D00QBU0Q2400D<Ha2448@DYA24008DY@0348@DYABU
008DY@0548@DYAS65:DHaP025:D248@011BU6<HHaQBU0Q240QBU00<@Q1BU
5:D011BU0QS60QcW00LHaQcW6<HHaQBU6<HLi`026<H011BU6<HHaQBU1AS6
0R4800<HaQBU48@01ABU00@HaQcW5:DDY@8@Q08DY@DHaP065:DHaQS67>LQ
21cW0b4800DLib489BTaS48@008icP04?NlYBR485:D27>L011BU48@<H`aS
1@Q200@<H`Q224848@8<H`04248<H`aS48@25:D00a242488@P08248010@Q
2488@P@Q10Q200@48@Q22488@P848@0436<@Q1246<H248@936<0112436<8
@PaS0Q240`aS00L@Q1BU48@@Q0aS48@DY@0348@00aBU48@DY@035:D00a24
36<<H`0236<00a2436<<H`0236<248@436<248@00`aS48@<H`0336<348@2
36<00`Q236<@Q00348@00aBU48@<H`0236<011BU48@@Q1240`aS0Q240PaS
0Q240PaS00@8@PaS48@@Q08<H`03248<Ha24008@Q0D<H`03248<H`aS00@<
H`0448@<Ha2448@436<248@236<348@01aBU36<<H`aS5:D<H`Q2008<H`03
48@<H`aS00@@Q08DY@0348@DYA2400D@Q0H<H`@@Q0<<H`8DY@8@Q00336<@
Q124008@Q0@<H`0448@<Ha2448@536<448@00`aS48@@Q00436<00a2436<<
H`0248@011BU48@@Q1240PaS00L8@Q2448@@Q0aS248<H`0248@00`aS48@D
Y@0236<248@00aBU48@<H`0224801A245:D@Q12436<00Q240PaS00<@Q0aS
36<010aS0Q240`aS00<8@PaS36<00a2400@<H`Q236<8@P8@Q0H<H`03248<
H`aS00D<H`03248<H`aS00@<H`88@P0336<8@PaS00D8@P0336<8@PaS00P<
H`<@Q0<<H`448@0000<000@Q00000P@Q00@000@Q124000<48@035:DYBQS6
00@DY@046<H@Q1BU5:D36<H25:D00a245:DDY@035:D56<H25:D011245:DD
YABU11240aBU0a2400@DYA2448@@Q0<HaP0748@DYABU48@DYA245:D00aS6
0a240QBU00<HaQBU5:D00aBU00<HaQBU48@0112400@DYA245:D@Q08DY@8@
Q0<DY@P@Q0065:DHaQS65:D@Q1BU0QS600<DYA2448@00Q240QBU1A240PaS
00@@Q1BU5:DDY@8@Q0<DY@0348@DYABU008@Q0036<HDYA24008@Q0045:D@
Q1BU5:D548@011BU48@DYABU2Q2400@DYA2448@DY@8@Q08DY@8@Q0055:DH
aQBU5:D@Q0035:D00aS65:DDY@0348@35:D00a245:DDY@055:D26<H25:D0
21S65:DLib489BTLiaS65:D27>L25:D36<H45:D01AcW6<HHaQS67>L00QBU
00H@Q1S67>LHaQBU7>L36<H011245:DDYABU0QS600<LiaS66<H00QS60aBU
0aS600dQ22U::DXQ22DY:DXU:AS67>LQ22e[9BTLi`029BT02R487>L@Q124
36<8@Q245:DLiaS60QBU00<@Q1BU5:D00QBU0Q2400<<Ha2448@00PaS0Q24
0PaS00@8@PaS48@DY@8@Q0055:DHaQcW5:D@Q0045:D01Q245:DDYAS65:D@
Q08<H`@@Q00336<@Q0aS00<@Q00436<@Q1BU48@236<00aBU6<H@Q00236<6
48@01PaS5:DDYABU6<H@Q08<H`<@Q0D<H`0348@<Ha2400<<H`8@Q0L<H`04
48@<Ha2448@25:D248@236<0112436<<H`aS0Q2400D<Ha2448@<Ha2400<<
H`03248@Q12400D<H`D@Q0<<H`03248<Ha2400<<H`8@Q0@<H`88@P0348@D
YA24008<H`0548@DYA2448@<H`0248@236<00a2436<@Q00248@01PaS248<
Ha245:DHaP@@Q08DY@P@Q0L<H`8@Q0035:D@Q0aS008@Q0045:D@Q12436<:
48@00`aS48@@Q00348@00`aS48@DY@0248@536<448@00`aS48@@Q00536<0
0a2436<<H`0236<01Q2436<@Q0aS48@<H`D@Q0045:D@Q0aS48@236<548@0
0`aS48@<H`0236<248@236<00aBU48@<H`0336<0112436<<H`aS0Q241@aS
00<@Q0aS36<00a240PaS00<8@PaS36<00PaS00<@Q0aS36<00PQ210aS0`Q2
00H<H`Q236<8@PaS248536<2248236<00a2436<<H`0248@2248336<000H4
8@0300048@@Q00<48@065:DQ21cW48@DYA240QBU0QS60QBU0aS611BU00<@
Q1BU6<H00aS600<LiaS65:D00Q240QBU0Q2400@DYA2436<@Q08DY@036<H@
Q12400<<H`DDY@8HaP8DY@0448@DYABU6<H25:D02A245:DHaQS65:DHaQBU
48@DY@026<H448@00aBU48@@Q0045:D348@35:D00a2436<@Q00448@01`aS
48@DYAcW6<HDYA2400<DY@0448@<H`aS48@25:D00a245:DDY@0448@35:D0
1A2436<@Q1BU48@00aBU00D@Q1BU5:D@Q1BU00D@Q0<DY@<@Q08DY@0448@D
YABU5:D248@01ABU48@@Q0aS48@00QBU00<@Q0aS48@00Q2400<HaQBU48@0
1QBU00<HaQBU6<H01ABU0Q2400<<HaBU48@011BU00DHaQBU6<HHaQBU008@
Q0085:DLiacW6<HQ21cW6<HDY@<HaP035:DHaQS6008HaP8DY@<HaP8Li`04
6<HDYABU5:D86<H45:D96<H02ABU6<HHaQBU6<HLibDY:DXQ20029BT01R48
7>LLibDY;F/U:@8Q20059BTQ21S65:DHaP0236<011245:DLiaS611240aBU
00D@Q0aS36<<Ha2400@<H`04248<H`aS36<248@35:D26<H25:D00a245:DD
Y@025:D01a245:DDYABU36<8@PaS00P@Q0<<H`H@Q0035:D@Q0aS00@<H`04
48@DYA2436<248@26<H248@236<00a2436<@Q00736<00a245:D@Q00236<0
0a2436<<H`02248448@00`aS48@@Q00448@00`aS48@@Q00248@00aBU48@@
Q00236<348@436<00a2436<<H`0336<01Q2436<@Q12436<@Q0@<H`0748@<
H`Q236<@Q1BU48@01PaS0Q240`aS1A240`aS0Q240PaS00D8@PaS36<@Q0aS
00H@Q0<DY@<@Q08<H`0348@<H`aS008<H`0548@<H`aS36<@Q00336<748@2
36<648@010aS48@@Q1BU1Q2410aS00<@Q0aS48@01A2410aS0a2400<<H`Q2
24800Q240PaS00@8@Q2448@@Q08<H`<@Q08<H`035:D@Q0aS00@@Q0<<H`8@
Q0T<H`0348@<H`Q200L<H`8@Q003248<H`aS00@<H`<@Q00336<8@PQ200T<
H`0348@<H`aS0088@P<<H`D8@P0536<@Q12436<8@P0236<248@336<00a24
36<<H`0236<12480000500048@001240000512401`00124@Q2485:D@Q1BU
008HaP035:DHaQS6008DY@046<HLiacW6<H65:D00aS67>LLi`026<H01124
5:DDYABU0QS60QBU00@@Q1BU6<HDY@L@Q08DY@8@Q0045:D@Q1BU6<H35:D0
11245:D@Q1BU0QS60QBU00D@Q1BU5:DHaQBU008@Q08DY@@@Q0035:D@Q124
00<@Q0035:D@Q124008@Q08DY@@@Q0045:D@Q12448@45:D00a245:DDY@02
48@236<65:D00a24248<H`0248@011BU48@DYABU0Q2400@DYA245:DDY@8@
Q0LDY@0436<@Q0aS36<248@00aBU48@@Q0035:D448@010aS48@@Q1240aBU
00<@Q0aS48@00Q241ABU11S600@DYA2448@DY@8HaP@@Q0066<H@Q0aS36<@
Q1BU0QS60QBU0QS600<LiaBU5:D00QBU00<HaQBU6<H011S60QBU00<@Q1BU
5:D00QS60aBU00<HaQBU5:D00QBU00<LiaS67>L00aS600<LiaS67>L00QcW
00PHaQBU7>LU:B487>L@Q1BU1AS600LDYAS65:DDYAS67>LHaP035:D00aS6
48@DY@026<H45:D26<H55:D26<H01ABU6<HHaQcW6<H00QBU00@HaQcW6<HD
Y@8@Q0045:DHaQBU48@25:D248@236<011BU6<H@Q1BU0PaS0Q2400DDYA24
48@@Q1S6008DY@0:36<8@Q245:DHaQ2436<@Q1BU48@236<01A245:D@Q124
36<00a2400H<Ha2448@DYA2436<448@236<45:D248@00aBU48@<H`0736<0
0aBU48@@Q00236<00a2436<@Q00248@00`aS48@<H`0448@236<548@00aS6
5:D@Q00236<448@336<248@536<020Q236<@Q1BU36<8@PaS48@336<01A24
36<48@Q236<00Q240`aS112410aS00<@Q0aS48@011240`aS00<@Q0aS36<0
0PaS00<@Q0aS36<0112400<DYA2448@00Q240PaS00@@Q0aS36<<H`8@Q003
36<@Q0aS00<<H`0448@<Ha2448@25:D00a245:D<H`0236<648@236<25:D0
1Q2436<<Ha245:D@Q0@<H`<@Q08<H`0348@<Ha2400@@Q0<<H`8@Q00336<@
Q0aS008@Q00636<DYA2448@8@PaS0Q240aBU112410aS00<@Q0aS36<00a24
00<<H`Q224800PaS00@@Q0aS36<<H`8@Q08<H`0548@<H`Q236<@Q00436<0
112436<<Ha242PaS00@@Q0aS36<@Q08<H`0548@<H`Q2248<H`0248@01@aS
2488@PaS24804@aS0A240@Q2000812403P0012448@@Q48@Q21S648@DYAS6
5:DHaQBU6<H25:D36<H25:D348@00aBU6<HLi`066<H35:D00aS65:D<H`02
48@01QBU48@@Q1BU6<H@Q08<H`PDY@036<HDYABU00@DY@0448@DYAS66<H2
5:D00a245:D@Q0045:D448@25:D348@25:D011245:DDYA240PaS0Q240PaS
0a2400<DYAS65:D00a240QBU0a2400HDYA245:DDYA245:D548@010aS48@@
Q1BU0a241aBU0Q240QBU112400@<Ha2448@DY@8@Q0045:D@Q1BU5:D948@0
0aBU48@@Q00448@35:D248@00aBU6<HLi`025:D00a246<HHaP045:D248@2
5:D248@01@aS5:DDYABU6<H00aBU0aS600@@Q1BU5:DLi`8HaP@DY@8@Q08D
Y@036<HDYAS6008DY@0448@DYABU5:D36<H01QcW6<HHaQBU6<HLi`<HaP8L
i`056<HLib487>LHaP025:D011cW6<HHaQS611BU0aS600<DYAS65:D00aBU
00HHaQ245:DDYAS67>L36<H25:D00a245:DHaP026<H25:D27>L35:D00aS6
7>LHaP0348@45:D00a245:D@Q00248@01@aS6<HHaQS648@00PaS00<@Q1BU
48@00Q2400DDYAS65:D@Q0aS00H@Q00336<@Q124008@Q00336<@Q124008@
Q00636<@Q1245:D@Q0aS0Q2400@DYA2436<<H`8@Q00436<@Q1246<H25:D0
1Q245:D<Ha2436<@Q0@<H`0348@<H`aS00<<H`8@Q0<<H`<@Q00536<@Q0aS
48@<H`0248@25:D00`aS48@@Q00248@00`aS48@@Q00536<00a2436<<H`03
248010aS48@8@PaS0a2400D<Ha2436<<H`Q200D<H`0348@<H`aS00D<H`8@
Q00436<@Q0Q236<248@010aS48@<Ha241@aS00@@Q0aS36<@Q08<H``@Q08<
H`8@Q00336<8@PaS00<<H`<@Q08<H`<@Q0035:D@Q124008@Q08<H`@@Q08<
H`0348@DYABU008@Q08<H`8@Q0@<H`0348@<Ha2400@@Q08<H`8@Q00436<8
@PaS48@236<00`Q236<<H`0236<0112436<<Ha240PaS0Q2400LDYA2448@<
Ha2436<@Q00436<01a2436<<Ha2436<8@PaS008@Q00336<8@PaS008@Q0H<
H`0348@<H`aS00<<H`8@Q0X<H`05248<Ha2436<@Q00236<01@Q236<<H`aS
48@00PaS0PQ200<@Q0aS24800PQ20Q2400@<H`Q236<8@P8<H`0448@<H`aS
36<348@00`Q236<<H`0124800006124000@Q00048@000`@Q00T000@Q124@
Q2DY7>LDYAcW6<H01ABU0QS600DQ21cW6<HDYAS600<DY@036<HLiaS6008H
aP037>LHaQS6008HaP8DY@8HaP085:DHaQ2448@DYA245:D@Q08DY@0448@H
aQBU5:D248@00aBU6<HDY@0248@01QBU48@@Q1BU48@HaPPDY@<@Q0<DY@D@
Q0046<HDYABU5:D336<248@236<348@35:D27>L01QBU48@@Q1246<HDY@8@
Q00336<@Q12400<@Q0035:D@Q1BU00<@Q0065:D@Q12448@<Ha240QBU0Q24
00<DYAS65:D0112400<DYA2448@00Q2411BU00@@Q1BU5:DDY@@@Q0035:D@
Q1BU00<DY@0448@DYABU5:D348@00aBU48@DY@035:D56<H25:D248@01ABU
48@@Q1BU48@00QBU00<@Q0aS48@00QBU11S61QBU0aS60aBU00LHaQBU48@@
Q1BU6<HDY@0248@25:D248@01AS65:DDYAS65:D00aS60aBU00<HaQcW8@P0
0QcW0RDY00DYBRDY6<HHaQcW008Q20056<H@Q1245:DHaP065:D00aS65:DD
Y@0348@35:D00a245:DDY@025:D02Q2436<<Ha245:D@Q1BU48@HaQBU0Q24
00<DYA2448@00PaS1A240PaS0QBU00@HaQBU48@@Q08DY@0348@DYA2400@@
Q08DY@097>LHaQS648@<Ha245:DHaQBU00H@Q0035:D@Q12400@@Q08<H`03
48@DYA2400D<H`<@Q00336<@Q1BU008HaP8DY@8@Q0H<H`<@Q0<<H`0848@D
YA2448@<Ha245:D@Q08<H`0348@<H`aS008<H`0548@DYA2436<@Q0025:D2
36<348@336<00a2436<<H`0436<00`Q248@DY@0248@236<248@736<248@4
36<00a2436<@Q00236<348@00aBU36<<H`0436<00a2436<<H`0336<00a24
36<<H`0236<0112436<<H`aS112400<DYA245:D01Q2400<<Ha2448@01A24
00@<Ha2436<<H`<@Q0055:D@Q12436<@Q0045:D00`aS48@@Q00248@011BU
48@DYA240PaS11240PaS00<@Q0aS36<0112400<8@PaS36<00a2400<<Ha24
48@00PaS00@8@Q2436<@Q08<H`0848@DYABU48@<Ha2436<@Q10<H`8@Q08<
H`05248<H`aS36<@Q00236<00a2436<8@P0536<224800`aS248@Q00236<0
0`Q236<<H`0536<011245:D@Q0aS0PQ210aS00@@Q0aS2488@PT<H`06248<
Ha2448@<H`Q20`aS0@Q200000`0012448@0912401QBU9BTHaQBU6<HDY@8H
aP045:DHaQBU6<H47>L25:D011S65:DHaQBU0aS60QcW0QS600LDYAS66<HD
YA245:DHaP035:D01A245:DDYABU48@00aBU0a2400<HaQBU5:D00aBU00@@
Q1BU5:D@Q08DY@8HaP<DY@046<H@Q12448@25:D348@25:D01AS648@DYA24
6<H00QBU0a2400<<Ha2448@00a240QBU00P@Q1BU6<HLiaBU48@<Ha240QBU
00LHaQBU48@<Ha2436<DY@036<H348@00aBU48@@Q0025:D248@35:D248@3
5:D248@25:D248@00`aS5:DDY@0348@36<H01ABU48@DYA246<H00aBU0Q24
1ABU00H@Q1BU48@@Q1BU48@25:D36<H00acW6<HDY@0248@00aBU6<H@Q002
5:D448@25:D00a245:DDY@025:D36<H011245:D@Q1S60QBU0QS600dDYAS6
6<HHaQBU48@DYAS65:DHaQ245:DHaP0248@35:D00a245:DHaP026<H01Q24
5:DLiaS65:DLi`8Q20066<HQ22DY;F/YBQcW0QBU00HHaR486<H@Q1BU6<H2
5:D248@25:D011S65:DDYABU0Q240QBU00@HaQBU5:DHaP<DY@@@Q08DY@@@
Q0<DY@@@Q08<H`0448@<Ha2448@25:D011S65:D@Q1240aBU0Q240PaS00<D
YA2448@00QBU0QcW00<@Q1BU48@00QBU0Q2400<DYAS648@01@aS00DDYA24
48@@Q0aS00<@Q08<H`0348@<H`aS00<<H`0548@<H`aS48@DY@026<H00aBU
48@@Q00336<248@336<00a2436<<H`0748@236<348@236<00a2436<<H`02
36<248@00aBU36<<H`0248@336<248@236<00a2436<<H`0536<348@00`aS
48@DY@0236<010Q236<<H`aS0a2400P<H`Q236<<Ha2436<@Q0aS0a2400D<
Ha2436<@Q0aS00@@Q00336<@Q0aS008<H`8@Q0<<H`0348@DYA24008<H`03
48@<H`aS00D@Q00336<@Q1BU00<@Q00336<@Q0aS00H@Q00736<@Q1245:D@
Q0aS48@00aBU00<@Q0aS48@00Q240PaS00<@Q1BU5:D011241PaS112400D8
@PaS48@DYA2400<<H`0348@<H`aS008<H`0348@<Ha24008@Q08<H`8@Q0<D
Y@<@Q00636<@Q0aS48@<Ha2410aS00<@Q0aS36<00`aS00<@Q0aS48@00PaS
00<@Q0aS48@00`aS00<@Q0aS36<00`aS0Q240`aS0`Q200<<Ha2448@00PaS
0a2400H8@PaS48@@Q1BU48@3248010aS48@@Q1240`aS00<@Q0Q236<01PaS
0Q2400<<Ha2436<00PaS0`Q200021240100012448@000`@Q00T000@Q124@
Q2DY7>LDYAS65:D00Q241ABU0QS60QcW00<HaQBU6<H011BU00LLib487>LL
iaS65:D@Q0025:D00acW6<HHaP026<H45:D0212436<@Q1S67>LHaQBU48@5
5:D26<H01QBU48@DYABU6<HDY@<@Q0<DY@8@Q0DDY@036<HDY@aS008<H`08
48@DYABU36<@Q1BU48@DY@<@Q08DY@8<H`0348@DYAS6008DY@<@Q0@DY@<@
Q0@DY@8@Q08DY@0348@<Ha2400<DY@8@Q0045:D@Q12448@45:D448@00`aS
5:D@Q0025:D011245:DDYA240aBU0a2411BU0Q2411BU00<HaQBU5:D00a24
0QBU00<HaQBU6<H02ABU00@@Q1BU5:D@Q0<DY@036<HDYABU008DY@8HaP04
5:DHaQBU6<H45:D26<H25:D01QS65:D@Q1245:DHaP@DY@036<HDYABU008D
Y@0348@DYA24008@Q0<HaP8Li`<HaP037>LQ21cW008YBP8U:@<Li`<HaP04
5:D@Q0aS5:D26<H248@45:D248@01AcW:DXU:AS648@00QS60QBU00@@Q1BU
5:D@Q08DY@0448@DYA2448@35:D00a2436<@Q00248@336<00a245:DHaP03
5:D348@00aBU6<H@Q00548@01@aS48@@Q1BU7>L00QS600<DYA245:D00QS6
0QBU0a240QBU00@@Q0aS36<@Q08DY@X@Q00336<@Q124008<H`8@Q0036<HD
YABU00@@Q00536<@Q1245:D@Q00336<248@01@aS48@@Q12436<00Q2400<D
YA2436<00PaS00D8@PaS36<@Q0aS00@@Q0@<H`8@Q08<H`04248<H`Q22484
36<00`Q236<@Q0025:D00acW5:D@Q00236<248@436<0212436<<Ha2436<@
Q0aS48@536<01A2436<@Q0aS48@010aS00@@Q0aS36<<H`8@Q00536<@Q124
5:D@Q00236<548@00aBU48@DY@025:D348@25:D00a2436<@Q00448@010aS
48@@Q1240`aS0Q2400HDYA2436<@Q0aS48@35:D248@35:D0112436<<H`aS
0Q2400<<Ha2436<011240`aS11240PaS00<@Q0aS5:D00QBU00<@Q0aS36<0
0Q241@aS00D@Q0aS36<<Ha24008<H`<@Q00436<8@PaS36<248@336<00a24
36<<H`0536<00a2436<<H`0224800`aS248@Q00248@324800`aS48@@Q002
36<2248248@236<00`Q236<<H`0448@00`aS2488@P0336<01PQ236<@Q124
36<@Q0L<H`0448@<Ha2448@236<00`Q236<<H`0124800005124000@Q1240
0007124011248@PHaQ240QBU00D@Q1S65:DDYA2400<HaP037>LHaQBU00@H
aP0348@DYABU00<Li`8HaP045:DHaQS66<H27>L26<H248@35:D021245:DD
YABU6<HDYA245:D248@45:D00aS65:DDY@0348@25:D248@35:D00a2436<@
Q00248@011BU6<HDYA240PaS0Q2400LDYA2448@@Q1BU48@<H`0248@00aBU
48@@Q0025:D00a245:DDY@035:D00a245:D@Q0035:D448@011BU6<HHaQ24
0PaS0QBU0a240QBU00L@Q1BU48@DYA245:D@Q0045:D00a2436<<H`0348@0
0aBU48@DY@026<H00aBU36<@Q0025:D248@25:D00a2436<<H`025:D26<H0
1ABU48@@Q1BU48@01ABU00LHaQBU5:DHaQBU48@DY@026<H00aBU48@@Q004
5:D02AS65:DDY@aS48@DYAS67>LHaP035:D26<H25:D46<H75:D36<H25:D0
1AS65:DDYA245:D00a2400@DYAS67>LLi`8HaP045:DHaQcW7>L38@P29BT0
0b487>LLi`036<H011BU6<HDYAS60QBU0Q240aBU00LHaQBU248@Q248:DXU
:@0248@00aS67>LHaP0248@00aBU48@DY@0348@55:D01A245:D@Q0aS2480
0Q240PaS00<@Q1BU6<H00QBU0Q240QBU0Q240aBU00/@Q0aS36<<Ha245:D@
Q1S67>LHaQBU008@Q0@DY@066<H@Q12448@DYA240PaS00<@Q1BU48@00PaS
00<@Q0aS36<00a240PaS0Q2400DDYA2436<<HaBU008HaP8@Q08DY@D<H`03
48@<H`aS00L@Q00336<@Q0aS00H<H`0448@<H`aS48@336<648@936<22482
36<00aBU36<DY@027>L00aBU36<8@P0248@00`aS248<H`0348@336<248@5
36<348@336<348@336<248@236<00a2436<@Q00436<00a2436<<H`0348@0
0`aS48@DY@025:D010aS48@@Q0aS0Q240QBU00@<Ha2448@DY@D@Q00336<@
Q1BU00<@Q0045:D@Q0aS48@35:D011245:DDYA240PaS00<@Q0aS36<01A24
00<<Ha2448@01@aS0Q240`aS00<@Q1BU6<H00Q2400L<Ha2448@@Q0aS48@D
Y@0248@00`aS48@@Q00336<348@336<00`Q236<<H`0248@236<00`Q236<<
H`0336<348@736<248@636<00a2436<<H`0236<248@010aS248<H`aS0Q24
00<DY@aS24800`aS00<@Q0aS36<00PaS00<8@PaS36<02`aS00<@Q0aS36<0
0PaS0@Q200000`0012448@0312400`0012448@0312401QBU:DXLia245:DH
aP<DY@076<HDYABU5:DHaQBU6<H011BU2AS60QBU00HHaQBU7>LQ21cW6<H4
5:D00aS65:DDY@025:D36<H00a245:DDY@036<H00aBU48@@Q0026<H35:D3
48@25:D00a245:DDY@0448@00aBU48@@Q00348@00aBU48@@Q00648@010aS
48@DYABU0Q240QBU00<@Q1BU48@011BU11240QBU00<@Q1BU5:D00QBU2124
0QBU0Q2400@<HaBU5:DHaP8DY@8@Q0<DY@0348@<H`aS008@Q0@DY@036<HD
YABU008@Q0035:D@Q12400<DY@<@Q0045:DHaQBU5:D448@35:D00a245:DH
aP055:D011S65:D@Q1BU0Q2411BU00D@Q1BU5:DHaQBU008@Q0035:D@Q1BU
00<HaP8DY@<HaP<DY@8Li`046<H@Q1BU6<H35:D011S648@@Q1240QS61ABU
00@HaQcW7>LHaP8DY@057>LQ22488@PU:@027>L26<H00aBU6<HHaP025:D2
6<H011cW6<HLiacW11S600@DYA245:D@Q0@HaP8DY@036<HDYABU008@Q006
5:DLiacW5:D@Q0aS11240PaS00D@Q1BU48@@Q0aS008@Q0045:D@Q12448@2
5:D548@01ABU48@DYA245:D0112411BU00<HaQcW8@P00acW00<Q21BU5:D0
0QBU0QcW0QBU0Q240QBU0a240`aS0Q2400@<Ha2448@DY@8@Q00636<@Q0aS
48@DYA240QBU11240PaS1A2400<8@PaS36<011240`aS00<@Q0aS36<01PaS
00D@Q1BU48@DYA2400<<H`8@Q0<<H`04248<H`aS36<2248010aS48@@Q1BU
0a2400<DYA2448@01@aS0Q2400<<Ha2436<00Q240`aS0Q241PaS00<@Q0aS
36<00PaS00<@Q0aS36<00PaS1A2410aS0a2400<<Ha2436<00Q240QBU00@@
Q1BU48@DY@<@Q0045:D@Q12448@436<248@00aBU48@@Q00248@00aBU36<@
Q00348@436<00a2436<<H`0348@01QBU48@@Q0aS48@<H`8@Q08<H`8@Q003
36<@Q0aS008<H`<@Q0@<H`0348@<H`aS008<H`0348@<Ha24008<H`8@Q0<<
H`0348@DYA2400<@Q0@<H`<@Q0D<H`<@Q08<H`03248<Ha2400<<H`04248<
H`aS36<248@336<348@224800`aS248@Q0045:D436<248@636<01A2436<8
@Q245:D00QcW0Q241@aS0@Q20@aS0@Q2000312400`001240000312401`00
12448AS69BTHaPaS00<DY@<@Q0045:DHaQS65:D36<H25:D02AS65:DHaQBU
48@DYAS67>LHaP025:D00acW6<H@Q0026<H00b487>LDY@075:D26<H25:D3
6<H00aBU6<HDY@036<H248@65:D011245:DDYABU0a240QBU00@@Q0aS36<@
Q08DY@D@Q00;36<DYABU48@<Ha2436<DYA245:D@Q0035:D248@35:D348@2
5:D01A245:DDYA245:D00Q2400<<Ha2448@00a2400DDYA2448@@Q1BU008@
Q0045:DHaQS65:D248@00aBU48@@Q00448@01ABU6<H@Q1245:D00QS60Q24
0QBU1A241aBU0Q2400@<Ha245:D@Q0<HaPTDY@8@Q0035:DLiaBU008@Q0DD
Y@8HaP045:D@Q1BU5:D26<H35:D27>L00aS65:DDY@027>L011S648@DYAS6
0QBU0Q240QBU00HHaQBU5:D@Q1BU7>L26<H25:D011cW6<HHaQS60acW00DU
:B488@PQ21S6008DY@0348@DYABU008HaP035:DHaQS6008HaP035:DHaQBU
008HaP<DY@8HaP055:DHaQS65:D@Q0035:D00aS65:DDY@0348@25:D00a24
36<<H`025:D00a2436<DY@0248@02@aS48@DYABU48@DYA245:D@Q0045:D2
48@00`aS48@@Q00448@021BU6<HHaQ246<HLibDY8@P26<H011cW6<HDYABU
0aS60a2400<DYAS648@00PaS0Q2400<<Ha2448@00`aS0a2400<<Ha2448@0
0a2400<DYA2448@0112410aS00<@Q0aS36<010aS0Q2400<<Ha2436<010aS
0Q240`aS00<@Q1BU48@0112400DDY@aS36<<Ha2400<<H`07248<H`aS36<8
@PaS48@00QS600@@Q0aS48@@Q08DY@L<H`0448@<Ha2448@336<224803@aS
48@@Q0aS248<Ha2436<@Q0aS48@<Ha2400@<H`@@Q00536<@Q0aS36<@Q003
36<00a2436<@Q00348@25:D248@010aS48@DYABU0Q2410aS0Q2400<DYA24
48@00Q240QBU00<@Q1BU48@01A2400<DYA2436<00PaS00D8@PaS48@DYA24
008<H`0448@DY@aS36<248@436<248@00aBU48@@Q00236<348@336<248@0
10aS48@<H`aS0Q240`aS00H@Q1BU48@<H`Q236<348@336<348@436<448@0
1@aS248<H`aS48@00PaS0Q2410aS00@@Q0aS36<@Q08<H`03248<H`aS008<
H`045:DHaQBU48@436<00a2436<<H`0236<02PQ236<<H`aS248<Ha245:DL
iaS60Q2400<<Ha2448@01@aS00000`001240000512402P0012448@@Q5:DY
BQcW48@DYA240QBU00D@Q1BU5:DLiaS6008DY@<HaP8DY@036<HDYAS6008H
aPDDY@046<HLiacW6<H37>L36<H25:D26<H25:D00a245:DDY@026<H35:D0
1AS65:DDYABU6<H00QBU00@HaQBU6<HHaP8DY@0648@DYABU5:D@Q0aS0Q24
00<<Ha2448@00Q2400<<Ha245:D00QBU00@@Q1BU48@DY@8@Q00636<@Q124
48@DYAS60QBU0Q2400@HaQBU48@@Q08DY@<@Q0@DY@H@Q0<DY@D@Q0045:D@
Q12448@25:D011S65:D@Q1BU0Q2400<DYA245:D00a240QBU00HHaQBU5:D@
Q1S65:D348@25:D548@26<H01QBU48@@Q1245:DHaP<DY@036<HDYABU008@
Q0<DY@8@Q0036<HDYABU00@DY@8HaP8DY@0448@DYAS66<H25:D00a245:DD
Y@035:D26<H011BU6<HHaQcW0QS60aBU0aS600@DYA2448@DY@8@Q08DY@8L
i`<HaP045:DHaQS67>L25:D021cW9BTYBRe[7>LQ21S65:D26<H01QcW5:DD
YAS67>LHaP<DY@037>LHaQBU00<HaP035:DHaQS6008HaP<DY@8HaPDDY@03
6<HDYABU008<H`8@Q0055:D@Q0aS36<@Q0025:D0112436<@Q1240aBU00H@
Q0aS48@DYA245:D248@01@aS48@DYA245:D01A2400@DYAS67>LHaP8DY@05
6<HDYA245:DHaP028@P27>L01AS65:D@Q1245:D00PaS1a2400@DYA2448@@
Q08DY@<<H`0348@DYA2400D@Q00336<@Q124008@Q0<<H`D@Q0<<H`@@Q08<
H`0448@<H`aS36<35:D248@01ABU48@<H`aS48@00PaS00<8@PaS48@00PaS
00<@Q0aS36<00PaS1a240`aS00@8@PaS48@@Q0<<H`0548@<H`aS36<8@P03
36<0112436<<Ha2410aS0Q2410aS00<@Q0aS48@00QBU00<@Q0aS36<00PaS
0Q2400@<Ha2436<@Q0<DY@<@Q0055:D@Q12448@<H`0448@00`aS48@DY@02
48@00`aS48@DY@025:D348@25:D00a2436<@Q00536<01A2436<<H`aS48@0
0PaS11241`aS00<@Q0aS36<00a2410aS0a2400@<Ha2448@@Q08<H`8@Q003
36<@Q124008@Q0<<H`<@Q08<H`8@Q08<H`D@Q0065:D<H`aS36<DYA240`aS
00<@Q0aS36<00PaS0Q240`aS00<@Q0aS24800PQ200<@Q1BU5:D00QBU00@@
Q0aS48@@Q08<H`03248<Ha24008@Q00436<8@PaS48@236<011245:DLiaS6
0QBU00@@Q0aS36<<H`8@Q04<H`48@P001@@Q00<000@Q124010@Q00@DYBDY
7>L@Q08DY@036<HDYABU008DY@056<HLiaS66<HDY@026<H25:D00a245:DH
aP026<H25:D248@00aBU7>LLi`027>L00b487>LHaP036<H35:D26<H25:D2
6<H00aBU6<HHaP035:D01A246<HHaQS65:D00Q2400DDYAS66<HDYAS600<D
Y@0448@DYABU48@236<011245:DDY@aS0Q240QBU0a2400<DYA2448@00Q24
00<<HaBU5:D00aBU00<@Q1BU5:D00QBU00<@Q1BU48@00a240QBU00@HaQBU
6<HDY@X@Q0DDY@8@Q08DY@036<HDYA2400H@Q08DY@<@Q08DY@0648@DYABU
48@DYA240QBU0a242ABU0Q240QBU0aS60QBU0Q2400HDYA245:DHaQBU48@2
5:D36<H35:D00a246<HHaP026<H35:D248@35:D00aS65:DHaP036<H011cW
5:DDYABU0QS61QBU0PaS00<DYAcW8@P011S600@LiaS65:DDY@8HaP8Q2004
;F/YBR487>L76<H011BU6<HHaQS60aBU00<HaQcW6<H00aS60QBU0aS600<D
YA245:D00aS611BU0QS600T@Q0aS36<@Q1BU48@<Ha245:D00Q2400<<Ha24
48@00QBU0a2400@DYA2448@@Q08<H`8@Q0035:D@Q1BU00<<H`0848@DYA24
5:DHaQcW6<HDY@8HaP8@Q0036<HLibDY00<Li`055:D@Q1BU6<HDY@0248@0
0`aS48@@Q00248@010aS48@@Q1BU1A2400@<Ha2448@DY@L@Q00336<@Q0aS
008<H`0348@DYA24008<H`8@Q08<H`8DY@0348@<H`aS00D<H`0448@DYABU
36<248@011BU48@<H`aS0Q240`aS0PQ20PaS112400@DYA245:D@Q08DY@@@
Q08<H`04248@Q0aS36<248@236<02@Q236<<Ha2436<8@PaS248<H`0348@5
36<748@011BU48@<Ha240`aS0Q240PaS0a2400<DYA245:D00Q240aBU0a24
10aS11BU00@HaQ245:D@Q08DY@8@Q00:36<@Q0aS48@<Ha2436<@Q0aS48@3
36<248@236<448@00`aS48@<H`0436<01Q2436<@Q0aS48@<H`8@Q0<<H`8@
Q0@<H`<@Q0<<H`8@Q0@<H`0348@<Ha24008@Q00536<@Q1245:D@Q00236<0
0a245:D@Q00:36<00a2436<<H`0336<00a2436<<H`0236<348@35:D348@0
10aS248<H`aS0Q2400<8@PaS48@00PaS00H8@PaS48@@Q1cW5:D26<H248@2
36<00`Q236<<H`0136<0000300048@0000<48@0400048@@Q0002124011BU
9BTLi`aS0aBU00<HaQBU6<H00acW00LHaQBU6<HHaQcW6<HDY@036<H35:D3
6<H01AcW6<HLiacW6<H00QcW00@HaQBU6<HHaPPDY@8HaP035:DHaQS6008D
Y@<HaP045:DHaQS66<H35:D01AS65:DDYA245:D00Q2400<<Ha2436<01124
00<DYA245:D00QBU00<HaQBU5:D00Q2400<DYAS65:D00a2400@DYA2448@@
Q08DY@046<H@Q12448@25:D010aS48@@Q1S60QBU00<@Q1BU48@00a241ABU
00<@Q0aS36<00a2400<DYA2448@00a2400LDYAS648@@Q0aS48@HaP035:D0
1AS65:DDYA245:D00Q241ABU00<@Q1BU48@01aBU0Q2411BU0Q2400<DYA24
48@00aBU00D@Q1BU5:DDYAS6008DY@036<H@Q1BU00<DY@8@Q0076<HDYA24
5:DHaQcW6<H00aBU0Q240aBU00@HaQBU5:DHaP8DY@036<HLiaS6008@Q00=
5:DHaQS65:D@Q0aS48@HaQcW6<HDYA2436<011BU00DHaQBU48@HaR48008U
:@@Li`@HaP@DY@0348@DYABU008HaP8DY@036<HLib48008HaP8DY@<Q2004
6<HDYABU6<H25:D011245:DDYABU112400<HaQBU48@0112400DDYA246<HH
aQBU00<@Q08DY@0648@<H`aS36<@Q1BU21241QBU00@HaQBU5:DHaP<@Q08H
aP035:D<H`aS00<@Q0055:DHaQS648@<H`0248@01QBU48@@Q0Q248@DY@8@
Q00336<@Q12400DDY@0536<8@PaS36<DY@0248@336<448@436<848@236<0
1A245:DDYAS65:D00Q2400@<Ha2448@<H`8@Q00336<8@Q24008@Q0D<H`@@
Q08DY@<<H`8@Q0<<H`03248<H`aS00@<H`03248<H`aS00P<H`8@Q08<H`8@
Q004248<H`aS5:D448@010aS48@@Q1240PaS0Q2400<HaQBU5:D00QBU0a24
00DDYA2448@@Q1BU008@Q00336<@Q1BU008@Q00536<@Q1BU48@DY@0248@0
0aBU36<<H`0236<348@436<00a2436<<H`0536<00a2436<<H`0236<00a24
5:D@Q00336<01A2436<<H`aS48@010aS11240`aS0Q240`aS0Q2400<<Ha24
48@00`aS00@@Q0aS36<<H`8@Q08<H`0548@DYA2448@<H`0348@336<248@4
36<00a2436<<H`0236<00`Q236<<H`0336<25:D00a2436<<H`0248@00`aS
248@Q00436<00a2436<<H`0436<248@25:D336<648@136<000@48@030004
8@@Q00D48@045:DQ21BU48@55:D00aS67>LLi`076<H25:D66<H25:D01QS6
7>LLib487>LHaP8DY@037>LHaQS600DDY@DHaP8DY@056<HDYAS66<HDY@04
6<H25:D26<H25:D248@00aS648@@Q00648@02QBU48@DYAS65:DHaQBU48@H
aQBU0QS600<DYA2448@00a2400<DYA245:D011BU1A240QBU0QS6112400@D
YA2448@@Q0<DY@0336<@Q1BU00<@Q0055:D@Q12448@DY@026<H01QBU48@@
Q0aS5:D@Q0DDY@8@Q08DY@036<HDYABU008@Q08HaP035:D@Q12400<DY@03
48@DYA2400@DY@0348@DYABU00<DY@8@Q08DY@056<HDYA2448@DY@0248@0
0aBU6<HDY@035:D00aS648@DY@035:D00a245:DDY@025:D00a245:D@Q003
5:D01QS65:DHaQBU6<HDY@<HaP8@Q08DY@046<HDYA2448@25:D26<H35:D0
0a245:D@Q0025:D01AS65:DHaQS67>L00R4811cW00<HaQBU6<H00aS61ABU
00HHaQBU6<HDYAS67>L28@P25:D27>L011S65:DDYAS611BU0QS600DDYA24
48@@Q1BU00<@Q0<DY@0436<@Q1245:D26<H00aBU48@@Q0025:D0112436<<
Ha240aBU00<@Q0aS36<00Q2400@DY@aS48@@Q08DY@0348@DYABU00DDY@08
48@DYABU5:D@Q0aS48@DY@@@Q0@DY@<@Q00336<@Q12400<@Q08<H`<DY@03
48@<H`aS00@<H`0348@<H`aS00<@Q003248<Ha2400@<H`<@Q0<<H`8@Q08<
H`<@Q0036<HDYABU00H@Q0H<H`8@Q0@<H`0548@DYA245:D@Q00636<00a24
36<@Q00736<00`Q236<<H`0836<448@236<348@00`aS48@@Q00248@02@aS
48@@Q12436<DYA2436<@Q0026<H00aBU48@@Q0025:D448@010aS48@@Q1BU
112400<DYAS648@00a2400HDYA2448@@Q0aS48@236<00`Q248@@Q00236<0
0`Q236<@Q00348@436<00a2436<@Q00248@236<00`Q236<@Q00236<01Q24
36<<Ha2436<@Q08DY@0348@<H`aS008@Q0<<H`8@Q0L<H`0:48@DYA2436<8
@PaS48@<Ha245:D248@236<248@236<00`Q236<<H`0636<00a2436<<H`02
36<01PQ236<@Q0aS48@<H`8@Q0035:D@Q124008<H`0448@<Ha2448@536<0
0`Q236<8@P0236<35:D348@00`aS48@@Q00336<12480000300048@000084
8@0?00048@@Q124000@Q248DYBU:6<H<Ha246<HDYAS600<DY@8HaP035:DH
aQS600DHaP035:DHaQS600DHaP045:DHaQcW6<H37>L26<H00aBU6<HHaP02
6<H00aBU6<HDY@026<H01aBU6<HHaQBU6<HLiaS6008DY@0448@DYABU6<H2
5:D00aS65:DHaP035:D248@00aBU48@DY@0348@02aS648@<H`aS48@HaQBU
48@DYAS65:D00Q2400DHaQBU5:D@Q1BU00<HaP@@Q08DY@H@Q0035:D@Q124
00<@Q08DY@0348@DYA24008@Q0<DY@096<HDYA2448@DYAS65:D@Q0aS00H@
Q00?5:D@Q12448@DYAS65:D@Q0aS48@DYA245:DHaQBU00<@Q0<DY@0548@D
YABU48@DY@0348@011BU6<HHaQBU0a241aBU00<@Q1BU48@00QS600PDYAS6
5:D@Q1BU48@HaQBU0Q2400<HaQcW5:D00QBU0aS600DDYA245:DDYAS600<D
Y@@HaP057>LDYA2448@DY@046<H55:D00a245:D@Q0045:D00a246<HDY@03
6<H27>L26<H011BU6<HHaQBU0QS60QcW00@@Q0aS48@@Q08HaP8DY@0848@D
YAcW6<HDYA246<HLi`8HaP8Li`046<HDYABU5:D348@01ABU48@DYABU6<H0
0QBU0Q2400@HaQBU5:D@Q0DDY@0348@<H`aS00<@Q00436<@Q1245:D248@0
0`aS48@@Q00348@00aS65:DDY@0248@00aBU48@@Q00448@95:D248@45:D0
0a245:D@Q00236<011245:D@Q0aS212410aS0a240`aS11240PaS1a2400P<
Ha2448@@Q0aS48@<Ha240QBU0a2400<DYA2448@00a2410aS00D8@PaS36<<
Ha24008<H`0448@<Ha245:D248@00`aS48@<H`0236<01Q2436<8@PaS48@<
H`<8@P8<H`8@Q00336<@Q124008<H`<@Q0<<H`0;48@<H`aS248@Q0aS48@D
YA245:D@Q00336<00`Q248@DY@025:D248@35:D02A2436<<H`aS48@HaQBU
48@<H`025:D00`aS48@@Q0026<H448@021BU48@@Q12436<@Q0aS48@336<3
48@436<01A2436<<Ha2436<00a2400<<Ha2448@010aS00@@Q0aS48@<H`L@
Q0<<H`0348@<Ha24008<H`0348@<H`aS00<<H`04248<H`aS5:D248@00`aS
48@@Q0035:D248@336<010Q236<<Ha240`aS0a240`aS00H@Q0aS36<<H`Q2
36<248@236<00`Q236<@Q00636<00a2436<<H`0236<00a2436<8@P0236<0
1124248<H`aS0Q240`aS00@8@Q2448@<H`48@P001P@Q00<000@Q12400`@Q
00@HaRU:7>L<H`<DY@046<HDYAS65:D76<H35:D26<H00acW6<HDY@035:D3
6<H37>L01aS67>LHaQS65:D@Q1BU00@HaP065:D@Q1S67>LHaQcW0QBU00<H
aQBU5:D00QBU00<HaQBU5:D00QBU11S600@DYA2448@@Q08<H`8@Q0035:D@
Q0aS00<@Q08DY@076<HDYA245:D@Q1BU48@01ABU0QS600<DYA2448@00QBU
00<@Q1BU48@00QBU11240aBU00@@Q1BU48@DY@8@Q0<DY@0648@DYABU5:D@
Q0aS0Q240QBU00<@Q0aS36<0112400@DYAS648@<H`L@Q0@DY@0348@DYABU
008HaP0948@DYABU48@DYA245:D@Q1BU008@Q0045:D@Q1BU48@25:D00a24
5:DDY@045:D248@25:D00aS65:DDY@035:D348@00aS65:DHaP026<H25:D3
6<H35:D26<H00aBU6<HDY@036<H45:D26<H65:D00a245:DDY@035:D01A24
5:DDYA245:D00QS60QBU00<HaQcW6<H00aS60aBU00<HaQcW6<H00QBU0Q24
00<DYAS65:D00Q240QBU00<HaQBU5:D00QBU0QS600DLiaS66<HDYA2400@D
Y@0348@DYA2400<DY@8@Q0035:D@Q1BU008DY@0348@DYAS6008DY@0336<@
Q12400<<H`/@Q0035:D@Q1BU00<@Q0035:D@Q124008@Q0<DY@066<HDYA24
36<@Q1BU11240aS600<DYA2448@01Q2400<DYA2436<00PaS00<@Q1BU48@0
0`aS00<@Q0aS36<00a240`aS00<@Q0aS36<010aS0a2400@<Ha2448@@Q08<
H`8DY@8<H`0348@DYABU00D@Q0L<H`8@Q0@<H`8@Q0086<HDYA2448@<Ha24
36<@Q0H<H`04248<H`Q2248436<00`Q236<<H`0348@736<348@00`aS48@@
Q00348@236<248@00`aS48@<H`025:D00a245:DDY@0448@010aS48@DY@aS
112400<DYA2448@00QBU00<HaQBU48@01A2410aS0Q240`aS0Q2400D<H`Q2
36<<Ha2400<<H`8@Q00336<@Q124008<H`@@Q0D<H`<@Q0<<H`0348@<H`aS
00D@Q00436<@Q12448@636<0112436<@Q0aS0Q2400@DYA2448@<H`8@Q08<
H`03248<Ha2400D<H`8@Q0H<H`04248<H`aS48@236<248@01@aS248<H`aS
48@00PaS00<@Q0aS36<00PaS00D@Q0aS36<<Ha2400@<H`0348@<H`aS00<<
H`88@P4<H`48@P0000D000@Q12448@0000D48@060008@QBU;F/Lia240aBU
11S60QBU0QS600<LiaS66<H00aBU00<@Q1BU5:D00aS600<DYAS66<H00acW
00<HaQcW7>L00QBU00@HaQcW7>LHaP8Li`046<HDYABU5:D26<H00acW6<HH
aP026<H00a245:DHaP026<H25:D36<H25:D248@00aBU48@@Q00248@35:D3
48@45:D00a245:DDY@0348@35:D248@00aBU6<HHaP025:D00a245:DDY@03
5:D236<46<H00aBU48@DY@0448@26<H448@36<H45:D00`aS48@<H`0248@0
11BU48@<Ha240QBU0a2400<DYA2436<00Q2400<DYA2448@00aBU11241ABU
0aS60aBU00<HaQ2448@00a241QBU00@HaQBU5:DDY@@HaP<DY@056<HDYA24
48@DY@026<H25:D00aS65:DDY@045:D00aS65:DHaP026<H25:D46<H248@0
11S67>LLiaS611240QBU00<@Q1BU5:D00QS60a2400LLiaS648@DYAcW8@PL
i`025:D00acW6<HHaP0248@021BU7>LLiaBU48@DYAcW6<H25:D248@01aBU
48@DYABU6<HDYA24008DY@036<HDYA24008DY@H@Q0075:DHaQBU5:D<Ha24
5:D01Q2411BU212400<DY@aS36<00PaS00@DYA245:DDY@H@Q0@<H`0448@H
aQBU48@25:D348@35:D00`aS48@DY@026<H25:D648@00aBU6<H@Q00336<3
48@236<348@336<448@336<00a245:D<H`0248@00aBU48@<H`0248@00aBU
48@<H`0236<448@01aBU48@DYABU48@<H`Q200<@Q00436<@Q0aS248336<0
0a2436<@Q0035:D448@336<01A2436<8@PaS24800`aS00<8@PaS48@00Q24
00<DYA2448@011240PaS00D@Q0aS36<<Ha2400<<H`8@Q00636<@Q0aS36<@
Q1BU0Q2400<<Ha246<H00Q2400D<Ha2448@@Q1BU008@Q0035:D@Q1BU00<@
Q00436<@Q1BU5:D26<H436<01QBU48@@Q12436<@Q08<H`0548@<Ha2436<@
Q00236<010Q248@@Q1240`aS0a2400<<Ha2448@00`aS0Q240PaS00@@Q1BU
48@@Q0<<H`0348@<Ha24008<H`0548@<Ha2436<@Q00836<248@00aBU48@@
Q00348@011BU48@<H`aS0Q2400<<Ha2436<00a240PaS112400@8@PaS36<8
@Q@<H`0448@<H`aS36<2248448@00`Q236<<H`0636<1248000848@030004
8@@Q00<48@0900048@@Q124DYBU:7>L@Q1S6008DY@046<HDYAS65:D56<H0
1QBU6<HDYABU48@DY@@HaP<DY@036<HLiaS6008HaP8Li`075:DHaQcW8@PL
iaS65:D00aS60QBU11S600<DYAS65:D00aBU0QS600<DYAS65:D00QS61ABU
112400<DYAS65:D00Q240aBU00<@Q1BU6<H00QBU0a2400<<HaBU6<H011BU
00<HaQBU5:D01ABU00<@Q1BU5:D00QBU0QS60QBU0Q240aBU00<HaQBU5:D0
0a2421BU0PaS00<@Q1BU48@00Q240aBU00@@Q0aS48@DY@8@Q00436<DYA24
36<248@011BU48@@Q0aS11BU00<@Q1BU5:D00aBU00HHaQBU5:D@Q1BU48@3
5:D011245:DDYAS62ABU00<HaQBU5:D00aBU0Q2400DDYAS66<HDYAS6008D
Y@086<H@Q1BU5:DHaQBU6<HDY@DHaPDDY@<Li`<DY@0;6<HDYA245:DHaQBU
6<HDYA245:D@Q0026<H01QBU48@DYAcW:DXQ208DY@0<6<HDYABU5:D@Q1BU
7>LHaQBU48@DYAcW0QS600D@Q1BU48@@Q1S600@DY@<HaPDDY@0748@<Ha24
48@DYA245:D00QS600<DYA2448@01ABU0a2400@DYAS65:D@Q0<<H`<DY@04
48@<Ha2436<248@00`aS48@@Q0025:D248@00`aS48@@Q00248@010aS48@@
Q1BU0Q240QS6112400PDYA245:D@Q1BU48@DYAS60QBU00H@Q0aS36<<Ha24
5:D348@536<448@01PaS48@<H`aS48@<H`8@Q00336<@Q12400D@Q08DY@@@
Q08<H`0548@DYA2448@<H`0248@25:D448@436<00`Q236<<H`0236<02124
36<<Ha245:DHaQBU36<548@00`aS248<H`02248436<00a2436<<H`0348@0
11BU48@@Q0aS0a240`aS0Q2400H<Ha2436<@Q0aS48@436<748@35:D548@2
5:D348@00`aS48@@Q0025:D011S65:DDYA240`aS00H@Q0aS36<<Ha2436<3
48@336<248@00`aS48@@Q00336<00a245:D@Q00236<00a245:D@Q00348@2
36<00a2436<@Q00236<01Q2436<<Ha2436<@Q0P<H`8@Q0L<H`T@Q0035:D@
Q0aS00D<H`0348@<Ha24008@Q00436<@Q12448@224800`aS48@@Q00236<0
0`Q236<@Q00536<2248236<00a2436<<H`0336<00`Q236<8@P0336<248@0
1@Q236<<H`aS48@00PQ20`aS00001@@Q00048@@Q000010@Q00T000@Q248H
aRU:7>L@Q1BU6<H011BU00<HaQBU5:D011BU00P@Q1BU5:DDYA245:DHaQcW
0aS60QcW00DHaQcW5:DLib48008HaP0348@DYAcW008HaP045:DHaQS66<H3
5:D36<H45:D00a245:DDY@025:D248@25:D00aS65:D@Q00348@00aBU6<HL
i`025:D00a245:DDY@035:D26<H01ABU48@<H`aS48@01ABU00<@Q1BU5:D0
0QS60a2400LDYAS65:DDYA245:DLi`036<H00aBU48@DY@035:D00aS65:DD
Y@025:D00a245:DHaP026<H348@00aS648@@Q00248@01ABU48@@Q1245:D0
0Q2400<DYA2448@00Q2400H<Ha2448@@Q0aS48@35:D348@45:D01A245:DH
aQBU6<H011BU0a2400@DYA2448@@Q0<DY@0348@DYABU008HaP065:DHaQS6
6<HDYA240aBU00@@Q1BU48@HaP8DY@0748@DYABU5:DLiaS67>L00QS600DD
YAS66<HHaQBU00@@Q08DY@<HaP8Li`056<H@Q12448@DY@0248@25:D01AS6
5:D@Q1245:D011S61ABU0QS60aBU0QS600XLiaBU6<HHaQBU48@<Ha245:DH
aP<@Q08DY@056<HDYA2448@HaP045:D248@35:D0112436<DYABU11240aS6
00PDYA2436<DYA246<HLiaBU0`aS00<@Q1BU48@00Q2400H<Ha2436<<Ha24
36<35:D0112436<<H`aS0Q240PaS00@@Q1BU5:DDY@8@Q08DY@<@Q08DY@04
48@DY@aS36<25:D011S65:D@Q1240QBU00@HaQBU48@<H`8@Q00336<@Q0aS
008@Q0045:D<H`aS36<848@00`aS48@<H`0448@336<248@336<248@336<3
48@25:D648@01PQ236<8@PaS48@<H`<@Q08<H`0348@DYABU00H@Q0D<H`03
248<H`aS00<<H`0648@HaQS66<HDYA242@aS0a240`aS11240`aS0a240`aS
0Q2400<DYA2448@00a240QBU00@@Q1BU48@@Q08DY@0348@DYA24008DY@8@
Q00336<@Q124008<H`<@Q0<<H`0648@<Ha2448@<Ha240PaS112400D<Ha24
48@@Q0aS00D@Q00436<@Q12448@336<00a2436<<H`0336<548@236<348@3
36<021BU48@<H`aS5:DHaQ2436<348@236<248@00`aS48@<H`0348@336<0
212436<<H`aS48@8@PaS248936<00`Q236<<H`0236<00a2436<@Q00636<3
48@010aS2488@PaS0PQ21PaS0@Q200031240100012448@001@@Q00@DYBU:
6<H<H`TDY@036<HDYABU008DY@<@Q0055:DHaQcW6<HDY@026<H37>L00aS6
7>LQ20028@P01QS65:DDYAS65:D@Q0DDY@<HaP035:DHaQS6008DY@0348@D
YABU00@DY@0348@DYABU008DY@8@Q0DDY@036<HDYA2400PDY@0548@DYA24
5:D@Q0025:D011S65:D@Q1BU0QS600<DYA2448@021BU00<HaQcW7>L00Q24
00LDYA246<HLiaS65:DHaP0236<25:D27>L448@25:D248@011BU48@<Ha24
0aBU0Q2400<DYA245:D00PaS0Q240QBU00<@Q1BU5:D00a240aBU11241QBU
00<@Q1BU5:D00a241QBU00HHaQBU48@@Q1BU6<H65:D00aS65:DDY@025:D0
0a245:DDY@026<H27>L26<H00aBU6<HDY@036<H25:D011245:DDYA240QBU
00@LiaS66<HLi`8DY@8@Q0065:D@Q1245:DHaQBU0Q2400<DYAS648@021BU
0Q240QS60QBU1QS60QBU00L@Q1BU5:DHaQ2436<@Q0026<H00aBU48@DY@03
5:D00a245:D@Q00248@01ABU48@<HaBU48@00QBU0a2400DDYAS65:DDYA24
008DY@066<HDYABU48@DYA240`aS2A240aBU0Q2400<<Ha2436<00a240QBU
11241QBU112400L<Ha245:DHaQBU48@<H`0248@00aBU48@@Q00236<248@3
36<348@236<348@00`aS48@@Q0025:D248@010aS48@@Q1240`aS0a240PaS
00<@Q0aS36<010aS0Q2400@DYA245:DDY@8@Q08<H`0448@<Ha2448@536<4
48@35:D336<00a2436<<H`0536<00a2436<<H`0248@00aBU6<HDY@0248@2
36<248@011BU36<<H`Q210aS0Q2400<DYA2436<011240PaS1A240PaS0Q24
00TDYA2448@@Q1BU6<HDYA2436<00Q240QBU0a2400HDYA245:D@Q0Q236<3
48@336<448@536<248@236<25:D0112436<<H`aS0aBU00D@Q0aS36<@Q1BU
00<@Q0<<H`0748@<H`aS36<@Q1BU48@00PaS00<@Q0aS36<00a2400<<Ha24
36<00Q240QBU00<@Q0aS48@00Q240PaS00L8@Q2448@@Q0aS48@<H`0348@6
36<01@Q236<8@PaS24800PaS00D@Q0aS248<Ha2400D<H`0348@<H`aS00@<
H`0348@<H`aS008<H`88@PD<H`<8@P@<H`0000<000@Q12400P@Q00/000@Q
12448@001248@QS6:DXLia2400@HaP<DY@DHaP075:DLiaBU5:D@Q1BU7>L0
31S611BU00DHaQBU5:DDYAS600<DY@HHaP8DY@0348@DYABU008HaP8@Q08H
aP8DY@8@Q0035:D@Q1BU00HDY@<@Q0DDY@0348@DYABU008DY@0448@DYABU
5:D248@01ABU6<H@Q0aS48@00aBU00@@Q1BU48@<H`8DY@096<H@Q1BU5:DH
aQcW6<HDYA24008DY@056<HDYABU5:D@Q0035:D011245:DDYAS60QBU0a24
00<DYA2448@00Q2400X<Ha245:DDYA2436<@Q1BU48@<H`8@Q0045:D<Ha24
48@35:D248@26<H011BU48@@Q1240aS60QBU0Q240QBU0a240QS600XDYA24
48@@Q1BU6<HLiaS65:DHaP8DY@036<HDYABU00<HaP8DY@046<H@Q1245:D2
7>L00aS65:DDY@035:D021245:D@Q1S648@DYA246<H95:D348@55:D76<H2
5:D01PaS48@DYABU6<HDY@@HaP035:DHaQS6008HaP055:DHaQBU6<HDY@02
48@36<H248@00aBU48@DY@035:D00a245:DDY@026<H00a245:D@Q0025:D3
48@26<H248@25:D00a245:DHaP025:D01Q2436<@Q1245:D@Q0D<H`<@Q004
5:D@Q12448@236<348@236<25:D0112436<@Q1BU0a2400@DYAS66<HDY@<@
Q0<DY@037>LHaQ24008@Q08HaP0:5:D@Q12436<@Q0aS248<Ha245:D348@0
11BU36<<Ha240QBU0PaS00LDYA2448@8@PaS48@DY@0236<00a2436<@Q002
36<00`Q236<@Q00248@01PaS48@@Q1BU48@DY@8@Q08<H`L@Q08<H`0348@D
YA24008<H`<@Q0<<H`<@Q0D<H`0448@<H`aS36<248@01ABU48@DYABU48@0
0`aS00<@Q0aS48@00`aS0Q240PaS00<@Q0aS36<00PaS0a240PaS11240PaS
112421BU00<@Q1BU48@011BU0Q240PaS0Q240`aS0Q2400<<Ha2448@010aS
0Q240QBU0a2400@<HaBU48@DY@H@Q08<H`8@Q08DY@0336<@Q124008@Q003
36<8@Q24008@Q00436<8@PaS5:D248@00`aS48@<H`0248@01@aS48@@Q124
5:D00Q240`aS0a240`aS00<@Q0aS48@011241PaS00D8@Q2436<<H`Q2008<
H`05248<H`aS36<@Q00536<0112436<<Ha2410aS00<@Q0aS24800`aS0PQ2
1PaS0PQ20@aS000010@Q00048@0020@Q00<DYBU:7>L00QBU00<HaQBU6<H0
1AS600<DYAS66<H00QcW00/DYA245:DLib487>LHaQBU7>LHaQcW00<HaP8L
i`046<HDYABU5:D26<H248@00aBU6<HLi`026<H021cW6<HDYA245:DHaQBU
48@25:D00aS65:DDY@025:D248@45:D00a245:DDY@045:D011S65:D@Q124
1ABU00@HaQBU48@@Q0<DY@8HaP@@Q0055:D@Q12436<@Q0035:D348@011BU
7>LHaQBU0Q2400@LiaS66<HDY@<@Q08DY@8@Q0@DY@036<HDYAS600<DY@06
6<HDYA2436<@Q1BU0Q240aBU00<@Q0aS36<00Q2400@DYA2448@DY@<@Q08D
Y@<@Q08HaP@DY@086<HDYABU48@DYA245:DHaP8DY@0648@<HaBU5:DHaQBU
0Q2400@HaQBU7>LDY@DHaPDDY@0448@DYABU6<H25:D46<H00aBU48@@Q003
5:D00a245:D@Q0025:D01AS648@DYABU6<H00aBU112400<DYA2448@00QBU
00<HaQBU5:D00QS600@LiaS66<HDY@<@Q0045:DHaQcW6<H25:D66<H021BU
6<HDYABU6<HDYA2436<25:D00aS65:D@Q0055:D26<H25:D00aS65:DDY@03
48@01AS65:D@Q0aS48@00QS600<DYA2448@00Q240QBU0QS600<DYA2448@0
0`aS0Q2400<DY@aS36<00PaS0QBU00<@Q1BU5:D00PaS1a2400<DYA245:D0
0Q2400<DYA245:D00QS60QBU11240QS600@DYA2448@DY@8HaP<@Q00336<@
Q0aS008<H`0448@DYA245:D348@01@aS48@DYABU48@00PaS00D@Q0aS48@<
HaBU00<@Q00336<@Q124008<H`<@Q08<H`0448@DYA2436<348@336<00a24
36<@Q00248@236<00`Q248@@Q00448@00`aS48@@Q00248@436<348@236<0
0`Q236<@Q00248@01PaS48@@Q1BU48@DY@@<H`0348@<Ha2400H@Q00336<@
Q0aS014@Q00436<DYAS66<H248@25:D01QS65:D@Q0aS48@DY@8HaP<<H`<D
Y@0436<8@PaS36<448@236<00a2436<<H`0248@011BU48@<H`aS112400PD
YA2436<<Ha245:D@Q0aS11240PaS11240PaS00L@Q0aS48@<Ha245:D@Q003
36<648@336<448@010aS48@<HaBU0a2400<<Ha2436<00PaS0a240PaS00<8
@PaS24800PaS0Q2400<<Ha2436<00`aS0a240`aS0QBU00<<H`Q236<00Q24
30aS00@8@PaS36<<H`48@P0010@Q00<000@Q124010@Q00D8@QcW=JdQ2124
008HaP<DY@@HaP045:DHaQS66<H85:D26<H35:D01QS67>LHaQBU6<HLi`8H
aPDDY@@HaP055:DHaQS66<HDY@0248@00aBU48@DY@035:D00a245:DDY@04
48@25:D00a245:DHaP025:D348@45:D011245:DDYAS60QBU0Q2400<DYAS6
5:D00aBU0a240aBU0Q240QBU00@@Q0aS48@HaP<DY@0548@DYABU6<HDY@02
6<H011BU48@@Q1BU0QcW00LDYA2448@@Q1S67>LHaP055:D348@01aBU48@@
Q1246<H@Q0aS008@Q0095:DHaQBU48@<Ha246<HDYA2400<DY@0348@DYABU
00LDY@036<HDYABU00<DY@036<HDYABU008@Q0035:DHaQBU008DY@0448@D
YABU6<H25:D011S65:DDYABU0aS600@@Q1BU5:D@Q0@DY@8HaP8DY@8HaP07
5:D@Q1246<HDYAS65:D00Q240QBU0Q240QBU0a2400<DYAS66<H00a2400PD
YAS65:DHaQ245:D@Q1BU0QS600@DYA2448@@Q08DY@8HaP045:DHaQS67>L2
6<H00aBU6<HLi`035:D26<H00a245:DHaP026<H00a245:DHaP026<H01ABU
48@@Q1246<H00QBU0a2400PDYAS65:D@Q0aS5:DHaQBU0a2400@DYA2448@@
Q08DY@0348@DYABU008@Q08<H`0348@<Ha24008@Q0035:D@Q12400`@Q004
36<@Q1245:D236<01a245:DHaQBU6<HDY@aS008@Q00336<DYAS6008Li`8@
Q08DY@0348@<Ha2400H<H`<@Q0055:D@Q0aS36<@Q0025:D00a2436<<H`02
48@436<348@436<448@436<00a2436<<H`0248@336<348@010aS48@@Q124
0`aS0a240PaS00<@Q1BU48@01A2410aS00H@Q0aS36<8@PaS5:D648@010aS
48@@Q1240`aS1A240`aS00<@Q0aS48@02Q240PaS0Q2400<DYAS66<H00QBU
00D@Q1BU5:D@Q1BU00<@Q0035:D@Q0aS008@Q0045:D<H`aS36<248@336<3
48@236<00a245:DDY@0248@00aBU48@@Q0055:D436<448@25:D348@336<0
0a2436<@Q00236<01Q2436<@Q12436<@Q08<H`8@Q08HaP0748@<H`aS36<D
YA2436<00Q240PaS00<@Q1BU48@00Q2400PDYA2436<@Q0aS48@<Ha241`aS
0PQ200@<Ha2448@@Q08<H`03248<H`aS00<<H`@@Q00336<8@PaS008<H`03
48@DYA2400@<H`88@P0336<@Q0aS008<H`4@Q048@P0000@000@Q124000@4
8@0700048@@Q248HaS6<8@P00aBU1AS600@LiaS66<HHaP@DY@036<HDYA24
008DY@066<HLiaS65:D@Q1BU0QS60QBU0aS600HDYAS66<HDYA245:D27>L0
11S65:DHaQBU0Q2400<DYAS648@00Q240aBU00@@Q1BU48@DY@<@Q08HaP<@
Q0085:DLiaS65:D<Ha245:DHaP8DY@0548@DYABU6<HDY@0348@041S65:DH
aQS648@DYA2436<@Q1BU6<HDYA245:DHaQBU0a2400@DYAS65:DDY@8@Q0@H
aP8DY@0648@DYABU5:DHaQBU0Q2400<DYAS66<H00aS600@@Q1BU48@<H`<@
Q08<H`@@Q08<H`055:DHaQBU5:D<H`0348@00aBU6<HHaP0248@011BU6<HH
aQBU0Q240aS61ABU00<HaQBU6<H00QBU0a2400@DYAS65:DDY@8HaP8DY@06
6<HDYAS648@DYAcW0QS600@DYA245:DDY@<HaPDDY@0348@DYABU008HaP05
5:DHaQBU48@DY@0248@35:D248@45:D36<H348@35:D011S65:DDYAS60aBU
112400HDYAS66<HHaQ246<H27>L00aS65:DDY@026<H45:D011245:DDYAS6
0aBU0QS60aBU1a2411BU00L@Q1BU5:DHaQBU36<@Q0025:D348@011BU48@D
YABU212400@<Ha2448@DY@L@Q0035:D@Q12400<DY@D@Q08<H`8@Q00;6<HD
YA2448@DYA2436<DYAS68@PLi`0348@00`aS48@@Q00236<00a2436<<H`03
36<45:D236<01A245:DDYABU36<01A2410aS00<@Q0aS48@00`aS00@@Q0aS
48@@Q08<H`@@Q08<H`D@Q08<H`0348@<H`aS00@@Q00336<8@PaS008<H`<@
Q00336<@Q12400@@Q08<H`8@Q0<<H`D@Q0035:D@Q124008<H`8@Q08<H`8@
Q0<<H`0348@<H`aS008<H`8@Q0045:D@Q12436<25:D348@236<01A245:DD
YABU36<00a240aBU1Q240QBU0Q2400<<Ha2448@00PaS2A2400H<HaBU5:DD
YA245:D448@336<348@00`aS48@@Q00348@236<248@436<448@236<448@2
36<01Q245:DDYABU36<@Q0D<H`05248<H`aS48@DY@0248@00`aS48@@Q002
48@00`aS48@<H`0736<00`Q236<<H`0736<00`Q236<@Q00:36<01A245:DD
Y@aS24801`aS00<@Q0aS36<00@Q200000`@Q00048@0212401@0012448@@Q
00000P@Q00HHaRU:7>L<HaBU48@35:D011245:DHaQS60QBU00<HaQBU5:D0
0Q242aBU1aS600@DYAS65:DHaP8DY@<HaP8DY@036<HDYABU00<@Q08DY@8H
aP055:D@Q1BU48@DY@0348@75:D00aS65:DDY@075:D00aS65:DHaP025:D0
11245:DDYA240QBU00<@Q1BU48@011BU0Q2411BU0aS600<DYA2436<00aBU
0QS621BU00D@Q1BU5:DDYAS6008DY@036<HDYA2400<@Q0035:D@Q124008@
Q08DY@@@Q08DY@8@Q00936<@Q1BU5:DHaQBU48@DYAS6008DY@8@Q0045:DH
aQS66<H35:D248@25:D011S65:DDYA240QBU0QS600LDYA245:DDYA245:DH
aP025:D01A245:DDYAS648@011BU00@HaQBU6<HDY@8HaP035:DHaQBU00<@
Q0075:DHaQBU6<HDYA245:D00Q240aBU0a2400<DYAS65:D00a240aBU0Q24
00DDYAS66<HDYA24008DY@0448@DYA2436<45:D00a245:DLi`025:D36<H2
5:D76<H25:D01QS648@DYABU6<HDY@8@Q00336<DYAS6008DY@0348@HaQS6
00<DY@056<HDYA2448@DY@0448@25:D01A2436<@Q1245:D00Q2400@<Ha24
48@@Q08<H`8@Q00536<@Q12448@DY@0248@25:D01a245:D@Q0aS48@DYAS6
008DY@8<H`0348@DYABU00<@Q0065:D@Q0aS48@DYAS60QBU00@@Q1BU5:D@
Q0<<H`0:48@<H`Q236<@Q0aS48@DYA245:D248@01@aS48@@Q1BU48@00`aS
0a2400<<H`Q236<011241PaS00<@Q0aS36<00PaS0Q240`aS00<@Q1BU5:D0
0PaS1A2400@<H`Q248@<H`8@Q00336<@Q0aS008@Q08HaP8@Q003248<Ha24
00@@Q00436<@Q0aS48@236<348@236<348@236<011245:DDYA240`aS00L@
Q0aS48@@Q0aS48@<H`0:48@35:D348@011BU48@@Q1240QBU0a2400<DYA24
48@01@aS00<@Q0aS36<00PaS0QBU00@@Q0aS36<@Q08DY@0348@DYA24008@
Q0<DY@<@Q0075:D@Q12436<DYA245:D00Q2410aS00P@Q0aS36<<Ha2436<@
Q1BU0a2400D<Ha2448@@Q1BU008@Q00636<@Q1245:D@Q0aS0a2400<<Ha24
48@00QBU0Q240PaS0a2400<<Ha2448@00`aS00<@Q0aS48@01`aS00<@Q0aS
36<01PaS00<@Q0aS36<00`aS00<@Q0aS36<010aS00<@Q0aS36<00PQ20PaS
0A240@aS0@Q2000212401@0012448@@Q00000`@Q00H000Q25:DYBQS648@2
5:D348@01ABU6<HHaQBU48@011BU00<@Q1BU5:D00QS611BU00<HaQBU48@0
0QBU00LHaQcW7>LDYAS65:DLi`026<H35:D00aS65:DHaP026<H45:D248@0
0aBU6<HHaP025:D011S648@@Q1240aBU0Q2400DDYA2448@DYAS6008DY@8@
Q0@DY@8HaP<DY@0348@DYABU00<DY@@@Q0065:DHaQS648@<Ha240QBU00<<
HaBU5:D00QS600DDYA2448@DYA24008DY@056<HDYAS65:D@Q0025:D01AS6
5:DDYABU48@00QBU0aS60a2400<<Ha2448@00QBU0Q2400HDYA2448@<Ha24
5:D348@25:D01A245:D@Q1BU48@00QS611BU0QS60QBU00<@Q1BU5:D00QBU
0aS60QBU0Q2411BU00<@Q1S66<H00QBU00<HaQ245:D00Q240QBU00<HaQ24
5:D00aS60aBU0aS61aBU00<HaQBU6<H00QBU0a2400@DYAS65:D@Q08DY@04
48@DYABU6<H25:D248@65:D26<H00aBU48@DY@0348@75:D011S67>LLiaS6
0QBU00DLiaS65:DHaQcW008HaP085:DHaQS66<H@Q1BU6<HDY@8@Q0035:D@
Q124008@Q0PDY@036<HDYABU00D@Q0<DY@<@Q08DY@0448@<H`aS36<25:D0
11245:D<H`aS0Q240aBU0PaS0Q2400@HaQ2448@<H`8@Q08DY@8@Q00436<@
Q1BU5:D248@00aBU48@@Q00248@25:D26<H25:D00a2436<<H`0248@436<4
48@00aBU48@@Q00236<0112436<DYAS60Q240PQ20PaS00<@Q0aS36<00PaS
00<DYA2436<00PaS112400@<Ha2436<@Q0@<H`D@Q0045:D@Q12448@236<2
48@010aS248<H`aS0a2400<<Ha245:D00QBU00@@Q0aS48@<H`D@Q00536<8
@PaS48@DY@0248@236<00a2436<@Q00748@236<00a2436<<H`0848@01ABU
48@@Q0aS48@011BU00<@Q1BU5:D00a240QBU2A2400HDYA2448@@Q0aS2483
36<348@00`aS48@DY@0648@35:D948@010aS48@@Q1240`aS0QBU0PaS00P@
Q1BU48@<Ha245:D@Q0aS0Q240QBU0Q240PaS0Q2400<<Ha2436<00Q240PaS
00<@Q1BU5:D00`aS0a240`aS00@@Q0aS36<@Q0D<H`03248<H`aS008<H`06
48@<H`Q2248<Ha2410aS0Q240PaS00<@Q0aS36<00Q240PaS0PQ200@<Ha24
48@<H`88@P<<H`48@P0000D000@Q12448@0000H48@08248HaRU:7>L<Ha24
5:D@Q08DY@046<H@Q1245:D26<H25:D26<H25:D248@25:D26<H45:D26<H0
1ABU6<HHaQBU6<H00QcW00@HaQBU48@DY@@HaP<DY@<@Q08DY@036<HDYABU
00<DY@<@Q0045:D@Q12448@65:D248@45:D01AS65:DDYABU6<H00QBU00<@
Q1BU5:D00QBU0Q241aBU00<@Q1BU5:D00QBU00<HaQBU6<H00QBU0Q2400<D
YA245:D00QS600@DYAS648@@Q08DY@046<HDYA2448@35:D00aS65:DDY@02
48@00aBU48@DY@0548@00aBU48@DY@0248@35:D348@00`aS48@@Q0026<H0
0acW6<HDY@056<H00aBU6<HHaP025:D00a245:DHaP025:D011245:DDYA24
0QBU0QS600DDYAS67>LHaQ2400<DY@0348@DYABU00<DY@036<HLiaS6008D
Y@036<HDYAS6008DY@8@Q0045:D@Q1BU6<H45:D00a245:DDY@0348@35:D0
0a245:DDY@035:D248@25:D011246<HHaQBU0Q2400<DYAS66<H01A240aS6
0QBU00@HaQcW6<HDY@8HaP<DY@@HaP055:DHaQS66<H@Q00=5:D36<H25:D0
0a245:DDY@0248@011BU48@@Q1240aBU00<@Q1BU48@00a2400@DYA2436<<
H`<@Q08<H`0548@<Ha245:D@Q00336<448@00aBU48@@Q00248@02ABU48@@
Q12436<DYA246<HDY@0248@01@aS48@@Q1245:D00QS600HDYA2436<@Q1BU
48@436<248@00aBU48@<H`0248@25:D00a245:D<H`0336<01ABU48@@Q0aS
48@00`aS0a2410aS0Q241@aS00<DYA2448@00`aS0Q2400<DYA2448@00`aS
00<@Q0aS36<00`aS0Q240PaS0Q2410aS0Q240QBU0Q2400<<Ha245:D010aS
0Q2400<DYA2436<00PaS00<@Q1BU5:D011240`aS112400DDYA2448@@Q1BU
00@@Q0045:D@Q1BU48@25:D648@35:D011245:D@Q1240aBU00D@Q0aS36<<
Ha24008<H`04248<Ha2448@236<248@00aBU48@@Q00248@01QBU48@@Q1BU
48@DY@8@Q0075:D@Q0aS36<@Q1BU48@00PaS1Q240PaS1A2400@DYA2448@<
H`@@Q0065:D<H`aS36<@Q1BU0Q2400<<Ha2436<0112400@DY@aS48@<H`<@
Q0@<H`04248<Ha245:D348@010aS248<H`Q20`aS0a2400H<Ha2436<@Q1BU
48@336<0212436<<H`aS48@<H`Q236<348@736<1248000<48@0300048@@Q
00H48@046<HYBQS636<25:D348@55:D248@45:D00a245:DHaP065:D01QS6
5:DHaQBU6<HDY@8HaP<Li`LDY@046<HDYAS648@25:D011245:DDYAS60aBU
0QS6112411BU0Q2400@DYAS66<H@Q0<DY@8@Q0055:DLiaS65:D@Q0055:D3
48@00aBU6<HHaP055:D248@011BU48@HaQS60QBU0Q2400<DYA2448@011S6
0Q240aBU00@HaQ245:D@Q08DY@8HaP<DY@036<HDYABU00<@Q08DY@8@Q004
36<DYA2448@35:D01AS648@@Q12436<00QBU0aS60QBU00<HaQBU7>L00QS6
00HLiaBU5:DDYA246<H35:D448@25:D36<H45:D00aS65:D@Q00248@00aBU
48@DY@036<H011BU48@DYABU0QS600<DYAS65:D00QBU0Q241aBU00P@Q0aS
48@@Q1BU48@DYAS60QBU00@@Q1BU5:D@Q0DDY@8HaP055:D@Q1245:DHaP02
5:D011245:D@Q1240QBU00@HaQBU5:DHaP<DY@046<HLiaS65:D26<H00acW
6<HHaP036<H35:D011245:DDYA240QBU0a2400@DYAS66<HDY@<HaP<DY@8@
Q0<DY@8@Q0035:DHaQS600<@Q08<H`0348@<HaBU008@Q0<<H`0448@<H`aS
36<448@336<00a245:DDY@0348@01ABU48@@Q1245:D00a240QBU00<HaQ24
36<00PaS00XDYA2448@HaQcW6<HDYA245:D@Q0<<H`L@Q0065:D@Q1BU48@D
YA240`aS00@@Q1BU48@<H`@@Q0D<H`<@Q00736<@Q12436<@Q0aS48@00PaS
00H@Q1BU48@@Q0aS48@25:D0112436<<Ha2420aS0Q240`aS1Q2400@DYA24
48@<H`@@Q00636<@Q0aS48@<Ha240PaS00@@Q1BU48@@Q08<H`0348@<H`aS
008@Q08<H`0348@DYA24008@Q00336<@Q124008@Q0@DY@0348@DYA2400<D
Y@0348@<Ha2400<@Q0<DY@0348@<Ha2400<<H`<@Q08<H`0348@<Ha24008@
Q08<H`8@Q08DY@D@Q0055:DHaQBU48@<H`0548@236<548@00aBU36<@Q002
5:D00a2436<<H`0248@011BU48@<H`aS0aBU11240PaS00@@Q1BU48@@Q0D<
H`8@Q0035:D@Q0aS008<H`8@Q0<<H`8@Q08<H`8@Q0<<H`0348@<Ha2400H<
H`0348@<H`aS00@<H`<@Q08<H`0348@<H`aS008<H`0348@<H`Q200H<H`48
@P0000<000@Q12400P@Q00<000@Q12400P@Q00P000Q25:DYBQcW36<@Q1BU
0Q243ABU0a2400DHaQBU6<HDYAS6008DY@8Q208HaP0336<DYABU00@HaP05
5:D@Q1BU5:DHaP065:D011245:DDYAS60QBU0a2400<DYA245:D01Q241ABU
0Q241QBU00<HaQBU5:D01aBU0a241QBU00@HaQBU5:D@Q08DY@036<HDYABU
00<@Q08DY@067>LHaQS65:D@Q0aS0QBU00DHaQBU5:DDYAS600@DY@@@Q004
5:DHaQS65:D548@00aBU48@@Q00848@35:D26<H25:D01A245:DHaQBU48@0
0QBU00<HaQBU48@00aS600<DYA2448@00QBU00<HaQBU5:D00QBU00<HaQBU
5:D011BU00<HaQ245:D00Q240QBU00<HaQBU5:D00QS600<DYA2448@00QBU
0Q240QBU00L@Q1BU6<HHaQBU48@<H`0248@00`aS48@DY@0348@36<H25:D0
21S65:DDYAS67>LHaQBU48@26<H00aBU48@@Q0025:D00aS65:DDY@0248@0
0aBU6<HHaP026<H011BU6<HHaQcW0aBU00<HaQcW6<H01QBU1A240QBU00H@
Q0aS48@DYAcW6<H55:D01Q2436<<Ha245:DHaP<@Q0<DY@8@Q0<DY@8@Q08<
H`0348@<Ha2400<@Q00536<@Q12436<@Q00336<348@00`aS48@@Q00248@2
36<248@336<248@25:D00a2436<<H`0436<011245:DHaQS60Q240QBU00D@
Q1BU48@@Q1BU008@Q00536<@Q12448@HaP0448@25:D636<02A2436<<H`Q2
36<@Q0aS48@<H`0448@336<01A2436<@Q1245:D00Q2400<DYA2448@00a24
10aS112400<<Ha2448@010aS0Q240PaS0Q2400<DYA2448@00a241`aS00<@
Q0aS36<00Q2400<<Ha2448@00Q240`aS00<DYA245:D00a2400<<Ha2436<0
1A2400<DYA245:D01A240QBU00H@Q1BU48@@Q1BU48@236<248@25:D248@2
36<348@236<348@236<00a245:DDY@0648@00aBU48@@Q00348@436<448@0
0`aS48@<H`0348@25:D948@021BU48@@Q0aS48@<Ha2436<448@536<00a24
5:DDY@0336<348@636<0112436<@Q1241PaS00@@Q0aS36<<H`<@Q0@<H`03
48@<H`aS00T<H`0348@<H`Q20088@P<<H`48@P0000D48@0012448@0000@4
8@0700048@Q25:DYBQS636<02ABU0aS600@DYA2448@@Q08DY@0348@DYABU
00@DY@<HaP057>LHaQBU5:D@Q0026<H01AcW6<HDYA245:D00Q241QBU00<@
Q1BU5:D011BU00<@Q1BU48@00QBU0Q240QBU0Q241ABU00<@Q1BU6<H00QBU
0Q241QBU0QS600@DYA245:D@Q0DDY@0448@DYABU5:D248@35:D00aS65:DH
aP045:D01a245:DHaQcW6<HDYA2400@DY@0448@DYA245:D248@00aBU48@D
Y@0248@00`aS48@@Q0035:D348@01QBU48@@Q12436<DY@8HaP0348@<H`aS
00<DY@<HaP<DY@046<HLiaBU5:D236<01A245:DHaQS65:D0112411S600DD
YA245:DDYAS600<DY@0448@DYABU5:D348@011BU6<HHaQBU0Q2400<HaQBU
5:D01ABU00<@Q1BU5:D00aBU1a2400<<Ha2448@01ABU0QS60aBU0QS600<D
YAS66<H00QS60a240aS60Q2400@DYAS65:DDY@@HaP047>LHaQS66<H35:D0
0aS67>LHaP065:D00a2436<<H`0248@00aBU48@DY@026<H55:D648@010aS
48@@Q1240QBU00<@Q1BU48@00QBU1Q2400@DYA2436<<H`<@Q08<H`0448@<
Ha2448@336<248@25:D348@010aS48@@Q0aS0Q240QBU00D@Q1BU36<<Ha24
00<<H`0648@HaQS66<HDY@aS0Q2400<DYA2436<01a2400@DYA2448@@Q0<<
H`8@Q08<H`0348@DYA2400<<H`8@Q0@<H`8@Q0@<H`H@Q00536<@Q1245:D@
Q00236<0112436<8@PaS0Q240PaS0a2400<8@PaS48@00a240`aS2a2400<<
Ha2436<01Q240PaS0Q240`aS00<@Q1BU5:D00a2400<<Ha2436<00Q2400@<
Ha245:DDY@@@Q0045:D@Q12448@25:D0112436<<HaBU11240PaS21240`aS
0a2400@<Ha245:DDY@<@Q0035:D@Q1BU008@Q0035:D@Q12400@@Q00>36<@
Q0aS48@<Ha2436<@Q1BU48@DYA2436<@Q0<DY@8@Q00436<@Q12448@25:D2
48@00`Q236<@Q00748@00`aS48@<H`0248@336<00a245:D@Q00236<00a24
36<<H`0236<248@00`aS48@<H`0336<0112436<<H`aS0a240`aS0Q240`aS
0Q2400<<Ha2436<00PaS00@@Q0aS36<@Q08<H`04248<Ha2436<2248000<4
8@0400048@@Q000512401AS6:DXLia245:D00aS60QBU00@@Q1BU5:D@Q08H
aP037>LDYABU00<DY@8@Q0@DY@<HaP8DY@036<HDYABU00HDY@0448@DYA24
48@25:D00aS65:DDY@025:D00a246<HDY@075:D348@01ABU6<HHaQBU36<0
0Q2400<DYAS66<H01aBU00D@Q1S65:DHaQcW008HaP035:D@Q1BU008@Q08D
Y@056<HDYA2448@DY@026<H011BU48@DYABU0QS600@@Q1BU48@DY@8HaP<D
Y@056<HLiaBU5:D@Q0025:D011S65:DHaQS60QBU00@@Q1S65:DDY@8@Q003
5:D@Q1BU00@DY@8@Q0<DY@0348@<H`aS008@Q0045:D@Q12448@35:D46<H3
5:D00a245:DDY@035:D011S67>LHaQBU0Q2400@DYAS66<HHaPDDY@<@Q003
5:DHaQBU00@DY@046<HDYA2448@25:D011245:DDYABU0Q240aBU00@@Q1BU
5:DDY@@@Q0075:D@Q0aS36<@Q1BU48@00QBU0QS600@DYA2448@@Q08DY@05
6<HDYABU5:DHaP025:D248@00aBU6<HDY@0448@35:D00aS65:DHaP036<H0
1ABU48@DYABU6<H00QBU00<HaQBU5:D00aBU00L@Q1BU48@@Q1BU6<HDY@03
48@011S65:DDYABU0Q2400<DYA2448@00Q2400<DYA2448@00Q2400<<HaBU
48@00QBU0Q2400<DYA2436<00`aS00L@Q1BU48@@Q0aS48@<H`0248@00`aS
48@@Q00248@01@aS48@@Q1BU48@00PaS112400<<Ha2448@00a2400<<Ha24
36<00`aS0Q2400<<Ha2436<00Q2400<DYA2448@00a2410aS0a2400@DYAS6
6<HDY@<@Q00736<@Q0aS36<@Q1BU48@00PaS00<@Q1BU48@00Q2410aS0Q24
00<<Ha2448@00QBU0Q2400D<Ha245:D@Q1BU00<@Q08<H`0348@<H`Q2008<
H`0348@<Ha24008DY@<<H`0348@<H`aS00@<H`<@Q00436<@Q12448@236<0
0`Q236<<H`0236<448@010aS48@@Q1BU0Q240PaS00@@Q1BU6<HDY@P@Q003
5:D@Q12400<DY@8<H`<DY@0348@<Ha24008@Q0035:D@Q12400D@Q00336<@
Q12400H@Q00436<@Q1245:D348@011BU48@DYAS60a2400DDYA2448@<HaBU
008@Q08<H`H@Q00336<@Q12400D@Q00336<@Q1BU008DY@0336<@Q12400D@
Q00336<@Q1BU008DY@0648@<Ha2448@DYA240`aS112400D<Ha2448@<H`Q2
008<H`0548@<H`aS36<@Q0035:D0112436<<H`aS0Q2400<<Ha245:D00QBU
0Q2400<<Ha2448@0112410Q200<<Ha2448@00`aS00<@Q0aS36<00PaS0@Q2
00000`001240000512402000124000Q26<HYBQS636<25:D011S65:D@Q124
0aBU00DHaQBU6<HDYAS600<DY@0648@DYABU5:D@Q1BU0aS60QBU0QS61aBU
00<HaQBU48@00Q240aBU0a2400<DYAS65:D011BU0QS60QBU0Q2411BU0a24
0aBU00H@Q1BU5:DHaQBU48@25:D00aS65:DDY@026<H00acW6<HDY@035:D2
48@25:D00a245:D@Q0025:D011S65:DDYABU0QS611BU00<@Q1BU5:D00QS6
00@DYAS66<HHaP8DY@0448@DYABU6<H45:D00aS65:D@Q00236<00aBU6<H@
Q0025:D00aS65:D@Q0035:D03Q2436<@Q1245:D@Q1BU48@DYA245:DHaQBU
6<H25:D46<H248@25:D01aS65:DHaQS67>LDYA24008DY@8HaP055:DHaQBU
5:D@Q0035:D248@25:D00aS65:DHaP025:D00a2436<@Q0035:D00a245:DD
Y@035:D01QS65:DDYA245:DHaP@@Q0035:D@Q12400<@Q0055:D@Q1BU5:DH
aP055:D00a245:DHaP026<H01QBU48@DYA245:D@Q08DY@046<HDYA2448@5
5:D56<H45:D011S65:DDYAS60aBU00<HaQ2448@00Q240aBU0Q241aBU0Q24
00<<Ha2448@0212411BU00<@Q0aS36<01A240`aS00<DYA2448@00PaS00@@
Q1BU5:D@Q0<<H``@Q0035:D@Q124008<H`@@Q08<H`8@Q00536<@Q12448@D
Y@0648@336<01A245:DHaQBU48@00QBU1A240PaS00D8@PaS36<DYA2400<<
H`<@Q08<H`0348@<H`aS00L@Q00336<@Q1BU008DY@0448@<Ha2448@436<3
48@010aS48@@Q1240PaS00<@Q0aS36<00PaS1a2400L<Ha2448@@Q0aS248<
H`0248@236<248@00aBU48@@Q00336<248@00aBU48@@Q00548@00aBU48@@
Q00448@011S65:D@Q1BU112400DDY@aS48@@Q1BU008@Q00736<@Q1BU5:D@
Q0aS48@00aBU112400<<Ha2448@00Q2400DDYA2448@<HaBU008@Q0<DY@8@
Q00436<@Q1245:D248@236<00a245:D@Q00248@00`aS48@@Q00:48@01ABU
48@<Ha245:D0112400@DYA2448@DY@<@Q08<H`0348@<H`aS00<@Q08<H`<@
Q0@<H`<@Q08<H`0348@DYA24008<H`0348@<H`aS008<H`095:DHaQBU48@<
Ha245:D@Q0aS00<@Q0D<H`8@Q0T<H`48@P0010@Q00<000@Q12401@@Q00@D
YBU:7>L@Q0HDY@0348@DYAS6008HaP035:DHaQS6008HaP0948@DY@aS36<D
YAS67>LHaQBU00@HaP055:DHaQBU5:DHaP025:D248@45:D00`aS48@@Q003
5:D248@25:D248@45:D01@aS48@DYAS65:D00Q2400DHaQBU5:DHaQcW008H
aP<DY@036<H@Q1BU008@Q0<DY@8HaP8Li`LDY@<@Q00:5:D@Q0aS48@HaQcW
5:D@Q1BU6<H65:D00aS65:DHaP035:D01A245:DDYABU48@011BU00@HaQBU
5:D@Q0@DY@@@Q0@DY@0548@DYA2448@<H`0248@25:D011S65:DDYAS62QBU
0QS60aBU0QS60QBU00@HaQBU5:DDY@<HaP<DY@0548@DYABU6<HDY@0348@0
11BU48@@Q1240aBU00<HaQBU48@00a2400@DYAS66<HDY@<@Q0045:D@Q124
36<248@00aBU48@@Q0065:D26<H25:D01`aS48@DYABU6<HDYA24008DY@8H
aP8@Q00436<@Q12448@35:D00a245:DDY@026<H65:D00a245:DHaP035:D0
11245:DDYAS60QBU00<@Q1BU6<H00QS600DDY@aS48@HaQBU008HaP8DY@05
48@DYA2448@<H`0548@00`aS48@DY@035:D00a245:D<H`0336<248@01ABU
48@@Q1245:D01Q240aBU0`aS0QBU0Q240PaS00L@Q0aS36<<Ha245:D@Q005
36<00a245:D@Q00248@00aBU48@@Q00436<348@01@aS48@@Q12436<00Q24
0QBU0a2410aS0a2410aS0a2400<<Ha2448@00Q241@aS0aBU212400D<Ha24
48@DYA2400<<H`0448@<Ha2436<348@336<0112436<@Q0aS1A2400<<Ha24
36<00Q240`aS00<@Q1BU48@02A240PaS00H@Q1S66<HDYA245:D248@00`aS
48@<H`0548@25:D348@00aBU48@@Q00248@010aS48@@Q1BU11240aBU0a24
00<DYAS65:D00Q2400<<Ha245:D00Q240aBU0Q2400DDYA2436<@Q1BU00@@
Q00736<@Q0aS48@DYA2436<01Q2400PDYA2436<<Ha245:D@Q1BU0a240PaS
00<@Q1BU5:D00PaS00<@Q1BU48@00PaS00L@Q0aS48@@Q0aS48@DY@0248@2
36<248@00`aS48@<H`0248@236<448@010aS48@DYABU0Q241@aS00@DYAS6
8@PHaPH@Q00436<@Q12448@636<01Q2436<<H`aS248@Q08<H`4@Q00000@0
00@Q124000848@0;00048@@Q124000Q26<H]JacW48@HaP055:D26<H35:D3
6<H25:D348@65:D00aS65:DLi`026<H248@00aBU6<HDY@0248@65:D01124
5:DDYABU0a2411BU0Q2400LDYA2448@@Q1BU6<HDY@0248@45:D26<H35:D0
0aS648@DY@055:D36<H011cW6<HHaQS61ABU0Q2400@DYAS648@@Q08DY@<H
aP045:D@Q1BU48@25:D01A245:DDYAS648@00QBU0QS600@DYA2448@DY@<@
Q0<DY@8@Q0045:DHaQBU5:D248@35:D02Q245:D@Q1BU48@DYA2436<DYA24
11BU00@HaQBU5:DDY@8HaP037>LHaQBU008@Q0035:DHaQS6008DY@8HaP03
5:D@Q12400@DY@036<HDYA24008DY@076<HDYA2448@HaQBU48@011BU00@@
Q1BU6<H@Q08DY@036<HDYA24008@Q08HaP8DY@0348@DYABU008DY@@@Q005
5:D@Q1BU48@DY@0248@02QBU6<HHaQBU48@<Ha245:DHaQBU0a240aBU00@@
Q1S65:DDY@8@Q08DY@056<HDYA2448@DY@026<H25:D00aS65:DDY@045:D3
6<H02ABU48@DYABU48@<Ha245:DHaP025:D00a245:DDY@075:D00a245:D@
Q00236<00a245:D@Q00248@01ABU48@@Q1245:D011240PaS00<@Q1BU48@0
0PaS0Q2400<DYA2448@01A2400D<Ha245:D@Q0aS008@Q0D<H`<@Q00336<@
Q0aS00<<H`0448@<H`aS5:D248@010aS48@@Q1240PaS00@@Q1BU5:D<H`8@
Q00336<@Q12400<DY@0348@DYA2400L@Q00336<@Q12400@<H`0548@DYA24
48@<H`0348@236<448@00aBU48@DY@0948@00`aS48@<H`0236<01a2436<<
H`aS48@DYA24008<H`0348@<H`Q200@@Q0@<H`0348@<Ha2400D@Q0<<H`04
48@DYABU48@236<00aBU48@<H`0248@25:D00a245:DDY@0248@00`aS48@@
Q00448@25:D01A245:DDYA245:D01A240QBU00@@Q0aS36<@Q08DY@<@Q0@D
Y@@@Q00336<@Q12400<DY@0348@DYA24008DY@0448@DYA245:D648@236<2
48@00aBU48@@Q00348@35:D0112436<@Q1240aBU0Q2400@<Ha2436<<H`8@
Q0045:D@Q0aS48@536<248@00aBU48@<H`0448@236<348@236<248@236<8
48@236<011BU7>LLiaS60Q2400<DYA245:D00Q2400<<Ha2436<02@aS00<8
@PaS36<00Q240@Q2000212400`0012448@0712401248?Nl]JaBU0QS600@D
YAS66<HHaP<@Q0055:DHaQS65:D@Q0025:D011S65:D@Q1240aBU00<HaQBU
5:D00aS60aBU0QS60Q2400@DYAS65:DDY@8@Q0045:D@Q1BU6<H35:D00a24
5:D@Q0035:D248@00aBU48@@Q00248@25:D01Q245:DDYAS67>LHaP8DY@8@
Q0035:DHaQS600<DY@046<HDYABU5:D46<H00aBU6<HHaP035:D26<H25:D0
11245:DDYA240aBU0Q240QS600<@Q0aS5:D00QS60QBU00<@Q1S66<H00aBU
00<@Q1S65:D00aBU00DHaQcW6<HHaQBU00<HaP035:D@Q124008@Q0035:D@
Q1BU00H@Q08DY@8@Q0DHaP@DY@0448@DYAS66<H35:D01AS65:DDYA245:D0
0Q2400<DYAcW7>L00Q2400<DYAS66<H011BU00@HaQBU5:D@Q0HDY@8@Q003
5:DHaQBU008@Q0056<HDYABU5:D@Q0065:D448@25:D00aS65:D@Q00248@0
11S65:DDYA241QBU00DHaQBU5:D@Q0aS008DY@056<HDYA2436<@Q0035:D0
11S65:D@Q1BU1aS60a241aBU00@@Q1BU48@DY@8@Q08DY@036<HDYA2400PD
Y@8<H`8@Q0055:D@Q0aS36<@Q0035:D248@00aBU48@@Q00236<248@25:D2
36<01A2436<@Q0aS48@00aBU2A2400D<Ha245:D@Q0aS008DY@036<H@Q0aS
008<H`08248@Q1BU5:D@Q1BU48@DY@<@Q0<<H`8@Q0045:D@Q124248236<0
11246<H@Q1BU0Q2411BU10aS00@DYA245:D@Q0@<H`<@Q0<<H`8@Q00836<@
Q12448@<Ha2436<@Q08DY@8@Q08<H`8@Q0045:D@Q12448@336<248@636<4
48@236<248@00aBU48@@Q00348@336<011245:D@Q1BU0a240PaS1Q240aBU
00@@Q0aS48@@Q08<H`0348@DYABU00<@Q0035:D@Q12400<@Q0045:D@Q124
48@25:D01A245:DDYA245:D00a2400H<Ha245:DHaQBU48@236<248@35:D2
48@011BU48@DYABU2A240PaS00@@Q1BU48@<H`<@Q08<H`D@Q0045:D@Q124
5:D248@236<00a245:D@Q00348@010aS48@DYA240`aS11240QBU00<HaQBU
48@00`aS0Q2400D8@PaS36<DYA2400<<H`D@Q00336<@Q1BU008DY@0636<D
YAS67>LHaQBU1Q2410aS00<@Q0aS36<01PaS0a240PaS00000`@Q00048@02
12400`0012448@0312402@Q28@PmkbDY5:DHaQcW6<HDY@0248@01@aS48@D
YABU6<H00QBU0QS600<DYAS65:D011BU00@HaQBU5:DDY@8HaP8DY@8HaP03
5:D@Q12400<DY@046<HDYABU5:D248@75:D248@25:D00aS65:D@Q00348@4
5:D011245:DHaQcW0QS60QBU00@@Q1BU5:DHaP<DY@036<HDYABU008HaP03
7>LHaQS6008DY@8HaP<DY@046<HDYA2448@25:D36<H348@25:D348@00aS6
5:DDY@065:D00aS65:D@Q0025:D248@02QS67>LHaQBU48@DYAS65:D@Q1BU
0Q2400TDYA245:D@Q1BU48@DYA245:D00a240aBU0aS61ABU00<HaQBU5:D0
0Q2400@DYAS65:DHaP@DY@0348@HaQS6008HaP0548@DYAS65:DHaP035:D0
0aS65:DDY@035:D01AS648@DYA245:D00QS60QBU00D@Q1BU5:DDYAS6008@
Q08DY@8HaP8@Q0035:D@Q124008@Q0035:DHaQBU008@Q0036<HLiaBU00DD
Y@0448@DYABU5:D348@35:D748@55:D26<H01AcW6<HHaQBU48@011BU00DH
aQBU5:DDYA2400@DY@8@Q0065:D@Q1BU6<HDYAS61QBU00<@Q0aS48@01A24
0PaS0Q240QBU112400@DYA2436<<H`<DY@D@Q00436<@Q1BU5:D248@00`Q2
36<@Q0025:D00a2436<<H`0348@236<011245:DDYA2410aS0Q240QBU1A24
0`aS11240QBU00D@Q0aS36<<Ha24008DY@<@Q08DY@8@Q08<H`0548@<Ha24
48@<H`0948@00`aS48@<H`0248@00`aS48@DY@0348@010aS48@DYA240PaS
00<@Q1BU5:D00`aS00@@Q0aS36<<H`8@Q08<H`0448@<H`Q236<248@236<8
48@236<25:D0112436<@Q1240QBU00D@Q0aS48@<HaBU008@Q0@DY@`@Q003
5:D@Q1BU00D@Q0035:D@Q124008@Q0055:D@Q0aS5:D@Q0025:D236<01124
5:DLiaS60a240QBU0`aS00@@Q1BU5:DDY@<@Q08DY@0348@<Ha2400@@Q004
36<@Q12448@35:D248@00`aS48@DY@0248@00aS648@@Q00236<01ABU36<<
H`aS5:D00Q240`aS0Q2400DDYA2448@@Q0aS008@Q00336<@Q124008DY@D@
Q0<<H`0348@<H`aS008@Q00336<@Q0aS008@Q0<<H`8@Q0055:D<Ha245:DH
aP027>L25:D236<448@236<00a2436<<H`0536<00a2436<<H`0336<12480
000500048@@Q1240000512401`00248LidHa=JdHaR4800<Li`035:D@Q0aS
00LDY@0348@DYA24008DY@<@Q0<DY@@HaP045:DHaQBU6<H45:D00aS65:DD
Y@0448@00aBU6<HDY@0248@35:D248@25:D248@25:D01A245:D@Q1BU48@0
0aBU0QS60QBU0Q2411BU00<HaQBU48@011BU0acW00<HaQBU5:D011S60QBU
00<HaQBU48@00Q240aBU0a2400HDYA245:DDYAcW6<H248@011BU48@@Q124
11BU00D@Q1BU5:DDYAS6008DY@8HaP8DY@0348@DYABU008HaP8DY@036<HD
YA2400<DY@<@Q08DY@036<HDYABU00@HaP065:D@Q12448@DYA2411BU0Q24
0aBU0Q240QBU00<HaQ245:D00aS600<DYAS65:D00QBU0Q240QBU00@HaQBU
5:D@Q0LDY@8HaP8DY@0348@<HaBU008HaP8DY@8@Q0<DY@0348@DYABU008D
Y@8@Q0LDY@036<HDYABU00L@Q0035:D@Q12400<DY@8@Q0DDY@036<HDYAS6
00@HaP8@Q08DY@066<H@Q0aS48@DYAS60aBU00@@Q0aS48@<H`HDY@8@Q0<D
Y@8@Q00336<@Q0aS00H@Q0036<HDYABU008@Q0085:D@Q0aS36<@Q1BU48@<
H`<@Q0035:D@Q124008@Q0055:D@Q0aS36<@Q0035:D00a2436<<H`0348@2
36<248@00aBU48@@Q00348@01QBU48@@Q0aS48@<H`P@Q00336<@Q12400@<
H`035:D@Q1BU008@Q00436<@Q1245:D248@01PaS48@@Q0aS48@DY@8@Q003
36<@Q0aS008<H`D@Q00436<@Q12448@536<00a2436<@Q00:48@336<248@2
36<010Q248@@Q1BU0Q240PaS0a240QBU0Q2400<<Ha2448@00a240PaS0Q24
00PDYA2448@@Q1BU48@<Ha240QBU0Q240QBU00D@Q0aS48@DY@aS008@Q08H
aPDDY@0448@DYABU36<348@00aBU48@@Q00348@236<248@00aBU6<HDY@02
5:D348@01QBU48@<H`aS48@DY@<@Q0045:D@Q12436<248@00`aS48@DY@03
48@00`aS48@@Q00248@010aS5:D@Q1BU1A2400@DYA2448@DY@<@Q0@DY@D@
Q0055:D@Q12448@<H`0248@00aBU48@@Q00236<011245:D@Q1241@aS00D@
Q0aS48@<Ha2400<<H`0348@DYA2400<<H`065:DHaQBU5:D@Q1BU0QS600LD
YA2436<<Ha245:D@Q00836<0112436<<H`aS0a240PaS000312400`001244
8@05124020Q29BU242e[6<HLib487>L26<H25:D00a245:DDY@035:D00a24
5:D@Q0035:D248@35:D011245:DHaQS60QBU00<HaQcW6<H00aBU00D@Q1BU
5:DDY@aS00<@Q0HDY@036<H@Q124008@Q0<DY@8<H`<DY@8@Q08DY@8HaP8D
Y@056<HDYA2448@DY@026<H011BU48@DYABU0QS60QBU00<LiaS65:D00QBU
0aS600@DYAS65:D@Q0DDY@046<HDYA2448@25:D248@36<H011BU48@@Q124
0QBU0a241ABU00@@Q1BU5:DDY@8HaP035:DHaQS6008DY@0448@DYABU48@5
5:D011245:DDYABU0a2400<HaQcW7>L00QS600D@Q1BU5:DDYA2400DDY@03
6<H@Q1BU00<DY@0848@DYAcW6<HDY@aS48@Li`8HaP0:5:DHaQ2448@DYA24
5:DHaQBU6<H<5:D348@26<H01ABU6<HDYA245:D00Q2400DDYAS65:DDYA24
00<DY@<@Q08DY@036<HDYABU008@Q00736<@Q1BU6<HDYA245:D00a240QBU
0a2400@DYAS65:D@Q0@HaP055:DHaQS66<HDY@0248@35:D248@55:D348@0
0aBU6<HDY@055:D:48@010aS48@<H`aS0Q2400<HaQBU5:D00Q240PaS0a24
00DDYA2436<<Ha24008DY@<@Q0@<H`8DY@<@Q08<H`<@Q0<<H`@@Q08<H`03
48@DYABU008@Q00<36<@Q0aS36<@Q0aS48@DYAS65:D@Q0aS1a2400<DYA24
36<00PaS0a240PaS00<@Q0aS36<00aBU00<@Q0aS36<00Q2410aS1A2400@<
Ha2448@<H`D@Q00336<@Q124008DY@@@Q0<<H`8@Q0035:D<H`aS008<H`@@
Q0@<H`0648@<Ha245:D@Q1BU0a2400<DY@aS48@0112400<DYA2436<00PaS
00<@Q1BU5:D01A240QBU00@@Q0aS36<@Q08DY@056<HDYABU5:D@Q0035:D0
0a245:DDY@0348@25:D00a2436<@Q00448@01ABU48@@Q1BU6<H00Q240aBU
1A240aBU00L@Q1BU48@@Q0aS48@DY@0248@00aBU48@DY@0448@00aBU48@@
Q00348@010aS48@@Q1BU112400<DYA2448@00Q2400<DYA2448@00PaS0Q24
00<DYA2436<01A2400H<Ha2448@@Q1BU48@336<00a2436<@Q00236<248@0
10aS248<H`aS0QBU00H@Q0aS36<<Ha245:D26<H25:D00aS65:DDY@0236<2
48@236<348@01@aS2488@PaS48@00`aS0Q240`aS0@Q200000`0012400003
1240100012448@000P@Q00<LicF]:DX00QS611cW00@HaQ245:D@Q08DY@07
48@DYABU5:DHaQBU48@00QBU0QS600@DYAS66<HHaP@DY@0<6<HDYABU48@<
HaBU6<HDYAS648@DYA240QS60QcW00@DYA2448@@Q0LDY@8@Q0045:D@Q1BU
5:D348@00aBU6<HLi`025:D26<H011BU48@HaQBU0Q241QBU00@HaQBU5:DH
aP8@Q08DY@057>LHaQBU5:DHaP025:D011S65:DHaQ240aBU112411BU0Q24
0aBU00<@Q0aS48@00aBU00<@Q1BU5:D00aBU0Q240QS600<Lib486<H00QBU
00<@Q1BU5:D00QS600<@Q1BU5:D011BU0aS611BU00HHaQBU5:D@Q1BU48@3
5:D248@25:D00a245:DDY@036<H00aBU48@DY@025:D00aS65:D@Q0035:D2
48@25:D00aS65:DDY@095:D01A245:DHaQS65:D00Q2400<DYA245:D01ABU
00`@Q1BU48@HaQBU6<HDYAS65:D@Q1BU6<H25:D011245:DDYABU2A2400@D
YAS66<H@Q08DY@@HaP8DY@@HaP047>LDYA2448@25:D00a245:DDY@065:D2
48@45:D26<H25:D348@01ABU48@@Q1245:D01A2400@<Ha2448@DY@@@Q004
5:D@Q1245:D348@01@aS48@@Q1245:D0112400@<Ha2448@@Q08DY@0448@<
Ha245:D448@25:D0112436<<H`aS0QBU00@@Q0aS36<@Q08DY@@<H`0648@D
YABU5:DHaQ240`aS00<@Q0aS36<011240PaS00D@Q0aS48@@Q1BU008@Q08<
H`0348@DYABU00H@Q00336<@Q0aS00H@Q00436<@Q12448@236<448@02@aS
48@DYA245:DHaQ245:D@Q00236<00a245:DDY@0336<00a2436<<H`0248@2
36<548@00aS65:DDY@0448@236<348@236<00a245:DDY@0248@35:D448@0
1ABU48@@Q0aS48@00QBU0QS60a241aBU0a2400<<Ha2448@00a2400@<Ha24
48@@Q08DY@D@Q0035:D@Q124008@Q0035:D@Q124008@Q08<H`0348@DYA24
00@@Q0045:D@Q12436<248@00aBU48@<H`0748@25:D348@00aBU48@DY@04
48@011BU48@DYABU0Q2400<<Ha2448@00a240PaS00@@Q0aS248<H`8@Q004
36<8@PaS48@25:D236<2248011245:DDYABU0Q240PaS0Q240QBU00D@Q1cW
7>LQ21cW008@Q08<H`0348@<H`aS008<H`0348@<H`aS00@<H`0348@<H`aS
008@Q04<H`48@P001@@Q00<000@Q12400`@Q00X8@QS6=JdYBQS68@PLib48
7>LHaP<@Q0@DY@0448@DYABU6<H248@35:D00aS67>LDY@035:D00aS65:DD
Y@026<H00aBU48@DY@025:D011S648@@Q1240aS600<DYAS65:D00a240QBU
00@@Q1BU5:DDY@H@Q08DY@8@Q0046<HLiaS648@35:D011245:D@Q1S611BU
0a2400@HaQBU5:D@Q0@DY@@HaP@DY@@HaP045:DHaQ245:D248@021BU48@D
YA245:D@Q0aS48@25:D248@25:D01AS65:DDYABU48@00QBU00<@Q1BU5:D0
0QS60QcW00HDYAS648@<Ha245:D26<H00aBU48@@Q00248@25:D36<H35:D0
11S65:DDYA240QBU00<@Q1BU5:D00aBU00@<Ha2448@@Q0<DY@066<H@Q124
48@DYAS611BU00<@Q0aS48@011BU00<HaQBU5:D00Q2400@HaQBU5:DHaP@D
Y@8@Q0035:DHaQS6008@Q08DY@036<HDYA24008@Q0DDY@8HaP<DY@0348@D
YABU008DY@8@Q0<DY@8@Q08DY@<@Q0046<HDYABU5:D26<H35:D01AcW6<HH
aQBU6<H00QcW00@HaQBU36<@Q0<DY@0348@DYABU008HaP055:D@Q1245:D@
Q0026<H01ABU6<HDYABU48@00QBU0a240QBU0a240PaS0Q241ABU0Q2400<<
Ha2448@01a240QBU0a2400@DYA2448@DY@@@Q0035:D@Q1BU00P@Q00336<@
Q12400P@Q08<H`8@Q0<DY@L@Q0<<H`0348@<Ha24008@Q08<H`0448@DYABU
36<248@25:D348@00aBU48@@Q00236<348@336<248@536<00a2436<@Q003
48@01@aS48@@Q1BU48@00QBU00@@Q0aS36<<H`8@Q0045:D<H`aS36<648@2
36<248@00aS65:D@Q00548@010aS48@@Q0aS0Q2400@DYA2436<@Q08DY@03
48@DYABU008@Q0<<H`D@Q08HaP035:D@Q0aS008DY@046<H@Q0aS48@35:D2
48@236<248@01ABU48@<H`aS48@00QBU11240QS600<@Q1BU36<00Q2400@<
Ha245:DDY@8@Q00536<@Q1245:D@Q00236<448@02ABU48@<H`aS48@DYA24
36<@Q0025:D0312436<@Q12436<@Q0aS48@DYA245:D@Q08DY@0648@<H`aS
48@DYA240PaS0aBU00P<Ha2448@<Ha245:D@Q1BU0`aS0Q240`aS00H@Q0aS
36<<Ha246<H25:D248@00`Q236<@Q0045:D27>L011S65:D@Q1241@aS00<@
Q0aS24800PaS0Q240`aS0Q240PaS0@Q200001@00124000@Q00001@@Q00D0
00@Q6<H]JbDY008DY@036<HLiacW008HaP8DY@8HaP055:D@Q1BU5:DHaP02
5:D248@01ABU6<HHaQS65:D00Q2400<DYAS65:D01ABU00@@Q1BU5:DDY@@@
Q0056<HLiaS65:D@Q0025:D01A2436<DYAS65:D00a240QBU00<@Q1BU48@0
0`aS00<DYAS67>L01AS60QBU00/@Q1BU6<HHaQBU48@<Ha245:DHaQcW00@H
aP<DY@8HaPLDY@8@Q0055:D@Q1BU48@DY@0348@45:D348@011BU48@@Q124
0aBU0Q240PaS0aBU0Q2400<DYAS65:D00QBU00XHaQBU48@@Q1BU48@DY@aS
48@DY@8HaP067>LDYAS65:D@Q1BU0Q2400@DYA245:DDY@8HaP0348@DYABU
008@Q0055:D@Q12448@DY@026<H45:D248@01QBU6<HDYABU48@DY@8@Q08D
Y@8HaP035:DHaQBU008@Q0DDY@0748@DYAS66<HDY@aS48@00QS600<DYA24
5:D00QBU00<HaQBU5:D01ABU0aS60aBU00<HaQBU48@00Q2411BU00<<Ha24
5:D00Q240QBU00<HaQ2448@011BU0Q2400PHaQcW5:DDYA245:DHaQ240QBU
00LHaQBU48@@Q0aS48@HaP025:D348@00aBU48@@Q0065:D00aS65:DDY@02
48@25:D00a245:D@Q00448@011BU48@DYABU1a2400<DYA2448@00Q240aBU
112400LDYA2448@DYA2436<DY@0648@00aBU48@@Q00248@00aBU48@@Q006
36<00a245:D@Q0035:D248@00aBU48@HaP0248@736<00a2436<@Q00236<3
48@00aBU36<@Q00248@25:D00a245:D@Q00436<448@236<448@00`aS48@<
H`0236<00a245:D@Q00336<748@25:D00a2436<@Q0025:D0112436<@Q1BU
0a2400@DY@aS48@@Q08DY@0448@DYAS648@236<00a245:D@Q00236<448@3
5:D448@25:D548@00aBU48@HaP026<H011BU48@HaQBU0Q2400H<HaBU5:DD
YA2436<248@011S65:D<H`aS0Q2400<DYA2448@0112400@<Ha2448@@Q08D
Y@@@Q0035:D@Q12400@@Q00536<@Q12448@<H`0548@236<448@011BU48@D
YA240PaS00<@Q1S65:D00PaS00@DYA2448@@Q0<DY@<@Q08<H`0448@DYA24
48@836<0112436<8@PQ20PaS00<@Q0aS36<00PaS00L@Q1BU7>LHaQ245:D@
Q00336<01a245:D@Q1BU6<HDYAS600<@Q00436<@Q0aS36<248@01@aS248<
Ha2436<00`Q20Q2400<<Ha2448@00@Q2000812402P0012448@Q26<HYBQS6
48@DYAcW0R4800<LiaBU5:D00aS60QBU00@@Q1BU5:DHaP@DY@DHaP8DY@03
48@DYAS600<HaPDDY@0548@<HaBU5:DHaP055:D248@35:D26<H248@236<2
48@011BU48@@Q1240aBU00@HaQBU5:DHaP<DY@8HaP035:D@Q12400<@Q003
6<HLiaS6008DY@@HaP045:DHaQS66<H25:D00a245:DHaP035:D448@25:D3
48@25:D01Q2436<@Q1BU48@DY@8@Q0@DY@@@Q0@DY@8@Q0045:DHaQS65:D3
48@00aBU6<H@Q00248@25:D36<H00aBU6<HDY@035:D00a2436<DY@026<H0
2QBU48@DYABU48@DYA245:D@Q1BU11S600LDYA2448@DYAS65:D@Q0035:D2
48@45:D26<H00aBU48@@Q0045:D01aS648@@Q1246<HLiaBU008@Q0035:D@
Q1BU00<@Q0035:DHaQBU00@DY@076<HDYABU6<HLiaBU48@00QBU00<HaQBU
5:D011BU00<@Q1BU5:D00Q2400<DYA246<H00Q240QBU0QS600<@Q1BU5:D0
21S600<@Q1BU48@01QBU00<HaQBU48@0112400@<HaBU5:DHaP<DY@8HaP8D
Y@<@Q08DY@<@Q00336<@Q124008DY@0348@DYABU00<@Q08DY@0548@DYA24
48@<H`0248@25:D0112436<@Q1BU0a2400D<Ha2436<@Q1BU00<@Q00:5:D@
Q12436<@Q1BU48@<Ha245:D648@336<00a245:DHaP035:D00`aS48@<H`03
48@236<02A245:D@Q124248<Ha2436<@Q0025:D348@011BU6<HDYABU0Q24
00<<Ha2448@00Q240`aS0a240`aS0a240PaS112400@<Ha2448@@Q08DY@@@
Q0045:D@Q12448@25:D348@00`aS48@@Q00548@00aBU48@DY@025:D548@3
36<248@25:D948@25:D0212436<@Q1246<HLiaS65:D348@00aBU36<@Q003
5:D00a2436<DY@0448@01ABU36<<Ha246<H00a240QBU1a2400<DYA2448@0
1Q2400@DYA245:DDY@@@Q0<DY@0448@DYA2448@236<011245:DDYABU0`aS
11240QBU00<HaQBU5:D00a2400DDYA2448@<Ha2400<DY@8<H`05248<Ha24
36<@Q00436<448@00`aS48@8@P0248@35:D01AS65:D@Q0aS24800a2400@D
YA2448@@Q08HaP035:D@Q0aS008@Q08<H`<@Q00436<@Q12448@224800`aS
48@@Q00248@136<12480000700048@00124000@Q00000P@Q00X000@Q124@
Q2487>L@Q1S65:DHaP8DY@036<HLiacW008Li`055:D@Q12448@HaP027>L0
0aS648@DY@095:D011S65:DDYA240QBU00@LiaS65:DDY@8@Q0065:D@Q124
6<HLiaS60Q2400H<Ha245:DDYA2436<348@00aBU48@@Q00448@36<H27>L0
0aS648@@Q0035:D00a245:DDY@0348@25:D021S65:D@Q1S67>LU:AS65:D2
6<H00aBU6<H@Q0035:D00aS67>LDY@0248@01ABU6<HDYA2436<00aBU0a24
00@<Ha245:DDY@8@Q00436<@Q1BU5:D548@010aS48@DYAS60QBU00<@Q1BU
6<H00QBU00<@Q1BU5:D00QBU0PaS00<@Q1BU7>L00aS60QBU0a2400P<Ha24
48@@Q1S65:DLiaS60QBU0Q241ABU0QS600<DYAS65:D00aBU0Q2400DDYA24
5:DDYA24008DY@046<HDYA2448@45:D00aS648@@Q0025:D00aS65:D@Q002
48@011BU6<HHaQBU0a240QBU00@HaQBU48@@Q08DY@036<HDYAS600<DY@8H
aP8DY@8@Q0045:DHaQS65:D248@35:D011S65:DDYABU0a2400@<HaBU6<HH
aP@DY@8HaP035:D@Q1BU008DY@<@Q0<DY@0436<@Q12448@25:D00a245:D@
Q0025:D00a245:DDY@025:D;48@25:D00a245:DDY@035:D448@25:D01124
5:D@Q1240PaS1A240QBU00@@Q1BU48@DY@<@Q00336<@Q12400@DY@<@Q08<
H`<@Q00736<@Q1BU5:D@Q1BU6<H00QBU00@<HaBU48@@Q08<H`<@Q00736<@
Q12436<@Q0aS48@00`aS0Q2400<DYA2448@00PaS00@@Q1BU48@@Q08<H`<@
Q00436<@Q0aS48@336<448@010aS48@<Ha240`aS1A240PaS00H@Q1BU5:DD
YA245:D548@00aBU48@@Q00448@01QBU48@DYA245:D@Q08DY@0648@<H`aS
48@DYA240PaS112400<DYA2448@02A2400<<Ha2448@00Q2400<DYA2448@0
0Q2400<DYAS648@00QBU00<@Q1BU5:D01A2400<<Ha245:D00a2400HDYA24
48@<HaBU48@236<348@336<00a245:D@Q00236<248@020aS5:DDYABU48@<
Ha245:D348@00`aS48@@Q00648@00`aS5:D@Q00348@25:D448@35:D00`aS
48@@Q00448@436<01A2436<@Q12436<00PQ200<<Ha2436<00PQ200D@Q0aS
48@<Ha24008DY@8HaP035:D@Q12400@<H`085:DHaQBU36<@Q1BU6<HDY@D<
H`<@Q08<H`<@Q00436<8@PaS36<248@136<1248000`48@085:DU:AS648@H
aQcW6<HDY@<HaP057>LQ22485:D@Q00236<26<H01ABU6<H@Q1246<H00QBU
0aS600<@Q1BU48@00QS60QBU00l@Q1S66<HHaQBU36<@Q1BU48@HaQ245:DQ
21S65:D00PaS0QBU0Q2400<DYA245:D00a2400@DYA2436<@Q0<DY@<HaP8D
Y@@@Q0035:DHaQS600DDY@046<HDYABU6<H37>L26<H25:D01A245:DDYAS6
5:D00QS600DDYA2448@@Q1S600<@Q0035:D@Q12400L@Q0085:D@Q12448@D
YAS648@<H`<@Q00736<@Q1S66<HDY@aS5:D00QS61QBU0a2421BU0a240QBU
0a240aS60aBU112411S60aBU0QS60QBU0Q2400<DYA246<H01ABU00@HaQBU
48@@Q08DY@0748@DYABU5:DHaQ245:D00Q240aBU00<HaQBU48@00a240QS6
0QBU00<@Q1S66<H011BU0aS61ABU00@HaQBU5:DDY@@@Q0035:DHaQS6008D
Y@0548@DYA245:D@Q0045:D26<H25:D348@00aBU6<HDY@0248@45:D00a24
5:D@Q0035:D248@25:D248@26<H448@00aBU48@@Q00648@00`aS5:DDY@02
5:D01A245:D@Q1BU36<0112400@<HaBU48@DY@@@Q00336<@Q1BU008DY@D@
Q00336<@Q124008DY@0548@DYABU5:D@Q00236<25:D01A2436<<Ha245:D0
0QS60aBU00H@Q1BU5:D@Q1BU48@336<248@236<00a2436<<H`0336<01Q24
5:D@Q1BU48@<H`8@Q0035:D@Q124008DY@<<H`0348@<H`aS008<H`035:D@
Q1BU00P@Q08<H`<@Q08<H`@@Q0045:DHaQBU5:D248@45:D348@010aS48@@
Q1BU0Q2400D<HaBU5:DDYAS6008@Q00436<@Q1245:D548@25:D00a245:DD
Y@0548@010aS48@@Q1BU0PaS00@@Q1BU6<HDY@<@Q0035:D@Q0aS008@Q08D
Y@8@Q0045:D@Q12448@25:D448@25:D348@00`aS48@@Q00248@00`aS48@@
Q00248@00`aS48@@Q0025:D248@00`aS48@@Q0025:D548@01PaS48@<H`aS
48@<H`8@Q00536<@Q12448@DY@0448@25:D348@25:D248@010aS48@DYABU
0Q243@aS00@@Q0aS36<8@P<<H`03248@Q1BU008Li`@@Q0045:D<H`aS36<3
5:D02A245:DDYABU48@<Ha2436<@Q00636<01@Q236<<H`aS48@00PaS0Q24
0@aS00001P0012448@00124000@48@0@0008@QS6:DXHaQ245:DHaQBU6<HD
YAS67>LQ22DY6<H27>L01ABU48@@Q1BU6<H00a240QS600@DYA245:D@Q08D
Y@<HaP8DY@8HaP067>LDYABU48@DYA240QBU0QS60aBU0Q240PaS00HDYA24
36<@Q1BU6<H348@01ABU48@@Q0aS5:D011S600<DYA245:D00QBU0a240aBU
0a2400HDYAS66<HHaQcW6<H27>L56<H25:D01AS65:DDYABU6<H00QBU00<@
Q1BU48@00Q2400<DYA245:D00a240PaS0a2400@DYA2448@@Q0@DY@8@Q003
5:DHaQS600HDY@@@Q0046<HDYABU5:D248@46<H0112436<@Q1240QBU00<@
Q1BU5:D01ABU0a2411BU00<HaQBU48@00QBU00@LiaBU5:D@Q0DDY@0348@D
YABU008DY@036<H@Q1BU00<DY@<@Q0065:DHaQS65:D@Q0aS0Q2411BU00@@
Q1BU48@@Q0<DY@0348@DYA24008DY@0348@DYAS6008DY@0348@DYABU00@D
Y@0348@DYA2400TDY@066<HDYABU48@HaQBU0QS600<DYA245:D00QS60QBU
00@@Q1BU5:DDY@<@Q08DY@0348@DYA2400<DY@0948@<Ha245:DHaQBU48@<
Ha2400<DY@0348@<Ha24008@Q0095:D@Q12448@DYAS65:D@Q1BU008@Q08D
Y@8@Q08<H`0348@DYABU00<<H`8@Q08<H`<@Q0045:D@Q1245:D348@00`aS
48@@Q0026<H00aBU48@@Q00348@01@aS48@@Q1S65:D00Q2411BU0Q2411BU
0Q2400@<Ha2448@@Q0@<H`0348@<H`aS008@Q08<H`<@Q0045:D@Q0aS36<2
5:D236<348@010aS48@@Q1240`aS00@@Q1BU48@@Q08<H`<@Q0<<H`D@Q005
5:D@Q12448@HaP025:D01A245:D@Q1245:D0112400<HaQBU5:D00PaS0a24
00<DYA2448@00QBU1A240aBU0Q240aBU0PaS00<@Q1BU48@00a240PaS0Q24
00@DYA2436<<H`<DY@<@Q0<DY@@@Q0<DY@0448@DYABU5:D248@25:D348@0
0aBU48@@Q0025:D548@010aS48@@Q1240aBU00@@Q0aS48@DY@P@Q00436<@
Q1245:D348@00`aS5:D@Q0035:D01A245:DDYABU48@00PaS00<@Q1BU5:D0
1Q2400D<H`Q22488@PaS00@@Q00436<8@PaS36<248@236<00a2436<<H`02
36<348@25:D548@010aS48@DYABU0a2411BU00H@Q0aS36<@Q0aS48@336<0
0a2436<@Q00348@236<148@1248000848@0300048@@Q00<48@0900048@@Q
124HaRDY6<H@Q1BU008HaP<DY@087>LU:B487>LHaQcW5:D@Q08DY@046<H@
Q12448@45:D248@01QBU6<HHaQBU6<HDY@8@Q0<HaP8DY@0348@DYA2400@D
Y@0348@DYABU00H@Q08DY@<@Q08DY@0348@<Ha2400DHaP8DY@0348@DYA24
008@Q0@DY@0448@DYA245:D36<H00aBU6<HLi`026<H25:D46<H01ABU6<HD
YABU48@00aBU0Q2400<DYAS648@00PaS00<DYA2448@00PaS0Q240aBU00<@
Q1BU48@00QBU0a2400<DYAS67>L011BU0Q240QBU00/@Q0aS48@LiaBU48@<
HaBU8@PLiaBU00@@Q0045:D@Q1BU5:D348@00aS65:DDY@045:D348@01ABU
6<HHaQBU48@01QBU00<@Q1BU5:D00QBU0Q2400DDYAS66<HHaQBU008@Q0@D
Y@0548@DYABU5:D@Q0025:D26<H00aBU48@@Q00248@35:D01A245:DDYA24
5:D00Q241QBU0a2411BU00D@Q1BU48@DYA2400<DY@0748@DYABU5:D@Q1BU
48@00QBU00PHaQBU6<HDYA246<HLiaS60Q2400<DYAS65:D00aBU0Q2400<D
YA245:D00aBU0Q2411BU0Q2400<DYA246<H00QBU00<@Q0aS36<00a2400PD
YA2448@@Q1BU48@DYA2411BU0a2400<DYA2436<00Q240`aS00<@Q1BU48@0
0a240QBU0Q240QBU0Q240QBU00@HaQBU48@<H`<@Q0075:D@Q1BU5:D@Q1BU
6<H00QBU0a2400LHaQBU48@<Ha2436<DY@0248@236<00a2436<<H`0336<2
48@25:D00a2436<@Q0025:D648@336<448@336<348@00`aS48@<H`0548@5
36<00a245:D@Q00448@00aBU48@DY@0348@25:D01AS648@@Q1245:D00`aS
00@DYA2448@@Q0<DY@0348@DYA24008@Q0035:D@Q124008@Q0045:D@Q1BU
36<248@35:D010aS48@<Ha240PaS00P@Q0aS48@@Q1BU48@DYA240QBU0a24
0aBU00@@Q1BU48@<H`8@Q0<DY@036<HDYABU008DY@8@Q00336<@Q12400@@
Q00336<@Q12400P@Q08DY@D@Q08DY@<<H`0348@DYA24008@Q0045:D@Q124
5:D348@55:D011245:DDYABU0Q2400HDYA2448@@Q0aS48@636<248@336<2
48@336<248@336<00a245:DDY@0648@00`aS48@DY@035:D248@011BU6<HD
YABU1`aS0Q2400<<Ha2436<00`aS0Q240@aS0@Q200001@0012448@@Q0000
1`@Q00D@Q2DY7>LDYAS600<DY@0348@HaQS6008Li`045:DHaQcW6<H236<0
1AS67>LDYA245:D00QS600@DYA245:DHaP8DY@8Li`8DY@8HaP0:7>LHaQBU
5:D@Q1BU48@DYA2436<25:D011cW6<H@Q0aS1Q240QBU0a241ABU0QS600<L
iaBU48@00Q2400<DYAS65:D01QBU0Q2400<DYA245:D00aS60aBU00<HaQcW
6<H00QS60aBU00@HaQ2436<@Q08HaP035:D<Ha2400<DY@L@Q08DY@046<HD
YA2448@25:D011245:DDYABU0QS60QBU0Q2400@HaQBU5:D@Q08DY@0948@D
YABU5:D@Q1BU6<HDYAS600@@Q08DY@036<H@Q124008@Q0036<HDYABU00<@
Q0045:D@Q12448@25:D01a245:DHaQS65:DHaQBU008HaP8DY@046<HDYABU
48@35:D00aS65:DDY@026<H00aBU48@@Q00248@35:D348@35:D448@011BU
48@@Q12411BU00@<Ha2448@DY@8HaP035:D@Q124008DY@<@Q0035:DHaQ24
00<@Q0DHaP<@Q0@DY@<HaP8DY@066<HDYABU6<HLiaBU0Q240aBU00P@Q1BU
5:DDYAS65:D@Q1BU11240QBU0a240QBU00<@Q1BU6<H00a2400L<Ha2448@@
Q1BU48@DY@026<H25:D00a2436<@Q00348@01aBU48@@Q12436<DYA24008<
H`H@Q0055:DHaQ245:D@Q0025:D00a245:DDY@025:D00a245:D@Q00348@0
0aS65:DDY@025:D021245:D@Q1245:D@Q1BU6<H25:D0112436<@Q1240aBU
00@<Ha2436<@Q08<H`<@Q00436<@Q1245:D448@25:D00a245:D@Q00336<2
48@236<348@01`aS48@<H`aS48@DYA2400@<H`0348@<H`aS00@@Q00536<@
Q12448@<H`0248@00aBU48@@Q00248@011BU48@DYABU0Q240PaS0a240PaS
0Q240QBU00<HaQBU5:D00QBU00D<Ha2448@DYAS6008DY@@@Q0055:D@Q124
48@<H`0748@00aBU48@DY@0248@55:D448@25:D348@00aBU48@DY@0248@3
5:D00a2436<@Q00236<011245:DDYABU0a2400<<Ha2436<011BU00H@Q1BU
5:DDYA245:D248@25:D248@010aS48@DYABU11240QBU00@@Q1BU5:DDY@8@
Q00336<@Q1BU008DY@H@Q0@<H`04248<Ha245:D336<00a2436<<H`0348@0
1aBU36<<H`aS248@Q0aS00@@Q0045:D@Q12448@236<248@00aBU48@DY@03
6<H01ABU48@<Ha2424800`aS00<@Q0aS36<00Q240`aS00<@Q0aS36<00@Q2
000312400`0012448@0312401`0012448ABU:DXLia2400@DY@8@Q0086<HL
iaS66<HDYAS648@<H`8@Q08DY@0448@DYAS66<H25:D248@00aBU6<HDY@02
5:D01QS65:DHaQS67>LDY@<@Q08DY@<@Q08HaP095:D<Ha2448@<Ha245:D@
Q1BU00<@Q08DY@8@Q0@DY@8HaP8DY@0548@DYABU5:DHaP055:D011245:D@
Q1240QBU0aS60aBU0acW0QS61QBU00<@Q1BU5:D00Q2400<DYAS65:D00QBU
0a240PaS00<DYA245:D01aBU0Q240aBU00<@Q1BU5:D00QBU0Q240QBU00<@
Q1BU48@00aBU00<@Q1BU6<H00aBU0a240aBU00H@Q1BU5:DHaQ2436<548@0
0aBU48@DY@025:D01QS65:DDYAS65:DHaP<DY@8HaP045:DHaQ2448@75:D0
0aS648@@Q00348@00aS65:D@Q00348@55:D00a245:DDY@0348@25:D248@0
10aS48@HaQS60aBU0a2400DDYA245:DDYA2400`DY@0348@DYA24008HaP03
7>LHaQS600PDY@0348@DYABU008@Q0035:DHaQS6008DY@036<H@Q1BU00<@
Q08DY@D@Q0035:DHaQ24008@Q00836<@Q12436<DYA245:D@Q08DY@056<HD
YA2448@DY@0548@01ABU48@@Q12436<00a2400DDYA2448@<HaBU008@Q003
5:D@Q124008DY@036<HDYABU00@@Q00336<@Q12400@DY@8@Q0<DY@8@Q003
5:DHaQBU00D@Q0<DY@@@Q00336<@Q0aS008<H`D@Q08<H`8@Q0<DY@0348@<
H`aS008@Q0035:D@Q124008<H`@@Q00336<@Q124008@Q0<<H`8@Q00436<@
Q12448@236<00a245:D@Q00748@75:D648@236<011245:DDYAS60a240aBU
0a240aBU0a2400<DYA2448@00a2400<DY@aS48@00QBU00<HaQ2436<01Q24
11BU0Q241QBU11240aBU212400@DYA2436<<H`D@Q0HDY@T@Q08DY@0348@<
Ha2400D@Q0DDY@0548@<Ha2448@DY@0548@01PaS48@<H`aS48@8@P8<H`<@
Q0<8@P0336<@Q0aS00@@Q00336<8@PaS00L@Q00336<@Q12400@@Q0045:DH
aQ2448@26<H00aBU48@<H`0336<248@010aS248<H`aS0Q2400D<Ha2448@<
H`Q200448@0000<48@0012400P@Q00<000@Q12400P@Q00H000Q25:D]JacW
5:D26<H25:D00a245:DDY@035:D36<H011BU48@DYABU0Q2400@DYAS66<HH
aP@DY@DHaP8DY@8HaP055:D@Q0aS48@DY@0348@26<H01ABU48@<H`aS48@0
0PaS00<@Q1BU6<H00QBU00D@Q0aS48@DYA24008DY@8HaP037>LDYA24008@
Q0HDY@8@Q0085:D@Q0aS5:DHaQBU48@<H`@DY@8HaP8Li`048@PLib487>L2
5:D236<35:D348@00aS65:D@Q00748@25:D01A245:DDYAS65:D00Q2400@L
iaS648@@Q08HaP8DY@@@Q08DY@036<HDYABU00<@Q0035:D@Q1BU008HaP8D
Y@@@Q0065:D@Q1BU5:D@Q1BU0Q240QBU0a240PaS0Q240QS600DDYAS65:DD
YAS600DDY@0448@DYABU5:D248@010aS5:DHaQS60QBU00<@Q1S65:D00a24
00DDYAS65:DDYA2400DDY@8@Q08HaP0548@DYABU5:D@Q00236<248@25:D0
1AS65:DDYA245:D00a240QBU00@@Q0aS5:DHaP<DY@036<HDYABU00DDY@8H
aP8DY@8HaP8DY@<HaP045:D@Q12448@55:D348@25:D248@00`aS48@DY@02
5:D248@45:D00a245:D@Q00236<01A2436<<Ha245:D00QS61A2400<DYA24
36<0112400<DYA245:D021240QBU00@@Q1BU5:DDY@8@Q0035:D@Q1BU008@
Q0035:D@Q12400<@Q0<DY@@@Q0045:D@Q1BU5:D748@25:D00a245:D@Q002
5:D436<00a2436<@Q0025:D0112436<<H`aS0QBU0QS60Q240PaS0a240`aS
00LDYA2436<<Ha245:D@Q00236<00a2436<<H`0348@336<548@010aS48@@
Q1BU0a2400DDYA2436<<HaBU008HaP045:D@Q0aS36<348@236<248@35:D0
0a245:DDY@025:D00aS65:D@Q0035:D00aS648@@Q00<48@25:D248@25:D3
48@25:D01A2436<@Q1BU48@011BU0Q2400@DYA2448@<H`8@Q08DY@0336<D
YABU008@Q00336<@Q1BU00@@Q0@DY@8@Q0056<HDYA245:D@Q0025:D448@0
0aBU48@@Q00348@011BU48@@Q1241ABU0Q240aBU00<@Q0aS36<0112400@<
Ha2448@@Q0H<H`0348@<H`aS00@@Q00336<@Q12400@<H`0448@<H`aS36<3
48@236<248@26<H25:D00a246<HDY@0248@236<01A2436<<H`aS48@00aBU
00D<H`Q2248<Ha24004<H`000P@Q00<000@Q00001`@Q00<DYBe[8@P00aBU
0Q240aBU00D@Q1BU5:DHaQBU008HaP045:D@Q12448@25:D26<H25:D00aS6
5:DDY@025:D36<H35:D01QS65:D@Q1245:D@Q0@DY@036<HDYABU00`@Q0DD
Y@036<HLiaS6008HaP035:D@Q12400<HaP<DY@<@Q0045:DHaQBU5:D348@0
11S65:DDYA240QS600@Lib487>LLi`8HaP095:D@Q12448@DYAS648@<Ha24
008DY@036<H@Q124008<H`@@Q0055:D@Q1245:DLi`0248@011BU6<HLiaS6
0QBU00@HaQBU5:D@Q0<DY@0548@DYA2448@DY@026<H348@00aS65:DDY@02
5:D00a245:D@Q0035:D448@00aBU48@@Q00848@011S65:DHaQS611BU00DH
aQBU5:DDYA2400@DY@0348@DYABU008DY@0448@DYABU5:D648@75:D248@8
5:D248@00aBU48@DY@025:D011S65:DDYABU112400<DYA2448@011BU0Q24
00<HaQBU6<H00QBU00<@Q1BU5:D00QcW0QS61aBU0Q2400<DYA245:D00aBU
00L@Q1BU5:DDYA2436<@Q0025:D011245:D@Q1240QBU00@@Q1BU5:DDY@8@
Q0045:D@Q12448@236<011BU6<HHaQBU11240aBU0a2400PDY@aS48@@Q1S6
5:D<Ha240QBU00@@Q0aS36<@Q0<DY@036<HDYABU008DY@8@Q08<H`D@Q0@D
Y@0648@<Ha2448@HaQBU1Q240QBU0Q240QBU00<@Q1BU5:D00a2400@<Ha24
48@DY@D@Q00436<DYABU5:D248@010aS48@@Q1240PaS0Q2400<DYA2448@0
0a241@aS00<@Q0aS48@00Q2400D<Ha2448@DYA2400<<H`@@Q0045:D@Q124
36<248@011S65:DHaQS6112400<<Ha2436<00a2400@DYA245:D@Q08HaP8@
Q0045:DHaQBU48@25:D011S65:D@Q1BU0a2400<DYA2448@01Q2411BU00@@
Q1BU48@@Q08DY@D@Q0045:D@Q12436<25:D248@35:D448@00aBU48@DY@02
48@01@aS5:DDYABU48@011BU00<@Q1BU48@00a2400HHaQBU5:D@Q1BU48@2
36<01A245:DHaQ2436<00Q240QBU00<@Q1BU5:D00QBU11240aBU0Q240PaS
00<@Q1BU48@00a240PaS0PQ210aS0Q240PaS0Q240`aS0Q240`aS1Q240`aS
0QBU00@HaQBU5:DDY@8HaP055:D<H`aS36<@Q00336<548@536<000030004
8@@Q00<48@0400048@@Q0002124011BU9BTLia240QS600H@Q1BU5:DHaQBU
48@65:D26<H248@25:D01QS65:DDYABU6<HDY@8@Q0055:DHaQS65:D@Q002
5:D00aS65:D@Q00248@00aBU48@@Q00448@011BU48@@Q1BU0PaS0Q240QBU
00@@Q1BU5:DDY@<@Q0@DY@8@Q08DY@096<HDYABU6<HDYAS648@DYA2400<D
Y@036<HDYABU008HaP@DY@8HaP<Li`0648@<Ha245:DHaQBU0a2411BU00<@
Q0aS48@00Q2400DDYA2448@@Q1BU008HaP8DY@8@Q00436<HaQS67>L25:D0
1QS65:DHaQ245:D@Q0@DY@<@Q00;5:D@Q12448@DYAS67>LHaQ2436<@Q002
5:D00a245:DHaP025:D011245:DDYABU0a2400<DYA2448@00a2400LDYAS6
6<HLiaS65:DHaP045:D00a245:DDY@035:D00a245:DDY@0248@25:D248@4
5:D348@25:D00aS65:D@Q00248@26<H01ABU6<HHaQS65:D01a2400<DYAS6
5:D00a2400<HaQBU48@00a2400<DYAS66<H00aBU00DHaQBU5:DDYAS600@D
Y@8HaP8DY@<HaP045:DHaQBU48@35:D00aS65:DDY@0348@25:D26<H25:D0
31245:DHaQS65:D@Q0aS48@DYA2436<@Q08DY@D@Q0DDY@D@Q0036<HDYABU
008@Q0DDY@8@Q0035:D@Q1BU00H@Q08DY@046<HDYABU5:D448@25:D248@0
0aBU48@DY@025:D26<H00aBU48@@Q0035:D01A2436<@Q1245:D00Q2400<<
Ha245:D00Q2400<<HaBU5:D00Q2400@<Ha245:DDY@8@Q0035:D@Q124008<
H`0548@DYA2448@<H`0448@010aS48@<Ha240`aS00<@Q1BU48@0112400@D
YA2436<@Q08DY@0448@<H`aS48@336<00aBU48@@Q00348@236<248@011BU
48@DYABU0a2400<DYA2448@00Q2400HDYA245:D@Q1BU48@35:D248@25:D0
0aS65:DHaP035:D248@01@aS48@DYA2436<00QBU00<HaQ2448@00QBU0Q24
00<DYAS648@00Q240QBU0Q2400<DYA2448@00Q2400@DYA2448@DY@D@Q0<D
Y@0348@DYABU00@@Q0035:D@Q12400<DY@8@Q0<DY@<@Q0055:D@Q1BU48@<
H`0248@25:D248@35:D448@65:D548@236<448@00`aS48@@Q00348@010aS
248<H`aS0Q2410aS00<@Q0aS36<00a2400<<Ha2448@00Q2410aS0aBU00<@
Q1BU5:D00a2400<DYAcW5:D00Q2400<DYA2436<00a2400<DYA2448@00PaS
00<@Q0aS36<00A24000412401@0012448@@Q00000`@Q00DDYBDY7>L@Q1S6
008DY@0448@DYABU5:D248@00aBU6<HHaP026<H01Q2436<<Ha245:DHaP@D
Y@036<HDYA24008@Q0@HaP8DY@036<H@Q1BU008DY@8@Q08DY@036<HDYABU
008@Q0<<H`8@Q0DDY@0348@DYABU008@Q08DY@8HaPDDY@8HaP055:D@Q124
5:D@Q0055:D00aS65:DDY@036<H011BU36<@Q1S60QcW00<HaQ245:D011BU
0Q240PaS0a240QBU00L<H`Q248@HaQBU36<@Q0036<H348@02PaS48@DYAS6
7>LDYA245:DHaQBU11240QBU0a2400@DYAS648@@Q08DY@037>LHaQ2400<@
Q00;5:DHaQBU48@DYA245:DHaQBU48@DY@0848@01ABU6<HHaQS67>L00QS6
00<DYA245:D00QS600DDYA2436<DYAS6008DY@0348@DYABU008DY@8@Q004
36<@Q1S648@236<01aBU6<H@Q1245:DLiaBU008@Q0035:DHaQS600<DY@03
6<HDYA24008@Q08DY@0348@DYABU008DY@0648@DYA2448@DYA240QBU00<@
Q1BU48@00Q2400<DYAS66<H00QBU00<@Q1S65:D00QS60QBU11S60QBU00DH
aQBU5:D@Q1BU008HaP<DY@0348@DYA24008@Q08DY@0348@DYA2400@DY@03
48@DYAS600<@Q0<DY@@@Q00336<@Q1BU008DY@0848@DYABU48@DYA245:D@
Q0@DY@0448@DYABU5:D448@00aBU48@<H`0248@45:D01A245:DDYABU36<0
0Q240aBU00<HaQBU5:D00Q240aBU00@@Q1BU5:DDY@D@Q00336<@Q12400@@
Q0<DY@0448@<Ha2448@35:D00a2436<@Q00248@236<648@436<248@011BU
48@<H`aS0Q2400HDY@aS36<@Q1BU48@236<248@25:D00a2436<<H`0236<7
48@010aS48@<Ha2411BU0Q240QBU1Q2400<<Ha245:D00aBU00@@Q1BU5:DH
aP@DY@8HaP8DY@8<H`H@Q0055:D@Q12448@DY@0348@35:D01A2436<@Q124
5:D00Q240QBU0a2400<DYAS648@00Q2400<DYA2448@00Q240QBU212400DD
YA245:DDYA24008DY@0548@<H`aS48@DY@0448@01ABU48@DYAS65:D00a24
00@DYA245:D@Q08DY@056<HDYA2436<DY@0248@00`aS48@@Q00848@>36<2
48@236<248@01PaS48@<Ha2436<@Q08<H`8DY@0648@<H`aS48@DYA241ABU
00<HaQBU48@00a240`aS00<@Q1BU48@01PaS00000`001240000212400`00
12448@0212401P00248DYBDY6<HDY@@HaP8DY@0448@DYABU5:D26<H25:D0
0a245:DHaP045:D26<H00aBU48@DY@075:D46<H00a2436<@Q0045:D00a24
5:D@Q00648@35:D248@00aBU6<HHaP0448@00aS65:D@Q0035:D00a246<HH
aP025:D248@25:D248@00aBU6<HDY@025:D011245:DDYAS60aBU00<HaQcW
6<H01A2400HDYA2436<@Q1BU48@45:D00a245:DDY@0248@236<00a245:DH
aP035:D03AS65:DDYABU6<HDYA245:D@Q1BU48@DYA2400<DY@@@Q00<5:D@
Q1BU48@DYAS65:DHaQBU48@DYA240QBU00<@Q1BU48@00QBU112400<DYA24
5:D01a2400@DYAS65:DHaPDDY@0548@<Ha2448@DY@026<H25:D011245:D@
Q1BU0a240aBU0Q241QBU0Q2400@<Ha2448@@Q08DY@8HaP8DY@0448@DYABU
48@45:D00a245:D@Q0035:D01A245:D@Q1BU48@011BU00D@Q1BU5:DDYAS6
00<DY@8HaP055:DHaQS67>LHaP035:D011S65:DLiacW0QBU0Q2400DDYAS6
5:DHaQBU008HaP045:D@Q0aS48@35:D00a246<H@Q00348@00aBU48@DY@02
48@25:D011245:DDYABU11240QBU00<@Q1BU48@00aBU00<HaQBU5:D00a24
00HDYA2436<<Ha245:D348@011BU48@@Q1241ABU0Q2400DDYA246<HDYAS6
00<DY@046<HDYABU5:D748@00`aS48@@Q00236<248@236<448@01@aS48@@
Q1BU48@00`aS112400<<Ha2448@00QBU0Q240PaS0a2400<<Ha2436<00Q24
00<<Ha2448@00Q2410aS00H@Q1BU48@@Q1BU48@336<248@25:D448@00`aS
48@@Q00748@011BU6<HHaQBU0a240QBU00D@Q1BU6<HHaQBU008@Q0045:D@
Q12448@55:D548@236<248@25:D01a2436<DYABU6<HDYA2400<DY@<@Q003
5:D@Q1BU00<DY@@@Q0035:D@Q12400<@Q0055:D@Q12448@DY@0748@00aBU
48@@Q00348@01ABU48@DYA246<H00QBU112400<DYA2448@00Q240aBU00T@
Q1BU5:D@Q0aS48@HaQBU36<00Q240QBU00H@Q0aS36<<Ha245:D248@00`Q2
36<<H`0336<248@236<248@336<00a2436<@Q00336<248@436<248@236<4
48@010aS48@@Q1240aBU00HHaQcW6<HDYA245:D748@336<248@000<48@03
00048@@Q00<48@0800048@@Q48@U:B485:DHaP@DY@0348@DYAS600LDY@05
48@DYABU6<HDY@036<H25:D248@75:D00acW6<HDY@0348@00aBU48@DY@02
5:D448@00aBU48@@Q00348@00aBU48@@Q0045:D348@00aBU48@@Q00248@0
1aS65:DHaQS65:D@Q0aS00<DY@8@Q08DY@066<HDYA2448@DYAS60aBU11S6
00<DYA2448@00QBU00@@Q0aS48@@Q08DY@8@Q08DY@D@Q08<H`0448@DYAS6
6<H35:D00a245:DDY@045:D011S648@DYA240aBU11240QBU00@@Q1BU6<HH
aP<DY@8HaP055:D@Q1245:DHaP065:D348@25:D011245:D@Q1BU0Q2400@D
YA246<HLi`8HaP0348@HaQS6008DY@0336<@Q1BU00@DY@<@Q0035:D@Q1BU
008@Q08DY@066<H@Q1BU5:DHaQBU0Q2411BU0Q240aBU00<HaQBU5:D00QS6
00<DYA2448@01ABU0Q2411BU0Q241QBU00<@Q1BU5:D01ABU11S60QBU0aS6
0QBU0QS60QBU00P@Q1BU5:DDYA245:D@Q1BU0QS61ABU0Q240QS600@DYA24
48@DY@@@Q0035:D@Q12400<DY@<@Q00:5:DHaQ2436<@Q1BU6<HDYA245:D2
6<H25:D448@35:D448@011BU48@DYA241ABU0a2400<HaQBU6<H011BU00<@
Q1BU5:D00Q2400<DYA2448@00Q2400<<Ha2436<0112400D<Ha2448@<Ha24
00<<H`T@Q00336<@Q1BU008@Q00336<@Q1BU008@Q0<<H`8@Q0@<H`0548@<
H`aS48@<H`0448@00`aS48@@Q0025:D336<01A245:DDYA2424800PaS00DD
YA2448@@Q1BU00<@Q0035:D@Q124008@Q0@DY@<@Q0055:D@Q1BU5:DHaP04
5:D448@25:D448@00aBU48@@Q00448@011BU48@DYABU0a240aBU0Q2400<H
aQBU48@00Q2400<DYA246<H00aBU0PaS0Q2400<DYA2448@00Q2400/DYA24
48@@Q1BU48@DYA245:D@Q1BU00<@Q08DY@8@Q0<DY@0448@DYAS65:D248@0
11BU48@DY@aS0Q240QBU0Q240QBU0a2400<DYA2436<00Q2400@HaQBU48@@
Q08<H`8@Q0035:D@Q12400T<H`0648@<H`aS48@<Ha2410aS00@@Q1BU48@@
Q08<H`0548@<H`aS36<DY@0448@00aBU48@@Q0035:D36<H35:D02a245:DD
YA2436<@Q1BU48@<H`Q236<00Q2400001@0012448@@Q00001`@Q00<<HbU:
8@P00QS600H@Q0aS5:DDYAcW6<H95:D00aS65:DDY@035:D00aS65:DDY@03
48@35:D011S67>LQ21S60QBU00@HaQBU5:DDY@<HaP@@Q0035:D@Q1BU008D
Y@8@Q00336<DYAS6008DY@0448@<Ha2448@25:D248@25:D021245:DDYAcW
6<H@Q0aS48@26<H45:D00aS65:D@Q00248@55:D01QS67>LLiaS648@DY@8<
H`@@Q00536<@Q1BU6<HDY@0348@25:D348@011BU48@HaQS60QcW00PHaQBU
48@@Q1BU6<HDYA240QBU00D<HaBU5:DHaQBU008@Q0DDY@8@Q0066<HLiacW
5:D@Q0aS1QBU00@@Q1BU5:DHaP8DY@<@Q0045:D@Q1245:D448@00aBU6<HD
Y@036<H35:D00a245:DDY@0248@25:D011S648@@Q1240QBU0a241QBU00<H
aQ2448@00QBU00<HaQBU48@00Q2400`DYAS65:DHaQcW6<H@Q1BU6<HLiaS6
5:D248@35:D248@00aBU48@@Q0035:D00aS65:D@Q00248@00aS65:D@Q002
5:D011S67>LLiaS60aBU0QS611BU00<HaQ246<H00QS600<DYA2448@00aBU
0aS600<DYAS65:D00QS600<DYA245:D00aBU0Q240aBU00D@Q1BU48@DYAS6
00@DY@0348@DYA24008@Q0@DY@0348@DYABU008HaP<DY@P@Q00436<@Q124
5:D348@03ABU6<H@Q12436<@Q1BU48@DYA245:DHaQcW008DY@8@Q0035:D@
Q1BU008HaP0;5:D@Q12448@<Ha2436<@Q0aS48@<H`0348@25:D00a2436<8
@P0348@236<011245:DDYABU0Q2400D<HaBU5:DDYA24008<H`8@Q08<H`04
48@<H`aS36<25:D00a2436<<H`0248@00`aS48@DY@0248@236<248@436<3
5:D348@01`aS48@@Q1BU48@DYA24008DY@8@Q08DY@0548@DYABU48@DY@04
48@35:D00a245:D@Q0025:D01Q245:DDYABU48@<H`8@Q0035:D@Q12400P@
Q0<DY@8@Q08DY@8@Q0055:D@Q1BU48@DY@0;48@011BU6<H@Q0aS0Q240QS6
1A2411BU0a2411BU00<HaQBU5:D00a2400@DYA245:D@Q0<DY@<@Q0045:D@
Q0aS36<248@010aS48@DYABU0a2400DDY@aS36<@Q1BU00<@Q0@<H`03248<
H`aS00<@Q00536<8@PaS36<@Q00236<00a245:D@Q00436<248@01`aS48@<
Ha2436<DYA2400DDY@8@Q08DY@8Li`035:D@Q0aS008DY@0448@<Ha2448@2
36<248@136<00003124000@Q00848@0400048@@Q000312400aBU:DXQ2004
5:D26<H25:D00aS65:D@Q0025:D01AS65:D@Q1BU48@00QBU0Q240aS600@@
Q0aS48@HaP<DY@066<HLib488@PDYA241ABU00@HaQBU5:DDY@H@Q08DY@03
48@DYABU00@@Q0035:D@Q1BU00<DY@8@Q0035:DHaQ2400<HaP065:D@Q124
6<HDYA240QBU00<HaQBU5:D011BU1AS600<LiaS65:D00a2400<<Ha2436<0
0Q2400DDYA2448@@Q1BU00<@Q0035:D@Q124008@Q08DY@046<HLiaS65:D3
6<H45:D26<H348@01QBU6<HDYA2436<@Q08DY@046<HDYABU5:D27>L01AS6
48@@Q1245:D00Q240aBU00H@Q1BU6<HDYA2436<35:D00a2436<@Q00448@0
11BU6<HDYAS60QBU0aS60QBU0Q2400@HaQBU5:DDY@8@Q0035:D@Q12400<D
Y@8@Q0@DY@036<HDYABU008@Q0<DY@<@Q0@DY@057>LDYABU48@DY@027>L0
0aS65:DDY@045:D01AS648@@Q1245:D00Q240QS600<DYA2448@00QS60aBU
1AS600hDYAS65:DDYAS67>LHaQBU48@DYAS67>LHaQBU0Q2400<DYA245:D0
0QS60aBU00<HaQBU48@00Q240QS600<DYA2448@011240PaS11BU00D@Q1BU
48@DYA2400<DY@8@Q08DY@076<HDYABU48@DYAS65:D00Q2400@DYA2448@@
Q08DY@8@Q08DY@8<H`0348@HaQS600@DY@0848@DYA2448@HaQcW6<HDY@<@
Q0DDY@8HaP8@Q08<H`@@Q00436<@Q12448@236<01A245:D@Q12436<00a24
00@DYA245:D@Q08DY@8@Q00336<@Q1BU008@Q00336<@Q12400D<H`D@Q007
36<@Q12448@DYA245:D00Q2400DDYA2448@@Q0aS00<@Q0<DY@0348@<Ha24
00D@Q0@DY@8@Q0035:DHaQBU00@DY@<@Q0035:D@Q1BU008DY@036<HDYA24
008@Q08DY@`@Q00436<@Q1BU6<H25:D02A245:DHaQBU48@DYA245:D@Q003
5:D348@00aBU48@@Q00448@00aBU48@DY@025:D348@011BU48@@Q12411BU
00@@Q1BU5:DDY@8@Q0045:DHaQBU5:D248@011BU48@DYABU0a240aBU00<@
Q1BU5:D00a240QBU00@<Ha2448@DY@8@Q0045:D@Q12448@236<448@236<0
10Q236<<H`aS0a241PaS00<@Q0aS36<00Q2400@<Ha2448@@Q0H<H`0448@D
YA2448@25:D01QS65:DDYA245:DLi`8HaP035:D<Ha24008DY@H@Q08<H`00
0`@Q00<000@Q124010@Q00D000@Q48@U:AcW008HaP0:5:DHaQBU48@DYAS6
7>LHaQBU48@35:D00aS65:DDY@0248@35:D248@25:D248@25:D01A245:DL
iacW6<H01ABU00<@Q1BU5:D00aBU112400<DYA2448@00QBU00<HaQBU5:D0
0Q2400HDY@aS36<@Q1BU6<H55:D01A245:DHaQBU48@00QBU00<HaQBU5:D0
1ABU00<@Q1BU48@00QS600HDYA2448@DYAS65:D248@35:D348@25:D00a24
5:D@Q0035:D248@25:D248@01aBU6<HHaQ2436<DYAS6008DY@<HaP8@Q0<D
Y@H@Q0PDY@0348@DYAS6008DY@8@Q08DY@046<HDYA245:D26<H00acW5:DD
Y@0248@35:D648@25:D01Q245:D@Q1BU6<HDY@8@Q0045:D@Q12436<248@2
5:D00a245:D@Q0025:D00aS65:D@Q00248@00aS65:DHaP035:D248@021BU
48@DYA245:DHaQBU6<H55:D56<H248@45:D011245:DDYAS60a2400D<Ha24
5:DDYAS600<DY@0:6<H@Q1BU6<HLiaBU48@DYAcW6<H25:D011S65:DDYA24
0QBU00@HaQBU48@@Q08HaP8DY@0448@DYABU5:D26<H01ABU48@@Q1BU6<H0
0QBU00D@Q1BU48@@Q1BU008HaP035:D@Q124008DY@046<H@Q12448@25:D0
0`aS48@DY@045:D26<H35:D248@011S65:DHaQBU0`aS00H@Q1BU5:D@Q1BU
48@25:D348@25:D00aS65:D@Q00248@25:D548@46<H00aBU48@@Q00336<0
2Q2436<<Ha245:DHaQ2436<@Q1BU0Q2400<DYA2448@00`aS00@@Q1BU5:DD
Y@@@Q0045:D@Q12448@236<00a2436<<H`0236<248@01aBU48@@Q0aS48@<
HaBU00D@Q0035:D@Q0aS00/@Q0045:D@Q1BU5:D348@00`aS5:DDY@045:D0
1A245:DDYA2436<00Q2400DHaQ2448@<HaBU008@Q0<DY@<@Q0035:D@Q124
00P@Q0@DY@@@Q0<DY@<@Q08DY@0348@DYA2400@DY@8@Q00336<@Q1BU00D@
Q0045:D@Q1BU5:D236<00a246<HHaP035:D248@35:D348@35:D248@00`aS
5:DDY@0248@25:D348@00aBU48@@Q00648@00aBU48@<H`0336<011BU48@@
Q0aS0Q2400D<Ha2436<<H`Q200d<H`0448@<H`aS48@436<00a245:D@Q003
36<011245:D@Q1240QBU0a2400<DYAS67>L00QS600<DYA2448@00a2400<<
H`Q236<00Q240@aS000212401@0012448@@Q00000P@Q00H000@Q124@Q2DY
7>L25:D248@26<H00aBU6<HHaP025:D011245:DDYAS60QBU00D@Q1BU5:DD
YA2400<DY@8@Q0@DY@0548@DYAcW7>LDY@0248@26<H25:D00a245:DHaP02
5:D00a245:DDY@0348@55:D011245:D@Q0aS0Q2400DDYA245:DDYA2400<D
Y@0648@DYAS66<HDYA240aS600<DYA246<H00QBU0Q241QBU00D@Q1S66<HH
aQ2400@DY@0348@DYABU008@Q0035:D@Q124008DY@0548@<H`aS36<@Q006
5:D00aS65:DHaP095:D00a2436<@Q0045:D011245:D@Q1BU0Q2400@DYA24
48@DY@<HaP035:D@Q1BU00@DY@8HaP077>LDYA245:DHaQBU48@011BU1124
0QBU00<HaQ2448@01ABU0a240QBU0a2400HDYA2448@@Q1BU48@35:D248@4
5:D011245:DDYABU0Q2411BU00@@Q1S65:D@Q08DY@037>LHaQBU008DY@<@
Q0045:D@Q12448@25:D348@35:D248@020aS5:DDYABU6<HLiaS65:D248@0
11BU6<HLiaS60QBU00@@Q1S66<HHaP<@Q0@DY@036<HDYABU00HDY@0448@D
YABU48@45:D348@00aBU48@@Q0026<H00aBU48@DY@025:D248@01aBU48@@
Q1245:DLiaS600LDY@0348@DYABU008DY@8@Q00436<@Q1245:D348@25:D3
48@35:D348@25:D01a2436<@Q1246<HDYA24008DY@047>LHaQBU5:D236<5
48@25:D348@236<25:D00a2436<<H`0548@25:D248@00`aS48@DY@0248@0
0`aS48@@Q00536<011245:DDYABU0PaS00<@Q0aS36<00Q2400<DYA245:D0
0QBU00<@Q0aS36<01a2400HDYA2448@DYA245:D248@01@aS48@@Q1246<H0
0QBU1A2400@HaQBU48@<H`8@Q08DY@8@Q0<DY@8@Q0035:D@Q12400<@Q08D
Y@086<HDYA24248<Ha245:D@Q0@DY@0348@DYA24008@Q0@DY@8@Q0DDY@03
48@DYA24008@Q0045:D@Q1245:D248@00`Q236<<H`025:D00a245:DHaP05
5:D248@35:D00a245:DHaP0448@25:D01A245:DDYABU48@00PaS00<@Q1BU
48@00PaS00<@Q1BU5:D00PaS1Q2400<DY@aS36<00a241PaS00@@Q0aS48@@
Q0@<H`8@Q00436<@Q124248236<348@536<348@011BU48@DYABU0a2400@D
YAcW7>LHaPDDY@8@Q00436<@Q0aS48@12480000500048@@Q124000071240
1QBU8@PHaPaS5:DHaP8DY@0448@DYAS66<H25:D248@00aBU48@DY@025:D3
48@00aBU48@DY@0448@01ABU6<HHaQS65:D00QS60QBU00@HaQcW6<HDY@8@
Q0055:DHaQS65:D<H`0348@02@aS48@DYABU48@DYA246<HDY@0448@01aBU
6<HDYABU6<HDYA24008DY@036<HDYAS600<DY@046<HDYABU6<H35:D36<H2
5:D648@00aBU6<HDY@025:D248@010aS48@DYABU1Q240QBU0a2400<<HaS6
7>L00QS600<@Q1BU5:D00QBU0Q2411BU00<@Q1BU48@00PaS00D@Q1S65:DD
YA2400<DY@0348@DYABU00<@Q0045:D@Q1BU48@55:D36<H00acW5:DDY@04
48@01@aS5:D@Q1BU48@00QBU00<HaQBU5:D00QS60QBU0Q2421BU00D@Q0aS
48@@Q1S6008DY@0348@<HaBU008HaPDDY@0448@DYABU5:D248@65:D01A24
6<HHaQS67>L00aS60aBU00<HaQBU5:D00QBU00@HaQBU5:D@Q08DY@0548@D
YABU5:D@Q0055:D00aS65:DHaP0;5:D648@01aBU7>LHaQS65:DHaQcW008H
aP<DY@046<HDYABU48@25:D27>L25:D248@011BU48@@Q1240QBU00<@Q1BU
5:D00Q2411BU0Q240QBU00@HaQBU48@@Q0@DY@036<H@Q1BU00<@Q08DY@<@
Q0035:DHaQBU008DY@0348@DYA2400@DY@8HaP0=48@<H`aS5:DHaQBU48@D
YAS65:DHaQ245:D00Q240PaS0Q2400DDYA2448@@Q1BU00<@Q0@<H`D@Q08D
Y@8HaP8DY@H<H`04248<H`aS5:D748@00aBU48@<H`0248@011BU48@@Q1BU
11240aBU0a240QBU00@@Q1BU5:DDY@8@Q00836<@Q1BU5:DHaQBU6<HDY@<@
Q08DY@036<HDYA24008@Q0035:DHaQBU00<DY@0348@DYABU008@Q08<H`8@
Q0055:D@Q12448@DY@0248@01@aS48@@Q1BU48@00QBU00<@Q1BU5:D00QBU
0Q240QBU00@@Q1BU48@@Q0<DY@0648@DYABU5:D@Q1BU0Q2400<HaQBU5:D0
0Q2400DDYA245:DDYA24008DY@8@Q0035:DHaQS6008DY@0348@DYABU008D
Y@8@Q08DY@8@Q0035:D@Q124008@Q08DY@8@Q00536<@Q1BU5:D@Q0025:D2
48@236<00a2436<@Q00448@336<01A2436<<H`aS24800Q2400<DYA2436<0
0PaS00`@Q0aS48@@Q0aS48@<H`Q236<@Q1BU48@236<248@336<248@010aS
48@@Q0aS0Q2400LDYAcW7>LLiaS648@DY@0348@236<348@000<48@040004
8@@Q000312401`00248DYBDY5:D<Ha2400<HaP<DY@8HaP0348@DYABU00DD
Y@8@Q0<DY@8@Q0035:D@Q12400<HaP<DY@056<HDYABU5:DHaP025:D01124
5:DDYABU0QS600HDYA2448@<HaBU48@45:D011S648@DYA240QBU0a2421BU
00<HaQBU48@00QBU00@HaQBU5:D@Q0@DY@056<HDYABU48@DY@0248@25:D0
0aS65:DDY@025:D248@00aBU48@DY@035:D548@01ABU48@@Q0aS48@00aBU
0QS61ABU00<@Q1BU5:D01ABU00@@Q0Q236<@Q08HaP8@Q0035:D@Q124008@
Q0<DY@0336<@Q124008DY@0648@DYABU5:D@Q1S60R4800/Lia2448@DYA24
5:D@Q1BU48@DYA24008DY@036<HDYABU00<HaP035:D@Q124008DY@0448@D
YABU5:D248@35:D348@25:D348@011BU6<HDYABU0QS600HDYA245:DDYA24
5:D248@35:D00aS65:DDY@025:D00aS65:DHaP025:D26<H01ABU48@DYA24
6<H00aBU0Q2400@DY@aS48@@Q0<DY@8@Q0046<HLiaS65:D248@26<H35:D0
0a245:D@Q0025:D348@35:D00a245:DDY@027>L00aBU48@@Q0036<H348@0
0aS65:DHaP0248@01ABU6<HHaQBU48@00aBU0Q2400DDYA245:DDYAS6008@
Q08DY@036<HDYABU00LDY@0748@DYABU5:D@Q1BU48@00aBU0Q240QBU1124
0aBU11240QBU0Q2400<DYA245:D00QBU00<@Q1BU5:D00QS60QBU0a240PaS
0Q240QBU0Q2400<<Ha2448@00`aS0Q2400L<Ha2448@DYA245:DHaP035:D3
48@736<448@436<448@01@aS48@@Q1BU48@00`aS0Q2400@DYA245:DDY@8@
Q0@DY@8@Q00336<@Q1BU008@Q0@DY@8@Q0035:D@Q1BU00D@Q0DDY@8HaP05
48@<H`aS48@DY@0336<00aBU48@<H`0248@01QBU48@<H`aS5:D@Q08DY@03
6<H@Q1BU00H@Q0LDY@L@Q0<DY@0348@DYA2400<@Q0035:D@Q124008@Q0<D
Y@046<HDYABU48@25:D00a245:D@Q00448@35:D00a2436<@Q0035:D248@0
11BU48@@Q1BU0Q2400@DYA2436<<H`8@Q0045:D@Q12448@636<00a2436<<
H`0436<00a2436<<H`0236<011245:D@Q0aS1A2410aS00<@Q0aS48@00`aS
0a2400<<Ha245:D00Q240aS61ABU00@@Q0aS36<@Q08<H`0000<48@001240
1P@Q00L000@Q124DYBU:6<H@Q0026<H25:D26<H25:D348@55:D00a245:D@
Q00248@45:D348@26<H248@01aBU6<HDYABU6<HLiaBU00<@Q0035:D@Q1BU
008HaP8DY@8@Q0035:D@Q1BU008DY@0348@DYABU008DY@0448@DYABU5:D2
6<H25:D011245:DDYAcW11BU00<HaQBU6<H01ABU0aS600DDYA245:DDYA24
00TDY@0348@DYA2400H@Q00336<@Q0aS00<@Q08DY@<HaP<DY@036<HDYABU
008HaP067>LQ21BU48@<Ha240QBU00D@Q0aS36<<Ha2400<DY@<@Q00<5:D@
Q1245:D@Q1BU48@<Ha245:DHaQBU0Q2400<DYAS66<H00aBU00<@Q1BU5:D0
0aBU0Q240QS600<LiaBU48@011BU0a2400<DYAS66<H00Q2400@<Ha245:D@
Q0DDY@<@Q0035:DHaQBU008HaP<DY@0748@DYA2448@DYAS65:D00Q2400<D
YAS65:D00Q240aBU0aS60QBU0Q2400@DYAS66<H@Q08DY@@@Q0045:DHaQBU
48@25:D02AS65:DDYABU6<HDYAS65:DHaP045:D26<H25:D248@65:D01124
5:DHaQS60aBU00<@Q1BU48@00aBU00D@Q1BU5:DDYAS600<DY@0348@DYA24
008DY@0348@DYA24008DY@046<H@Q1245:D26<H01ABU48@@Q1246<H00QBU
00@@Q1BU48@@Q08DY@@@Q0046<HDYABU5:D348@55:D248@00`aS5:DDY@02
5:D348@00aBU48@@Q00348@56<H25:D248@00aBU48@DY@0348@236<548@0
1@aS48@DYAS65:D00Q2400@DYAS648@<H`<@Q0D<H`0448@<Ha245:D448@0
21S648@@Q0aS5:D@Q1BU48@236<01A2436<@Q0aS48@00aBU00D@Q1BU48@@
Q1BU008HaP045:D<Ha245:D348@00aBU48@@Q0025:D01AS65:DDYAS65:D0
0Q2400PDYAS65:DDYA245:DHaQBU112400@DYA2448@DY@H@Q08<H`0648@D
YA2436<@Q1S60aBU00<@Q1BU6<H00QBU00<@Q1BU48@00aBU0Q240aBU00T@
Q1BU5:D@Q0aS48@DYA245:D021240QBU0QS60Q240QBU00<HaQ245:D01a24
00<<Ha2448@00Q2400D<Ha245:D@Q0aS008@Q0046<H@Q1245:D248@010aS
48@@Q0aS1A2410aS00<@Q0aS36<010aS00<@Q0aS36<00`aS00@DYA2448@@
Q0<<H`0648@<Ha2448@<H`Q20PaS00<DYA2436<00`aS0Q2400@DYA2448@<
H`8@Q0065:DLiacW7>LQ21BU0Q2400@<Ha2448@@Q04<H`0000<000@Q0000
0P@Q00<000@Q124010@Q00DHaRDY6<H<HaBU00<HaP8DY@046<HDYABU5:D2
48@25:D00a245:D@Q00348@25:D01A245:D@Q1BU48@01ABU00L@Q1BU6<HL
iaS65:D@Q0055:D36<H00aBU36<@Q0045:D00a245:DDY@035:D011245:D@
Q1BU11S60a2400@DYAS66<HDY@8@Q0045:DLiaS65:D248@00aBU6<HHaP05
5:D01Q245:D@Q1BU6<HDY@8@Q0<DY@8@Q0035:D@Q1BU008DY@0448@<H`aS
36<248@45:D26<H011BU6<HDYAS60aBU0QS60R4800@HaQBU48@DY@8@Q08<
H`035:D@Q124008@Q08DY@0348@DYA24008@Q08DY@<@Q0035:DHaQBU008D
Y@0548@HaQS65:D@Q0025:D348@00aS65:DDY@0248@00aBU6<HHaP025:D0
1AS65:DDYABU48@00QBU0QS600HDYA2448@@Q1BU48@25:D0412436<DYABU
48@DYA245:DHaQcW6<HLiaBU6<HDYA241ABU0Q240aBU00DHaQBU5:D@Q1BU
00DHaP055:DHaQBU6<H@Q0025:D248@25:D0212436<<HaBU6<HDYA245:D2
6<H00aBU6<HHaP0:5:D248@35:D00a245:D@Q0025:D011S65:D@Q1240QS6
0QBU00H@Q1BU5:DHaQ245:D248@25:D00aS65:D@Q00348@25:D01AS65:DD
YABU6<H00Q2400DDYA245:DHaQBU008@Q08DY@0348@DYA2400<@Q08DY@8@
Q00336<@Q1BU008DY@8@Q08DY@046<HDYABU6<H248@01@aS5:DDYA2436<0
0Q2400@DYA2448@@Q0<DY@8@Q0045:DLiacW6<H25:D236<011245:DDYABU
2A2400<<Ha245:D00aBU00D@Q1BU5:DDYA2400<<H`0348@<H`Q2008<H`<@
Q00336<@Q12400D@Q0055:D@Q12436<@Q0025:D01a2436<<Ha2436<@Q1BU
008HaP035:D@Q12400D@Q0045:D@Q12436<348@01ABU6<HHaQBU48@011BU
00@@Q1BU5:DDY@8@Q0045:DHaQS65:D348@35:D248@236<348@010aS48@D
YABU11240QBU00D@Q1BU48@@Q1S600/DY@0548@DYA2448@DY@0348@25:D0
0a2436<@Q00448@25:D01QS65:D@Q1245:DHaP8DY@8HaP035:D@Q0aS00D@
Q0035:D@Q12400<@Q0085:D@Q12448@DYA245:D@Q08DY@8@Q0035:D@Q124
008<H`@@Q00336<8@PaS00H<H`0548@<Ha2436<@Q00236<248@01ABU48@<
H`aS48@01`aS00@@Q0aS36<<H`8@Q0<<H`D@Q0095:D@Q1cW8@PLiaS648@D
YA2400@<H`48@P0010@Q00D000@Q12448@0000<48@065:DYBQcW5:DHaQBU
0aS600<DYAS67>L00QBU00<@Q1S66<H00QBU00D@Q1BU6<HHaQBU008@Q0PD
Y@036<H@Q1BU00<DY@046<HLiaS65:D248@00aBU48@DY@045:D011245:DD
YAS60QBU0Q2400<DYAS65:D00Q2400HDYAcW6<HDYA245:D248@00aBU48@@
Q0035:D01A245:DDYAS65:D00Q240QBU0QS600<@Q1BU5:D00QBU00@@Q1BU
5:DHaP8DY@0336<@Q1BU008DY@0348@<HaBU008DY@D@Q08<H`0348@DYABU
008DY@036<HLiacW00<DY@0548@HaQS66<HLi`036<H25:D00a2436<<H`04
48@00`aS48@DY@035:D01a245:DDYA245:D@Q1BU00<@Q0035:D@Q1BU008H
aP035:DHaQBU008HaP0348@<Ha24008DY@<@Q0<HaP035:D@Q1BU008DY@<@
Q0035:DHaQBU008@Q0045:DHaQS65:D248@25:D448@36<H35:D00aS65:DD
Y@0348@55:D248@35:D00a245:DHaP026<H01A246<HLiacW5:D00Q2400<D
YA245:D00aS60a2400HDYAS65:DDYA246<H45:D26<H25:D01Q245:DHaQBU
48@DY@8HaP<DY@036<HDYA2400<DY@8@Q08DY@8@Q0@DY@036<HDYABU008@
Q0045:D@Q1BU5:D248@35:D248@25:D00aS65:D@Q0025:D011245:DDYABU
11240QBU00P@Q1BU5:DDYA2436<@Q0aS0Q2400<DYA245:D00Q2400LDYA24
5:DDYAS648@DY@0448@25:D348@25:D248@236<011245:DDYA240QBU00@H
aQcW6<HDY@8<H`045:DHaQ2436<248@45:D436<00aBU6<HDY@0236<25:D0
0a24248<H`0348@00`aS48@@Q00248@336<248@021BU48@@Q0aS48@<Ha24
5:D348@236<248@25:D348@35:D648@021BU48@@Q1BU48@DYAS65:D448@2
6<H25:D01A2436<DYABU6<H01QBU00<@Q1BU5:D00a2400<DYA2448@01124
0aBU0a2400@HaQBU48@DY@8@Q0035:D@Q1BU008DY@8HaP<DY@0648@DYA24
5:D@Q1BU0Q240QBU00@@Q1BU48@DY@8@Q00336<@Q124008@Q08DY@8@Q0@D
Y@0348@DYABU008DY@T@Q08<H`@@Q0<DY@0536<@Q1BU5:D@Q00236<448@0
0`aS48@<H`0736<348@536<448@00`aS48@@Q00436<248@336<348@00`aS
48@@Q00336<248@35:D01a2436<DYAcW9BTQ21S6008DY@@@Q048@P000P@Q
00D000@Q12448@0000D48@036<HYBR4800@DY@DHaP035:D@Q1BU008DY@8@
Q0@DY@0348@DYABU00LDY@036<HDYABU00<@Q0036<HLiaS600DDY@8@Q08H
aP8DY@0448@DYAS66<H35:D26<H01AcW5:D@Q1245:D00QS600DDYAS65:DD
YAS6008@Q0035:DHaQBU008@Q0045:DHaQS648@35:D26<H35:D00a245:D@
Q0025:D648@35:D348@45:D348@01PaS48@<Ha245:D@Q08DY@@HaP8DY@03
48@HaQS6008HaP<DY@8@Q0035:D@Q12400@@Q08<H`045:DHaQ2448@35:D4
48@25:D00a245:D@Q0025:D00aS65:DHaP045:D648@011BU7>LDYABU0Q24
00XDYAS66<HDYA245:DHaQBU48@<H`@@Q0DDY@8@Q0DDY@076<HLiaBU5:D@
Q1BU6<H01ABU00<@Q1BU5:D00QBU00D@Q0aS5:DDYAS6008DY@076<HLiacW
6<H@Q1BU48@00aBU00@@Q1BU5:D@Q0<DY@066<HDYAS66<HDYAS60QBU0QS6
00<DYA245:D00aBU00@@Q1BU5:DDY@<@Q0036<HLiaS6008DY@0448@DYAS6
6<H25:D348@01aBU6<HDYAS648@DYA24008DY@0448@DYABU5:D248@011BU
6<HDYA241ABU00@@Q1BU5:DDY@8@Q08DY@8@Q08HaP055:D@Q0aS48@DY@02
48@00`aS48@<H`025:D021S65:D@Q0aS48@HaQBU6<H348@35:D348@00aBU
48@@Q00248@35:D248@01QBU48@DYABU6<HLi`8DY@0336<@Q1BU008DY@8@
Q0035:D@Q0aS008<H`085:D<H`aS48@DYA2436<@Q08DY@D@Q0<<H`0348@D
YA2400<<H`/@Q0055:D@Q0aS48@<H`0348@45:D011S648@@Q1240QBU00@@
Q0aS36<DY@8@Q0045:DHaQBU48@55:D26<H348@35:D00aS65:DDY@035:D4
48@01aBU6<HDY@aS48@<Ha24008DY@8@Q0035:D@Q12400@DY@8@Q0<DY@04
48@DYABU6<H25:D248@25:D448@35:D348@00aBU48@@Q00448@00aBU48@@
Q0025:D011245:D@Q1S61QBU0a2400@DYA2448@<H`L@Q00336<@Q1BU00<@
Q0<DY@@@Q0035:D@Q1BU008<H`0448@<H`aS48@236<02A2436<@Q0aS48@<
Ha2436<8@P0236<00aBU48@<H`0236<248@336<01Q2436<8@PQ248@DY@D@
Q0<<H`0448@DYABU48@236<021S67>LU:B485:DHaQ2436<348@136<00004
00048@@Q000612402000248DYBe[7>L@Q1S65:D26<H011BU6<H@Q1240QBU
00@HaQBU48@HaP<DY@036<HDYABU008@Q0HDY@056<HDYABU48@DY@036<H0
11BU6<HHaQBU0Q2400D<Ha245:DDYAS6008DY@8HaP0348@DYA2400HDY@04
48@DYAS66<H25:D011245:DDYA240QS60aBU00<HaQBU48@00Q2400<HaQBU
5:D01ABU0a240QBU00@HaQBU48@@Q0PDY@8@Q0055:DHaQ2448@<H`0348@0
1ABU48@DYABU6<H00QcW00<Q21cW6<H00QBU00<HaQ245:D011BU0QS60aBU
0Q240QBU112411BU00<@Q1BU48@00Q2400<DYA2448@00a240aBU00DHaQBU
6<H@Q1BU00@@Q0036<HDYA24008DY@056<HDYA2448@DY@026<H348@26<H0
1aBU48@@Q1BU48@DYAS6008DY@0648@<Ha245:D@Q1BU0a240QBU00@LiaS6
5:DHaP<DY@0348@DYABU008DY@0348@DYABU008DY@0348@DYA2400<DY@03
6<HDYABU008@Q0035:D@Q1BU00<@Q0<DY@0348@DYABU00DDY@087>LHaQBU
5:DHaQ245:D@Q08DY@036<HDYABU008DY@8@Q08DY@036<HDYABU008DY@<@
Q0035:DHaQBU00@DY@0348@DYABU008@Q0075:DHaQ2448@<Ha245:D00a24
0QBU00DHaQBU5:D@Q1BU008@Q0DDY@0348@DYA24008DY@8@Q0035:D@Q124
00<@Q08HaP045:D@Q12448@25:D26<H00aBU6<H@Q00248@25:D00a2436<@
Q0025:D248@25:D00a2436<@Q00248@011BU48@DYA2411BU00<<Ha2448@0
0Q2400<<Ha245:D0112400@DYA2448@<H`8@Q08DY@8@Q08<H`0548@<Ha24
48@<H`0548@01ABU36<<H`aS48@00QBU00@@Q1BU5:DDY@8<H`0348@DYA24
008@Q0065:D@Q1245:D@Q1BU0a2400DDYA2448@@Q0aS00@@Q0<DY@0448@<
Ha2448@65:D248@011BU6<HDYABU112400<DYA2448@00QBU0Q240aBU0a24
0QBU112400PDYA245:DDYAS648@DYA240aBU00@@Q1BU48@@Q0@DY@<@Q08D
Y@036<HDYA24008@Q0035:D@Q12400H@Q0045:D@Q1BU48@26<H35:D00aS6
5:DDY@025:D848@236<248@25:D648@011BU48@@Q0aS0a2400<<Ha2448@0
0Q240PaS00D@Q0aS36<@Q0aS008@Q00436<8@PQ236<248@436<00a245:DD
Y@0336<348@236<348@236<01Q2436<<Ha2436<@Q08DY@0=48@DYA245:DL
ib487>LHaQBU36<@Q0aS5:D00A2400000`@Q00048@021240100012448@00
0P@Q00@8@QS6;F/U:@<DY@0448@DYAS66<H25:D011246<HHaQ240QBU00<H
aQBU5:D00QBU0Q240aBU00<HaQBU5:D00QBU0Q2400<DYA2448@00QBU0QS6
0QBU00<@Q1BU48@00Q240QBU00<HaQBU5:D01QBU00@@Q1BU6<HHaQ0DY@8H
aP0348@DYABU00<@Q0HDY@8@Q08DY@<@Q0<DY@0348@DYABU00DDY@8@Q0<<
H`8@Q0045:D@Q1BU5:D26<H28@P01QcW6<HDYAS67>LDY@8@Q08HaP055:D@
Q1S66<HDY@0236<448@011BU48@@Q12411BU00H@Q1BU48@DYA245:D448@2
5:D01AS65:DDYABU6<H00QBU00<@Q1BU48@00a240QS60QBU0Q240QBU0QS6
0aBU0Q2400@DYA2448@@Q0<DY@@@Q0055:DHaQBU5:D@Q0035:D46<H00aBU
48@@Q0035:D248@00aBU6<HDY@0248@011S648@DYA241ABU00DHaQBU48@D
YA2400<DY@0548@DYA245:D@Q0035:D01AS65:DHaQBU6<H00aBU00<HaQBU
5:D00QBU00<@Q1BU6<H00QBU0Q240QBU00@HaQBU5:D@Q08DY@@@Q0065:DH
aQBU5:D@Q1BU0Q240aBU2a240aS600@DYA245:DDY@@@Q08DY@0648@DYABU
48@DYA240PaS0QBU00<@Q1BU6<H00QBU112400/DYAS65:DHaQBU48@DYA24
5:D@Q0aS00<@Q0045:D@Q1BU5:D448@01aBU48@@Q1BU48@DYA24008DY@D@
Q00536<@Q1BU6<HDY@0236<348@00aBU48@@Q00348@236<448@436<848@0
0aBU6<HDY@0:48@45:D01A245:D@Q1245:D00Q2400<DYA2436<00PaS00D@
Q0aS48@DYAS6008DY@0648@<HaBU5:DHaQBU112400@DYAS66<HHaP8DY@03
48@DYABU008DY@<@Q0DDY@046<H@Q12448@35:D00a245:D@Q0025:D00aS6
5:DHaP0248@00aBU48@@Q0025:D26<H011245:DDYABU0a241QBU112400DD
YA245:D@Q1BU008@Q0035:D@Q1BU008DY@8@Q0<DY@<@Q0@DY@<@Q00636<@
Q1245:D@Q1BU0a2400@<HaBU5:DDY@8@Q0035:D@Q12400<@Q0035:D@Q0aS
00H<H`0548@<H`aS36<8@P0336<0112436<@Q0aS11240PaS0Q2400@DYA24
48@@Q0L<H`H@Q0@DY@0548@HaQcW8@PLi`0236<348@136<000848@030004
8@@Q00D48@0800048ABU:DXHaQ246<HLi`DHaP055:DHaQBU48@<H`025:D0
11S648@@Q1BU0QS600<DYA245:D00aS600DDYA245:DDYA24008DY@036<HD
YAS6008DY@8HaP045:D@Q12448@25:D348@011BU48@DYABU0QS600DDYA24
36<@Q1BU008HaP035:D@Q1BU008DY@8@Q0LDY@8@Q0<DY@0448@DYA2448@3
6<H25:D01`aS48@DYAS65:D@Q0aS008DY@0348@DYABU008DY@8@Q08DY@09
48@DYABU36<@Q0aS48@DYAS6008DY@@HaP@DY@056<HLiaS65:DHaP0248@2
5:D26<H01ABU48@DYA245:D00PaS0QBU00<HaQBU5:D00QBU0a2400<DYA24
48@00aBU0a2400@DYAS66<HHaPHDY@0448@DYAS66<H45:D348@25:D00a24
5:DDY@025:D248@011BU48@DYAS60QBU00D@Q0aS48@<Ha2400DDY@<HaPLD
Y@0448@DYABU5:D248@45:D248@35:D26<H55:D01@aS48@@Q1S65:D00aS6
11BU0QS600<DYA245:D011241ABU0Q240QBU00@@Q1BU5:DHaPDDY@8@Q0LD
Y@<@Q08DY@0548@DYA2448@<H`0248@00`aS48@@Q0045:D011S648@@Q1BU
0QS60QBU00<@Q1S65:D011BU00H@Q1BU5:D@Q0aS48@25:D00aS65:D@Q002
48@00aBU48@@Q0055:D248@00`aS48@DY@0348@25:D00aS648@@Q00548@2
36<248@55:D00a245:D@Q00248@00`aS48@DY@025:D236<348@25:D248@0
1`aS48@@Q1245:D@Q1BU00<@Q00436<@Q1245:D348@00aBU48@@Q00348@0
11BU36<@Q1240aBU1Q2400D<Ha245:D@Q1BU00<@Q0035:D@Q124008@Q005
5:D@Q12448@DY@0348@45:D448@00`aS48@@Q00548@25:D011S65:D@Q124
11BU00H@Q1BU48@DYAcW5:D348@00aS65:DDY@025:D00a246<H@Q00248@2
5:D02AS65:DDYABU48@DYA245:D@Q0045:D248@25:D0112436<<Ha240aBU
00<@Q1BU48@00aBU00<HaQBU48@00Q2400@DYA245:D@Q0DDY@8@Q00336<@
Q12400T@Q0075:D@Q12436<@Q1BU48@00PaS00<@Q0aS48@00Q240`aS0Q24
00<<Ha2448@01a2410aS1A240PaS1A2400<DYA2448@00PaS0Q241@aS0Q24
1ABU0QcW00@DY@aS36<@Q04<H`0000L000@Q12448@001240000212401P00
12448ABU9BTLi`@HaP047>LHaQS66<H95:D00a245:DHaP055:D021246<HD
YABU36<@Q1BU6<H25:D01aS65:DDYA245:DHaQBU008@Q08DY@8@Q08DY@03
48@DYA24008DY@036<H@Q124008DY@8HaP8DY@<HaP8DY@8@Q0046<HDYAS6
5:D248@35:D348@65:D011S648@@Q1BU0aS60Q2400HDYA245:DDYAS65:D2
48@25:D348@35:D01@aS48@DYABU6<H00aBU00HLiaS66<H@Q1BU6<H27>L3
5:D01QS65:DDYAS67>LHaP8DY@D@Q0035:DLiaS6008DY@8HaP0448@<Ha24
6<H348@25:D010aS48@DYAS60QBU00<HaQcW6<H011BU00@@Q1BU5:DDY@8H
aPHDY@0448@DYABU6<H25:D010aS48@@Q1BU0QS60QBU0a2400<DYA245:D0
0QBU00<@Q1S65:D01AS600@DYAS648@@Q0<DY@0348@DYABU00<DY@036<HD
YA24008DY@066<HDYA245:DHaQBU0Q2400PHaQBU5:D@Q1BU6<HLiaS60aBU
00<@Q1S65:D00QS600@DYA245:D@Q0<DY@0548@DYABU5:DHaP0=5:D248@2
5:D00aS65:DDY@0248@25:D01A245:DDYABU36<00Q2400<DYA2436<00PaS
0QBU00@HaQBU5:D@Q08DY@036<HDYABU00DDY@8@Q0<DY@<@Q0035:DHaQBU
008@Q0035:D@Q124008@Q0<DY@8@Q08DY@<@Q08DY@8@Q0045:D@Q1BU5:D3
48@25:D248@011BU48@@Q1S61ABU0a2400<DYA245:D00QBU11240PaS0QBU
00<@Q0aS48@00a240QBU0Q2400<<Ha245:D00PaS0aBU0Q2400@DYA2448@@
Q08DY@<@Q0045:D@Q12436<248@00aBU36<@Q00248@01QBU48@@Q1245:D@
Q08<H`H@Q0<DY@0348@DYA24008@Q08DY@H@Q0@DY@0348@DYABU00HDY@04
48@DYA2448@25:D00aS65:DDY@035:D348@35:D348@45:D00a245:DDY@02
48@25:D011S65:D@Q1240aBU0a241aBU00D@Q1BU5:DDYA2400HDY@0348@D
YA2400@DY@8@Q00336<@Q0aS008@Q0045:D@Q0aS36<35:D00a2436<<H`03
48@00`aS48@@Q00336<648@336<348@736<648@236<348@01`aS48@@Q1BU
36<@Q0aS008@Q0<<H`8@Q0LDY@037>LHaQBU008@Q08<H`0000<48@001240
2@@Q00HHaRU:6<H@Q1S67>L26<H01AcW6<HDYABU48@011BU00@HaQBU48@@
Q08HaP@DY@0448@HaQBU6<H45:D26<H35:D248@00aBU6<HDY@0348@25:D5
48@26<H25:D348@01`aS5:DDYAS65:D@Q1BU008HaPDDY@8@Q0<DY@8@Q08D
Y@0748@8@PaS48@LiaS65:D00Q2411BU00<@Q1BU48@011BU112400HHaQBU
5:DDYA245:D248@00aBU48@DY@035:D00aS65:DDY@035:D01A245:D@Q124
5:D00aS600<DYAS66<H01AS60QBU00P@Q1BU48@@Q1BU6<HDYAS61ABU00<@
Q1BU48@00QBU0aS600<@Q1BU5:D00QBU0QS60QBU00@@Q1BU5:D@Q08DY@03
6<HLiaS600@DY@8@Q0035:D@Q1BU00<@Q0035:D@Q1BU00<DY@@@Q0@DY@03
48@DYAS6008HaP8@Q0@DY@8@Q0035:DHaQBU008@Q08DY@<HaP055:D@Q1BU
6<HLi`025:D01QS65:DDYABU48@DY@8HaP8DY@0448@DYAS66<H65:D00a24
5:D@Q00248@01@aS48@DYABU6<H011BU00<@Q1BU5:D00QBU0a2400<HaQBU
5:D00QBU00<@Q1BU48@00QBU0QS600<DYA245:D00a2400<DY@aS36<00Q24
00DDYA245:DDYAS6008DY@0336<@Q12400TDY@066<HDYABU5:D@Q1BU0a24
00@DYA2448@@Q08DY@036<HDYA2400<DY@0348@<HaBU008@Q08<H`8@Q0<D
Y@<@Q0@DY@8@Q00436<@Q12448@35:D248@35:D00a245:DDY@0348@01AS6
5:D@Q1245:D00Q2400<<Ha2448@00QBU00D@Q0aS48@DYA24008<H`0348@<
H`aS008<H`035:D@Q12400@@Q08DY@0348@<Ha24008DY@0348@8@PaS00H@
Q0035:D@Q12400<@Q00336<@Q12400D@Q08<H`H@Q08DY@0348@DYA2400D@
Q0<DY@8HaP045:DHaQBU5:D248@35:D01A245:D@Q1BU48@01QBU00<@Q1BU
48@00a242QBU00@HaQBU48@@Q0<DY@0648@DYA245:D@Q1BU0Q240QBU1Q24
11BU1Q241QBU2a240QBU0Q2400D<Ha2448@@Q1BU008@Q0<<H`0448@<H`aS
36<648@236<348@336<348@00aBU48@<H`0236<248@010aS48@@Q1240`aS
00@@Q1BU48@@Q08<H`0348@<H`aS008<H`8DY@0848@<Ha2448@HaQcW5:D@
Q08<H`000P@Q00<000@Q00001@@Q00L000Q26<H]JacW48@DY@066<H25:D0
1A246<HDYAS648@00QBU00<HaQBU5:D00QS600@DYA245:DDY@8HaP075:D@
Q1BU6<HLiaS65:D00QS600D@Q1BU48@@Q1BU008@Q0<DY@8@Q0055:D@Q1BU
48@HaP025:D448@00aBU6<HHaP025:D00a246<HDY@025:D00aS65:DDY@02
48@35:D248@00aBU48@@Q00248@00aBU6<HDY@025:D248@00aBU6<HHaP02
48@25:D00aS65:D@Q00248@35:D348@25:D00aS648@@Q00248@011BU6<HD
YABU0aS60Q2400<DY@aS5:D011BU0aS600<DYAS66<H00QS60QBU00<@Q1BU
5:D00QBU00<HaQBU6<H00QBU00@@Q1BU5:DDY@<@Q0035:DHaQS600HDY@<H
aP075:D@Q1BU5:DHaQBU48@00aBU0QS61aBU00<@Q1BU48@00Q2400<HaQBU
5:D00Q2400DDYAS65:D@Q1BU008@Q08DY@8HaP065:D@Q1BU6<HLiaBU0Q24
00THaQBU48@@Q1S65:D@Q0aS5:D00aS600@DYA245:DDY@8Li`036<HDYABU
008DY@0448@DYABU6<H45:D36<H01ABU48@@Q1BU48@00aBU00P@Q0aS36<@
Q1BU6<HDYA241QBU00@HaQBU5:D@Q08DY@8HaP8@Q08DY@8@Q0065:DHaQS6
6<HDYA240aBU00@@Q0aS48@@Q0@DY@0448@DYABU48@35:D00a245:DDY@02
5:D26<H55:D011245:DDYA240QBU0Q2400@<Ha245:DHaP8DY@036<HDYABU
00<@Q00336<@Q12400@@Q0@DY@0536<@Q1246<HDY@0348@01PaS48@<Ha24
5:DHaP8DY@0848@DYABU48@DYA245:D@Q0DDY@0348@DYA24008@Q0<<H`8@
Q0035:D@Q12400@@Q08<H`8@Q00336<@Q12400@@Q0<DY@0536<@Q1BU5:D@
Q00236<00a2436<@Q00448@25:D348@25:D236<01A245:DDYA2436<01A24
00<DYA2448@00QBU00<@Q0aS48@00QBU0a2400DHaQBU5:DDYAS6008DY@8@
Q0<DY@0448@DYA246<H25:D248@25:D248@35:D348@35:D01A245:DDYABU
48@00QBU00<HaQBU48@01Q240aBU00@@Q1BU5:DHaP<DY@0348@DYABU008D
Y@T@Q0045:D@Q1BU5:D448@00aBU48@DY@025:D01A2436<@Q1245:D00a24
00<DYA2448@01A240`aS0a240`aS0a240`aS0a2410aS00<@Q0aS48@01124
00@<Ha2436<<H`8@Q08<H`8@Q0065:D@Q0aS36<@Q0aS11240`aS0QBU0QcW
00<HaQBU48@00@aS00000`0012448@0312400`0012448@03124011S6;F/Q
21240QcW0aS60acW00<HaQBU5:D00aS611BU0QS600<LiaS66<H00QBU0aS6
00<DYA2448@00aS61ABU0Q2400<<Ha2448@011BU0Q240QBU00@@Q1BU5:DD
Y@<@Q0046<HDYABU5:D36<H25:D348@00aBU6<HHaP025:D00a245:DDY@02
5:D011245:DDYA2411BU00@@Q1BU5:DHaP@DY@<HaP<DY@036<HDYA24008@
Q0<DY@0448@DYA245:D348@00aBU6<HHaP035:D02PaS48@DYA245:D@Q1BU
6<HDYAS60Q2400`HaQcW7>LHaQBU48@HaQBU6<HDYA245:D26<H00aBU48@@
Q0035:D26<H00a2436<@Q0036<H25:D01aS65:D@Q1245:DHaQBU008@Q08D
Y@066<HDYABU5:DHaQBU0aS61ABU00H@Q1BU48@HaQBU6<H25:D00a245:D@
Q0045:D011245:DHaQBU0Q2400<DYAS65:D00Q2411BU0Q2400<DYAS66<H0
0QBU0QS60aBU11S60QBU00<@Q1BU5:D00a2411BU00<HaQ2448@00Q2411BU
00DHaQBU48@@Q0aS00D@Q08DY@<@Q0<DY@0448@DYA2448@45:D00a245:DD
Y@0248@011BU6<HHaQBU0a240QBU0a2400<DYA245:D00aBU0Q2400HDYA24
48@@Q1BU6<H25:D46<H00aBU6<HDY@055:D021245:DDYA245:D@Q1S648@2
5:D26<H011BU48@@Q1BU0a2400LDYA2448@@Q1BU6<HDY@0248@45:D236<3
5:D00aS65:DDY@0248@45:D011S65:DDY@aS0a240aBU00<HaQBU48@00a24
00@DYA2448@DY@<@Q00336<@Q124008@Q08<H`<@Q00336<@Q124008@Q006
36<@Q0aS48@DYA240QBU0Q240PaS1A240QBU00H@Q0aS36<@Q1S65:D448@0
0`aS48@@Q00348@01aBU36<@Q0aS48@HaQBU008@Q08DY@046<HDYA2448@2
5:D248@00aS67>LHaP045:D248@35:D011245:DDYA241ABU00@@Q1BU36<@
Q0DDY@<HaPD@Q0TDY@8@Q0<HaP045:D@Q1BU6<H25:D648@00`aS48@@Q006
5:D236<248@45:D336<00a245:DDY@0348@011BU48@@Q1241PaS0Q240QBU
0PaS21240`aS0a2400@DYA2448@@Q08<H`0748@<Ha2448@<Ha2436<00Q24
10aS0Q2410aS0Q2400D<Ha2448@<Ha2400<Li`4DY@4<H`0010@Q00<000@Q
12401@@Q00@HaRe[8@PDY@8HaP035:DHaQcW00<Li`036<HDYABU00@DY@03
6<HDYAS600<HaP045:DHaQS65:D26<H45:D36<H65:D348@00`aS48@@Q002
5:D248@011BU6<HLiacW0Q240aBU0Q240aBU00DHaQBU5:DHaQ24008DY@04
48@DYAS65:D248@00aBU7>LDY@0248@45:D00aS65:DDY@035:D348@01ABU
6<HLiaS648@00QBU00@HaQBU5:DHaP@@Q08DY@D@Q0<HaP055:D@Q12448@D
Y@0248@011BU48@DYA241QBU00DHaQcW6<HDYAS600@DY@0348@DYABU008H
aP@@Q00:5:DHaQS65:D@Q1BU6<HLiaBU48@25:D248@00aBU6<HDY@025:D0
0a245:D@Q0036<H35:D00acW6<HHaP045:D00aS65:DDY@025:D26<H00aBU
48@DY@025:D248@00aBU48@@Q00248@011BU48@DYABU0Q2400<DYAS65:D0
0aBU00<HaQBU5:D00QBU0QS600<DYAS66<H00aBU0aS60QBU00d@Q1BU5:D@
Q0aS48@HaQBU48@DYA245:DHaP025:D01A245:DDYAS65:D01Q2400DDYA24
5:DDYA24008DY@0348@DYABU00DDY@@@Q08DY@0448@DYABU48@55:D548@2
36<248@00aS67>LHaP0248@25:D248@35:D00aS67>LHaP025:D46<H35:D0
11245:DDYABU0a240QBU00P@Q1BU5:DDYAS648@DYA240QBU0a240aBU00@@
Q1BU5:D@Q08DY@086<HDYA2448@<Ha245:DHaP<DY@@@Q08DY@036<HDYA24
008<H`0448@DYAS66<H35:D448@00aBU48@@Q00648@436<448@00`aS48@@
Q00448@00aBU48@@Q00248@01ABU36<<H`aS48@00QBU0a240QBU112400<D
YA2448@01Q2400@<Ha2448@DY@@@Q08DY@<@Q0<DY@0348@DYA24008DY@<H
aP045:D@Q12448@35:D00a246<H@Q00248@25:D348@25:D548@00aBU6<HD
Y@026<H011BU6<HDYABU11240aBU00@@Q1BU5:DHaP<DY@056<HDYABU48@H
aP045:D01A2436<<Ha245:D0112411BU00D@Q1BU5:D@Q1BU00<@Q08DY@8@
Q00436<@Q1245:D548@236<00a2436<@Q00436<248@00`aS48@@Q00336<3
48@010aS48@@Q0aS0Q2400DDYA2436<@Q1BU00<<H`8@Q00336<@Q124008@
Q00536<@Q12436<@Q00236<348@536<0112436<HaQS60QcW0ABU0A240000
0`00124000021240300012448@@Q00048@Q26<HaS2DY5:DLi`@HaP@Li`<H
aP<Li`8HaP035:DHaQcW008Q20046<H@Q1BU48@:5:D011S65:DDYABU0`aS
00@@Q1BU6<HHaPLDY@8HaP035:D@Q12400<DY@8HaPDDY@0348@DYABU00@D
Y@0548@DYA245:D@Q0045:D00aS67>LDY@0248@35:D00a245:DHaP025:D0
1AS67>LHaQS65:D00a240aS60a2400<DYA2436<00Q2400@HaQcW6<HDY@8@
Q08DY@8HaP<@Q0035:D@Q1BU008DY@0448@DYABU6<H25:D011246<HHaQS6
0QBU00D@Q1BU5:D@Q1BU008HaP8DY@0348@DYA24008@Q0036<HLiaS600@D
Y@<@Q0<DY@036<HDYABU008@Q0035:DHaQS600<DY@8HaP035:DHaQS600<D
Y@8HaP037>LDYABU008DY@046<HDYABU48@45:D011245:DDYABU0QS600<D
YA2448@00QS600<DYAS65:D011S611BU00HHaQBU6<HDYA246<H27>L25:D0
0a245:D@Q00348@35:D00aS65:D@Q0026<H25:D01a245:DDYAS65:D@Q1BU
008@Q0<DY@8@Q0035:DHaQBU00@DY@0648@DYABU48@<Ha240aBU0Q241QBU
00<HaQBU48@00Q240aBU00@@Q1BU5:DDY@<@Q0<DY@8@Q08DY@8HaP047>LH
aQBU5:D26<H00aBU6<HDY@026<H25:D011245:DDYAS60QBU00<HaQBU5:D0
112400HDYA245:DDYA2436<248@25:D248@25:D248@25:D348@011BU6<HH
aQS61A2411BU0a2400T<Ha2448@<HaS67>LHaQBU48@00aBU00L@Q0aS36<@
Q1BU48@8@P0436<248@00aBU48@@Q00448@236<248@00aBU48@@Q00248@0
0aBU48@@Q00336<011245:D@Q12410aS00H@Q1BU5:D@Q0aS48@35:D248@2
36<248@011BU48@@Q1240QBU0Q2400HDYAS648@@Q1BU6<H25:D00a245:D@
Q0025:D00aS65:D@Q0025:D011S65:DDYABU0Q240QBU00DHaQBU5:DDYA24
008<H`0448@DYAS648@25:D26<H011245:D@Q12411BU0Q240QBU00<@Q1BU
5:D00aS600<DYA245:D00aBU00D@Q1BU5:D@Q0aS00H@Q0035:D@Q124008D
Y@<@Q00336<@Q1BU008DY@0348@<Ha24008DY@8@Q00436<DYA245:D348@0
10aS48@@Q12420aS0QBU00D@Q0aS36<@Q1BU008@Q08<H`0348@<Ha24008@
Q08<H`0648@<H`aS48@DYA240PaS0Q2410aS00@@Q0aS48@<H`8@Q0@<H`@@
Q0035:DLiacW004@Q0001P@Q00<000@Q12400`@Q00PHaS6<9BTDYAS67>LH
aQcW0QS611cW00@HaQBU6<HHaP8Li`036<HDYABU00<Q20035:D@Q124008D
Y@056<HDYABU48@DY@036<H248@00aS65:D@Q00436<26<H25:D248@35:D0
0aS65:DHaP025:D248@011BU6<HHaQBU11S600/@Q1BU5:DDYAS65:D@Q0aS
48@DYAS6008DY@0648@DYABU6<HDYAS60PaS00H@Q1BU6<HHaQBU36<248@0
1AS67>LHaQS65:D00Q2400DDYA245:DDYA24008DY@0548@DY@aS48@DY@03
6<H248@35:D00acW6<HDY@0248@25:D00a245:DDY@095:D01AS67>LHaQBU
48@00aBU0QS60QBU00H@Q1BU5:DDYA245:D26<H25:D26<H25:D00a245:D@
Q0035:D26<H00aBU48@@Q0026<H00aBU48@DY@027>L00aS65:DHaP045:D0
0acW6<HHaP025:D00a245:D@Q0055:D248@02ABU48@DYABU6<HDYA245:DH
aP045:D26<H35:D011245:DDYABU0QS60aBU0aS600@@Q1BU48@<H`8@Q0DD
Y@0448@DYA2448@25:D00aS65:DDY@0348@01QBU48@@Q1245:D@Q0HDY@04
48@DYABU5:D448@25:D02Q245:D@Q1BU48@DYAS65:DHaQBU0a2400@DYA24
48@@Q08DY@036<HDYABU008@Q0045:D@Q1BU48@35:D01A245:DHaQS65:D0
0aS600<DYAS65:D00QBU00THaQBU5:D@Q1BU7>LHaQBU6<H00QBU0a2400<D
YA2448@00aBU0a240aBU00@@Q1BU5:DDY@8@Q0@DY@8@Q0046<HLiaS65:D2
48@236<00a245:DDY@025:D00a245:D@Q00248@35:D26<H00aBU48@@Q003
48@00aBU48@<H`0248@236<00a2436<<H`0648@01@aS48@@Q1245:D00Q24
0QBU0a2410aS00<@Q1BU48@00QBU0`aS00@@Q1BU5:DDY@8@Q08<H`8@Q08D
Y@0336<@Q0aS00<@Q0DDY@0448@DYA2448@45:D248@75:D248@011BU6<HH
aQBU0Q2400@DYAS65:DDY@8@Q08DY@0336<@Q12400@HaP8DY@036<H@Q124
008@Q08DY@0448@DYA2436<248@00aBU6<HDY@025:D01A245:DDYABU6<H0
0aBU0Q240aBU0Q2400D<HaBU5:D@Q1BU008@Q08DY@8@Q0@DY@0348@DYABU
00@@Q08<H`<@Q08<H`<@Q0<<H`8@Q00536<@Q1245:D@Q00236<548@236<2
48@01ABU48@<H`aS48@00PaS00@@Q1BU48@<H`@@Q08<H`0348@<H`aS00@@
Q0L<H`0448@DYABU6<H27>L15:D0000400048@@Q000612401P00248Licg_
;F/HaP<Li`@HaP057>LHaQBU6<HQ20027>L00aBU6<HHaP046<H00acW6<HD
Y@0348@011S65:D@Q1S611BU00HHaQBU48@@Q1BU48@236<01A245:D@Q1BU
48@01ABU0a2400<HaQBU5:D00Q240QBU00<HaQBU5:D00aBU0Q241QBU0Q24
0QBU00H@Q0aS6<HLib485:D248@25:D26<H00a245:DDY@0248@55:D011cW
5:D@Q1240QS6112400@DYA2448@@Q08HaP045:D@Q0aS48@36<H01a2436<<
HaBU6<HDYA24008DY@0348@DYAS600<HaP@DY@046<HDYABU5:D448@35:D2
6<H01ABU48@@Q1246<H00QBU00@HaQBU5:D@Q08DY@8HaP<DY@8Li`@DY@8@
Q0DDY@0348@DYAS600<DY@037>LHaQBU008@Q08DY@0448@DYA246<H35:D5
48@011BU6<HHaQS60aBU0QS600<DYAS66<H01ABU0QS60aBU0QcW00@HaQ24
48@<H`8@Q0@DY@056<HDYABU48@DY@026<H00aBU48@DY@026<H35:D348@0
11BU6<H@Q1240aBU00H@Q1BU5:DDYAS65:D348@25:D26<H02Q2436<@Q124
5:DLiaS65:D<Ha240QBU0Q2400<DYAS67>L00QBU0a2400HDYAcW5:D@Q0aS
48@35:D011246<HLiaS60aBU0QS60QBU00<@Q1BU5:D00aS611BU00<@Q1BU
48@011BU0a2400<DYA2448@02a241ABU00@HaQBU48@<H`<@Q00536<@Q124
5:D@Q0035:D348@01ABU48@DYAS65:D00a2400DDYA2436<<Ha24008<H`03
48@DY@aS00<<H`0448@DYA2436<548@236<248@45:D248@01aBU48@DYA24
36<@Q1BU00@@Q08DY@H@Q00336<@Q12400D@Q0075:D@Q12436<@Q1BU6<H0
0QBU00<HaQ2448@00Q240QS600<@Q1BU48@00aBU00D<HaBU5:DHaQBU008@
Q08DY@046<HDYABU48@25:D448@45:D011S67>LHaQBU0PaS00H@Q1S66<HD
YA2436<35:D348@26<H35:D01AS65:DHaQS65:D00a2400<HaQBU5:D00Q24
00<DYA2448@0212400<DYAS648@00a2400DDYA2448@@Q0aS008@Q00436<@
Q12448@236<248@010aS248<H`aS0Q240`aS00@@Q1BU48@<H`<@Q0<<H`05
48@<H`aS48@DY@0248@436<01ABU48@@Q1BU48@00`aS0a2400<8@PaS36<0
0Q2400@8@PaS36<@Q08<H`<@Q00336<@Q1BU004@Q00000D48@0012448@00
00H48@05248U:CW>:DXDY@028@P37>L00b487>LDY@025:D47>L36<H25:D4
6<H248@00aBU48@DY@025:D00a245:D@Q0045:D00a245:DDY@0548@45:D0
11245:D@Q1S60aBU00D@Q1BU5:DDYAS600XDY@0448@DYAS65:D348@35:D2
48@01aS68@PLiaS636<@Q1BU008HaP8DY@0748@DYABU6<HDYAS648@00aBU
0QS600<DYAS648@00a2400DDYA2448@@Q1BU008Li`045:D@Q1BU48@36<H3
48@00aS65:DHaP055:D011245:DDYAS60QBU0aS60QBU00L<Ha245:DDYA24
5:D@Q0036<H348@26<H011245:DHaQS60QBU0QS60QBU0aS61aBU00<HaQ24
48@011BU11S600@DYAS67>LHaP@DY@0348@DYAS6008DY@0348@DYABU008D
Y@0448@DYABU6<H45:D00aS65:DDY@026<H55:D00aS65:DDY@025:D46<H0
1QBU48@@Q0aS48@DY@8HaP8DY@036<HDYABU00PDY@086<HDYA2448@DYA24
5:D@Q0DDY@036<H@Q1BU008DY@0748@DYA2448@DYA246<H00QBU0a2400@D
YA245:DDY@8HaP045:D@Q1245:D26<H011BU48@@Q1S60Q240aBU0Q2400DD
YAS65:DDYAS6008DY@036<HDYABU008HaP<DY@046<HDYABU5:D36<H00aBU
48@DY@025:D348@25:D348@00aBU6<HDY@0748@00`aS48@@Q0035:D00`aS
48@HaP027>L00aBU48@<H`0348@00`aS48@@Q0025:D248@01ABU48@DYABU
48@00aBU00<@Q0aS48@00a240PaS00@@Q1BU48@<H`88@P8@Q0036<HDYA24
008@Q00336<@Q124008@Q0<<H`8DY@0348@DYA24008@Q0<DY@<@Q0045:D@
Q12448@25:D648@336<448@01QBU48@DYA245:D@Q08DY@0648@DYAS65:D@
Q0aS0aBU0Q240QBU0aS61a240aBU00<@Q1BU5:D00a240QBU0a240aS600<D
YA2448@01QBU0a240QBU00@@Q1BU5:DDY@<HaP8DY@036<HDYABU008@Q003
36<DYABU00<DY@D@Q0<DY@0348@<Ha24008DY@<@Q0<DY@0448@<Ha2448@2
5:D436<548@336<00a245:D@Q00748@536<248@336<248@236<248@35:D0
0`aS48@@Q00336<248@:36<448@15:D16<H15:D000848@0500048@@Q1240
000512400aS6=JdYBP037>L011S67>LLib480QcW00<HaQcW6<H011S600<D
YAS65:D00QS600<LiaBU5:D00Q2400<DYAS65:D00a240QBU0Q2400<DYAS6
6<H00QBU00@@Q1BU5:D@Q08DY@046<HLiaBU5:D348@25:D248@011BU7>LH
aQS60Q2400@DYAS66<HHaPTDY@0348@DYA24008DY@<@Q08DY@0348@DYABU
00<HaP035:D@Q1BU00@@Q08DY@8@Q08DY@8HaP095:DHaQBU5:D@Q1BU48@D
YA24008DY@8HaP045:D@Q1S66<H25:D248@01QBU48@DYA245:D@Q0DDY@8@
Q0<DY@0348@DYAS6008DY@@@Q08DY@0548@DYABU5:D@Q0045:D00a245:DH
aP026<H01A245:DDYAcW6<H00QBU00<@Q1S66<H00aBU0aS600DDYA245:DD
YA2400<HaP8DY@036<HDYAS600<HaP@DY@046<H@Q1245:D448@02aBU6<HH
aQS65:D@Q1BU48@DYAS65:D011S600DDYA245:DDYAS600<@Q0066<HLiaBU
48@HaQBU0Q240aBU00T@Q1BU6<HHaQ246<HDYAcW6<H00aBU00@@Q1BU5:DH
aP<DY@0348@DYABU00DDY@036<HDYABU008DY@0448@DYA2448@25:D00aS6
5:DDY@0348@00aBU48@@Q00248@25:D248@01QBU6<HDYABU48@DY@8HaP05
5:D@Q0aS48@HaP035:D011246<HLiaS611BU0QcW00<HaQ245:D00QS600<L
iaS65:D00QBU00D@Q1BU5:D@Q1BU008@Q00336<@Q1BU00<DY@0336<@Q124
00<DY@0348@DYA2400D@Q08DY@8@Q00336<@Q124008@Q08<H`0448@DYABU
5:D248@00aBU48@DY@025:D448@01ABU48@@Q1245:D00Q2400<<Ha2448@0
0a2410aS112400@<Ha2448@@Q08<H`8@Q0055:D@Q1BU48@<H`0348@011BU
48@@Q1BU2A2400@<Ha2448@@Q0<<H`0348@DYA2400<@Q0035:D@Q124008@
Q0<DY@8@Q0<DY@H@Q00636<@Q1245:DLiaS60QBU0Q2400HDYA2448@DYAS6
5:D248@35:D248@75:D348@35:D648@45:D26<H35:D00a245:D@Q00248@2
6<H00aBU48@DY@035:D248@011BU48@@Q0aS0Q2411BU00H@Q0aS48@DYA24
5:D348@011BU48@@Q0aS1Q240PaS0Q240PaS0Q240QBU00<@Q0aS48@00Q24
0PaS0Q2410aS0Q240`aS0a2400@<Ha2448@@Q08<H`04248<H`aS48@936<0
112436<@Q0aS0Q240PaS00000`0012448@0212400`0012448@0212402000
248LicW>:DXHaR487>L26<H00acW8@PQ20026<H011BU6<HLiaS60QBU00<H
aQcW6<H00aS60QBU00<<Ha245:D00QS600@<Ha2448@HaPLDY@0748@DYA24
5:D@Q1BU48@00QBU00DHaQBU5:D@Q1BU00<@Q0@DY@0448@DYAS66<H:5:D2
48@45:D248@75:D00aS65:DDY@035:D00aS65:D@Q0025:D448@011S65:DD
YABU0a240QBU0Q240QBU00<HaQBU5:D00aBU0QS600@DYA2448@@Q08DY@<@
Q08DY@8HaP035:D@Q1BU00<DY@X@Q08DY@036<HDYABU008@Q08DY@8@Q0DD
Y@@HaP8DY@036<HDYABU00<HaP035:D@Q12400DDY@036<HDYAS6008HaP08
5:DHaQcW6<HLiaBU48@DY@<@Q08DY@D@Q08DY@036<HDYA24008DY@8HaP<D
Y@<Li`045:DHaQBU48@35:D00aS65:DDY@055:D248@00aS65:DHaP055:D0
0aS65:DHaP0248@01ABU6<HHaQBU48@01ABU00<@Q1BU5:D01aBU0a2400HD
YAS65:DDYAS65:D248@25:D448@55:D01QS65:DDYA245:DHaP8DY@0348@D
YABU00HDY@046<HDYAS65:D248@01AS67>LLiaS648@00QBU00<LiaS65:D0
0QBU0QS60aBU0a2400<DYA2448@00Q2400<DYA2448@00aBU0Q240QBU00@@
Q0aS48@@Q08DY@0548@DY@aS48@<H`0448@01@aS48@@Q1245:D00a240QBU
1Q2400D<Ha2448@@Q1BU00@@Q00336<@Q0aS00<@Q00336<DYA24008<H`09
48@DYA2448@<Ha245:D@Q1BU00L@Q0035:D@Q12400<DY@H@Q00436<@Q1BU
5:D436<848@011BU48@@Q1240QBU00D@Q1BU5:DHaQBU00@@Q0045:D@Q124
48@35:D021S67>LDYA2436<@Q1BU48@25:D00aS65:DDY@0348@01@aS48@D
YABU48@01QBU00@@Q1BU5:DDY@<@Q0035:D@Q12400<@Q0@HaP8DY@8@Q003
5:D@Q0aS008@Q0<DY@0348@DYA2400h@Q08DY@0448@DYA245:D348@01ABU
48@@Q12436<00a240PaS1A2400@<Ha2448@@Q08DY@8@Q0@<H`<@Q0<<H`07
48@<Ha2448@<Ha2436<00a240`aS0a2400<<Ha2436<00`aS112410aS1124
00001@@Q00048@@Q000010@Q00L000@Q124HaS6<8@PHaP027>L26<H25:D7
6<H25:D00a245:DHaP026<H45:D248@01QBU48@@Q1245:DHaP<DY@036<HD
YAS600<HaPDDY@8@Q08DY@036<HDYA24008@Q0045:D@Q1BU6<H25:D01a24
5:DLiaS65:D@Q1BU00<HaP8@Q08DY@8@Q0035:DLiaBU008@Q0055:DHaQBU
5:D@Q0035:D01AS65:DDYABU48@00QBU00<HaQBU5:D00QBU00@HaQBU5:DH
aP<DY@0348@DYABU00<DY@@@Q0035:D@Q1BU008DY@8HaP8DY@0448@<HaBU
5:D26<H00a245:DDY@0348@00aBU48@DY@0248@25:D01AS648@@Q1245:D0
0a240QS600@DY@aS48@DY@8HaP8DY@0448@DYAS66<H25:D46<H25:D36<H3
5:D36<H01Q245:D@Q1BU6<HDY@@HaP8DY@8HaP035:DHaQBU008DY@@@Q08D
Y@0448@DYA2448@36<H01QBU48@DYAS65:D@Q08DY@038@PLiaBU008DY@8@
Q08DY@046<HDYABU48@65:D00aS65:DDY@065:D011S65:DHaQ240aBU00<H
aQBU5:D01aBU112411BU00<@Q1BU5:D00QBU112411BU00HHaQ2448@DYAS6
7>L26<H45:D00aS65:DDY@0248@25:D248@00aBU6<HHaP036<H25:D00a24
5:DDY@026<H01A245:DLiacW6<H011BU00@HaQBU6<HDY@8@Q08DY@8@Q0<D
Y@0348@DYA2400<@Q08DY@036<HDYABU008@Q0<DY@036<HDYA24008<H`05
5:D@Q0aS248<H`0448@01ABU48@@Q1BU6<H00QBU2Q2400<<Ha2448@00a24
00@<Ha2448@@Q08<H`8@Q08DY@P@Q0055:D@Q12448@DY@0248@45:D248@2
5:D0112436<<Ha240aBU0Q2400<<Ha2448@011240QBU00DHaQ2448@@Q1S6
008DY@@@Q0085:D@Q1BU5:D@Q1BU48@DY@D@Q08DY@8HaP037>LDYABU008@
Q08DY@0348@DYAS600<@Q0<DY@8@Q0035:D@Q1BU00<DY@036<HDYABU00D@
Q0HDY@046<HLiaBU48@25:D00aS65:D@Q0025:D00a245:DDY@0448@010aS
48@@Q1BU0Q241QBU00<@Q1BU5:D00Q240QBU0Q2400DDYA245:D@Q1BU008@
Q00336<@Q0aS00<@Q0<<H`0548@<Ha2448@DY@0248@236<00a2436<@Q002
48@010aS48@<H`aS0Q240`aS0QBU00<@Q0aS36<00Q241@aS0Q2410aS1124
1@aS0@Q2000212401@0012448@@Q000010@Q00H8@QBU;F/Q21BU7>L26<H0
0aBU6<HLi`026<H01R487>LLiaBU48@HaP<DY@8HaP8@Q0045:DHaQBU5:D4
48@011BU6<HHaQS61QBU00<HaQBU6<H011240aBU00<HaQBU48@00Q240QBU
00@@Q1BU5:DHaP<DY@036<HDYAS6008HaP045:DHaQBU5:D448@25:D011S6
5:D@Q1241ABU00<@Q1BU6<H00QS61ABU00@@Q1BU5:DHaP8DY@8HaP@DY@04
6<HDYABU48@25:D348@25:D248@04ABU6<HHaQBU6<HDYA2436<@Q1BU7>LH
aQ245:D@Q1BU6<H00QBU0QS600/@Q0aS48@LiaS648@<HaBU6<HDYA24008D
Y@8@Q0HDY@8HaP@DY@@HaP035:DHaQS6008HaP8DY@<HaP<DY@0448@DYABU
5:D36<H35:D00aS65:DHaP045:D011245:DDYABU0a2400@DYA245:DHaP8D
Y@0448@DYABU6<H25:D01Q245:DLiacW6<HDY@8@Q0@DY@8@Q08DY@8@Q006
5:DHaQS65:D@Q1BU0QS60aBU0QS60aBU00<HaQBU48@01QBU0aS60QBU00<@
Q1BU5:D00QBU0QS60a2400<DYAS648@00a240aBU00<@Q1BU5:D00aBU0aS6
0aBU00D@Q1BU6<HHaQBU008@Q0HDY@8HaP057>LHaQS65:D@Q0025:D011S6
5:D@Q1BU0aS600<@Q1BU5:D00aS600@DYA245:DDY@8@Q0DDY@8@Q0045:D@
Q12448@25:D248@45:D01Q245:DDYABU48@<H`8@Q0035:D@Q12400D@Q003
5:D@Q124008DY@046<H@Q12436<448@01@aS48@DYA245:D00a2400D<Ha24
48@@Q0aS00<@Q00436<@Q1245:D448@011BU48@DYABU1Q2411BU00D@Q0aS
48@@Q1BU00<@Q00336<@Q12400<@Q08<H`0348@DYA24008<H`0348@HaQS6
00<DY@0448@HaQBU5:D248@01QBU48@DYABU48@DY@L@Q0035:D@Q1BU00TD
Y@0448@DYABU5:D248@011BU48@DYABU0Q240QBU0QS611BU00<@Q0aS48@0
0QBU0a240QS600PDYAS67>LDYA2436<DYAS60QBU0Q240aBU0a2400@<Ha24
36<<H`8@Q0<DY@@@Q0035:D@Q1BU008DY@8@Q0035:DHaQBU00P@Q00436<@
Q0aS36<648@336<0212436<<H`aS48@DYA2436<348@336<348@00aBU36<<
H`0236<248@436<00a2436<<H`0536<00a2436<@Q00236<00a2436<<H`01
2480000500048@@Q1240000512401@00124DYBDY8@P00QBU0QS600<LiaS6
6<H00aBU0QcW0aS600<LiaS66<H00QS60QBU00H@Q1BU5:D@Q1BU6<H45:D0
0aS65:DDY@046<H02ABU6<HHaQS65:D@Q1BU6<HLi`0248@00aBU6<HHaP03
48@25:D01AS65:DDYAS67>L00aS60QBU0aS60a240QS600<DYA246<H01ABU
0aS600HDYAS66<HHaQ245:D36<H01ABU48@@Q1BU6<H00QBU00@@Q1S66<HH
aP<@Q0055:DLiaS65:D@Q0045:D248@35:D00aS65:DDY@0348@35:D00a24
5:DDY@0448@45:D248@011BU6<HHaQBU0Q2400@HaQBU5:D@Q08DY@0848@D
YAS65:D@Q1BU7>LHaP8DY@0448@HaQS66<H25:D01AS67>LHaQS65:D00QS6
0aBU0QS60aBU00/@Q1BU48@<HaBU7>LQ21S65:DHaQcW008DY@0336<@Q1BU
008HaP0;5:D@Q12448@<Ha245:DHaQBU48@DY@056<H011BU48@DYAS60R48
00HHaQBU48@@Q1S65:D348@25:D26<H01ABU48@DYABU6<H00QBU00@@Q1BU
48@@Q08DY@036<HDYAS6008Li`045:D@Q1246<H45:D011S65:DDYAS60QBU
0Q2400<DYAS65:D00a240aBU112400<DYAS66<H011BU00<HaQBU6<H00aS6
0QBU00<@Q1BU5:D00QBU0Q241ABU0QS60QBU0a240QBU00<@Q1BU5:D00QS6
0QBU00<HaQBU6<H011BU00@HaQBU5:DDY@8@Q0065:D@Q1BU5:D@Q1BU0Q24
11BU0Q2400D<Ha245:DDYAS600D@Q08<H`8@Q0035:D@Q12400D@Q0035:D@
Q1BU008HaP8DY@0348@DYA24008<H`0448@DYABU48@25:D448@336<25:D0
0a2436<@Q0025:D348@25:D248@00`aS48@DY@0448@35:D248@010aS48@@
Q1240PaS0Q2400<DYA245:D0112400@<HaBU48@DY@<@Q0035:D@Q12400@D
Y@<@Q0@DY@0548@DYABU48@DY@0448@020aS48@@Q1cW8@PHaQBU48@25:D3
48@01ABU6<HHaQ245:D00Q2400<DYAS66<H00a240QS60aBU0Q240PaS0Q24
0aBU0aS600<LiaS648@00Q2400<HaQ2448@00QBU0a2400@DYA2448@<H`D@
Q0036<HDYABU00@DY@8HaP<@Q08DY@8@Q08HaP8@Q0035:DHaQ24008<H`03
48@DYA2400@@Q00436<@Q1245:D348@236<248@25:D248@00`Q236<DY@04
48@25:D01A2436<<Ha245:D011240PaS112400<<Ha2448@00PaS00<8@PaS
48@00Q240@aS0@Q2000312400`0012448@0212402@0012448@@Q48@YBQS6
5:DHaP027>L36<H45:D011S65:DLiacW1AS600<DYA245:D00aBU00H@Q1BU
5:DDYA246<H35:D00aS67>LHaP035:D00aS67>LDY@0248@01aS67>LHaQ24
5:DHaQBU008@Q00436<@Q1BU6<H25:D36<H011BU6<HLiaS611BU00<@Q1BU
5:D00QBU0Q240aBU00<@Q1BU6<H00QS611BU00@HaQBU6<HHaP8DY@8@Q004
5:DHaQBU48@25:D01AS65:DDYA245:D00QS60QBU0Q2411BU0a2400DDYAS6
5:DDYA2400HDY@0448@<Ha2448@25:D348@25:D01Q245:DHaQS65:D@Q08D
Y@036<H@Q1BU00<@Q08DY@046<H@Q1BU5:D26<H25:D011S65:DHaQBU0QS6
0QcW11S611BU0QS600LDYA2448@@Q1BU48@HaP027>L00aS65:DLi`026<H2
48@45:D248@25:D248@021BU6<HDYABU48@DYAS67>L26<H248@36<H27>L0
11BU48@@Q1240QBU11241ABU0Q2400@HaQBU6<HDY@<@Q0035:DHaQBU008D
Y@037>LHaQS600PDY@8HaP055:D@Q1BU5:DHaP0448@25:D00a245:DDY@04
48@00aBU6<HHaP025:D00aS65:DHaP026<H011BU6<HDYA240QBU00@HaQBU
48@DY@<@Q0045:D@Q1BU5:D27>L011BU48@@Q12421BU00<HaQBU6<H00QS6
00DDYAS66<HHaQBU008@Q0035:DHaQBU008DY@0548@HaQS66<HDY@0248@3
5:D348@25:D011245:DDYABU0Q240PaS0a2400@DYA2448@<H`@@Q00:5:D@
Q1BU5:DHaQBU48@<Ha2436<248@00aBU48@<H`035:D00a2436<@Q00248@0
0`aS48@@Q00248@01PaS48@@Q1246<HDY@<@Q0<DY@0436<@Q12436<248@3
5:D00a245:D@Q00348@236<00aBU48@DY@0548@00aBU48@@Q00248@25:D5
48@011BU48@DYA240QBU00<@Q1BU48@00QBU00<@Q1BU48@01a2400<HaQBU
6<H00QBU00<@Q1BU48@00QBU0aS60aBU00@@Q1BU5:DHaP<@Q08DY@096<HD
YABU48@DYA245:D@Q0aS008@Q0056<HDYABU6<HDY@026<H011246<H@Q124
0QBU00<HaQBU5:D00Q241PaS0Q241ABU00<@Q1S65:D00aBU00D@Q0aS48@@
Q1S600<DY@0348@DYA2400T@Q00336<@Q12400<@Q0<<H`0448@<H`aS36<2
5:D336<448@25:D448@01PaS48@@Q12436<8@P@<H`<@Q00536<8@PaS48@<
H`0248@00aBU48@<H`012480000300048@@Q00848@0500048@@Q12400002
124011BU9BTLia240QS600@@Q1BU7>LLi`8DY@0348@DYAcW00DHaP035:DH
aQBU00@@Q0HDY@036<HDYAS600<HaP035:DHaQBU00DDY@0448@DYABU5:D2
48@01QS67>LHaQBU48@DY@8@Q0045:DHaQS65:D36<H45:D00a245:DDY@04
5:D01A245:DHaQcW5:D00Q2400<DYAcW7>L00QS600<DYAS66<H00aBU0aS6
0QBU00P@Q1BU6<HDYAS65:DHaQBU0QS60aBU0Q2400<DYAS65:D00a241aBU
00@HaQBU48@@Q0@DY@8@Q08DY@036<HDYABU008HaPHDY@0548@DYAS65:DH
aP045:D26<H25:D36<H248@01aS65:D@Q0aS48@DYAcW00DHaP<DY@8@Q08H
aP075:D@Q1245:DHaQBU48@00QBU00<LiaBU5:D00Q2400<HaQBU48@00Q24
11BU00D@Q0aS48@DYAS6008DY@<@Q0045:DHaQBU6<H25:D56<H01QBU6<HD
YA2436<@Q08DY@0348@DYAS6008HaP8@Q0055:D@Q1245:D@Q0025:D00a24
5:D@Q0025:D01AS65:DHaQBU6<H011BU00@HaQBU5:D@Q0<DY@036<HDYABU
008DY@0648@DY@aS36<@Q0aS0Q2400@DYA245:DDY@8HaP8DY@0548@HaQS6
7>LDY@0248@35:D348@00aBU48@@Q00248@00aBU48@DY@025:D011S65:DD
YAS60a240QBU00<@Q1BU5:D011S60QBU00<HaQBU5:D01ABU00<@Q1BU5:D0
0QBU00@@Q0aS5:D@Q0@DY@056<HDYA2436<@Q0025:D00a245:D@Q00336<6
48@020aS48@@Q12436<@Q1BU6<H45:D00acW6<H@Q00248@00`aS48@DY@03
5:D00a2436<@Q00248@236<00a2436<<H`0236<348@01PaS48@DYA245:D@
Q08<H`8@Q0055:D<H`aS48@DY@0248@236<00a2436<<H`0248@236<00a24
5:D@Q00248@00aBU6<H@Q0025:D248@00`aS48@@Q0045:D01a245:D@Q124
5:DHaQBU008<H`0348@DYAS600<@Q08<H`0348@DYAS600@DY@8@Q0<DY@<@
Q08HaP045:D@Q1245:D26<H00a245:DDY@0248@35:D948@01ABU6<HLiaS6
5:D00Q240aBU00D@Q0aS48@@Q1BU00L@Q0<DY@D@Q0DDY@8HaP8DY@8@Q08D
Y@8@Q00636<@Q1BU48@<Ha240aBU00<<Ha2448@0112400<<Ha2448@01A24
00<DYA2448@00`aS112400<<Ha2448@0112400D<Ha2448@<H`Q2008<H`03
48@<H`aS008<H`8@Q0H<H`4@Q04DY@48@P000P@Q00<000@Q00001`@Q00/H
aRDY6<H@Q1S67>LHaQBU6<HLiaS6008@Q0036<HLiaS600<DY@8HaP045:D@
Q1BU6<H55:D348@26<H01QBU48@DYABU7>LHaP<DY@056<HDYA245:D@Q004
5:D36<H01QBU36<<Ha245:DHaP8DY@@HaP045:DHaQ2448@35:D00a245:DH
aP025:D01A245:DHaQBU48@00QBU00<HaQcW7>L00QS60QBU0aS62QBU00@H
aQBU5:DDY@8HaP8DY@0348@DYABU00<DY@8@Q08DY@096<HDYA245:DHaQBU
48@DYA2400@DY@8@Q08DY@086<HDYABU6<HLiaS65:D@Q08HaP<DY@8HaP@D
Y@8HaP@DY@8HaP045:D@Q1BU5:D348@26<H01ABU6<HHaQcW6<H00QBU0Q24
0aS60a2400@HaQBU5:DDY@8HaP0448@DYABU6<H25:D00a245:DDY@025:D5
48@45:D248@011BU48@DYABU0QS60QBU0aS60aBU00@@Q1S65:DDY@8@Q006
5:D@Q1S67>LHaQBU0Q2400<DYA245:D00aBU00@<HaBU5:DHaP8@Q0036<HL
iaBU008@Q0045:DHaQS66<H55:D011245:DDYAS60QBU0a240QBU1A240QBU
0QS60QBU00@@Q1BU6<HLi`8HaP8DY@0348@DYA2400<@Q0035:D@Q12400PD
Y@036<HDYABU008@Q0045:DHaQ245:D248@26<H27>L26<H00aBU6<HHaP02
5:D011245:DDYAS60QBU00@@Q1BU5:DDY@8@Q08DY@<HaP0448@<H`aS48@2
5:D00a2436<<H`0236<011245:DDY@aS2Q240QS611BU00DHaQBU48@<Ha24
008DY@0348@DYA2400L@Q00336<@Q0aS008@Q0035:D<H`aS00<@Q0055:D@
Q12448@<H`0548@021BU48@DYA2436<@Q0aS48@236<448@00aBU48@@Q004
5:D348@011BU48@<Ha240QBU00<@Q0aS36<00aBU00<@Q1S65:D00a2400<H
aQBU48@0112400@DYA245:DHaP8DY@8@Q0<HaP8DY@0748@DYABU48@DYA24
5:D00aS600HDYA245:D@Q1BU48@25:D01AS65:D@Q12436<00Q2400DDYA24
5:DHaQcW008HaP8@Q08DY@056<H@Q12448@DY@0348@25:D348@25:D348@0
0aBU6<HDY@0248@25:D00a245:DDY@026<H348@35:D648@25:D248@00`aS
48@@Q00248@436<448@236<01QBU48@@Q12436<DY@8<H`8@Q0035:D@Q124
00<<H`0448@DY@aS248236<0112436<<H`aS0Q240PaS00<@Q0aS36<00`aS
0A240@aS0@Q2000512400`0012448@04124011BU:DXLiaBU0QS60QBU00DH
aQcW5:D@Q1S6008Li`036<HDYABU00@HaP<DY@036<HDYABU00HDY@8HaP03
7>LDYA24008@Q08HaP035:D@Q124008DY@<HaP045:DHaQBU6<H25:D248@2
5:D76<H25:D01QS65:DDYAS65:DHaPPDY@8@Q0045:DLiaS67>L35:D46<H4
5:D00aS65:DHaP035:D00a245:DDY@075:D36<H35:D00aS65:D@Q0055:D0
11S648@@Q1BU0QS600<@Q1BU5:D00aS611BU00@HaQcW7>LDY@8HaP8DY@05
48@DYAS65:D@Q0035:D348@011S67>LHaQS60Q2400<DYA2448@00QBU0QS6
0aBU00DHaQBU5:DDYA2400<DY@8HaP<DY@0548@HaQS67>LHaP0:5:D348@7
5:D248@25:D00aS67>LHaP025:D00a246<HLi`025:D011245:DDYAS60QBU
00<@Q1BU5:D011BU0QS600@DYA2448@<H`8@Q0066<H@Q12448@DYAS61ABU
0QS600@DYA2448@DY@8HaP065:D@Q12448@DYAS60QBU11240QBU0a2400@D
YAS66<HHaPDDY@0348@DYABU008HaP8DY@0348@DYA24008@Q0045:DHaQBU
48@55:D00aS65:D@Q00248@25:D01Q245:DDYABU36<DY@8Q20047>LDYAS6
7>L35:D011S65:D@Q1BU0aS600@DYA2448@@Q0<DY@<@Q08DY@0448@DYABU
5:D448@010aS48@<Ha240`aS0Q240PaS1Q2400TDYA2448@<HaBU6<HLiaS6
48@00QBU00<<Ha2448@00QBU00<@Q0aS48@0112400<<H`Q236<00Q2400<D
YA2436<01A240aBU0Q2400<<Ha2448@0112400D<HaBU48@DYA24008<H`08
48@<HaBU48@DYA2436<@Q08DY@0848@<H`aS5:D@Q1BU48@DY@@@Q0035:D@
Q1BU00H@Q00336<@Q0aS00D@Q0045:DLiaS65:D248@01ABU48@HaQBU6<H0
11BU00<HaQBU6<H02ABU0a240QBU1A240QBU0QS61QBU00@@Q1BU48@DY@L@
Q08<H`045:DHaQcW6<H348@25:D448@35:D01A245:DHaQS65:D00Q240QBU
00<HaQ2436<00Q240QBU0Q240PaS0Q2400@DY@aS48@<H`@@Q0035:D@Q0aS
008<H`8@Q00436<@Q12436<248@011BU48@<H`aS0Q240`aS00@@Q0aS36<<
H`8@Q08<H`@@Q08<H`04248<Ha2448@136<00004124000@Q000512402000
12448A24;F/Q21S67>L25:D26<H011BU48@DYAS60QcW0aBU0aS60QBU00<@
Q1BU5:D00QBU00<HaQBU6<H00Q2400@DYAS67>LHaP8@Q08DY@066<HDYABU
48@DYAS60QBU00@HaQBU5:DDY@8HaP055:D@Q1245:DHaP025:D00a246<HL
i`027>L25:D01AS65:DHaQS65:D011S600<DYA245:D011BU0aS600<DYAS6
6<H00QS600@DYAS66<HHaP8DY@036<HDYA24008DY@046<HDYABU5:D36<H0
0aBU48@DY@035:D37>L011S648@DYABU0aS60QBU00@@Q1BU5:DDY@8@Q08D
Y@036<HDYABU00<DY@036<HLiaBU00<HaP037>LHaQBU00@DY@8HaP<@Q005
6<HDYA245:D@Q0037>L00aS648@@Q00336<011246<HDYA240aBU0a2400@D
YAS65:DHaP8DY@0448@DYABU5:D56<H35:D01A245:DDYAS65:D00Q240QBU
0a2400@DYA2448@DY@8HaP<DY@8Li`035:DHaQ2400<DY@096<H@Q1245:DL
iaS648@<Ha2400<DY@036<HDYAS6008@Q0045:D@Q1BU48@25:D248@01ABU
48@DYA245:D00aS60aBU0QS600<DYA2448@00QBU00<HaQBU6<H01ABU00<@
Q1BU5:D00QBU00@@Q0aS48@@Q0HHaP8DY@066<HDYABU5:DHaQBU0a240QBU
00<@Q1BU5:D00QBU112400<DYA2448@00Q2400<DYAS65:D00Q2400PDYA24
48@HaQBU7>LHaQBU0QcW00DHaQ245:DDYAS600@DY@036<HDYA2400HDY@03
48@DYABU00@@Q08DY@0348@<Ha24008<H`0548@<Ha2448@DY@0348@236<2
48@011BU48@<H`aS0QBU00D<HaBU7>LHaQBU008@Q08DY@0448@DYA245:D3
48@436<348@336<448@01ABU48@@Q1245:D00a2400<<Ha2436<00a240`aS
00@@Q1BU5:D@Q08<H`8@Q0045:D@Q12448@35:D648@45:D00a2436<<H`02
48@00aBU48@@Q00348@01ABU48@<H`aS48@00QBU00@<Ha2448@HaPHDY@<H
aP0648@DYABU48@DYA240QBU00<HaQBU6<H00QBU00<@Q0aS48@011BU00D@
Q1BU48@@Q1BU008@Q0075:DHaQcW6<HDYAS65:D00a240QBU112400HDYA24
48@@Q0aS48@45:D248@236<00a245:DDY@035:D248@01QBU6<HDYABU48@<
H`H@Q0045:D@Q12448@25:D00a2436<@Q00248@01@Q248@@Q12436<00Q24
00<DYA2436<011240`aS00H@Q0aS36<@Q1BU48@336<00a2436<8@P0336<0
1A2436<@Q12436<011241PaS00001`0012448@@Q00048@0000<48@080008
@QBU:DXLiaBU6<HLi`<DY@8HaP8DY@8HaP<DY@036<HDYABU00@DY@8@Q005
5:DHaQS65:D@Q0045:D021S65:DDYA245:D@Q1BU48@35:D00aS65:DDY@02
5:D01AS65:DDYABU48@011BU0Q2400PDYAS67>LHaQBU6<HLiaS60QBU0aS6
00DDYA2448@DYAS6008DY@0448@DYABU6<H25:D00a245:DDY@025:D01AS6
5:DDYABU6<H011BU00@HaQBU48@DY@<HaP065:D@Q1BU5:DHaQcW0aS600HD
YAS65:D@Q1BU6<H27>L25:D36<H00aBU6<HDY@025:D26<H25:D02a245:DD
YA245:D@Q1BU6<HDYAS65:D00QS61ABU0a240QBU0Q240aBU0Q2400<DYAS6
48@00Q240QS60Q2400@DYAS648@DY@8HaP045:D@Q1BU7>L26<H25:D00aS6
5:DDY@025:D26<H00aBU6<HDY@036<H25:D248@011BU48@@Q1BU11240QBU
0QS60QBU0QS600<@Q1BU5:D00QS60QBU0Q240aBU0Q2400<DYA246<H011BU
0Q240aBU0a2400DDYA245:DDYAS600<DY@036<HDYABU008DY@036<HDYAS6
00@DY@036<HDYAS6008DY@0448@DYABU5:D348@00aBU6<HDY@025:D01a24
5:DHaQBU48@DYA24008DY@0448@DYABU5:D348@25:D02aS65:DHaQBU48@D
YAS648@DYA245:D011S60QBU0Q2411BU0QcW00PHaQ245:DHaQBU6<HDYAS6
11BU0QS60QBU00@@Q1BU5:DDY@@@Q08DY@8<H`0348@HaQBU008@Q0@<H`03
48@DYABU008@Q00436<8@PaS36<248@236<00a245:DDY@0348@01ABU6<HD
YABU6<H00aBU00<<Ha2448@00Q2400<<Ha245:D00Q240PaS0a2400<<Ha24
48@011BU00<@Q0aS48@00Q2400<<Ha2448@0112400<<Ha245:D00QBU00D@
Q0aS36<<Ha24008DY@8@Q0035:D@Q124008<H`D@Q0<DY@0348@<Ha2400<@
Q00336<DYABU008DY@0548@<Ha2436<@Q0045:D00a245:D@Q00348@01aBU
48@DYA245:DHaQcW008HaP035:D@Q1BU00<DY@0348@DYABU00@@Q0@DY@03
48@<Ha2400<DY@<@Q0055:D@Q1BU48@DY@0248@45:D00a2436<<H`0236<0
0aBU48@@Q0025:D01AS648@<Ha246<H01QBU00@@Q0aS36<@Q0DDY@D@Q004
36<@Q1BU5:D648@25:D248@010aS48@DYA240`aS0a2410aS0Q2400@<Ha24
48@@Q08<H`8@Q0D<H`0448@<H`Q236<348@00`aS48@<H`0248@336<148@1
248000<48@0300048@@Q00H48@045:DYBQcW48@66<H011BU6<HDYAS611BU
0QS60QBU00D@Q1BU6<H@Q1BU00<HaP055:D@Q1BU5:DHaP065:D00aS65:DD
Y@065:D26<H00aBU6<HDY@0248@25:D01AS65:D@Q1BU6<H00QcW00HHaQBU
6<HLiaS65:D36<H011BU48@DYABU0a2400DHaQBU6<HDYAS600<DY@8HaP<D
Y@8HaP@DY@0448@DYABU5:D46<H25:D26<H00aBU48@HaP027>L26<H25:D2
6<H01ABU6<HHaQcW6<H00QBU0QS60aBU0QS611BU00@HaQBU5:D@Q08DY@8H
aP8DY@<HaP<DY@<@Q0@DY@0448@DYABU5:D348@011BU48@@Q1BU0QS60QBU
00<HaQBU5:D00Q2400<DYA246<H00QcW00hHaQBU5:DHaQBU48@DYAS67>LH
aQBU6<HDYAS60QBU00HHaQBU5:D@Q1BU48@35:D548@25:D01AS67>LHaQS6
5:D00QS600@@Q1BU6<HDY@8@Q0035:DHaQBU008@Q0DDY@8HaP8@Q0055:D@
Q1245:D@Q0025:D01Q245:D@Q1245:DHaP8DY@8@Q0036<HLiaS600@DY@<H
aP@DY@<@Q0@DY@046<HDYABU6<H55:D011S65:D<Ha240aBU00<@Q1BU5:D0
0QBU00<@Q1BU5:D00QBU00@@Q1BU5:DHaP8DY@0348@<H`aS008DY@<HaP04
5:D@Q1BU48@46<H01ABU48@DYABU6<H00QcW00<HaQBU5:D00QS60QBU0aS6
0QBU00PHaQBU5:DDYA245:DHaQBU0Q2400<DYA2448@00a2400D<Ha242488
@Q2400<DY@D<H`@@Q00336<@Q12400<@Q0035:DHaQBU00@DY@8@Q00336<@
Q12400D@Q00436<@Q0aS48@336<00a245:DDY@0448@00`aS48@@Q00548@0
0`aS48@@Q00248@01ABU48@DYA2436<00Q2400HDYA2448@DYA245:D648@3
5:D348@00aBU48@@Q00236<848@00`aS48@@Q0026<H248@01ABU48@DYA24
36<00Q2411BU00`HaQcW6<HDYAS648@DYA245:DHaQBU6<H248@00`aS48@D
Y@025:D448@01ABU48@@Q1BU48@01ABU00<@Q1BU48@00Q2400@DYA245:DD
Y@8@Q0<<H`0548@HaQBU5:D@Q0075:D011245:D@Q1BU0Q240QBU0QS600D@
Q1BU5:D@Q1BU00<@Q0<DY@0336<@Q1BU008@Q0035:D@Q124008<H`8@Q003
5:D@Q0aS008<H`035:D@Q124008<H`<@Q0@<H`0348@<Ha24008<H`03248<
Ha2400@<H`8@Q0045:D<Ha2436<248@436<22480000300048@@Q00848@04
00048@@Q000312401QBU:DXQ21246<HDY@@HaP<DY@056<HLiaS66<HLi`05
6<H248@45:D26<H45:D00aS65:DDY@0248@01ABU6<HHaQBU48@00QBU00D@
Q1S67>LLiaS6008DY@056<HDYAS648@DY@0248@011S67>LLiaS60QBU00LH
aQBU5:DDYAS65:DHaP035:D26<H35:D348@25:D011S648@HaQS60QcW0aBU
0QS60aBU00<HaQBU6<H011S600@DYAS66<HHaP8DY@@HaP8DY@8HaP8DY@<H
aP035:DHaQBU008DY@0648@DYABU48@DYAS60QBU00@@Q1S65:DDY@8@Q08D
Y@0348@DYABU00DDY@086<HDYA245:D@Q1BU48@DY@<@Q0PDY@076<HDYA24
48@DYAS65:D00Q2400<DYAS66<H00QBU00HHaQBU6<H@Q1BU48@26<H35:D0
1AS65:DDYA245:D00QS600<LiaBU5:D00QBU0Q240aBU0a2400D<HaBU6<HH
aQcW00<DY@8HaP<DY@0548@HaQBU6<HDY@0448@55:D00aS65:D@Q0026<H0
1ABU48@DYABU6<H00QBU00<HaQBU6<H01ABU00@HaQBU6<HHaP8DY@0448@D
YABU6<H35:D01Q245:DDYA246<HDY@8@Q0055:DHaQS66<H@Q0025:D448@2
6<H01ABU36<<HaBU6<H00Q2400<DYAS66<H01ABU00<@Q1BU5:D01QBU00<H
aQBU48@00Q240QS60QBU0aS60QBU00HHaQBU48@DYAS67>L25:D011246<HH
aQS611BU00@HaQBU5:D@Q08DY@046<HDYA2448@35:D448@01aBU48@<H`aS
248<Ha2400<<H`@@Q00336<@Q124008@Q0<DY@0348@DYAS6008HaP<@Q004
36<@Q0aS248248@25:D448@00aBU48@@Q00236<35:D00a2436<@Q00248@2
5:D00a2436<<H`0248@00aBU48@@Q00248@01@aS48@@Q1245:D011240aBU
0`aS00D@Q1S65:DDYA24008DY@@@Q0035:D@Q12400T@Q0055:D@Q1245:D@
Q0035:D248@01@aS48@@Q1BU48@00aBU00HHaQBU5:DDYA246<H25:D36<H3
5:D02A245:D@Q1245:D@Q1BU48@DY@0348@25:D03QS67>LHaQBU48@DYA24
5:D@Q1BU48@DYA245:D248@01QBU48@@Q1BU48@DY@8@Q08DY@036<H@Q124
008DY@036<H@Q12400<@Q0035:DHaQBU00<@Q0045:DHaQBU5:D348@00aBU
48@@Q00348@01QBU36<@Q1245:D@Q08<H`<@Q0<<H`8@Q08<H`0348@<Ha24
008@Q0H<H`8@Q00436<8@PQ2248248@00`aS48@<H`0236<248@010aS248<
Ha240@aS000212400`001240000712400aBU:DXLi`025:D00aS65:DHaP07
5:D46<H25:D26<H25:D011245:DHaQS60aBU00<@Q1BU6<H00QBU00@@Q0aS
5:DDY@8HaPHDY@<HaP045:DHaQBU6<H348@25:D26<H00acW6<HHaP035:D0
0aS65:DDY@055:D01A245:DDYABU48@00aBU0QS600D@Q1BU48@HaQcW00DH
aP035:DHaQBU008DY@<HaP<DY@037>LHaQS600@HaP065:DHaQBU5:DHaQBU
0aS611BU11240aBU00<HaQBU48@00QBU00DHaQBU5:DDYAS600@DY@046<HD
YABU48@25:D01QS65:D@Q1BU48@DY@<@Q0035:D@Q1BU00<DY@0348@DYABU
00<DY@8HaPHDY@0448@DYA246<H45:D00aS65:DHaP025:D01A245:DDYAS6
7>L00QBU00P@Q1BU7>LHaQBU6<HLiaBU0a2400TDYAS65:D@Q0aS48@DYAS6
7>L00aBU0aS600<DYA245:D01ABU0Q2400@DYA2448@@Q0DDY@036<HDYABU
00PDY@036<HDYA24008@Q0DDY@036<HDYA24008DY@046<H@Q1245:D26<H0
0aBU48@HaP035:D00a245:DHaP036<H00aBU48@@Q0025:D00a245:DHaP02
5:D00a245:D@Q00248@011BU6<HHaQS60QBU0Q2411BU00<HaQBU5:D00aBU
0a2400<HaQcW8@P00QBU0aS60aBU00<@Q1S65:D01ABU00@HaQBU5:DDY@<@
Q0035:DHaQBU008@Q0<DY@P@Q08DY@0548@<H`Q236<@Q00436<0112436<@
Q0aS0a2400<DYA2448@01ABU0QS600@DYA2448@<H`X@Q08<H`L@Q0045:D@
Q0aS36<248@00aBU48@@Q00236<348@00aBU48@@Q00=48@00`aS48@@Q002
5:D26<H00aBU48@<H`0448@01@aS48@<Ha245:D00Q2400<<Ha2448@00aBU
0Q240QBU0QS60Q240PaS0Q240aBU00DHaQcW6<HDYA2400<DY@046<HDYABU
5:D26<H011BU48@<Ha240aBU00<<HaBU5:D00QBU0a2400DDYAcW6<HHaQBU
008@Q0<DY@<@Q00336<@Q1BU008@Q00436<@Q1BU5:D448@25:D00a245:DD
Y@0748@35:D348@01aBU48@DYABU48@DYA2400<<H`075:D@Q12448@DYA24
5:D00Q240PaS00<@Q1BU48@00`aS0a2400@<Ha2436<<H`@@Q00536<8@PaS
36<DY@0236<00`Q236<@Q00248@236<00aBU48@<H`02248236<1248136<0
00D48@0500048@@Q1240000212400aBU;F/Q20035:D00aS67>LHaP035:D0
0a245:DHaP026<H25:D00aS65:DDY@035:D011S65:DDYAS61ABU0aS600<D
YAS66<H00QS611BU00<HaQBU5:D00QS600LLiaS66<HHaQBU6<HDY@0248@0
1ABU6<HHaQS67>L01AS60QBU1QS60QBU0QS60QBU00D@Q1BU6<HLiaBU00HH
aP<Li`@HaP<DY@056<HLiaS65:DLi`035:D00`aS5:DDY@027>L00aS648@@
Q0025:D26<H348@00aBU6<HHaP065:D01A245:DDYAcW6<H00a2400<DYAS6
5:D00QBU00DHaQBU48@DYAS600<DY@0348@HaQBU00DDY@8HaP065:D<H`aS
48@LiaS60a2400DDYAS66<HLiaS600@DY@036<HDYABU00<DY@8@Q0055:DL
iaS65:D@Q0026<H35:D00aS67>LHaP056<H00aBU48@DY@036<H011BU48@@
Q1240aS60Q2400<DYAS648@00Q2421BU00P@Q1BU5:DDYA245:D@Q1S60aBU
0a2400LDYAS66<HHaQBU6<HDY@026<H348@26<H35:D00aS65:DHaP025:D2
6<H25:D01A245:DDYABU6<H00QBU00<@Q1BU5:D00QS60Q240aBU0Q240QBU
0QS60Q2400PDYA245:DDYAS648@DYA240QBU0QS60QBU00<@Q1BU6<H00QS6
00@DYA245:D@Q08DY@067>LHaQS648@DYAS60QBU00@HaQBU5:DDY@8HaP8L
i`056<HDYABU6<HDY@0348@36<H01ABU48@DYA246<H011240aBU1A2400@D
YA2448@@Q08<H`@@Q08<H`@@Q00336<@Q1BU008DY@<@Q0045:DHaQBU5:D3
48@01@aS48@@Q1BU48@00PaS00P@Q1BU5:D@Q1BU48@<Ha240QBU00<@Q1BU
48@00aBU0`aS00<DYA2448@011BU00H@Q1BU48@@Q1BU48@75:D248@336<0
11BU7>LLiaS60Q2400<<Ha2448@00Q2400<<Ha245:D021240QBU00<@Q1BU
6<H00QS600@DY@aS48@@Q0<DY@8HaP<DY@8HaPDDY@8HaP8DY@0748@DYABU
5:D@Q0aS48@00QBU00<HaQBU5:D00Q2400<HaQBU6<H011BU00@HaQBU48@<
H`8@Q00336<@Q1BU008DY@8@Q00436<@Q1BU5:D348@00aBU6<HHaP0348@0
0aBU48@@Q00348@011S65:DDYABU1A2400<<HaBU5:D00QBU00D<Ha2448@D
YA24008DY@<<H`<@Q00336<@Q1BU00<@Q0035:D@Q124008<H`8@Q00336<@
Q12400<<H`8@Q00836<8@PQ236<DYA2436<8@P<<H`0348@DYA2400<<H`4@
Q04<H`0000@000@Q124000H48@0600048ABU:DXQ21240QS60QBU0QS60Q24
00DDYAS66<HDYA2400<DY@066<HDYA2448@DYA241aBU00@HaQBU6<HHaP@D
Y@066<HDYABU5:DLiaS60QBU00@HaQcW7>LLi`8DY@0348@HaQBU00<DY@8H
aP037>LHaQS600<HaP077>LDYAS65:DHaQcW6<H00QBU11S60aBU00<HaQBU
5:D00QBU00@HaQcW7>LLi`<HaP037>LHaQS600<HaP8DY@HHaP045:D@Q1BU
5:D36<H25:D011245:DDYABU0a2400<DYAS66<H00QS600<@Q1BU48@01QBU
00<HaQBU36<00Q2400<DYAS65:D00aBU00@@Q1BU6<HHaP<DY@066<HDYAS6
48@DYA2411BU0Q240aBU0Q240QBU00@HaQcW6<HHaP<DY@036<HDYA2400DD
Y@0348@DYABU00@DY@<HaP<DY@DHaP045:D@Q1BU48@25:D00aS65:DDY@06
5:D248@36<H35:D00aS65:DDY@025:D348@35:D00a245:DDY@035:D00aS6
5:DDY@025:D26<H35:D26<H55:D00a246<HDY@025:D00a245:D@Q0035:D0
0aS65:DDY@075:D011S65:DDYABU0a2411BU0QS600DDYA245:DDYA2400@D
Y@8@Q0035:DHaQBU008HaPDDY@046<HDYABU5:D248@36<H35:D36<H55:D2
6<H00aBU6<HHaP025:D248@021BU48@@Q1BU6<HDYA2436<35:D248@25:D3
48@25:D00a2436<<H`0336<00a2436<<H`0448@00`aS48@<H`0348@25:D3
48@00`aS5:DDY@026<H00aBU48@@Q00236<248@25:D01Q2436<@Q1BU6<H@
Q08<H`8@Q00336<@Q124008@Q08<H`0448@<Ha245:D248@236<00a245:DD
Y@0348@00aBU48@@Q00248@75:D348@00`aS5:DHaP026<H00a2436<<H`02
48@01QBU48@@Q0aS48@DY@8@Q08<H`0:48@DYABU48@<HaBU6<HLiaS636<3
48@00aBU6<HHaP0248@25:D00aS65:D@Q0026<H011BU48@DYABU0QS60QBU
00<@Q1BU48@00aBU00@HaQBU5:DDY@8@Q08DY@036<HDYABU00D@Q0<DY@03
48@<Ha2400<@Q0055:D@Q12448@<H`0448@55:D248@01ABU48@@Q1245:D0
0Q2400<DYA245:D0112400@DYAS65:DDY@<@Q0055:D@Q12448@<H`0248@0
1QBU48@<H`aS48@<H`<@Q0035:D@Q0aS008<H`8@Q00436<@Q12448@536<0
1124248<H`aS0Q240`aS112400@<Ha2436<<H`88@P0000D48@0012448@00
00L48@045:DYBQcW5:D36<H011245:DDYAS60QBU00<@Q1BU6<H00QBU0Q24
0aBU00P@Q1BU5:DDYA245:D@Q1BU0Q2400@DYAS65:D@Q08DY@037>LDYA24
008DY@036<HDYABU008HaP075:DHaQS66<HDYA245:D00QS600<DYA245:D0
11S600PLib488@PHaQ245:DHaQcW1aS600<LiaS66<H00QS600<DYAS65:D0
0QS60QBU00@HaQBU6<H@Q08DY@0348@DYA2400<DY@@HaP055:D@Q1S66<HD
Y@0248@011BU6<HHaQS60aBU00D@Q1BU5:DDYAS600DDY@036<HDYAS6008D
Y@0348@DYABU00<@Q0<DY@066<HDYAS66<HDYAS611BU00@@Q1BU5:DDY@<H
aP045:D@Q12448@75:D348@25:D26<H35:D00acW8@PHaP036<H00aBU48@D
Y@045:D00a245:DHaP085:D36<H01A245:DHaQS65:D00Q2400<DYAS65:D0
0Q2400<HaQBU48@00QS60QBU00<@Q1BU5:D00a2400HDYAS66<HDYA245:D2
6<H00aBU48@DY@025:D011245:DDYAS61ABU00<HaQBU5:D011BU0aS600<D
YA245:D00aBU0Q2400<DYAS65:D00Q240aBU0aS600<@Q1BU48@00QBU00<@
Q1BU48@00Q241ABU0QS600<DYA2448@00aBU00D@Q1BU5:DLiaS6008DY@08
6<HLiacW5:DHaQBU48@DY@<HaPDDY@@HaP045:D@Q1BU48@26<H00aBU6<HH
aP035:D36<H25:D46<H00a245:DDY@0248@236<35:D348@25:D00a2436<@
Q00348@011BU48@@Q0aS0Q240`aS1A2400<DYA2436<00Q2400L<Ha245:DH
aQBU48@<H`0448@01ABU48@DYA245:D00Q2400H<Ha245:D@Q0aS48@25:D2
48@01ABU48@@Q12436<00a2400<DYA2448@01a2400<<HaBU5:D00QBU0Q24
00<DY@aS48@00QBU0a2400<HaQBU5:D01A2400<DYA2448@00a2400<<Ha24
48@0112400D<HaBU6<HHaQBU008@Q0055:D@Q12448@DY@0348@25:D00a24
5:D@Q0045:D00aS65:DDY@0248@01ABU48@@Q12436<00Q2400<DYAS67>L0
0aS600@DYA245:D@Q08DY@D@Q08<H`<@Q0055:D@Q0aS36<@Q0025:D548@0
11S67>LHaQBU112400<DYA2448@00Q2411BU00@<Ha2448@@Q08DY@8@Q08D
Y@<HaP8@Q0<<H`8@Q08<H`0348@DYA24008@Q0055:D<H`aS48@DY@0248@0
10aS48@@Q12410aS0Q241`aS00<@Q0aS48@00Q241@aS0002124010001244
8@000P@Q00L000@Q12448ABU:DXHaP025:D00aS65:DHaP035:D00a245:DD
Y@026<H00aBU48@DY@026<H011BU48@DYAS611BU0Q241ABU00@HaQBU6<HH
aP8DY@0448@DYAS65:D36<H25:D26<H25:D00a245:DDY@036<H011245:DD
YAS60QcW21S60QcW00DHaQBU5:DHaQBU008HaP047>LHaQS65:D46<H01ABU
6<HHaQS65:D00Q2400DDYA245:DDYA24008HaP037>LHaQBU00@DY@8@Q003
5:DHaQS6008DY@046<HDYAS66<H45:D00aS65:DDY@025:D011S65:D@Q124
0QBU00DHaQ2436<@Q1BU008HaP0348@DYABU00DHaPDDY@<HaP055:D@Q124
5:DHaP025:D01a245:DDYAS648@DYA2400@DY@8HaP8DY@8HaP067>LDYABU
6<H@Q1BU0Q2400<DYAS65:D01QBU1AS600HDYAS66<HHaQBU48@35:D248@2
5:D26<H011BU48@@Q1BU0aS600<@Q1BU48@00QBU00DHaQBU6<HDYA2400<D
Y@036<HDYABU00LDY@0348@DYABU00<HaP@DY@0448@HaQBU6<H25:D00aS6
5:DDY@075:D01AS648@DYA245:D011S60Q2400PDYA2448@@Q1S648@DYA24
11BU00<HaQBU5:D01ABU0Q2400HDYAS66<HDYA245:D36<H25:D011S67>LH
aQBU0Q240aS600HDYA246<HLiaS648@55:D26<H85:D011245:DHaQS60QBU
00<@Q1BU5:D011240QBU00<<Ha2448@00QBU00H@Q0aS48@@Q0aS48@25:D3
36<248@236<021245:D@Q0aS48@<Ha245:D548@00aS65:D@Q00236<>48@0
0aBU48@<H`0248@00aBU48@<H`0548@01ABU48@@Q1245:D00a2400<DYAS6
48@00Q2400@HaQBU48@<H`<@Q08DY@8@Q00536<DYABU6<HDY@0548@236<0
1QBU48@<H`aS48@DY@L@Q0045:DHaQS65:D348@25:D348@35:D348@00aBU
6<HHaP055:D248@01aBU48@@Q1BU48@DYAS6008DY@036<HDYABU008DY@8H
aP045:D@Q12448@25:D011245:DDYA240`aS0Q2400@DYA2448@DY@8@Q08<
H`045:DHaQS67>L35:D00a2436<<H`0248@00aBU48@@Q0045:D00a245:DD
Y@0448@00aS65:DHaP025:D011245:D@Q0aS212400<DYA2448@01Q2410aS
00DDYA2448@<Ha24008<H`0348@<Ha2400D<H`<@Q0D<H`0000<000@Q1240
1P@Q00L000@Q124DYBe[9BT@Q0035:D01AS65:DDYA246<H00QBU11S600<D
YAS66<H011BU00<HaQBU5:D00QBU0Q2400DDYAS65:DDYA2400DDY@0348@D
YABU008HaP037>LDYABU008DY@8HaP045:DHaQS67>L26<H01QBU6<HHaQcW
6<HDY@<HaP035:D@Q1BU008DY@8HaP8@Q00536<DYABU6<HDY@036<H00aBU
6<HHaP026<H021BU6<HHaQS65:DHaQ245:D248@25:D36<H35:D46<H35:D2
6<H35:D26<H00aBU6<HDY@035:D01AS65:DDYA245:D00QS60QBU0Q2411BU
0Q2400<DYA245:D00QS60QBU00<@Q1BU48@00Q240aBU00<HaQ2448@00QBU
0QS60aBU0QS600<DYA245:D00aBU00<HaQcW5:D00QBU00<HaQcW6<H00QBU
00@HaQBU5:DDY@8HaP8DY@8HaP045:DHaQS66<H35:D01AS67>LHaQS65:D0
0aS61ABU00<HaQBU6<H011BU00D@Q1BU5:DDYA24008DY@0348@DYA24008D
Y@036<HDYAS6008HaP045:DHaQBU48@25:D00aS65:DDY@036<H25:D36<H3
5:D00aS65:DHaP0348@00aBU6<HHaP045:D248@25:D011S65:DDYAS60a24
00<DYAS66<H00aBU0Q241ABU0QS600<@Q1BU5:D00QBU0a2400<DYA245:D0
0QBU00<@Q1BU5:D011S600LDYA245:DHaQcW6<HDY@036<H35:D36<H35:D2
6<H00aBU6<HHaP025:D00aS65:DHaP027>L00aS65:DDY@026<H011BU48@D
YABU0Q240QBU00@@Q0aS48@@Q0@DY@0348@<Ha24008DY@0448@<Ha245:D2
48@00`aS48@@Q00248@00aBU48@<H`0248@25:D0112436<<Ha240QBU00<H
aQBU5:D00Q240QBU00D@Q0aS36<@Q1S6008DY@8@Q0035:D@Q12400@@Q004
5:DHaQS65:D348@00aBU48@<H`0248@01QS65:D@Q0aS48@<H`T@Q08<H`07
48@<Ha2448@DYA245:D00a2400<DYA2448@00Q2400<DYA2448@00a2411BU
00<@Q1BU5:D011240aBU0a241ABU11240QS600@DYA2448@@Q0<DY@@@Q005
5:DHaQcW7>LDY@026<H65:D0112436<<Ha240QBU00@@Q0aS48@<H`D@Q003
36<@Q1BU00<@Q08DY@036<HDYABU008@Q00436<@Q12436<248@35:D348@3
5:D00a2436<@Q0035:D01A245:DHaQS65:D00Q2400<<Ha2448@0112400@D
YA245:D@Q08<H`@@Q0<<H`055:D@Q0aS248<H`0248@010aS48@DY@aS0PQ2
00<<Ha2448@00PaS0Q2400<<Ha2448@00@aS00031240100012448@000`@Q
00L000Q26<H]JacW48@HaP035:D011245:D@Q1BU1AS600@DYAS66<HHaP8@
Q0055:DHaQBU5:D@Q0025:D00a245:DDY@025:D248@25:D26<H01ABU48@@
Q1BU6<H00R4800@HaQBU48@DY@8HaP8DY@8HaP047>LHaQBU6<H27>L011S6
48@HaQcW0QS60QBU00<HaQBU6<H011BU00<@Q1S65:D011S600@DYAS66<HH
aP8DY@046<HLiaS65:D348@45:D011246<HHaQS60aBU0aS60aBU0QS60QBU
00H@Q1BU5:DHaQBU48@25:D26<H011BU48@DYAS60QBU0a2400<DYAS66<H0
0Q2400<DYA245:D00QBU11S600<DY@aS48@00QBU0a240QBU00<HaQBU5:D0
0aBU0QS60QBU0a2400<DYAS66<H00QS611BU00<HaQBU6<H00aS60Q241QBU
0QS611BU00<HaQBU6<H00aS61QBU00@HaQBU5:DHaPHDY@0448@DYABU6<H2
5:D020aS48@@Q1BU6<HDYAS65:D26<H01ABU48@@Q1BU6<H00QBU00<HaQBU
5:D00QBU0aS600@DYAcW6<HDY@8@Q0<HaP<DY@036<HDYABU008@Q08DY@04
6<H@Q1245:D26<H00a245:DDY@025:D01Q246<H@Q12436<@Q0@DY@0348@D
YABU00PDY@046<H@Q1BU48@25:D348@01ABU6<HLiaS65:D00Q2400HDYAS6
7>LHaQBU6<H25:D26<H27>L45:D26<H45:D248@00aBU6<HHaP026<H25:D2
6<H00aBU6<HHaP025:D548@010aS48@@Q1S60QBU0a2400LDYA24248<Ha24
5:D@Q00236<011245:DDYA240`aS2A2411BU0Q2400<<Ha2448@00QBU1124
0QBU00X@Q0aS36<@Q0aS248<HaBU6<HDY@D@Q08DY@<@Q0045:D@Q12436<2
48@25:D00a2436<@Q00548@00`aS48@@Q00248@25:D248@00aBU6<HDY@04
48@336<55:D011245:D@Q1240aBU00<@Q0aS48@00QBU0a241aBU00<@Q1BU
5:D00QS611BU0Q2400<<Ha2448@00QS600@Q21cW7>LLi`8HaP045:D@Q124
48@25:D236<01A245:DDYA245:D00Q2400H<Ha2448@DYAS648@236<01124
5:DDYA240QBU0QS60QBU0a240QBU0a2400DDYA245:D@Q1BU00<@Q00336<@
Q12400DDY@036<HDYA2400H@Q00536<@Q1BU5:D@Q00236<548@236<00a24
36<<H`0248@636<00a2436<<H`0436<448@336<0000500048@@Q12400007
12400aS6;F/Q200248@25:D00aS65:DDY@025:D46<H25:D00a245:DDY@02
48@45:D01Q245:DDYABU6<HLi`8HaP8DY@8HaP0:5:DHaQBU5:D@Q1S65:DQ
21cW6<H25:D01aS67>LHaQS648@DYA2400@DY@0448@HaQBU6<H65:D03AS6
7>LHaQBU48@DYAS65:DHaQcW6<HLiaS6008DY@8HaP<DY@036<HDYAcW008D
Y@8@Q0045:D@Q12448@56<H35:D011245:DDYAS60QBU00HHaQcW6<HHaQBU
6<H35:D00a245:DDY@025:D00aS65:DDY@085:D26<H35:D46<H348@25:D0
1QS65:D@Q1245:DHaP8@Q0065:DHaQS66<HDYAS62ABU00T@Q0aS6<HHaQcW
5:D@Q1BU6<H00QBU00@@Q1S65:DHaP<DY@8HaP8DY@8HaP<DY@@HaP075:DH
aQcW7>LHaQ245:D00QS60QBU00<HaQBU5:D021BU00P@Q1BU5:DDYA245:DL
iaS60QBU00<HaQcW6<H00a2400@DYAS66<HLi`LDY@0348@DYAS6008HaP8D
Y@<HaP8DY@8HaP8DY@8@Q08HaP@DY@066<H@Q12448@DYAS60QBU0a2411BU
00<HaQBU5:D00Q2400<DYAS66<H031BU00<HaQBU6<H00QBU0QS60QBU0aS6
0QBU0aS60QBU00<HaQ245:D00aBU00@HaQBU5:DDY@8HaP<DY@8HaP<Q20@D
Y@8HaP8@Q00336<@Q1BU00H@Q0035:D@Q1BU00@@Q00336<@Q12400L@Q003
36<DYA24008<H`@@Q08DY@8@Q0065:DHaR487>LHaQ240PaS0a240QBU00@@
Q1BU36<@Q08<H`8@Q0@DY@0448@<H`aS36<55:D00a2436<@Q00448@236<2
48@25:D436<248@011S65:D@Q0aS0Q240QBU11240aBU0a2411BU0QS60QBU
00H<Ha2448@@Q1BU48@35:D0112436<DYA240QS60QBU1Q240QBU1Q2400<<
Ha246<H00QS60QBU0QS61ABU00<@Q1BU48@01A2400<DYA245:D0112400<D
YAS648@00PaS00<DYAS648@00Q2400LHaQBU48@@Q1BU7>LDY@0348@35:D2
48@020aS48@@Q1245:D@Q1BU48@25:D248@45:D348@00`aS48@@Q0025:D4
48@00`aS5:DDY@0248@336<248@010aS48@@Q1240PaS0Q240`aS00<@Q0aS
36<00PaS0Q2400<<Ha2448@00@aS00021240100012448@000`@Q00/000@Q
248HaRe[7>L<HaBU48@DYA2400@DY@8HaP067>LHaQBU6<HDYAS60a240aBU
00X@Q1BU6<HDY@aS48@DYAcW6<H@Q0TDY@056<HLib487>LHaP025:D27>L2
6<H65:D00aS65:D@Q0025:D011S65:DDYA240QBU0QS600@DYAS65:DDY@8H
aP8Li`<DY@036<HDYAS6008DY@076<HDYAS66<H@Q1BU48@00QBU00H@Q0aS
48@DYAcW6<H:5:D01Q246<HHaQcW6<HDY@<HaP045:D@Q1BU5:D26<H65:D0
1a245:D@Q1245:DHaQBU00<@Q0035:DHaQS6008@Q08DY@0648@DYABU5:DH
aQ240aBU00D@Q1BU7>LLiaS600<DY@036<HDYABU008DY@<HaP0648@DYABU
6<HDYAS60aBU00@@Q1BU5:D@Q08HaP@DY@@HaP8DY@036<HDYAS6008DY@03
6<HDYAS6008HaP<DY@046<HDYABU5:D26<H25:D00a245:DDY@025:D248@3
5:D011245:DDYABU11S61aBU0aS61QBU0QS60aBU00<HaQBU6<H00QBU0QS6
00@DYAS648@<H`8@Q0<DY@0348@DYA2400<DY@0548@DYAS66<HDY@0348@2
5:D011246<HHaQS61ABU00@@Q1BU5:DHaP8DY@8@Q0035:DHaQBU00<DY@03
6<HDYABU008DY@<HaP035:DHaQS6008HaP<DY@8HaPLDY@036<HDYAS600DD
Y@056<HLiacW7>LHaP035:D36<H248@236<248@00aBU48@<H`0248@45:D2
48@00`aS48@<H`0448@00`aS48@@Q00248@236<248@236<011245:DHaQ24
0PaS00@DYAS67>LHaP8@Q00536<@Q1BU48@DY@0648@236<348@011BU48@@
Q1BU1A240QBU0a240aBU0Q2400<<HaBU48@01Q2400<<Ha2448@01Q2400<D
YA2448@01Q2400<DYA2448@00aBU2A240QBU0a2400<DYAS648@00Q240aBU
0Q2400HDYA245:D@Q1BU48@25:D348@01QBU48@DYABU6<HDY@8HaP<DY@03
48@DYABU008DY@8@Q00336<@Q124008DY@D@Q0055:D@Q1245:D@Q0055:D2
36<011245:D@Q1BU0Q240QBU0Q2400@DYAS65:D<H`<@Q00436<@Q1246<H3
5:D248@00aBU48@@Q0025:D248@236<00a245:DDY@0236<448@011BU48@@
Q0aS0a240PaS0a241@aS00D@Q0aS36<<Ha2400<<H`8@Q0035:D@Q0aS0048
@P000`@Q00<000@Q124010@Q00H000Q26<HYBQcW36<25:D00a246<HDY@04
6<H01acW6<HDYABU48@DYA2400<DY@<@Q0035:DHaQBU008DY@<HaP8DY@08
48@DYAS66<H@Q1BU48@DY@@Li`8HaP035:DHaQBU008DY@0448@DYABU6<H2
5:D36<H00aBU48@HaP027>L011S65:DDYABU0QS60aBU00<HaQBU5:D011BU
0Q2400<DYAS66<H00QBU0QS600<DYA2448@00aS600D@Q1BU5:DHaQcW008H
aPDDY@046<H@Q1BU5:D36<H25:D01AS65:DHaQS65:D00Q2400<DYAcW6<H0
0Q240QS60aBU0Q2400DDYA245:DDYAS6008DY@<HaP035:D@Q12400<@Q003
5:DHaQBU00<DY@0448@DYABU5:D26<H348@011BU6<HHaQBU0Q240aBU0Q24
00DDYAS648@DYA2400HDY@036<HDYA24008DY@037>LHaQS6008HaP045:DH
aQBU5:D46<H35:D00acW6<HHaP0248@25:D36<H348@00aBU6<HHaP025:D0
0a245:DDY@025:D01QS65:DHaQS65:DHaP8DY@<HaP035:D@Q124008DY@04
48@HaQS66<H35:D46<H35:D01QS65:DHaQBU6<HDY@<HaP8DY@0348@DYABU
008DY@0448@DYAS66<H248@00aBU48@@Q00348@00aBU6<HHaP035:D01AS6
5:DDYABU6<H011BU00<@Q1S65:D00aBU00HHaQBU5:D@Q1BU48@25:D00aS6
5:DDY@026<H25:D00a245:DDY@025:D36<H00a245:DDY@036<H25:D01124
6<HHaQBU0Q2400<DYAS68@P00R4800@DYA245:DHaP@DY@8@Q0055:D@Q124
48@<H`0248@010aS48@DYA240PaS00L@Q1BU48@DYA245:D<H`0348@336<0
0a245:DDY@0348@010aS48@@Q1240PaS00@HaQcW7>LHaP8@Q0045:D@Q124
48@25:D348@336<748@35:D01A2436<<Ha245:D00PaS00<@Q1BU5:D00Q24
0PaS11240PaS0Q2400DDYA245:D@Q1BU008@Q00336<@Q124008@Q0035:D@
Q12400D@Q0046<HDYABU48@35:D236<448@00aBU48@DY@0248@01ABU48@H
aQS65:D00a241ABU00<@Q0aS5:D00QS600@@Q0aS5:DDY@<@Q0035:D@Q1BU
008@Q0045:D@Q1BU5:D548@011BU48@DYABU1a240QBU0a2400<DYA2448@0
0aBU00L<Ha2448@HaQBU48@DY@0248@35:D248@00`aS48@DY@035:D248@0
1ABU48@@Q1245:D0112400<DYA2448@00QBU00LHaQBU48@@Q0aS48@<H`02
48@01@aS48@@Q1BU48@00`aS00/@Q0aS36<8@Q245:D@Q0aS248<Ha2400H<
H`4@Q04DY@4<H`0000<48@0012400`@Q00<000@Q12400P@Q00/8@QS6:DXH
aPaS5:DLiaBU48@HaQcW00<DY@0:6<HLiaS65:DHaQBU48@DYA245:D348@0
11BU48@DYAS60QBU00HHaQBU6<H@Q1BU6<H25:D26<H25:D26<H27>L00aS6
7>LHaP025:D00a245:DDY@025:D011S65:D@Q1240aS60QBU0QcW00<HaQBU
48@00QBU00<HaQBU5:D00QS60QBU00@HaQBU6<HDY@8@Q0<HaP0548@DYAS6
6<HDY@0248@45:D011245:DDYAcW0QS600DDYA245:DDYAS600@DY@036<HL
iaS600@DY@8HaP8DY@0648@DYABU48@DYA241ABU00<@Q1BU48@011BU0aS6
0aBU0a2400@<Ha245:DDY@8@Q0<DY@0436<DYAS67>L35:D00aS65:DHaP02
5:D00a245:D@Q00348@01ABU6<HDYAS648@011BU00<@Q1BU5:D00QS60Q24
0QBU00@HaQBU5:DDY@<HaP8DY@046<HLiaS65:D26<H55:D00a245:DHaP02
6<H25:D248@00aBU6<HDY@025:D00a246<HDY@025:D26<H00aBU6<HDY@04
5:D26<H35:D02a245:DDYABU6<HDYAS65:DHaQcW6<H00aBU00<HaQBU6<H0
0QBU00@HaQBU6<HDY@8@Q0LDY@0548@DYA245:D@Q0035:D248@25:D00aS6
5:DDY@036<H35:D011S65:DHaQBU0QS63QBU00@HaQBU5:DDY@8@Q0DDY@8H
aP8DY@0648@DYAS65:DHaQBU0a2400<HaQBU5:D00Q2400DHaRDY9BTLiaBU
008@Q08DY@8@Q00736<@Q1BU48@DY@aS48@00PaS00@@Q1BU5:DHaP@@Q003
5:D@Q0aS00<@Q0<<H`@@Q08<H`T@Q0056<HLiacW6<H<H`0748@011BU48@<
H`aS1A2400@DYA2448@@Q0<DY@0348@<Ha2400<DY@0348@DYA24008@Q006
36<@Q12436<DYA2410aS1ABU00L@Q1BU48@DYA2436<@Q0025:D348@00aBU
48@@Q0035:D01A245:DDYABU48@00PaS0Q240QBU112431BU0a2400@DYAS6
6<HDY@H@Q0PDY@8@Q0<DY@<@Q0035:D@Q1BU00<@Q0035:D@Q12400<DY@<@
Q0055:D@Q1BU48@DY@0348@25:D348@011BU48@@Q1240QBU00D@Q1BU5:D@
Q1BU00<@Q0<DY@0348@<Ha2400H@Q0@DY@@@Q00336<@Q124008@Q00436<@
Q0aS248236<348@336<348@436<248@236<248@15:D136<0000300048@00
00H48@0700048@Q26<HYBQS636<00QBU0QS60QBU0QS60QcW0aBU00@HaQBU
48@<H`<DY@8@Q0065:DHaQ245:DHaQcW0QS60QBU00<@Q1BU5:D00QBU00<H
aQBU5:D00QBU0aS60QBU0QS60QBU00@@Q1BU6<HHaP8DY@8HaP047>LHaQBU
6<H25:D26<H00aBU6<HHaP026<H348@00aBU6<HDY@045:D01QS65:DHaQS6
5:D@Q08DY@036<HDYABU00@DY@0548@DYABU7>LHaP055:D248@01ABU6<HH
aQS65:D00QS600DDYA245:DDYAS600<DY@<HaP0448@DYABU6<H25:D00aS6
5:D<H`0248@011S65:DDYA240QBU00@HaQBU5:D@Q08DY@8@Q08DY@<@Q003
6<HDYABU00@DY@8@Q0035:DHaQS600@DY@0548@<Ha245:DHaP045:D448@0
11BU48@@Q1BU0a2400<DYAS66<H01AS600<DYAS66<H00acW00<HaQBU5:D0
0aS600<DYAS66<H00aBU00HHaQBU5:DHaQBU6<H45:D248@011BU6<HHaQBU
11S600DDYAS66<H@Q1BU008HaP8DY@0348@HaQS600@DY@036<HDYABU008D
Y@8HaP8DY@0748@DYABU5:DHaQBU6<H00QBU11S60aBU00<HaQBU5:D00Q24
0QBU00@@Q1BU5:DHaP<DY@037>LHaQS6008DY@056<HDYAS66<HDY@026<H4
5:D26<H011BU48@@Q1241ABU0a241aBU00<@Q1BU48@00Q2400DDYAS65:DD
YA2400DDY@@@Q08DY@067>LHaQ246<HQ21cW0Q240QS600DDY@aS36<@Q1BU
00D@Q0035:D@Q0aS00D@Q00336<@Q12400@@Q00336<@Q0aS00D@Q08<H`8@
Q08DY@<@Q08DY@8HaP065:D@Q12448@DYA240PaS0Q2400<<Ha2448@00a24
0QBU0a2400@DYA2436<<H`<@Q00436<@Q12448@25:D248@236<748@011BU
48@DYABU1Q2400@<Ha245:DDY@@@Q0<DY@0348@DYABU00@@Q0035:D@Q124
008@Q00536<@Q12448@DY@026<H248@25:D248@35:D00a2436<@Q00248@3
5:D00acW5:DDY@025:D26<H00aBU48@@Q00348@010aS48@DYABU0a2400DH
aQBU48@@Q1BU008@Q08DY@0348@DYA2400HDY@<@Q08DY@8@Q0055:D@Q124
48@DY@0448@00aBU48@@Q00236<011245:DDYABU0Q240aBU0Q2400HDYA24
5:D@Q1BU48@55:D336<248@236<348@236<448@536<01a2436<<H`aS48@<
Ha24008<H`<@Q00010@Q00<000@Q00001@@Q00LDYBU:7>L@Q1BU6<HDY@02
6<H011cW5:DHaQS60QcW00<HaQBU5:D00aBU0Q2400@<Ha246<HHaP@DY@<L
i`045:D@Q1BU5:D36<H01A245:DDYAS65:D00QS60aBU0QS600@DYA2436<@
Q08DY@DHaP8Li`8DY@0548@HaQBU6<HDY@026<H45:D011245:DHaQS60QBU
00L@Q1BU6<HHaQBU48@DY@026<H25:D26<H25:D00a245:DDY@026<H01QcW
5:D@Q1245:DHaP8@Q0055:DHaQcW7>LHaP025:D26<H35:D26<H00aBU6<HH
aP075:D01aS65:D@Q1245:DHaQBU008@Q0<DY@036<HDYA24008@Q0<DY@03
36<@Q1BU008DY@8@Q08DY@076<HDYA245:D@Q1BU48@00aBU00<HaQBU5:D0
0QBU0QS60QBU0Q240aBU0a2400@DYA2448@DY@8HaP<DY@037>LHaQS6008D
Y@@Li`8DY@036<HDYAS6008HaP085:DHaQS66<HDYA245:DHaP8DY@0448@D
YAS66<H55:D01AS67>LHaQS65:D00QS611BU0QS600@DYAS65:DHaP<DY@8H
aP045:DHaQS66<H;5:D021245:DDYAS65:DHaQBU6<H25:D00a245:DDY@03
48@36<H25:D248@01AS67>LHaQS65:D00aS611BU0aS60QcW00<HaQBU5:D0
1aBU00@HaQ2448@@Q08DY@8@Q0@DY@056<HDYA245:D@Q0035:D01QS65:D@
Q1BU48@<H`8@Q0086<H@Q1BU6<HLiaS65:DHaP8Li`036<HDYABU008DY@D@
Q00336<@Q12400<DY@0748@<H`aS48@DYA2436<01A240PaS00@8@Q245:DH
aP<@Q0035:D@Q0aS008@Q0035:D@Q124008@Q0055:DLiacW5:D@Q00236<2
48@236<548@25:D648@00aBU48@@Q00236<:48@00aBU48@<H`0548@011BU
48@DYAS60aBU00<@Q0aS36<00Q240QBU11240QBU00LHaQBU5:D@Q1BU48@<
H`0248@35:D248@010aS48@@Q1240QS61QBU0Q240QBU1A2400DDYAS67>LH
aQ2400PDY@8@Q00436<@Q1BU6<H25:D00a245:DHaP0348@01ABU48@@Q124
6<H00QBU00<@Q1BU6<H00a2400<DYAS65:D00a240QBU1A2400DDYA2448@@
Q1BU00@@Q0045:D@Q1BU48@25:D021245:DDYABU48@<Ha2436<248@25:D0
0aS65:DHaP0348@436<0112436<<H`aS0Q2400<<Ha2436<00a2430aS0Q24
0@aS0000100012448@001@@Q00T000@Q248HaRe[8@P@Q1BU7>L00aS611cW
00@HaQBU5:DDY@8HaPTDY@<HaP037>LHaQBU008DY@0448@DYAS65:D26<H2
48@25:D00aS65:DDY@0248@35:D348@25:D26<H00acW6<HHaP056<H00aBU
48@@Q0055:D00a245:DDY@046<H25:D01A245:DDYAS65:D00QS60aBU0QS6
0QBU00D@Q1S66<HHaQcW008HaP<DY@8@Q08DY@057>LDYABU5:DHaP035:D0
1QS65:DDYAS65:DHaP8DY@8@Q08DY@036<HDYAS600<DY@8@Q0<DY@8@Q0PD
Y@<@Q00336<@Q1BU008DY@8@Q08DY@036<HDYA24008@Q0076<H@Q1245:DH
aQBU48@00QBU00<HaQBU5:D00QBU0a2411BU00<@Q1BU48@00aBU00/@Q1BU
7>LLiaS648@HaR487>LHaQBU00DHaP8DY@<HaP048@PLiacW6<H25:D36<H5
5:D01QS648@DYABU6<HLi`<HaP8DY@0548@DYABU5:DHaP025:D011S65:DD
YAS60aBU0QcW00@HaQBU5:DHaP8DY@046<HLiaBU48@25:D01AS65:D@Q1BU
6<H00aBU00<HaQBU5:D011BU00@HaQBU48@DY@DHaPHDY@8HaP<DY@0548@D
YAS66<HDY@0248@00aBU7>LHaP0448@011S65:D@Q1241QBU0Q2400@DYA24
48@@Q0<DY@0348@DYAS600HDY@<@Q0PDY@8HaP048@PYBR485:D236<011S6
48@@Q0aS0Q2400<DYA2448@00PaS1A240aBU00<@Q0aS48@011240PaS00D@
Q0aS48@@Q1BU00@@Q0<DY@8@Q0045:DLiaS66<H548@01@aS48@@Q1245:D0
112400<DY@aS48@00Q2400<DYA2436<01a2400<DYA245:D01A2400HDYA24
48@@Q0aS5:D248@25:D348@01PaS48@DYABU6<H@Q08<H`0348@HaQcW008D
Y@T@Q08<H`0448@<Ha2448@35:D011S65:DDYABU0Q2400@DYAS65:D@Q08<
H`0548@DYA245:D@Q0036<H00aBU48@DY@025:D01A245:DDYAS648@00aBU
00D@Q1BU5:DHaQBU00D@Q08DY@8@Q0@DY@0348@DYABU008DY@8@Q0035:D@
Q12400<@Q0035:D@Q1BU00<@Q0065:D@Q12448@DYA240`aS1QBU00@HaQ24
36<@Q08DY@<@Q0035:D@Q12400H@Q08<H`8@Q0@<H`0348@<Ha24008<H`@@
Q00336<@Q0aS00H<H`4@Q04DY@4@Q00000<48@0012402@@Q00DLibU:5:D<
HaBU008Li`035:DHaQBU008HaP037>LHaQBU00<DY@8HaP<DY@0348@HaQBU
008HaP8DY@<HaP8DY@0448@DYABU48@55:D248@011BU7>LHaQBU0Q2400<H
aQBU48@00QBU0Q2400<DYAS67>L01aS600<DYA245:D01QBU0QS600@DYAS6
5:DHaP8DY@036<HDYAS600@DY@046<HDYAS66<H25:D248@00aBU6<HHaP02
6<H00aBU6<HDY@025:D248@26<H35:D011S67>LLiaS60Q240QBU00HHaQBU
5:DDYAS65:D26<H00aBU48@@Q0026<H248@25:D26<H011245:D@Q1240QS6
0Q240PaS0QBU112400<HaQBU5:D00a2400@DYA2448@@Q08DY@036<HDYABU
008@Q0<DY@046<HDYA245:D248@00aBU48@DY@0348@00aBU48@<H`025:D0
21S65:DDYAS67>LHaQBU6<H37>L36<H25:D36<H00aBU6<HHaP028@P00acW
6<HDY@026<H011BU6<HHaQS60QBU00@@Q1BU5:DDY@@HaP8DY@8@Q0<DY@03
6<HDYABU008DY@@HaP035:DHaQBU00LHaP045:D@Q1BU6<H25:D011245:DH
aQS60QBU00@HaQBU48@DY@8HaP035:D@Q1BU00<DY@036<HDYAS600DDY@<H
aP8DY@8HaP035:D@Q124008HaP8DY@8HaP8DY@046<HDYA2448@35:D348@2
5:D01QS648@@Q1245:D@Q0DDY@0348@DYABU008HaP035:D@Q1BU00<DY@06
48@DYA245:D@Q1BU0aS600XDYAS65:DLibDY8@PLi`aS48@DY@8@Q08<H`8@
Q0045:D@Q0aS248248@25:D236<01ABU48@@Q1245:D00Q2400<<Ha2448@0
0Q2400@8@PaS48@DY@8@Q00336<@Q1BU008DY@8@Q08Li`046<H<H`aS5:D4
48@236<35:D348@35:D448@01ABU36<<Ha245:D011240PaS00<@Q1BU5:D0
0a2400<DYA2448@00a2400<DYA2448@00QBU112400@DYA2448@@Q0<DY@04
48@DYA245:D248@236<248@25:D348@01PaS48@@Q1245:DHaP8DY@8@Q005
5:D@Q1BU48@DY@0848@01QBU6<HHaQBU48@DY@8HaP0948@DYABU5:D@Q1BU
48@DY@aS008@Q08DY@0348@<Ha24008@Q0035:D@Q1BU00<@Q0035:D@Q124
008DY@036<HDYABU00<@Q08DY@0336<@Q124008DY@8@Q0<DY@<<H`D@Q003
5:D@Q124008@Q0<DY@8@Q0035:D@Q1BU00<DY@0348@<Ha2400<@Q0085:D@
Q12436<@Q1BU48@<H`8@Q00336<8@PaS008@Q00336<@Q0aS00@@Q00436<8
@PaS36<248@236<000<48@0400048@@Q000312401P00248HaRU:6<HDY@@H
aP035:DHaQBU008HaP057>LDYABU5:DHaP025:D01A245:DHaQS65:D00QS6
1ABU00D@Q1BU5:DDYAS6008DY@056<HDYABU5:D@Q0025:D36<H25:D01QS6
5:DDYABU48@DY@8HaP035:DHaQBU008HaP037>LHaQBU00<DY@036<HDYABU
00@DY@0348@DYABU008Li`8HaP055:DHaQS66<H@Q0025:D00aS65:DDY@04
5:D011245:DDYABU0aS600DDYAS65:DHaQBU008@Q0035:D@Q1BU00<HaP<D
Y@8@Q08DY@036<HDYA2400LDY@0348@DYABU008HaPHDY@8@Q0055:D@Q1BU
5:D@Q0025:D448@35:D248@36<H021BU48@@Q1BU48@HaQBU6<H25:D01124
5:DHaQS60QBU0Q2400@DYA2436<DY@8@Q08<H`0848@DY@aS5:DHaQcW6<HD
Y@8HaP045:DHaQS67>L76<H25:D26<H35:D37>L011S65:DDYAS61ABU0QS6
0QcW11BU00<LiaS66<H01QBU00<HaQBU48@00QBU0aS600DDYAS66<HHaQBU
00@HaP065:DHaQBU5:D@Q1BU0QS611BU00<HaQBU5:D00aS60QBU00PHaQBU
48@HaQcW8@PLia240QBU0Q2400<DYAS67>L00aS60aBU0QS600<DYAS65:D0
11BU00DHaQBU5:D<Ha2400<DY@8@Q00336<@Q1BU00HDY@<@Q0046<H@Q0aS
48@36<H00a245:D@Q00248@00aBU48@DY@035:D248@01aS67>LHaQ245:DH
aR4800@HaP035:D@Q124008@Q00336<@Q124008@Q00736<@Q12436<@Q0aS
48@00aBU00<<H`Q236<00Q240PaS00@8@Q2448@@Q0D<H`0948@DYAS66<HD
YA245:D@Q1BU008HaP055:D<H`aS48@DY@0248@01AS65:DDYABU48@00aBU
00@@Q0aS36<<H`<@Q08<H`8DY@@@Q08<H`8@Q0035:D@Q12400D@Q0045:D@
Q12436<248@55:D348@25:D00aS65:DDY@0548@336<348@00`aS48@DY@03
5:D00a245:DDY@025:D448@25:D348@25:D348@55:D011S648@DYA240aS6
00DDYAS648@DYA24008DY@D@Q0035:D@Q1BU00<@Q0035:D@Q124008<H`8@
Q0065:D@Q1245:DHaQ240`aS00<DYAS65:D00a2400<DY@aS36<01A240`aS
0Q2400<DYA2448@01Q2400<DYAS65:D00QBU0Q2410aS0Q2400<DYA2448@0
0QBU00@@Q0aS36<@Q0D<H`0348@<H`Q200@<H`88@P0336<@Q124004@Q000
00<000@Q00000P@Q00@000@Q124000<48@065:DU:AS648@DYAS60aBU00<L
iaS65:D00QBU00<HaQBU6<H01QBU11S60aBU00<HaQBU6<H0112400<HaQcW
6<H00QBU00<<HaBU5:D00QS60QBU00<LiaS65:D00Q2400@DYAS66<HHaP<D
Y@086<HDYAcW7>LHaQBU48@<H`8DY@8HaP045:D@Q12448@35:D36<H01124
5:DHaQS60aBU0QS60aBU00@HaQBU5:DHaP<DY@036<HDYAS6008DY@036<H@
Q1BU00<@Q0045:DHaQcW6<H25:D248@011BU6<HDYABU0Q2400<HaQBU5:D0
0aBU00<HaQBU5:D01ABU0Q240QS600HDYA2436<@Q1BU48@25:D448@01ABU
48@@Q1245:D00a240QS600@DY@aS48@@Q08DY@8HaP8@Q0<DY@<@Q0<DY@<@
Q0035:D@Q12400<@Q08DY@036<HLiaS6008HaP035:DHaQS600<HaP035:DH
aQBU00LHaP8@Q0046<HQ22486<H25:D01AS65:DHaQcW6<H00aBU00<HaQBU
6<H01QS60aBU00@@Q1BU5:DHaP<DY@8@Q0045:DLiacW7>L35:D00acW6<HH
aP085:D00aS65:DDY@026<H25:D46<H55:D01A245:DLib486<H00Q240QBU
0Q2400@DYAcW7>LHaP<DY@036<HDYA2400HDY@8HaPDDY@036<HDYA24008@
Q0@DY@8HaP035:D@Q12400LDY@056<HDYABU5:D@Q0025:D00`aS48@DY@02
6<H00aBU48@@Q0035:D02Q246<HLib486<H@Q1BU6<HDYA240PaS00<@Q1BU
48@00`aS1a240aBU00<@Q0aS36<011241@aS0Q2400<DYA2448@00a2400@D
YA2448@DY@<HaP8DY@0436<@Q12448@25:D26<H00aBU48@@Q0025:D00a24
36<@Q0025:D01Q2436<@Q1BU48@<H`8@Q08DY@<<H`<DY@8@Q0035:D@Q124
00X@Q0035:DHaQ2400<@Q0<HaP8DY@<@Q0<<H`0=48@<Ha2448@DYA2436<@
Q1BU6<H@Q1BU6<H00a2400<DYAS65:D00Q2400<DYA2448@00Q240QBU00d@
Q0aS48@DYAS67>LHaQ2436<@Q1S67>LHaP035:D348@35:D;48@00`aS48@@
Q0025:D648@00aBU48@<H`0248@25:D248@00`aS48@@Q00348@436<448@0
0aBU48@@Q00336<248@36<H011BU48@@Q0aS0a2400<<Ha2448@00aBU00H@
Q0aS48@@Q0aS248236<01A2436<@Q0aS48@010aS0`Q20a240@aS00041240
0`0012448@0412401@Q25:D]JacW48@00QBU00<@Q1BU5:D00aS60aBU00<H
aQBU5:D011BU00<HaQBU6<H00QBU00<HaQcW6<H00aBU0aS60QBU0QS600<D
YAS65:D00aBU0QS600<LiaS65:D00QS60aBU0QS600LDYAS67>LLiaBU48@H
aP027>L25:D348@25:D26<H348@00aBU6<HDY@026<H55:D011S65:D@Q124
0QBU0QS60a2400PDYAS66<HDYAS67>LHaQBU0Q2400HDYA2448@@Q1BU6<H3
5:D01A245:DDYABU48@011BU00DHaQBU5:DDYA2400@DY@<HaP045:D@Q1BU
6<H27>L00aBU48@@Q00348@011BU48@DY@aS0a240QBU00DHaQBU48@DYA24
00<DY@8HaP0348@DYABU008DY@0548@<Ha2448@DY@0348@25:D348@011BU
48@@Q1240aBU00THaQcW6<HDYA245:DHaQBU6<H011cW0aBU00<HaQcW7>L0
0QS60QBU00<HaQBU6<H00QS600<DYAS66<H00QcW00@HaQBU5:DDY@@HaP8D
Y@8HaP<DY@<HaP<DY@8HaP8DY@8HaP037>LDYABU008HaP<DY@@HaP8DY@03
48@DYAS600@DY@086<HDYABU5:DHaQBU48@DY@<HaP<@Q0@DY@8HaP@DY@03
6<HQ21S600<DY@036<HLiaS600@DY@056<H@Q1BU6<HDY@0248@01QBU6<HD
YABU48@DY@8@Q0045:DHaQS65:D348@00aBU6<HDY@0248@01ABU48@DYABU
6<H00QBU00<@Q1BU48@00Q240QBU00H@Q1BU6<HLiaS65:D248@65:D36<H0
0aBU48@<H`0448@00`aS48@@Q0025:D448@011BU48@@Q1240PaS00H@Q0aS
2488@PaS48@336<248@236<01A245:DHaQ245:D00Q240aS600@LiaS65:D@
Q08<H`055:DHaQS65:D@Q0025:D248@00`aS48@@Q00748@01QBU48@@Q0aS
48@<H`8@Q08DY@0336<@Q124008DY@8<Ha0@Q0055:DHaQS648@<H`0248@0
0`aS48@DY@0348@236<248@01@aS48@@Q1BU6<H00QBU0Q2400<DYAS66<H0
0a240aBU00@<Ha245:DDY@<@Q08DY@037>LHaQBU00<HaP0348@DYAS6008D
Y@8<H`0448@<H`aS36<348@01ABU48@@Q0aS48@00QBU0a240aBU0Q2400@<
Ha2448@<H`8@Q0045:D@Q12436<348@236<00a2436<@Q00248@00`aS48@@
Q00248@236<348@00`aS48@@Q00248@35:D348@00`aS48@@Q00248@010aS
48@DYAS60aBU00@@Q0aS36<<H`<@Q0<<H`0648@<H`aS248<H`Q20`aS0A24
0@aS000010@Q00048@001@@Q00T000@Q124HaRDY6<H@Q1S65:D00Q240QBU
00<LiaS65:D011BU00<HaQ2448@00aBU00<HaQBU6<H00aS60QBU00@@Q1BU
6<HHaP@DY@8HaP8DY@0348@DYAS6008HaP8DY@8Li`8HaP055:D@Q1BU48@D
Y@036<H25:D36<H01Q2436<DYA245:DHaP8DY@0348@DYABU008DY@0348@D
YABU008HaPDDY@096<HDYA245:DHaQcW6<HDYA2400DDY@<HaP035:D@Q124
00@@Q0045:D@Q1BU48@55:D01A245:DDYA246<H00QBU00H@Q1BU48@@Q1BU
48@65:D46<H00aBU48@<H`0248@01ABU48@DYA245:D00a2411BU00@@Q1BU
6<HHaP<DY@056<HDYA245:DHaP025:D248@25:D248@00`aS48@@Q00248@2
5:D248@35:D011245:DLiacW0aBU11S600<Q21cW6<H00QBU0aS600@LiaS6
6<HHaP@DY@<HaP8DY@037>LHaQBU008DY@046<HDYABU5:D36<H25:D26<H5
5:D26<H25:D011245:DDYABU0QcW0QS600<@Q1BU5:D00QS600<DYA245:D0
0QS60QBU0QS600@DYA245:DHaP<DY@046<HDYA245:D26<H00aBU48@@Q002
5:D011S65:DDYA2411BU00@@Q1cW7>LLi`8DY@036<HLiaS6008DY@HHaPDD
Y@036<HDYABU00<DY@056<HDYA245:DHaP025:D00a245:DDY@025:D236<0
1ABU6<HHaPaS48@00QBU0a240aBU00<@Q0aS5:D00QS600<DYA245:D00QBU
0QS600<DYAcW7>L00QS6112410aS312410aS00@8@PaS36<@Q08<H`@@Q003
36<@Q1BU008DY@<@Q08DY@8HaP<DY@8@Q0HDY@8@Q00336<@Q12400@@Q08D
Y@8@Q00336<@Q12400<@Q00336<@Q0aS00<@Q0045:D@Q12436<248@010aS
48@@Q1BU0a2400<DYA2448@00PaS0Q2400<DYAS65:D01A2400<<Ha2448@0
0QBU0a2400D<Ha245:D@Q1BU008@Q0056<HDYABU48@HaP035:D848@25:D3
48@26<H45:D00acW6<HDY@035:D01Q2436<<Ha245:D@Q0<<H`<@Q00736<@
Q1245:D@Q1BU48@00QBU00<@Q1BU48@00Q240PaS00@@Q1BU6<HDY@<@Q08D
Y@8@Q08<H`045:D@Q1BU5:D748@01`aS48@DYA245:D<Ha2400<DY@H@Q08<
H`0448@DYABU5:D548@<36<00`Q236<8@P0436<0000300048@@Q00848@03
00048@@Q00@48@055:DYBQS648@DY@026<H25:D36<H01ABU48@DYABU7>L0
0QS600<DYA245:D00aS600<@Q1BU5:D00QS600@DYAS65:DHaP8DY@@HaP06
5:DLiaS66<HLiaS60aBU00<@Q1BU5:D01aBU0QS61aBU00<@Q0aS5:D00QBU
0Q2400@DYAS65:D@Q0@DY@0648@HaQS66<HDYA240aBU0Q240QS600<DYA24
48@00QBU1AS600D@Q1BU48@@Q1BU008HaP<@Q08DY@0448@DYA2448@55:D0
0a245:DHaP025:D00a245:DDY@025:D248@25:D348@26<H011BU48@@Q0aS
112400HDYA2448@@Q1BU6<H25:D01A245:DHaQS65:D00Q240QBU00@@Q1BU
48@DY@<@Q08DY@036<H@Q124008@Q08DY@8@Q0035:D@Q124008DY@036<HD
YABU00<HaP8DY@8HaP8Li`046<HLiacW6<H25:D00aS67>LLi`046<H25:D0
1QS65:DDYABU6<HLi`<HaP@DY@<HaP8DY@036<HLiaS600<DY@037>LHaQBU
008DY@8HaP055:D@Q1BU6<HLi`046<H25:D01QS65:DHaQBU6<HDY@8HaP09
5:D@Q1S67>LHaQBU48@DYAS6008DY@0448@DYABU5:D26<H35:D00a246<HD
Y@035:D00a246<HHaP035:D46<H00aBU6<HDY@025:D36<H35:D248@25:D0
0aS65:DDY@036<H25:D26<H65:D248@25:D348@25:D011245:DDYA241aBU
00@@Q1S65:DDY@<@Q0035:D@Q1BU008DY@8@Q0035:DLiaS600<@Q08DY@06
48@<H`aS48@HaQBU11240`aS00<@Q0aS36<01A2400HDYA2436<<Ha245:D3
48@35:D021245:D@Q1245:DHaQcW8@P26<H236<011BU7>LLiaS60Q240QBU
00<@Q0aS24800a2400HDYA2436<@Q0aS5:D548@236<00a2436<<H`0348@2
36<348@00`aS48@@Q00748@00`aS48@DY@026<H00aBU48@@Q0065:D00a24
36<<H`0248@35:D00a245:DDY@045:D00aS65:D@Q00648@00aBU6<HHaP03
5:D00aS65:DDY@046<H35:D011245:DDYA240PaS00<@Q1S648@00PaS00<@
Q1BU5:D01A2400<DYA245:D01Q240`aS00<@Q0aS48@00QBU00<@Q0aS36<0
0Q2400<<Ha245:D00Q2400<<Ha245:D01a240PaS0a2400@DYAS65:DDY@8@
Q0055:D@Q1BU5:D@Q00436<01a245:DDYABU48@DYA24008<H`8@Q0<<H`04
48@<H`aS248336<248@136<1248000@48@0300048@@Q00848@0900048@@Q
5:DU:ABU48@HaQcW008DY@@HaP035:DHaQS6008DY@8HaP065:D@Q1S66<HD
YA240QBU11S600@DYAS65:DDY@<HaP045:DHaQcW7>L26<H011BU7>LLiaS6
0aBU0QS600DDYA245:DDYAS600<DY@8HaPDDY@0348@DYA24008DY@0348@D
YABU00LDY@<HaP8@Q0<HaP8@Q08HaP047>LHaQBU48@45:D011S65:DDYABU
0Q2400<DYA245:D00Q241ABU00<<Ha245:D011BU00<@Q1BU48@011BU0Q24
00<DYA245:D011BU00<@Q1BU5:D00aBU1Q240QBU11240QBU00<@Q1BU48@0
11BU0Q2400@DYA245:DDY@8@Q0@DY@@@Q0055:D@Q1BU48@DY@0248@35:D0
2Q246<HLiacW5:D@Q1BU6<HLiaS60QcW00@HaQcW7>LHaP8DY@8HaP047>LH
aQBU5:D36<H00aBU6<HHaP026<H011BU6<HHaQS60aBU0QS600<LiaS65:D0
0aS60QBU0QS611BU0QS600<DYA245:D00QcW00@HaQBU6<HHaPDDY@036<HD
YAS6008DY@<HaP045:DHaQBU5:D36<H00aBU48@DY@025:D348@25:D011S6
48@DYABU0Q2400<DYAS65:D00aBU0aS600<DYAS65:D00QS600HDYAS65:DH
aQBU48@75:D00aS65:DDY@0248@011S67>LHaQBU0Q240QBU00D@Q1BU5:DD
YAS600<@Q0<DY@0348@DYABU00LDY@036<HDYABU008@Q0045:D@Q1BU5:D2
48@011BU48@DYAcW0QS600<DY@aS48@0112400@<Ha2448@DY@8@Q0<<H`04
5:D@Q0aS48@236<01A2436<@Q1245:D00Q240PaS00H@Q0aS5:D@Q1BU48@2
5:D248@25:D01aS68@PLiacW6<H<Ha24008DY@056<HDY@aS48@DY@0336<2
48@00aBU48@@Q00336<248@00aBU48@@Q00348@436<448@236<448@00aBU
48@<H`0248@01QBU48@@Q0aS5:D@Q08DY@8@Q0075:D@Q0aS48@DYAS65:D0
10aS0aBU00@@Q1BU48@<H`8@Q0036<HDYA24008DY@0748@<Ha245:D@Q0aS
48@011BU00<@Q1BU5:D00aS600<DYAS65:D00aBU212400<<Ha2448@00PaS
0Q2400DDYA2448@@Q1BU00<@Q0055:D@Q12436<@Q00236<248@00aBU48@<
H`0548@01@aS48@@Q12436<00Q240QBU1A2400<<H`Q248@00QBU00L@Q0aS
36<DYAS65:D@Q00236<00aBU48@@Q00848@00aBU48@DY@0248@736<01A24
36<<H`Q236<00a240@aS00000`@Q00048@0212400`0012448@0412401aBU
:DXQ21BU7>LHaQBU008HaP<Li`<HaP0;7>LHaQBU5:DHaQcW6<H@Q1BU6<HD
Y@046<H57>L011S67>LLiacW1QS62QBU00@@Q1BU5:DDY@<HaP8DY@@HaP@D
Y@8@Q08DY@036<HDYABU00<DY@8HaP8DY@8HaP@DY@0548@DYAcW7>LHaP03
5:D011S67>LHaQBU1Q2400@DYAS65:DDY@8@Q0055:D@Q1245:DHaP0248@0
10aS48@HaQS60QBU00<@Q1BU5:D00QBU0Q2400<DYA245:D011BU0a240QBU
0Q240QBU0Q2400<DYAS65:D00Q2400@HaQBU5:DHaP8DY@0548@DYA245:D@
Q0035:D00a2436<@Q0025:D011245:DHaQS60QBU0QS600<DYA245:D00QBU
0Q240QS60aBU0QS60QBU00HHaQBU6<HHaQcW6<H25:D36<H35:D00a245:DD
Y@036<H45:D26<H25:D01AS65:DHaQS67>L00QS600@DYAS66<HHaP8Li`8H
aP0448@DYABU5:D36<H25:D011S65:DHaQcW0aS60QcW0aBU1AS611BU1AS6
41BU0aS60aBU0QS60aBU00<LiaS66<H00QBU00D@Q1BU5:DDYAS600HDY@08
6<HDYAS66<HDYAS65:DHaP8DY@8HaP045:D@Q12448@26<H25:D00a245:D@
Q0025:D00a245:DDY@035:D00a245:D@Q00248@00aBU48@DY@035:D348@4
5:D248@25:D27>L25:D248@00aBU48@DY@0248@236<348@01QBU48@<Ha24
36<@Q08<H`<@Q08<H`<@Q08<H`0548@DYA245:D@Q0025:D248@25:D37>L0
0aBU48@DY@025:D448@236<448@236<248@011BU48@<H`aS11240PaS1A24
00@<Ha2448@@Q08<H`8@Q08DY@L@Q0055:D@Q12448@<H`0248@00aBU48@@
Q00236<01ABU48@@Q1245:D00a2400<DYA2448@00a240QBU0a2400<DYA24
48@00aBU00<@Q1BU5:D02ABU00<HaQBU5:D00aBU00<@Q0aS48@00aBU00<@
Q0Q236<00Q2400@DYA2448@@Q0<DY@0448@DYABU48@25:D648@01@aS48@@
Q0aS5:D01Q2410aS112400@DYA2448@<H`@@Q0<DY@0348@DYABU008@Q004
5:D@Q1BU5:D248@00aBU48@@Q00336<00a245:D@Q00336<00a2436<<H`02
36<00a2436<<H`0336<00a245:DDY@0136<0000400048@@Q000812401aBU
:DXLiaBU6<HLiaS600<Li`8HaP095:D@Q1cW7>LHaQBU48@DYAcW00@DY@03
6<HLiaS6008HaPDLi`068@PLiaS67>LHaQcW11S61QBU00D@Q1BU48@@Q1BU
008HaP055:DHaQBU5:DHaP0;5:D00a245:DDY@065:D00aS65:DDY@025:D2
6<H011BU48@DYABU0aS60QBU11S60aBU112400<DYA2448@00aBU00@@Q1BU
5:DDY@D@Q0045:DHaQcW5:D248@00aS648@@Q00248@25:D248@011BU48@D
YABU2Q2400@HaQBU36<@Q0<HaP075:D@Q1S65:D@Q1BU6<H00QBU00<<HaBU
6<H00Q2400@<Ha245:DDY@8HaP<DY@0348@DYABU00<DY@8@Q0<HaP035:D@
Q124008DY@036<HDYAS6008HaP037>LHaQS6008HaP035:DHaQBU008HaP06
5:DHaQBU5:DHaQBU0QS60aBU00HHaQBU5:DDYA245:D66<H011BU6<HLiacW
1AS611BU00<HaQBU5:D00QBU0QcW0QS611BU00<LiaBU5:D00QBU0QS60aBU
00<HaQcW6<H00aS60QBU00<@Q1BU6<H00QBU00D@Q1BU48@DYA24008DY@04
48@DYABU5:D26<H25:D36<H35:D26<H35:D00aS65:DDY@025:D01a245:DD
YA245:D@Q1BU00<HaP8DY@8HaP065:D@Q1BU6<HDYA2411BU00<@Q1BU48@0
1ABU00<@Q1BU5:D00QBU00@@Q1BU48@DY@8@Q0035:D@Q1BU00<@Q0055:D@
Q1BU48@DY@0248@01aBU6<HHaQS65:DHaQBU00D@Q00536<@Q12448@<H`03
48@236<00a245:D@Q00236<248@00`aS48@@Q00248@236<248@35:D348@2
5:D01Q247>LQ21S65:D@Q08DY@8@Q00336<@Q124008@Q00536<@Q1245:D<
H`0248@00aBU48@<H`0248@336<348@00`aS48@@Q00848@236<548@010aS
48@@Q1BU0QS600@DYA2436<<H`<DY@@@Q00436<@Q12448@25:D00aS65:D<
H`0248@00aBU6<HHaP0348@01ABU48@@Q0aS48@00aBU0Q2400LDYA2448@@
Q1BU6<HDY@026<H35:D01A245:DDYABU48@00PaS0Q2400<<Ha2436<00a24
00@DYA2448@@Q0<DY@8@Q0035:D@Q12400X@Q08<H`8@Q0035:D@Q12400@<
H`<@Q0035:D@Q124008@Q08<H`@@Q0<DY@0448@DYABU48@25:D348@010aS
48@@Q0aS21242PaS0a240@aS0@Q2000212401@0012448@@Q00000`@Q00P0
00Q25:DYBQcW48@DYAcW0QS60QcW1AS60acW1QS600@Lib487>LLi`<HaP04
7>LHaQS65:D26<H27>L00aS65:DHaP055:D00a246<HHaP025:D248@011BU
48@@Q1BU0QS600<LiaS648@00QBU0QS600DDYAS66<HDYAS6008@Q0095:DH
aQS65:D@Q1BU6<HDYAS6008Li`046<HDYABU6<H35:D01A246<HHaQS65:D0
0Q2400@HaQBU5:DHaP8Li`DHaP8@Q08<H`XDY@8@Q0035:DHaQBU00<@Q003
5:D@Q124008DY@<@Q0035:DHaQBU008DY@0348@DYA2400DDY@046<HDYA24
5:D248@00aBU48@DY@055:D26<H25:D348@45:D26<H00aBU6<HDY@036<H2
5:D011245:DDYAS61ABU00H@Q1BU5:DLiaS65:D26<H011BU6<HHaQS60aBU
0QS600DDYA2448@HaQBU00DHaP035:DHaQBU008HaP035:DHaQBU00<HaP03
7>LHaQS6008HaP8Li`036<HDYAS600<HaP035:DHaQS600@DY@036<HDYABU
008DY@047>LHaQS66<H45:D00aS65:DHaP025:D56<H01A245:DDYAS65:D0
0Q240aBU00@@Q1BU5:DHaP8DY@056<HDYAS66<HDY@036<H01Q245:DDYAcW
6<HDY@8HaP8DY@0448@DYABU6<H45:D00aS67>LHaP045:D27>L01aS648@@
Q1BU7>LHaQBU008HaP0348@DYABU00<DY@8@Q08DY@036<HDYABU00@@Q003
5:D@Q12400@@Q0@DY@046<HDYABU48@35:D348@95:D248@25:D248@010aS
48@DYABU0Q2410aS0Q240PaS00@@Q1BU48@@Q08DY@D@Q0<DY@<@Q0035:DL
iacW00<DY@0448@DYA2436<948@010aS48@DYABU112400HDYA245:D<Ha24
5:D248@224800`aS48@@Q00236<011245:DHaQBU0a2400D<Ha245:DHaQBU
00<@Q0@DY@8@Q08<H`8@Q0045:D@Q12448@25:D01A245:D@Q1BU6<H00aBU
00<@Q1BU48@00QBU00<@Q1BU5:D01ABU0a2400<HaQ245:D011S60aBU00<H
aQ2448@00PaS00<@Q0aS36<00PaS00@@Q0aS48@@Q08DY@@@Q0035:D@Q124
00@@Q08DY@H@Q0035:D@Q124008<H`8@Q0035:D<Ha24008@Q08<H`0348@D
YABU008<H`8@Q08<H`0348@DYA2400<DY@<@Q0045:D@Q12436<248@236<4
48@00`aS48@<H`0236<248@00`aS48@@Q0025:D336<248@15:D148@136<0
0005124000@Q124000031240200012448@@Q5:DU:AS65:D26<H37>L01QS6
7>LLiaS65:DHaP8Li`8HaP<DY@<HaP087>LU:AcW6<HDYAcW8@PLi`<DY@04
6<HLiacW7>L36<H45:D011S65:DDYABU0a240QS60aBU0QS60Q240QBU00@H
aQBU5:DDY@8HaP035:D@Q1BU00HDY@@HaP047>LHaQBU5:D26<H45:D011S6
5:DDYA240aBU11S600<LiaS65:D00QBU00LHaQBU48@@Q1BU48@DY@0548@0
11BU48@<Ha240QS600PDYA2436<DYA2436<@Q1BU11241ABU00<@Q1BU5:D0
0QBU00D@Q1BU48@DYAS600<DY@0448@DYABU6<H25:D00aS65:DDY@0248@3
5:D00a245:DDY@0348@00aBU6<HHaP026<H01ABU6<HDYAS65:D00Q2400@D
YAS66<HHaP@DY@0348@DYABU008HaP8DY@<HaP035:DHaQBU008HaP8DY@8@
Q08DY@036<HDYABU00<DY@0348@DYABU008HaP8DY@<HaP065:DHaQS65:DH
aQcW0QS600DDYAS66<HHaQBU008HaP0448@DYABU5:D26<H35:D46<H02124
6<HDYABU6<HDYAS65:D36<H011cW5:DDYA241QBU0aS611BU0Q2400LDYAS6
5:DHaQBU6<HDY@0248@25:D36<H01ABU48@DYABU6<H00aBU00D@Q1BU5:DD
YA2400<DY@036<HDYABU008DY@046<HDYABU5:D36<H65:D36<H348@55:D0
0aS648@@Q00348@236<01Q245:DHaQS65:D@Q0DDY@036<H@Q12400<DY@07
36<@Q1BU6<HLiaS65:D02A2400@DYA2448@@Q0@<H`045:D<H`aS36<25:D0
1A2436<@Q1245:D0112400/<Ha245:D@Q0aS5:DHaQcW6<H@Q1BU008@Q007
36<@Q1BU48@<Ha2436<01a240aBU0Q2400<DYA2436<00Q240QBU0PaS00<@
Q0aS48@00Q2400<<H`Q248@00QBU00<@Q0aS5:D01A2400@DYA2436<@Q0<D
Y@8@Q0035:D@Q0aS008@Q08DY@<@Q0035:D@Q12400DDY@8@Q0<DY@8@Q006
5:DHaQBU5:D@Q1BU11240QBU11S60QBU00@HaQBU5:D@Q08<H`0548@DYA24
48@<H`0248@011BU48@@Q0aS0aBU0a2400<<Ha245:D00QBU0a2400@DYA24
48@DY@<@Q00336<@Q12400<DY@<@Q00336<@Q0aS00d@Q0035:D@Q1BU00L@
Q00436<@Q12436<348@010aS48@@Q1241@aS00@@Q0aS5:DDY@8@Q08<H`<@
Q04<H`0000<000@Q12400P@Q00<000@Q124010@Q00@DYBU:8@PDY@8HaP03
7>LQ21cW00<Q20HLi`046<HLiacW6<H25:D36<H25:D248@<5:D00aS65:D@
Q00248@35:D00a245:DDY@045:D011S65:DHaQS60aBU00@HaQcW6<HDY@8@
Q08HaP035:DHaQS6008Li`8HaP065:DHaQcW6<HDYA240QBU0QS600<LiaBU
6<H00aBU0Q240QBU00@HaQBU5:D@Q08DY@8HaP8DY@0448@DYAS65:D248@2
5:D02Q245:DHaQcW6<HDYA245:D@Q1BU0Q2400@DYA2448@<H`8@Q08DY@@@
Q0045:DHaQBU5:D248@011BU6<HDYA241aBU0a2411BU0Q240QS60QBU0Q24
00<DYAS66<H00QBU00<@Q1S65:D011S600DLiaS66<HDYA2400<DY@047>LH
aQBU5:D248@55:D011S65:DHaQBU0Q240QBU00<LiaS65:D011BU0QS61QBU
0Q2400<DYAS66<H00QcW00<Q21cW6<H00QBU00<HaQcW6<H00aS600HDYAcW
6<HDYAS65:D36<H00aBU6<HHaP046<H25:D00a246<HHaP045:D00aS65:DH
aP066<H25:D011245:DDYAS60QcW11BU00@HaQBU6<HLi`8HaP8DY@8HaP04
5:DHaQBU5:D248@26<H45:D011S65:DDYAS60aBU00<HaQcW5:D00QBU00<H
aQcW5:D011BU00<HaQ2448@00QS60Q2400<DYAS65:D00aBU00<HaQBU5:D0
0Q2400DDYA2448@@Q0aS00D@Q0035:D@Q1BU00HDY@8@Q0035:D@Q124008D
Y@<@Q0036<HDYA24008@Q08DY@@@Q08DY@0448@DYA245:D348@236<248@0
11BU48@@Q0aS0Q241PaS00@@Q1BU6<HDY@8@Q08DY@0<6<HDYABU6<HDYAS6
48@DY@aS48@<Ha240QBU00@@Q1BU48@<H`8@Q0035:DHaQBU008<H`0348@D
YABU00<@Q0075:D@Q12448@<Ha245:D00Q2400<<HaBU5:D00a2400<DYA24
48@00Q2400<<Ha245:D00QBU00@@Q1BU5:DDY@@@Q0@DY@H@Q0<DY@<HaP<@
Q08DY@8HaP045:D@Q12448@25:D00a245:D@Q0035:D00acW6<HDY@025:D0
0aS65:D@Q00448@00`aS48@@Q00548@011BU48@DYABU0Q240PaS00<@Q1BU
5:D00a240aBU112400<<Ha2448@00a240PaS00@@Q0aS36<<H`@@Q0<<H`03
5:D@Q124008<H`<@Q0045:D@Q12448@35:D548@25:D248@00aBU36<@Q002
48@01PaS48@<H`aS48@DY@8@Q08<H`@@Q04<H`48@P000P@Q00<000@Q0000
10@Q00L000@Q124DYBe[8@PDY@027>L00aS67>LLi`048@P00acW6<HLi`02
6<H01AcW8@PLib486<H00QBU0aS60QBU00D@Q1BU5:DDYA24008DY@036<HD
YA2400<HaP045:D@Q1BU5:D248@55:D00aS65:DDY@025:D26<H01aBU6<HD
YA246<HLiaS600<DY@<HaP8DY@<HaP8DY@036<HLiaBU008DY@8HaP8DY@05
48@DYABU5:DHaP0448@00acW6<HDY@055:D021cW5:D@Q1245:DHaQBU48@3
5:D00a246<HHaP026<H01a245:D@Q1245:D@Q1BU00<@Q08DY@8@Q08DY@8@
Q0035:DHaQS6008DY@0548@DYABU5:D@Q0055:D01aS65:DDYA2436<@Q1BU
008HaP8@Q08DY@036<HDYABU008DY@8@Q0095:DHaQBU6<HDYAS65:DHaQBU
008HaP035:DHaQS600<DY@8HaP047>LHaQBU48@55:D36<H01ABU6<HDYA24
6<H00QcW00<DYA2448@00aBU00<@Q1BU5:D00QS61aBU00<Lib487>L00QcW
00<HaQBU6<H00QS600DLiaS66<HHaQcW00<HaP0348@DYAS600<HaP0348@D
YAS600THaP035:D@Q1S6008DY@056<HDYAS65:DHaP035:D01AS65:D@Q124
5:D011S611BU00PHaQcW7>LHaQBU48@DYAS60QBU0aS600<DYA245:D00aS6
00DDYA2448@HaQBU008HaP035:DHaQBU00<DY@8HaP057>LHaQBU5:DHaP02
5:D248@45:D011S65:D@Q1240QBU00<HaQBU5:D011BU1A240aBU00<<Ha24
5:D00QS600<@Q1BU48@00QBU1Q240aBU00@@Q1BU48@DY@8@Q08DY@036<HD
YABU00<DY@<@Q0<<H`<@Q00336<@Q0aS00<<H`0348@<Ha24008@Q00;36<@
Q12448@DYA245:D@Q1BU48@DY@036<H25:D348@010aS48@@Q1240QBU00<@
Q1BU5:D00Q2400<<Ha2448@00a240aBU0a2400<DYA2436<00a2400<<Ha24
48@00QBU00D@Q1BU48@DYA24008DY@0348@<Ha24008DY@0348@DYA24008D
Y@8@Q00336<DYAS6008DY@8@Q0@DY@8@Q0035:DHaQS6008DY@0536<@Q124
5:DHaP055:D01A245:DDYA245:D00Q240aS60QBU0aS61Q2400HDY@aS248<
Ha245:D248@00aBU6<HDY@0248@011BU48@@Q1240QBU00<@Q0aS48@011BU
00@@Q0Q236<<H`8DY@<<H`035:D@Q12400<<H`8@Q0035:D@Q12400<@Q003
36<@Q124008@Q00336<@Q1BU008<H`0548@HaQBU48@<H`0248@011BU48@@
Q0aS212410aS00@@Q1BU48@DY@@@Q04<H`48@P001P@Q00<000@Q12400P@Q
00D8@QS6<H`U:ABU008Li`8HaP047>LQ21cW7>L46<H00acW6<HDY@036<H0
0acW5:DDY@025:D00aS65:DDY@025:D26<H011BU48@DYABU0QS600HDYAS6
5:DDYAS65:D448@25:D011245:DDYABU0QS600<LiaS65:D00Q240QS61ABU
11S600@DYA245:DHaP8Li`8HaP8DY@8@Q08DY@HHaP8DY@0348@DYABU008D
Y@066<H@Q1BU5:D@Q1S60aBU00<@Q1BU5:D00aBU00<HaQ2448@00Q2400<H
aQBU5:D00aBU0a240aBU0Q240QBU0Q2400<DYAS65:D00Q2400<DYA245:D0
0QBU00HHaQBU6<HHaQBU6<H35:D00a245:DDY@045:D00aS65:DHaP036<H0
0acW6<HDY@036<H25:D248@35:D011S67>LLiaS60QBU0QS600DLiaS67>LL
iaBU008@Q0035:DLiaS600<HaP8Li`046<H@Q1BU6<H25:D248@25:D26<H4
5:D36<H45:D46<H37>L26<H011BU6<HHaQBU11S600<DYAS66<H01AS600@D
YAS65:DDY@<HaP<DY@066<HLiaS65:DHaQBU0QS60Q2400@DYAS66<HHaPDD
Y@8HaP037>LDYABU008HaP037>LHaQcW00@Li`@HaP8DY@8HaP8DY@036<HL
iaBU008@Q0035:DHaQS600<DY@056<HLiacW6<HDY@046<H35:D00aS65:DH
aP035:D00aS648@DY@025:D26<H448@00aBU48@@Q00248@25:D01A245:D@
Q1245:D00Q2400<DYA2448@00QBU00HHaQ245:DDYAS65:D248@35:D348@0
11BU48@DYA240QBU112400<DYA245:D00a2400D<Ha2448@@Q1BU00H@Q0D<
H`0348@DYABU008@Q0<DY@0448@DYA245:D248@011BU6<HHaQS6112400L<
HaBU6<HDYA2436<@Q0025:D248@00`aS48@@Q00448@25:D448@35:D348@2
5:D00a245:D@Q00348@336<01ABU48@DYABU6<H00QBU0Q2400@DYA245:DD
Y@8HaP<DY@@@Q08DY@<HaP045:D@Q1BU5:D36<H00aBU48@HaP025:D01124
5:DDYABU0Q240QBU00<HaQBU48@00Q2400HHaQcW6<HDYA2436<25:D01A24
5:D@Q1BU48@011BU00@@Q1BU5:DDY@D@Q0035:D@Q12400<@Q0<DY@<@Q003
5:D@Q0aS00@@Q00336<@Q0aS00<<H`@@Q00336<@Q124008@Q00336<@Q124
00D@Q0@DY@0348@DYA2400<DY@8@Q00336<@Q124008@Q0<<H`<@Q00636<@
Q1245:DHaQBU0Q240@aS00001P@Q00048@00124000@48@060008@QS6=JdU
:ABU0aS60acW00<Q21cW6<H00QcW00<HaQcW6<H01aS621BU11240QS61QBU
00<@Q1BU5:D00QBU0Q2400LDYA245:DDYAS67>LHaP045:D00aS65:DHaP02
5:D00a245:DDY@035:D01aS65:DHaQS65:DHaQBU008HaP8DY@0348@DYAS6
008HaP8DY@8HaP035:D@Q12400LDY@0348@DYABU00<DY@8@Q08DY@036<HD
YABU00DDY@8HaP8@Q0045:DHaQBU36<248@00aBU48@@Q0025:D00aS648@@
Q00236<35:D00a2436<@Q0026<H45:D248@45:D01A245:DDYABU6<H00QBU
00L@Q1BU7>LLiaS648@DY@056<H45:D011S65:DHaQcW11S600<LiaS65:D0
0QS600HDYA245:DDYAcW6<H25:D011S68@PLiaBU0Q2400<DYAS65:D00PaS
00<@Q1S66<H00QBU00<@Q1S66<H011BU00@@Q1BU5:DHaP8DY@@Li`DHaP07
5:DHaQS66<HDYAS65:D00aS60aBU1aS61QBU0aS600<DYAS65:D00QBU0QS6
00@DYA2448@DY@@HaP035:DHaQS6008HaP<Li`@HaP047>LHaQS66<H75:D3
6<H248@25:D00aS65:DDY@036<H35:D36<H25:D01Q245:DHaQS65:D@Q0DD
Y@036<HDYABU008@Q0<DY@<@Q0036<HDYABU00DDY@0948@DYA245:D@Q1BU
6<HDYAS6008DY@8HaP<@Q0035:D@Q12400D@Q0035:D@Q12400@DY@8@Q0<D
Y@@@Q08DY@0348@<Ha2400<@Q00336<@Q0aS0088@P0536<@Q12436<@Q002
5:D236<00a245:D@Q00248@01aS65:DHaQBU48@<HaBU00@@Q0035:D@Q124
008DY@T@Q0035:D@Q1BU00@@Q00336<@Q12400<@Q08DY@0448@<Ha245:D2
48@010aS48@@Q1241ABU1A240aBU112400<DYAS648@00a2400<DYAcW6<H0
0QBU0Q240QBU00<HaQBU6<H00QBU00H@Q1BU5:DHaQBU48@55:D00a245:D@
Q0026<H00acW5:D@Q00348@01QBU48@@Q0aS48@DY@8@Q08DY@8@Q00436<@
Q12448@35:D01`aS48@@Q1BU6<H@Q1BU00<@Q08DY@D@Q0<<H`0448@<H`aS
48@336<348@236<248@00`aS48@@Q0026<H25:D011245:DDYAS60Q2400<D
YA245:D00QBU00H<Ha2448@<Ha2436<348@336<248@25:D248@15:D148@1
36<0000300048@@Q00H48@0800048@@Q7>LaS2U:5:DHaP8DY@036<HLiacW
00DHaP037>LHaQcW00DHaP8Li`8DY@0;48@DYAS65:DHaQcW6<H@Q1BU6<HL
i`025:D00a245:DDY@035:D01A246<HDYABU48@00QBU0aS600HDYAS66<HH
aQBU48@45:D36<H35:D26<H35:D00aS67>LHaP026<H00aBU48@@Q0025:D0
0acW6<HDY@035:D00aS65:DDY@045:D248@35:D248@01QBU6<HDYABU48@D
Y@@HaP<DY@0348@DYA24008DY@<@Q0035:DHaQBU00<@Q0045:DHaQBU5:D2
48@55:D011246<HDYABU0aS60QBU00<@Q1BU5:D01aBU0Q2400HDYAS67>LL
iaBU48@25:D27>L00aS65:DHaP045:D01AS67>LHaQBU6<H00QcW00<HaQBU
5:D00QcW00@HaQBU5:DDY@<HaP065:DHaQS67>LHaQ240QBU0QS60QBU00@@
Q1S66<HLi`<DY@<HaP@DY@HHaP8Li`056<HLiacW7>LDY@026<H27>L26<H2
5:D46<H25:D00a246<HHaP028@P36<H011245:D@Q1S60aBU00<HaQBU5:D0
0QBU0QS600<DYAS66<H00Q2400TDYAS66<HHaQ245:DHaQBU6<H00acW0QS6
0QcW0aS600DDYA246<HHaQcW008DY@8HaP045:D@Q1BU6<H45:D011cW6<HH
aQS611BU00@HaQBU5:D@Q0DDY@<HaP047>LHaQS65:D248@85:D01A245:DD
YABU48@00aBU0Q240aBU00D@Q1BU5:D@Q1BU008HaP8DY@0336<@Q12400H@
Q0<DY@0548@<Ha245:D@Q0025:D248@236<248@00aS648@<H`0248@25:D3
48@00`aS48@@Q00348@00`aS48@@Q00248@011BU48@DYA240QBU0Q240QBU
0aS60a240aBU0a2400@DYA2436<<H`D@Q00336<@Q124008@Q0035:D@Q124
008@Q0035:D@Q0aS008@Q0066<HLiaBU48@<Ha240QBU0Q2411BU0Q2400DH
aQBU48@@Q1BU008HaP055:D@Q1BU5:DHaP025:D248@00aBU6<HHaP0248@0
11BU6<HHaQBU0QS60Q2400<<Ha245:D00QBU00<HaQ245:D00aBU00HHaQBU
5:DHaQBU6<H348@36<H548@45:D248@45:D0112436<@Q1BU0QS600P@Q0aS
48@DYA245:D@Q1BU21240`aS0a240PaS212400@<Ha2448@<H`D@Q0055:D@
Q12448@DY@0948@010aS48@@Q12410aS0a240QBU1A240003124010001244
8@0010@Q00H8@QS6=JdQ21245:D56<H27>L01aS65:DHaQS67>LHaQcW008H
aP8DY@<Li`@DY@0348@HaQS6008DY@0448@HaQS67>L45:D00aS65:D@Q002
5:D01AS65:DDYA245:D01AS600<LiaBU48@00QBU00DHaQ245:DHaQcW008H
aP0848@DYA246<HDYA245:DHaP8Q208HaP8DY@066<H@Q1BU5:DHaQcW0aS6
00LDYA2448@DYAS65:D@Q0075:D248@00aBU48@@Q00248@26<H=5:D248@0
11BU48@@Q1240aBU0a240QBU00<HaQBU6<H011BU0QS611BU0a2400DDYA24
5:DDYAS600@@Q08Li`@DY@@HaP8DY@036<HLiacW00LHaP8DY@046<HLiaS6
6<H45:D56<H00aBU6<HDY@025:D26<H011BU48@@Q1BU11S60QBU0aS600@D
YA2448@@Q08DY@046<HLiacW7>L66<H00aBU6<HLi`056<H25:D021S65:DH
aQBU48@HaQcW8@P37>L00aS65:DDY@0248@25:D01QS65:DHaQBU6<HDY@8H
aP047>LDYA2448@35:D011S65:DHaQS60QBU00@HaQBU5:DHaP8Li`046<HL
ib487>L25:D46<H35:D36<H35:D011245:DHaQS60QBU0QS60aBU00@HaQBU
5:D@Q0@DY@0848@DYABU6<HDYAS65:DHaP/DY@0448@DYA2448@25:D348@2
5:D00a245:DDY@075:D948@01PaS48@@Q1BU48@<H`8@Q0035:D@Q0aS008@
Q00336<@Q1BU008DY@<@Q0@DY@0448@<H`aS36<348@020aS48@@Q1245:D@
Q1BU48@35:D348@00aS67>LLi`025:D011245:DDYAS611240QBU00D@Q1BU
48@@Q0aS008@Q0065:D@Q12448@DYA240PaS00<DYAS65:D00Q240PaS00@D
YAS65:D@Q08<H`8DY@0648@<H`aS48@DYAS60aBU0a2400<<Ha2448@00QBU
00@@Q1BU6<HDY@8@Q0045:DHaQS648@45:D00a245:DHaP026<H01ABU48@@
Q1BU48@00aBU0a2400@DYAS65:DDY@<@Q0@DY@8HaP8DY@L@Q0<DY@046<H@
Q1245:D348@00aBU48@@Q00348@010aS48@DYABU0a240QBU00H@Q0aS36<<
Ha245:D248@01@aS48@@Q12436<00a240`aS00D@Q1BU48@@Q0aS008@Q003
5:D@Q1BU008@Q0<DY@0448@<Ha245:D448@00`aS48@@Q00248@236<01Q24
5:D@Q12436<@Q08DY@4@Q04<H`4<H`0000D000@Q12448@0000@48@0>0004
8@Q27>L]JacW48@HaQcW5:DHaR489BTQ208HaP8Li`076<HLiacW6<HLiaBU
48@00QS600XLiaS65:DDYAcW6<H@Q1BU6<HLi`<DY@THaP045:DHaQBU6<H2
5:D011S65:DLiacW0QS60QBU00D@Q1BU5:DDYAS6008DY@<HaP8@Q0<HaP03
48@DYABU00DHaPDDY@<HaP035:D@Q1BU008HaP035:D@Q124008DY@8HaP<D
Y@0548@DYABU5:DHaP095:D26<H00aBU48@DY@025:D011245:DLiaS60QBU
00<@Q1BU5:D00aBU00@@Q1BU5:DHaP<DY@8HaP@DY@036<HDYA24008@Q08D
Y@0348@DYABU008HaP8DY@0848@DYABU48@DYAS67>LHaP8DY@037>LDYABU
008@Q0055:DHaQS66<HDY@026<H27>L00b487>LDY@055:D26<H011cW6<HH
aQS60QcW00@HaQBU5:DDY@8HaP045:DHaQS66<H35:D021cW5:DHaQS67>LH
aQBU48@25:D36<H25:D021S67>LLiacW6<HDYAS67>L46<H25:D36<H35:D2
6<H47>L26<H00aBU6<HDY@0348@26<H25:D26<H35:D27>L011S648@@Q124
0QS60QBU0QS60QBU00DHaQcW5:DDYAS6008Li`8HaP037>LHaQcW00<DY@03
6<HLiaS600LHaP<DY@036<HLiaBU008@Q0056<HLiacW6<H@Q0045:D01Q24
5:DDYAS65:DHaP@DY@8HaP0948@DYAS66<HDYA245:DHaQBU00H@Q0035:D@
Q1BU008DY@8@Q0035:D@Q1BU008DY@0348@<Ha24008@Q00436<@Q1245:D2
48@010aS48@DYAS60Q2400P<Ha245:D@Q1BU48@DYA241ABU0a240QBU0Q24
00LDYA2448@@Q0aS48@<H`0348@25:D336<248@01QBU48@@Q1245:DHaP8L
i`036<HDYA2400<DY@@@Q0035:D@Q12400P@Q08<H`8@Q0095:D@Q1245:D@
Q1BU48@DYA24008DY@8HaP035:D@Q124008DY@<@Q0055:D@Q12448@<H`02
5:D26<H01QBU36<@Q1245:DHaPDDY@036<HDYA24008@Q00:36<@Q1BU7>LH
aQBU48@DYA245:D248@35:D348@011S65:D@Q0aS0QBU0a2400<HaQBU6<H0
0QBU00<<Ha245:D00QBU0Q2400@DYA2448@@Q08DY@<@Q0<DY@@@Q0045:D@
Q1245:D248@236<248@00`aS48@<H`0248@00`aS48@DY@0448@010aS48@<
H`aS11240PaS00<@Q0aS36<00a2400<<Ha245:D00QBU1a2400<DYA2436<0
0PaS0Q240PaS00<@Q1BU5:D00Q2400<DYA245:D00@aS000212400`001244
8@0612401@Q26<HaS1cW48@00QS600DDYAS68@PU:AcW008HaP<Li`046<HL
iaS67>L35:D01QcW8@PLiaBU48@DY@@HaP065:DHaQS65:DHaQBU0QS600@D
YAS66<HDY@<@Q0@HaP065:DHaQS66<HLiaS61QBU00L@Q1S66<HHaQBU48@D
Y@026<H25:D00aS65:D@Q0026<H27>L01AS65:DDYA245:D00QS60QBU00`@
Q1BU5:DLiaS65:D@Q1BU6<HDYA245:D26<H00aBU48@@Q0085:D26<H00aBU
6<HDY@055:D00a245:DDY@026<H65:D348@25:D46<H021BU6<HHaQS648@D
YAS65:D248@00aBU6<H@Q0035:D26<H00aBU48@DY@045:D36<H01ABU6<HH
aQS65:D00Q240QBU00@LiaBU5:DDY@<Li`046<HDYAS67>L26<H45:D00acW
6<HHaP027>L01ABU48@DYABU7>L00aS600HDYAS65:DDYA245:D26<H011BU
6<HLiaS60aBU00`HaQBU5:DLiaS65:D@Q1S68@PLiaS65:D66<H00aBU6<HH
aP036<H25:D01QS65:DHaQS67>LQ208HaP035:D@Q1S600<DY@0648@DYAS6
5:DHaQBU0QS600LLiaS65:DDY@aS48@DY@036<H35:D76<H01QBU6<HHaQcW
6<HLi`<HaP035:DHaQBU00<HaP037>LHaQBU00<DY@<HaP8DY@066<HDYAS6
6<HDYAS61ABU00@@Q1BU6<H@Q08DY@037>LHaQBU00<DY@056<HDYABU5:D@
Q0036<H55:D01A245:DDYABU36<00Q240QBU0Q2400<DYAS66<H00QBU00<<
H`Q248@00QBU00@@Q0aS48@DY@@@Q0045:D<Ha245:D348@35:D248@021BU
48@@Q1BU6<HDYA2436<248@236<00a245:D@Q00548@01ABU48@DYABU48@0
0aBU1A2400DLib486<HDYA24008DY@0348@<Ha2400<@Q00436<@Q1245:D3
48@25:D348@25:D248@00aBU48@DY@0248@00aBU48@DY@0:5:D248@010aS
48@<Ha240QBU00L@Q1BU48@<Ha245:DLi`025:D248@36<H25:D248@25:D3
6<H348@26<H01ABU48@@Q1245:D00Q2400<DYAS66<H00Q2400<DYAS65:D0
0Q2400@DYAS65:DDY@8@Q08DY@8@Q08DY@<@Q0035:D@Q1BU008DY@8@Q08D
Y@8@Q00336<DYABU00X@Q00336<@Q12400@@Q08DY@D@Q0<<H`8@Q08DY@8<
H`<@Q00436<@Q0aS36<248@011BU48@<H`aS0Q240QBU00<@Q0aS36<00a24
0PaS1A240QBU0A240@aS000312400`001240000412401`00124HaRU:8@PD
YAS600LLi`036<HLiacW008Li`046<HLiacW7>L25:D01A246<HDYAS65:D0
0Q2400@DYAS67>LHaP8@Q0035:DHaQS6008DY@056<HLiaS66<H@Q0025:D2
7>L25:D011245:DHaQcW0aS611BU0QS600@DYAS65:DHaP8DY@0348@DYAS6
008HaP@DY@046<HDYABU5:D26<H25:D00aS65:D@Q0025:D01AS65:DDYA24
5:D00a240aBU112411BU0Q2400@DYAS66<HDY@8@Q0055:DHaQBU5:DHaP02
5:D00a245:DHaP026<H25:D01AS65:DDYABU6<H00QBU00D@Q1BU5:DDYAS6
008DY@056<HDYA2448@DY@036<H25:D348@011BU6<HDYAS61ABU1aS600DD
YA2448@DYAS6008DY@8HaP8DY@037>LQ21cW008HaP057>LHaQBU48@DY@02
6<H75:D46<H011BU48@DYABU0QcW00<HaQBU5:D01QS60QBU0aS600@DYAcW
6<HLi`DHaP047>LHaQS65:D46<H011BU6<HHaQBU0QS600DLiaS67>LQ21cW
00<DY@8HaP035:DHaQBU008DY@8HaP057>LDYAS66<HLi`055:D011245:DD
YAS60aBU0QS60acW0aBU00<LiaS65:D00QS60QcW00<DYAS65:D00aBU00<L
iaS65:D011S600<DYAS65:D00QBU0aS600<DYAS67>L00aBU00<HaQBU5:D0
0QBU0QS61aBU0aS600@DYAS66<HDY@8@Q0075:DHaQS65:D@Q1BU48@00QBU
00HHaQ2448@@Q0aS5:D448@36<H248@01QBU48@<H`aS48@DY@<@Q0035:D@
Q1BU008@Q08DY@0748@DYABU48@DYA245:D00`aS00<@Q1S65:D00Q2400<<
HaBU48@00PaS0Q240PaS00@DYAS66<HHaP8@Q0035:D@Q1BU008@Q00:5:DH
aQ245:D@Q1BU7>LHaQcW6<H548@00`aS48@DY@025:D01A245:D@Q1245:D0
112400<DYA2448@0212411BU00<@Q1BU6<H00aBU00<HaQBU48@00a2400<<
Ha2448@00QBU00@HaQBU48@@Q08DY@0348@DYABU008HaP8DY@8<H`8@Q0HD
Y@8@Q08DY@<@Q0035:D@Q12400<DY@0548@DYABU5:D@Q00236<348@35:D0
0a2436<@Q00348@45:D00a2436<@Q0025:D248@011BU48@@Q1BU0a240PaS
0a2400@DYA2448@<H`H@Q0035:D@Q12400X@Q00336<@Q12400<@Q0045:D@
Q0aS36<348@00`aS48@<H`0336<348@35:D01PaS48@@Q12436<@Q0<DY@03
48@DYABU004@Q00000<48@0012400`@Q00<000@Q12400`@Q00LDYBe[8@P@
Q1S67>LHaP027>L00b487>LLi`037>L00b486<HHaP026<H011cW5:D@Q1BU
0aS60Q240QBU00@HaQBU5:DHaP@DY@DHaP@DY@<HaP035:D@Q1BU00HHaP03
48@DYABU00@HaP055:D@Q1BU48@DY@026<H00acW5:DHaP036<H65:D26<H0
0aBU6<HHaP026<H35:D011S65:DDYABU0Q2400HDYAS65:D@Q0aS48@95:D3
48@65:D01A245:DDYAS67>L00QBU00H@Q1BU5:DHaQBU48@75:D26<H01124
5:DDYAS60QBU0a2400@HaQBU48@@Q08DY@056<HDYABU5:D@Q0045:D46<H2
5:D00aS65:DDY@025:D26<H35:D00aS68@PLi`025:D00aS65:D@Q0025:D0
21S65:DDYAcW8@PHaQ245:D26<H25:D00aS65:DDY@025:D00acW6<HHaP02
7>L25:D011S67>LHaQS60aBU11S600LDYAS67>LLiaS65:DHaP027>L25:D3
6<H01ABU6<HLiaS67>L00QS60QBU0aS600@LiaS66<HHaP8DY@0348@DYABU
008DY@057>LHaQS66<HDY@036<H35:D36<H25:D00aS67>LHaP025:D01AcW
9BTHaQBU48@011S60acW00HHaQBU5:DDYAS67>L36<H011BU6<HHaQBU0QS6
11BU00<HaQBU5:D00QcW00LHaQBU5:DDYAS648@DY@036<H55:D26<H45:D2
6<H00a245:DDY@0248@01QBU6<HDYA2436<@Q0@DY@<@Q0HDY@8HaPD@Q08<
H`<@Q00336<@Q1BU00<DY@0348@DYA24008DY@8@Q00336<8@PaS00@DY@03
48@<Ha2400<@Q08<H`8@Q0<DY@036<HDYA2400<@Q0035:D@Q1BU00D@Q003
5:DHaQcW008Li`<@Q00336<@Q1BU008DY@L@Q0035:D@Q124008<H`035:DH
aQBU008<H`0348@DYA24008@Q0<DY@0448@DYABU6<H55:D248@01ABU48@@
Q0aS48@00aS60a2400DDYAS65:DDYAS6008DY@8@Q0055:D@Q12448@DY@02
6<H00aBU48@@Q0035:D00a245:D@Q00348@55:D248@00`aS48@@Q00348@0
1aBU6<HHaQS65:D<Ha24008<H`@DY@0336<@Q1BU00H@Q0035:D@Q124008D
Y@0548@<Ha2436<@Q00336<248@01ABU36<<Ha245:D01A2400DDYA2448@@
Q0aS00H@Q0035:D@Q0aS00<@Q00736<@Q12448@<Ha2436<00a2400<<Ha24
48@0212400@<HaBU48@DY@D@Q00000@000@Q124000D48@0800048@Q27>La
S24848@Li`8Q20<Li`038@PLiaS600<HaP8Li`036<HLiaS600<DY@8HaP8D
Y@0448@DYAS66<H35:D00aS65:DHaP025:D37>L45:D01QS65:DHaQS67>LH
aP<DY@8Li`8DY@<HaP@DY@8HaP035:DHaQS6008DY@0348@DYAS6008HaP8@
Q0HDY@036<HDYAS6008HaP045:DHaQS66<H25:D011245:DDYA241QBU00DH
aQBU5:DDYAS6008DY@8HaP057>LHaQBU5:D@Q0025:D00a245:DHaP026<H2
5:D021S65:DDYABU7>LHaQBU48@25:D00aS65:DHaP036<H25:D01A245:DD
YABU48@00QBU00DHaQBU5:DDYA24008HaP035:DHaQS600@DY@8Li`8HaP8D
Y@8HaP035:DHaQS600<HaP8Li`046<HDYABU6<H27>L03QS65:DHaQcW6<HD
YA245:DHaQcW6<H@Q1BU48@37>L26<H25:D00aS65:DHaP057>L01B487>LQ
21S65:D00QS600<LiaBU6<H00QS600@LiaS65:DDY@8HaP8U:@077>LHaQBU
6<HLiaS65:D01QS611cW0QS60QBU0aS600@DYAS65:DDY@8HaP047>LHaQS6
7>L26<H25:D011S65:DDYABU0aS611BU0QcW0QBU00@@Q1S66<HLi`@HaP<D
Y@036<HDYAS6008Li`036<HDYA24008HaP8DY@8HaP8@Q0055:DHaQS66<HD
Y@026<H25:D36<H37>L26<H01A245:DDYAS67>L00QS600<DYAS66<H00QBU
00@HaQBU5:DHaP8DY@0748@DYABU48@<Ha2436<00aBU00@@Q0aS48@DY@8@
Q00336<@Q1BU008DY@h@Q0@DY@8@Q0035:D<H`aS00<@Q0<DY@@@Q0055:D@
Q12436<@Q00236<01QS67>LU:B486<HDY@L@Q0035:D@Q12400<@Q0045:DH
aQS66<H548@00`aS48@@Q0025:D00a245:DDY@025:D448@01ABU36<@Q0aS
48@00aBU0Q240QBU0Q2400<DYAS65:D00aBU0QS60QBU10aS00HDYAcW7>LH
aQBU48@35:D248@011BU7>LLiaS60Q240QBU00D@Q1BU5:DDYA2400@DY@03
48@DYABU00<@Q08DY@056<HDYA2448@DY@0248@00`aS48@DY@035:D011S6
5:DDYABU0Q2400<<HaBU48@00aBU0Q2400@DYAS65:DDY@8<H`8@Q08DY@05
48@DYA2448@DY@0348@336<00`Q236<@Q00248@35:D0112436<<H`aS0Q24
00<DYA245:D01A2400<DYAS648@00Q2400DDYA2448@@Q1BU008@Q08<H`<@
Q00336<@Q12400D@Q08DY@<@Q0<DY@4@Q04<H`000P@Q00D000@Q12448@00
00D48@035:DYBQcW008HaP8Li`038@PLiacW00@HaP035:DLiaS6008HaP03
7>LHaQBU008DY@086<HDYABU5:D@Q1S65:DHaP<DY@8HaP055:D@Q1BU5:DQ
20027>L011245:DDYABU0QS60aBU0Q2400<HaQcW6<H00aBU00<HaQBU6<H0
0QBU00LHaQBU5:DHaQBU6<HDY@0248@36<H45:D00aS65:DDY@035:D46<H2
5:D00aS65:D@Q00248@00aBU48@DY@0248@25:D00aS65:DDY@065:D26<H0
0aBU48@DY@035:D00a245:DDY@025:D46<H25:D01QS67>LHaQS648@DY@<H
aP<DY@036<HDYABU00DDY@0648@DYABU6<HDYA240QBU00<@Q1BU5:D011BU
11S600LLiaS66<HHaQBU48@DY@046<H27>L25:D01AS67>LLiaS65:D00aS6
11BU00PHaQcW5:DDYA245:DHaQcW0QS60QBU11S60QcW00<Q21cW8@P00acW
0QS600@DYAS66<HLi`<HaP<DY@8HaP047>LQ22487>L36<H011cW6<HHaQS6
0acW00DDYAS66<HDYAcW008HaP@DY@0348@DYABU00<DY@056<HLiacW6<HD
Y@036<H00aBU6<HDY@025:D011S65:DDYAS60aBU00LHaQcW7>LHaQBU48@D
Y@027>L25:D011S67>LHaQS60QBU1AS60aBU0aS600<DYA245:D00QBU00<H
aQBU6<H00QcW00<HaQBU6<H011S600<LiaS66<H00QBU00LHaQBU6<HDYAS6
5:DHaP055:D26<H25:D011245:D@Q1240QBU0Q2400<DYA2448@00Q2400@<
HaBU48@@Q08<H`@DY@0448@<H`aS36<348@01PaS48@@Q1245:D@Q08<H`8@
Q0045:D@Q0aS36<348@00aBU48@DY@025:D248@35:D336<011245:DHaQS6
0QcW00/DYA2436<@Q1BU48@<Ha245:D@Q1BU00@@Q0<HaP045:D@Q1BU5:D7
48@35:D348@35:D0112436<<H`aS212400<DYAS65:D00aBU00@HaQBU5:D@
Q0<DY@0336<@Q124008DY@8HaP@DY@0348@DYA2400<HaP<@Q08DY@0448@D
YABU5:D348@45:D348@35:D248@010aS5:DDYABU0a2400@DYA2448@DY@<H
aP<@Q0045:D@Q12448@35:D011245:DDYABU0Q2400<<Ha2436<00aBU00D@
Q0aS48@@Q1BU00<@Q00436<8@PaS48@336<00a245:DDY@0848@00aBU48@@
Q00248@01QBU6<H@Q12436<@Q08DY@<<H`D@Q08<H`0348@DYABU00T@Q08D
Y@8@Q04DY@4<H`0000D000@Q12448@0000@48@0900048@Q26<H]JacW5:DL
ib4800HLi`046<HDYAS65:D47>L45:D00aS67>LDY@035:D26<H01QcW5:DD
YA245:DHaP8DY@<HaP035:DHaQS600<DY@@HaP<DY@8HaP045:D@Q0aS5:D2
6<H021BU48@DYAS65:D@Q1BU6<H448@26<H35:D36<H25:D26<H35:D36<H4
5:D46<H35:D36<H25:D36<H011BU6<HDYAS60QBU00<@Q1BU5:D00QS60aBU
0QS600LDYAS66<HHaQBU6<HLi`026<H25:D00a245:DDY@045:D00aS65:DD
Y@0348@95:D00aS65:DHaP045:D01AS67>LHaQBU48@00QBU0aS60QBU0aS6
0QBU1QS600@LiaS66<HHaP8DY@0548@DYAcW7>LHaP035:D26<H37>L35:D0
0aS67>L@Q0025:D38@P00acW6<HDY@046<H25:D00aS65:DHaP055:D00aS6
7>LLi`066<H00aBU6<HHaP027>L00aS65:DHaP027>L36<H00aBU6<HHaP03
6<H011BU6<HHaQBU1QS60QBU0QS600@DYAS66<HHaP8DY@<HaP8DY@046<HD
YAS648@25:D01QS67>LHaQBU6<HDY@@HaP037>LHaQBU008DY@8HaP0348@H
aQS6008HaP@DY@DHaP8DY@8HaP037>LHaQS6008DY@0448@DYABU5:D36<H0
0aBU6<HDY@026<H00aBU6<HDY@025:D011245:DDYABU0a2400T<Ha245:D@
Q1BU48@DYA2436<01A2400<DYA2436<00PaS0Q2400@DYA2448@DY@8<H`07
5:DHaQBU48@<Ha245:D00Q240QBU0Q2400@<Ha2448@DY@8@Q00436<@Q124
48@236<0312436<@Q1BU6<HLiaS65:DHaQ245:D@Q08DY@0436<@Q0aS48@3
5:D236<00a246<HHaP035:D00a245:D@Q00248@55:D00a245:DDY@0248@4
5:D248@01ABU6<HDY@aS48@00aBU00D<Ha245:DDYAcW008HaP@DY@<@Q003
36<DYABU00DDY@8HaP0648@DYA245:D@Q1BU0Q2400<DYA2448@00QBU0QS6
112400LDYAS65:DDYA2436<@Q0045:D348@02ABU48@@Q1245:DHaQ2436<H
aP027>L00aBU36<@Q00348@25:D00a245:DDY@035:D236<248@01AS65:D@
Q1BU48@00`aS0a2410aS112400<DYA2448@00`aS00@@Q1BU48@DY@@@Q0<D
Y@036<H@Q12400D@Q0045:DHaQBU5:D548@236<848@236<348@236<000<4
8@0300048@@Q00H48@076<HYBQS648@Q22DY8@P00QS60acW00DDYAS65:DH
aQcW00<HaP<DY@@HaP@DY@037>LHaQS6008@Q0065:DLiaS66<HDYAS611BU
00<HaQBU6<H00aS60QBU11S60Q2400HDYAS66<HDYA245:D36<H01QBU48@D
YABU48@HaP8DY@036<HDYA24008DY@DHaPHDY@@HaP035:DHaQBU008@Q007
5:DHaQS65:D@Q1BU6<H00aBU1AS60QBU112400<HaQBU6<H00QS60aBU1aS6
00DDYA245:DDYAS6008DY@0348@HaQBU00@DY@<@Q0<DY@0348@DYABU008D
Y@046<HDYABU6<H25:D56<H25:D01aS65:DDYAS67>LHaQcW00<DY@036<HL
iaS6008DY@@HaP<DY@8HaP8Li`8DY@056<HDYAS66<HLi`026<H35:D00acW
6<HHaP025:D28@P27>L26<H011BU6<HLiaS60aBU00<LiaS66<H00QS60QBU
0QS600@LiaS66<HLi`8HaP035:DHaQcW008Li`HHaP035:DHaQBU008HaP<D
Y@8HaP045:DHaQS66<H25:D36<H45:D00acW6<HDY@025:D00aS67>LHaP02
5:D36<H35:D01Q245:DHaQS67>LHaP8DY@DHaP8DY@8HaP8DY@0348@DYAS6
00<DY@@HaP8DY@8HaP8DY@8HaP037>LHaQS6008DY@0;6<HDYAS66<HDYAS6
8@PHaQBU48@DY@026<H45:D00a245:DDY@025:D236<011246<HHaQ240PaS
00<@Q1BU5:D01A2400<DYA2448@01a240PaS0Q2400@DY@aS36<@Q0<DY@H@
Q0055:D@Q1BU36<@Q0025:D0112436<@Q1240PaS00<DYAS67>L011BU3124
00<DYAS65:D011BU0Q2400H<Ha2448@@Q1BU6<H35:D348@011BU48@DYABU
0Q2400D<HaBU5:DHaQBU008@Q0035:D@Q124008@Q0036<HDYAS600<DY@03
48@DYA2400<@Q0045:D@Q1BU48@25:D26<H25:D248@26<H0212436<@Q1S6
5:D@Q1BU48@26<H248@01@aS48@HaQBU6<H00QBU0Q2400<HaQBU6<H01124
0aBU00<@Q1BU5:D00a2400<HaQcW6<H01A2400<DYA245:D00aBU1Q2400<D
YA2448@00Q2400<DYA2436<00`aS00<@Q0aS36<00`aS0Q240aBU0Q2400<<
Ha2448@021240aBU00<@Q0aS48@00aBU112400<DYA2448@01A240`aS00<@
Q1BU48@0112400<DYA2436<00@Q200000`@Q00048@0212402P0012448@@Q
00048@Q25:D]JbDY0QS60QcW00PQ21cW6<HDYAS65:D@Q1BU0QS60QBU0aS6
0QBU00<HaQBU6<H011S60QBU00<@Q1BU6<H01AS60aBU00PHaQcW6<HDYA24
6<HLiaS60QBU0QS600DDYA245:DDYA2400<HaP8DY@0448@HaQBU5:D26<H0
1QBU48@<HaBU7>LHaP8Li`@DY@046<HDYABU5:D36<H25:D46<H25:D00aS6
5:DDY@045:D011S65:DDYABU11S600@DYAS67>LDY@8@Q08DY@8@Q0035:DH
aQS6008HaP077>LDYAS67>LQ21cW6<H01aBU0Q2400<DYA245:D00Q2400<D
YA2448@00QBU0QS62ABU00@@Q1BU6<HHaP8DY@8@Q0035:D@Q1BU008DY@8H
aP038@PLiaS6008DY@036<HLiaS600DHaP8DY@0448@DYAS66<H25:D66<H0
11BU6<HDYAS61QBU11S600@Lib487>LLi`8HaP8DY@096<HDYAS66<HDYA24
5:D@Q1BU00@Li`065:DHaQBU5:DHaQBU11S600@DYAS66<HLi`8HaP8DY@03
48@DYABU00PHaPHDY@0448@DYABU5:D36<H00aBU6<HLi`026<H248@00aBU
6<HHaP045:D37>L25:D26<H27>L01R487>LLiaS65:DHaP8DY@036<HLiaS6
00<DY@8HaP037>LHaQS600@HaP8DY@046<HDYAS66<H35:D248@26<H00acW
6<HDY@025:D26<H00a245:DDY@025:D00aS65:DDY@025:D01Q245:D@Q0aS
48@DY@T@Q0@DY@<@Q08<H`T@Q00336<DYABU008HaP055:D@Q1BU48@DY@03
48@25:D248@010aS48@@Q1BU0Q2400@DYA245:DDY@<@Q0<DY@@@Q0035:D@
Q0aS008@Q0035:D@Q124008@Q0045:DHaQBU48@35:D00a245:D@Q0035:D0
11S648@@Q12421BU0a2400DDYA245:DDYA24008DY@036<HDYABU008DY@06
7>LHaQBU48@<Ha2411BU00<@Q1BU5:D00aBU00DHaQBU48@<Ha2400@DY@03
48@<Ha2400HDY@036<HDYABU00<@Q0035:D@Q1BU00@DY@<@Q0<DY@<@Q08D
Y@@HaP035:DHaQBU008@Q00536<DYABU5:DHaP0248@00`aS5:DDY@026<H0
2A2436<@Q1245:DHaQBU48@<H`0348@236<35:D248@35:D0312436<@Q1BU
48@<Ha245:DHaQBU48@DY@8@Q0035:D@Q124008@Q0035:D@Q12400<@Q004
5:D@Q1BU48@236<448@336<01a2436<@Q12436<@Q0aS0048@P0000D000@Q
12448@0000L48@036<HaS2DY008HaP8Li`036<HLiaS6008DY@8@Q08DY@<H
aP035:DHaQBU00@HaP035:DHaQS6008Li`046<HDYA2448@26<H011cW6<HD
YABU0QS600@DYAS66<HHaP8DY@8HaP8DY@8Li`036<HDYABU008DY@8HaP8D
Y@0348@DYAS600<DY@8HaP075:D@Q12448@HaQcW6<H00QBU11S60QBU00@H
aQcW6<HDY@@HaP8DY@<HaP0348@DYABU00<HaP0348@DYABU008DY@046<HL
iaS66<H25:D011245:D@Q1BU0Q240QBU1QS600DDYAS68@PQ21S6008@Q006
5:DHaQBU5:D@Q1BU0Q2400<DYA245:D00QBU0a2400<DYAS648@00QBU0QS6
21BU00@HaQBU5:DDY@8@Q0045:DHaQBU5:D26<H27>L00aS65:DDY@047>L2
6<H45:D36<H011BU48@DYABU1aS600<LiaBU48@00QBU0QS60QBU0QS60acW
00@Q21S66<HDY@<HaP037>LHaQS6008DY@036<HDYAS600HHaP<DY@056<HL
iacW6<HDY@046<H01QcW5:DHaQBU6<HLi`8HaP045:DHaQS65:D26<H35:D0
0aS65:DHaP035:D011245:DDYABU0QS600<LiaS66<H01aBU1AS60QcW11S6
00DLiaS67>LHaQcW008HaP8DY@046<HDYAS66<H25:D00aS67>LHaP036<H0
11cW6<HHaQBU0QS600<LiaS65:D01ABU00@@Q1BU6<HLi`8HaP045:DLiaS6
6<H248@35:D26<H00aBU48@@Q0025:D348@25:D248@01ABU48@<Ha2436<0
0aBU0Q240QBU00<@Q0aS36<0112400<<Ha245:D00QBU00<@Q1BU6<H01ABU
3A2400@DYA2448@HaP8DY@8@Q00336<@Q12400X@Q0TDY@D@Q0046<HDYABU
5:D248@011BU48@DYA240aBU00@HaQBU5:DDY@8@Q0045:DHaQS65:D248@0
0aS65:DDY@025:D26<H448@01AS648@@Q1246<H00Q240QBU00DLiaBU5:D@
Q1BU008@Q0065:DHaQBU5:D<HaBU0Q240QBU00@HaQcW5:DHaP@@Q0045:D@
Q12448@45:D448@01QBU48@@Q1BU48@DY@<HaP8DY@036<HDYABU00<@Q08D
Y@8HaP035:D@Q0aS00<DY@0448@DYABU6<H35:D01PaS48@@Q1245:D<H`8@
Q0035:D@Q12400<@Q00336<@Q124008DY@0448@DYA2448@25:D00aS65:DD
Y@0236<448@00`aS48@DY@0248@00aBU6<HDY@0236<01A2436<<Ha2436<0
0a2400<DYA2448@00PaS0Q240PaS000212401@0012448@@Q00001@@Q00@H
aS6<8@PDY@<Li`058@PLiacW6<HDY@026<H01acW5:DDYAS65:D@Q1BU008L
i`036<HDYABU008HaP<DY@DHaP8DY@8Li`036<H@Q124008DY@0648@DYAS6
7>LHaQBU0QS600<DYAS66<H00aS60aBU00HHaQBU5:D@Q1BU6<H45:D01124
6<HHaQBU0QcW0QS60QBU11S600@DYAS67>LLi`8HaP8Li`056<HDYABU6<HL
i`026<H01A245:DHaQS648@00QBU00<HaQBU6<H00QS600@LiaS65:DDY@8@
Q08DY@036<HDYABU008DY@8Li`<HaP047>LQ21cW6<H25:D26<H25:D248@2
5:D248@010aS48@DYA240QBU00<HaQ2448@01aBU0a240QBU0QS60QBU1A24
00@DYAS68@PQ208Li`065:D@Q1S66<HQ21cW0aBU00DHaQBU6<HDYAS6008D
Y@8HaP<DY@8HaP075:DHaQS66<HDYAS65:D00aS600<DYAS66<H011cW0aS6
0acW0aS60QcW00HHaQBU48@DYAS67>L66<H35:D01QS65:DHaQS65:DLi`@H
aP<DY@046<HLiacW6<H25:D36<H75:D248@36<H00aBU6<HLi`027>L25:D0
11245:DHaQS611BU11S600<LiaS65:D00QS600@Lib487>LLi`@HaP045:DL
iacW6<H25:D36<H25:D36<H00acW6<HLi`026<H00aBU6<HHaP035:D00a24
5:DHaP056<H55:D00a245:D@Q0035:D26<H01a2436<@Q1246<HDYA24008D
Y@<@Q0035:D@Q124008@Q08DY@<HaP0648@<H`aS48@DYA240QBU0a2400<D
YAS65:D0112400@<Ha2448@DY@@@Q0@DY@0348@DYABU00P@Q08DY@@@Q0<<
H`H@Q0<DY@0348@DYAS6008HaP@DY@056<HLiacW6<H@Q0095:D011S65:D@
Q1240QBU0Q241ABU0a240aBU00<@Q1BU6<H00QcW0QBU00<@Q1BU5:D00aBU
00@HaQBU5:D@Q0DDY@0348@DYA2400@DY@8HaP045:D@Q0aS36<348@35:D0
0a245:DDY@025:D00a245:DDY@025:D448@01ABU6<HHaQBU7>L00QS60a24
11BU00DHaQBU5:DDYA2400@HaP@DY@<@Q0@DY@D@Q08<H`0348@DYA2400@@
Q00536<DYABU6<HDY@0948@00aBU48@@Q00648@00aBU48@DY@0548@35:D0
0a2436<@Q00348@124800003124000@Q00848@0300048@@Q00848@060008
@QBU;F/Q21S611cW00DQ21cW5:D@Q1S6008Li`8DY@<HaP8DY@056<HDYAS6
6<HLi`036<H01aBU6<HHaQcW6<HDYAS600@DY@056<H@Q12448@HaP027>L4
5:D26<H02ABU6<HHaQBU6<HDYA246<HLi`026<H011245:DDYA240QBU00HH
aQBU48@DYAS67>L56<H011BU6<HHaQBU0QS600DQ21cW6<HDYAS6008Li`05
6<HDYABU5:DHaP035:D00aS65:DHaP025:D248@01ABU6<HLiacW6<H00QBU
00@@Q1BU6<HHaP8DY@0448@DYAcW7>L26<H25:D37>L26<H35:D01QS65:DD
YABU48@DY@H@Q0@DY@036<HDYAS6008DY@0348@DYABU00DDY@036<HDYABU
00<@Q0<DY@8HaP048@PLib487>L35:D021S67>LLiacW5:DHaQBU6<H25:D0
11246<HDYAS60QBU0aS60QcW0QS600<DYAS65:D00aS60QBU11S60QcW00LQ
21S65:DHaR487>LHaP025:D37>L35:D46<H01ABU6<HHaQcW6<H00QBU00@H
aQBU5:DDY@DHaP035:DHaQS600<DY@036<HDYAS600<HaP<DY@<HaP035:D@
Q124008DY@8HaP8Li`<HaP8DY@066<HDYAS65:DHaQ240aBU0QS600<LiaS6
6<H01AS60QcW00<HaQBU6<H00acW00LHaQBU6<HHaQBU6<HDY@037>L36<H2
7>L01aS65:DLiaBU48@DYA24008DY@8HaP035:DHaQBU00@HaP075:D@Q1BU
5:D@Q1BU6<H00aBU00@HaQ2448@@Q0<DY@0648@DYABU5:D@Q0aS0a2400<D
YA245:D00QBU00<HaQ2448@00Q2400<DYA2448@00PaS00<DYA245:D00QS6
0Q240QBU00<@Q0aS36<00Q240QBU2A240QBU00<@Q1BU5:D00a240aBU1124
00<<Ha245:D0112400PDYA2448@<Ha245:DLiaS60QBU00@HaQBU5:DHaP8L
i`XDY@<@Q0055:DHaQBU5:DHaP025:D011245:DHaQBU0a240aBU0Q240QS6
00/DYA2448@HaQBU6<HDYA245:DLiaS600<@Q08HaP035:D@Q1BU008@Q08D
Y@@HaP035:D@Q12400<@Q0@DY@0348@DYA24008DY@0448@DYA2448@35:D2
48@25:D00acW6<HDY@036<H011BU48@DYA240aBU0Q241ABU00DHaQBU48@D
YA2400<DY@0348@DYA2400@@Q0045:D@Q12448@236<00a2436<@Q00248@3
5:D348@35:D:48@01QBU48@<Ha2436<DY@<@Q0035:D@Q12400<@Q08DY@<<
H`4@Q048@P0000@000@Q124000D48@0700048@@Q6<H]JbDY7>L00RDY0QcW
0R4800LLiaS66<HQ22DY7>LDY@026<H00aBU6<HHaP036<H27>L26<H011BU
6<HLiacW0R4800HHaQBU6<HHaQcW6<H45:D011246<HLiacW0aBU00<HaQcW
7>L00QS61ABU00DHaQBU5:D@Q1BU00@HaP@DY@056<HLiacW6<HLi`036<H0
11BU6<HHaQBU1aS600<LiaS65:D00QBU0QS60QBU00<HaQBU48@00Q2411S6
0aBU00<@Q1BU5:D011BU00<@Q1BU48@00QcW1AS600<LiaS65:D00aBU00<H
aQ245:D00QS600@DYA2448@DY@D@Q0<DY@0448@DYA2448@25:D011S65:D@
Q12421BU0Q2400DDYAcW8@PHaQBU00<HaP8DY@0348@DYAS600<Li`036<HD
YABU00<HaP<@Q08DY@<HaP@DY@056<HDYAS67>LHaP025:D00a246<HHaP02
7>L011S67>LLiaS60aBU00<LiaS66<H00QcW00@HaQBU6<HLi`<DY@8HaP05
5:DHaR488@PHaP0248@00aS65:DHaP046<H85:D26<H00aBU6<HHaP055:D0
3AS65:DDYABU48@DYA246<HLiaS67>LHaQBU00@HaP<DY@036<HLiacW008H
aP8DY@<HaP035:DHaQS6008Li`036<HDYAS600@HaP045:DHaQS66<H27>L4
6<H57>L00aS65:DLi`027>L00aS648@@Q0045:D01AS67>LLib487>L00QS6
0QBU0Q240QBU00<HaQBU48@00Q240QS60QBU0Q2400@DYAS66<HDY@@@Q003
5:D@Q12400T@Q08<H`0348@DYABU00<DY@<@Q00436<@Q0aS36<448@25:D0
112436<@Q1240QBU0a2400<DYAS65:D00Q240aBU1A2400@<Ha2436<<H`8@
Q0035:D@Q0aS00@@Q0055:DHaQcW6<HDY@036<H011cW6<HHaQS60QBU00@H
aQBU5:D@Q0@HaP<@Q0<DY@0336<@Q124008HaP<DY@0448@<Ha2448@45:D2
6<H01aBU48@@Q1BU6<HDY@aS008DY@036<HDYA24008DY@@@Q0085:DHaQBU
48@DYA245:DHaP8@Q00736<@Q1BU48@<Ha245:D00a240QBU00<HaQBU48@0
0QBU00DHaQBU5:DDYAS600<DY@8HaP047>LDYABU48@45:D248@85:D00a24
5:D@Q0025:D248@25:D00aS648@@Q00848@00`aS48@@Q00448@35:D01Q24
5:DDYA245:D@Q08<H`0348@DYA2400<<H`0348@DYA2400D@Q08DY@046<HD
YA2448@25:D011245:D@Q1BU0Q24000412400`001240000412401@Q25:D]
Jb487>L0124811cW0R4800@LiaS66<HHaP8Li`055:DHaQBU5:DHaP037>L0
11S65:DDYAS60acW0aBU0QcW00<HaQBU48@011BU00@LiaS65:DDY@<HaP04
5:DHaQS66<H35:D36<H45:D26<H25:D00a245:DLi`046<H00aBU6<HHaP07
6<H01QcW6<HHaQBU6<HDY@LHaP045:D@Q1BU5:D248@01ABU6<HLiacW6<H0
1QBU00H@Q1BU5:DDYA245:D26<H00acW6<HHaP026<H27>L01AS65:DDYABU
6<H00QBU0aS611240QBU0a240QBU00LHaQBU5:DDYA245:D@Q0025:D248@0
1ABU6<HDYAS648@00QBU00<@Q1BU5:D011S600@DYAS66<HHaP<DY@046<HL
iacW6<H35:D26<H011245:D@Q1BU11S600DLiaBU6<HDYAS6008Li`8HaP8D
Y@<HaP057>LHaQS66<HDY@046<H00aBU6<HHaP037>L76<H25:D00a246<HL
i`027>L01ABU48@DYAS67>L00aBU00@HaQcW6<HDY@8HaP0448@DYABU6<H3
5:D011cW6<HDYA240QS60QBU00@@Q1BU5:D@Q08DY@8Li`8HaPLDY@036<HD
YAS6008DY@<HaP<DY@8HaP045:DHaQS68@P27>L66<H011cW6<HHaQS60QcW
1AS60acW11S600HDYA245:DHaQBU6<H25:D47>L26<H01ABU48@@Q1BU48@0
0QBU00/@Q0aS6<HLib485:D@Q0aS48@DYAS600@DY@@@Q0035:D@Q124008@
Q0045:D@Q1BU5:D248@00`aS48@@Q0035:D00a245:DDY@0248@236<348@0
0`aS48@DY@0848@00aBU48@@Q0026<H01ABU36<@Q1245:D00Q2400HDYA24
36<@Q0aS48@236<00a245:D@Q00348@01QBU36<DYABU6<HLi`8HaP095:DH
aQS67>LQ21S65:D@Q1BU008HaP035:D@Q1BU008HaP035:D@Q124008DY@05
6<H@Q12436<@Q0036<H00aBU48@<H`0548@01ABU6<HHaQS648@01QBU00@H
aQcW6<HHaP<@Q0<DY@0548@DYABU6<HDY@0248@35:D248@00`aS48@@Q003
48@00aBU48@DY@035:D00a245:D@Q0035:D011246<HHaQS60QBU0aS60QBU
0Q2400@DYA245:D@Q0<DY@<@Q0<DY@056<HDYABU48@DY@0248@26<H248@0
1`aS48@DYA2436<@Q1BU00@<H`<DY@8@Q0@DY@0448@<Ha2448@236<348@0
11BU48@<H`aS0Q240QBU11240QS60QBU00<<Ha245:D00QBU0Q240ABU0A24
0@aS00000`@Q00048@0712401P00124HaS6<9BTLi`<U:@<Q208HaP058@PU
:B487>LDY@026<H27>L36<H01AcW6<HLiacW6<H00acW0aS61AcW0QS60QBU
00<HaQBU6<H01ABU0QS600DLiaBU5:DHaQBU008HaP035:DHaQBU008DY@03
6<HLiaBU008DY@8HaP8DY@036<HLiaS600DHaP<DY@047>LHaQBU5:D26<H0
0aBU48@HaP026<H00aBU6<HLi`025:D011S65:DHaQS611BU00@LiaS65:DH
aP<DY@8@Q08DY@036<HDYAS600DHaP035:D@Q1BU00HDY@0648@DYABU6<HD
YA240QBU00<LiaS65:D00PaS00L@Q1BU5:D@Q0aS5:DHaP025:D011245:D@
Q1240QBU00DHaQ245:DDYAS600@DY@<HaP037>LHaQcW008HaP@DY@<Li`<D
Y@8HaP8DY@0548@DYA245:DLi`026<H00a245:DHaP036<H02AcW6<HDYABU
6<HLib487>LHaP047>L00aS65:DHaP046<H35:D37>L76<H37>L011S65:DH
aQS60QBU00<@Q1BU6<H00aS611BU00@HaQBU5:DDY@<HaP035:DHaQS6008H
aP8@Q0045:DHaQS66<H25:D00a245:DHaP026<H45:D01QS65:DDYABU48@H
aP8DY@DHaP095:DHaQS66<HLiaS67>LHaQBU00<HaP067>LHaQBU6<HLiaS6
11cW00THaQcW7>LHaQcW6<HDYAS67>L00QS60Q240aBU0aS600<LiaS65:D0
1ABU00<@Q1BU5:D00a2400LDYAS65:DDY@aS48@DY@026<H011BU48@@Q1BU
0Q2411BU0a2400<<HaBU48@01QBU1Q2400<DYA2436<00PaS00LDY@aS36<<
Ha245:D@Q00236<00aBU48@DY@025:D348@25:D248@35:D748@00`aS48@@
Q0025:D448@00aBU48@@Q0025:D76<H011245:DDYABU0QS600<DYAS65:D0
0QBU0Q240aBU0Q2400@DYAS65:D@Q0<DY@8@Q0<DY@0448@<Ha2448@26<H4
5:D01a245:DHaQBU6<HDYA2400<DY@0348@DYA24008DY@0548@DYABU5:D@
Q00236<248@65:D248@00`aS48@DY@085:D00aS65:DDY@085:D011245:DD
YABU0a2400DDYA245:DDYAS6008DY@036<H@Q12400<@Q0065:D@Q12448@D
YAS60QBU00@<Ha245:D@Q0@<H`<@Q0045:D@Q1BU48@25:D448@00aBU48@<
H`0248@00aBU48@@Q00248@00`aS48@@Q00348@236<248@00aS65:DDY@04
5:D011245:D@Q1BU0@aS00001@0012448@@Q00001`@Q00L@Q2e[:DXQ22DY
8@PLi`038@P00acW6<HQ20029BT00b486<HHaP027>L021S65:DHaQS68@PL
iaS67>L28@P26<H27>L26<H011BU6<HHaQcW0QS60aBU0QS600DDYAS66<HH
aQBU00DHaP075:DHaQS65:DHaQBU6<H00QBU0QS60QcW11BU0aS60QcW0QS6
00@LiaS66<HDY@<HaP8DY@DHaP@DY@<HaP@DY@036<HDYABU008HaP8DY@8H
aP8DY@0448@DYABU6<H45:D36<H35:D00aS65:DDY@095:D00a245:DDY@02
6<H02ABU48@@Q0aS48@DYA245:DHaP025:D01A245:DDYAS65:D00a2400@D
YAS66<HDY@8@Q0035:DHaQS600<HaP047>LHaQS66<H45:D021S67>LLiacW
6<HDYAS67>L25:D00aS65:DDY@025:D66<H01ABU6<HHaQS67>L011S60acW
00<HaQcW6<H01AS60QBU00HHaQBU6<HLib487>L26<H27>L46<H00b487>LH
aP025:D01AcW5:DDYAS65:D011S600@DYA2448@DY@<HaP035:DHaQS6008H
aP8DY@046<HDYABU5:D348@00aBU6<HDY@036<H00aBU6<HDY@036<H55:D0
0a245:DDY@026<H35:D46<H27>L26<H25:D26<H00aBU6<HHaP026<H01QcW
6<HLiacW6<HLi`8HaP8Li`LHaP045:D@Q1BU5:D36<H00aBU6<HLi`026<H0
11BU48@@Q1240aBU0a240aBU0Q2421BU00@@Q1BU5:DDY@8@Q0035:D@Q1BU
008@Q0045:D@Q1BU5:D348@00aBU48@@Q0025:D0112436<@Q1BU0Q240PaS
00D@Q1BU5:D@Q0aS00@@Q08DY@8@Q0085:DLiaS65:D@Q1BU6<HDY@<@Q08<
H`<@Q00336<@Q124008DY@0748@DYA2436<@Q1BU7>L00aBU00<HaQcW7>L0
0QS600<DYA245:D00aBU00PHaQBU6<HHaQBU48@<Ha240QS600HDY@aS36<@
Q1BU6<H25:D011245:DDYA240aBU00`<Ha245:DLiaS65:D@Q1BU48@DYAS6
7>L26<H00a245:DDY@035:D448@35:D011246<H@Q1240PaS0a240QBU0Q24
00<<Ha2448@00QBU00P@Q1BU5:DHaQBU6<HDYAS611BU00<HaQBU6<H00QBU
00@@Q1BU5:DHaP8DY@<@Q08DY@0648@DYA246<HDYAS60QBU0PaS00<@Q1BU
5:D00Q2400@DYAS65:DDY@8@Q00436<@Q0aS36<248@011BU48@DYABU1A24
00<DYA245:D01A2400<DYA2448@02Q2400`<Ha245:DDYAS65:D@Q1BU6<HD
YA245:D248@000848@0500048@@Q1240000212401`0012448AS6<H`Q21S6
00@Q208U:@<Li`8U:@037>LHaQcW00@HaP8Li`<HaP8DY@036<HLiaS6008H
aP038@PLiaS6008HaP037>LHaQS6008DY@8@Q0045:DHaQBU6<H35:D36<H3
5:D00aS65:DHaP046<H00aBU6<HDY@026<H00aBU6<HHaP025:D021S67>LL
iaS65:DHaQcW5:D26<H00acW6<HHaP075:D26<H25:D011S67>LHaQS611BU
1AS600<DYAS65:D00QBU0QS600@DYA2448@DY@<HaP0348@HaQS600<@Q0<H
aP035:D@Q1BU00<Li`<@Q0DDY@8@Q08DY@0448@<Ha245:D26<H25:D00a24
6<HDY@0248@65:D00a245:DHaP027>L011S65:DDYAS60QBU00<@Q1BU5:D0
0QcW0aS600<DYAS65:D00QS60aBU00<HaQBU6<H021BU0QcW00@Q21cW7>LL
i`<HaP8DY@<Li`036<HDYABU008Li`8HaP075:D@Q1S66<HLib487>L011S6
00<LiaS67>L00QcW00HHaQBU5:DDYAS67>L25:D01a245:DDYABU6<HDYAS6
00<DY@8HaP<DY@046<HDYABU5:D348@01ABU6<HDYAS65:D00aS600<DYAS6
5:D00QBU0QS60QBU00<@Q1S66<H00aBU2QS600@DYA245:DHaP8Li`<DY@DL
i`046<HDYABU7>L35:D011S67>LDYABU11S600@DYAS65:DHaP<Li`8HaP03
5:D@Q1BU00HDY@<@Q0035:D@Q1BU00<HaP<DY@0648@DYA2448@DYA240QBU
0a2400<<HaBU48@00aBU0aS600<@Q0aS36<01Q2400<DYA2448@00`aS0Q24
00@8@PaS36<DY@<@Q0035:D@Q124008DY@076<H@Q12448@DYAS65:D00Q24
00<<Ha2448@0112400<<Ha2448@00aBU00D@Q0aS48@DYAS6008DY@0548@H
aQcW7>LHaP035:D26<H248@011BU6<HDYABU0Q2400HDYAS65:D@Q0aS48@9
5:D748@45:D248@25:D011S648@DYA241QBU00@HaQBU5:DDY@<@Q0075:D@
Q0aS36<@Q1BU6<H01ABU00<HaQBU48@01aBU00@HaQBU5:DDY@<@Q08DY@07
6<HDYABU5:D@Q1BU48@00QBU0Q2400<DYA245:D00QBU00@HaQBU5:DDY@8@
Q0055:D@Q0aS48@DY@0248@01PaS48@@Q12436<@Q0<<H`8@Q0045:D@Q124
48@55:D248@010aS48@<H`aS0Q240QBU1A2400@<Ha245:D@Q0<<H`0348@D
YABU008@Q0@DY@8@Q04DY@4<H`0000<48@0012400P@Q00<000@Q124010@Q
00D@Q2U:9BTQ22DY00<Li`038@PU:AcW008Li`8U:@047>LHaQcW7>L26<H2
7>L26<H01ABU6<HHaQBU6<H00QcW00<DYAS66<H00R4800@LiaS66<HHaPLD
Y@@HaP035:DHaQcW00<DY@<HaP8Li`8HaP045:DHaQS67>L36<H01ABU6<HD
YA246<H00QcW0aS600@LiaS65:DHaP8Li`8DY@036<HDYAS600@DY@8HaP03
5:DHaQS600<HaP<DY@8HaP<DY@8Li`035:D@Q12400<DY@8@Q0046<HLiacW
5:D248@45:D01A246<HHaQBU48@00QBU00@LiaBU5:D@Q08DY@<@Q08<H`03
48@DYABU00<@Q0066<HDYA2448@DYAS611BU00<@Q1BU5:D00QBU00@HaQ24
48@DY@<Li`8HaP8DY@046<HDYAS65:D37>L00aS65:DDY@025:D00aS65:DH
aP035:D00acW6<HHaP065:D36<H011cW8@PLib481QS60QcW0QS60QcW0QS6
0QBU0aS600@LiaS67>LHaP8Li`@HaP047>LHaQS66<H25:D26<H00acW5:D@
Q0035:D00a245:DHaP036<H35:D46<H55:D26<H248@01QBU6<HLiaBU6<HD
Y@8HaP035:D@Q12400HDY@@HaP035:DHaQS600<HaP037>LHaQBU00<HaP8D
Y@<HaP@Li`HHaP8DY@<HaP8DY@8HaP045:DHaQS66<H27>L26<H01AcW5:DD
YABU6<H00QBU0Q240QBU00<@Q1BU5:D00a2400@DYAS66<HDY@@@Q08DY@8@
Q0035:D@Q12400@@Q0DDY@046<H@Q1BU48@25:D248@010aS48@<H`aS0a24
0PaS00H@Q0aS48@@Q0aS48@35:D0112436<@Q1240QBU00<@Q1BU48@00aBU
00<HaQ2436<00PaS0Q2400<<Ha2448@01Q2400<DYA245:D00aBU00<@Q1S6
6<H00QcW0QBU00<HaQBU5:D00QBU0QS60QBU0a2400HDYA2448@<Ha246<H2
5:D00a245:DDY@025:D248@00aBU48@@Q0025:D00aS65:DDY@0448@36<H0
0aBU48@DY@026<H00aBU48@DY@025:D26<H748@010aS48@DYAS60QBU00<@
Q1S65:D00Q2400<DYAS65:D01ABU0QS600DDYA2448@@Q1BU008@Q0TDY@04
48@DYABU6<H25:D01QS65:DDYABU48@DY@<@Q08DY@0348@DYABU008DY@H@
Q08<H`0348@DYABU008DY@8@Q0055:D@Q1BU48@DY@0248@236<35:D348@0
1aBU48@<Ha245:D@Q1BU008<H`8@Q0046<H@Q12448@35:D011245:D@Q124
0@aS0000100012448@001@@Q00P000@Q248HaSF]:DXDYAcW0QS60QcW1248
00DLibDY8@PQ21cW008HaP8Li`058@PLiaS65:DHaP025:D00aS67>LLi`02
7>L02BDY8@PHaQS67>LQ21cW6<HDY@026<H25:D00aS65:DDY@025:D00aS6
5:DDY@025:D26<H00acW6<HHaP036<H01QcW5:DHaQS67>LHaP<DY@<HaP04
5:DHaQS67>L56<H00aBU6<HHaP025:D01AS65:DDYABU6<H00aBU00<HaQBU
6<H00QcW11BU00<HaQcW7>L00QS600DDYAS66<HHaQ2400<DY@037>LHaQS6
008HaP<DY@046<HDYAS65:D46<H00aBU48@DY@045:D00aS65:DDY@0448@0
0aBU48@DY@0248@011BU6<HHaQS60aBU00<LiaS66<H00Q240QBU00<HaQBU
48@00aBU1AS611BU0QS600<DYAS66<H00acW00DHaQBU48@HaQBU008HaP8D
Y@036<HDYAS600HDY@<Li`<HaP047>LHaQS65:D46<H01acW6<HLiacW6<HD
YA24008DY@DHaP0;7>LHaQcW7>LHaQcW6<HDYAS65:DHaP035:D00aS65:DD
Y@025:D00aS65:D@Q0025:D00a245:DHaP036<H35:D46<H45:D01AS65:DD
YAS65:D021S61aBU0QS600@DYAS66<HLi`HHaP@DY@<HaP055:DHaQcW7>LQ
20036<H021BU6<HDYAS65:DHaQBU48@65:D26<H011BU6<HHaQS60aBU00<H
aQBU5:D011BU00@HaQBU5:D@Q08DY@036<HDYABU008DY@0448@DYABU5:D2
48@00`aS48@@Q0035:D448@45:D348@45:D348@01aBU6<H@Q0aS48@DYA24
00<<H`0548@DYA2436<@Q0035:D010aS48@@Q1BU0Q241ABU00DHaQBU48@@
Q1BU00D@Q0035:D@Q12400D@Q00336<@Q1BU00@DY@8HaP@DY@8HaP067>LH
aQBU5:D@Q0aS0aBU00<@Q0aS36<00Q2400<DYAS66<H00QS600D@Q1BU48@@
Q1BU00H@Q00536<DYAS66<HDY@0248@26<H35:D01QS65:DDYABU6<HDY@<H
aP8@Q08<H`@@Q0036<HDYA2400DDY@036<HDYABU008@Q0046<HDYAS648@5
5:D0112436<@Q1BU0QS611240aBU0Q2400<DYAS66<H00Q240aBU0Q2400<D
YA2436<00Q240QBU0a240QBU0Q2400<<Ha2436<00PaS00d@Q1BU5:DHaQBU
48@DYA245:D@Q0aS48@DY@0248@00`aS48@@Q0025:D448@00aBU48@<H`02
36<0112436<@Q1BU0PaS0Q240QS60a240@aS000412400`00124000051240
11BU<H`U:AS60QcW00<HaQcW8@P00R4800<LiaS68@P00RDY0QcW00HDYAcW
8@PLiaS67>L26<H35:D01AS65:DLiacW9BT00b481QcW00@HaQBU6<HDY@<@
Q0035:DHaQS600<DY@036<HLiaS6008HaP8DY@@Li`DHaP8DY@0548@DYAS6
7>LHaP025:D26<H25:D00acW8@PLi`065:D248@011BU6<HDYABU0QS600@L
iaS65:DHaP8DY@046<HLiacW6<H25:D011S65:DDYABU0Q240aBU00HHaQcW
6<HDYA245:D26<H25:D36<H01ABU48@DYABU6<H00Q240aS600@DY@aS48@<
H`8@Q08DY@<@Q0<DY@8@Q0045:DLiaS65:D448@00aBU6<HDY@025:D56<H0
0aBU6<HDY@025:D011S65:DLiaBU0QS60QcW00@HaQBU6<HDY@@HaPDDY@08
6<H@Q1BU6<HDYAcW6<HLi`@HaP045:DHaQBU7>L26<H01QcW6<HLiaS65:DL
i`@DY@HHaP057>LHaQS66<HDY@026<H35:D01A245:D@Q1245:D00QS60aBU
00<HaQBU5:D011BU11S61QBU00DHaQBU5:D@Q1BU00<HaP8DY@<HaP@DY@03
6<HDYAS600@HaP035:DHaQS6008HaP047>LHaQS66<H35:D00aS65:DHaP02
5:D26<H37>L00aS67>LHaP046<H01A245:DHaQcW6<H00Q241QBU0aS600PL
iaS66<HHaQBU6<HDYA240QBU0QS600<DYA245:D021BU00D@Q1BU48@@Q0aS
008@Q0035:DHaQ2400<@Q0065:D@Q0aS48@DYAS60a240aBU0a240QBU0a24
0PaS00<@Q0aS48@00a2400H<Ha2448@DYAS648@236<00aBU48@<H`0248@2
5:D448@25:D00a245:DDY@0248@236<248@00`aS48@DY@0348@021BU6<HD
YABU48@DYAS65:D348@56<H00aBU48@@Q0035:D548@011BU6<HHaQBU0aS6
00<DYA245:D011240aBU00D@Q0aS48@DYAcW008DY@036<HDYABU008DY@03
6<HDYA24008HaP047>LDYABU5:D648@01QBU48@@Q1245:DHaP<DY@D@Q08D
Y@046<HDYAS65:D348@25:D01Q245:DDYAS65:D@Q0<DY@8@Q0@DY@8@Q005
6<HDYABU48@<H`0248@011BU48@<H`aS0QBU0a2400<DYA245:D00Q2400D<
Ha2448@@Q1BU00@@Q0<DY@0648@<H`aS36<@Q0aS0Q2400T<Ha2448@DYA24
5:D<Ha245:D00Q2400<<H`Q248@01a240QBU0Q240ABU0AS60@aS00000`00
1240000712401P00248HaS6<9BTDY@@Li`056<HQ21cW7>LQ20027>L00b48
7>LLi`027>L28@P011cW8@PLiaS60QBU00@HaQcW9BTQ208HaP037>LQ2248
008Li`8HaP047>LHaQcW5:D248@011BU6<HDYA2411BU0acW00DHaQBU6<HH
aQBU008HaP037>LHaQcW008Li`<DY@8HaP<DY@047>LHaQS66<H25:D011S6
5:DHaQS60QBU00DHaQBU5:DDYA24008DY@036<HLiaS6008DY@056<HLiaS6
6<HDY@027>L011S65:DHaQS611BU00<@Q1BU6<H00QS600D@Q1BU6<HLiaS6
008@Q0045:D@Q1BU48@25:D46<H65:D011245:DDYA240aBU00@<Ha245:DH
aP8DY@0448@DYA245:D36<H85:D46<H011BU6<HDYAS611BU0aS600<LiaS6
6<H00aBU00@HaQBU5:D@Q08DY@DHaP075:D@Q1BU48@DYAS65:D011S60QcW
00@HaQBU5:DHaP8Li`<HaP045:DHaQBU6<H35:D36<H25:D02Q245:DHaQBU
6<HQ21cW6<HDYA240QBU0Q240aBU0QS61ABU00@@Q1BU48@DY@@HaP035:DH
aQS6008Li`036<HDYA24008DY@8HaP045:DHaQBU6<H25:D96<H011BU6<HH
aQS60QBU00HHaQcW7>LLiaS67>L35:D26<H45:D36<H01QBU6<HHaQcW6<HL
i`8HaPDDY@0348@DYABU00<DY@8HaP035:DHaQcW00@DY@046<H@Q1245:D2
6<H011BU6<HHaQBU0Q240aBU11240aBU0a240aBU00@@Q0aS48@DY@D@Q003
36<@Q12400D@Q08<H`8@Q08DY@@@Q00336<@Q12400@@Q0035:D@Q12400D@
Q08<H`0348@DYABU00<HaP045:D@Q1245:D348@01@aS48@DYA2436<00Q24
00<DYA2436<00a2400<DYA2448@00Q2400XHaQcW5:DDYA245:DLib487>LD
Y@<@Q08DY@8@Q08<H`<DY@046<HDYAS66<H55:D00a2436<@Q0025:D248@4
5:D26<H00aBU6<HDY@025:D00a245:DHaP025:D26<H25:D248@236<01A24
36<@Q1BU6<H00QBU00@@Q1S65:DHaP8DY@0348@DYABU008DY@<@Q0@DY@D@
Q0035:DHaQBU00DDY@8@Q0035:D@Q124008@Q0036<HDYABU00<@Q08DY@@@
Q0035:D@Q0aS008@Q0<DY@8<H`0948@DYABU5:D@Q1BU6<HDYAS6008DY@@@
Q0035:D@Q12400<<H`8@Q00436<@Q0aS36<348@00aBU48@<H`0236<748@2
5:D148@136<000@48@0300048@0000D48@056<H]JbDY5:DLi`036<H27>L0
0aS67>LLi`028@P27>L00aS67>LLi`027>L00b487>LLi`046<H37>L01AS6
7>LQ22DY8@P011cW0aS60QBU00<HaQBU5:D00QBU0Q2400@DYAS66<HLi`DH
aP045:DLiaS67>L56<H00aBU48@DY@035:D66<H25:D011S67>LHaQBU0aS6
0Q240QS600<DYA245:D01QS600@DYAS66<HHaP<Li`<HaP8DY@8@Q0036<HL
iacW008DY@067>LQ21BU48@DYAS60QBU00H@Q1BU6<HDYAS67>L25:D00`aS
5:DHaP025:D00a245:D@Q0025:D248@00aBU48@DY@045:D00a245:DDY@05
6<H25:D01aS65:DDYA245:DHaQBU00@HaP8DY@0548@DYAS66<HLi`026<H0
0acW6<HHaP026<H25:D011245:DHaQBU1AS60QBU0Q240QBU00@LiaBU6<HH
aP8Li`THaP8Li`036<HLiaS600HDY@0448@DYABU5:D26<H012487>LHaQcW
0QBU00<@Q1BU5:D011BU0aS60QBU00<HaQBU5:D00Q2411S60aBU00LLiaS6
6<HHaQ245:DHaP035:D00acW5:DDY@0248@011S65:DHaQBU0aS60QcW0QS6
00@DYAS66<HHaP8DY@066<HLiaS67>LHaQ240QBU00@HaQcW5:DDY@<HaP8D
Y@<HaP8Li`8HaP<DY@@HaP035:D@Q124008DY@8HaP<DY@8HaP035:DHaQBU
008DY@<HaP065:DHaQS66<HDYAS60QBU00<@Q0aS48@01ABU0Q240PaS0QBU
0Q2400@<Ha245:D@Q08<H`0348@DYA2400<@Q0036<H@Q124008<H`@@Q006
5:D@Q0aS48@DYA240PaS00H@Q1BU48@<Ha245:D348@00aBU48@<H`0236<0
0aBU48@DY@035:D00a245:D@Q00348@01ABU48@@Q1245:D00Q2400<<Ha24
5:D00PaS00<@Q1S648@00Q2400@DYAS66<HDY@8@Q0055:DLib487>LDY@03
48@25:D248@00`aS48@DY@035:D46<H00aBU48@DY@0348@35:D248@25:D2
6<H65:D00a245:DDY@046<H35:D00a245:D@Q00336<35:D00aS65:DDY@02
5:D011245:DDYABU0Q2400DDYAS648@@Q1BU008HaP0348@DYAS6008DY@<@
Q0085:DHaQS65:D@Q1BU48@DY@D@Q0035:D@Q12400<@Q00536<@Q1BU6<HD
Y@0236<011246<HDYA240QBU112400<DYAS65:D00Q241aBU00<@Q0aS48@0
0QBU0`aS00<@Q1BU48@02A2400HDYA2448@@Q0aS48@236<01A245:DDYABU
48@00@aS00000`0012448@0612401`0012448AS6;F/Q21S600<Li`038@PL
iacW00<Q208HaP067>LHaQS65:DHaR480bDY00@Q21S67>LHaP8Li`088@PL
iacW6<HLib487>LHaP<Li`036<HDYAS6008HaPLDY@8HaP<Li`DHaP035:DH
aQS600<HaP<DY@8HaP045:D@Q1BU5:D26<H021BU48@DYABU6<HDYAS65:D3
6<H00aBU6<HDY@025:D011S67>LHaQS60QBU00@HaQcW7>LHaP8DY@<HaP07
5:DHaQS66<H@Q1BU48@00QS600@LiaS65:DHaP<Li`045:D@Q1BU5:D26<H0
1A245:DHaQS648@00QBU00<Q21S65:D00aBU00@HaQBU48@@Q0<DY@036<HD
YABU008DY@036<HLiacW00TDY@8@Q08DY@<HaP8DY@@HaP0:5:D@Q1S66<HL
iaS65:D@Q1BU48@25:D36<H011BU6<HHaQS60QBU11S60aBU00<@Q1BU5:D0
0QS600<LiaS66<H00QBU0aS600@LiaS65:DDY@8HaP@DY@<HaP065:D@Q124
5:DHaQ240QBU0QcW00<HaQBU5:D011BU00L@Q1BU6<HHaQBU6<HDY@026<H5
5:D011S65:D@Q1BU0aS60QBU00<HaQBU5:D01aBU0aS600@DYAS65:DDY@@H
aP035:DHaQS600<HaP035:DHaQS600@Li`8DY@<HaP035:DHaQBU00<DY@8H
aP<Li`056<HDYA245:DHaP035:D248@00aBU48@DY@026<H;5:D26<H35:D2
6<H55:D01AS65:D@Q1BU6<H01QBU00@<Ha2448@@Q08DY@0448@DYA245:D4
48@010aS5:DDYABU31240QBU1A2400<DYA2448@021241ABU00DHaQBU6<HD
YA2400<DY@0648@<H`aS48@DYA240PaS0Q2400<DY@aS48@00PaS0a2400DD
YAS67>LLiaS600<DY@0448@DYABU5:D648@25:D36<H45:D00a245:D<H`02
48@25:D01QS648@DYABU6<HLi`8HaP055:D@Q1BU5:DHaP0248@35:D248@0
0aBU48@DY@0548@25:D011S65:DHaQBU0Q240aBU0a2400<DYAS66<H00Q24
1QBU0a2400<DYA246<H00QS600DDYA2448@@Q1BU00D@Q08DY@@@Q0035:D@
Q124008@Q0046<HDYA2448@35:D348@35:D011S65:DDYABU0QS60aBU0a24
00@<Ha245:DDY@@@Q0035:D@Q124008@Q0055:D@Q0aS36<@Q00336<448@3
36<248@236<00004124000@Q000212400`0012448@0212401`Q26<HaS2DY
5:DLiaS6008Li`046<HLiacW8@P47>L011S65:DHaQcW0bDY00<Q21cW7>L0
0QcW00DHaQcW7>LLiaS6008Li`038@PLiacW008Q208Li`046<HDYAS65:D2
6<H25:D248@25:D011cW8@PQ21S60QBU0QcW00<DYAS66<H01AS611BU00<H
aQBU5:D011S60aBU0QS600<DYAS65:D01AS600<DYAS66<H00acW00<DYAS6
6<H00QcW00<HaQBU6<H00QS600<LiaS65:D01ABU00H@Q1S67>LLiaS65:D2
6<H35:D26<H35:D26<H35:D26<H011cW6<HDYAS61aBU00HHaQ2448@@Q1BU
6<H27>L00aBU6<HDY@036<H00aBU48@DY@025:D00a245:DDY@026<H00aBU
6<HDY@026<H25:D56<H011cW6<HHaQBU0Q241QBU00<HaQBU5:D00aS600LD
YA245:DDYA245:D@Q0026<H00acW6<HHaP035:D01AS67>LLiacW6<H00QBU
00<HaQBU6<H00Q240QBU0QS60QBU0Q2400@DYA245:DHaP8Li`<HaP0348@D
YABU00<DY@8HaP055:D@Q1BU5:DHaP045:D26<H35:D00aS67>LHaP045:D3
6<H35:D66<H011BU7>LHaQS60acW0QBU00@HaQcW6<HDY@@HaP037>LQ21S6
00<HaP035:DHaQ24008@Q0055:DHaQS66<HDY@056<H25:D011246<HHaQBU
0Q240aBU00@HaQBU5:DDY@8HaP@DY@086<HDYABU6<HLiaS65:DHaP<DY@8@
Q0045:DHaQBU48@25:D26<H35:D248@011BU48@DYABU112400DDYA2448@<
HaBU008@Q0045:D@Q1BU5:D248@336<01A245:D@Q12436<01a2400<DYA24
48@00Q240QBU00@@Q0aS36<@Q0<DY@8@Q0035:DHaQBU00<@Q0035:D@Q1BU
00L@Q00336<@Q124008@Q00436<@Q12448@25:D36<H011cW6<HHaQS61ABU
00<HaQBU48@00Q2400<DYAS66<H01ABU00<HaQBU5:D00Q240QBU00<HaQBU
5:D00QBU1QS60aBU00@@Q1BU5:D@Q08DY@0448@DYA245:D648@011BU6<HD
YAS611BU0Q2400HDYA245:D@Q1BU6<H25:D448@011S67>LDYABU0Q241ABU
00HHaQBU5:D<Ha2436<548@35:D348@00aBU48@DY@055:D348@25:D248@0
11BU6<HHaQS60aBU0QS60aBU00<HaQ2448@01A2400<DYA2436<00Q240QBU
0Q2400DDYA2448@@Q0aS00@@Q00436<@Q12436<348@1248000@48@030004
8@@Q00848@0800048@Q25:D]Jb4848@HaP8Li`049BTYBR488@P27>L00b48
7>LLi`057>L00b489BTU:@028@P01BDY8@PLiacW8@P02QcW0aS60QcW00<H
aQBU5:D011BU0acW0QS600<DYAS66<H00QcW00HHaQcW7>LQ21cW6<H25:D0
1aS65:D@Q1245:DHaQBU00@HaP075:DHaQS65:DHaQBU6<H01ABU11S600<D
YAcW7>L011S600@LiaS65:DDY@8HaP037>LHaQS600DDY@<Li`036<HDYABU
008HaP035:DHaQS6008HaP035:DHaQBU00LDY@<HaP8Li`<DY@8HaP065:DH
aQS67>LHaQBU0QS600@LiaS66<H@Q08DY@056<HDYABU5:DHaP025:D01QS6
7>LLiacW5:DHaP8DY@<HaP037>LHaQS6008DY@056<H@Q12448@DY@026<H2
7>L01AS65:DDYABU7>L00aS60aBU0QS60QBU00<@Q1BU5:D00QS61QcW0aS6
00@LiaS66<H@Q0HDY@8@Q08DY@036<HDYABU008DY@XHaPDDY@<HaP@DY@8H
aP<DY@8HaP0448@DYABU5:D36<H00acW6<HHaP035:D46<H25:D26<H00acW
6<HLi`036<H00aBU6<HHaP056<H37>L26<H01aBU48@<HaBU6<HLiaS6008D
Y@@HaP045:DHaQBU6<H35:D248@95:D248@01aBU6<HDYABU48@DYAcW008H
aP<DY@0448@HaQS65:D248@011BU6<HDYABU0a2400@DYAS66<HDY@8@Q003
5:DHaQS600<DY@@@Q0<DY@076<H@Q12436<@Q1S65:D00Q2400@<Ha245:DD
Y@D@Q00536<@Q12448@DY@0548@00aBU48@<H`0248@00aS65:D@Q0025:D3
48@00aBU6<HHaP025:D248@00`aS48@@Q00548@00aBU48@<H`0248@01AS6
5:DDYA245:D00R4800@LiaBU36<@Q08DY@047>LHaQBU6<H25:D00aS65:DH
aP027>L65:D01A245:DDYABU48@00QBU11S600<DYA2448@00QBU0Q2400<D
YA2448@00Q2400@DYAS65:DHaP<@Q08<H`0348@DYABU008DY@0348@DYABU
008@Q0055:D@Q1245:D@Q0025:D348@00aBU6<HDY@0248@011S67>LHaQBU
0a240QBU0QS600LDYA2448@<Ha245:D@Q0035:D348@01aS65:DHaQBU6<HD
YAS600<DY@<@Q0035:D@Q12400@@Q08HaP047>LDYA245:D26<H00aBU48@@
Q00448@00aBU48@@Q00336<348@00aBU48@@Q00436<00a2436<<H`0648@2
36<148@136<000848@0300048@@Q00L48@057>L]JacW48@HaP027>L01248
9BTU:AcW0QS600DLib487>LHaQcW008HaP047>LQ22DY9BT38@P97>L26<H4
7>L66<H25:D00aS65:DHaP025:D27>L26<H00aBU6<HHaP037>L01AS67>LH
aQBU6<H00QBU0aS600<@Q1BU6<H00QS600<DYAcW7>L00QBU0QS600<LiaBU
6<H011S600@DYAS65:DDY@8Li`8HaP055:DHaQcW8@PHaP035:D26<H25:D0
0aS65:D@Q0025:D011cW6<HHaQS60aBU00@@Q1BU7>LLi`8DY@0348@HaQS6
008DY@8HaPHDY@<HaP<DY@DHaP037>LHaQBU008DY@056<HDYABU48@Li`02
5:D00a246<HHaP025:D26<H011cW6<HHaQS60Q240QBU00TLiaS66<HHaQBU
6<HDYA245:D00Q2400<HaQBU7>L00acW00DDYAS65:DHaQcW008DY@0348@D
YAS6008DY@0348@DYA2400@HaP035:DHaQcW008HaP077>LHaQS65:DHaQBU
6<H00aBU0aS60Q2400@DYAS66<HHaP8DY@036<HDYAS600LHaP@DY@0348@D
YABU008HaPPDY@8HaPDDY@056<H@Q1245:DLi`026<H25:D46<H00aBU6<HH
aP046<H00acW6<HHaP026<H25:D26<H47>L26<H45:D248@25:D36<H45:D0
1QS65:DDYAS65:DHaP8DY@8@Q08DY@056<HDYABU48@DY@0348@011BU6<HH
aQS60QBU00<HaQBU48@00Q2400DDYAS65:DDYA2400DDY@<@Q08DY@<@Q003
5:D@Q1BU008HaP8DY@8@Q08DY@8@Q08<H`<@Q0035:D@Q1BU00<@Q08DY@D@
Q08<H`0748@DYA2436<@Q1BU48@00PaS11241ABU0QS600<DY@aS48@00Q24
0QS60Q2400<<HaBU5:D00Q2400<<Ha245:D01a2400LDYA246<HLibDY7>LD
Y@0236<25:D26<H248@25:D00aS65:DHaP025:D00aS65:DHaP026<H75:D0
0aS65:DDY@025:D01QcW6<HHaQBU48@DY@H@Q08DY@0348@DYABU008@Q08<
H`0448@DYABU5:D348@25:D00aS648@DY@0348@65:D011S648@<HaBU0QS6
00@DY@aS48@DY@8@Q0045:DHaQBU5:D748@011BU48@DYABU0Q2411BU0Q24
00<DYAS65:D00Q240aBU00P@Q0aS48@@Q0aS6<HLiaS60Q2400<DYAS66<H0
2Q240PaS0Q2400@<Ha2436<DY@@@Q00336<8@PaS00<@Q0@<H`8@Q08<H`00
00H000@Q124000@Q000412401P00248DYC6<9BTDY@<HaPHQ20037>LHaQS6
008Li`098@PHaQS67>LQ21cW8@PHaQcW00<Q20037>LHaQS6008Li`049BTQ
21S65:D46<H00aBU6<HHaP026<H00aBU6<HDY@056<H012486<HDYABU0QcW
0aS60QcW00<DYAS65:D00aBU00LHaQcW7>LHaQBU6<HDY@056<H65:D011cW
6<HQ22480QS600@DYAS67>LLi`@HaP065:DHaQS67>LHaQBU0aS60QBU00@H
aQ245:DDY@<HaP8DY@0348@DYAS6008HaP035:D@Q1BU008HaPDDY@@HaP04
5:DHaQS66<H25:D26<H25:D46<H25:D26<H01ABU48@HaQS67>L00QBU00HH
aQcW5:DHaQcW8@P27>L26<H01ABU6<HDYABU6<H00QcW00@HaQ246<HHaP<D
Y@036<HDYABU008HaP038@PLiacW00<Li`065:D@Q1246<HLiaS60QBU0QS6
00@DYA245:DLi`8HaP037>LHaQS6008DY@8HaP8DY@036<HDYABU008DY@04
6<HDYABU48@35:D011S65:DHaQBU0QS60aBU00<@Q1BU6<H00QcW00DHaQBU
5:DDYAS6008DY@0348@DYABU00<DY@0448@HaQBU6<H25:D46<H25:D36<H0
1A245:DDYAS67>L011BU1AS611cW0QS600<DYAS66<H00QcW00DHaQBU6<HH
aQcW008HaPDDY@036<HDYAS6008DY@@HaP035:DHaQS6008HaP<@Q0036<HD
YABU008HaP8DY@8@Q08DY@<@Q08DY@046<H@Q1BU5:D26<H25:D648@031BU
6<HDYABU48@DYA245:D@Q1BU6<HDY@<@Q0035:DHaQBU00<@Q0036<HLiaBU
00<DY@8@Q00436<@Q1245:D348@01ABU48@@Q1245:D01A2400@DYA2448@@
Q08DY@0548@<Ha2448@DY@036<H448@25:D248@35:D548@01@aS48@DYABU
48@00PaS00<@Q1BU48@011BU0aS600<Lib485:D00QBU00<Lib486<H00aS6
0QBU0QS60QcW00<HaQBU5:D00aBU0Q241QBU0aS611240aBU0a240aBU0a24
00<HaQBU48@00PaS00<DYA245:D01ABU00<HaQBU6<H00QBU00<@Q1BU5:D0
0a240QBU00@@Q1BU48@@Q0DDY@<@Q0PDY@0448@<Ha2448@26<H75:D26<H2
48@00aBU48@DY@0348@01QBU48@@Q1245:DHaP@DY@0448@DYA245:D248@0
1PaS5:D@Q12436<@Q0<<H`<@Q00336<@Q12400<@Q00436<@Q0aS36<248@0
1QBU48@<H`aS48@DY@8@Q048@P0000<48@0012400`@Q00<000@Q12400`@Q
00@DYBe[9BTDY@8HaP047>LQ22488@P27>L01QS67>LLiaS67>LQ20@HaP8L
i`036<HLiacW008Q208Li`8DY@047>LQ22487>L46<H011cW6<HDYABU0aS6
11BU0QS60acW11S600<LiaS66<H00QcW11S600HDYA246<HLiaS648@25:D2
6<H01aBU6<HDYABU6<HDYAS600@DY@046<HLib488@P27>L011S65:DDYABU
0QS60QBU0aS600@LiaS67>LHaP8DY@036<HDYABU008DY@056<HDYAS66<H@
Q0025:D01A246<HHaQBU48@00aBU0QS600<DYAS65:D00QS60QBU00<@Q1S6
7>L00QcW0QBU0QS600<@Q1S66<H00QcW00DHaQBU5:DHaQcW00<DY@8HaP8D
Y@<HaP035:DHaQcW008Li`8HaP@DY@<HaP035:DHaQBU008HaP8DY@046<HD
YA246<H28@P26<H37>L00aBU48@HaP035:D01AS648@<HaBU48@00QS60QBU
0QS600<LiaS65:D011S60aBU00<HaQBU6<H00QBU0a2400LDYAS66<HDYA24
5:DHaP025:D26<H25:D00aS67>LLi`025:D26<H01QBU48@@Q1S65:DHaP8D
Y@0548@DYABU5:DHaP025:D011246<HDYAS611BU0QS611BU00<HaQcW6<H0
0QS600<DYAS67>L00QcW00LHaQcW6<HHaQBU6<HDY@027>L011S65:DDYABU
0QS600@LiaS67>LDY@<@Q08HaP045:DHaQS65:D46<H45:D00a245:D@Q003
6<H00aBU48@DY@045:D00aS65:DDY@0236<02ABU48@HaQ245:DHaQBU6<HD
Y@0448@35:D00a245:D@Q00248@25:D348@01QBU48@@Q1BU6<HDY@8@Q08H
aP8DY@056<HDYA2448@DY@0348@25:D00aS648@@Q00548@01ABU48@@Q1BU
48@00PaS00<@Q1BU5:D0112400<<HaBU5:D00QBU0a2411BU0Q2411BU1A24
0aBU0`aS0Q240aBU0QS600HDYAS67>LLiaBU48@25:D66<H01ABU6<HLiaS6
5:D00QS60QBU00L@Q0aS48@DYAS65:D@Q0025:D26<H25:D011245:D@Q0aS
112400<<Ha245:D00Q240QBU00<HaQ2436<00`aS0Q240aBU00<@Q1BU5:D0
0aS600<DYA245:D00a241ABU0a241ABU0Q240QBU00DHaQBU48@DYA2400<D
Y@<@Q0035:D@Q1BU008DY@036<HDYAS6008DY@0548@DYA2448@DY@0248@0
0`aS48@DY@0348@00aBU48@DY@025:D011245:D@Q1BU1A2400<<Ha2448@0
0`aS11240PaS0Q2400<<Ha2448@00PaS0Q2400<DYA2436<011240`aS0003
12400`0012448@03124020001248@QcW<H`U:A245:D26<H27>L011S67>LL
iacW0QS600<LiaS66<H00aS611cW0QS60acW00<HaQcW6<H00QcW00<Q21cW
6<H00QcW0aBU0QS60QBU0QS600<DYAS65:D01QcW0QS60aBU0QS600@DYAS6
5:DDY@<HaP<Li`8HaP077>LHaQBU5:DHaQcW6<H00QBU00<HaQBU6<H00QcW
00DQ21cW7>LLib4800XHaP057>LHaQcW8@PHaP025:D36<H25:D00a245:DD
Y@035:D011245:DHaQBU11S611BU00@HaQBU6<HHaP8DY@0348@DYAS600<H
aP047>LHaQBU5:D26<H011cW6<HDYABU0QS600PLiaS66<HHaQBU6<HDYA24
0QS600@LiaS66<HHaP8Q20047>LHaQBU5:D66<H01AcW6<HLiaS65:D00QS6
00DDYAS65:DHaQcW00<Q20069BTLiacW6<HDYA240aBU0Q241ABU21S600@D
YAS66<HHaP8DY@066<HLiaS65:D@Q1S611BU00@@Q1BU5:D@Q0<DY@8@Q003
5:DHaQS600HHaP<DY@0548@DYABU5:DHaP045:D00a245:DDY@025:D26<H0
0aBU48@@Q0025:D01AS65:DDYABU6<H011BU0aS600PDYAS67>LHaQcW6<HD
YAS61AcW0QS600<DYAS66<H00QS600@DYAS67>LDY@8@Q0<HaP035:D@Q1BU
00<Li`046<H@Q1S66<H55:D26<H35:D248@011BU6<HDYABU0Q2400<DYA24
48@00QS60QBU0Q2400<DY@aS48@00aBU0Q241ABU00@@Q1BU5:DDY@8@Q0HD
Y@0348@DYABU008DY@046<HLiaS65:D248@01AS65:DHaQBU6<H00a2400DD
YAS65:D@Q1BU008@Q0075:D@Q12448@DYA245:D00a2411BU0Q2411BU0Q24
1ABU00P@Q1BU5:DDYA245:D@Q1BU1A2400@<Ha245:DLi`@HaP077>LHaQS6
6<HLib487>L01ABU00DHaQBU6<HHaQcW008HaP<@Q0055:DHaQBU5:D@Q002
5:D011S65:DDYA240QBU1a240aBU00<@Q1BU48@00aBU112400@DYA245:DD
Y@8HaP045:D@Q1BU6<H25:D01QS65:DHaQ245:D@Q08DY@<@Q0055:D@Q124
5:D@Q0035:D348@35:D011245:DDYABU0Q2400<<Ha245:D00QBU00<@Q1BU
5:D00aBU0a240aBU0Q2400DHaQBU5:D@Q0aS008@Q0065:D@Q1BU5:DHaQBU
0Q240QBU0Q2400@<Ha245:D@Q08<H`8@Q0<<H`0348@<H`aS008@Q003248<
H`aS008DY@@@Q08<H`0448@DYABU48@1248000848@0300048@0000L48@05
6<HaS2485:DHaP025:D36<H37>L011S67>LLiacW0aS600<Lib487>L00QS6
00<DYAcW7>L00acW0QS600<DYAcW7>L011cW00@HaQBU5:DDY@<HaP@DY@8L
i`8HaP057>LQ21S66<HDY@036<H25:D36<H00aBU48@DY@026<H00acW6<HH
aP026<H01AcW5:DHaQS67>L011BU0aS611cW00HQ21cW7>LLiaS67>L26<H0
11BU7>LHaQBU0QS600<LiaS66<H00aBU0QS61QBU00<HaQBU48@00QBU0QS6
1ABU00@HaQBU6<HHaP8DY@036<HDYAS6008HaP0348@DYAS600<Li`8DY@8H
aP067>LHaQBU5:DHaQBU0QS600<DYAS66<H00aBU00<HaQcW6<H00QBU00DL
ib487>LLiaS6008DY@@HaP055:DHaQcW6<HDY@026<H35:D01AS67>LLib48
9BT00R4800@HaQBU5:D@Q0<DY@@@Q0@DY@046<HDYAS67>L36<H011245:DH
aQcW0aBU00<HaQcW6<H01aBU00HHaQBU48@DYA245:D348@25:D021S65:DH
aQcW6<HDYA246<H35:D00a246<HHaP025:D011245:DHaQS611BU00DHaQBU
5:DDYA2400@DY@046<HDYABU6<H25:D46<H01QBU6<HHaR487>LHaP8Li`04
6<HDYAS66<H27>L00aS65:DHaP026<H27>L45:D36<H25:D00a246<HDY@02
6<H011BU6<HDYABU0QS600<@Q1BU5:D00QS600DDYAS65:DDYA2400<DY@8@
Q00336<DYABU008DY@0648@DYABU48@DY@aS112400DDYA2448@DYA24008D
Y@0448@DYA245:D348@25:D01AS65:DDYA245:D0112400@HaQcW6<HHaP8@
Q0<DY@036<HDYABU008@Q0DDY@@@Q08DY@0348@DYA24008@Q08DY@0348@D
YA2400@DY@8@Q0<DY@0348@DYABU00<DY@0548@DYABU48@DY@0248@00`aS
48@DY@0248@25:D36<H27>L26<H011BU6<HLiaS60QcW0QBU00@@Q1S66<HH
aP8DY@<HaP065:D@Q1245:DHaQBU112411S600<DYA245:D00Q240PaS00@@
Q0aS36<@Q08DY@8@Q08DY@8@Q00736<@Q1BU6<HDYA245:D00QS61QBU0a24
00<HaQ245:D00Q240QBU212400<DYA245:D00QBU0a2400<DYA245:D00a24
00HDYA2436<<Ha245:D26<H021BU48@@Q1245:D@Q1BU48@25:D00a245:DD
Y@0236<248@25:D00a245:D@Q0035:D548@00`aS48@@Q00248@436<01124
36<@Q1241PaS00@@Q0aS36<@Q0<<H`0448@DYA2436<12480000300048@@Q
00<48@0300048@@Q00848@05248HaRe[8@PDY@036<H37>L011S67>LLiacW
1AS600<LiaS66<H00aS60acW00<HaQBU6<H00aS600<DYAcW7>L00RDY0QcW
0QS600<Q21S66<H00QS60acW0QS600<Lib486<H00QS611cW0QS600DLiaS6
6<H@Q1BU008HaP<Li`HHaP@Li`8HaP037>LHaQS600HLi`8HaP<DY@0348@H
aQS600@HaP037>LQ2248008HaP095:DHaQS65:DHaQBU6<HDYAS600<DY@03
6<HLiaS600<HaP<DY@047>LHaQBU5:D26<H00aBU48@DY@056<H45:D01QS6
5:DDYAS65:DHaP8DY@0348@DYABU00@HaP8Li`046<HDYABU5:D26<H00aBU
6<HLi`036<H011BU7>LLiaS60QBU00<LiaS65:D00QBU00<LiaS66<H00QBU
0QcW0R480QcW11S600LDYA2436<DYAS67>LDY@0248@25:D248@011BU6<HL
iacW0QS600@DYAS67>LHaP8DY@8HaP057>LDYABU48@DY@026<H25:D248@0
0aS65:D@Q00248@011BU48@@Q1BU0QS60aBU0aS61aBU00DHaQBU5:DDYAS6
00<DY@8Li`036<H@Q1BU00<DY@0348@DYAS6008DY@@HaP045:DHaQBU5:D2
6<H27>L00aS65:DHaP037>L011BU6<HHaQcW0aS60aBU00@HaQBU5:DDY@8H
aP8DY@046<HDYABU5:D46<H00aBU6<HDY@025:D26<H00aBU48@@Q0025:D0
0a245:D@Q0046<H011BU48@DYABU0QS600@DYAS65:D@Q08<H`0348@DYA24
008<H`0348@DYABU008HaP8DY@0348@DYA24008@Q0<DY@0348@DYA2400<@
Q0055:DHaQcW6<HDY@0248@00aBU48@DY@0248@021BU6<HHaQS65:DHaQBU
48@25:D00aS65:DDY@045:D01A245:DDYABU6<H00QBU112400PDYAS66<HH
aQBU6<H@Q1BU112400<DYA245:D0112400<DYA245:D00QBU00<@Q1BU6<H0
0QcW0QS60QBU00H@Q1S67>LQ21cW5:D46<H01A245:DDYAcW6<H00aBU00<@
Q1BU48@011BU00<@Q1BU5:D00aBU00@@Q0aS36<<H`8@Q0<DY@8@Q00336<@
Q1BU008DY@036<H@Q1BU00@DY@@HaP8DY@036<HDYABU00DDY@046<HDYAS6
5:D448@35:D348@25:D248@25:D26<H25:D00a245:D@Q00248@011BU48@D
YA240aBU0Q2400<DYA2448@011240QBU0a2400<DY@aS36<00Q2400@DYA24
48@@Q0<DY@0448@DYA245:D236<348@236<348@436<01A2436<@Q12436<0
0Q2400L<H`Q236<@Q1BU48@<H`0248@136<00003124000@Q00848@050004
8@@Q12400002124011BU;F/Q21240QBU00<HaQcW7>L00QcW1AS60QBU00<H
aQBU6<H00acW0QBU0QS60QcW11S600@DYAS67>LQ208Li`035:DHaQcW008L
i`8DY@036<HLiaS6008HaP@Li`046<HLiacW7>L46<H01AcW6<HHaQBU48@0
0QS600<Lib487>L00QS600<DYAS66<H00QS60QcW00PHaQBU5:DHaQcW6<HL
iaS61AcW0QS611BU00<HaQcW7>L00QBU00<Lib487>L00aS60aBU0QS60QBU
00@@Q1BU6<HLi`8HaP045:DHaQS66<H35:D27>L25:D011S65:DDYABU0QS6
00<DYA245:D01QBU0QS600<DYAS66<H00aS60QBU0aS600<DYAS66<H00QS6
0QBU1QS600<DYAS66<H00QS600DDYAS66<HHaQcW00DHaP035:DHaQcW008L
i`036<HQ224800<HaP067>LHaQBU48@<HaBU0QS600@DYA246<HDY@<@Q08H
aP8Li`046<HLiaS67>L26<H25:D00a245:DDY@026<H55:D01a245:DDYA24
5:D@Q1BU008@Q0035:DHaQBU008@Q0035:DHaQS6008Li`036<HDYA2400<D
Y@0448@DYABU6<H45:D01A245:DQ22486<H00QBU0QS611BU0QS600<DYAS6
7>L00QS60QBU1QS600<DYAS66<H00acW00<HaQcW6<H00QS600<LiaS65:D0
0QBU00DHaQBU5:D@Q1BU008HaP<DY@<HaP045:DHaQS66<H35:D26<H25:D0
1A245:DDYABU48@00QBU00@@Q1BU5:DHaP8@Q0055:DHaQS65:D@Q0025:D0
0a2436<@Q0025:D448@00aBU48@@Q0025:D01AS65:D@Q1BU48@00aBU00<H
aQBU5:D00Q2400<DYA245:D00QS600@DYA245:DDY@<@Q0035:DHaQBU00@H
aP8DY@0348@DYABU00@DY@0348@DYABU008DY@046<HDYABU48@25:D248@2
5:D011S65:DDYA240QBU0a240aBU112400LDYA2448@@Q1BU6<HDY@026<H2
7>L01AS65:DHaQ245:D00QS600<Q21cW5:D00aBU00DHaQBU5:D@Q1BU008L
i`035:D<Ha2400<DY@8@Q0055:DHaQcW6<HDY@0448@236<;48@01QS65:DH
aQBU48@DY@<HaP<DY@036<HDYABU008HaP035:D@Q1BU008DY@0348@DYABU
008DY@@@Q0035:D@Q124008@Q0035:D@Q12400PDY@0648@DYA245:D@Q0aS
0Q2400<HaQBU5:D00a2400H<Ha2448@DYAS65:D248@25:D248@010aS48@D
YABU0a240aBU0Q2400<DYA2448@00`aS00<@Q1BU36<00PaS00@DYA2448@@
Q0<<H`8@Q0@<H`8@Q0<<H`0448@DYABU48@136<000<48@0300048@@Q00H4
8@086<HYBQcW5:DHaQcW6<HDY@<HaP<Li`056<HDYAS66<HLi`036<H00acW
6<HLi`027>L66<H47>L66<H012487>LLiaS60QcW0QS600<Lib487>L00QS6
00<LiaBU5:D00QS600<Lib487>L01QS600HLiaS67>LLiaS65:D56<H00acW
8@PLi`026<H011cW6<HHaQcW0R480QcW00<Q21cW6<H00QBU0QS60acW11S6
0acW00<HaQBU5:D00aS60QcW11BU1aS600<DYAS66<H00QS600DLiaS65:DD
YA2400<HaP<DY@8HaP<DY@057>LHaQcW6<H@Q0025:D00a246<HDY@056<H0
21BU6<HHaQS65:DHaQBU6<H35:D66<H01AcW6<HLiacW6<H00QcW00@HaQcW
6<HLi`<HaP045:DLiacW8@P26<H27>L00aS648@@Q0025:D248@011BU6<H@
Q1BU0Q240QBU0QS60QcW11S600TDYAS65:DDYAS65:DHaQBU7>L00aS600<D
YAS67>L00QBU00@<Ha2448@@Q0PDY@036<HDYABU00<Li`DHaPLDY@8HaP06
7>LDYA245:DHaQBU0Q2400<DYAS65:D00aS600<LiaS66<H00aS60aBU11S6
0QcW11S60QcW00@HaQBU5:DDY@8Li`@DY@046<HDYABU5:D26<H00aBU6<HH
aP027>L021S648@@Q1BU6<HDYA245:D26<H00a245:DDY@0248@35:D01AS6
5:DDYABU48@01ABU0Q240aBU0Q2400@<HaBU5:DDY@<@Q0075:DHaQ245:D@
Q1BU48@011BU00d@Q1BU5:DDYAS65:D@Q1BU6<HDYA2436<@Q0035:D348@0
0aBU6<HHaP025:D00a2436<@Q0035:D00aS65:DDY@025:D01AS65:DHaQS6
5:D00Q2400<DYAcW6<H00QBU00DHaQcW6<HDYA2400<DY@046<HDYABU48@3
5:D448@01ABU6<HHaQS67>L00R4800@Lia245:DDY@<HaP045:DHaQcW6<H2
7>L45:D00aS65:DHaP0448@00aBU36<@Q00248@00aS65:DDY@035:D02124
5:D@Q12436<@Q1BU48@45:D448@25:D36<H011BU6<HDYAS60QBU00<@Q1BU
5:D00a2400<DYAS66<H01QBU0a2400<DYA245:D00aBU0a240aBU0Q2400@H
aQBU48@DY@<@Q08DY@0348@DYA24008@Q0@DY@0848@<Ha2448@DYA245:DH
aP8DY@D@Q0036<HDYABU00@DY@8@Q0@DY@<<H`045:DHaQBU36<248@00`aS
48@@Q00248@00`aS48@<H`0248@00`aS48@@Q00236<011245:D@Q1240@aS
00000`00124000031240300012448@@Q0008@QS6;F/Lia246<HLi`HHaP05
7>LQ21S65:D@Q0026<H35:D27>L26<H00aBU6<HLi`036<H02QBU6<HHaQcW
6<HDYAS67>LDYAS60QcW0R480QcW0QS600<LiaS67>L00acW00<HaQBU6<H0
0QS600@Q21cW7>LLi`8DY@8HaP8Li`038@PLiaS6008HaP035:DHaQcW008H
aP038@PLiaBU008DY@0:7>LHaQBU6<HLibDY8@PLib487>L25:D01Q246<HH
aQS67>LHaP<Li`8HaP8Li`@HaP8DY@8HaP037>LHaQBU00THaP8DY@036<HL
iaS6008DY@8@Q0045:DHaQS66<H25:D021S65:D@Q1BU48@HaQcW6<H25:D0
0a245:DDY@025:D36<H25:D26<H00acW6<HDY@025:D00a246<HDY@035:D5
6<H27>L00aS67>LHaP047>L011S65:DHaQS61acW00DHaQBU48@<Ha2400@D
Y@0448@DYA2448@25:D36<H01AcW6<HLiaS65:D00QS600@@Q1BU5:DHaP8D
Y@046<HDYAS66<H75:D011245:DDYA240QBU00<HaQBU5:D01QBU00HHaQcW
7>LHaQBU6<H45:D011245:DDYABU0QS600DDYAS66<HDYAS600<DY@8@Q003
5:DHaQBU00@HaP<DY@<HaP<DY@047>LHaQS67>L46<H011cW6<HDYA240QBU
00TLiaS65:D@Q1BU6<HDYA245:D00aS600DLiaS67>LHaQBU008HaP<@Q08H
aP8DY@036<H@Q124008@Q0DDY@0348@DYA2400@DY@@@Q0035:D@Q12400<<
H`0448@DYAS648@25:D00aS65:D@Q0035:D01a245:DDYABU48@DYAS6008D
Y@0348@DYABU008DY@086<HDYA2436<@Q1BU48@<H`8DY@036<HDYA2400<@
Q0@DY@036<HDYA24008@Q08HaP045:DHaQBU6<H45:D26<H45:D248@00aBU
6<HDY@035:D748@00aBU6<HHaP037>L00b487>LHaP035:D00aS65:DHaP06
6<H00aBU48@DY@026<H348@25:D448@00aS65:DHaP055:D0212436<<Ha24
36<@Q1BU48@25:D00a245:DHaP035:D010aS48@DYAS60QcW0aBU00@@Q1BU
48@DY@<@Q0PDY@0348@DYA2400<@Q08DY@8@Q08<H`0448@DYAS66<H25:D0
0a245:DDY@0348@00aBU48@@Q00248@00aBU48@@Q0035:D00a2436<<H`02
5:D021S65:D@Q1BU6<HDYA2436<248@25:D00aS65:DDY@025:D248@00aBU
48@@Q00248@01PaS248@Q1BU6<HDY@<<H`@@Q0<<H`0448@DYA2436<248@0
1PaS48@DYA245:D@Q048@P0010@Q00<000@Q12401@@Q00@HaS6<9BTDY@8H
aP8Li`046<HLiaBU6<H38@P011S648@DYABU0QS60QBU00LLib487>LHaQBU
6<HLi`026<H67>L56<H01ABU7>LLiacW6<H00QBU1QS60QcW0QS60acW00<H
aQcW5:D00QBU00DHaQcW7>LDYAS6008Li`8HaP8Li`036<HDYAS600@HaP03
7>LHaQS6008HaP057>LQ21cW7>LDY@066<H37>L00b486<HLi`027>L00b48
7>LHaP037>L36<H00acW6<HLi`076<H25:D46<H01B486<HDYA245:D00aS6
0aBU0QS600@DYAS67>LLi`<HaP8DY@0448@DYABU6<H25:D26<H00aBU6<HL
i`027>L011S67>LLiaS60QBU00<HaQBU6<H00QS60acW00@Q21S66<HDY@<L
i`075:DHaQcW7>LHaQcW8@P00QcW0aS600<DYAS66<H00QBU00@@Q1BU48@D
Y@@@Q0035:DHaQBU00@DY@086<HDYABU6<HLiaBU6<H@Q08HaP<DY@@HaPLD
Y@8@Q0DDY@086<HDYABU48@DYA245:DHaP<Li`DHaP<DY@077>LHaQS66<HD
YA245:D00aS60Q2400@DYAS648@DY@8HaP037>LHaQS600DHaP8DY@LHaP03
5:DHaQBU008HaP037>LHaQS6008HaP037>LHaQS600@HaP065:DHaQBU5:DH
aQcW0QS600<DYAS65:D00QS600@DYA245:D@Q0<DY@8@Q0035:DHaQBU008D
Y@036<HDYA24008@Q0035:D@Q1S600<DY@L@Q08DY@8@Q00436<DYABU5:D2
48@011BU48@DYA240QBU00LHaQBU5:DHaQcW6<HDY@0248@00aS65:DDY@02
5:D248@35:D248@011BU6<HDYABU0a2400<DYA2448@00Q240aBU0aS600DL
iaBU5:DDYAS600<DY@8HaP8DY@047>LHaQBU5:D36<H00a245:DDY@0348@2
5:D36<H00acW8@PQ20036<H25:D00aS65:DDY@035:D36<H00aBU6<HHaP03
6<H011BU48@@Q1240QBU0Q2400@<Ha245:DHaP@DY@8@Q00536<@Q1BU5:D@
Q0035:D02aS65:DDYABU6<HDYA2436<@Q1BU48@00QS600<LiaS65:D01ABU
00<@Q1BU48@00QBU00<HaQ245:D00QBU00@HaQBU48@@Q0<DY@036<H@Q124
008<H`0848@DYAS65:DHaQ245:D@Q08DY@<@Q0<DY@<@Q0<DY@<@Q0@DY@07
6<HDYABU48@DYAS65:D00Q2400<DYAS65:D011BU00<HaQBU48@00aBU00<@
Q1BU5:D011240aBU00H@Q0aS48@@Q1BU48@336<648@00`aS48@@Q00248@0
000400048@@Q000512402@0012448ABU<H`U:ABU6<HLi`056<H01acW8@PQ
21cW6<H@Q1BU00<HaP035:DHaQS6008Li`<HaPLLi`038@PLiacW008HaP04
7>LHaQS66<H37>L46<H47>L26<H67>L26<H011BU48@HaQcW0QBU00<HaQcW
7>L00QS60QcW0QS600<DYAS67>L01QS60QcW00@Q21cW7>LHaP8DY@096<HL
iaS65:DHaR489BTQ21cW008HaP037>LQ21cW008Li`036<HDYAS600<HaP05
7>LHaQS66<HDY@026<H25:D36<H248@26<H011cW6<HDYABU1AS600<DYAS6
5:D00aBU0aS600<DYA2448@00QBU00@HaQBU5:DHaP8Li`045:DHaQcW7>L2
5:D011S67>LLiaS60QBU0aS600@DYAS66<HHaP8Li`035:DHaQS6008Li`03
8@PHaQS6008HaP<Q20037>LHaQBU00<HaP035:D@Q1BU00<DY@0448@DYA24
48@25:D00aS65:DDY@025:D56<H011BU6<HDYAS60QBU0aS600@DYAS66<HH
aP<DY@8HaP8DY@8@Q08DY@8HaP035:D@Q12400<DY@0448@DYABU6<H37>L0
0aS65:DDY@036<H25:D00acW6<HDY@025:D36<H35:D00aS65:DDY@025:D0
0acW6<HHaP027>L35:D26<H00aBU6<HLi`027>L031S65:DHaQBU6<HLiaS6
7>LHaQBU6<HDY@<HaP035:DHaQBU00DDY@046<HLiaS67>L26<H00aBU6<HH
aP036<H00a245:DDY@035:D448@00aBU6<HHaP025:D02a245:DDYABU48@D
YA245:D@Q1BU48@00`aS1Q2400<DYA245:D00a240QBU0Q2400<DYAS66<H0
0aS60QBU0a2400<DYAS65:D00Q240QBU0a240aBU0Q2400<DYAS66<H00Q24
00<DYA245:D00QBU00HHaQBU6<HHaQBU6<H25:D00acW6<HDY@026<H25:D0
0aS67>LHaP035:D36<H25:D011245:D@Q1BU0QS61acW0aS61ABU00@HaQBU
6<HDY@@HaPDDY@8@Q08DY@8@Q0035:D@Q1S600DDY@8@Q08<H`0548@DYA24
48@DY@036<H00aBU48@@Q0045:D011S67>LLiaS60QBU00<@Q1BU5:D00Q24
11BU0Q240QS60QBU00<@Q1BU5:D00Q240QBU0Q240QBU0a240QBU00@@Q1BU
5:DDY@8@Q0<DY@@@Q08DY@<@Q0085:D@Q12448@DYA245:D@Q08DY@D@Q004
5:DHaQS66<H55:D00a245:DDY@035:D00a2436<@Q0035:D348@01@aS48@@
Q1245:D00a2400<<Ha2448@00PaS0a240PaS0A240@aS000212401@001244
8@@Q00001@@Q00DDYBe[9BTLibDY008Q20037>LHaQS6008HaP<Li`8HaPDD
Y@076<HLiacW6<HDYA246<H00acW00DQ21S66<HLiaS600<Li`086<HLiaBU
6<HLib487>LHaP8DY@037>LHaQS6008Li`066<HDYABU5:DLiaS60QcW00HH
aQcW6<HDYAS65:D47>L00b487>LHaP027>L26<H00aBU6<HLi`096<H27>L0
1B486<HHaQS65:D00acW0QS60QcW0R480aS60R4800<LiaS65:D00aS600HL
iaS67>LHaQcW8@P36<H35:D011S67>LHaQcW0QS600DLiaS67>LDYAS6008D
Y@036<HDYABU008DY@056<HDYABU6<HLi`026<H25:D00a245:DHaP027>L0
11S65:DHaQS60QcW0QS600@DYAS66<HLi`8HaP8DY@HHaP8DY@0848@DYAS6
6<HDYAcW8@PLi`<HaP@Li`@HaPDDY@@@Q0<DY@8HaP<DY@036<HLiaS600<D
Y@036<HLiaS6008HaP077>LHaQS66<HLiaS65:D00QS600<LiaS65:D00QBU
0QS611BU00HHaQBU5:DDYA245:D36<H011BU6<HLib480QcW00<HaQcW7>L0
0QS600<DYAS66<H011BU0QS60aBU0QS600HDYAS65:DDYAS65:D96<H011cW
6<HLiacW0aS600<DYAS66<H01AS611cW0aS60aBU00<HaQcW6<H00QBU11S6
1aBU00<@Q1BU5:D00aS600<DYAS65:D00QBU0Q240aBU00@@Q1BU5:DDY@8@
Q08DY@<@Q0065:D@Q12436<@Q1BU0Q241QBU00<@Q1BU5:D00QS60QBU0QS6
1QBU00<@Q1BU5:D00QBU0Q240QBU00<HaQBU5:D00Q240aBU0a2400DDYAcW
6<HHaQ24008DY@8Li`035:DHaQS600<DY@HHaP@Li`8DY@0348@HaQS6008D
Y@0548@HaQS67>LU:@028@P00aS65:DHaP046<H35:D26<H01B487>LDYA24
5:D00QS600<LiaBU5:D01QBU00<@Q1BU6<H00QBU00<HaQcW5:D00Q2400<D
YAS648@00Q2400LDYAS66<HDYA245:DHaP025:D248@46<H011245:DHaQS6
11BU00X@Q1BU5:DHaQcW6<HDYA245:DHaP<DY@8HaP<DY@0348@DYA2400<@
Q0<DY@<HaP045:D@Q1245:D26<H00aBU48@@Q0025:D248@00aBU48@@Q005
48@25:D01a245:DDYABU6<HDYAS600@DY@036<HDYABU008@Q0<HaP8DY@<@
Q00536<@Q1245:D@Q0035:D448@00aBU48@@Q00236<548@35:D136<00005
124000@Q1240000712401QS6=JdU:AS67>LQ208Li`<HaPDLi`035:DHaQBU
00<HaP055:DHaQS66<HDY@026<H27>L01B487>LLiacW6<H00QcW1QS600HL
ib488@PLiaS67>L36<H37>L00aS65:DHaP026<H00acW6<HHaP027>L26<H0
11BU7>LHaQcW0aS60acW00DHaQBU5:DHaQcW00HHaP077>LHaQcW6<HLiaS6
7>L01AS600@LiaS67>LLi`<Q20@HaP8Li`<HaP047>LHaQcW6<H27>L00aS6
5:DHaP026<H021BU6<HDYAcW6<HLiaS67>L66<H01ABU6<HHaQBU48@00QBU
00LHaQBU5:DDYAS67>LHaP0348@01AS65:DLiaS67>L00aS600<LiaS67>L0
0aS600@LiaS66<HDY@8HaP045:DHaQS67>L66<H011cW5:DHaQS60R4800<L
iaBU6<H011cW00<HaQcW6<H011BU00HHaQBU48@@Q1BU48@25:D36<H01ABU
6<HDYA245:D021S600LLiaS66<HDYAS67>LHaP025:D26<H00acW6<HHaP06
5:D00aS65:D@Q0025:D26<H35:D26<H01QcW6<HLiaS67>LDY@8HaP067>LH
aQBU48@HaQBU1aS60aBU00<HaQBU5:D00QBU00<HaQBU6<H00aS600<DYAcW
7>L00QS600<DYAS66<H01AS600@LiaS65:DHaPDLi`046<HDYABU5:D26<H0
0aBU7>LLi`026<H55:D01A245:DDYAS65:D00Q2400<DYAS66<H011S600<D
YAS65:D02ABU0Q240QBU0a2400<DYA2436<00Q2400<DYA245:D011BU0Q24
0QBU00DHaQBU7>LLiaS600<DY@056<HDYABU5:D@Q0045:D021245:D@Q124
5:DLiaS65:D248@45:D011245:DDYAS60QBU00<HaQcW6<H00QBU0aS61ABU
11S600<LiaS67>L00QS600@DYAS66<HHaP8DY@096<HLiaBU6<HQ22DY8@PH
aQBU008HaP8DY@8HaP<DY@8Li`8HaP<DY@057>LHaQBU48@DY@026<H011BU
48@@Q1S60QBU00@HaQcW6<HHaP<@Q08DY@036<H@Q12400<DY@036<HDYA24
008DY@0348@DYABU00<HaP035:DHaQBU008DY@046<HDYABU48@45:D36<H3
5:D011245:DDYAS611BU112400<DYA245:D00Q2400@DYAS66<HHaP8DY@@@
Q0045:D@Q12448@35:D348@00`aS5:D@Q0035:D00a245:D<H`045:D00aS6
5:D@Q0025:D00aS65:DDY@025:D26<H02ABU48@@Q1245:D@Q0aS48@DY@03
48@01ABU48@@Q1245:D00PaS0Q2400<DYA2436<00a240aBU0@aS00000`00
12448@0212401@0012448@@Q00000`@Q00D000@Q12448@0000<48@050004
8@@Q1240000312401@0012448@@Q00000`@Q00D000@Q12448@0000<48@05
00048@@Q1240000312401@0012448@@Q00000`@Q00D000@Q12448@0000<4
8@0500048@@Q1240000312401@0012448@@Q00000`@Q00D000@Q12448@00
00<48@0500048@@Q1240000312401@0012448@@Q00000`@Q00D000@Q1244
8@0000<48@0500048@@Q1240000312401@0012448@@Q00000`@Q00D000@Q
12448@0000<48@0500048@@Q1240000312401@0012448@@Q00000`@Q00D0
00@Q12448@0000<48@0500048@@Q1240000312401@0012448@@Q00000`@Q
00D000@Q12448@0000<48@0500048@@Q1240000312401@0012448@@Q0000
0`@Q00D000@Q12448@0000<48@0500048@@Q1240000312401@0012448@@Q
00000`@Q00D000@Q12448@0000<48@0500048@@Q1240000312401@001244
8@@Q00000`@Q00D000@Q12448@0000<48@0500048@@Q1240000312401@00
12448@@Q00000`@Q00D000@Q12448@0000<48@0500048@@Q124000031240
1@0012448@@Q00000`@Q00D000@Q12448@0000<48@0500048@@Q12400003
12401@0012448@@Q00000`@Q00D000@Q12448@0000<48@0500048@@Q1240
000312401@0012448@@Q00000`@Q00D000@Q12448@0000<48@0500048@@Q
1240000312401@0012448@@Q00000`@Q00D000@Q12448@0000<48@050004
8@@Q1240000312401@0012448@@Q00000`@Q00D000@Q12448@0000<48@05
00048@@Q1240000312401@0012448@@Q00000`@Q00D000@Q12448@0000<4
8@0500048@@Q1240000312401@0012448@@Q00000`@Q00D000@Q12448@00
00<48@0500048@@Q1240000312401@0012448@@Q00000`@Q00D000@Q1244
8@0000<48@0500048@@Q1240000312401@0012448@@Q00000`@Q00D000@Q
12448@0000<48@0500048@@Q1240000312401@0012448@@Q00000`@Q00D0
00@Q12448@0000<48@0500048@@Q1240000312401@0012448@@Q00000`@Q
00D000@Q12448@0000<48@0500048@@Q1240000312401@0012448@@Q0000
0`@Q00D000@Q12448@0000<48@0500048@@Q1240000312401@0012448@@Q
00000`@Q00D000@Q12448@0000<48@0500048@@Q1240000312401@001244
8@@Q00000`@Q00D000@Q12448@0000<48@0500048@@Q1240000312401@00
12448@@Q00000`@Q0@000@@Q0@@Q000312401@0012448@@Q00000`@Q00D0
00@Q12448@0000<48@0500048@@Q1240000312401@0012448@@Q00000`@Q
00D000@Q12448@0000<48@0500048@@Q1240000312401@0012448@@Q0000
0`@Q00D000@Q12448@0000<48@0500048@@Q1240000312401@0012448@@Q
00000`@Q00D000@Q12448@0000<48@0500048@@Q1240000312401@001244
8@@Q00000`@Q00D000@Q12448@0000<48@0500048@@Q1240000312401@00
12448@@Q00000`@Q00D000@Q12448@0000<48@0500048@@Q124000031240
1@0012448@@Q00000`@Q00D000@Q12448@0000<48@0500048@@Q12400003
12401@0012448@@Q00000`@Q00D000@Q12448@0000<48@0500048@@Q1240
000312401@0012448@@Q00000`@Q00D000@Q12448@0000<48@0500048@@Q
1240000312401@0012448@@Q00000`@Q00D000@Q12448@0000<48@050004
8@@Q1240000312401@0012448@@Q00000`@Q00D000@Q12448@0000<48@05
00048@@Q1240000312401@0012448@@Q00000`@Q00D000@Q12448@0000<4
8@0500048@@Q1240000312401@0012448@@Q00000`@Q00D000@Q12448@00
00<48@0500048@@Q1240000312401@0012448@@Q00000`@Q00D000@Q1244
8@0000<48@0500048@@Q1240000312401@0012448@@Q00000`@Q00D000@Q
12448@0000<48@0500048@@Q1240000312401@0012448@@Q00000`@Q00D0
00@Q12448@0000<48@0500048@@Q1240000312401@0012448@@Q00000`@Q
00D000@Q12448@0000<48@0500048@@Q1240000312401@0012448@@Q0000
0`@Q00D000@Q12448@0000<48@0500048@@Q1240000312401@0012448@@Q
00000`@Q00D000@Q12448@0000<48@0500048@@Q1240000312401@001244
8@@Q00000`@Q00D000@Q12448@0000<48@0500048@@Q1240000312401@00
12448@@Q00000`@Q00D000@Q12448@0000<48@0500048@@Q124000031240
1@0012448@@Q00000`@Q00D000@Q12448@0000<48@0500048@@Q12400003
12401@0012448@@Q00000`@Q00D000@Q12448@0000<48@0500048@@Q1240
000312401@0012448@@Q00000`@Q00D000@Q12448@0000<48@0500048@@Q
1240000312401@0012448@@Q00000`@Q00D000@Q12448@0000<48@050004
8@@Q1240000312401@0012448@@Q00000`@Q00D000@Q12448@0000<48@05
00048@@Q1240000312401@0012448@@Q00000`@Q00@000@Q12448@400000
0?l000@Q00048@00124000@Q00048@00124000@Q00048@00124000@Q0004
8@00124000@Q00048@00124000@Q00048@00124000@Q00048@00124000@Q
00048@00124000@Q00048@00124000@Q00048@00124000@Q00048@001240
00@Q00048@00124000@Q00048@00124000@Q00048@00124000@Q00048@00
124000@Q00048@00124000@Q00048@00124000@Q00048@00124000@Q0004
8@00124000@Q00048@00124000@Q00048@00124000@Q00048@00124000@Q
00048@00124000@Q00048@00124000@Q00048@00124000@Q00048@001240
00@Q00048@00124000@Q00048@00124000@Q00048@00124000@Q00048@00
124000@Q00048@00124000@Q00048@00124000@Q00048@00124000@Q0004
8@00124000@Q00048@00124000@Q00048@00124000@Q00048@00124000@Q
00048@00124000@Q00048@00124000@Q00048@00124000@Q00048@001240
00@Q00048@00124000@Q00000?l000@Q00048@00124000@Q00048@001240
00@Q00048@00124000@Q00048@00124000@Q00048@00124000@Q00048@00
124000@Q00048@00124000@Q00048@00124000@Q00048@00124000@Q0004
8@00124000@Q00048@00124000@Q00048@00124000@Q00048@00124000@Q
00048@00124000@Q00048@00124000@Q00048@00124000@Q00048@001240
00@Q00048@00124000@Q00048@00124000@Q00048@00124000@Q00048@00
124000@Q00048@00124000@Q00048@00124000@Q00048@00124000@Q0004
8@00124000@Q00048@00124000@Q00048@00124000@Q00048@00124000@Q
00048@00124000@Q00048@00124000@Q00048@00124000@Q00048@001240
00@Q00048@00124000@Q00048@00124000@Q00048@00124000@Q00048@00
124000@Q00048@00124000@Q00048@00124000@Q00048@00124000@Q0004
8@00124000@Q00048@00124000@Q00048@00124000@Q0000084000@Q0004
8@00124000@Q00048@00124000@Q00048@00124000@Q00048@00124000@Q
00048@00124000@Q00048@00124000@Q00048@00124000@Q00048@001240
00@Q00048@00124000@Q00048@00124000@Q00048@00124000@Q00048@00
124000@Q00048@00124000@Q00048@00124000@Q00048@00124000@Q0004
8@00124000@Q00048@00124000@Q00048@00124000@Q00048@00124000@Q
00048@00124000@Q00048@00124000@Q00000@@Q0000\
\>"], "Graphics",
  Evaluatable->False,
  ImageSize->{640, 480},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:00001h1000`40O003h00O00<000@Q12400P@Q
00X000@Q124000@Q00048A247>LDY@<@Q0DDY@8HaP035:DHaQS600@@Q0045:DHaQBU5:D348@00aBU
48@@Q00248@01aS648@@Q1245:DQ22U:008]J`<U:@047>LHaQBU5:D36<H01QBU48@@Q1BU6<HLi`8H
aP0348@<Ha24008DY@056<H@Q12448@<H`0248@011BU48@@Q1240`aS00@@Q1BU48@DY@8@Q0045:D@
Q12448@35:D348@01ABU48@DYA245:D00Q240aBU00<HaQBU5:D00QBU0aS60QBU0aS611BU0QS60QBU
00D@Q1BU5:DDYA2400<DY@0348@HaQS6008@Q00736<@Q1S648@DYA245:D011S60QBU00<HaQcW6<H0
0aBU0QcW00@HaQ2448@DY@DHaP037>LDYAS6008Li`<HaP058@PLiacW5:DHaP025:D27>L76<H37>L0
1AS67>LQ21cW8@P01acW0R4800<LiaS66<H02AS600<DYAS67>L00QcW00HHaQBU6<HQ22DY7>L25:D0
11cW6<HDYAS611cW0aS600<DYAS65:D00QS60aBU0QS60aBU0QS600HLiaBU5:DHaQBU6<H55:D011S6
5:DDYAS60QcW0QS60QBU00DHaQBU48@@Q1BU00<HaP<DY@046<HDYABU6<H25:D00a2436<@Q00348@4
5:D00aS65:D@Q0035:D01QS648@DYAcW6<HDY@8@Q0035:D@Q124008DY@<HaP045:D@Q1S65:D448@3
5:D00aS65:DDY@0236<248@011S65:DDYA240QBU00@HaQBU5:DDY@D@Q0035:D@Q1BU00<@Q0@DY@03
48@DYA24008DY@@@Q08HaP8@Q0@DY@0548@DYABU6<HDY@026<H00aBU48@@Q0045:D00aS65:DHaP03
5:D00a245:DHaP0348@011BU48@<Ha240QBU0Q240aBU00P@Q1BU6<HDYA2436<@Q0aS0Q240PaS00H@
Q1BU5:D@Q0aS48@35:D00a2436<<H`0348@336<348@35:D00a2436<@Q00436<0112436<@Q0aS1Q24
00D<Ha2448@<Ha2400L<H`0548@<Ha2448@DY@0248@00`aS48@@Q00248@336<348@836<248@536<0
0a2436<<H`0<36<25:D236<01Q2436<<H`aS48@DY@<<H`035:D@Q12400D<H`8@Q0<<H`8@Q0D<H`03
248<H`aS008<H`<@Q0<<H`0548@DYA2436<8@P0?36<348@236<00a2436<<H`0224800`aS248@Q004
48@336<348@136<00005124000@Q12400007124011BU9BTDY@aS11BU00@HaQcW6<HDY@@HaP035:DH
aQBU00<DY@036<HDYABU008DY@0548@DYABU6<HDY@0248@35:D26<H27>L28@P01BDY;F/]JbU:9BT0
1aBU00DHaQBU5:DDYA2400@DY@@@Q08DY@<@Q0035:D@Q1BU008@Q0035:D@Q1BU00<DY@8@Q0<DY@04
6<HDYAS66<H25:D248@36<H01ABU48@DYAS67>L00QS600@DYAS66<HLi`<HaP047>LHaQS65:D26<H2
5:D00aS65:DHaP025:D00aS65:DHaP045:D248@00aBU48@HaP036<H35:D36<H00aBU6<HHaP047>L4
6<H00acW6<HDY@025:D37>L00aS65:DHaP036<H00aBU6<HLi`028@P01acW6<HHaQS65:DHaQBU00<L
i`<HaP8Li`8Q208Li`<Q20@Li`<Q20@Li`<HaP047>LHaQBU6<H27>L03aS67>LQ22487>LHaQBU6<HQ
22DY8@PLiaBU6<HQ20029BT011cW6<HDYAS60R4800DLiaS66<HHaQcW008DY@036<HLiaS6008DY@<H
aP<DY@047>LHaQS66<H55:D26<H00aBU6<HHaP046<H011cW6<HDYA240QBU00D@Q1S66<HHaQBU008@
Q0066<HDYABU6<HLiaBU0a240aBU0aS611BU0QS600@DYA2448@DY@8HaP<@Q0DHaPDDY@8@Q08DY@<@
Q0035:D@Q1BU008@Q0055:D@Q1BU5:D@Q0035:D26<H35:D01A245:DDYA245:D00Q2400<DYA2448@0
0a2411BU11240aBU0QS600@DYAS65:DDY@8HaP037>LHaQBU00<HaP035:DHaQBU008DY@036<HLiacW
008DY@036<HDYABU00@DY@0448@DYABU48@236<00a245:D@Q0025:D248@25:D26<H348@236<00aBU
48@@Q00248@00aBU6<H@Q00248@011BU48@DYABU112400D<Ha245:D@Q1BU00@@Q0<DY@8@Q00336<@
Q12400H@Q00336<@Q124008@Q0<<H`<@Q0<<H`0448@<Ha2436<448@00`aS48@@Q00248@00`aS48@@
Q00336<448@336<00a2436<<H`0348@336<548@336<00a2436<8@P0236<248@021BU48@@Q12436<@
Q1BU48@236<0212436<<H`aS48@DYA2436<448@236<348@336<0112436<<H`Q20PaS212400@<Ha24
36<@Q0<<H`8@Q0/<H`@@Q00336<8@PaS00<<H`0548@<Ha2448@DY@0248@336<00a2436<@Q00236<0
00848@0300048@@Q00H48@06000DYBDY7>L@Q1S60a2400DDYAS66<HHaQBU008HaP0448@DYABU6<H4
5:D011245:DDYABU0Q2400T<Ha246<HHaQBU6<H@Q1BU6<H00b4800<Lib489BT00Re[0R4800HHaQcW
6<H@Q0aS48@25:D00aS65:D@Q00248@35:D00aS648@@Q00348@00aBU48@DY@0448@00aBU48@@Q002
5:D01QS648@@Q0aS48@DY@<HaP<DY@8@Q0<DY@046<H@Q1BU48@36<H00aBU6<HHaP026<H27>L01b48
7>LHaQBU48@DYAS6008Li`<DY@@HaP<DY@0348@DYAS6008DY@8@Q0DDY@076<HDYAS65:DHaQcW8@P0
1AcW1AS60QBU00<HaQcW6<H00aS600@DYAS67>LLi`<HaP037>LQ21cW00<HaP047>LHaQS66<H27>L0
1AS65:DHaQcW8@P00QcW0R4800<Lib487>L00RDY00@Q21cW7>LLi`8Q208Li`058@PLiaS66<HDY@04
6<H47>L02B487>LLiaS65:DLibDY8@PLi`026<H38@P011cW6<HHaQBU0R4800HLiaS65:DHaQcW6<H2
5:D01QS65:DDYABU7>LHaP8DY@036<HLiaBU00<HaP8DY@0448@DYABU5:D46<H011cW6<HHaQS60QBU
00<HaQ245:D00QBU0aS60QBU0Q2400@DYAS66<HLi`8DY@8@Q0DDY@8HaP045:DHaQS66<H35:D26<H0
1AcW5:D@Q1245:D00QS60QBU0aS60aBU00<@Q1S65:D00QBU00D@Q1BU5:DDYA24008DY@<@Q0<DY@03
48@DYABU00<HaPXDY@<@Q0065:D@Q1BU48@DYA2411BU00@@Q1BU5:DDY@8HaP<DY@@HaP8DY@8HaPDD
Y@036<HDYABU00@HaP0448@DYAS66<H25:D248@00aBU48@@Q00248@45:D00a245:DDY@035:D348@2
36<248@25:D248@00`aS48@DY@025:D248@011BU48@@Q1240PaS0Q2400<DYA2448@00QBU00<HaQ24
36<00Q2400D<Ha2448@@Q1BU00@@Q08<H`8@Q08<H`<@Q0@<H`8@Q00336<@Q124008@Q00836<@Q124
5:D@Q0aS48@<H`8@Q00436<@Q12448@336<248@00`aS48@@Q00248@336<248@236<0212436<<H`Q2
36<@Q0aS48@336<548@00`aS48@<H`0348@010aS48@@Q1240`aS00<@Q0aS48@011240`aS0a241PaS
0a240`aS0Q241@aS00@@Q0aS48@<H`<@Q00436<8@PaS48@436<448@00`aS48@<H`0436<00a2436<<
H`0236<00aBU48@@Q00236<00a2436<8@P012480000400048@@Q00021240100012448@000P@Q00<@
Q2DY7>L00Q240QBU00DHaQcW6<HHaQBU008HaP<DY@036<HDYA24008DY@036<HDYA24008@Q0045:D@
Q1S65:D26<H01aBU48@DYABU6<HLiaS6008Li`036<HDYAcW008Q20036<H@Q1BU00DDY@8HaP035:DH
aQBU008DY@<@Q08DY@@@Q0035:D@Q12400<DY@0336<@Q1BU008HaP0348@DYABU00<DY@0348@HaQS6
008HaP8@Q08DY@8Li`045:D@Q1245:D26<H25:D00a246<HHaP027>L01QS67>LLiaBU6<HDY@8HaP03
5:DHaQS600DDY@046<HDYA2448@35:D248@00aBU6<HHaP086<H011BU6<HLib480QS600@Lib488@PL
i`8HaP8DY@046<HLib487>L56<H27>L011S67>LLib480QcW0QS60QcW00<Q21cW6<H00QS60QcW0QBU
00@HaR489BTQ20@U:@<Q20047>LQ22488@P47>L00b487>LLi`067>L01ABU6<HLib489BT00acW0R48
00LLiaS66<HLibU:;F/YBP026<H01ABU7>LLiacW6<H00QcW00DQ21S66<HHaQBU00@HaP0748@HaR48
7>LDYA245:D00aS600L@Q1BU5:DDYAcW6<HLi`036<H35:D00aS67>LHaP0448@01QBU6<HLiaS65:D@
Q0<DY@8HaP035:D@Q1BU008DY@036<HDYAS600<DY@036<HDYABU008HaP045:D@Q1BU48@55:D011S6
7>LLiaBU0QS60a2411BU0QS60aBU00L@Q0aS36<<Ha245:D@Q0045:D36<H45:D01a245:DDYA245:DH
aQBU00<@Q0<DY@066<HDYA2448@DYA240QBU00<@Q1BU5:D021S600<LiaS66<H011S600<DYAS65:D0
1AS611BU0QS60QBU00<@Q1BU5:D00Q2400<<Ha2448@00aBU00<@Q1BU5:D00aBU0Q2400@DY@aS48@<
H`8@Q0<DY@0348@DYABU008DY@8@Q08<H``@Q0045:D@Q1245:D248@00aBU36<<H`0248@011BU48@<
H`aS0Q2400<<Ha2448@01A240PaS0a240PaS11240PaS0a240PaS112400<<Ha2448@00PaS00<8@PaS
5:D011240PaS00<@Q0aS48@00Q2400<<H`Q236<00Q2400@<Ha2436<<H`8@Q08<H`8@Q00336<@Q124
00<@Q00536<@Q0aS48@<H`0248@01PaS48@DYABU48@<H`8@Q08<H`<@Q0<<H`03248<H`aS008@Q0@<
H`8@Q0@<H`0448@<Ha2448@336<248@436<0112436<@Q0aS0QBU00D@Q0Q236<<HaBU00<<H`D@Q0H<
H`<@Q04<H`0010@Q00<000@Q12400`@Q00T000@Q5:DU:AcW36<@Q1BU48@00QS600@LiaS66<HDY@@H
aP035:DHaQS6008HaP<DY@0348@DYA24008DY@056<HDYABU5:D@Q0025:D26<H02R487>LLiaBU6<HQ
22DY8@PHaQBU0QS60a2400DHaQcW6<HDYA2400<DY@<@Q0035:D@Q12400@DY@0448@DYABU5:D448@4
5:D01A245:DDYABU6<H00QBU0QS600DDYA2448@DYAS600HDY@8HaP<DY@036<HLiaS6008HaP037>LH
aQS600<DY@8HaP@DY@0448@DYABU6<H35:D02AS65:DDYABU48@HaQBU6<HDY@036<H01ABU6<HDYABU
7>L00R480QS600LLib488@PHaQBU6<HDY@026<H012487>LLiaBU0aS600@LiaS67>LHaP<Li`048@PL
iaS66<H57>L36<H00acW6<HHaP026<H28@P01BDY8@PQ22DY8@P00QcW00@Q22DY7>LHaP8Li`038@PH
aQS600<Li`056<HLiacW6<HLi`026<H01AcW8@PQ21cW6<H00QcW0R4800LHaQcW8@PYBRe[9BTQ2003
6<H00acW6<HLi`026<H27>L011S65:DDYAcW0QS60QBU0QS600@LiaS66<HDY@8HaP065:D@Q1BU48@D
YAS60QcW00<HaQBU5:D00aS60QcW00PHaQBU36<@Q1BU48@HaQBU0aS60aBU11S600<@Q1BU6<H00QS6
0QBU0aS60aBU00<HaQBU5:D00Q240QS600DDYA2448@HaQcW008HaP8DY@0348@HaQBU00@DY@036<HD
YABU008@Q0055:D@Q12448@DY@0448@45:D011S67>LHaQBU0Q2400@DYA2448@@Q0<DY@@@Q0DDY@03
48@DYABU00@DY@8HaP037>LHaQBU008HaP<Li`086<HDYABU7>LHaQBU48@DY@<HaP8DY@<HaP8DY@06
6<HDYABU5:D@Q1BU1Q240aBU00@@Q1BU5:DHaP<DY@0448@DYA245:D248@00aBU48@DY@0348@00aBU
6<H@Q00236<00a245:D@Q00436<25:D348@010aS48@DYABU0Q240PaS1a2400<<Ha2436<0112400<<
Ha2448@01`aS0a240PaS0Q2400<<Ha2436<00a2410aS00<@Q0aS48@00a240`aS112400<<Ha2448@0
0PaS0Q240`aS00@@Q0aS36<<H`@@Q08<H`<@Q00336<@Q124008@Q00336<@Q0aS008<H`@@Q0035:D@
Q12400@<H`065:D<H`Q2248<Ha2420aS00<@Q0aS36<010aS00T@Q0aS36<@Q1BU48@<H`Q236<00a24
0PaS00D8@Q2448@DY@aS008@Q0H<H`@@Q08<H`06248<H`aS48@<Ha240PaS00000`00124000091240
1ABU9BTHaQ245:D00aS60aBU11S60QBU0aS600<DYAS65:D00QBU0Q2400<DYAS66<H011BU21S60QcW
00@HaQBU6<HHaP8DY@8@Q0<HaP8DY@036<HDYABU008DY@0348@DYABU00DDY@8@Q0@DY@0448@<Ha24
48@25:D00a245:DHaP025:D011S65:DLiacW0QBU0Q240QBU0aS60QBU00<@Q1BU5:D00QBU00<@Q1BU
6<H00QcW00<DYAS65:D00QS61aBU0aS60QBU00@HaQBU5:D@Q08DY@056<HDYAS65:DHaP035:D27>L0
0aS65:DHaP027>L00aS67>LLi`028@P37>L011S65:DDYAcW0R4800DLiaS66<HHaR4800<Li`@HaP8L
i`078@PLiaS67>LU:B487>L00QS600<LiaS66<H011S600DQ22DY9BTU:B48008YBP069BTLiacW8@PL
ib480QcW00<HaQcW7>L00QcW0QS600<Lib488@P00QS600<DYAS66<H011cW00HQ22DY7>LHaQcW8@P2
;F/01BU:7>LHaQBU6<H00acW00<Q21cW7>L01QS60QBU00<HaQBU5:D00QBU0QS60QBU00DHaQ245:DD
YAS6008Li`066<HLiaS65:DHaQBU0aS600@DYA246<HHaP<DY@8HaP045:D@Q1BU5:D26<H01ABU6<HD
YABU6<H00QcW00DDYA245:DDYAS6008DY@036<H@Q1BU00@DY@<@Q0045:DHaQS66<H55:D011245:DH
aQS60aBU00@HaQBU6<HDY@@@Q0035:D@Q124008@Q0045:DHaQS66<H25:D01AS65:DHaQS65:D00Q24
0aBU0Q242aBU0aS60QBU00<HaQBU6<H00QS600@Lib487>LLi`DHaPHDY@066<HDYABU6<HDYAS60aBU
00<HaQBU5:D00QBU00<@Q0aS48@00QBU00<@Q1BU48@01ABU0Q2400DDYA2448@@Q1BU008@Q0@DY@<@
Q0035:D@Q124008<H`@@Q0055:D@Q12448@<H`0248@55:D436<348@236<00a2436<<H`0236<248@0
1QBU36<@Q0aS248<H`<@Q08<H`8@Q08<H`8@Q0055:D@Q12448@<H`0248@436<0112436<8@PaS0a24
00<<Ha2448@010aS0a241@aS0a240`aS0Q240`aS00<@Q0aS48@00Q2400@DYA2448@@Q08<H`<@Q0<<
H`0448@<H`aS248736<00a2436<@Q00236<0212436<@Q12436<@Q0aS48@336<010Q248@@Q1240`aS
00D@Q0aS48@<Ha24008<H`8@Q0035:D@Q12400@<H`<@Q00536<@Q12436<8@P0236<0112436<<H`aS
0a240@aS000512401@0012448@@Q00000P@Q00PDYBDY6<H<HaBU6<HLiaS60aBU0aS60QBU11S600<D
YAS65:D00QBU00<@Q1BU5:D011BU11S600<DYAS65:D00QS600HLib486<HHaQcW5:D348@26<H35:D2
6<H35:D00aS65:D@Q00248@011S65:DDYABU0a240QBU00<HaQBU48@00Q2400<DYAS648@00QBU00`H
aQBU5:DDYAS67>LHaQBU6<HDYA246<H25:D00aS65:DDY@026<H25:D00a245:DDY@046<H011cW6<HH
aQS611BU00<HaQBU6<H00QBU00<HaQBU6<H00QS60QBU00H@Q1BU5:DDYAS65:D248@25:D66<H47>L0
0aS67>LHaP028@P01AcW6<HHaQ245:D00b4800<HaQ246<H00R480QcW0QS61AcW0QS60QcW00<Q21S6
6<H00QS600LLiaS65:DDYAS68@PU:@038@P01bU:9BTU:BU:9BTLiaS6008Li`048@PLiacW6<H27>L0
0b486<HLi`037>L00aS65:DLi`027>L01R487>LQ22487>LQ208Li`068@PU:BU:;F/YBQS60QBU00TH
aQcW6<HLib489BTLiaBU6<H00QcW00@HaQBU5:DDY@8HaP045:DHaQS66<H25:D36<H011245:DLib48
0aS600<DYAS65:D00QS60aBU00<LiaBU5:D00QBU0aS60QBU00<@Q1BU5:D00aS60aBU0QS60aBU00<H
aQBU5:D00QBU0QS60QBU11240QBU0QS600@DYAS65:DDY@8HaPHDY@036<HDYAS600<DY@0336<@Q124
008DY@<@Q0<DY@<HaP<DY@0348@DYABU00<@Q0<DY@0448@DYA245:D248@35:D00a245:DHaP025:D0
0a245:DHaP026<H011BU6<HLiacW0R4811S600<DYAS65:D00aBU00<HaQBU5:D00aBU0Q2400@DYAS6
5:DDY@<@Q0<DY@@@Q0<DY@036<HDYABU00<DY@0348@DYABU008@Q0036<HDYABU008@Q0055:D@Q124
36<@Q00336<548@35:D448@00aBU6<HHaP0248@00aBU48@@Q00348@336<00a2436<<H`025:D248@0
10Q236<@Q0aS1Q240`aS0Q2400<DYA2436<00a2400<<Ha2448@01A240`aS0a2400<<Ha2436<00PaS
0a2410aS0a2410aS00@@Q0aS36<8@P<@Q0035:D<H`aS008@Q0045:D@Q12436<448@00`aS48@@Q002
48@236<01A2436<<H`aS48@020aS0Q2420aS00<@Q0aS36<00PaS00<@Q0aS36<010aS00<@Q0aS48@0
0Q2400<DYA2448@010aS112400<8@PaS48@00Q240`aS0a240@aS0@Q200001@00124000@Q00001P@Q
00L001BU8@PDYA245:DLi`046<H25:D01QS65:DLiacW6<HDY@8HaP057>LHaQ245:D@Q0065:D26<H3
5:D00aS67>LLi`036<H01ABU6<HHaQS648@00aBU0QS60QBU0aS600<DYAS65:D01QBU00D@Q1BU48@D
YA2400HDY@0448@<Ha245:D36<H248@25:D26<H45:D01Q245:DHaQS65:D@Q08HaP8DY@8@Q0@HaP03
5:DHaQS6008HaP0548@DYABU7>LHaP035:D26<H01ABU48@@Q1BU6<H00QBU00D@Q1BU5:D@Q1BU00<H
aP035:DHaQBU00<HaP057>LHaQS66<HQ20027>L011S67>LHaQBU0QS611cW0b480QS60QcW00@U:B48
8@PLi`8HaP8Li`<HaP047>LQ22488@P36<H27>L01QS65:DLiacW9BTQ208Li`049BT]Jbe[9BT27>L0
0b487>LLi`026<H48@P36<H37>L36<H47>L28@P37>L01QBU7>LYBRe[:DXLi`@HaP8Li`038@PLiaS6
008HaP045:DHaQcW7>L26<H00aBU6<HHaP065:D00a245:DDY@027>L66<H00acW6<HHaP025:D011S6
5:DDYAS60QBU00<@Q1BU6<H00QS60aBU00<HaQBU7>L00aS60aBU00<HaQBU6<H011BU00DHaQBU5:DD
YA24008DY@8@Q0045:DHaQS66<H25:D00aS65:DDY@085:D36<H00aBU48@@Q00348@01QBU48@@Q1BU
6<HLi`<DY@056<HLiaS65:D@Q0025:D248@25:D248@35:D02A245:DHaQBU48@DYA246<HDY@056<H0
11BU6<HDYAS60QcW00<Q21cW7>L01AS61QBU0a2411S61ABU0Q2400HDYA245:D@Q1BU48@25:D00aS6
5:DDY@025:D448@45:D348@25:D00a2436<@Q00248@00`aS248<H`0248@011BU48@@Q12410aS00D@
Q1BU5:DHaQBU00@@Q00336<@Q12400D@Q08<H`8DY@0348@<H`aS00T<H`<@Q00436<@Q1245:D236<0
1a245:D<H`aS248<Ha2400X<H`D@Q00336<@Q12400@<H`D@Q00336<8@PaS00D@Q0035:D@Q0aS00<@
Q08<H`8@Q0045:D<H`aS36<248@236<00`Q236<<H`0436<248@010aS248<Ha240PaS0a241@aS1A24
0`aS00<@Q0aS36<00`aS11240PQ200@<Ha2436<<H`@@Q00336<@Q0aS00<<H`<@Q00336<@Q0aS008<
H`002@@Q00X000@Q124DYBDY6<H<HaBU6<HLi`8HaP<DY@036<HLiaS6008DY@8HaP8Li`8HaPTDY@03
48@HaQS6008HaP8DY@DHaP035:DHaQBU00DDY@046<HDYAS65:D26<H01ABU6<HDYABU48@00aBU00HH
aQBU5:D@Q1BU6<H25:D01Q245:D@Q1245:D@Q0<DY@0648@DYABU5:DHaQBU0QS600DDYA2448@DYAS6
00LDY@8@Q0<DY@<HaP037>LHaQBU00<DY@@HaP8DY@<HaP@DY@036<HDYA24008@Q08DY@@HaP055:DH
aQBU6<HLi`056<H37>L011S65:DDYABU11S600@Lib488@PLi`8HaP8Li`038@PU:AcW00DLi`<HaP04
8@PU:B487>L25:D37>L031BU6<HDYAcW8@PU:B487>LU:BU:;F/U:@8HaP8Li`078@PHaQS67>LQ22DY
7>L00QS600DLiaS67>LHaQcW008HaP<Li`056<HLib489BTQ20026<H01QcW9BTYBRDY7>LDY@8HaP03
5:DLiacW008Q20<Li`056<HLiaS67>LHaP025:D36<H25:D46<H25:D00aS67>LLi`036<H011BU6<HH
aQcW11BU00<HaQBU5:D00aBU11S611BU00DLiaS66<HHaQBU008@Q0046<HDYAS66<H248@25:D36<H2
5:D248@45:D36<H25:D011245:DDYABU0QS60aBU00HHaQcW6<HDYAS648@236<248@45:D26<H00acW
5:DDY@036<H35:D248@01ABU48@@Q1245:D00a240aBU00@@Q1BU48@HaP@DY@DHaP8DY@066<HQ2248
7>LDYAS60aBU0QS611BU00@@Q1BU48@@Q08DY@8HaP<DY@<@Q08DY@0448@DYABU5:D348@55:D00a24
5:D@Q0025:D01A245:DDYABU48@00aBU00<@Q0aS36<0112400@<Ha2448@DY@8@Q00336<@Q0aS008@
Q08DY@0548@DYAS65:D@Q00236<348@011BU48@<Ha240PaS00TDYA2448@DYA2436<8@PaS48@010aS
0Q2400D<Ha2436<DYA2400<<H`035:D@Q12400D<H`<@Q08<H`0648@<Ha2436<@Q0aS0a2400D<Ha24
48@<Ha2400<<H`0648@<H`aS48@DYA240`aS00<@Q0aS48@00a2400D<Ha2448@@Q0aS00<@Q00436<@
Q12448@736<00a2436<<H`0236<00a2436<@Q00:36<348@436<248@336<00a2436<<H`0348@01PaS
248<Ha2436<8@P8<H`0348@<Ha24008@Q08<H`0348@<H`aS008<H`0348@DYA24008@Q048@P0000L0
00@Q00048@001240000312401@00124@Q2485:D00Q240QBU0aS60aBU1AS600DLiaS66<HHaQBU00@H
aP<DY@<HaP045:DHaQS67>L26<H00aBU6<HLi`045:D00aS648@DY@026<H35:D36<H45:D26<H25:D2
48@00aBU48@@Q00248@00aBU6<HDY@0248@35:D00a245:DDY@055:D01QS65:D@Q1BU6<HLi`@DY@<@
Q08DY@8HaP<DY@046<HLiacW6<H45:D00aS65:DDY@025:D26<H25:D00a2436<DY@026<H25:D00a24
5:DHaP026<H35:D36<H011cW6<HLiacW11S611cW00@HaQBU6<HHaP8Q200:7>LHaQcW7>LQ22DY7>LH
aQcW6<H27>L26<H27>L01QBU6<HHaQcW8@PLi`DHaP035:DHaQcW008Li`0=6<HLibDY8@PHaQcW9BTY
BRDY7>LHaQcW5:D00QS600HLib487>LLib486<H25:D01AcW8@PLiaS65:D00QS60QcW00DDYB48:DXY
BR48008HaP038@PLiaS6008Li`@HaP8Q20037>LHaQBU008Li`036<HDYABU00@HaP<DY@046<HDYA24
48@25:D00acW6<HHaP025:D01QS67>LHaQS65:DHaP<DY@0548@HaQS67>LDY@0248@01QBU6<HDYABU
7>LHaP8DY@036<HLiacW00@DY@0348@DYABU00<HaP035:D@Q12400HDY@0748@DYABU6<HDYAS65:D0
11S60aBU0QS61ABU00<HaQBU36<00Q2400@HaQBU5:D@Q08DY@0848@DYAS65:DHaQ245:DHaP8DY@04
48@DYABU5:D248@01ABU48@DYABU48@011BU00@HaQBU6<H@Q0<DY@086<HDYAS66<H@Q1BU48@HaP8L
i`039BTQ21cW008DY@@HaP8DY@0348@DYA24008@Q0LDY@H@Q0045:D@Q1BU48@35:D00a245:D@Q005
48@011BU48@@Q1240aBU0Q2400HDYA245:D<Ha2436<848@636<01Q245:DHaQBU48@DY@<@Q00436<@
Q0aS48@236<548@00`aS48@<H`0248@536<25:D01124248<H`aS0Q2400<<Ha2436<00`aS00<@Q0aS
24800PaS00@@Q0aS36<@Q0<<H`@@Q08<H`0448@<Ha245:D236<01@Q248@@Q12436<00Q2400@<H`Q2
36<<H`8@Q00436<@Q0aS48@236<00`Q236<@Q00336<348@736<01PQ236<<H`Q236<@Q0<<H`0348@<
Ha2400<<H`03248<H`aS008<H`0348@<H`aS00/<H`<@Q00336<8@PaS008<H`D@Q08<H`0648@DYA24
48@<H`Q21a240@aS000712400`Q200048@0212401ABU8@PHaPaS48@011S600<DYAS65:D00QBU11cW
1AS600<DYAS65:D00aBU0aS600<DYAS65:D00QS600<LiaS66<H011S60QBU0Q2411S60Q240QBU0aS6
0QBU0aS600<DYA245:D00Q2400<DYA245:D011BU11242ABU0QS61ABU00@@Q1BU5:DHaP<@Q0<DY@04
6<HDYAS66<H27>L01aS65:DDYABU6<HLiaS600HDY@<@Q0035:DHaQBU008@Q0045:DHaQS66<H25:D2
6<H27>L36<H011cW8@PLiacW1AS60QBU00<HaQcW8@P00QcW00<HaQcW8@P00b4811cW00<Q21cW7>L0
0acW00<DYAS67>L00R4800<LiaS65:D01AS60QcW00<HaR488@P00b480RU:00@U:AcW7>LLi`8HaP8L
i`@Q20036<HLiaS600<HaP067>LHaQS67>LQ21cW0b4800<U:B486<H00acW00HQ21cW7>LHaQBU7>L2
8@P00acW6<HDY@027>L36<H25:D37>L01aS648@DYABU6<HDYAS600<DY@036<HQ21S600<DY@<Li`03
6<HDYABU00<DY@<HaPDDY@037>LHaQS6008HaP045:DLiaS66<H35:D26<H25:D26<H00aBU48@DY@03
5:D011245:D@Q1BU0Q2400@DYAS65:DHaP<DY@8HaP8DY@0348@HaQBU008@Q08DY@076<HDYABU48@D
YA245:D00a2400<DYAS66<H00QBU00<@Q1BU5:D00QBU0aS600DDYA2448@@Q1S600@DY@0448@DYABU
5:D26<H45:D01QS648@DYAS67>LHaP8DY@076<HLiaS67>LQ21cW6<H00QBU00<LiaS65:D00QBU00<@
Q1BU48@00a240QBU00<HaQBU5:D00aBU0a242QBU00<@Q1BU48@00a2400DDYA245:DDYAS600DDY@`@
Q08<H`0448@<Ha2448@25:D011245:DHaQBU11240PaS00@@Q1BU48@@Q0<<H`045:D@Q0aS36<348@2
36<0112436<<H`aS0a240PaS00H@Q0aS48@@Q0aS48@436<348@00`aS48@<H`0436<248@336<248@0
10aS48@@Q1240`aS00<@Q0aS36<00PaS0Q2410aS00<@Q0aS36<00PaS0Q2410aS00<DYA245:D020aS
0Q241`aS00<8@PaS24800a2400<<H`Q236<00Q2400<8@PaS48@00Q2400<8@PaS36<00Q2400D<H`Q2
36<<HaBU008@Q0045:D<H`aS248636<00a245:D@Q00436<248@00`aS48@<H`0348@1248000050004
8@0012400007124011BU:DXHaQ241aBU1AS60QcW0QS600<DYAS66<H01aS600<DYAS66<H011cW1AS6
0aBU1AS600<DYAS65:D00QS60aBU00@HaQBU5:DHaPHDY@0448@DYABU6<H25:D00a245:DDY@025:D0
1A245:DHaQS65:D00Q240QS600<DYA245:D01QBU0QS600@DYAS65:D@Q0<DY@047>LHaQcW6<H25:D0
1AS65:DHaQS65:D00Q240QBU0QS600<DYA2448@01A241ABU00<HaQcW6<H00QBU00@HaQcW8@PLi`8H
aP035:DHaQBU00@HaP047>LHaQS67>L38@P01AS67>LLib487>L00QS60QcW0R4800@HaQcW6<HHaP<L
i`058@PLiacW7>LHaP027>L26<H051cW8@PQ21cW6<HLiaS67>LU:B489BTQ22DY;F/U:AcW6<HDYAS6
7>L28@P47>L46<H011BU6<HHaQcW0QS600@LiaS68@PQ20<Li`066<HLiaS67>LHaQcW0QS600DLibDY
9BTLiaBU008Li`035:DHaQS6008Li`036<HLiaS600<DY@8HaP0448@DYA246<H27>L00aS65:DDY@02
6<H00aBU6<HDY@026<H011BU48@DYA240QBU00<LiaS66<H00QBU11S600<DYAS65:D00aS60QBU0aS6
00@DYA2448@@Q0@HaP045:D@Q1BU6<H25:D00a245:DDY@036<H35:D01AS67>LLiaBU48@00QBU0QS6
0QBU00D@Q0aS48@DYAS6008DY@0448@DYAS65:D26<H248@010aS48@DYA240aBU0a2400@DYAS65:DD
Y@8HaP<@Q0DDY@<HaP035:D@Q1BU00<HaP035:DHaQBU008HaP047>LQ21cW6<H35:D36<H35:D348@0
0aBU48@DY@025:D01A245:DHaQBU48@00PaS00D@Q1BU48@DYA2400<DY@8@Q00536<@Q1245:D<H`03
48@00aS65:DDY@025:D448@00aBU48@<H`0248@25:D548@00`aS48@<H`0236<00a245:DDY@025:D2
6<H01QBU48@DYA245:D@Q08<H`<@Q0<<H`0448@<Ha245:D248@536<011245:D@Q0Q20PaS0QBU00@@
Q0aS248<H`8@Q003248<H`aS00<@Q0P<H`L@Q0035:D@Q0aS008<H`8DY@8@Q0H<H`0548@<H`aS48@<
H`0948@436<00a2436<8@P0936<00`Q236<<H`0348@936<00`Q236<<H`0348@236<00a2436<<H`06
36<00a2436<<H`0336<448@236<348@536<248@236<000H48@0400048@@Q000212401ABU9BTLia24
6<H00aBU0QS60Q2400@DYAS68@PLi`8HaP8DY@8HaP8Li`046<HDYAS65:D66<H27>L26<H00aBU6<HH
aP026<H35:D00a245:DDY@026<H45:D27>L00aS65:DDY@036<H011BU6<HHaQS60QBU00@@Q1BU5:DH
aPDDY@<@Q0035:DHaQBU00DDY@046<HDYABU6<H35:D01AS67>LHaQBU48@00aBU00DHaQBU5:DHaQBU
00<HaP@DY@036<HDYABU008DY@056<HDYA245:D@Q0025:D348@55:D37>L26<H00aBU6<HLi`027>L0
1QS65:DHaQcW6<HDY@8HaP<Li`046<HLiacW7>L28@P01bDY7>LLiacW8@PLib48008HaP067>LHaQcW
6<HLiaS60QcW0R480QcW00DQ21S66<HDYAS600LLi`8U:@06:DXU:BDY:DXU:B480QS60QcW00LHaR48
8@PQ21S65:DHaP027>L46<H00acW6<HHaP026<H28@P27>L00aS67>LLi`036<H27>L00aS67>LQ2002
7>L00aS67>LHaP036<H01QcW6<HHaQS67>LHaP8DY@036<HDYABU008DY@LHaP<DY@<HaP055:DHaQBU
48@DY@046<H35:D26<H01AcW6<HDYAS67>L00QS60aBU0QS61ABU00<HaQBU5:D00aBU00@@Q1BU48@@
Q0<DY@036<HDYAS6008HaP055:DHaQS66<HDY@0248@45:D0112436<@Q1241QBU00@HaQBU5:D@Q0<D
Y@0348@DYABU00<DY@0548@HaQBU6<HDY@0348@35:D011245:DHaQS60QBU00<HaQBU5:D00QBU1AS6
00@DYAS66<HHaP8Li`8HaP055:DLiaS65:D@Q0026<H00aBU48@@Q00248@35:D00a245:D@Q00248@0
11BU48@@Q1BU11240aBU2A2400DDYA245:DDYAS6008DY@8@Q0035:D@Q12400<@Q0035:D@Q12400D@
Q08<H`8@Q00836<@Q12448@HaQcW6<H@Q08<H`<DY@<<H`@@Q08<H`@@Q0<<H`@@Q0035:D<H`aS008<
H`@@Q0@<H`<@Q00336<@Q12400<<H`03248<Ha2400H<H`8@Q00436<8@PQ236<548@636<348@236<3
48@00`Q236<@Q00548@436<00a2436<<H`0236<348@436<248@436<01A2436<<H`aS24800PaS0Q24
0`aS0Q2400<<H`Q224800Q240`aS00<@Q0aS36<01@aS1A2410aS00<@Q0aS36<011240@aS0A240@Q2
00001@00124000@Q00001@@Q00T000@Q48@YBQS65:DHaQBU48@00QBU0aS600<DYAS67>L00QS600<L
iaS66<H00QS60QcW00/HaQBU6<HLib487>LDYAS67>LQ21cW008DY@8HaP8Q20037>LHaQS6008DY@<H
aPDDY@036<HDYAS600<DY@036<HDYA24008DY@046<HDYABU48@25:D00aS65:DDY@075:D011S65:DD
YA240QBU00<HaQBU5:D00QBU00D@Q1BU6<HHaQcW008DY@046<H@Q1BU5:D26<H37>L26<H35:D00acW
6<HHaP035:D348@01QBU48@<H`aS48@DY@8@Q0055:DLiaS66<HDY@056<H27>L28@P00acW6<HHaP02
6<H25:D011S65:DHaQS611cW0QS60QcW00HQ21cW6<HLib489BT27>L28@P00acW5:DDY@077>L01AS6
7>LLiaS67>L00R4800@U:AcW6<HHaP8Li`8U:@8Q20077>LU:BDY7>LHaQBU7>L00QS60QcW0R480acW
00@HaQcW6<HLi`DHaP8Li`038@PLiacW00HHaP047>LHaR487>L46<H011BU6<HHaQcW0QS600@LiaS6
6<HDY@8HaP8DY@0348@DYAS6008Li`8HaP045:DHaQBU5:D36<H25:D011245:D@Q1BU0aS600HLiaS6
6<HHaQcW6<H248@011BU7>LHaQ240aBU0QS611BU00@@Q1BU5:DHaP@DY@0348@DYA2400<DY@<HaP03
5:DHaQS600<HaP8DY@0448@DYAS65:D36<H011BU48@@Q1240QS611BU00@HaQBU5:DHaP8DY@@@Q0lD
Y@8HaP<DY@<HaPHDY@<HaP8DY@056<HLiaS67>LHaP025:D00aS65:DLi`026<H01ABU48@@Q1BU6<H0
0aBU0Q240aBU0a2400TDYA2448@@Q1BU6<H@Q0aS48@00PaS00D@Q1BU6<HDY@aS008@Q0045:D@Q124
5:D348@00aBU48@@Q00236<348@00aBU48@@Q00248@236<248@00`aS48@@Q00348@46<H348@236<0
1A2436<<H`aS48@010aS0a240`aS0Q2400@<Ha2448@@Q0<<H`0348@DYA24008<H`0348@<Ha24008@
Q0<<H`04248<Ha2448@236<010Q236<<Ha240`aS00DDYA2436<@Q1BU008@Q00436<@Q0aS48@836<0
0`Q236<@Q00348@00`aS48@<H`0:36<00`Q236<<H`0436<00`Q236<<H`0248@2248236<248@236<0
0a2436<@Q00436<00a2436<<H`0336<00a2436<<H`0236<448@00`aS48@<H`0336<248@436<00`Q2
36<<H`0548@00`aS48@<H`0236<000`48@0648@YBQcW48@DYA240QS600<DYAS66<H011S60QcW00<H
aQBU5:D01AS60QBU0acW0QBU00LHaQcW7>LDYAS65:DHaP037>L26<H25:D00aS65:DDY@035:D26<H0
0aBU6<HHaP025:D01A245:DDYA245:D00aS611BU0QS60QBU00<HaQBU5:D00Q2411BU0Q240aBU00@H
aQBU5:D@Q08DY@8HaPLDY@8HaP047>LHaQS66<H45:D26<H011BU6<HDYAS60QBU0Q2400<<Ha2448@0
11240aS600<DYAS66<H011S60acW00LHaQcW7>LHaQBU6<HDY@056<H28@P36<H01AcW9BTLiacW6<H0
1AcW00PQ21cW7>LLiaBU6<HLib480QcW0QS60QcW0QS60R4800@YBR487>LHaP<Li`078@PU:B488@PU
:B489BT00QcW0aS621cW0QS60QcW0QS600@DYAS66<HLi`8Q20077>LHaQBU6<HLiaS67>L00QS611cW
2QS600<LiaS66<H01QBU1AS60aBU00<HaQBU5:D00Q2411BU0QS60aBU0QS600@LiaS65:DHaP<DY@04
48@HaQBU7>L46<H25:D00a245:DDY@095:D011S65:DDYABU21S600<@Q1BU6<H00QS60Q240aBU00T@
Q0aS48@DYAcW6<HDYA246<H00QBU00<HaQBU5:D0112400<DYA2448@00aBU0QS60QBU0Q241QBU00@H
aQBU5:DDY@<HaP@DY@<HaP065:DHaQBU5:DHaQcW0QS60aBU0aS600<DYA2448@00Q2411BU112400DD
YA2448@@Q1BU008@Q0@DY@8@Q08<H`0648@DYABU48@DYA240QBU00@@Q1BU5:DDY@<@Q08DY@8@Q005
36<@Q1BU5:D@Q00536<348@01ABU36<<Ha245:D00aS600HDYA2448@@Q1BU48@336<348@336<248@2
36<348@010aS48@@Q1240`aS112400<<Ha2448@00Q240`aS112410aS00<8@PaS36<00`aS11240PaS
00L@Q0aS36<<Ha2436<@Q00236<03A2436<@Q12436<8@PaS48@DYA2436<8@PaS00H@Q0D<H`0348@<
H`aS00<<H`03248<H`aS008<H`0348@<H`aS008<H`8@Q0D<H`0848@<H`aS248<Ha2436<@Q08<H`03
48@<H`aS008<H`0348@<Ha2400L<H`0348@<Ha2400<<H`0348@<H`aS00@@Q00536<@Q12436<@Q001
2480000300048@0000848@0500048@@Q1240000212401QBU:DXLia245:DHaP8DY@8HaP8Li`046<HD
YAS66<H27>L011S65:D@Q1BU0QcW00<HaQcW5:D02AS600DDYAcW7>LQ21S600<DY@047>LHaQS66<H4
5:D00a245:DDY@095:D00a245:DHaP025:D011245:DHaQS60aBU0aS600<@Q1BU5:D00QBU00<@Q1BU
7>L00QBU00@<Ha245:DDY@8HaP<Li`8DY@0548@DYAS67>LQ20047>L00aS65:DDY@025:D00aS65:DD
Y@035:D011S65:DDY@aS0Q2400@<HaBU48@DY@8@Q08DY@046<HDYAS65:D37>L28@P00aS65:D@Q002
5:D36<H45:D00aS67>LHaP035:D00b487>LLi`026<H01R489BTYBRU:8@PLi`<HaPTLi`046<HLiacW
7>L39BT00acW6<HLi`027>L38@P011cW6<HQ21cW0QS600<DYAS67>L01AS611cW00<HaQcW7>L00QS6
00LDYAS68@PQ22DY8@PLi`026<H021cW5:DHaQBU6<HLib487>L26<H25:D37>L01QS65:DHaQcW6<HD
Y@<HaP035:D@Q1BU00THaP035:DHaQBU008HaP@DY@0548@DYA245:DHaP027>L01AS65:DDYAS65:D0
0QS600@DYAS65:DDY@8@Q0HDY@0548@DYAS66<HDY@0248@00aS65:DDY@036<H25:D00aS67>LHaP02
5:D26<H011cW6<HDYA2411BU00<@Q1BU5:D01aBU00<HaQBU6<H00aBU112400<DYA245:D00a240QBU
00<HaQBU48@00aBU0aS60aBU00DHaQBU6<HDYAS6008DY@066<HDYABU5:D@Q1BU0aS600<DYAS67>L0
0QS611BU00@HaQBU5:D@Q0@DY@046<HDYA2448@25:D00a2436<@Q0025:D01Q245:D@Q1BU48@DY@8@
Q00336<@Q0aS00<@Q0085:D@Q1BU48@HaQBU48@DY@8<H`8@Q0045:D@Q12436<35:D01Q2436<<H`aS
48@<H`@@Q08<H`0448@DYABU7>L36<H01aBU48@<H`aS48@<Ha2400H<H`D@Q0<<H`8@Q08<H`8@Q006
36<@Q12448@DYA240`aS0Q240PaS00<8@PaS36<0112410aS0a2400<<Ha2448@00PaS0a2400@<H`Q2
36<<H`8@Q088@P@<H`@@Q0<<H`0348@<Ha24008@Q0<<H`<@Q0<<H`05248<H`aS48@<H`02248236<0
0`Q248@@Q00336<448@436<01A2436<<H`aS48@01`aS00@DYA2436<8@Pd<H`04248@Q12448@336<0
112436<<Ha240PaS000312400`0012448@0412402000124HaRU:7>L@Q1BU6<H25:D011245:DHaQcW
0aS60acW00<HaQBU5:D00QS60QcW0aS60QcW0QS60QcW0QS600@DYAS67>LQ208Li`<DY@<HaP8DY@8@
Q0@DY@046<HDYA2448@35:D00a245:DHaP036<H45:D26<H00aBU6<HDY@075:D011S65:DDYA241ABU
1AS60aBU00@HaQBU8@PLi`8Q20036<HDYAS600@HaP8DY@8@Q00:5:D@Q1245:D@Q0aS48@DYA245:D2
48@011BU6<HLiaS60QBU00LHaQcW6<HLib487>LHaP025:D26<H35:D01AS65:DHaQS67>L00aS600DD
YAS67>LQ21cW008HaP048@PU:Be[:DX47>L011S65:DHaQcW0R4800<LiaS68@P00acW00PQ22DY8@PL
ib489BTLiaS60QcW0RDY0b480acW0aS600@DYAcW8@PLi`@HaP038@PLiacW008Li`0>5:DHaQ246<HL
ib489BTQ21S67>LHaQBU6<HDY@<HaP047>LQ21cW7>L25:D26<H011cW6<HHaQS60QcW00@HaQ245:DD
Y@@HaP035:DHaQS6008Li`8HaP037>LHaQ24008DY@8HaP0648@DYABU6<HDYA240QBU00<HaQcW6<H0
0QS611BU00@HaQBU48@DY@DHaP8DY@8@Q0035:D@Q1BU008DY@0348@DYABU008DY@8HaP035:DHaQBU
00HHaP047>LDYAS648@25:D011S65:DHaQS62QBU0QcW0QBU0a2400<DYA2448@00a242ABU00<HaQBU
5:D00QS611BU0aS600<DY@aS48@00QBU0aS60QBU0QS600`DYAS66<HHaQ245:DHaQcW6<H@Q1BU6<H2
5:D011245:DDYABU112400<DYA245:D00aBU00D@Q1BU48@@Q1S6008@Q08<H`0348@DYABU00@@Q003
5:DHaQS600L@Q0045:D@Q0aS48@25:D01Q2436<@Q0aS48@<H`8@Q08<H`8@Q08DY@046<HLiaS66<H4
48@336<248@01PaS2488@PaS48@<H`8@Q00336<@Q0aS00<<H`8@Q08<H`8@Q08DY@0348@<Ha24008@
Q00336<@Q1BU00<<H`0348@<H`aS008<H`0548@<H`aS36<@Q00436<01A2436<<Ha2436<00a2400<<
Ha2448@00a240`aS112400D<Ha2436<@Q0aS00@@Q08<H`0348@<H`aS00@<H`03248<H`aS00<<H`8@
Q00836<@Q0Q2248<Ha245:D@Q08<H`<@Q08<H`03248<H`aS008@Q08<H`8@Q0@<H`<@Q0P<H`8@Q0<<
H`0348@<H`aS00<@Q0045:D<H`aS48@336<0000700048@@Q124000@Q00001@@Q00HDYBe[6<H<Ha24
6<H37>L01aS65:DHaQS65:DHaQBU00<HaP035:DHaQS6008HaP<DY@@HaPDDY@036<HDYABU00<DY@<L
i`076<H@Q1BU5:DHaQBU48@00aBU00/HaQBU5:DDYA245:D@Q1BU48@DYA2400@DY@<HaP035:DHaQS6
00XDY@8HaP@DY@0648@HaQS67>LQ21S60aBU00@LiaS67>LHaP<Li`8HaP035:DHaQS6008DY@0448@D
YABU5:D26<H0112436<<Ha240aBU00L@Q1BU5:D@Q1S67>LHaP025:D00aS68@PLi`036<H00aBU6<HD
Y@025:D00a245:DHaP026<H01QBU7>LHaQS648@DY@8Li`076<HLiacW6<HDYAS68@P00RU:0R4800<L
iaS67>L00aS60acW0R4800<LiaS67>L00bDY0QcW0b4800<LiaS66<H00R4800@U:AcW7>LLi`<HaP8L
i`045:DHaQcW7>L26<H27>L00b487>LLi`056<H47>L00aS65:DDY@026<H00aBU48@Li`028@P011BU
6<HQ21cW0QBU0QcW00@HaQBU6<HLi`8HaP<DY@8HaP0448@DYAS67>L36<H01QcW6<HDYA245:DHaPHD
Y@0348@DYA24008DY@036<HLiacW00<DY@8HaP035:D@Q1BU008HaP@DY@0348@DYAS6008DY@0436<@
Q1BU48@25:D01AS65:DDYABU6<H00aBU0QcW0QBU00HHaQcW7>LHaQBU48@45:D00aS65:D@Q0055:D0
0aS65:DHaP055:D348@00aBU48@DY@0348@00aBU48@@Q00248@011BU48@DYABU0QS600DLiaBU5:D@
Q1S6008DY@8HaP<DY@8HaP8DY@0448@DYABU6<H248@01ABU6<HLiaBU48@00aBU00@@Q1BU5:D@Q08D
Y@0348@DYA2400@DY@0348@<Ha24008@Q0<DY@<@Q0035:D@Q0aS008<H`@@Q0@DY@0348@DY@aS008<
H`<@Q0<<H`8@Q08DY@0748@<H`aS36<@Q0aS48@00PaS112400PDYAS66<HHaQBU6<H@Q1BU0PaS00@@
Q0aS36<<H`<@Q0@<H`035:D@Q12400<<H`<@Q0035:D@Q12400<@Q08<H`8@Q0035:D@Q0aS008<H`04
48@<H`aS36<248@236<2248236<00a2436<<H`0836<00a2436<@Q00836<348@236<00a245:D<H`02
36<348@236<01@Q236<@Q0aS24803`aS1Q240`aS00@8@PaS36<@Q0T<H`0348@<Ha2400@<H`0348@<
H`aS008<H`03248<H`aS00<<H`8@Q00336<@Q0aS00L<H`000P@Q00<000@Q12401@@Q00L000@Q5:DY
BR4848@DY@026<H00acW6<HHaP026<H01ABU6<HHaQBU6<H00QcW0QS600DLiaS66<HHaQBU00@HaP03
5:DHaQS6008DY@8HaP047>LHaQS65:D36<H00acW6<HHaP025:D00a245:DHaP026<H011BU48@DYAS6
0QBU0a2400@DYA245:DHaP8DY@<HaP@DY@046<HLiaBU5:D248@00aS65:DDY@046<H45:D26<H27>L0
1AS65:DDYABU6<H00QcW0aS600DLiaS66<HDYAS600HDY@036<HDYAS6008@Q08<H`8@Q08DY@0348@D
YAS600@DY@036<HLib4800<Li`8HaP035:D@Q1S600<DY@8HaP055:DHaQcW7>LHaP025:D26<H37>L0
11S648@HaR480RU:0R480QcW1AS60QcW00<Q21cW7>L00QcW00HQ22DY9BTLib489BT27>L00aS67>LQ
20067>L26<H27>L26<H00aBU7>LLi`026<H011cW8@PLiaS60QcW00@HaQBU5:DHaP8Q208Li`8DY@DH
aP037>LQ21cW008DY@8Li`065:DHaQS67>LHaQBU0acW0aBU0QS600HDYA2448@HaQcW8@P36<H55:D0
11S65:D@Q1BU0aS600@DYA245:DDY@8HaPDDY@036<HDYABU008HaP<DY@046<HDYA245:D26<H011BU
48@@Q1BU0Q2400@DYAS66<HDY@8@Q08DY@057>LQ21S66<H@Q0066<H01aBU48@DYABU6<HDYAS6008D
Y@8@Q0HDY@076<HLiaS648@8@Q245:D01Q2400<DYA245:D011BU00@@Q1BU6<HHaP8DY@0348@DYAS6
008DY@<HaP045:D@Q1BU5:D36<H45:D36<H45:D00a245:DDY@025:D01QS65:DDYABU6<HDY@D@Q004
36<@Q1BU5:D448@00aBU48@<H`0548@01@aS48@DYABU6<H00QBU0Q2400<<Ha2448@00a2410aS00@D
YA245:D@Q0@<H`<@Q0<<H`0448@HaQS66<H55:D248@336<248@236<00`Q236<@Q00236<348@00`aS
48@@Q0025:D348@00`aS48@DY@0448@01ABU48@<H`aS48@01@aS00<@Q0aS36<00`aS00<@Q0aS36<0
0`aS00<@Q0aS36<01PaS00<8@PaS36<00Q240PaS00@8@PaS48@@Q0<<H`8DY@8<H`04248<Ha2448@5
36<00a2436<<H`0236<020Q236<<H`Q236<8@PaS248236<00a245:D@Q00248@236<00a2436<@Q004
36<248@02@aS48@<Ha2436<8@Q2436<@Q00936<248@236<010Q236<<Ha240PaS0Q240PaS00@8@PaS
36<@Q04<H`0000@000@Q124000D48@0800048@@Q6<H]Jb485:D@Q08HaP8Q20036<HDYAS6008DY@8H
aP037>LHaQS600<HaP047>LHaQBU6<H45:D26<H85:D36<H01AcW6<HHaQBU6<H00QBU0Q240aBU0QS6
0QBU112400<HaQcW6<H01ABU0QS600<LiaS65:D00aS600HDYA245:DDYAS65:D36<H01QBU48@HaQS6
5:DLi`<Q20<HaP055:DHaQS66<HLi`026<H65:D348@25:D011245:DDYAS60Q2400<<HaBU5:D00QS6
0aBU0QS60QBU00@HaQcW8@PQ208HaP8DY@056<HDYABU5:D@Q0045:D00aS67>LHaP035:D27>L26<H0
0aBU6<HHaP028@P01BDY8@PLiacW8@P01AcW00<HaQcW6<H00acW00DHaQcW7>LQ21cW00DQ20077>LH
aQS67>LQ21cW8@P00QcW00@HaQcW5:DHaP<Li`<HaP8Q208Li`056<HDYAS66<HLi`025:D011S67>LL
iaS60QBU0QS600<LiaS67>L00R480aS60QcW00<HaQBU6<H00QS600<DYAS67>L00QS600@@Q1BU5:DL
i`8HaP035:DHaQcW00<DY@036<HLiacW008HaP8DY@8HaP8DY@0548@DYABU5:DLi`046<H01QBU48@D
YABU6<HLi`8HaP045:DHaQBU5:D248@25:D248@35:D248@00aBU48@DY@045:D27>L26<H02Q245:DH
aQS67>LHaQBU48@DYA2411BU00DHaQBU6<HDYAS600<DY@8HaP<DY@D@Q08DY@@@Q08DY@036<HDYA24
008@Q0<DY@036<HDYABU00<@Q08DY@066<HDYABU6<HDYAS61QBU00@HaQBU5:DDY@8HaP<DY@0348@D
YA24008@Q0045:D@Q1BU48@45:D648@00aBU48@DY@0448@236<248@011BU48@<Ha240QBU0QS60aBU
10aS00@@Q0aS48@<H`D@Q0<<H`D@Q08<H`0348@DYABU00@DY@L@Q00736<@Q0aS36<@Q0aS48@00PaS
0a2410aS3Q2400<<Ha2448@00Q240`aS00<@Q0aS36<02PaS11240PaS00<8@PaS36<01PaS0a240`aS
112400<DYA2448@02@aS00<@Q0aS48@01@aS0`Q200<<Ha2448@00a2400HDYA2436<8@PaS48@336<3
48@01@aS48@<H`aS24800`aS00<@Q0aS36<01PaS00<@Q0aS48@00`aS0Q241PaS00<@Q0aS48@00Q24
0@aS0@Q2000512400`0012448@0412403ABU<H`Q20aS5:DHaQcW8@PLiaS65:DHaQBU008HaP<Li`8H
aP035:DHaQS600<DY@8HaP035:DHaQBU008DY@036<HDYABU00@HaP035:DHaQS6008HaP035:DHaQS6
00DDY@0448@DYABU5:D26<H011BU48@@Q1240QBU00<HaQBU5:D01QBU00@HaQcW6<HHaP@DY@8@Q0DH
aP065:D@Q1BU5:DQ22DY0R4800@LiaS66<HDY@@HaP<DY@8HaP<DY@0348@DYA2400DDY@0448@DYA24
36<248@01QS65:DHaQBU6<HDY@8HaP035:DHaQcW008Li`@HaP8DY@8@Q0<DY@036<HDYAS6008HaP8D
Y@056<HLiacW7>LDY@026<H011cW9BTU:BDY0R480QcW0QS600<DYAS67>L02QcW0R4800<U:AcW8@P0
0aS600@Lib487>LQ20DLi`<HaP8Li`085:DHaQcW9BTQ21S67>LHaP<DY@@HaP067>LHaQS65:DHaQcW
0aS600DLiaS68@PLiaS600<Li`036<HDYAS600HHaP037>LHaQBU00@DY@DHaP047>LHaQcW6<H248@2
5:D00acW6<HHaP025:D248@25:D36<H011BU48@DYABU0QS60QBU00DHaQcW5:DDYA2400DDY@036<HD
YA24008<H`0548@DYAS66<HDY@0248@011S67>LLiaS60aBU1AS600@DYA2448@DY@8HaP<DY@0348@D
YA24008DY@036<HDYABU008HaP8@Q00436<@Q1BU5:D236<011245:DDYABU0a2400<DYA245:D00Q24
11BU00<@Q1BU5:D01QBU00@HaQBU5:DDY@<HaP0348@DYABU00<DY@<HaP065:D@Q1BU48@HaQBU0Q24
00<DYA2448@00Q240QBU2A240aBU0Q240PaS00<@Q1BU48@00Q240aBU00<HaQcW5:D00`aS00<@Q0aS
48@011240QBU00<@Q0aS48@00Q2400D8@PaS36<@Q1BU008@Q08<H`045:DHaQS66<H348@25:D00a24
36<<H`0336<348@236<248@436<01A2436<<H`aS48@00QBU00H@Q0aS48@@Q1BU48@236<01A2436<<
H`aS48@00`aS00<@Q0aS24800`aS00<@Q0aS36<00`aS00<@Q0aS36<010aS00P@Q0aS2488@PaS48@<
H`Q210aS0a240`aS11241`aS0a240PaS00<8@PaS36<00PaS00@8@PaS48@@Q0<<H`0448@<H`aS36<3
48@636<248@436<00a2436<@Q00336<01PQ248@@Q12436<8@PP<H`@@Q00436<@Q0aS248236<248@1
36<124800005124000@Q1240000712401QS6;F/Q21245:DHaP8Li`046<HDYABU6<H25:D36<H47>L2
5:D27>L011BU48@<Ha240aS600@DYA245:DHaP<DY@<HaP@DY@037>LDYABU00<DY@046<HDYABU5:D2
6<H00aBU48@DY@0248@46<H00aBU6<HHaP026<H37>L25:D26<H248@011BU6<HDYA240QBU00<HaQ24
5:D00aBU00@HaR487>LLi`8DY@096<HLiaS66<HDYA245:DHaQBU00<HaP035:D@Q12400LDY@036<HD
YABU008DY@0348@DYABU00DHaP<DY@036<HLiacW008HaPDDY@0348@DYAS600@HaP037>LHaQS600@H
aP8DY@8HaP065:DQ22U::DXU:AS611cW0aS600DLib487>LQ21cW008HaP<Li`8Q20037>LQ21cW008Q
20077>LHaQcW7>LDYAS67>L00RDY11S600@Q21cW6<HHaP<Li`DHaP8DY@047>LQ22DY7>L35:D021S6
7>LHaQS67>LQ21cW5:D37>L25:D36<H01ABU6<HHaQS67>L00QS600LDYAS65:D@Q1S67>LHaP035:D0
0acW6<HHaP036<H011BU6<HQ21S60QBU0QS600<DYA2448@00QS600TLiaS67>L@Q0aS48@HaQcW6<H0
0QBU0QS600DDYA245:DDYAS6008DY@8@Q0045:DHaQS66<H55:D26<H03QcW6<HDYA245:DHaQBU6<HD
YA245:D@Q1BU48@25:D00aS65:D@Q0065:D36<H35:D01A245:DDYA2436<00Q2400<DYAS65:D00QBU
0a2400<HaQBU5:D00QBU00<HaQBU48@01QBU00@HaQBU6<H@Q08HaP@DY@LHaP0348@DYABU00<DY@05
48@DYABU5:D@Q0025:D00aS65:DDY@0248@00aBU48@@Q00348@010aS48@DYABU0Q240PaS0a2400<<
Ha2448@00QBU00<@Q1BU5:D01Q240PaS0Q2400<DYA2448@01@aS00<@Q0aS36<00a2400<<Ha2436<0
1ABU00<@Q1BU48@00Q240PaS0Q240`aS0Q2400T<Ha2448@@Q0aS248<Ha2436<01A240`aS0Q2400<D
YA2448@00PaS00<@Q0aS36<00PaS00H@Q0aS36<@Q0aS48@236<00a2436<<H`0636<010Q236<@Q124
0`aS00<8@PaS48@00Q241PaS00@@Q0aS48@@Q08DY@0348@<H`aS00D<H`8@Q08<H`0348@<H`aS00<<
H`03248<H`Q200P<H`0548@<H`aS36<8@P0636<00a2436<@Q00236<00a2436<<H`0236<00`Q236<<
H`0836<248@436<00a2436<@Q00336<348@236<0000300048@0000L48@0900048AcW<H`Q21245:DH
aQcW008HaP8DY@076<HDYABU6<HDYAcW6<H00QcW1AS600DDYA245:DDYAS600DDY@<HaP<DY@8Li`04
6<H@Q1BU5:D36<H01Q246<HHaQBU48@DY@8HaP0448@DYABU6<H35:D03AS65:DDYAS67>LDYA247>LU
:B485:D@Q1BU008HaP8@Q0055:D@Q1BU5:DHaP025:D011245:DDYABU0QcW00<Q21cW5:D01AS600/D
YAS66<HDYA245:DHaQcW5:D@Q0aS00<DY@066<H@Q1BU5:D@Q1BU0Q2400<DYAS66<H00aBU00<HaQcW
6<H00aBU00<HaQcW7>L00QS60QBU00<HaQBU48@00QBU00LHaQBU6<HHaQcW6<HLi`036<H00acW6<HL
i`026<H00aBU6<HU:@02:DX01BDY7>LLiacW6<H00QBU0QcW00DHaQcW8@PQ21cW008HaP077>LHaQcW
7>LQ22DY8@P011cW00<Q21cW6<H00QcW00TQ21cW8@PLiaS65:DHaQcW8@P00QcW00<HaQcW7>L00acW
0aBU00<HaQcW8@P00QcW00<HaQBU5:D00QS600@DYAS68@PQ20<HaP038@PLiaS6008DY@HHaP8Li`8H
aP<DY@046<HLiaS67>L25:D26<H011cW6<HDYABU0aS600<LiaS65:D00QBU00<@Q1BU5:D011S60QBU
00@@Q1BU5:DHaP8DY@<HaP035:D@Q1BU008@Q0035:DHaQBU008@Q0045:DHaQS66<H35:D56<H25:D2
48@46<H00a245:DDY@046<H:5:D00a245:DDY@0348@35:D248@55:D248@45:D00a246<HHaP055:D2
48@01ABU6<HHaQ245:D00Q240QS60QBU00<HaQBU5:D01AS600DDYA245:DDYA2400DDY@8@Q0035:DH
aQBU00<@Q0<DY@0448@DYA2448@35:D0112436<<H`aS11240PaS0QBU00<HaQBU48@00Q2400<DYA24
36<00PaS00@@Q1BU6<H@Q08<H`8@Q0<<H`D@Q08<H`0448@DYABU5:D248@00aBU48@DY@0448@010aS
48@<H`aS0a240PaS112400D8@PaS48@DYA24008<H`8@Q0<<H`045:D@Q12448@936<00a2436<<H`02
36<00a2436<<H`0436<00a2436<8@P0236<00a2436<<H`0536<0112436<8@PaS0a240PaS112400@<
Ha2448@@Q0L<H`8@Q0d<H`0348@<H`aS008@Q00336<8@PaS00@@Q0T<H`0548@<H`aS36<@Q00536<0
10Q236<<Ha240PaS0Q2410aS00D@Q0aS36<<Ha24008<H`4@Q04<H`48@P0010@Q00<000@Q12400P@Q
00L000@Q124DYBe[7>LDY@046<H25:D56<H00acW6<HHaP025:D03AS67>LLiaS65:D@Q1S65:DHaQBU
6<HDYAS600<DY@8HaP8DY@<HaP0348@DYABU00@DY@066<HDYA245:DHaQBU0Q2400HDYA2436<@Q1S6
7>L46<H011BU6<HLiacW0QS600HDYAS66<HDYA245:D46<H25:D00aS65:DDY@045:D01AS67>LQ21S6
5:D01QS600@@Q1BU48@DY@@HaPHDY@036<H@Q124008DY@8HaP8DY@036<HDYABU008HaP035:DHaQBU
00DHaP8DY@076<HDYABU48@DYAS65:D00aS60QcW0QS60acW00<HaQcW7>L011cW00@U:BU:9BTQ20<L
i`<HaP037>LQ21cW00PLi`038@PLib48008Li`8Q20DLi`8HaPdLi`068@PHaQS648@HaQcW0QS60QcW
00@Q21cW5:DHaP8DY@8Li`068@PLiaS67>LHaQcW11S600PDYAcW7>LQ21S648@HaQcW0QBU00D@Q1BU
6<HHaQBU008HaP075:DHaQBU6<HLib487>L00QS600<DYAS65:D00acW00DHaQBU48@HaQBU00@HaP03
5:D@Q1BU00<DY@066<HDYAS66<HDYA240QBU00<LiaS65:D00aBU00LHaQcW7>LDYA245:DHaP035:D2
7>L00aBU48@DY@035:D26<H35:D00aS65:DDY@025:D00aS65:DDY@025:D01AS65:D@Q1245:D00QS6
1ABU1A240aBU0Q2400<DYAS65:D00aBU0Q2411BU00@@Q1S65:DDY@8@Q0045:DHaQcW6<H25:D00aS6
5:DDY@056<H25:D00aS65:DDY@095:D348@00aBU48@@Q00236<648@25:D00`aS48@@Q0025:D648@0
0aBU48@@Q00748@00aBU48@DY@0348@00`aS48@@Q00248@01PaS48@@Q0aS48@<H`<@Q0035:D@Q124
008@Q0035:D@Q124008DY@0348@<H`aS00<@Q08<H`<@Q08<H`0548@<Ha2436<@Q00336<348@336<6
48@00`aS248<H`0236<0112436<<H`aS0PQ20PaS0a240PaS00<8@PaS36<010aS00<@Q0aS36<00PaS
00<@Q0aS36<011240`aS112400@<Ha2448@@Q0H<H`D@Q0<<H`0348@<H`aS0088@P0536<@Q0aS36<8
@P0248@00`aS248<H`0?36<00a2436<<H`0248@236<010Q236<@Q1240`aS0Q240PaS0a240PaS0Q24
0PaS00@@Q0aS48@@Q048@P000P@Q00@000@Q124000H48@075:D]Jb4848@DYAS65:D01QS60aBU0QS6
0QcW0aS611BU00DHaQBU5:DDYAS600@DY@0348@DYAS6008Li`036<HDYABU00<HaP8@Q08DY@036<HD
YA24008@Q0<DY@<@Q0045:DHaQS65:D26<H35:D27>L35:D00a245:DHaP025:D011S65:D@Q12411BU
00/HaQBU6<HDYAS67>LHaQcW6<HDYAcW008HaP<DY@0348@DYAS6008HaP8DY@056<HDYABU5:D@Q009
5:D01AS65:D@Q1245:D00QS600@DYAS66<HHaP8DY@046<HLiacW6<H55:D26<H02ABU7>LLiacW6<HD
YAS68@PHaP025:D27>L48@P29BT012486<HLiacW0aS611cW0QS60QcW0aS60acW00PHaQcW8@PQ22DY
8@PHaQcW0QBU00@HaQcW9BTQ20LLi`@HaP037>LHaQcW00<HaP8Li`038@PLiaS600DDY@DLi`088@PL
iaS66<HLiaS648@DY@8Q20036<HDYAS6008HaP035:D@Q1BU008DY@037>LHaQBU008HaP035:DHaQS6
00<Li`045:DHaQBU5:D37>L011S65:DDYAS60QBU00@HaQcW5:DDY@8@Q0DDY@056<HDYA2448@DY@02
7>L00aS648@@Q00248@46<H25:D46<H25:D36<H00aBU48@DY@026<H35:D26<H011245:DHaQBU0Q24
0aS600<@Q1BU48@00aBU00<@Q1BU5:D00aBU00D@Q1BU48@DYA2400@DY@8@Q0HDY@8@Q0<DY@0348@D
YABU008DY@046<HDYABU6<H45:D76<H35:D248@00aBU6<H@Q0025:D26<H248@35:D248@25:D548@2
36<248@01QBU48@<H`aS48@<H`8@Q0055:D@Q12448@<H`0748@010aS48@@Q1BU1A240PaS0Q240PaS
11240aBU0Q2400<DYA2448@0112400<<Ha2436<00PaS0Q2400<<Ha2436<00PaS0a240PaS0Q2400<D
YA2436<00`aS0Q240PaS00<@Q1BU48@010aS00<@Q0aS48@010aS00@@Q0aS36<<H`8@Q0@<H`03248<
H`aS008@Q0@<H`<@Q0@<H`D@Q08<H`@@Q08<H`0348@<H`aS00@<H`0348@<Ha2400L<H`0348@<Ha24
008@Q0@<H`03248<H`aS00@<H`<8@P0548@<H`aS36<@Q00636<0112436<<Ha2410aS00D@Q0aS36<<
Ha2400<<H`8@Q0<<H`8@Q0035:D@Q0aS00448@0000@000@Q124000848@040008@P@Q000212400aBU
;F/Q20026<H01ABU48@DYABU6<H00aBU00<HaQcW6<H00QS600<DYAS65:D00QS60QBU00<HaQBU6<H0
0QS60QBU00<HaQBU6<H00QBU00L@Q1BU5:DDYAS65:DHaP027>L25:D00a245:DHaP026<H0112436<<
Ha2411BU0QS60QcW00@HaQBU5:DDY@DHaP<DY@0348@DYAS600<DY@036<HLiaS600<DY@<HaP8DY@8H
aP0948@DYAcW7>LHaQBU48@DYAS600<DY@8@Q0<DY@066<HDYABU5:D@Q1BU0Q240QBU1QS600<LiaS6
6<H00QBU00@HaQcW7>LQ208HaP035:DHaQS600<DY@057>LHaQBU5:DHaP035:D37>L01ABU6<HHaQS6
7>L00bDY0R4800<U:B488@P011cW0QS60QcW0QS60QcW00<HaQcW7>L01QcW00<Q21cW8@P011cW11S6
00DLib488@PLib48008HaP8Q20039BTQ21BU00DHaP057>LHaQS67>LQ20027>L36<H47>L01QS67>LL
iacW6<HDY@8HaP8Li`LHaPDDY@046<HDYABU6<H37>L25:D36<H27>L00aS67>LHaP036<H45:D36<H<
5:D01Q245:DDYABU48@DY@8HaP035:D@Q1BU008HaP8@Q0035:D@Q1BU008DY@056<HDYABU5:D@Q004
5:D00aS65:DHaP025:D46<H35:D01AS65:DDYABU6<H00Q240QBU00<HaQBU5:D01A240aBU0a240aS6
00@DYA2448@@Q08DY@0348@DYABU008HaP0348@DYABU008DY@036<HDYABU00<HaP<DY@036<HDYAS6
00<DY@0348@DYABU008DY@0348@DYA2400<DY@0348@DYABU008DY@0348@<H`aS00D@Q0035:D@Q0aS
00<@Q08DY@8@Q0035:D@Q124008@Q08DY@<@Q0035:D@Q1BU008@Q0045:D@Q12436<448@010aS48@@
Q12410aS00HDYA2448@<Ha2436<348@011BU48@DYABU0a2400@<Ha2436<<H`<@Q00436<@Q1245:D4
48@00`Q236<<H`0348@01PaS48@@Q12436<@Q08<H`0348@<Ha24008@Q00836<8@PaS36<@Q0aS248<
H`8@Q0T<H`04248<H`aS248236<248@236<00a2436<@Q00736<348@;36<0112436<<H`aS0a2430aS
00<@Q0aS36<00PaS00H@Q0aS2488@PaS48@236<010Q236<@Q12410aS0Q2400D<H`Q236<<H`Q2008<
H`L@Q0T<H`4@Q04<H`4<H`0000<48@00124020@Q00l001BU;F/Q21BU6<HDYAS65:DHaQBU6<HDYAS6
7>L00QS600<DYAS66<H00QBU11S600<DYAS65:D00QBU0aS600<DYAS66<H00aBU0QS600<DYA245:D0
0QBU00<HaQBU6<H00aS60a2400P<HaBU5:D@Q1BU48@HaQBU0aS600<LiaS66<H01AS60QBU00<@Q1BU
5:D00QBU00<@Q1BU7>L00QcW0QBU00DHaQBU5:D@Q1S6008Li`8HaP8DY@036<HDYABU00LDY@8@Q0<D
Y@036<HDYABU008@Q0@DY@<HaP065:DHaQcW6<HLiaS60QBU00<HaQcW7>L00QS600<LiaS66<H011BU
1AS60QBU00@HaR488@PLi`8DY@8HaP8Li`0:8@PU:AcW9BTYBRDY7>LDYAcW8@P36<H37>L00aS67>LH
aP026<H27>L26<H00acW8@PU:@028@P37>L26<H00aBU6<HQ20067>L011S67>LQ22480QcW00LHaQcW
6<HDYAS67>LQ20026<H47>L00aBU6<HHaP026<H011cW6<HLiaS60QBU0QS60QcW00<HaQBU5:D00QcW
1QS600DDYA246<HLiaS600<DY@037>LHaQS600<HaP055:DHaQS68@PLi`026<H35:D00aS65:DHaP03
6<H011BU48@@Q1241ABU0Q2400HDYAS66<HDYA245:D248@45:D00a245:DDY@025:D00aS65:DHaP02
5:D00aS65:DDY@025:D56<H01A245:DDYABU7>L00aS60QBU0QS600<DYAS65:D00QBU0Q2400DHaQBU
5:DDYA2400<DY@0:48@DYA2436<@Q1BU6<HLiaS65:D648@02ABU6<HHaQBU6<HDYA245:DHaP055:D0
21S65:DDYA245:DHaQBU6<H45:D00a245:DDY@035:D01a245:D@Q1245:D@Q1BU008@Q00636<@Q124
5:D@Q0aS1Q240QBU00<@Q1BU5:D00PaS00<@Q1BU48@00PaS00D@Q1BU5:D@Q1BU008@Q0035:D@Q124
00<@Q0045:D<H`aS36<348@236<0212436<<H`aS48@DYA245:D448@25:D448@01@aS48@<Ha245:D0
0Q240PaS0aBU0`aS0Q2410aS1A2410aS00<@Q0aS36<00PaS00D@Q0aS36<8@PaS00<@Q0@<H`0348@<
H`aS00P<H`8@Q0<<H`<@Q0@<H`@@Q0@<H`<@Q00336<@Q0aS00@<H`<@Q00436<8@PaS36<248@010aS
248<H`aS0a242@aS00D@Q0aS36<<Ha2400D<H`8@Q0@<H`0548@<H`Q2248<H`0348@01@aS48@@Q124
5:D00PaS00<@Q0aS36<00PaS00<@Q0aS48@00PaS0@Q2000312400`001240000412401P00124DYBU:
8@P@Q0<DY@037>LHaQS600@DY@@Li`096<HDYABU48@HaQBU6<HLiaS600@DY@037>LHaQBU00DDY@03
6<HDYABU008HaP057>LDYABU7>LHaP055:D011245:DDYA240QBU00<HaQcW7>L00QS600<DYA245:D0
0aBU1QS60QBU00<@Q1BU48@00QS600<LiaS66<H011S600<DYA245:D00QS60QBU0QS600@DYA2448@@
Q0PDY@8HaP<DY@<@Q0035:DHaQS600<Li`<HaP047>LDYABU5:D36<H01QBU6<HHaQBU6<HDY@HHaP8L
i`066<HDYA246<HLib480QS600@DYAS66<HHaPDQ20049BTQ21cW6<H27>L00aS65:DHaP027>L00aS6
7>LLi`027>L36<H27>L58@P37>L011S65:DHaQS60R4800<Lib487>L00QcW0QS600@Q22DY8@PQ20<D
Y@066<HLiacW8@PLiaS60QcW00@Q21cW6<HDY@8HaP048@PLiaS66<H25:D86<H011BU6<HLiacW0QS6
0QBU0aS600<DYAS648@011S611BU0QS600<LiaS67>L00aBU00<HaQBU48@00QBU0aS60QBU00@@Q1BU
5:D@Q0<DY@0748@DYABU6<HDYA245:D00QS600@DYA2448@HaP@DY@8@Q0DDY@076<HLiaS66<H@Q1BU
6<H00QcW00<DYAS66<H00aBU0acW0aS600@@Q1BU5:DHaPTDY@8@Q00336<@Q12400DDY@056<HDYABU
5:D@Q0035:D00aS65:DDY@055:D011245:DHaQS611BU11S600PDYAS65:DDYA245:D@Q1BU0Q2400<<
Ha245:D00Q240QBU0a240aBU00<@Q1BU48@00Q2400<<Ha245:D00QBU0Q240QBU00<@Q0aS48@01Q24
0QBU00@<Ha2448@DY@8@Q08DY@8@Q08<H`P@Q00336<@Q124008@Q08<H`0448@DYABU36<248@00aBU
48@@Q00548@00aBU48@@Q00248@00aBU48@@Q00248@01QBU48@<H`aS48@<H`8@Q08<H`@@Q00336<@
Q12400H<H`0448@<H`aS48@436<0112436<<H`aS0Q240PaS00<8@PaS36<00`aS0a2400<8@PaS36<0
112410aS00<@Q0aS48@00Q2430aS0Q2410aS00@8@PaS48@@Q08<H`0348@<H`Q2008<H`0348@<H`Q2
008<H`0448@<H`aS48@236<00`Q236<@Q00236<00a2436<<H`0:36<748@00aBU48@@Q00236<00`Q2
36<<H`0236<148@136<1248000848@0300048@@Q00<48@0900048@@Q124DYBU:7>LDYA2400HDY@08
7>LHaQS67>LHaQcW6<HDY@@HaP8DY@036<HLiaBU008DY@<Li`045:D@Q1BU5:D26<H011BU48@DYAS6
0QcW0aS600<LiaS65:D011BU0Q240QBU1AS60QBU00<HaQcW5:D00QBU0QS600<DYAS67>L00QcW00<@
Q1BU5:D00QBU0QcW0aS600DLiaS65:DDYA24008DY@8HaP045:DLiaS65:D248@01QS65:D@Q1245:DH
aP8DY@036<HLiaS600<DY@@@Q0036<HLiacW00PHaP037>LHaQS6008DY@<HaP035:DHaQS6008DY@03
6<HLiacW00<HaP8DY@046<HQ21cW7>L25:D36<H00b489BTU:@038@P27>L00aS67>LHaP036<H47>L0
0b487>LHaP046<H27>L00b487>LQ20028@P27>L00aBU6<HHaP027>L00aS67>LQ20028@P00acW6<HL
i`048@P26<H00aBU48@Li`047>L26<H00acW8@PLi`026<H27>L26<H02ABU6<HHaQBU6<HLiaS65:D@
Q0056<H27>L011S65:DDYABU0aS600<@Q1BU6<H00QcW00<HaQBU5:D00QS600DDYAcW7>LLiaS6008D
Y@<HaP<DY@<HaP035:DHaQBU00HDY@0648@DYABU6<HDYA240QBU00/HaQBU5:DDYA245:DHaQBU48@D
YAS600LDY@046<HDYABU5:D27>L011S65:DDYAS60QBU00HLiaS67>LHaQBU6<H25:D00a245:DHaP03
5:D02aS65:DDYABU7>LDYA2436<@Q1S65:D00Q2400<DYAS65:D011BU0a241ABU00<HaQ2448@00QBU
11S60QBU11S61QBU00@@Q1BU5:DDY@<@Q0<DY@8@Q0035:D@Q124008@Q0035:D@Q124008@Q0055:D@
Q12448@DY@0248@35:D248@00aBU48@@Q00248@35:D236<248@25:D548@336<348@236<01A2436<@
Q1245:D01A2400DDYA2448@DYA24008DY@<<H`8@Q0055:D@Q12448@<H`0248@01@aS5:DDYABU48@0
0PaS00<@Q0Q236<00PaS0a240`aS0Q242@aS00<@Q0aS36<010aS0Q2410aS00D8@PaS36<<Ha2400<<
H`0348@<H`aS00<<H`0448@<H`aS36<348@00`aS48@<H`0636<02A2436<<H`aS248<Ha245:D@Q003
36<248@336<248@436<0112436<<H`Q21`aS00<@Q0aS36<00Q240`aS0Q2400<<H`Q236<00PaS00<@
Q0aS24800`aS1Q240PaS00<@Q0aS48@00PaS00D8@PaS48@@Q0aS0048@P0000D000@Q12448@0000@4
8@0700048@@Q5:D]JacW48@00QBU11S600DLiaS66<HDYAS600<Li`8HaP<DY@8HaP8Li`@HaP037>LD
YABU008DY@036<HDYAS6008DY@036<HDYAS6008DY@046<HLiaS66<H75:D011245:DHaQBU1AS600<D
YA245:D011S60QcW11S60aBU2AS60QBU0aS60aBU00DHaQ245:D@Q1BU00<HaP035:DHaQcW008Li`04
5:DHaQS66<H25:D248@00aBU7>LHaP026<H00aBU6<HLi`027>L35:D012487>LHaQBU11S600@DYAS6
6<HLi`8HaPDLi`076<HQ22488@PHaQBU6<H011cW0R480QcW0RDY00<Q21S67>L00acW0R4800<U:AS6
6<H00acW0QS600<LiaS67>L00R4800LLiaS65:DHaQcW6<HLi`046<H38@P26<H01AcW6<HLiacW8@P0
0QcW0QBU0aS600<LiaS67>L011cW00DHaQcW7>LLib4800DHaP057>LHaQBU48@DY@027>L011S65:DH
aQS611cW00<HaQBU48@00aBU00<LiaS66<H00aS60QBU00<HaQBU6<H00aS60QBU0QS611BU1AS60QBU
00<@Q1S66<H00QBU00<@Q1BU5:D00aBU00<@Q1BU5:D00aBU00D@Q1S65:DDYA24008DY@046<HDYABU
48@26<H00aBU6<HHaP066<H25:D01AS67>LHaQS67>L011S611BU00<@Q1BU6<H00QBU00@HaQcW6<HD
Y@8@Q0045:D@Q12448@36<H35:D26<H25:D248@00aBU6<HDY@045:D00a245:DDY@026<H45:D01QS6
5:DHaQBU6<HDY@<@Q0035:DHaQBU00<@Q0035:D@Q12400<@Q0065:D@Q0aS48@DYAS60PaS00<@Q1BU
48@00PaS0aBU00<HaQBU48@00a2400HDYA2448@DYA245:D248@01@aS48@@Q1S65:D00a2400@DYA24
48@DY@8@Q00436<@Q0aS36<448@00`aS48@@Q00448@00aBU48@@Q00248@00aBU48@<H`0248@45:D7
48@236<448@236<010Q236<@Q1240PaS0Q2400D<Ha2448@DYA2400H<H`8@Q0@<H`0348@<H`aS00L<
H`0348@<H`aS00D<H`0448@<H`aS36<348@236<348@536<00a2436<<H`0248@436<348@236<010Q2
36<<H`aS0Q240PaS00<@Q0aS48@00`aS0Q241PaS00<@Q0aS36<00PaS11241PaS0PQ200P<Ha2436<<
Ha245:DHaQBU0`aS0a2400<<Ha2436<00`aS00<@Q0aS48@00@aS000010@Q00048@0020@Q00@@Q2DY
7>L@Q0<DY@8HaP065:DHaQcW6<HDYAS60QcW00@HaQBU6<HHaP<DY@@HaP<DY@036<HLiaBU008@Q003
6<HLiaBU008@Q08HaP0448@DYAS67>L66<H25:D01A245:DDYAS65:D011S600<LiaS65:D00QBU11S6
00<DYAS66<H00QS600@DYA245:DDY@<HaP8Li`8HaP045:D@Q1245:D66<H25:D248@65:D37>L25:D3
6<H01ABU48@DYA246<H00QcW0aS600<Lib486<H00QBU00@HaQcW7>LHaP8DY@8HaP035:DHaQS600@H
aP047>LQ21cW6<H25:D01QcW8@PLiacW5:D@Q08HaPDLi`8U:@058@PLiacW6<HQ20037>L00bDY7>LL
i`026<H01AcW6<HHaQS67>L00QS600<Lib488@P00QcW0aS60acW00@DYAS67>LQ20<HaP037>LQ21S6
00<Q20036<HDYABU008HaPLLi`8HaP8Li`8Q20067>LHaQBU6<HLiaS60aBU1QS61AcW11BU0aS600@D
YAS67>LLi`8HaP8DY@036<HDYAS600<HaPPDY@036<HLiaS6008DY@0448@DYABU6<H248@25:D00aS6
7>LDY@025:D248@45:D021246<HDYABU48@DYA245:D36<H021BU6<HHaQBU6<HLiaS67>L25:D00a24
5:DHaP086<H25:D248@01AS65:DDYA245:D011S600@<Ha2436<@Q08DY@0348@DYAS6008DY@<HaP03
5:D@Q124008DY@8HaP045:D@Q1BU5:D26<H25:D021cW5:D@Q1245:DLiaS65:D26<H25:D248@45:D3
48@236<00a245:DDY@0348@25:D00a245:D@Q00248@010aS48@@Q1240QBU0QS600P@Q0aS48@DYAS6
5:D@Q0aS0Q2400<DYA2448@00Q240QBU00<@Q1BU5:D0112410aS00@DYA2448@@Q08<H`H@Q0035:D@
Q124008@Q0045:D@Q0aS36<248@00aBU48@DY@025:D248@25:D248@01@aS48@@Q12436<00Q240`aS
00<@Q1BU36<00`aS0Q240`aS0Q241`aS0Q2400@<H`Q236<<H`8@Q0<<H`0348@<H`aS00L<H`05248<
H`aS48@<H`0348@01`Q236<@Q12436<8@PaS008@Q0@<H`8@Q00336<8@PaS008@Q08<H`03248<Ha24
008@Q0<<H`0448@<H`aS248636<00`Q236<<H`0736<01A2436<<H`aS48@00`aS00@@Q0aS36<8@P8<
H`0348@<Ha2400@@Q0<<H`0348@<Ha24008@Q0<8@P0336<@Q0aS0048@P001@@Q00<000@Q12400P@Q
00`000@Q5:D]Jb485:DHaQBU6<HLiaS65:D26<H25:D011S68@PU:AcW1AS600@DYAS66<HLi`<HaP8L
i`@HaP8DY@0948@DYABU5:DHaQcW6<HDYAS600<Li`<DY@8HaP065:D@Q1BU5:DLiaBU0acW00@HaQBU
6<HHaP<DY@036<HLiaS6008Li`036<HDYA24008DY@0348@DYAcW008Q20076<HDYABU48@DYAS65:D0
0QS60QcW0QS600HDYA2448@DYAS67>L46<H01acW5:D@Q1247>LQ21cW00<DY@046<HLiaBU5:D26<H0
0acW6<HDY@046<H011cW6<HHaQBU1QS600<LiaS67>L00R480aS600LQ21cW6<HDYAS68@PLi`036<H0
0aBU6<HLi`087>L00b487>LLi`028@P011cW8@PLiacW0QS600<LiaS66<H00QS600@Q21cW7>LLi`<H
aPTLi`<HaP<Li`046<HLiacW7>L66<H27>L00b487>LHaP026<H011cW8@PQ21S60QBU00DHaQBU6<HH
aQcW00HHaP037>LQ21cW00HHaP8DY@<HaP037>LDYABU008DY@046<HLiaS65:D26<H021BU6<HDYABU
6<HDYAS65:D36<H25:D00aS65:DDY@026<H011BU48@DYA240QBU00@HaQ245:D@Q08DY@0348@DYABU
008HaP<DY@0648@DYABU7>LHaQBU0acW00@HaQBU5:DHaP8Q20057>LDYABU6<HDY@026<H01ABU6<HH
aR487>L00QS600<DYA245:D00QBU00<HaQBU6<H011BU0a2400HDYA245:DDYAS65:D248@25:D26<H2
5:D26<H35:D041S65:D@Q0aS48@DYAS67>LHaQ2436<@Q1BU7>LHaQBU11240QBU0QS61Q2400<DYA24
48@00a240aBU0Q2400@<Ha2448@DY@<@Q08DY@066<HDYABU48@DYA240aBU112400<<Ha2448@00Q24
0QBU0Q240QBU0Q2400@<Ha2436<<H`<@Q00336<@Q124008DY@<@Q00336<@Q12400<@Q08<H`0548@D
YABU48@<H`025:D248@45:D348@011BU48@@Q1240`aS0Q240PaS0Q2400D<Ha2448@@Q1S6008@Q08<
H`0348@<H`aS008<H`8@Q0@<H`8@Q00336<8@PaS00L<H`0348@<H`aS008<H`D@Q00336<@Q0aS00<<
H`0748@<H`aS36<@Q0aS24800PaS00@@Q0aS36<8@P8<H`<@Q0H<H`<@Q0<<H`0448@DYA2436<22480
0`aS48@<H`0536<248@336<0112436<<Ha241`aS00<@Q0aS48@00`aS00D@Q0aS48@@Q0aS00<@Q0<<
H`0348@<H`aS008@Q04<H`0000@000@Q124000848@030008@P0000<48@0448@YBR486<H25:D01QS6
8@PLiaS65:DHaP8DY@057>LQ22486<HDY@036<H00aBU6<HHaP025:D01AS67>LLiaS65:D00QS60QBU
0QS600@DYA2448@HaP<DY@8HaP8Li`8HaP8DY@056<HDYA245:D@Q0025:D011S67>LHaQS61ABU00LH
aQ245:DHaR487>LHaP045:D248@26<H00b487>LDY@025:D26<H00aBU6<HDY@026<H011cW6<HHaQBU
0Q2400TDYAS66<HHaQBU6<HLiaS65:D00QS60aBU00HHaQBU5:DDYAS67>L25:D01AS67>LLiaS65:D0
0QS600@LiaS65:DHaP8Li`8HaP035:DHaQBU008HaP047>LQ21cW7>L26<H27>L26<H00acW6<HHaP04
6<H87>L012487>LLiaS60QcW00@HaQcW7>LQ208HaP035:DHaQS600<HaP<Li`<HaP8Li`8HaP8Li`03
6<HLiaS600<Li`045:DHaQBU7>L28@P01AS65:DHaQS67>L011S600/LiaS67>LLiaS65:DLib487>LH
aQBU00@HaP<Li`036<HDYAS6008HaP0:7>LHaQS66<HDYAS67>LHaQBU6<H45:D26<H011BU6<HHaQcW
0QS60QBU00<@Q1S65:D00aBU00<HaQBU6<H00QS611BU0QS60QBU00@@Q1BU5:DHaP8DY@0348@DYABU
008DY@8@Q08DY@046<HDYABU48@35:D01AS65:DDYABU6<H00QcW00@HaQ245:DHaP<Li`8DY@8HaP03
7>LHaQS600@Li`035:DHaQ2400<@Q08HaP065:D@Q1BU5:DHaQBU0a2400HDYA2448@DYAcW5:D248@7
5:D011245:D@Q1S60aBU0Q240QBU0aS600<DYA245:D011BU0Q240QBU00DHaQBU48@@Q1BU008@Q003
36<@Q12400<@Q0055:D@Q1BU5:DHaP0448@011BU48@DYA240QBU00<LiaS65:D00a2411BU00P@Q1BU
48@DYA2436<@Q0aS0aBU0a2400<DYA2448@01A241@aS0Q2400@DYA2436<<H`8@Q00336<@Q124008<
H`0348@<Ha2400@@Q0035:D@Q1BU00H@Q00436<@Q1245:D248@00`aS48@@Q00348@436<35:D00a24
36<<H`0248@336<00`Q236<<H`0636<248@336<00`Q236<8@P0248@836<248@01@aS48@@Q1BU48@0
1`aS00<8@PaS36<00Q2410aS00<@Q0aS36<010aS00@@Q0aS36<<H`8@Q0<<H`0348@<H`aS00<<H`03
48@<H`aS008<H`88@P8<H`8@Q0D<H`8@Q0P<H`8@Q0@<H`0348@<Ha2400H<H`8@Q04<H`48@P0000D4
8@0012448@0000@48@0700048@@Q5:DaS2486<H00acW0aS600@DYAS66<HLi`8Q208Li`036<HLiaS6
008HaP045:DHaQS65:D27>L00aS65:DHaP037>L35:D76<H35:D46<H00a245:DHaP027>L26<H00aBU
6<HLi`046<H35:D36<H00acW6<HHaP025:D01aS65:DDYA245:DHaQcW00<HaP8@Q0095:DHaQS648@D
YAS69BTQ21cW008DY@0348@HaQS6008HaP035:DLiacW00<DY@0348@HaQcW008Li`056<HDYAS66<HD
Y@026<H00acW6<HDY@066<H27>L011S65:DHaQBU0QcW11S600<LiaS66<H00QS60b480QcW00<Q21S6
6<H01ABU0QS60b480QcW0R480aS60acW0QS60QcW00DQ22DY7>LHaQBU00<Li`<HaP<Li`048@PLiaS6
6<H37>L26<H011cW6<HLiacW0QS600PDYAcW7>LLiaS65:DHaQcW0QS600/Lib486<HDYAS69BTQ21S6
48@DYAcW008HaP035:DHaQBU00LLi`045:DHaQS66<H27>L36<H35:D36<H00aBU6<HDY@025:D36<H3
5:D36<H00aBU6<HHaP026<H25:D26<H01aBU6<HHaQS65:D@Q1BU008HaP<DY@0348@DYABU00<DY@8H
aP037>LHaQ2400<DY@<Li`DHaP037>LHaQcW008HaP045:DHaQS65:D46<H00acW6<HLi`036<H75:D2
6<H011BU6<HDYABU0a2411BU00D@Q1BU6<HDYAS600@DY@<HaP<DY@036<HDYABU008DY@8HaP8DY@03
48@DYAcW008DY@066<HDYA2448@<Ha240QBU112400@DYA2436<<H`<@Q08<H`<DY@<<H`@DY@8@Q005
5:DHaQBU5:D@Q0035:D011S648@@Q1240aBU212400@DYA2448@<H`8DY@046<H@Q12448@236<00a24
36<DY@0248@00aBU48@@Q00548@00`aS48@@Q00548@01ABU48@@Q1245:D00a2400@DY@aS36<<H`<@
Q00336<@Q1BU00<<H`8@Q00536<8@Q2448@DY@0248@00aBU48@@Q00248@236<00`Q236<<H`0336<2
48@236<248@<36<0112436<<Ha2410aS0a243`aS0Q240`aS00<@Q0aS36<00PaS0Q241@aS00<@Q0aS
36<00PaS00L8@PaS36<@Q0Q236<@Q00436<348@336<248@336<01Q2436<<H`aS48@DY@8@Q08<H`03
48@<H`aS008<H`0448@<H`aS48@436<148@136<000848@0300048@@Q00L48@045:D]Jb485:D56<H0
0aBU6<HHaP026<H37>L26<H37>L02AS65:DHaQBU7>LHaQBU6<HLi`036<H00acW6<HDY@025:D26<H2
5:D00aS65:DDY@026<H27>L011BU48@HaQBU0QS60aBU0QS600TLiaS66<HHaQBU48@DYA246<H00QBU
00HHaQcW7>LLia245:D248@25:D011S67>LLiacW11BU00/HaQBU48@DYAS68@PLiaS65:DHaQBU008H
aP035:DHaQS6008HaP@DY@046<HLib487>L35:D46<H00aBU6<HHaP086<H00aBU6<H@Q0025:D26<H2
5:D01AcW8@PLiacW6<H00QcW00DHaQcW7>LQ21cW00<HaP8DY@0348@DYAcW00DLi`8Q20087>LHaQBU
5:DHaQcW8@PLi`8HaP@Li`@HaP037>LHaQS600<HaP037>LQ21cW00<HaP038@PLiacW008HaP8Li`LH
aP037>LHaQS6008HaP8Li`058@PLiaS67>LQ20027>L00aS65:DDY@056<H57>L26<H27>L56<H27>L0
1QBU48@DYAS67>LDY@<HaP0>5:DHaQS65:DHaQcW5:DHaQ245:DHaQBU6<HLi`8HaP@DY@<HaP<DY@DH
aP0448@DYABU48@35:D46<H00aBU48@DY@026<H01AcW6<HHaQS67>L00QS60QBU11S600<DYAS67>L0
0QS600<DYAS66<H00QcW0QS600<DYAS65:D011BU0QS60QBU00L@Q1BU5:DDYA245:D@Q0055:D01AS6
5:DDYABU48@00QBU00<HaQBU6<H00aS600<DYA245:D01aBU00@HaQBU5:DDY@8HaP045:D@Q0aS48@3
5:D348@00aBU48@<H`0448@00`aS48@@Q0035:D348@45:D00a245:DDY@026<H01aBU48@DYABU48@D
YAS6008DY@<@Q08DY@<@Q0@DY@0348@DYA24008@Q0045:D@Q0aS36<248@00aBU48@@Q00448@236<5
48@00aBU48@@Q00348@010aS48@DYABU1A2410aS00@@Q1BU48@@Q08<H`8@Q0<<H`8@Q0<<H`H@Q0P<
H`@@Q08<H`0348@<H`aS0088@P0336<@Q124008<H`0348@<H`aS0088@P0336<@Q124008@Q0<<H`03
248<H`aS008<H`0548@8@PaS36<@Q00336<01@Q248@@Q0aS48@020aS00D@Q0aS2488@PaS008@Q005
36<@Q0aS36<@Q00236<010Q236<8@PQ21PaS00<@Q0aS48@00Q240`aS00D@Q0aS36<<Ha2400<<H`<@
Q00336<@Q124008<H`05248<H`aS36<@Q00536<0000500048@@Q1240000412401`0012448AS6<H`U
:ABU008Li`068@PLiacW6<HDYAS60QcW00<Q21cW7>L00QS600<DYAS66<H00QS600<DYAS66<H00aS6
00DDYAcW7>LLiaS6008DY@8HaP047>LHaQS65:D36<H35:D36<H00aBU6<HHaP027>L00aS65:DHaP03
6<H45:D00a245:DDY@026<H45:D011S65:DDYA240QS600HQ21S66<HDYAS648@45:D00a245:DLi`02
8@P00aS65:DDY@025:D01aS67>LHaQBU48@DYAS600<DY@8HaPLDY@@HaP<Li`<DY@8Li`DHaP055:DH
aQS66<HLi`026<H25:D01QS68@PLiacW5:DHaP<Li`036<HDYA2400<DY@076<HLiacW6<HLiaS68@P0
11cW00@HaQcW7>LLi`@HaP@Li`@HaP8Li`038@PLiacW00<Li`048@PLiaS66<H27>L012487>LLiaS6
0QcW11S60acW00DDYAS66<HQ21cW00@HaP8Li`@HaP<DY@046<HDYAS67>L26<H27>L00b486<HDY@02
5:D37>L00aS65:DHaP026<H25:D01aS65:DHaQBU6<HDYA24008DY@8HaP035:DHaQS600<HaP045:DH
aQBU6<H27>L00aBU48@HaP027>L00aBU48@@Q0026<H35:D00a246<HDY@025:D011246<HLiaS60QBU
00<Lib487>L00QS600@LiaS65:DHaP8Li`DHaP055:DHaQBU5:DHaP037>L36<H011BU48@@Q1240QS6
0aBU00<HaQBU5:D011BU00<HaQBU5:D01ABU00<@Q1BU5:D00QBU00@HaQBU5:DDY@<HaP055:D@Q1BU
5:D@Q0035:D00a245:DDY@0348@011BU6<HDYABU0Q240QBU00<HaQBU48@00a2400<DYA2448@00Q24
00L<Ha2448@@Q1BU48@DY@0248@00aBU48@<H`0348@45:D00aS65:DHaP025:D348@45:D348@010aS
48@@Q1240QBU112400DDYA2436<@Q0aS008DY@0448@<H`aS36<348@336<348@00aBU48@<H`0336<2
48@01ABU48@@Q1245:D00Q240PaS0QBU0Q240`aS00@@Q0aS48@@Q0<<H`0348@<H`aS008@Q08DY@<@
Q0045:D@Q1BU48@336<00`Q236<@Q00348@00`aS48@<H`0536<00a2436<<H`0236<00a2436<<H`02
24800`aS48@<H`0248@536<0112436<8@PQ20Q240PaS00D8@PaS36<@Q0aS008@Q08<H`8@Q0D<H`06
248<Ha2448@<H`Q21PaS0a2420aS00<@Q0aS36<01@aS00<@Q0aS48@00Q240PaS0Q2410aS00<@Q0aS
48@010aS11240@aS0A240@aS000312400`001240000612401aBU;F/LiaBU7>LQ21cW00<HaP035:DH
aQS600@Li`066<HDYAS66<HLiaS60QBU00<HaQcW6<H00aBU0QS600@DYAS65:DDY@DHaP<DY@036<HD
YABU008DY@047>LDYAS65:D46<H25:D00aS67>LHaP026<H45:D46<H25:D00a245:DDY@035:D26<H0
0acW6<HHaP025:D248@00aBU48@@Q0026<H28@P26<H35:D56<H00acW5:D@Q00248@011S65:DDYA24
0QBU0QS60QBU0QcW00<HaQBU7>L00QcW0QS60QBU0QS60aBU00HHaQBU6<HDYAS67>L36<H27>L01R48
7>LLiacW6<HLi`8HaP8DY@<HaP047>LHaQcW8@P27>L011S67>LLiacW0aS611cW0QS60QcW00@HaQcW
6<HDY@8HaP8Li`066<HLiacW7>LHaQcW0aS61AcW0aS60acW00<HaQBU7>L00QcW00@HaQBU6<HLi`8Q
208HaP047>LHaQcW6<H75:D46<H01acW6<HLib487>LHaQBU008HaP8Li`056<HDYA245:DHaP027>L0
1QS65:DDYABU48@DY@<HaP<DY@<HaP<DY@DHaP8DY@036<HLiaS6008@Q0035:DHaQS600<@Q08DY@8H
aP035:DHaQBU008HaP055:DHaQS67>LQ20026<H25:D36<H011cW6<HHaQcW0QS600<DYAS67>L00QBU
00<HaQcW7>L00QBU00@LiaS65:D@Q0<DY@0448@DYAS65:D26<H45:D00a246<HHaP026<H:5:D01Q24
5:DHaQS65:D@Q08DY@0448@DYA246<H25:D348@00`aS5:DDY@026<H0112436<<Ha240QBU0Q2400<<
Ha2448@00Q2400DDYA2448@<Ha24008<H`L@Q0035:D@Q1BU00DDY@<@Q0<DY@0448@DYABU5:D248@0
1ABU48@@Q1245:D0112400<DYA2448@00a2400DDYA245:D@Q0aS008@Q08DY@@<H`0348@<H`aS00@@
Q00336<@Q12400L@Q08DY@8@Q00436<@Q12448@236<010Q236<@Q1240`aS0Q2400D<Ha2436<@Q1BU
008@Q08<H`035:D@Q124008<H`8@Q08<H`08248<Ha2448@<Ha2436<8@PH<H`0648@<H`aS248<Ha24
10aS0Q241PaS00<8@PaS36<00PaS00D8@Q2436<<Ha24008<H`04248<H`aS48@336<348@836<01124
36<@Q1241PaS00<@Q0aS24800PaS0a2410aS0Q2400D<H`Q236<<Ha24008<H`0448@DYA2448@436<0
112436<<H`aS0Q241@aS0A240@aS0@aS00000`0012448@0612401`0012448AS6=JdU:ABU008HaP8L
i`8HaP035:DHaQS600@HaP<Li`036<HDYABU00@HaP055:D@Q1BU6<HLi`026<H01ABU6<HHaQS65:D0
11S60QBU0aS600LDYAS66<HHaQBU6<HLi`026<H011BU6<HHaQcW0QBU00@@Q1S66<HHaP8DY@8HaP8D
Y@046<H@Q1BU5:D46<H011BU6<HHaQS60aBU1QS60QcW11S60QBU0Q2400@HaQcW6<HHaP<DY@046<HD
YABU48@55:D26<H00aBU6<HHaP047>L26<H01AcW6<HHaQS65:D00aS600LDYAS67>LLiaS65:DHaP06
7>L46<H27>L56<H00acW8@PQ20028@P27>L00aS67>LQ20036<H01AcW6<HDYAS67>L021S60QcW0b48
0QcW0aS600LLib486<HHaQcW8@PLi`026<H27>L76<H27>L00b487>LLi`028@P011cW6<H@Q1BU0aS6
00@DYAS66<HLi`DHaP8Li`LHaP047>LDYAS65:D26<H00a245:DDY@026<H00aBU6<HHaP046<H248@2
5:D021cW6<HHaQBU6<HLib486<H25:D021cW6<HHaQBU48@DYAcW6<H348@00acW6<HHaP026<H25:D0
0aS65:DLi`047>L36<H00acW6<HHaP076<H00a245:DDY@036<H37>L36<H348@011BU6<HHaQBU0Q24
0QBU0QS60aBU00<HaQBU5:D00QBU0QS600@DYAS66<HHaP<DY@DHaP045:D@Q1245:D248@35:D00`aS
48@DY@026<H00a245:DDY@0348@35:D348@00aBU48@@Q00348@00aBU48@@Q00848@25:D00a245:D@
Q00248@01ABU6<HHaQS65:D01A240QBU0Q2400/DYA2448@@Q0aS48@DYA245:D@Q1BU00<@Q00336<@
Q124008@Q08DY@0448@<H`aS36<348@00`aS48@8@P0236<448@010aS48@@Q1BU0PaS00@@Q1BU6<HD
Y@<@Q0036<HDYA24008<H`<@Q00436<@Q0aS48@236<248@00`aS48@@Q00648@26<H248@01@aS48@@
Q0aS48@00PaS00<@Q1BU48@01`aS0Q241@aS00<@Q0aS48@010aS0a2430aS0Q240`aS0a240`aS0Q24
00@8@PaS248@Q0L<H`0448@<H`Q2248336<00`Q236<<H`0336<01A2436<@Q0aS24800`aS00<@Q0aS
36<00PaS0Q2400<<Ha2436<02@aS0Q2410aS0Q240@aS00021240100012448@001P@Q00DHaS6<9BTD
YAS6008Li`8HaP045:DHaQS67>L56<H27>L26<H25:D00aS67>LLi`035:D00aS68@PLi`076<H00aBU
6<HDY@055:D011S67>LHaQS611BU00LHaQcW6<HHaQBU6<HDY@036<H00aBU6<HDY@036<H65:D01AS6
5:DDYABU6<H00QcW0QBU00<@Q1BU6<H00aBU1AS600<LiaS648@00Q2400<DYAS65:D00QBU0Q240QBU
0aS61aBU0aS61acW0QS60aBU0aS600<DYAS66<H00QS600<DYAS67>L00acW1AS60QcW00<HaQBU5:D0
0aS60R4800<U:AcW6<H00QcW0aS60acW0aS600<DYAS65:D00QS60QcW0aS60QcW00<Q21cW6<H00QcW
00<HaQcW7>L011cW00PQ21cW6<HLiaS67>LDYAS60acW0QS600XLib488@PHaQBU7>LQ21cW6<H@Q0<H
aP045:DHaQS65:D56<H47>L36<H00aBU6<HHaP026<H25:D01QS65:DDYABU6<HLi`<HaP045:DHaQBU
6<H25:D00a245:DHaP026<H25:D26<H27>L45:D02QS648@@Q1BU6<HLiaBU48@DYAS60QBU00@@Q1BU
5:DDY@8HaP8Li`048@PLiacW7>L46<H00acW6<HHaP037>L01aS648@DYAS65:DHaQBU008HaP8Li`8H
aP8DY@0648@DYABU6<HDYA240QBU00<@Q1BU5:D01QBU11S600@DYAS65:DLi`@DY@036<HDYABU008H
aP035:D@Q124008DY@0448@DYA245:D248@25:D248@35:D00a2436<@Q00248@00aBU48@@Q00248@0
1`aS48@@Q1BU36<@Q0aS00<@Q0035:D@Q12400P@Q08DY@8HaP8DY@8@Q0065:D@Q1245:D@Q0aS0Q24
00@HaQ24248<H`8DY@8@Q0035:D@Q124008<H`@@Q00336<@Q1BU008@Q00336<@Q12400<<H`8@Q004
36<8@PaS36<248@236<00aBU48@<H`0248@26<H348@011BU48@DYA242@aS0a2400H<Ha2448@@Q1BU
48@236<01Q246<HHaQ245:D@Q0<<H`0348@<Ha24008@Q08<H`0348@<Ha240088@P@<H`05248<H`aS
36<@Q00;36<00`Q236<<H`0836<00a2436<<H`0236<448@01@aS48@<H`aS48@00PaS00D8@PaS248<
H`Q200@<H`<@Q08<H`04248<H`aS48@236<00a2436<<H`0336<2248236<00a2436<@Q00348@236<0
0a2436<<H`0336<0112436<8@PaS0a240PaS00<@Q0aS36<00@Q2000312400`0012448@06124011S6
<H`Q21240acW1AS600<DYAS67>L011S600<DYAS66<H01QS600<DYAS67>L00QcW00lDYAS66<HHaQBU
6<HLiaS65:D@Q1BU6<HDYAS65:D00aS60aBU0aS600DLiaS66<HDYA2400HDY@8HaP8DY@8HaP8DY@03
48@DYABU008HaP045:DHaQcW7>L26<H25:D47>L01AS67>LLib487>L00QS60aBU21S60aBU11S600HD
YAS65:DHaQBU6<H27>L01B487>LHaQcW6<H00QcW0QS600@DYAS67>LLi`<HaP037>LDYAS6008DY@05
6<HLiacW6<HDY@086<H00acW8@PLi`026<H02AcW9BTU:AcW5:DHaQcW8@PLi`026<H27>L26<H011cW
5:DDYABU0QS600<DYAS67>L00R480QcW0R4800HDYAS67>LLiaS65:D26<H01QcW8@PLiacW6<HQ20<H
aP8Li`8HaP8Q20037>LHaQcW008Q20047>LHaQS66<H35:D011cW6<HLib480QcW00LHaQBU6<HHaQcW
6<HLi`025:D76<H01ABU48@DYABU6<H00aBU0QS600@LiaBU5:DDY@8HaP8DY@8HaP8DY@036<HLib48
008HaP8DY@8HaP<DY@<HaP035:D@Q12400<HaP037>LHaQBU008DY@036<HQ2248008Li`036<HLib48
008Q20087>LHaQS66<HLiaS65:DHaP8DY@046<HLiacW7>L36<H27>L25:D248@00aBU6<HDY@0248@0
0`aS5:DDY@025:D00a245:DDY@026<H35:D56<H00aBU6<HHaP026<H01aBU6<HHaQBU48@DYAS6008@
Q0<DY@8@Q08HaP0648@DYAS66<HDYA240PaS00<DYAS66<H00Q2400DDYA2448@@Q1BU008@Q00436<@
Q1245:D248@00`aS48@DY@0248@010aS48@DYABU0Q241QBU00<@Q1BU6<H0112400<DYA2448@01124
00<<Ha245:D00Q2400@<Ha2436<@Q0<<H`0348@DYA2400<@Q0035:D@Q12400@@Q08<H`0448@DYABU
48@236<448@236<248@01ABU6<H@Q12436<01A240PaS0a2400@<Ha2436<<H`8@Q0<<H`<@Q00336<@
Q12400L@Q00336<@Q0aS00<<H`0348@<H`aS00D<H`0348@<H`aS00@<H`8@Q00336<@Q0aS00H@Q006
36<@Q0aS36<@Q0aS0Q241PaS00<@Q0aS36<00PaS00@@Q1BU48@@Q0L<H`05248<H`aS36<@Q00436<0
0a2436<<H`03248010aS48@@Q1240`aS00<@Q0aS24800PaS00@@Q0aS36<@Q0<<H`<@Q0@<H`03248@
Q12400<<H`0448@<H`aS36<248@136<00003124000@Q00848@0500048@@Q12400002124011S6<H`L
iaBU0acW00@HaQBU6<HDY@HHaP8DY@8Li`8DY@036<HLiaS600<DY@@Li`<HaP@DY@036<HDYABU00<D
Y@8HaP<DY@8HaP@DY@<Li`LDY@8HaP045:D@Q1BU5:D26<H00a245:DDY@026<H25:D01aS67>LQ21cW
5:D@Q1BU00<HaPHLi`036<HDYABU00@HaP045:DHaQcW6<H65:D46<H00aBU6<HDY@046<H37>L00aS6
7>LLi`036<H01QBU7>LLiacW6<HDY@<HaP035:D@Q1S600<HaP067>LHaQBU5:DHaQcW0aS600@DYAS6
7>LHaP8Li`<Q20HLi`056<HLiacW6<HDY@026<H27>L25:D26<H77>L01QS67>LHaQcW6<HDY@8HaP8Q
20037>LHaQS600@Li`036<HLiaS6008HaP8Q20087>LHaQBU6<HLib487>LHaP8@Q0DHaP057>LQ2248
7>LDY@036<H37>L36<H27>L26<H35:D011245:DDYAS611BU11S60QBU0QS600TDYA245:DHaQBU7>LH
aQcW6<H00QBU00<HaQBU5:D01ABU00<@Q1BU5:D00aS61ABU00DHaQcW9BTQ21cW008HaPDLi`DHaP06
5:DHaQS67>LHaQcW0aS600@LiaS66<HHaP8DY@<@Q08DY@0348@DYABU008DY@0448@DYABU5:D26<H2
5:D56<H01ABU6<HHaQcW6<H00QBU0aS600`DYAS65:DDYA245:DHaQ2436<@Q1BU7>L55:D00a2436<@
Q0045:D348@35:D348@00aBU48@@Q00236<448@00`aS5:D@Q0055:D01@aS48@DYABU6<H00QBU00<@
Q1BU48@01A2400@<Ha2436<<H`D@Q08<H`@@Q00536<@Q12448@<H`0248@25:D00a2436<@Q00748@3
36<248@01QBU48@@Q12436<@Q08DY@0548@<H`aS48@DY@0448@336<0112436<8@PaS0Q240`aS3124
0PaS0a241PaS00@@Q0aS36<8@P8<H`0348@<H`aS00<<H`05248<H`aS36<@Q00336<00a2436<<H`03
36<00a2436<@Q00236<248@636<448@236<00a2436<@Q00236<3248236<448@<36<00a2436<<H`02
248236<00a2436<<H`0248@336<0112436<<H`Q20PaS00<@Q0aS36<00PaS0Q241PaS0Q2400000`00
12400009124011S6=JdYBQS60QcW00<DYAS67>L00QS600DDYAS66<HQ21cW00@HaP8Li`036<HDYABU
00DHaP047>LHaQBU6<H27>L011S65:DDYAS61ABU0QS60QBU0aS60QcW0aS600<DYAS65:D00QBU0QS6
1ABU00<HaQBU5:D00aBU0aS600LDYAS65:DDYAS67>LQ20026<H011BU7>LLiacW11S600<DYAS66<H0
0QBU0aS600DDYAS67>LLiaS600@DY@8HaP035:DHaQS600<HaP<Li`036<HLiacW00<HaP037>LHaQS6
00LHaP<Li`036<HDYABU008DY@066<HLiaS65:DHaQcW0R4800DLiaS66<HLib4800<HaP035:DLib48
008Q20076<HLiaS67>LQ21S67>L011S600@DYAS66<HDY@DHaP047>LQ21cW6<H27>L00b487>LHaP03
6<H011BU6<HLiaS60acW0QBU00@HaQcW8@PHaPDLi`086<HLiacW8@PLiaS65:DHaP8DY@8HaP057>LD
YAS67>LQ20047>L021S65:DDYAS67>LU:B487>L26<H27>L00aS65:DHaP045:D46<H011BU6<HHaQBU
0aS60aBU00<@Q1S66<H00QcW00<HaQcW7>L00QBU00X@Q0aS48@HaQcW6<HDYAS65:DHaPDDY@8HaP04
7>LHaQcW8@P47>L38@P27>L011S65:DHaQBU0QS600<LiaS67>L00QcW0aS60QcW00DHaQ2448@@Q1BU
008Li`055:D@Q0aS48@DY@0248@011BU6<HHaQS60QBU00@HaQBU5:DLi`8HaP035:D@Q1BU00<HaP@D
Y@<HaPDDY@8@Q0065:DHaQS65:D@Q1S60aBU00@@Q1S65:DDY@8@Q0055:DHaQS648@<H`0348@25:D0
0aS648@@Q00348@01ABU48@@Q0aS48@00QBU0QS60QBU00D@Q1BU5:DDYA2400@DY@<@Q00336<@Q0aS
00D@Q0035:D@Q12400@@Q08<H`X@Q0055:D@Q12448@DY@0348@00`aS48@@Q00548@236<348@00`aS
48@@Q00336<248@236<00`Q248@<H`0548@00`aS48@<H`0336<;48@236<00`Q236<DY@0248@936<2
248636<00a2436<@Q00248@436<01Q2436<<H`Q236<@Q0<<H`8@Q08<H`<@Q00336<@Q12400<@Q0H<
H`07248<H`Q236<8@PaS48@02PaS0a2400<8@PaS24800PaS0a240PaS00@8@Q2436<@Q0P<H`03248<
H`aS00X<H`48@P0010@Q00<000@Q12400`@Q00H000Q27>LaS2485:D47>L01QS67>LHaQcW6<HLi`DH
aP8Li`<HaP037>LHaQBU00DHaP8Li`036<HDYABU00<HaP045:DHaQ245:D36<H35:D01AcW6<HHaQS6
7>L011S611BU0QS60QBU00@HaQBU5:D@Q08DY@066<HDYA2448@DYAS60QBU00D@Q1BU7>LQ21cW008D
Y@056<HQ21cW8@PLi`026<H75:D00aS65:DLi`027>L01AS65:DHaQS65:D00Q240QBU1QS600<DYAS6
7>L00QcW00HHaQcW8@PHaQBU6<H27>L36<H02QcW6<HHaQBU6<HDYAS648@DYAS60QcW00HHaQBU6<HL
ib487>L36<H00acW8@PLi`026<H011cW8@PU:B480QS60acW00@Q21cW6<HHaP<Li`036<HDYAS600@D
Y@047>LQ22488@P27>L012487>LHaQS60QcW00TDYAS67>LQ21cW6<HLib487>L00QS60acW00<HaQcW
7>L00aS600<Lib487>L00aS600@DYAS65:DDY@<HaP037>LHaQcW00<Li`036<HDYABU008HaP038@PL
iacW00<Li`<HaP8DY@036<HDYAS600DHaP<DY@046<HDYABU6<H25:D248@011S67>LQ21cW1AS60Q24
00<DYAS65:D00Q2400DDYAS65:D@Q1BU008HaP8DY@<HaP078@PU:AcW6<HDYAS68@P00RDY00<LiaS6
48@021S60QcW0QS60QcW0QS60Q2400@DYAS65:DDY@8@Q0<DY@0848@DYABU5:DHaQBU6<HLi`@DY@8H
aP<DY@<HaP<DY@036<HDYABU008HaP8DY@8@Q0045:D@Q1BU6<H45:D00aS65:D@Q0045:D248@01QBU
48@DYAS648@<H`8@Q08DY@0348@DYABU00@@Q0055:D@Q12448@HaP045:D00a245:D@Q0026<H25:D0
0aS65:DDY@0348@00aBU48@<H`0236<01a245:DDYA245:D@Q0aS008@Q0035:D@Q12400@@Q08<H`05
48@DYABU48@<H`0348@020aS48@@Q0aS48@<Ha245:D448@236<648@00`aS48@<H`0836<0112436<@
Q0aS0a240PaS00@@Q0aS48@<H`8@Q0035:D@Q0aS008<H`8@Q00436<@Q0aS36<248@436<0112436<@
Q0aS0PQ21PaS00<@Q0aS48@00Q243PaS00<@Q0aS36<00PaS00<@Q0aS48@00a240PaS00<@Q0aS36<0
0PaS00<8@PaS24800PQ200<<Ha2436<00PaS00<@Q0aS36<00PQ20PaS0Q2400@<H`Q236<8@P<<H`03
48@<Ha2400<@Q00336<8@PaS00<@Q0<<H`04248<H`aS248236<01a2436<<H`aS48@<Ha2400<<H`00
00<000@Q12400P@Q00<000@Q124010@Q00@LicW>8@P@Q0@HaP8Li`8HaP<Li`@HaP045:DHaQS67>L3
5:D011cW6<HHaQBU21S611BU11S60aBU0aS600<DYAS66<H00QS60QBU11S600<DYAS66<H011BU00@H
aQBU5:DDY@8@Q0046<HLiacW6<H25:D01QS68@PQ21cW6<HDY@<Li`036<HDYA24008HaP035:D@Q1BU
00PHaP0448@DYABU6<H25:D00a245:DDY@0:6<H011cW6<HHaQBU0QS60aBU11S600<Q21cW7>L00aBU
00<HaQBU6<H01AS60acW0QS60QcW0QS600HDYAS68@PQ22DY8@P36<H011cW9BTQ22480QcW0aBU0QS6
0QBU00HHaQcW6<HHaQcW9BT67>L25:D011S67>LQ21S60QBU00@Lib489BTQ208Li`036<HLiacW00<L
i`8HaP057>LU:BDY8@PLi`036<H00acW8@PLi`036<H011cW8@PQ22480acW11S600DQ22DY8@PQ21BU
008HaP057>LHaQS648@HaP027>L00aS65:DDY@025:D00aS65:DHaP025:D36<H25:D26<H011BU6<HH
aQS60QcW0QS600D@Q1BU5:DDYAS600<DY@8@Q08DY@066<HDYAS65:DHaQcW0R480QcW00`HaQcW7>LL
ib487>LHaQBU6<HLiaS648@25:D37>L01AS67>LLib487>L011S60a240QS60a2400DDYAS66<HDYA24
00<HaP055:DHaQBU7>LDY@0248@00aBU6<HHaP025:D26<H01QcW5:D@Q1245:DHaP8DY@036<HDY@aS
008@Q0036<HLiaBU00`DY@8@Q08DY@@@Q0DDY@0348@<H`aS00D@Q0035:D@Q1BU008DY@036<HDYA24
008@Q0@DY@D@Q00336<@Q12400D@Q0045:D@Q12448@436<011BU48@DYA240`aS112400@<Ha246<HD
Y@<@Q08<H`8@Q08DY@8@Q0@<H`8@Q0<<H`0348@<Ha2400<@Q00336<@Q124008@Q00436<@Q12448@2
36<01@Q236<@Q1245:D00`aS00D@Q0aS36<@Q1BU008@Q0H<H`<@Q00436<@Q0aS48@536<01a2436<8
@PQ236<DYA2400<<H`<@Q0H<H`D@Q00336<@Q0aS008@Q0@<H`035:D@Q124008<H`05248<H`aS48@<
H`02248236<00`Q236<<H`0436<00`Q236<<H`0248@236<00`Q236<<H`0236<010Q236<@Q1241@aS
00<@Q0aS36<00PaS00@8@PaS36<<H`88@P0436<8@PQ236<248@00`aS248<H`0336<1248000<48@03
00048@@Q00<48@0800048@@Q8@Pe[BDY5:DHaP<Li`055:DHaQS67>LQ20027>L36<H00acW6<HHaP03
6<H35:D27>L26<H25:D011S67>LLiacW1ABU0QS600@LiaS66<HDY@LHaP035:DHaQS6008DY@<HaP03
5:DHaQBU008@Q0TDY@@HaP0348@DYAcW008Li`8DY@<HaP8DY@036<HDYA2400@DY@@HaP035:DHaQBU
008DY@0:7>LHaQBU48@DYAcW5:D@Q1BU7>L46<H01AcW6<HHaR487>L00QBU00<@Q1S66<H00aS60QBU
00PLib488@PLiaS65:DHaQBU11S600@LiaS66<HHaP8Li`8HaP077>LQ21cW7>LDYAS67>L00b4800<H
aQcW8@P01QcW0aBU00@HaQBU6<HDY@<HaP<Li`<HaP8Q20046<HDYABU6<H37>L26<H27>L28@P00acW
6<HLi`047>L01QS65:DHaR489BTQ208HaP047>LHaQS66<H27>L25:D00acW8@PQ20037>L00aS67>LH
aP027>L00aS67>LLi`028@P46<H012485:DDYABU0QcW0aBU00<HaQBU5:D00QS60aBU00<LiaS66<H0
0QBU00DHaQcW6<HDYAS6008Li`035:D@Q124008HaP035:D@Q1BU008@Q0035:D@Q1BU00<DY@<HaP<L
i`8HaP8Q20@Li`<HaP077>LHaQS65:DHaQcW8@P00QS600DDYAcW8@PQ21cW008HaP0948@DYA2448@H
aQBU6<HDYA2400DDY@0448@DYAS66<H45:D01AS65:DDYABU48@00QBU00<HaQcW7>L011BU0QS600@D
YA2448@@Q0<DY@0448@DYABU6<H25:D248@35:D011245:D@Q1240QBU00@@Q1BU36<<H`8@Q0036<HD
YABU00P@Q0035:D@Q1BU008DY@<@Q0<DY@0348@DYABU008DY@<<H`D@Q08<H`0348@DYABU00@@Q08<
H`8@Q08DY@<<H`<@Q08<H`0448@DYABU5:D348@236<248@00aBU48@@Q00436<248@236<248@020aS
248<H`aS5:D@Q0aS248236<248@010aS48@@Q1240PaS0Q240`aS00@@Q0aS36<<H`<@Q0055:D@Q0aS
36<@Q00236<00a2436<<H`0336<248@836<348@236<248@236<348@236<248@236<448@736<248@3
36<248@236<01@Q236<<H`aS24801`aS00@8@PaS36<<H`<@Q00336<8@PQ200<8@P0336<@Q124008<
H`0348@<H`aS008<H`8@Q0D<H`03248<H`aS0088@PD<H`0348@<H`aS008<H`48@P0000D48@001244
8@0000L48@086<HaS1cW5:DQ21cW6<HDY@8HaP<Li`066<HDYAS66<HLiaS60aBU00<LiaS65:D00QS6
0QBU0QS60QcW21S600@DYAS66<HHaP8DY@HHaP085:DHaQS67>LHaQBU48@DY@@HaP085:DHaQS65:DH
aQBU6<H@Q08DY@8HaP<DY@036<HDYAcW008Q20039BTLiaS600DHaP<DY@0348@DYAS6008Li`046<HD
YAS66<H85:D011S65:DLiacW0QS611cW0QBU0QS600<LiaS65:D00QBU1aS60acW00TDYAS65:DDYAS6
5:DLiaS65:D00QcW00DQ21S66<HLib48008Li`036<HLiaS600<Li`038@PLiacW008HaP057>LQ22DY
8@PHaP025:D00acW6<H@Q0025:D011S65:DHaQS60acW0R4800`LiaS65:DHaQBU6<HLib487>LHaQBU
6<H28@P27>L02B487>LHaQcW8@PHaQBU6<HLi`029BT38@P00aS67>LQ20028@P00aS65:DLi`047>L0
12487>LLiacW0aS60QcW0R4800<LiaS66<H00QBU11cW00@HaQBU6<HHaPPDY@DHaP038@PLiaS6008D
Y@066<HLiacW5:DHaQBU0Q240QBU0QS611BU1AS60acW00<HaQcW7>L00acW00<HaQcW5:D011S600@D
YAS65:DHaP8Li`036<HLiaS6008Li`8Q20037>LHaQS6008@Q0045:DHaQBU5:D248@26<H011cW6<HH
aQ240QBU0aS60QBU0Q240QBU00<HaQBU5:D00aS60aBU0aS600@DYA245:DDY@<@Q0035:DHaQBU00<D
Y@8@Q0<DY@0348@DYA2400@DY@8@Q0@DY@0348@DYA24008DY@0436<@Q0Q236<248@35:D348@00aS6
5:DDY@035:D00a245:D@Q00548@336<01QBU48@@Q1245:D@Q0<<H`0648@<Ha2436<@Q0aS1A240`aS
00L8@Q245:DHaQBU48@<H`0348@25:D248@336<248@236<648@00`aS248<H`0348@636<248@236<0
0`Q236<@Q00248@436<648@336<448@00`aS48@@Q00248@00`aS248<H`0536<00a2436<<H`0248@2
36<2248636<548@01@aS248<H`aS48@00`aS0a240`aS00<@Q0aS36<00PaS00<8@PaS36<00PaS00<8
@PaS36<00`aS0Q240PaS00<8@Q2436<00PQ21`aS00D@Q0aS36<<Ha2400D<H`8@Q0P<H`03248<H`aS
00<@Q0@<H`000P@Q00<000@Q12401`@Q00HLibe[7>L@Q1S68@P26<H00aBU6<HHaP037>L00aS65:DD
Y@036<H011BU6<HHaQBU0aS60aBU0acW00XHaQBU6<HHaQcW6<HDYA246<HDY@8HaP0:5:DHaQS67>LH
aQcW6<HDYAS65:D36<H25:D26<H01ABU6<HHaQS65:D00Q2411BU00D@Q1BU5:DLiaS600@DY@066<HQ
22U:9BTHaQBU11S600DLiaBU48@@Q0aS008HaP<Li`056<HDYABU5:DHaP065:D011246<HHaR480QS6
00@@Q1S66<HLi`<HaP8Li`<DY@@HaP<DY@<Li`8HaP@DY@046<HLiacW6<H27>L00b487>LHaP077>L3
6<H011cW8@PLiacW0QS600@Lib488@PLi`<HaP045:D@Q1BU5:D56<H37>L02b487>LHaQS67>LHaQ24
6<HQ22DY7>L00QBU0R4800<U:B487>L00QS600<LiaS67>L00QcW00@HaQcW9BTU:@8Q20047>LQ2248
7>L46<H00acW6<HHaP027>L28@P36<H01AcW8@PQ21cW8@P00QS60QBU00<HaQcW8@P00QcW00<@Q1BU
5:D00QcW00<DYA245:D00QS600DDYAS66<HHaQBU00<HaP8Li`076<HDYAS66<HLiaS65:D00a240QBU
0QS60a2400<DYAcW7>L00QBU00PHaQcW7>LQ21cW6<HDYAS60acW0QS600HLiaS66<HDYAS65:D36<H2
7>L00aS67>LHaP027>L28@P01QcW5:D@Q1245:D@Q0@DY@0348@DYABU008HaP<DY@056<HLiaS65:DH
aP025:D00a245:DHaP035:D36<H248@01aBU6<HHaQS65:D@Q1BU008@Q08DY@8HaP8DY@0348@DYA24
00@DY@0348@DYA24008@Q08DY@8@Q0@DY@0348@DYA24008@Q08<H`<@Q0035:D@Q1BU008@Q00:5:D@
Q1245:D@Q0aS48@DYAS65:D248@00aBU48@@Q00236<011245:D@Q0aS0Q2400<DYA2436<01PaS1A24
00<<Ha2448@00PaS00H@Q1BU6<HDYA2436<448@010aS48@@Q12410aS00<@Q0aS36<00Q241PaS00<8
@PaS48@00Q240PaS0a2400<<Ha2448@010aS11241PaS00LDYA2448@<H`Q236<@Q00836<0112436<@
Q1240PaS00<8@PaS48@011240`aS0Q240`aS0Q2400<<Ha2448@00Q2410aS112400<<Ha2436<00Q24
10aS00<@Q0aS36<00PQ20PaS00D@Q0Q236<<H`Q200<<H`0448@<H`Q236<2248536<00a2436<<H`03
36<248@336<248@00`aS2488@P0436<01@Q236<<H`aS48@01@aS0@Q20000100012448@000P@Q00X0
00@Q12448@00124HaRe[7>L@Q08Li`036<HDYAS6008Li`076<HDYAS66<HDYAS67>L00QS60aBU11S6
00<DYAS66<H00QcW0QS600@DYAS65:DDY@<HaPDDY@@HaP035:DHaQS6008HaP<DY@8HaP035:DHaQcW
008Li`055:DHaQS66<HDY@0348@011BU7>LLiaS60QBU0QS600P@Q1S69BTYBRe[8@PDYAS60QBU0QS6
0QBU0Q2400PDYAS68@PLiaBU6<HLiaS61QBU00H@Q1BU6<HHaQcW6<H25:D27>L00b486<HHaP026<H2
5:D26<H25:D011245:DHaQcW0QS600<DYAS66<H00aS60aBU0QS600XLiaS66<HLiaS65:DLib489BTL
i`8DY@<Li`8HaP<Li`035:DLibDY008YBP037>LHaQcW008DY@<@Q0<HaP065:DHaQS65:DHaQcW0R48
00<HaQBU5:D00QS60QcW0aS60QcW00@Q21cW7>LHaP@Li`036<HDYAcW008U:@8Q20@Li`038@PU:AcW
00<HaP8Q20077>LHaQcW6<HLiaS65:D00QcW0R480aS600@DYAS66<HLi`<HaP8Li`046<HLiaS66<H4
5:D00a245:DDY@027>L26<H37>L36<H01AcW6<H@Q0aS48@00QS60QBU00DHaQBU5:DDYA24008DY@07
7>LHaQcW7>LHaQcW6<H01QcW0aS60acW0aS600@LiaS66<HLi`8HaP057>LQ22DY8@PLi`026<H00aBU
6<HDY@0248@011BU6<HHaQ240QS600@DYAS65:DHaP8DY@@HaP8@Q08DY@036<HDYABU00@HaP8DY@05
6<HDYAS66<HDY@0348@25:D00aS65:DDY@0248@25:D00a245:DDY@0348@00aS648@@Q00248@00aBU
48@@Q00248@25:D348@35:D448@011BU48@@Q1BU0a2400@DYAS65:D@Q08DY@@@Q08DY@0548@DYA24
48@DY@0248@011BU48@@Q1241@aS00<8@PaS36<00a240`aS00@@Q0aS36<<H`8@Q0035:D@Q124008@
Q0055:D<H`aS36<@Q0025:D00a2436<@Q00248@236<00aBU6<H@Q00336<00a24248<H`0248@010aS
248<Ha2410aS00@@Q0aS36<<H`8@Q0065:D@Q0aS36<@Q1BU0Q240`aS0Q240PaS00<@Q0aS36<00`aS
00@@Q0aS36<8@PT<H`035:D<H`aS008<H`0548@<H`aS36<@Q00336<248@25:D00a2436<<H`0436<0
0`Q236<@Q00648@436<00a2436<8@P0536<01a2436<<H`aS248<H`Q200X<H`0448@<H`aS36<248@2
36<248@236<010Q248@@Q12410aS0`Q20PaS00<8@PaS36<010aS000412400`0012448@0212402P00
12448AcW;F/HaQ246<HQ21cW0QBU00DLiaS67>LLiaS6008DY@036<HLiacW00<DY@036<HDYABU00<H
aP035:DHaQcW008Li`8@Q0035:DHaQcW008HaP045:DLiaBU6<H25:D46<H02QBU48@DYAS67>LHaQBU
48@HaQcW0QS600@LiaS67>LHaPDDY@8@Q0035:DHaQcW008Li`0=5:D@Q1BU5:DLibDY:DX]Jb486<HD
YA245:D00QS60aBU00<@Q1S66<H00acW00<HaQBU5:D00aS60aBU00<@Q1BU5:D00QcW1QS60aBU00DH
aQBU6<HDYAS600<DY@0748@HaQS68@PLiaS65:D00aS600@DYAS648@DY@8HaP047>LHaQBU5:D26<H0
1R489BTU:B486<HDY@@HaP8Li`058@PLiaS66<HU:@02;F/01AcW6<HHaQBU6<H00Q240QBU11S600DL
iaBU6<HLib48008Li`8DY@066<HLiacW8@PHaQBU0QS600<Q21cW8@P00acW0QS600<LiaS66<H00QcW
0RDY00<Q21cW8@P00QcW00DQ22DY8@PLiaS6008Li`8HaP@Li`066<HDYAS67>LU:AcW0aS600<DYAS6
6<H00QS60QcW00PHaQcW6<HHaQcW6<HDYA241ABU0aS60QcW00@HaQBU5:DHaP8Li`036<HDYABU008D
Y@0:48@DYABU5:DHaQBU48@DYAS65:D36<H011cW8@PLib480QS600XLib488@PLiaS65:DHaQBU7>LQ
208Li`036<HDYABU00<Li`8HaP047>LYBRDY7>L46<H01ABU48@DYABU6<H01ABU0aS60aBU0QS60QBU
00<@Q1BU5:D011BU0QcW0aS600DDYAS66<HHaQ24008DY@8@Q0035:DHaQBU008@Q0035:DHaQ24008D
Y@096<HDYA2448@<Ha245:D@Q1BU00@@Q08DY@8@Q08<H`035:D@Q1BU008<H`8@Q08DY@<@Q0045:DH
aQBU48@55:D248@00`aS5:DDY@025:D348@00aBU48@@Q00248@00aBU36<<H`0736<348@01@aS48@@
Q12436<00Q2400<DYA2448@00a240PaS00<@Q1BU5:D00Q2400<<Ha2448@01Q240PaS00H8@PaS36<@
Q0aS48@236<248@536<00a2436<@Q00248@336<448@00aBU48@@Q00436<248@236<248@436<00`Q2
36<8@P0448@00`aS248<H`0536<248@536<00a2436<<H`025:D0112436<<Ha240`aS0Q240PaS00H@
Q1BU48@@Q0aS48@236<00a2436<<H`0436<00`Q236<8@P0236<00a2436<<H`0236<248@010Q236<<
H`Q20`aS00@8@PaS36<<H`8@Q08<H`06248<Ha2448@<Ha240PaS00P@Q0aS36<<H`Q236<@Q0aS0`Q2
1@aS0@Q200000`001240000212400`001248@P0412401aS6<H`Q21BU8@PLiaS6008DY@8HaP035:DH
aQcW008HaP045:DHaQS66<H35:D26<H00aBU6<HHaP076<H25:D66<H00aBU6<HLi`036<H00aBU7>LL
i`036<H25:D56<H01QcW8@PQ21S65:D@Q08DY@0448@DYABU48@27>L03AS65:DDYAS67>LDYAcW9BT]
JbU:7>LDYA24008DY@8HaP8@Q0035:D@Q1S6008Li`056<HDYA245:DHaP055:D00a245:DDY@056<H0
0aBU7>LLi`026<H01ABU6<HLiaS65:D00QS600<DYAS65:D011S600<LiaS66<H00aS600DLiaBU5:D@
Q1S6008Li`065:DLib489BTQ21S60R480QS600<Lib486<H00aS600DLiaS66<HHaRDY008YBP047>LH
aQS67>L25:D01A245:DHaQS65:D00Q2400HDYAS67>LLiaS67>L56<H27>L36<H37>L00b487>LLi`04
7>L01AS68@PQ22489BT00R4800<Lib487>L00R4800<LiaS67>L00b4800@DYAS67>LLi`8Q20037>LH
aQS6008Li`8Q208HaP8DY@8HaP048@PLiaS66<H47>L00aS65:DDY@025:D011S65:DDYAS60QcW00@D
YAS66<HLi`<HaP047>LHaQBU48@35:D00aS65:DDY@025:D00aS65:D@Q0025:D26<H011cW8@PQ21cW
0aS60R480QcW00<DYAS66<H01AS600PLiaS65:DHaQcW8@PLiaS60b4800<LiaS66<H011BU0QS600@L
iaS65:DDY@<HaP@DY@<HaP035:D@Q1S6008HaP035:DHaQS600<HaP055:D@Q1245:DHaP035:D02A24
5:DDYA245:D@Q1BU6<H@Q00236<00a245:DDY@025:D248@011BU48@DYABU1A240QBU212400<<Ha24
5:D00a2400@DYAS65:DDY@8HaP<@Q0<DY@0348@DYA2400<@Q08DY@0348@<Ha2400@@Q0@<H`<@Q003
36<@Q0aS00@@Q0@<H`8@Q0075:D@Q12448@DYAS65:D00PaS00<@Q1BU48@00Q240QBU0Q2410aS00L8
@PaS36<<Ha2436<8@P0236<248@636<248@336<01Q2436<<Ha245:D@Q0<<H`@@Q0<<H`8@Q08<H`8@
Q0@<H`0348@<H`aS008<H`8@Q08<H`08248<H`aS48@<Ha2436<@Q08<H`0348@DYABU00D@Q0X<H`03
48@DYA2400D<H`0348@<H`aS00H<H`8@Q0<<H`8@Q0D<H`06248<Ha2448@<Ha241@aS00<@Q0aS48@0
0Q2400<<Ha2436<00a240PaS0PQ21PaS0Q240PQ2000:12401P00124HaRe[7>LDY@8Li`HHaP045:DH
aQS65:D36<H00aBU48@DY@036<H01ABU48@DYAS67>L00aS600DDYA245:DHaQcW00@HaP055:DHaQS6
6<HLi`026<H25:D00aS67>LLi`035:D011S65:DDYA240QcW00<Q21cW5:D00QS60QBU00@@Q1BU48@D
Y@<Li`0:6<H@Q1S66<HDYAS69BTaS2U:7>L25:D00aS65:DHaP025:D00aS65:DDY@036<H25:D00aS6
7>LHaP025:D36<H011BU48@HaQS60QcW00@HaQBU48@HaP8Li`046<HDYAS67>L36<H45:D011S67>LH
aR480acW0aBU00<@Q1BU5:D011S600DDYAS68@PU:B4800PLi`8HaP<Li`066<HLib48:DXU:B480QS6
00LLiaS648@@Q1BU6<HLi`025:D01A245:DHaQcW6<H00QcW00<HaQcW6<H00QS60acW00<HaQcW6<H0
0QS60acW0QS600DLiaS66<HHaQcW008U:@8Q20039BTLib4800<Li`046<HLib487>L26<H87>L011S6
8@PLiacW0QS600<DYA246<H01AS60acW1AS600@DYA2448@DY@DHaP048@PHaQBU5:D27>L01AS648@D
YABU48@02ABU00D@Q1BU5:DHaQcW00<Q20076<HLiaS67>LQ21cW6<H00QBU11S600<DYAS67>L00acW
0R4800hHaQcW6<HQ22DY8@PLiaBU36<@Q1BU48@HaQcW0QS600<DYAS66<H01aBU0QS61ABU00DHaQBU
5:DHaQcW00<DY@8HaP045:D@Q1BU48@25:D011245:D@Q1BU1A2400<DYA245:D00aBU0Q240aBU00@@
Q0aS36<<H`@@Q0035:D@Q12400@@Q00636<@Q0aS5:D@Q1BU0Q2400HDYA2448@<HaBU6<H448@01QBU
48@@Q1245:D@Q0<DY@0348@<H`aS008@Q08<H`0348@<Ha2400@<H`8@Q0035:D@Q0aS00<@Q00436<@
Q0aS5:D348@25:D348@336<00a245:D@Q00448@00`aS48@@Q00236<00`Q236<@Q00536<00a2436<@
Q00348@236<00`Q236<<H`0248@236<01PQ248@DYA2436<8@P<<H`8@Q0<<H`<@Q00336<8@PQ2008<
H`0348@<H`Q200H<H`8@Q0@<H`0;48@<H`aS36<@Q0aS48@<HaBU48@DY@0248@936<348@636<00a24
36<<H`0536<01@Q236<@Q12436<00PQ20`aS00@8@PaS36<8@PH<H`0348@<H`aS008<H`8@Q00536<@
Q0aS36<@Q00236<248@236<010Q236<8@PaS0PQ21@aS0@Q20000100012448@000P@Q00<000@Q1240
0`@Q00@HaSF]9BTDY@THaP065:DHaQS67>LHaQBU11S600DDYA2448@HaQcW00DHaP0548@DYABU5:DH
aP035:D011S67>LLiacW0QS600<LiaS66<H00QS600@LiaS66<HDY@8HaP047>LHaQS65:D26<H35:D0
0aS65:DDY@025:D01AS65:DDYABU6<H00QcW00<HaQBU6<H00b4800LU:AcW6<HLiaBU6<HDY@026<H5
5:D26<H00acW6<HHaP045:D011S65:DDYABU1aS600TDYAS65:DDYAS65:DLib487>L00QS600@@Q1S6
6<HDY@DHaP075:DHaQS66<HDYAS65:D00QS611cW00<HaQcW8@P00QcW0QS600<LiaS67>L00QS600DD
YAS66<HHaR4800<U:@8Li`<HaP<@Q0035:DLiaS600@DY@<Li`088@PLiaS65:DLibDY7>LHaP8DY@8L
i`036<HLiacW00DLi`068@PLiaS67>LU:B480QS600HLibDY9BTLiaS67>L28@P012DY8@PLib480QS6
1acW00PU:B488@PLiaS65:DHaQcW0aS60QBU0QcW00@Q21S66<HLi`8HaP8DY@047>LHaQcW7>L46<H4
5:D00a245:DDY@035:D66<H45:D66<H011cW6<HHaQS60R480QS60acW00PHaQBU7>LQ22DY8@PLiaS6
0QcW0QS600<Lib489BT00QcW00<HaQ245:D00QBU00<HaQBU6<H00QcW1AS600LDYA2448@DYAS67>LH
aP035:D01AS67>LHaQBU6<H00QcW00<HaQBU48@00QBU00@HaQBU48@@Q08DY@0348@HaQBU008@Q003
36<@Q1BU00<@Q0HDY@036<HDYABU00<@Q00336<@Q12400<DY@8@Q00436<@Q1245:D348@35:D00a24
5:DDY@025:D011245:D@Q1BU1A2400@DYA2448@@Q0<DY@8@Q0035:D@Q12400<<H`8@Q0<<H`<@Q003
5:D@Q124008<H`0948@<H`aS36<DYA245:D@Q0aS008@Q0036<HDYABU008<H`<@Q0065:D<H`aS48@<
Ha240`aS00@@Q0aS36<<H`<@Q0<<H`8@Q0<<H`0448@<H`aS36<548@00aBU48@@Q00348@536<01a24
36<@Q0aS48@<Ha2400@<H`<@Q0<<H`8@Q0d<H`<@Q0035:D@Q12400<@Q0P<H`0348@DYA24008DY@@<
H`0348@<H`aS00<<H`8@Q08<H`D@Q08<H`0348@<H`aS00@<H`04248<Ha2448@236<010Q236<<Ha24
0PaS0a2410aS00<@Q0aS36<00`Q200@<H`Q2248<H`8@Q04<H`48@P0000D48@0012448@0000848@03
24848@0000848@046<HaS2DY5:D27>L00aS65:DHaP046<H00aBU6<HDY@046<H00aBU6<HHaP025:D3
6<H37>L26<H01QBU48@DYABU6<HDY@@HaP8Li`<HaP8Li`036<HDYABU008HaP035:DHaQBU00@HaP03
7>LHaQcW00<DY@0748@DYABU5:DHaQBU7>L011S600@DYAS65:DLi`8U:@037>LHaQS6008Li`@HaP03
5:DHaQBU00<DY@046<HDYAS66<H95:D01AS67>LHaQS65:D00QS600<LiaBU5:D00QBU0R480QcW11BU
00<HaQcW7>L00QcW00<DYAS65:D00QS611BU0QcW00DHaQcW6<HHaQcW008Q20067>LHaQS66<HLiaS6
0QcW00XHaQBU6<HHaR487>LQ22U:9BTLi`8HaP037>LHaQBU00<DY@8HaP<DY@056<HLib488@PLi`03
6<H28@P011S65:DHaR481AcW00DQ21cW7>LLiaS600<Li`<Q20037>LQ2248008Q20<Li`<Q20057>LH
aQBU5:DHaP037>L011S68@PQ224811cW00<DYAS66<H00QcW00@HaQBU6<HHaP8Li`086<HLiacW7>LD
YA245:DLi`<HaP8Li`056<HDYABU5:DHaP025:D00a245:DHaP026<H45:D26<H45:D00aS67>LLi`02
6<H27>L36<H27>L26<H27>L01aS65:DDYAcW8@PU:B4800<HaP<Li`038@PLiacW008Li`8HaP055:D@
Q1BU6<HDY@037>L011S65:DHaQS60QBU00<@Q1BU5:D00aS600PDYA246<HHaQcW6<HDYAS60QcW00<H
aQBU6<H01QBU0Q240QBU00@HaQ2436<@Q08DY@<@Q0035:D@Q124008@Q0HDY@0348@<Ha2400<DY@X@
Q08DY@<@Q0DDY@8@Q08DY@<@Q08DY@0636<@Q1BU6<H@Q0aS0a240PaS0Q240PaS1Q240PaS11240PaS
0QBU00<HaQ2436<00Q2400<DYA2448@00Q2400@<Ha2448@@Q08<H`@@Q00436<@Q0aS248236<00a24
36<<H`0936<248@336<00a2436<<H`025:D248@836<00a2436<<H`0536<248@00`aS248<H`0236<0
0a2436<<H`0736<00a2436<<H`0536<248@236<248@236<00`Q236<<H`0336<248@01@aS248<H`aS
48@00`aS11241@aS00<@Q0aS36<00PaS00<@Q0aS48@04@aS00@8@Q2436<@Q0L<H`88@PD<H`0348@<
H`aS00<<H`000P@Q00D000@Q12448@0000D48@057>LaS1cW48@HaP037>L36<H00acW6<HHaP046<H0
1ABU6<HDYABU6<H00aBU0QcW0QS600LDYAS66<HLiaS65:D@Q0025:D00aS65:DHaP036<H00acW6<HH
aP036<H01QBU6<HHaR487>LHaP<Li`<DY@8Li`036<HDYA24008DY@8HaP055:DHaQS66<HLi`046<H0
0acW8@PQ20028@P02AcW6<HHaQS65:DHaQBU6<HLi`035:D02a246<HHaR487>LHaQBU6<HDYA245:D0
0QS600@LiaS66<HHaP<Li`<HaP085:D@Q1BU6<HQ22DY8@PLi`HHaP038@PHaQS600@HaP0448@DYAS6
5:D26<H02QcW9BTQ21S65:DHaQcW8@PLiaS611cW0aS600<DYAS67>L00R480acW11S600<DYA245:D0
0R4800DHaQBU48@DYAS6008Q20<HaP<Li`8DY@036<HQ21cW00<HaP037>LQ21cW008HaP8Li`056<HL
ibDY9BTLi`026<H28@P00bDY7>LLi`028@P012DY8@PQ22DY0b4800PLiaS65:DHaQcW8@PLib480QcW
0aS600@LiaS66<HHaP<DY@<HaP037>LQ21cW008HaP037>LQ21cW008DY@046<HLiacW7>L25:D00a24
5:DDY@025:D00a245:DDY@025:D26<H27>L35:D00aS65:D@Q0025:D27>L00aS65:DHaP026<H011cW
6<HHaQS611cW0QS600<Lib488@P00R4800<Lib486<H00QS600@Lib488@PLi`8HaP0448@DYABU6<H2
5:D26<H27>L35:D36<H35:D01QS65:DHaQS65:DLi`8DY@8HaP8Li`036<HDYABU00<DY@046<H@Q124
5:D36<H248@01ABU48@@Q12436<00QBU00H@Q0aS48@DYAS65:D248@011BU48@<H`aS1A240QBU0Q24
00<<Ha2448@00QBU1A2400<DYA2448@0112400<DYA2436<00Q2400<HaQ2448@00aBU00<@Q1BU48@0
0Q2410aS00<@Q0aS48@010aS0Q2400H<Ha2436<DYA2436<848@236<348@25:D436<348@00`aS48@<
H`0236<01Q2436<<H`aS248<H`8@Q0<<H`8@Q0D<H`8@Q00636<8@PaS48@DYA242@aS00<8@PaS36<0
0Q241@aS00<@Q0aS36<00`aS11240PaS00D8@PaS36<<Ha2400@<H`8@Q0<<H`8@Q0H<H`05248<H`aS
48@<H`0448@00`aS48@<H`0836<348@336<248@236<248@236<248@00`aS248<H`0336<2248436<0
0`Q236<@Q00248@536<01`Q236<<H`aS248<H`Q200<<H`4@Q04<H`4<H`0000<000@Q12400P@Q00D0
00@Q12448@0000848@066<HaS24848@HaQcW0QS600<DYAS66<H00acW0aS600@LiaS648@@Q08HaP8D
Y@@HaP8DY@8HaP035:DHaQ2400@DY@036<HLiacW00DHaP035:DHaQS6008HaP<Li`PHaP8Li`055:D@
Q1246<H@Q0025:D011cW6<HHaQBU0QcW00DHaQBU7>LQ22DY00<Q20<HaP047>LDYABU5:D26<H02QBU
48@@Q1BU7>LHaQcW6<HDYA240QBU00DHaQBU6<HHaQcW008DY@036<HLiacW008HaP077>LDYA2448@H
aR489BT00QcW00PHaQBU6<HLiaS68@PHaQcW1QS60aBU00<HaQcW7>L00R4800DLiaS66<HHaR48008L
i`8HaP@Li`8DY@067>LU:BDY8@PHaQcW0QS600<DYAS66<H011BU0QS600LDYA246<HLibDY7>LHaP02
5:D00aS67>LHaP026<H00acW6<HHaP026<H01QcW6<HLiacW6<HQ208Li`036<HLib48008Q20047>LH
aQS68@P29BT27>L48@P011cW8@PQ21cW0aS60R480acW00DQ21cW7>LLiaBU00<HaP8DY@036<HDYABU
00<Li`036<HDYAcW008Li`036<HLiacW008Li`046<HLiaS66<H45:D00a245:D@Q0035:D00aS65:DH
aP036<H75:D36<H01ABU6<HHaQS67>L011S60acW0aS600<LibDY:DX00R480QcW00<HaQcW7>L00QcW
00<HaQcW6<H00QBU00HHaQBU6<HDYAS65:D56<H011BU6<HDYAS60aBU00@HaQcW5:DHaP8Li`046<HD
YAS67>L26<H00a245:D@Q0045:D011245:DHaQcW0a2400<HaQBU48@01A2400<HaQBU48@00Q240aBU
0Q240PaS00<DYA246<H00aBU00<@Q0aS36<00Q240QBU0Q2400DDYAS65:DDYA24008DY@0448@<Ha24
5:D348@00aBU48@@Q00248@011BU6<HHaQBU0`aS00H@Q1BU48@<H`Q236<248@436<248@010aS48@@
Q1240PaS0a240PaS00@@Q1BU5:D@Q08<H`8DY@<@Q00936<@Q12448@<Ha2436<@Q0aS00<@Q0H<H`03
248<H`aS00D<H`04248<H`aS48@336<01A245:D@Q0aS24800PaS00@8@Q2448@@Q088@P0336<@Q0aS
008<H`0348@<H`aS008<H`8@Q00336<@Q0aS008@Q0055:D@Q0aS36<8@P0536<01Q2436<<Ha2436<@
Q08<H`0348@<Ha2400<@Q003248<H`aS00<<H`0848@DY@aS36<@Q1BU48@<H`88@P8<H`<@Q0/<H`8@
Q0D<H`03248<H`aS00H<H`8@Q08<H`03248<H`aS00<<H`8@Q00436<8@PaS248336<00`Q236<@Q002
36<124800005124000@Q1240000712401B48<H`Lia245:D00R480QcW0aS60QcW00HQ21cW6<HHaQBU
6<H25:D36<H27>L76<H00aBU6<HDY@025:D36<H45:D01QS65:DHaQBU6<HLi`<HaP@Li`036<HLiaS6
008HaP045:D@Q1BU48@35:D02Q246<HHaQcW6<HLiaS67>LQ21cW0QS600DLibDY9BTQ21cW00<DY@06
7>LHaQBU6<HDYA240QBU0QS60QcW0QS600<DYA2448@00QS60QcW00<DYAS65:D00aS600TDYAS67>LH
aQBU6<HLib487>L00QS600<LiaS66<H00acW00@Q21S65:DHaP8Li`<DY@DHaP<Li`055:DHaQS67>LQ
20027>L26<H00acW5:DHaP026<H37>L26<H00aBU6<HHaP026<H00aBU6<HHaP026<H00aBU6<HHaP02
6<H27>L00b487>LHaP026<H021cW6<H@Q1BU7>LU:AcW5:D37>L26<H012487>LQ21cW0b4800@LiaS6
6<HHaP8Q20@Li`8U:@058@PU:Be[:DXU:@025:D00aS67>LQ20028@P01AcW6<HLib487>L00QS600@D
YAS66<HHaP8DY@036<HLiacW00<HaP8Li`@HaP038@PLiaS600PDY@046<H@Q1BU48@35:D26<H45:D2
6<H01QBU48@@Q1BU8@PLi`@HaP047>LHaQBU5:D26<H021BU6<HLib487>LHaQcW6<H47>L00aS68@PL
i`027>L00bDY7>LHaP0248@25:D01aS65:DHaQBU6<HDYAS600@DY@036<HDYABU00@DY@036<HLiacW
008HaP035:DLiacW008Li`046<H@Q12448@25:D248@25:D448@00aBU48@HaP025:D248@25:D00a24
5:DHaP035:D548@00`aS48@DY@025:D248@00aBU48@@Q0045:D348@00aBU6<HDY@0248@010aS48@@
Q0aS0a2400DDYA2448@<Ha24008DY@096<H@Q12448@<Ha2436<@Q0aS00<@Q00336<@Q0aS00<<H`03
5:D@Q124008@Q0035:D@Q12400D@Q0045:D@Q12436<448@00`aS48@@Q00248@00`aS48@@Q00236<0
20Q248@@Q1245:D@Q0aS248236<01A2436<8@PaS48@00`aS00<@Q0aS36<00PaS11241@aS00D@Q0aS
36<<H`Q200<<H`8@Q08<H`0548@<H`aS36<@Q00236<0112436<@Q12410aS00D@Q0aS36<<Ha2400<<
H`8@Q005248<H`aS36<@Q00336<224800`aS48@@Q00736<548@236<348@236<248@010aS48@<Ha24
10aS00<@Q0aS36<00Q2410aS00<8@PaS36<02@aS00D@Q0Q2248<Ha2400<<H`0348@8@PQ200<8@P04
36<@Q0aS248248@136<000848@0300048@@Q00L48@047>LaS2485:D37>L00aS67>LHaP026<H27>L0
12487>LLiaS60aBU00P@Q1BU6<HLiaS65:DHaQcW0QS600@DYAS66<HHaPHDY@8HaP8DY@<HaP065:DL
iaS65:DHaQBU11cW00DHaQcW7>LLiaS600<DY@0548@DYABU6<HDY@036<H27>L25:D00aS67>LLi`03
6<H01acW9BTU:AcW6<HDYAS6008DY@086<HQ21S65:D<Ha246<HLi`<HaP035:DHaQBU008DY@8Li`04
6<HDYAS67>L36<H011BU6<HHaQS60QBU00<HaQcW7>L00aS600DDYAS66<HLib48008Li`8HaP037>LH
aQS6008DY@<HaP8Li`078@PLiaS66<HDYAS67>L00QS611cW00HHaQBU5:DDYAcW8@P27>L25:D011S6
5:DDYABU11S600<DYAS648@00QS60QcW0QS600@Q21S66<HDY@8Li`035:DHaQcW008Li`8HaP037>LH
aQcW008Li`8Q20037>LHaQcW008Q20047>LHaQS68@P29BT00acW6<HLi`029BT02AcW8@PYBRU:8@PH
aQBU7>LHaP048@P47>L66<H35:D36<H27>L25:D26<H00acW8@PLi`046<H248@25:D26<H00a245:D@
Q0035:D56<H35:D021S65:DDYABU6<HLiaS65:D56<H27>L26<H00aBU6<HHaP027>L00b487>LQ2005
7>L00aS67>LHaP037>L00aS65:DDY@045:D011245:DHaQcW0QS600/DYAS66<HDYAS65:DHaQBU6<HD
YAS6008Li`8HaP035:DLib48008Li`8DY@0448@DYABU5:D348@25:D448@65:D01A245:DHaQBU48@0
0QBU0a2400D<Ha2448@@Q1BU00D@Q08DY@0448@DYABU5:D348@00aS65:DDY@025:D336<248@01`aS
48@DYA245:D@Q0aS008DY@8HaP8@Q0045:D@Q12448@236<0112436<<H`aS112400<DYA2448@00Q24
00<DYA2448@00Q2400@DYA2448@<H`<@Q08<H`0548@DYABU48@<H`0248@236<248@236<00a245:DD
Y@0348@636<01A2436<<H`aS48@00PaS00L@Q0aS48@@Q0aS48@<H`0248@236<248@436<00a2436<8
@P0336<0112436<<H`aS0Q240`aS0Q240PaS00<@Q0aS36<00Q241PaS0PQ200<<Ha2448@00PaS0Q24
0`aS00@@Q0aS2488@P8<H`8@Q08<H`@@Q0@<H`@@Q00336<8@PaS008<H`0748@<H`aS36<@Q0aS48@0
1@aS0a2410aS00<@Q0aS36<01@aS00<8@PaS36<00PaS0Q2400@<H`Q236<@Q08<H`07248<H`aS36<@
Q0aS48@00@aS00001@0012448@@Q00001@@Q00L000@Q6<HaS24848@HaP057>L00aS67>LHaP036<H2
5:D36<H25:D01QS67>LQ21cW6<HDY@8Li`048@PHaQBU5:D26<H27>L25:D26<H00aBU6<HDY@036<H0
0aBU6<HHaP027>L01AS65:DHaQS67>L00aS600DLiaBU5:D@Q1BU008HaP<DY@0848@DYAcW7>LU:B48
7>LQ20<Li`036<HLiacW008Li`<DY@<HaP<DY@046<HDYABU5:D26<H00acW6<HHaP0248@011S67>LQ
21S60QBU00@HaQBU6<HDY@8HaP037>LHaQBU008HaP068@PLiacW8@PU:AS60QBU0QcW00TDYAS68@PQ
21S65:DHaQcW6<H00QBU0aS60QcW00DHaQBU6<HLib4800<HaP047>LDYA246<H27>L26<H27>L25:D3
6<H01ABU48@DYAS67>L00QS600<@Q1BU6<H00QcW00<HaQBU7>L00R480QS600<DYAS66<H00acW00<H
aQBU6<H01AcW00THaQcW9BTYBR487>LDYAcW8@P00acW00@Q21S67>LQ208YBP8U:@03:DXQ2248008D
Y@047>LQ22DY9BT37>L36<H00acW6<HHaP025:D248@00aBU6<HHaP036<H27>L01AS65:DDYAcW6<H0
0QcW0aS600<DYA2448@011BU00@@Q1BU48@DY@8HaP<@Q08HaP8DY@0448@DYAS67>L66<H00acW6<HD
Y@055:D00aS65:DHaP037>L36<H27>L28@P01AcW6<HDYAS67>L00aBU00<LiaBU5:D00Q2411BU00<H
aQcW7>L00QBU00L@Q1S65:DHaQBU6<HQ20027>L01aS65:DDYAS68@PLiaS6008@Q0086<HDYA2448@D
YAS65:D@Q0DDY@046<HDYABU5:D448@00`aS5:DDY@026<H00aBU48@@Q00248@25:D236<248@00aS6
5:D@Q00248@25:D00a245:DDY@025:D448@00aBU48@@Q00236<:48@011BU48@@Q1240`aS0Q2400@<
Ha245:D@Q08<H`@@Q00336<@Q124008@Q0035:D@Q1BU00<<H`<@Q08<H`8@Q0055:D@Q0aS36<@Q002
36<248@010aS48@<H`aS1a241`aS00D@Q0aS36<@Q0Q200<<H`<@Q0<<H`0348@<H`aS008<H`07248<
H`aS36<@Q0aS48@010aS00@@Q0aS36<<H`@@Q00636<8@PaS36<@Q0Q20PaS0Q2420aS00@8@PaS36<@
Q08<H`03248<H`aS008<H`03248<H`aS00<<H`0548@DYABU48@<H`0248@236<00a2436<<H`0236<0
0a2436<<H`0536<00`Q236<<H`0636<00`Q236<<H`0936<00a2436<<H`0636<00`Q236<<H`0248@0
1PaS248<H`Q236<@Q08<H`000`@Q00H000@Q124000Q2000312401QS6<H`LiaBU6<HQ208Li`8HaP@L
i`036<HLiaS6008DY@0<6<HDYABU5:DHaR487>LHaQBU6<HLib480QS60QBU00@HaQcW7>LHaP8DY@04
6<HDYAS65:D86<H011cW6<HLiacW0QBU0QS60QcW11BU00HHaQBU5:DDYAS65:D26<H37>L00b487>LQ
20027>L011S67>LLiacW0QS60QBU0QS600<DYAS65:D00QBU00@HaQcW6<HDY@<HaP<DY@8Li`076<HD
YABU6<HLiaS65:D011S60QBU00<HaQcW8@P01acW00XQ21BU48@DYAcW8@PHaQBU6<HLi`8HaP035:DH
aQS6008HaP035:DHaQS6008Q208Li`8DY@046<HDYAS66<H27>L00aBU6<HLi`026<H011BU6<HLiaBU
0a2400@HaQcW7>LHaP8DY@067>LQ22487>LDYAS60acW00@DYAS65:DHaP8Q20047>LHaQS66<H27>L3
6<H27>L2:DX012DY7>LHaQS60R4800XLib487>LHaQcW8@PYBRe[9BTQ20<U:@047>LHaQS68@P29BT6
7>L01aS67>LQ21cW5:D@Q1BU008HaP035:DHaQS6008Li`<HaP8DY@8HaP037>LHaQBU008DY@8HaP03
48@DYABU008DY@0348@<HaBU008DY@036<HDYABU008DY@<@Q08DY@<HaP035:DLiaS6008HaP037>LH
aQS600<DY@DHaP048@PLiacW6<H47>L00b486<HHaP026<H01QcW5:D@Q1BU6<HDY@8@Q0036<HLiaS6
008HaP8Li`086<HDYABU5:DLiaS648@HaP<Li`<HaP065:DHaQcW8@PLiaBU0Q240aBU0Q240QS60a24
0QS600D@Q1BU5:D@Q1BU008@Q0PDY@8@Q0<DY@8<H`0548@DYABU5:D<H`055:D248@55:D01A2436<<
H`aS5:D00PaS00@@Q1BU48@<H`8@Q0@DY@8@Q08<H`8@Q00436<@Q12436<348@01@aS48@DYA2436<0
0a2400<DYA2448@00aBU00<@Q0aS36<0112400DDY@aS48@<HaBU008@Q00336<@Q0aS008@Q0<<H`8@
Q0035:D@Q12400D<H`0548@<H`aS36<8@P0336<0112436<<H`aS0a2400@<H`Q2248<H`<@Q0<<H`07
248<Ha2448@<HaBU48@00`aS0a240`aS0a2400<8@PaS36<01`aS00<8@PaS36<00PaS00<8@PaS36<0
1PaS00@8@PaS36<<H`<@Q0<<H`<@Q0@<H`0348@<H`aS008<H`0348@<H`aS008<H`8@Q00336<8@PaS
00P<H`0348@<H`aS00D<H`<@Q08<H`<@Q08<H`05248<H`aS36<@Q00736<348@12480000300048@@Q
00848@0500048@@Q1240000212401124:DXQ21BU1QcW11S600<LiaS67>L00QS60QcW00@DYAS67>LQ
208Li`036<HLiacW008Li`<HaP067>LHaQBU6<HLiaBU11S60aBU00<LiaS66<H00QS600<DYAS65:D0
0aS600DLib487>LHaQBU008HaP<DY@076<HLiaS66<HDYAS67>L00RU:0R4800<DYAS66<H021S600@D
YA2448@@Q0DDY@066<HQ22487>LHaQBU0aS60aBU0aS600<DYAS65:D00aS600@LiaS67>LHaPLLi`PH
aP047>LQ21cW6<H35:D26<H47>L00b487>LHaP027>L01QS65:DDYAS68@PLi`8U:@047>LHaQBU5:D2
7>L26<H01ABU48@HaQS67>L011S600HLib486<HHaQBU6<H27>L00aS65:DDY@047>L26<H00acW6<HL
i`036<H01QcW9BTU:BDY8@PLi`8U:@048@PLib488@P36<H00b489BTU:@029BT28@P37>L011S68@PL
ib480RDY0aS60R4800@LiaBU5:DHaP@DY@8@Q0055:DHaQcW7>LHaP035:D00aS65:DDY@055:D36<H3
5:D01aS65:D@Q0aS6<HLiaBU008@Q0035:DLiaS6008DY@0348@DYAS600<HaP035:DHaQcW008HaP03
5:D@Q12400DDY@8HaP037>LHaQcW008HaP@Li`046<HDYAS67>L26<H01ABU48@@Q1245:D00aS600<D
YAS67>L00QcW00<HaQBU6<H00QBU00@HaQcW7>LLi`<HaP047>LHaQBU5:D27>L00aS65:DDY@075:D0
11S65:D@Q12411BU00<@Q1BU5:D00QBU00H@Q0aS5:DHaR487>L348@25:D0112436<<H`aS112400HD
YA245:D@Q1BU48@25:D00a245:DDY@0248@00`aS5:D@Q00748@00`aS48@DY@025:D348@00`aS48@<
H`0236<348@00aBU36<@Q00248@236<01a245:D@Q12436<@Q1BU00<@Q0<<H`8DY@8<H`0348@DYABU
00<<H`8@Q0@<H`<@Q00436<@Q1245:D648@236<00a2436<@Q00536<00`Q236<<H`0248@00`aS48@@
Q00536<00a2436<<H`0336<248@336<0112436<<H`aS0Q2400@<Ha2448@@Q0<<H`<@Q0@<H`0348@<
H`aS00D<H`0548@<H`aS248@Q00536<0112436<@Q1BU1a240QBU00<@Q0aS48@00`aS00<8@PaS48@0
0Q2410aS00<8@PaS36<01A240`aS0Q240PaS00T@Q0aS36<<Ha245:D@Q0aS248020aS0Q240PaS00<8
@PaS36<00`aS0@Q200001@@Q00048@@Q00001`@Q00HHaRe[7>LDYAS67>L26<H47>L011BU6<HHaQcW
1QS60QcW00<Q21cW7>L00QS60acW0QS600<LiaS66<H01AS600@DYAS66<HDY@8HaP035:DHaQS6008H
aP@Li`DHaP057>LDYAS65:D@Q0035:D011S67>LLiaS60QcW00@Q22DY8@PQ20<HaP075:DHaQS67>LH
aQBU6<H01QBU00PHaQcW5:D@Q1S67>LQ21cW0aBU00<HaQcW6<H00aBU0QS600DDYA245:DHaQcW00<H
aP047>LQ22488@P37>L26<H011BU6<HHaQS61acW00<HaQBU5:D01AS60acW00@HaQcW7>LLi`<DY@03
6<HLib48008Q20047>LHaQS65:D36<H011245:D@Q1S60acW00@DYAS66<HQ208Li`035:DHaQcW008L
i`046<HDYABU7>L28@P00acW6<HHaP037>L26<H00aBU7>LQ20029BT01QcW8@PQ22DY8@PLi`8Q208L
i`046<HQ22DY8@P2:DX012DY7>LHaQcW0R4800<Lib489BT01acW11S60aBU00<HaQBU5:D00QBU00DH
aQcW6<HHaQ24008DY@<HaP035:DHaQBU008HaP045:D@Q12448@35:D01A245:DDYAS65:D00Q240QBU
00@HaQBU5:DDY@8HaP035:DHaQS6008Li`8HaP035:D@Q1BU008DY@056<HDYABU5:DHaP047>L26<H0
0acW6<HLi`046<H00acW6<H@Q00348@00aBU48@DY@026<H01ABU6<HLib487>L00QS60QBU00<HaQBU
5:D00QcW00@Q21cW5:DHaP8DY@8HaP8Li`0;6<HDYABU5:D@Q1BU48@DYAS65:DHaP025:D248@45:D5
48@01QBU7>LQ21S65:D@Q08DY@H@Q0<DY@L@Q0065:DHaQBU6<H@Q0aS0Q240QBU0PaS0a240PaS00L@
Q1BU5:DDYA2436<@Q00436<248@00aBU48@<H`0248@00aBU48@<H`0236<248@00`aS5:D@Q00448@0
0aBU48@@Q00348@236<448@01@aS48@<H`aS48@00`aS1Q240QBU0Q240PaS00D@Q0aS36<<Ha2400L<
H`<@Q0L<H`0348@<H`aS00<<H`<@Q0H<H`8@Q0065:D@Q1245:D@Q0aS0PQ20a241PaS0Q241`aS00<@
Q0aS36<00PaS00L@Q0aS248@Q0aS48@DY@0248@010aS48@DYABU0a2410aS00D@Q0aS48@<Ha2400X<
H`<@Q0P<H`<@Q00336<8@PaS008@Q0X<H`0348@<H`aS008<H`8@Q04<H`48@P000`@Q00<000@Q1240
10@Q00L000@Q6<HaS2485:DHaP037>L012487>LLiaS611cW0QS612480QcW0QS60acW00<Q21cW7>L0
0acW11S600@LiaS66<HHaP8Li`036<HDYABU00HHaP8Li`8HaP8Li`036<HLiaS6008Li`8HaP045:D@
Q1BU6<H27>L01QS67>LLib487>LHaP8DY@036<HLiaS6008DY@8Li`046<HDYABU48@35:D26<H00aBU
6<HHaP026<H00aBU6<HHaP027>L00aS65:D@Q0025:D00aS65:DDY@036<H011BU6<HQ21cW0QS600<L
ib487>L00acW0QS611BU00<HaQcW7>L00QS600LDYAS66<HHaQBU6<HDY@027>L00aS67>LQ20027>L2
6<H01AcW6<HDYABU6<H00acW00@Q21S66<H@Q0<HaP8DY@0348@DYABU00@HaP8Li`<HaP@Li`8DY@06
6<HLib487>LHaR480acW00TQ21cW6<HDYAS67>LU:BU:8@P00QcW00@Q22DY9BTQ20<HaP<Q20<U:@8L
i`8Q20<Li`<Q208U:@077>LHaQcW8@PU:B486<H00aBU00<HaQBU48@00QBU0aS611BU0Q2400<DYAS6
6<H00Q2400@DYA2448@@Q08DY@076<HDYA2436<@Q1BU6<H00QBU0Q240aBU00@HaQ246<HDY@8HaP03
5:D@Q1BU008HaP<DY@0348@DYABU00DDY@8HaP8DY@066<HLiacW6<HDYAS60QBU00H@Q1BU6<HHaQBU
48@46<H00aBU6<HLi`056<H00aBU6<HDY@036<H47>L02AS65:D@Q1BU8@PLiaS65:DHaP045:D36<H2
5:D01A245:DDYABU6<H00aBU00@@Q0aS36<<H`8@Q0085:DHaQS66<H@Q0aS48@<H`8DY@<@Q0075:D@
Q12448@DYAS65:D00Q2400@DYAS67>LDY@8@Q0@<H`8@Q0<DY@0348@<Ha24008DY@0548@<H`aS36<@
Q00236<010Q236<@Q1240`aS00<DYA2448@00`aS00<DYA2448@00Q2410aS1A240`aS00@@Q0aS48@<
H`<@Q08<H`8@Q0@<H`@@Q00336<@Q12400@@Q00436<@Q12448@>36<248@436<0112436<@Q0aS0Q24
00H<Ha2436<<H`Q236<548@00aBU48@<H`0436<348@236<00`Q236<<H`0248@236<010Q236<<H`aS
0PQ210aS00D@Q0aS36<8@PaS00@@Q0055:D@Q1BU5:D@Q0025:D01A2436<<H`aS48@00PaS0a240PQ2
00D<Ha2436<<Ha2400<<H`<@Q0@<H`0348@<H`Q2008<H`<@Q08<H`8@Q00336<8@PaS008@Q0<<H`@@
Q0H<H`0000<48@0012400P@Q00D000@Q12448@0000848@056<HaS24848@HaP057>L36<H27>L00aS6
7>LLi`027>L38@P27>L00aS67>LLi`037>L011S68@PLiacW11S600@LiaS66<HHaP8Li`036<HDYA24
008HaP8Li`8DY@036<HLiacW008Li`<DY@036<HQ21cW008HaP055:D@Q1S65:DLi`026<H37>L00b48
6<HHaP025:D00aS65:DHaP026<H27>L00aS65:DDY@045:D26<H01aBU6<HHaQcW6<HDYAS6008Li`03
5:D@Q1BU008HaP055:DHaQBU5:DLi`036<H00b487>LHaP026<H01R487>LHaQS67>LHaP<DY@036<HD
YAS600<Li`<HaP045:DHaQS65:D36<H01AcW8@PQ22487>L01AS60QBU0QcW00<U:B486<H00aBU00@L
iaS65:DDY@@HaP055:DHaQS67>LHaP037>L26<H27>L03ABU48@DYAS68@PLib487>LHaQBU6<HQ22DY
008HaP0548@HaRDY:DXU:@027>L00b489BTU:@027>L011S67>LQ21cW0R4800<U:B487>L00b480acW
124800@U:B487>LLi`8Q20047>LHaQS65:D26<H35:D26<H35:D36<H01QBU48@DYABU48@DY@8@Q003
5:D@Q1S600<DY@@@Q0035:DHaQBU00<DY@@@Q08DY@<HaP095:D@Q1245:DHaQcW6<HDYAS600<@Q0<D
Y@036<HDYAcW008DY@056<HLiacW6<HDY@026<H25:D26<H00aBU48@@Q0025:D36<H25:D46<H00aBU
6<HLi`025:D01aS67>LLiaBU6<HQ21cW00<DY@036<HLiaS6008HaP0348@DYA24008DY@8HaP067>LD
YABU5:D@Q1S611BU1Q2400DDYAS66<HDY@aS008@Q0046<HDYA2448@236<011245:DDYABU0a240aBU
00L@Q1BU7>LDYA24248<H`0448@01@aS48@DYABU48@00PaS00D@Q1BU5:D@Q0aS008@Q00336<@Q0aS
008<H`L@Q00336<@Q12400@@Q00336<@Q12400H@Q0<<H`D@Q0<<H`<@Q0@<H`8@Q0035:D@Q12400@@
Q08<H`<@Q003248<H`aS00<<H`03248<H`aS008@Q0@<H`0548@<H`aS36<8@P0236<348@236<01124
36<@Q0Q20PaS0Q2400D<Ha2448@<Ha24008<H`0448@<Ha2436<348@336<248@00`aS2488@P0636<0
112436<<Ha240`aS00D@Q0aS48@@Q1BU00X@Q00336<@Q0aS008<H`0648@<H`aS48@<Ha240PaS00D@
Q1BU48@@Q0aS00@@Q0H<H`0348@<H`aS00<<H`8@Q0D<H`8@Q08<H`<@Q08<H`<@Q04<H`48@P0000<0
00@Q00002@@Q00HHaRe[7>LDYAcW8@P47>L00aBU6<HQ20029BT011cW5:DHaR480bDY0QcW00<HaQcW
7>L011cW00DQ21cW7>LLiaS6008Li`@HaP047>LHaQBU5:D26<H28@P011S65:DDYAS60QcW00HHaQBU
5:DHaQcW8@P26<H27>L011S648@DYABU0QS600<LiaS66<H00QcW0QS600@DYAS66<HDY@8HaP8DY@05
6<HLiaS66<H@Q0055:D36<H011BU6<HDYAS60QcW0QS60aBU11S600@DYA245:DDY@<Li`8HaP8Q2003
7>LHaQS6008HaP035:DHaQS6008HaP@DY@<HaP045:DHaQS67>L26<H28@P012DY8@PLiacW1AS600<L
ib488@P00acW00<DYAS66<H01AS611BU00HHaQcW6<HLib486<H25:D00aS68@PLi`025:D36<H67>L0
1aS65:DDYABU6<HQ22DY00<Q20069BTQ21S67>LU:AcW0QS600DQ22e[:DXLiaS6008Q20037>LHaQcW
00HQ208U:@038@PLiacW00@Li`8HaP067>LHaQS66<HLiaS60aBU0Q2400DDYA245:D@Q1BU008HaP04
5:D@Q1BU5:D248@010aS48@@Q1240PaS0Q2400@DYA2448@@Q0<<H`0448@DYAcW7>L26<H00aBU6<HD
Y@095:D00a245:DDY@026<H021245:DDYABU6<HDYA245:D36<H448@26<H25:D26<H01QBU6<HHaQS6
7>LHaP8DY@8HaP035:D@Q12400<HaP057>LQ21S66<HDY@046<H27>L00aBU48@DY@036<H35:D01A24
5:D@Q1BU48@00aBU0a2400DDY@aS36<@Q1S6008Li`8@Q0035:D<Ha24008@Q0075:DHaQBU48@<Ha24
6<H00aBU0Q2400/DYA245:D@Q1BU48@<Ha2436<@Q1BU00D@Q00336<@Q124008@Q005248<Ha245:D@
Q00336<448@336<648@010aS48@<H`aS112410aS0a2410aS112400<DY@aS36<010aS00D@Q0aS48@@
Q0aS008@Q0045:D@Q12436<348@01@aS48@<H`aS48@01@aS00<@Q0aS24800PaS0a240PaS00H8@PaS
48@<Ha245:D248@336<00a2436<@Q00248@00aBU48@<H`0336<0112436<<H`aS112440aS00<@Q0aS
36<00PQ200<<Ha245:D00Q240aBU0a240QBU0Q240PaS0a240`aS00<@Q0aS36<00Q2400<DYA2436<0
0PaS0a242`aS00<@Q0aS36<00`aS00<@Q0aS36<00a240PaS0a240PQ200<<Ha2448@00@aS00051240
0`0012448@0212402@00124HaS6<8@PHaR487>LQ20036<H00aBU6<HU:@029BT012486<HHaR480bDY
11cW00@Q21S66<HHaP8Q20037>LHaQcW008Li`@DY@8Li`036<HDYABU008DY@8Li`036<HDYABU00<L
i`036<HDYAS6008HaP047>LHaQcW7>L26<H01ABU48@DYAS67>L01QS600<DYAS67>L00aS600<DYAS6
6<H00aS60QBU00<HaQBU48@00QBU00@HaQcW7>LHaP8DY@046<HLiacW7>L35:D76<H25:D00aS68@PL
i`026<H37>L36<H00aBU6<HDY@046<H00aBU6<HHaP046<H01QcW5:DHaQcW6<HQ208Li`058@PLib48
7>LDY@026<H00acW6<HHaP047>L01AS65:DHaQS65:D00QS60Q2400DHaQcW6<HDYAS6008Q20047>L@
Q1BU6<H37>L35:D02AS67>LLib487>LQ21cW6<HDY@027>L041BU48@LibDY;F/U:AcW8@PLib487>LQ
21cW5:DHaRDY0RU:0QcW00<Q21cW7>L00QcW0R480RDY1b4800HLib488@PLiaS67>L25:D36<H011cW
6<HDYAS60a240QBU0QS600@DYA2448@DY@8@Q0055:D@Q1S65:D@Q00236<848@010aS248@Q1240aS6
00<LiaBU48@00Q240QBU0aS61QBU00<HaQBU6<H00aBU00<HaQBU5:D011BU0a2400<DYAS65:D011BU
0QS600@DYAS67>LHaP8DY@0648@HaQBU5:DHaQcW0QS60QcW00<Q21cW6<H00aBU00HHaQcW6<HHaQBU
48@35:D011S67>LDYABU0Q241QBU112400H<HaBU48@HaQcW5:D348@00aBU48@@Q0025:D01Q2436<<
Ha245:DHaP@@Q08DY@0348@DYA24008@Q00436<@Q12436<248@01ABU48@@Q12436<00a240PaS1124
0PaS00<8@PaS48@00Q240PaS21240`aS00D@Q1BU36<@Q1BU008@Q0@<H`0348@<Ha2400<<H`0348@<
H`aS00X<H`8@Q00536<@Q12448@<H`0248@00aBU36<<H`0336<00a2436<<H`0236<248@00`Q236<<
H`0336<248@01@aS48@@Q12436<00Q2410aS00<DYA2436<00PaS0a240`aS0a2430aS0PQ20PaS00<@
Q0aS24800PaS00@@Q0aS36<<H`H@Q0085:D@Q1BU48@DYA245:D@Q0<<H`D@Q00736<@Q0aS36<@Q1BU
48@00`aS0a2410aS00@@Q0aS36<<H`@@Q0@<H`0548@<H`aS36<@Q00636<348@00`aS248<H`0236<0
000400048@@Q00051240200012448AcW=JdU:ABU6<H37>L36<H011cW8@PQ22480QcW00<HaR489BT0
0RDY0aS60acW00<HaQcW7>L01AcW0QS600<DYAS67>L00QcW00<HaQBU5:D012481QS600DDYAS66<HH
aQcW008HaP045:DHaQS65:D36<H35:D36<H011BU6<HHaQcW0QS61ABU00LHaQcW6<HHaQ2436<@Q003
5:D00a245:DHaP076<H00b486<HHaP025:D26<H00acW6<HHaP046<H37>L011BU6<HLiacW1AS600<@
Q1S66<H00QcW0QBU00PHaQcW7>LLiaS67>LQ21S60acW0RDY0QcW11S60QcW00<Q21cW7>L00QS600@L
iaS65:DHaP@DY@056<H@Q1BU6<HLi`026<H00acW9BTLi`025:D011S68@PLiacW11S611cW00XHaQcW
6<HDYAS67>LQ21S67>LQ208YBP048@PLib488@P36<H012DY8@PU:BDY0b4800<HaQBU6<H00R4800HU
:AcW8@PQ22DY8@P29BT012487>LQ21cW11S600DQ21S65:DDYAS6008DY@8@Q08DY@046<HDYAS66<H3
5:D011245:D@Q1240`aS00X@Q0aS36<8@PaS48@<H`Q236<@Q0D<H`0448@<H`aS48@25:D00a2436<@
Q0025:D348@36<H01QBU6<HLib487>LHaP8Li`036<HLiaBU00DDY@0448@<Ha2436<25:D00aS65:DD
Y@025:D37>L25:D26<H25:D01A245:DHaQS67>L00QS60QBU0aS61AcW11BU00DHaQBU6<HHaQBU00<@
Q08DY@0348@DYABU008@Q00536<@Q12448@DY@026<H00aBU48@DY@025:D348@00aBU6<H@Q00236<0
0a246<HDY@0248@01ABU48@@Q1245:D00Q2400<<Ha2448@00PaS00T@Q1BU48@@Q0aS48@<Ha2436<0
1A240PaS00<@Q0aS48@0212400@<Ha2436<<H`8@Q0035:D@Q124008@Q00336<@Q0aS00D<H`<@Q08<
H`0348@DYABU00<<H`<@Q0<<H`<@Q0045:D@Q12448@336<348@336<348@736<348@536<448@01QBU
48@<H`aS248<H`8@Q0045:D@Q0aS48@236<248@336<448@336<248@636<00`Q236<<H`0548@00`aS
248<H`0436<00a245:DDY@025:D348@00aBU48@DY@0248@236<448@236<248@01aBU48@@Q0aS48@<
Ha2400<<H`0348@<H`aS008<H`0448@<H`aS48@436<00a2436<<H`0736<248@336<01A2436<<H`aS
48@00@Q200000`@Q00048@0212400`0012448@04124011S6<H`U:ABU0QcW00PQ21cW7>LHaQBU7>LQ
22DY0QcW0QS600HU:BU::DXQ21cW6<H87>L00b487>LHaP037>L00aS65:DHaP027>L36<H27>L01248
7>LLiaS60QBU00<HaQBU6<H00QS60QcW11S600<DYAS66<H00QS60aBU00DHaQcW6<HHaQBU008HaP03
7>LHaQBU00<DY@076<HLiaS66<HDYA245:D00Q240QBU0QS600@DYA245:DHaP8Li`036<HLiaS600<H
aP8DY@0<6<HLiaS66<HDYAcW6<HDYAS65:DLib480QcW0aS600<DYAS65:D00aS600<LiaS65:D00QBU
00dHaQcW6<HHaQcW8@PLiaBU7>LU:BU:7>LHaP027>L36<H012487>LLib480QcW11S60QBU0QcW00<H
aQ245:D00QS600XDYAS66<HQ22DY7>LHaQ246<HQ20<HaP037>LHaQBU008Li`8Q208HaP8DY@086<HL
iacW7>LHaR489BTYBP<Q208Li`8Q20<U:@8Q20037>LHaQcW008Q20046<HLiacW9BT38@P00bDY8@PU
:@028@P37>L011S67>LLiaS60aBU0aS600DDYA2448@DYAS6008DY@8HaP035:D@Q1BU008DY@<@Q004
36<@Q0aS248236<00a2436<<H`0236<01PQ236<8@PaS5:D@Q08DY@<@Q00836<@Q1245:D@Q1BU48@D
Y@8HaP8DY@046<HLiacW6<H25:D011cW8@PLiaBU0a2400<HaQBU48@00a2400DDYA2448@DYAS6008D
Y@<Li`066<HDYABU6<HDYA2411BU00@HaQcW7>LLi`<DY@036<HQ21cW008Li`8HaP045:D@Q1BU6<H2
5:D00acW5:DDY@0248@35:D00aS65:D@Q00336<011BU48@DYAS60QBU00H@Q1BU5:D@Q0aS48@35:D0
0a245:D@Q0025:D00a245:DDY@0348@00aBU48@DY@0248@236<;48@336<448@01@aS48@<H`aS48@0
0PaS00<@Q0aS48@00a2400<<Ha2448@00`aS1A2400@<Ha2436<<H`<@Q0@<H`0348@DYA24008<H`<@
Q0@<H`D@Q00536<@Q0aS36<@Q00236<00a2436<<H`0336<248@336<348@336<248@02@aS48@@Q124
5:D<Ha2436<@Q00236<248@236<448@00`aS48@@Q00536<248@436<248@936<00a2436<<H`0436<0
0`Q236<<H`0348@35:D00a245:D@Q00248@00aS648@@Q00536<00a245:D@Q00236<348@336<348@6
36<00a2436<<H`0236<548@236<00`Q236<<H`0348@01PaS48@@Q12436<@Q0H<H`000P@Q00<000@Q
12401`@Q00@HaRe[8@PDY@8Li`8HaP047>LQ22DY8@P36<H00acW8@PQ20028@P011cW6<HHaQS60acW
0aS60QcW00XDYAS67>LLiaS65:DLibDY8@PLi`8DY@8HaP@Li`DHaP8DY@<Li`8HaPHDY@8HaP055:D@
Q1S67>LHaP0248@01AS67>LLiaBU7>L01AS600DLiaS66<HHaQBU00<@Q0065:DHaQS65:D@Q1BU0QcW
0aBU00@HaQcW8@PLi`8DY@086<HDYAS66<HLiaS65:DHaP8Li`038@PLiacW00<HaP065:DHaQcW7>LD
YA240QBU00<LiaS65:D00aS60acW0R4800@Lib488@PU:@8YBP057>LHaQBU5:DQ20027>L00bDY8@PH
aP025:D011cW6<HDYABU0aS600HDYA245:D@Q1S67>L28@P01aS67>LQ21cW5:D@Q1BU00<Q20@HaP04
8@PLiacW6<H27>L01B486<HLiacW8@P00QS600@Q22U:;F/U:@@Li`038@PU:BDY008Li`036<HLiaS6
00<Li`038@PU:AcW00<Li`<Q208U:@048@PHaQS67>L26<H011BU6<HHaQcW0QS600<@Q1S66<H01QBU
00@<Ha2436<@Q0<<H`03248<H`Q2008<H`0324848@Q20088@P031248@PQ200<8@P0:1248@P@Q248<
H`Q21248@P@Q36<7248336<448@35:D01QS65:D@Q0aS48@DY@8@Q003248<H`aS00H@Q08DY@8HaP8D
Y@0>48@DYABU5:D@Q1BU6<HDYAS65:DHaQBU6<HDY@@HaP0348@DYAcW008Li`035:D@Q1S6008HaP<D
Y@036<HDYA24008@Q0036<HDYABU00P@Q08DY@8HaP8DY@0:48@<Ha245:DHaQBU36<8@PaS6<H55:D0
1AS65:D@Q1245:D0212400@<Ha245:D@Q08<H`8@Q00336<@Q1BU008DY@@<H`@@Q08<H`0648@DYABU
48@8@Q240aBU0PaS1Q2400<<Ha2448@0112410aS00<@Q0aS48@00`aS0Q2400@<H`Q236<@Q0@<H`8@
Q00536<8@PaS48@DY@0336<248@00aBU48@@Q00336<010Q236<<H`aS0Q240PaS0a2400@<Ha245:D@
Q08<H`@@Q0<<H`0348@<H`aS008<H`@@Q08<H`<@Q0@<H`0348@<H`aS008<H`0448@<H`aS36<348@4
36<00`Q236<<H`0236<0112436<DYABU0Q2400D<Ha2448@DY@aS008@Q00336<@Q124008@Q08<H`<@
Q0035:D@Q124008@Q0<<H`<@Q08<H`0448@<H`Q236<248@02`Q236<<Ha2436<8@PaS48@<H`Q236<0
0Q241PaS00<@Q0aS36<010aS00001@0012448@@Q000010@Q00P000@Q124HaSF]9BTDYAS60acW0R48
00/HaQcW6<HLiaS67>LQ21cW8@PYBR4800<DY@8Q20036<HDYAS6008Li`048@PLiacW8@P36<H38@P0
1AcW5:DHaQBU6<H00acW00<Q21cW7>L00aS60QBU00DHaR488@PHaQBU008HaP045:DHaQcW6<H35:D6
6<H011BU6<HHaQcW2AS600@DYA2436<@Q0@DY@0348@DYAS600<HaP045:D@Q1S67>L28@P00acW6<HH
aP076<H01QBU8@PU:BDY8@PDY@HHaP035:D@Q1BU008HaP045:DHaQS67>L26<H37>L28@P01QcW9BTU
:BU:9BTLi`8HaP<Li`058@PLib486<HDY@026<H011cW5:DDYABU0QS600<DYAS66<H00QBU00<HaQcW
8@P00QS60QcW00DHaQBU5:DLib48008Li`8HaP038@PLiacW00@Li`036<HLiacW008Q208Li`058@PU
:BU:9BTQ20037>L012489BTQ22480acW0QS60acW00<Q21cW7>L00QcW00<U:B488@P00RDY00@Q21cW
6<HLi`8HaP8DY@8Li`046<HDYAS65:D26<H55:D348@00`aS48@<H`0236<00`Q236<8@P0524831240
10Q21248@P@Q0PQ200<48@Q212400PQ200H48@Q2248<H`Q236<4248010aS48@DYABU11241QBU1Q24
10aS0Q2400<DYA245:D00QBU0QS60QBU0Q2400<HaQBU5:D021BU00<HaQcW6<H00QS600<Lib487>L0
1ABU00<HaQBU6<H00QBU0Q240QBU00DHaQBU5:D@Q0aS00<@Q0HDY@8HaP035:D@Q124008@Q0035:D@
Q124008@Q0045:DHaQBU48@65:D248@236<348@011BU48@@Q0aS0a240`aS00T@Q1BU48@@Q0aS48@<
Ha2436<00Q240PaS00D@Q1S65:D@Q0Q200D@Q0065:D<H`aS36<@Q1BU0a240PaS00@@Q1BU5:D@Q0<<
H`<@Q0D<H`0348@<H`aS00<<H`<@Q0<<H`8@Q00336<@Q124008@Q08<H`0448@DYA2448@336<00a24
36<@Q00248@00`aS48@@Q00448@010aS48@DYABU10aS00<@Q0aS48@010aS00@8@PaS48@@Q0<<H`<@
Q00336<8@PaS00@<H`03248<H`aS008<H`0348@<Ha24008<H`8@Q00536<8@PQ236<@Q00236<25:D2
48@01PaS48@@Q0aS48@<H`@@Q00336<@Q124008@Q08<H`8@Q0035:D@Q0aS00<<H`<@Q0@<H`@@Q08<
H`03248<H`aS00H<H`0348@<H`aS008<H`<@Q08<H`8@Q0<<H`48@P0000<48@0012400`@Q00X000Q2
12448@00124HaS6<9BTHaP8Li`066<HLiacW9BTQ21S60QBU00DLib489BTQ21S600<Li`<HaP8Li`04
6<HDYAcW7>L28@P25:D00aS67>LQ20027>L00aBU6<HHaP026<H00aBU6<HLi`047>L00b486<HLi`04
6<H25:D011245:DDYAS61QBU00<HaQBU5:D00a2400DHaQcW7>LLiaS6008DY@047>LHaQS66<H37>L0
0aS65:D@Q0026<H248@00aBU7>LHaP025:D46<H37>L26<H25:D66<H67>L46<H45:D01QS67>LHaQS6
5:DHaP8Li`056<HDYAcW8@PYBP02>Lh022e[9BTHaR487>LDYAS65:D39BT01B487>LLib486<H00QBU
00@HaQcW6<HDY@8HaP<DY@056<HLiaS66<HLi`026<H25:D02aS65:DHaRDY:DXU:AS67>LQ21cW5:D0
0QS600<Q21cW8@P00RDY00@LiaS65:DLi`8Q208U:@048@PLib488@P29BT00b489BTQ20047>L00b48
9BTQ20026<H011cW8@PQ21cW0R4800@YBRDY9BTQ208Li`076<HDYAS67>LHaQcW5:D01a240PaS00@@
Q0aS2488@P8<H`<48@0324848@@Q01448@0324848@@Q00<48@0324848@@Q00<48@0300048@@Q0084
8@P8@P<<H`066<HLiaS636<8@PaS0Q240`aS11240QBU00LHaQBU5:DDYA245:D@Q0045:D248@45:D0
1QS65:DHaQcW6<HDY@8@Q08HaPPDY@8@Q0@DY@0548@<Ha2448@DY@026<H55:D448@011BU48@@Q0aS
0Q2411BU00@HaQBU5:D@Q0<DY@D@Q0055:D@Q1245:D@Q00436<248@01ABU48@@Q1245:D00Q2400@<
Ha2436<<H`8@Q0045:D@Q12436<448@236<748@236<548@00`aS48@@Q00248@00`aS48@@Q00248@0
10aS48@<Ha241`aS00<@Q0aS48@00a2420aS00<@Q0aS36<00`aS0a240PaS00<@Q1BU5:D00QBU00<@
Q0aS36<00a240`aS0Q240PaS00<8@PaS36<00PaS00D@Q1BU48@@Q0aS00<@Q0D<H`03248<H`aS00h<
H`04248<Ha245:D448@536<748@010aS48@@Q0aS1A240PaS00<@Q0aS48@00Q240`aS00L@Q0aS36<<
Ha2436<@Q00536<00a2436<<H`0436<01@Q236<<Ha2436<00Q240`aS0A240@aS0@aS000312400`00
1240000612400aS6=JdU:@046<H00acW8@PLi`027>L01QS65:DLib48:DXU:@<Li`036<HLiaS6008H
aP8Li`046<HLib487>L36<H00acW6<HLi`027>L36<H27>L01AS65:DHaQcW6<H00R480QcW00<HaQBU
6<H011S600<@Q1BU6<H01ABU00<HaQBU5:D00aBU00P@Q1BU5:DHaQcW6<HLiaS60QcW11S60QcW00@D
YA245:D@Q08HaP<DY@0348@DYAS6008HaPDLi`046<HDYAS66<H27>L00aS65:DDY@026<H01QcW6<HL
iacW6<HLi`HDY@8HaP8DY@036<HLiacW00DHaP068@PYBSg_>Lhe[BU:0acW00@HaQBU6<HLi`<Q20@L
i`045:DHaQS66<H35:D00aS65:D@Q0026<H01AcW6<HLiaS67>L00aS60QBU00@Lib489BTQ208Li`05
8@PLiaS65:DHaP037>L00bDY8@PLi`026<H01B489BTU:BDY:DX00acW00<U:BU:9BT0124800<LiaS6
7>L00acW00<HaQcW7>L00R4800@Lib489BTU:@8YBP059BTLiaBU6<HDY@037>L011S65:DDYABU0a24
0PaS0a240PaS00<8@PaS24800PQ210@Q00<8@P@Q00000`@Q00H8@P@Q124000@Q000612400`Q21244
8@071240200012448@@Q24848@Q21242248436<00a245:DDY@026<H01Q2436<8@PQ248@<H`8@Q08<
H`8@Q08DY@8HaP035:D@Q124008DY@8HaP047>LDYA2448@25:D011246<HHaQS60QBU00<Lib485:D0
0Q2400@HaQBU48@DY@8HaP035:D@Q1BU00@DY@046<H@Q12436<25:D00a245:DDY@025:D00a245:DD
Y@025:D448@011BU48@DYA240QBU0a240aBU0a2400<<Ha2448@00QBU1a2410aS00<@Q1BU48@01a24
0PaS00D@Q1BU5:D@Q0aS00L@Q0035:D<H`aS00@@Q00336<@Q12400<@Q00336<@Q12400@<H`0348@<
H`aS008@Q08<H`04248<H`aS48@436<348@236<248@336<248@00`aS48@<H`0448@01`aS48@@Q124
36<@Q1BU008@Q0<DY@0348@<H`aS00D@Q00436<@Q0aS48@436<01A245:D@Q12436<01A2400<<H`Q2
36<01@aS0Q240`aS00<@Q0aS36<00`aS00@@Q0Q236<<H`<@Q00836<@Q12448@<Ha2436<@Q0<DY@<@
Q00536<@Q12448@<H`0248@25:D00a2436<@Q00548@25:D436<448@836<00a2436<<H`0836<248@2
36<148@12480000300048@@Q00H48@0900048@@Q5:DaS2DY5:DLiaS6008Li`8Q20057>LHaQBU6<HQ
20039BT47>L36<H25:D47>L01AS67>LLiaS67>L00b4800@LiaS66<HDY@DHaP@Li`036<HLiacW008H
aP<DY@8HaP8DY@<HaP045:DHaQBU6<H25:D348@26<H00acW6<HHaP027>L46<H012487>LLiaS60aBU
00DHaQBU5:DDYA2400@HaP035:DHaQS600DLi`036<HDYAS600DHaP047>LQ21cW7>L36<H011BU6<HH
aQS61ABU11S600DDYAcW8@PU:AcW008HaP057>LQ22489BTYBP028@P011cW6<HQ21cW0b4800/U:AcW
8@PLiaS65:DHaR487>LHaQBU008HaP8DY@0648@HaQS67>LHaQcW0aS600DLiaS66<HHaR48008YBP03
8@PLib48008DY@8HaP038@PLiacW00HLi`<Q200:6<HQ22U:9BTQ21S68@PYBRDY7>L36<H38@P37>L6
8@P47>L01bDY:DXU:BDY6<HDYA24008DY@@@Q00536<8@PQ21248@P0212400`Q21240000212400`Q2
12448@0D12400`0012448@0312400`Q212448@081242248;12401@Q212448@Q248@00QBU00L@Q0aS
48@<Ha245:D@Q0035:D02A245:D@Q1BU6<HDYA2436<@Q0035:D448@01QBU7>LHaQS648@DY@8HaP05
5:D@Q1BU5:D@Q0025:D26<H011BU6<HHaQBU1A240QBU0Q2400<DYA245:D00Q240QBU0Q2400@<Ha24
6<HHaP<@Q0055:DHaQBU48@<H`0248@25:D348@00aBU48@@Q0025:D00a2436<8@P0336<00aBU48@@
Q00548@00aBU48@@Q00748@00`aS48@DY@0248@00`aS48@@Q00748@00aBU48@<H`0236<748@436<0
11245:D@Q1241@aS11241@aS00<@Q0aS36<010aS0a2400H<Ha2448@<Ha2436<248@00`aS48@<H`04
48@236<248@00aBU48@<H`0436<00a2436<<H`0336<011BU48@@Q1BU0Q240`aS00<DYA2436<00PQ2
00D<Ha2436<<H`Q200T<H`0448@<Ha2436<248@00aBU48@@Q00336<748@00`aS48@@Q00248@236<3
5:D448@236<348@436<00a2436<<H`0436<00a2436<<H`0>36<00a2436<<H`0336<00006124000@Q
00048@001P@Q00<HaSF]:DX011S61AcW0QS600@Lib489BTQ20@Li`046<HDYAS66<H47>L00b487>LH
aP026<H27>L00b487>LHaP056<H00acW6<HHaP067>L36<H25:D26<H75:D011S67>LHaQBU0a240aBU
00<HaQcW7>L00aS600<LiaS66<H011S60aBU00DHaQBU48@@Q1BU00<HaP0348@DYAcW008Q20036<HD
YAcW008HaP035:DHaQS6008HaP<Li`038@PLiacW00@HaP@DY@0348@HaQS600<HaP077>LHaQBU6<HQ
22DY7>L00QS600PQ21cW8@PU:BU:9BTQ21BU0QS600@LibDY8@PQ208Li`8Q20037>LHaQBU008Li`8D
Y@0348@HaQS600<HaP<Li`036<HDYAS600<HaP0548@HaR48:DXU:@047>L25:D00acW8@PQ20067>L2
8@P012DY7>LHaRDY0RU:0QcW00@Q22U:9BTLi`8HaP8Li`8Q20LLi`8Q208Li`086<HQ22488@PU:BU:
7>LDY@8@Q0045:D@Q12448@236<5248812400`0012448@0312400`0012448@0212400`0012448@03
12400`Q212448@041240100012448@0010@Q00@000@Q1248@P<48@88@P848@0324848@@Q00<48@88
@P051248@PQ248@<H`0948@00aS65:DDY@0348@00aS65:DDY@025:D011245:DDYABU0Q2400<DYA24
6<H00QcW00<HaQBU5:D00QS600<DYAS65:D011BU11S600<DYA245:D00Q2400@<Ha2448@@Q08DY@03
48@DYA2400<@Q0035:D@Q124008@Q0@DY@0448@DYABU5:D248@02ABU48@@Q1245:D@Q0aS248@Q002
5:D248@336<00`Q236<@Q0025:D01A2436<@Q1245:D00Q2400@DY@aS48@@Q08DY@0448@<Ha245:D4
48@336<011BU48@@Q1240PaS0a240PaS0a2400<<Ha2436<01@aS0a2400D<Ha2436<<Ha2400<<H`03
48@<Ha2400@@Q004248<H`aS48@336<00a245:D@Q00248@00`aS48@<H`0248@336<011BU48@@Q0aS
0a240`aS0Q240`aS00@@Q0aS36<<H`<@Q08<H`8@Q0055:D@Q0aS36<@Q00936<00a2436<<H`0<36<3
48@536<248@00aBU48@@Q00448@020aS48@@Q1BU48@DYA245:D248@00`aS48@@Q00348@02@aS48@@
Q1BU48@<Ha2436<8@P0636<248@236<00`Q236<<H`0936<148@136<136<000`48@046<HaS2485:D4
7>L36<H27>L011S67>LLib4811cW0QS60QcW00DDYAS66<HHaR4800<Li`066<HLibDY:DXU:AcW0QS6
00<LiaS65:D00QBU00<LiaS66<H011cW00<HaQcW6<H00QS600<LiaS65:D00aS60aBU00<HaQBU5:D0
11BU0Q240QBU00@LiaS66<HQ208Li`036<HDYAS6008DY@046<HLiaS66<H65:D46<H00aBU6<HLi`02
5:D00a246<HHaP035:D26<H00acW6<HLi`028@P27>L01QBU6<HHaQS65:DHaP8DY@066<H@Q1245:DH
aQcW0QS61AcW00<HaQBU6<H00QcW0RDY0QcW00@HaQcW9BTU:@<Q20047>LQ22489BT27>L25:D01QS6
7>LLiaS65:DHaP8Li`056<HDYAS65:DHaP037>L36<H49BT011cW6<HHaQBU0aS600LLib488@PLiaBU
6<HQ20027>L01B487>LQ21cW8@P00bDY1AcW0aS60QcW0QS600<Lib487>L01AS600XLib48:DXU:BU:
9BTHaQBU36<DY@8@Q08<H`88@P031248@PQ200848@0500048@@Q1240000312400`0012448@061240
0`0012448@0512400`0012448@0@12401000124000@Q10Q20`@Q00@000@Q1248@P848@0300048@@Q
00<48@04248<HaBU5:D348@01QBU48@@Q0aS248<H`8@Q0035:D@Q1BU00<HaP045:D@Q12448@45:D0
0aS65:DHaP025:D27>L011BU48@<H`aS0aS600<LiaBU5:D00aBU00<@Q0aS48@00QBU0Q2400<DYAS6
5:D00a240QBU00<@Q0aS48@00QS600@@Q1BU48@HaP@DY@0348@<H`aS008@Q00436<DYABU6<H25:D4
48@336<248@236<00a245:DDY@025:D448@011BU36<<H`aS0a240`aS00@@Q1BU48@@Q0<DY@D@Q0@<
H`8@Q0055:D@Q124248<H`0448@536<248@00`Q236<<H`0448@00`aS48@@Q00248@336<248@236<0
0`Q236<@Q00548@00`aS48@@Q00648@00aBU48@DY@0648@236<01PQ236<<H`aS48@<H`<@Q0035:D@
Q0aS008<H`8@Q08<H`03248<H`aS00<<H`05248<H`aS36<@Q00336<01A2436<@Q1245:D00a2400D<
Ha2448@<Ha2400<<H`8@Q0065:D@Q0aS48@<Ha240`aS00P@Q1BU48@@Q0aS48@HaQBU112400<<Ha24
36<01Q240`aS00<@Q0aS36<03PaS00<@Q0aS48@00Q240@aS00000`001240000212401@0012448@@Q
00000P@Q00HHaSF]:DXHaQcW6<H47>L36<H01QcW8@PQ21cW6<HLi`8Q20<HaP8Li`8HaP8Li`038@PL
iaS6008Li`058@PU:AcW7>LHaP037>L25:D00aS67>LHaP037>L00aS67>LLi`036<H35:D26<H25:D0
1aS65:DDYA245:DHaQBU008@Q0045:D@Q1BU5:D26<H01QBU7>LLib486<HDY@@HaP055:DHaQS66<HD
Y@0248@26<H011cW6<HHaQcW0QS600<LiaS67>L00QS600<DYAS66<H01AS60acW0R4800TLiaBU6<HD
YAS67>LDYA245:D00QS600<DYA245:D00QS600HLiaS67>LQ21cW8@P46<H011cW9BTU:B480aS600@U
:B488@PQ208Li`058@PU:BDY9BTLi`046<H011cW5:DHaQS60acW0aS600@DYAcW7>LLi`<HaP088@PU
:BU:8@PLiaBU6<HDY@<HaP047>LQ22487>L26<H28@P27>L00b487>LQ20028@P29BT01B487>LHaQcW
8@P00QS600PLib487>LDYAS67>LQ21cW0QS600<Q21cW8@P00QcW00HQ22DY:DXU:AS65:D236<00a24
36<<H`04248212400`Q212448@0:12400`0024848@03124020Q212448@00124000@Q000212400`00
12448@0212401@0012448@@Q00002P@Q10Q200<48@Q212403@@Q00@8@Q246<HHaP8DY@0336<@Q124
008<H`0648@DYA2448@DYAS61ABU00<@Q1BU5:D00Q2400@DYAS67>LHaP8DY@<HaP8DY@8@Q0045:DH
aQcW6<H55:D348@011BU48@@Q12411BU112400<<Ha246<H00QS600@DYA245:DDY@<@Q08DY@0348@D
YA2400<@Q0<DY@8@Q0035:D@Q12400<<H`8@Q00536<@Q12448@DY@0348@25:D248@00`aS48@@Q003
48@02@aS48@@Q12436<@Q0aS48@DY@0448@436<248@00`aS48@<H`0236<0212436<<H`aS48@<Ha24
36<348@236<00a2436<@Q00248@00`aS48@@Q00248@636<00a2436<<H`0348@010aS48@<HaBU1124
00H<Ha2436<@Q1BU48@25:D548@336<448@336<848@00aBU36<8@P0736<01A2436<8@PaS24801@aS
11240PaS00D@Q0aS48@<H`Q2008<H`0348@<Ha24008@Q0035:D<Ha2400<@Q0@<H`8@Q0055:D@Q124
48@<H`0:48@336<00a2436<@Q00636<00a2436<8@P0236<00a2436<<H`0236<248@336<000@48@03
00048@@Q00D48@087>LaS24848@HaR487>LQ208Li`036<HLiaS600<Li`<HaP<Li`035:DHaQcW00<H
aP8Li`<HaP8Li`039BTQ2248008HaP065:DHaQBU5:DHaQcW0aS60acW00<DYAS66<H01QS600<DYAS6
5:D00QBU0QS600@DYA2448@@Q0<DY@0348@DYABU00DHaP035:DHaQBU00@HaP035:DHaQS6008Li`<H
aP035:DHaQS600<HaP035:DHaQBU00<HaP045:DHaQS66<H25:D00aS67>LLi`029BT01B487>LDYABU
6<H01ABU00<HaQBU6<H00aS600<DYAS67>L00QcW00@HaQBU6<HDY@<Li`038@PU:AcW008HaP079BTY
BRDY7>LDYAcW:DX00Re[00<LiaBU6<H00aS60acW00<HaQBU6<H00acW0aS600@DYAS65:DHaP8Li`8Q
20047>LQ21cW7>L36<H27>L28@P02AcW5:DHaQcW9BTQ21cW5:DLi`028@P01bDY:DXU:BU:6<HLiaS6
008Li`038@PLiacW00<HaP047>LHaQS67>L36<H27>L00b487>LLi`025:D248@236<4248412400`Q2
1240000212400`0012448@0212400`0012448@0312400`0012448@0312400`0012448@0B12400`00
12448@0412400`002488@P02248=124010001248@PQ210aS00@8@PaS36<<H`<@Q08<H`0348@<Ha24
00HDY@0436<@Q12448@45:D00a245:DHaP025:D02A246<HDYA245:DHaR487>LHaP025:D348@25:D3
36<011BU48@DYABU0Q2400DDY@aS48@DYA24008HaP<@Q0LDY@036<HDYABU008<H`8@Q08HaP8@Q003
36<8@Q2400<<H`8@Q08<H`0448@DYA2448@25:D548@010aS48@@Q1240`aS00P@Q1BU48@<Ha2436<@
Q1BU0a241@aS0Q2420aS00<8@PaS48@00Q240`aS00<@Q0aS48@00`aS0a240PaS112400<<Ha2448@0
10aS0Q240PaS00<8@PaS48@00Q240PaS00H@Q0aS48@@Q0aS48@35:D248@01@aS48@<H`aS48@010aS
0Q240PaS0a2400<<Ha2448@010aS00<@Q0aS36<00PaS0PQ21PaS1A240PaS0a2400P<Ha2448@<H`Q2
36<@Q1BU0Q241@aS00<@Q0aS36<00PaS00@DYA245:DDY@@@Q0055:D@Q12448@DY@0248@00`aS48@@
Q00536<00`Q236<<H`0836<00a2436<<H`0336<348@12480000400048@@Q000412401`0012448@@Q
7>Le[BDY008DY@056<HLib488@PLi`036<H37>L01QS65:DHaQcW8@PLi`8HaP037>LHaQBU00@Li`04
5:DHaQS67>L28@P47>L46<H01ABU6<HHaQS67>L011S600<LiaBU6<H00aS600<DYAS66<H00QS60aBU
00@HaQBU5:D@Q0<DY@0648@DYAS66<HLiaBU11S60QBU0aS600DDYAS66<HLiaS6008DY@<HaP035:DH
aQS6008HaP095:DHaQS65:D@Q1BU6<HLiaS6008DY@<Li`<Q20<HaP8DY@8@Q0045:DHaQBU6<H35:D2
6<H011BU6<HHaQcW0aS600@DYAS66<HLi`8U:@067>LDYAcW8@PYBRDY0QS600PLibU:<H`YBQcW5:DL
iaS60QBU00HLib487>LHaQcW6<H27>L01ABU6<HDYAcW6<H00QBU00<Lib486<H00QcW00@U:AcW7>LD
Y@<HaP@Q20<HaP<Q20047>LHaQcW8@P39BT38@P27>L011S67>LLib4811S600@LiaS66<HLi`<HaP06
5:DHaQcW7>LQ21S60QBU0Q2400@<H`Q21248@P@48@0324848@0000L48@0400048@@Q000<12400`00
1240000212400`0012448@0612400`0012448@0212401@0012448@@Q24800P@Q00<000@Q24801@@Q
00@8@P@Q124000X48@88@P@@Q00336<8@Q24008@Q00536<8@PaS6<HDY@0248@00aBU48@@Q00236<0
11245:DDYAS611BU0QS60aBU0Q240QS60QcW0aBU00<@Q1BU5:D00Q2400LDYA2448@@Q1BU6<HDY@02
48@436<011BU6<HHaQBU0a240QBU00<HaQBU5:D00aBU1A240aBU00<@Q0aS36<00PaS0Q241@aS0aBU
0a2400HDYA2448@<Ha2436<548@236<348@00`aS48@<H`0248@436<348@436<348@236<00a2436<<
H`0336<248@536<348@00aBU48@@Q00236<348@436<00a2436<@Q00636<248@25:D348@01PaS5:DD
YABU48@<H`8@Q0D<H`0348@<H`aS008@Q08<H`03248@Q1BU008@Q0h<H`88@P0348@<H`aS008<H`8@
Q00336<@Q12400@<H`0348@<H`aS00<<H`8@Q0@<H`8@Q08<H`@@Q00336<@Q124008@Q0045:D@Q124
5:D648@236<00a2436<<H`0436<010Q236<@Q1240PaS00<8@PaS36<010aS0Q2400<<Ha2424800@aS
00021240200012448@@Q0008@P@Q0002124011S6=JdU:ABU11cW00<HaQcW7>L00QcW00<HaQcW6<H0
0acW00DQ21S67>LHaQBU008HaP8Li`8HaP037>LQ21cW008Q20056<HDYABU6<HLi`026<H01ABU6<HH
aQS65:D00aS60acW00<HaQBU6<H00QcW00<HaQBU6<H00QBU0aS60QBU00@@Q1S648@DY@8@Q0DDY@03
6<HLiaS6008DY@046<HDYAS65:D26<H011BU7>LLiacW0R4800<LiaS66<H01AS60QcW00<HaQBU6<H0
0aS60QBU00DHaQcW7>LU:B48008Li`8HaP8DY@<HaP8DY@036<HLiaS6008DY@8HaP8Li`DHaP087>LH
aQS68@PU:BU:9BTLi`8HaP8Q208Li`076<HU:CF]=Jd]JacW48@00QS600<DYAS67>L00QcW0QS600<L
iaBU6<H00aS60QBU0QS600PDYAS68@PQ21cW6<HLib480QcW00PHaQcW8@PU:B486<HDYAS611cW00<H
aQcW7>L00R480RU:00<U:B487>L00QcW00<Q21cW7>L00QS60QcW00<Q21S66<H00QS60QcW0QS60QBU
0a240PQ200<48@Q212400P@Q00<000@Q12400`@Q00<000@Q124010@Q00<000@Q12400P@Q00<8@P@Q
00001`@Q00<000@Q124010@Q00<000@Q12400P@Q00<8@P@Q12401@@Q00<000@Q12402`@Q00<000@Q
124010@Q00<000@Q124010@Q00D000@Q2488@PaS00<8@P0848@8@P@Q248<HacW6<HDY@8@Q00336<@
Q124008@Q08DY@0436<@Q1246<H55:D348@25:D02QS648@HaR487>LHaQ245:DHaQBU0PaS00D@Q1BU
48@DYAS600<DY@8@Q08DY@8@Q08DY@036<H@Q12400<DY@0548@DYA2448@DY@026<H02QBU48@<Ha24
5:D@Q1BU6<HDYA240PaS0a240`aS0Q240PaS00H@Q1BU48@@Q1BU48@336<248@236<348@336<348@4
36<00a2436<<H`0448@00`aS2488@P0736<00a2436<<H`02248236<00a2436<<H`0936<00a2436<<
H`0236<348@336<248@536<0112436<<H`aS0Q2400<<Ha245:D00QBU1A2400D8@PaS248<Ha24008<
H`8@Q0<<H`8@Q08<H`0348@<H`aS008<H`0948@<H`aS248<H`Q236<8@Q24008<H`0348@<Ha2400<<
H`D@Q00336<@Q0aS00D<H`0348@<Ha2400@@Q00336<@Q0aS008@Q0035:D@Q124008@Q08DY@0748@D
YA2436<@Q0aS48@010aS0a242`aS00@@Q0aS36<<H`8@Q0<<H`0348@<Ha240048@P0000D48@001244
8@0000L48@087>LaS2485:DLib487>LHaP8Li`038@PLiacW00@Li`036<HLiaS600<Li`036<HDYABU
008HaP8Li`<HaP047>LQ22487>L25:D26<H00aBU6<HHaP096<H00aBU6<HHaP036<H011BU48@DYABU
0aS61QBU00@@Q1BU48@@Q08DY@057>LHaQS66<HDY@026<H25:D011245:DHaQcW0aS600<Q21cW7>L0
0QBU0QS600<LiaS67>L00QS611BU00XHaQBU5:DDYAS67>LQ22DY8@PLi`8HaP077>LHaQBU48@DYAS6
5:D00QS600<LiaS66<H00QBU1aS600@LiaS67>LHaP8Li`8U:@067>LHaQS67>LU:B480QcW00DU:C6<
>Lh]JaS6008DY@036<HDYAS6008Li`8HaP8Li`046<HDYA245:D46<H011BU6<HQ21cW0R480acW0QS6
0QcW00@Q22DY7>LLi`<HaP047>LQ21cW7>L26<H01R489BTYBRe[9BTQ20<Li`038@PLiaS600HLi`8H
aP057>LQ21cW5:DHaP035:D236<2248236<612400`0012448@0212401@0012448@@Q00002P@Q00<0
00@Q124020@Q00<000@Q124020@Q00<000@Q12401@@Q00<8@P@Q124020@Q00<8@P@Q24800`@Q00@0
00@Q124000848@0324848@@Q00<<H`0324848@Q200848@0536<@Q1cW7>LDY@0648@25:D448@011S6
5:DDYAS60aBU0Q240QBU0QS600DDYAcW7>LHaQBU008HaP0448@<H`aS5:D26<H00aBU36<@Q0035:D3
48@65:D36<H00aBU48@<H`0248@25:D01AS648@<Ha245:D00QS60QBU0a240PaS0Q240PaS00<8@PaS
36<00a240aBU112400@<Ha2448@<H`8@Q08<H`@@Q08<H`<@Q0D<H`<@Q005248<H`aS248<H`0248@0
0`aS248<H`0236<010Q236<<H`aS0Q240PaS00@8@PaS36<<H`<@Q08<H`8@Q0<<H`8@Q0@<H`8@Q006
36<8@PQ236<@Q0aS0a240`aS0QBU00DHaQBU48@@Q0aS008@Q00536<8@PaS36<@Q00236<00a2436<<
H`0236<01A2436<<H`aS48@00`aS00@@Q0aS36<<H`8@Q00336<8@PaS00L<H`<@Q08<H`055:D@Q0aS
36<8@P0336<0112436<@Q1240`aS0a240PaS0Q2400@DYA2448@@Q08DY@@@Q0035:D@Q12400<<H`04
48@<Ha2436<548@536<00a2436<8@P0348@236<348@00`aS48@@Q00136<0000300048@@Q00848@05
00048@@Q1240000212401ABU;F/LiaS68@P00acW00DU:Be[8@PLiaS600@Li`8HaP037>LHaQS6008D
Y@8Li`8U:@038@PLiacW00@HaP045:DHaQS65:D26<H27>L00aBU6<HDY@046<H00aBU6<HHaP036<H0
0acW6<HHaP025:D26<H00acW6<HDY@045:D00aS65:DDY@035:D26<H35:D36<H011BU48@@Q1BU0QS6
00HDYAS66<HQ21cW6<H27>L00aS65:DDY@026<H01ABU6<HHaQS65:D00aS60QBU00<HaQcW9BT00R48
00LLiaS66<HLib486<HDY@0248@36<H45:D011S65:DHaQS60QcW0aS600DLib485:DHaR48008]J`03
9BTHaQS600DLi`086<HLib488@PLiaS65:DLi`8HaP045:DHaQS66<H25:D26<H00aBU6<HDY@045:D2
7>L00b489BTQ20027>L011S68@PQ22480RDY00<Q21S66<H00QcW00<DYAS66<H00R4800<Lib488@P0
0bDY12480acW00@U:AcW6<HHaP8Li`8HaP087>LQ22486<HDYA2436<@Q08<H`0624848@Q224848@00
0P@Q00<8@P@Q12400P@Q00<000@Q12400P@Q00<000@Q124010@Q00<000@Q12401P@Q00T000@Q1244
8@001248@P@Q00000P@Q0`Q20P@Q0PQ210@Q00<000@Q12401`@Q00D000@Q12448@0000d48@032484
8@@Q00848@88@P041248@PaS2483124010aS248@Q1BU0Q2400<DYA2448@00PaS00<@Q1BU5:D01124
11BU00<@Q0aS48@00aBU00@LiaS66<HHaP8@Q0035:D@Q1BU008DY@<@Q08HaP@DY@<@Q0DDY@8HaP04
48@<H`aS48@45:D0112436<@Q12410aS00@@Q0aS36<<H`<DY@8@Q0<<H`@@Q00536<DYABU48@8@P02
36<448@236<00a2436<@Q00248@936<348@336<00`Q236<@Q00836<0112436<<H`aS0Q2400H<H`Q2
248<Ha2436<448@010aS48@<H`aS0a2400DDYA2436<<Ha24008<H`0348@<H`aS008<H`095:D<H`aS
36<DYAS65:D@Q1BU008@Q00336<@Q1BU00<@Q0T<H`D@Q088@P8<H`0448@<H`aS48@336<010Q236<<
H`aS0Q2410aS0a2400<DYA2448@00Q2420aS11240PaS00<@Q1BU48@00PaS00<@Q1BU5:D00a2400@<
Ha2436<DY@D@Q0065:D@Q0aS36<8@PaS0a240`aS00@8@PaS36<8@P@<H`0448@DYA2448@236<448@0
00<48@0300048@@Q00H48@066<HaS2485:DLib480QS600DQ22DY9BTLiaS600@Li`8HaP8Li`<DY@03
7>LQ22DY008Q208HaP<Li`036<HDYAS6008HaP035:DHaQcW00@HaP037>LHaQcW00DHaP035:DHaQS6
008HaP035:DHaQS6008Li`8HaP8DY@036<HDYABU00DDY@8HaP065:DHaQBU5:DHaQBU0QS60QBU00<@
Q1S65:D00QcW00<Q21cW7>L01AS60aBU00PHaQcW6<HHaQ245:DHaQBU0QS600DLib488@PQ21cW00<H
aP038@PLiaS6008DY@<HaP<DY@036<HLiaS6008HaP037>LHaQS6008HaP8Li`036<HDYBDY008]J`04
8@PDYAcW8@P77>L28@P76<H01QcW6<HHaQBU6<HDY@<HaP<DY@0348@HaQcW008U:@8Li`8HaP048@PL
iaS67>L28@P00acW6<HLi`027>L26<H01b487>LQ21cW8@PU:B48008YBP038@PLiaS6008Li`038@PL
iaS6008HaP8Li`036<HLiacW008Q20056<HDY@aS36<@Q00236<2248=12400`0012448@0212400`00
12448@0512400`0012448@0612400`0012448@0412400`0012448@03248212400`0012448@061240
0`0012448@041240100012448@Q230@Q00@000@Q12448@<8@P031248@PQ20088@P848@03248<Ha24
00L@Q00536<@Q1245:DHaP0448@25:D248@25:D00a246<HHaP026<H00aBU6<HDY@025:D248@35:D0
0a245:DDY@025:D011245:DDY@aS0Q240QBU00<@Q1BU5:D00QBU11240QBU0Q2400@DYA2448@<H`@@
Q0055:D@Q0aS248<H`0248@00`aS248<H`0648@00aBU48@@Q00236<01@Q236<@Q0aS5:D00a2410aS
00<@Q0aS36<00PaS00@@Q0aS36<<H`D@Q00336<8@PQ2008<H`0448@<H`aS36<248@436<00`Q236<@
Q00248@01PQ236<@Q0aS248<H`@@Q00536<@Q0aS36<@Q0025:D248@00`aS248<H`0236<00a2436<@
Q00336<0112436<<Ha240aBU0Q2400<DYA2436<00a2410aS00@8@PaS36<@Q0<<H`8@Q0T<H`0548@<
H`aS248<H`0248@00`aS248<H`0248@236<448@00aBU48@<H`0236<548@236<648@236<00a2436<<
H`0248@25:D548@00`aS48@@Q00248@236<00a2436<<H`0348@536<010Q236<<Ha240PaS1A2400@<
Ha2448@@Q08<H`0000D000@Q12448@0000D48@0600048AS6<H`Q21BU0QcW00PHaQcW9BTU:B487>LH
aQcW0R480QcW0aS60QBU00@HaR489BTQ20@HaP@Li`DHaP8DY@<HaP035:DHaQcW008HaP055:DHaQcW
5:DHaP028@P02AS65:D@Q1BU7>LHaQcW6<HDY@026<H00aBU6<HDY@027>L01R487>LHaQ246<HDY@8@
Q08DY@056<HDYA245:D@Q0046<H37>L46<H011cW6<HDYA240aBU11S600TDYAS66<HHaQcW8@PYBR48
7>L00aS600<DYAS65:D011S611BU11S60QcW0aS600DQ21cW6<HHaQcW008YBP059BTLiaBU5:DHaP03
7>L00aS65:DHaP028@P00acW6<H@Q0026<H45:D26<H01QcW6<HHaQS65:DHaP8DY@036<HDYAS600DL
i`048@PLiacW8@P29BT00b486<HHaP027>L26<H011BU7>LLib480acW0RDY0RU:00<Q22DY7>L00aS6
00<Lib487>L00aS60QcW00DHaQ245:D@Q0aS0088@P@48@0424848@@Q000212400`0012448@071240
0`0012448@061240100012448@002@@Q00<000@Q124010@Q00H8@P@Q12448@aS24841242248<1240
0`001248@P0212400`Q212448@031240100012448@Q21P@Q00@8@PaS36<8@P<48@03248<H`aS00<8
@P0336<DYAS6008DY@0336<@Q1BU008DY@036<HDYA24008@Q0055:D@Q1245:DHaP035:D011S65:D@
Q1240aBU00<@Q1BU6<H00aBU0aS600<DYA2448@00Q240QBU00H@Q1BU5:D@Q1S65:D236<00a245:DD
Y@025:D848@010aS248<H`aS0QBU00H@Q0aS36<<Ha245:D248@00`aS48@@Q00248@236<348@236<0
11245:D@Q1240PaS112410aS0Q240PaS00@@Q1BU48@8@P8<H`88@P0336<@Q12400<<H`0348@<H`Q2
00<<H`<@Q00336<@Q0aS00D<H`<@Q0065:D@Q12448@<Ha240PaS00<8@PaS36<010aS0Q241@aS1124
0QBU0a2400DDYA2436<<Ha2400D<H`0348@<Ha2400<<H`8@Q0<<H`08248<H`aS36<@Q0aS248<H`8@
Q00436<8@PaS48@336<448@010aS48@<Ha241PaS11240PaS0Q2400<DYA2448@0112400@DYA2448@@
Q0<<H`<@Q08<H`0748@8@PaS36<@Q1BU48@00PaS00D@Q0aS36<<Ha2400<<H`8@Q0<<H`0448@<Ha24
36<548@136<000848@0400048@@Q0006124021S6;F/Q21246<HQ21S67>L39BT011cW6<HHaQcW0R48
0QS600<LiaS65:D00QS600<Q22DY8@P00QcW00DDYAS67>LQ21cW00<HaP057>LDYAS65:DLi`035:D0
1AS68@PLiacW5:D00aS600@LiaS66<HHaP@DY@086<HLiaS66<H@Q1BU6<HDY@<HaP057>LHaQBU5:DH
aP025:D01Q245:D@Q1S65:DHaP@DY@036<HDYAcW008Li`8HaP065:DHaQcW7>LHaQBU0Q2400DDYAS6
6<HHaQBU00<HaP037>LDYAS600<U:@8HaP8Li`056<HDYABU6<HDY@026<H011cW5:DDYAS60QcW0QS6
0R4800THaQBU6<HLiaS67>LHaQcW8@P00RDY00<Q21S65:D00acW00hHaQBU5:DLib489BTHaQ245:DH
aR487>LDYA240QBU0QcW0QS60QBU00D@Q1BU6<HHaQBU008HaP048@PLiaS67>L38@P39BT47>L66<H2
7>L38@P29BT00b489BTU:@028@P26<H27>L00b487>LHaP026<H011cW6<HDYAS60Q2410Q20P@Q00<0
00@Q124020@Q00<000@Q12401P@Q00D000@Q12448@0000L48@0324848@@Q00848@0300048@@Q00@4
8@<8@Ph48@0500048@@Q124000041240100012448@Q21@@Q00<000@Q00000P@Q00P8@P@Q12448@00
24848@aS0`Q200<48@Q2248010Q20PaS00<DYAS65:D00PaS00@@Q1BU48@@Q08HaP045:D@Q0aS48@3
5:D00aS65:DHaP025:D36<H00a2436<<H`035:D26<H35:D01QS65:DDYA2436<DY@<@Q00336<@Q1S6
008DY@L@Q00336<@Q124008@Q08<H`0348@<H`aS008<H`8@Q0D<H`@@Q08<H`<@Q00336<@Q0aS00<<
H`8@Q0055:D@Q0aS48@DY@0248@00`aS48@<H`0236<248@00`aS48@@Q00736<248@536<0212436<<
H`Q236<@Q0aS48@436<00a2436<@Q00348@236<448@01@aS48@@Q12424800PaS0a240`aS00<@Q0aS
36<00PaS0Q240QBU112400<DYA2448@020aS0Q2400<<Ha2448@00Q240PaS00<8@PaS36<00PaS00L8
@PaS36<@Q0aS48@<H`0248@536<25:D01a2436<@Q1BU48@<H`Q2008<H`<@Q00336<@Q12400<@Q08<
H`D@Q0045:D@Q12436<648@00`aS48@@Q00536<248@00`aS48@<H`0336<00a2436<<H`0436<448@4
36<348@136<00003124000@Q00H48@0700048@@Q6<H]Jb486<H00acW0b4800<LiaS66<H00R4800@L
iaS66<HHaP8Li`8HaP047>LQ21cW7>L66<H00acW6<HHaP026<H00acW6<HHaP025:D26<H00aBU6<HL
i`026<H00aBU6<HLi`036<H00aBU6<HHaP036<H27>L00aS65:DDY@025:D36<H27>L00aS65:DDY@03
6<H00a245:DDY@035:D26<H00acW6<HDY@037>L00aS65:DDY@046<H01ABU48@DYAS65:D011cW0aS6
0QcW0b480QcW00<HaQBU5:D00Q2400DDYAcW7>LHaQBU00<HaP8Li`8Q20<HaP037>LHaQS600<HaP05
7>LU:BU:9BTLi`036<H011BU6<HHaQS60QcW00<HaQcW6<H00QS600<LiaS65:D00QS600@LiaS66<HD
Y@PHaP<Li`046<HLiaS66<H27>L02B489BTU:B487>LDYAcW6<HLi`046<H27>L00b487>LQ20039BT0
0b487>LLi`026<H47>L022486<HDYAS65:DHaQBU36<4248312401PQ212448@@Q0008@P@48@030004
8@@Q00T48@0724848@001248@P@Q00002@@Q00@000@Q1248@P<48@88@P031248@P@Q00848@042484
8@@Q1242248612400`0012448@0312400`0012448@0312400`aS24848@0;12401@Q21248@PQ21240
0`Q20P@Q0`Q20P@Q00<8@P@Q24800Q2400PDYAS648@@Q1BU7>LQ21S60Q240aBU00@HaQBU6<HDY@8H
aP045:D@Q12448@35:D00a245:DDY@026<H01aBU48@DYA245:D@Q1BU00<@Q08DY@036<H@Q12400<@
Q0<DY@0748@<Ha2448@DYA245:D00a2400@<H`Q236<<H`<@Q08<H`8@Q0035:D@Q0aS00<<H`0348@<
H`aS00<@Q08<H`<@Q00536<@Q1BU48@<H`0248@236<00`Q236<<H`0448@011BU48@<H`Q20`aS00D@
Q0aS48@@Q0aS008@Q08<H`88@P0436<@Q12448@2248236<0112436<<H`aS0Q240PaS00@@Q1BU48@@
Q08<H`8@Q08<H`05248<Ha2448@<H`0348@236<00`Q236<@Q0025:D248@00`aS48@@Q00448@336<0
0a2436<<H`0236<00a2436<@Q00936<01PQ248@@Q0aS48@8@PD<H`0348@<Ha24008@Q08<H`0348@D
YA2400<<H`0448@8@PaS36<348@236<021245:D@Q12436<@Q1BU48@236<648@011BU36<8@PaS0a24
0`aS00<@Q0aS36<01PaS00<@Q0aS36<00`aS00<@Q0aS48@00a240`aS0Q240ABU0A240@aS00031240
0`001240000612401aBU<H`U:ABU6<HQ21cW00<U:@048@PHaQS66<H37>L021S67>LLiacW6<HDYAS6
8@P37>L01AS67>LHaQcW6<H00acW00<HaQBU5:D00QcW00@HaQBU6<HHaP<Li`086<HDYAS67>LQ21cW
6<HDY@@HaP035:DHaQS600THaP@Li`045:DHaQBU48@25:D00aS65:DDY@026<H01acW6<HLiacW6<HL
iaS6008Li`056<HDYAcW7>LHaP045:D01aS67>LLiacW6<HDYAS600<Li`8Q208Li`036<HLiaS6008@
Q0035:DHaQS6008HaP8DY@8HaP055:DLib488@PLi`036<H02acW6<HLiacW5:DLibDY:DXU:AcW5:D0
0QS60QBU00<@Q1S66<H00QcW00@HaQBU5:DDY@@HaP8Li`036<HDYAS6008Li`@HaP8Li`056<HLib48
8@PHaP025:D27>L01248:DXYBR480aS600DLiaS65:DDYAcW008HaP037>LQ2248008Q20039BTYBRU:
008Li`8HaP037>LHaQcW008U:@038@PHaQBU008HaP045:D<H`aS36<3248312400`0012448@031240
0`0012448@0<1240100012448@001@@Q00<000@Q124020@Q0`Q21@@Q0PQ21@@Q0PQ20P@Q00<000@Q
12401@@Q00<000@Q12400P@Q00<8@P@Q12400`@Q00@000@Q124000@48@0324848@@Q00848@<8@P84
8@88@P<48@D8@P0336<DYAS600<@Q08HaP067>LHaQS65:DHaQBU0QS600DLiaS66<H@Q1BU008@Q08D
Y@086<HDYABU5:D@Q1BU48@DY@8HaP8DY@0448@DYA2448@45:D01A245:DDY@aS48@00aBU112400<D
YA2448@00PaS0a240`aS0Q2410aS11BU0a240`aS00<@Q1BU48@00PaS0Q2400<<Ha2448@011241`aS
0a241@aS00<8@PaS36<00PaS00<8@PaS36<00Q240PaS00@8@PaS48@@Q0L<H`04248<Ha2448@336<2
48@00aBU48@@Q00248@436<248@010aS48@<H`aS0PQ20Q2400H<Ha2448@@Q1BU48@45:D248@436<2
48@010aS48@<Ha2410aS00D@Q0aS36<<H`Q200<<H`8@Q0D<H`0548@<H`aS48@<H`0348@236<448@4
36<348@02@aS48@DYABU48@<Ha245:D@Q00236<648@01ABU48@@Q0aS48@00PaS00<@Q0aS36<00PaS
112410aS00@@Q0aS36<8@P8<H`@@Q00336<@Q12400<<H`04248@Q1245:D148@0000300048@@Q00H4
8@0800048@@Q5:D]Jb485:DLi`8HaP037>LQ2248008Li`036<HLiacW008HaP047>LHaQS66<H37>L0
1AS67>LHaQS67>L00QBU00@HaQcW8@PQ208HaP<Li`8DY@8HaP8Li`8DY@8HaP8Li`036<HLiaS600<L
i`8HaP037>LQ2248008HaP0448@DYAS65:D26<H00acW6<HHaP046<H00aBU6<HDY@025:D01A245:DH
aQS67>L00QS600<LiaS65:D00QBU0QS600DLiaS66<HHaQcW008HaP8DY@076<HLiaS66<HDYAS67>L0
0b4800<HaQBU5:D00QBU00@HaQcW5:D@Q0@DY@8HaP<Li`@HaP035:DLiaS6008HaP087>LQ21cW6<HQ
22U:;F/U:@8HaP0548@DYABU5:DHaP027>L012487>LHaQcW0aS600@LiaS66<HHaP8Li`036<HDYABU
00<HaP045:DHaQcW7>L28@P26<H25:D021S68@PQ22487>LHaQcW6<H25:D00aS67>LHaP026<H00b48
7>LLi`027>L48@P47>L01R489BTQ21S648@DY@8HaP0348@8@PaS0088@P@48@0324848@@Q00@48@06
00048@@Q00048@Q22@@Q00@8@P@Q124000D48@0300048@@Q00d48@0424848@Q22487124224821240
0`0012448@0212400`00124000071244248612401@001248@P@Q24800`@Q10Q20`@Q1@Q210@Q00L8
@Q2448@@Q1BU6<HLi`036<H02AcW8@PQ21cW5:D@Q1BU6<HDY@0248@01PaS5:DHaQBU6<HDY@<@Q003
5:DHaQBU008DY@0548@DYA2448@DY@0448@25:D348@35:D248@00aBU48@@Q00248@011BU48@@Q124
0PaS0a2400@<Ha2448@@Q08HaP8@Q00336<DYABU00@@Q08<H`D@Q00436<@Q1245:D248@01`aS48@@
Q12436<@Q0aS00D@Q0@<H`<@Q08<H`8@Q0D<H`<@Q00436<@Q0aS48@536<00a2436<<H`025:D01124
36<@Q1240aBU0Q2420aS00<8@Q2448@00a2400@<Ha2448@<H`8@Q08DY@8@Q0@<H`0348@<H`aS008<
H`8@Q0<<H`03248<Ha2400@<H`0348@<H`aS00L<H`0348@<H`aS00H<H`<@Q0@<H`0548@<H`aS48@D
Y@0248@00`aS48@@Q00236<948@01PaS48@@Q12436<@Q0<<H`@@Q00436<@Q12448@236<01@Q236<<
H`aS48@01@aS0Q2400@<Ha2436<@Q0<<H`<@Q00000D48@0012448@0000L48@086<HaS1cW48@HaQcW
6<HLi`8Q20037>LHaQcW00@Li`<HaP037>LHaQS600<Li`036<HDYAS6008DY@067>LQ22488@PHaQcW
1AS60QBU0QS60QcW00HDYAS66<HHaQcW6<H37>L01AS65:DHaQS68@P00QcW0QBU0QS600TDYA246<HQ
21cW6<HDYAcW6<H00QBU0QS60QBU00H@Q1BU6<HLib487>L26<H00aBU6<HHaP025:D56<H35:D26<H0
0acW6<HHaP027>L01ABU6<HHaRDY8@P00acW00@HaQBU5:DHaP8DY@8@Q0@HaP037>LQ21cW00@HaP8L
i`056<HDYAS67>LQ20026<H02bDY;F/aS2U:5:DHaQ245:DHaQBU6<H00QcW00<Q21cW6<H00QBU00<H
aQcW6<H00QS60QcW00<Q21S66<H00QBU00<LiaS67>L00QS600<Q21cW7>L00aS600<DYAS68@P00R48
00<HaQBU6<H01aS60b4800@LiaS67>LQ208U:@038@PHaQcW008Li`<Q20077>LDYAS66<HDYA2436<0
0PQ20P@Q00<8@P@Q248010@Q00<000@Q124020@Q00@000@Q124000848@0324848@@Q00@48@030004
8@Q200D48@0400048@@Q248612400`Q21248@P081243248512400`Q212448@061240100012448@@Q
0PQ20P@Q00D000@Q00048@0000@48@88@P<48@88@P03124000@Q00<8@P0336<8@PQ200<48@88@P04
48@<HaBU5:D36<H00aBU6<HHaP028@P00acW5:D@Q00248@25:D248@25:D011cW6<H@Q1241aBU0a24
00DDYA2448@<Ha2400@DY@0348@DYABU008DY@0348@DYA2400H@Q00336<@Q124008<H`04248<Ha24
48@236<00a245:DDY@0548@336<248@01@aS48@<HaBU48@00PaS1A241@aS00@@Q0aS48@<H`<@Q0<<
H`0348@<H`aS00@<H`0648@DY@aS36<8@PaS0a240`aS0Q241@aS00H@Q0aS36<<Ha2436<248@00aS6
5:D@Q00436<348@536<00a2436<<H`0236<00aBU48@@Q00548@236<248@336<448@336<248@636<0
0a2436<<H`0336<00a2436<<H`0436<00a2436<@Q00236<00a2436<@Q00236<0112436<<H`aS0Q24
00<<Ha2448@00Q240PaS00<@Q0aS36<00Q2400@DYA2448@DY@H@Q08<H`0448@<H`aS36<348@00`aS
48@<H`0336<248@236<00a2436<<H`0348@336<00a2436<<H`0348@236<000848@0500048@@Q1240
000212401`0012448AS6;F/Q212400@HaP<Li`8HaP8Li`058@PHaQS65:DHaP037>L36<H27>L00aS6
5:DHaP027>L00b487>LLi`036<H37>L56<H27>L36<H00acW8@PQ20026<H011BU7>LQ22DY0QcW00<D
YAS66<H00aS600<LiaS67>L00aS600<DYAS66<H00QBU00<@Q1S66<H00QBU00@HaQcW7>LLi`@DY@8H
aP037>LHaQS600@HaP@Li`046<HLiaS66<H27>L01B487>LHaQS67>L00QBU00<@Q1BU5:D01QBU00DH
aQcW7>LLiaS600<Li`<HaP095:DHaQS67>LQ22DY8@PHaQcW008U:@047>LDYABU6<H35:D26<H28@P0
1AcW6<HLiaS65:D00aS60QBU0acW0QBU00@HaQBU6<HHaP8Li`<HaP037>LHaQS6008Q20049BTQ21S6
6<H25:D27>L01B487>LHaQcW6<H00QcW124811cW00<Q21S68@P00RU:00DLiaBU48@DYA240088@P03
1248@P@Q0088@P@48@0324848@@Q00H48@0400048@@Q000A12400`001240000512400`Q212448@02
124010Q2124000@Q1@Q210@Q0`Q21P@Q00L000@Q00048@00124000041240100012448@Q22P@Q0PQ2
10@Q1`Q200D<H`Q224848@Q200<48@<8@P0:1248@Q245:DLiaS648@DYAcW8@P46<H00acW5:DDY@02
48@55:D011S65:DHaQBU0QS600PDYA2448@@Q1BU48@DYA2411BU0a2400@HaQcW6<HDY@8@Q0035:D@
Q124008DY@0448@<H`aS36<348@00aBU48@@Q00248@00aS65:D@Q00248@011BU48@<H`aS212400<<
Ha2448@011240PaS2A2410aS0a240PaS0a241`aS0Q2400<<Ha2436<010aS0a240PaS00L@Q0aS36<8
@PaS5:DHaP025:D00a2436<<H`0236<01A2436<<H`aS48@010aS00<@Q0aS36<00PaS1A240PaS0Q24
1@aS0QBU0Q240PaS00<@Q0aS48@00`aS1A240PaS00@@Q0Q236<<H`8@Q0T<H`0348@<H`aS00L<H`06
48@<H`aS36<@Q0aS0a240`aS1A2400@<Ha2448@@Q0<<H`0548@<H`aS48@<H`0248@436<248@236<0
0a2436<<H`0348@336<248@436<348@12480000300048@@Q00848@0300048@@Q00@48@035:D]Jb48
00<HaP045:DHaQcW8@P46<H00bDY8@PHaP025:D021S67>LQ21S67>LHaQBU6<H25:D26<H27>L28@P0
11S65:DDYAS60R480acW0aBU1AS600<Lib487>L00QcW00DHaQcW8@PQ21cW008HaP055:DHaQS66<HD
Y@036<H27>L56<H00aBU6<HDY@056<H27>L36<H00aBU6<HHaP037>L00aS65:DDY@056<H27>L01248
6<HHaQS611cW0aS600DDYA245:DDYAS600<DY@036<HDYAcW008HaP057>LQ21cW6<HDY@046<H011BU
6<HQ22DY0QcW00DQ22DY9BTLia2400<DY@8HaP047>LHaQS67>L28@P00acW6<HHaP046<H27>L01248
6<HDYABU0QS600@DYAS67>LLi`<HaP<Li`@Q208Li`036<HDYAS6008Li`036<HDYABU008Li`059BTQ
22488@PLi`028@P02aS65:DLiacW:DX]Jb487>LDYA245:D00Q240PQ200<48@Q212401@@Q00@000@Q
124000l48@0300048@@Q01448@0524848@@Q1248@P03124010Q236<8@PQ20P@Q00<000@Q124010Q2
00<48@0012402P@Q00<000@Q12402@@Q00<000@Q00000P@Q0PQ20`@Q0PQ200D<H`Q212448@Q200<<
H`<48@0300048@@Q0088@P0:36<8@P@Q248DYAcW6<HDYAS67>L28@P00aS65:DDY@026<H00acW48@@
Q00248@25:D01AS65:D@Q1BU6<H00QBU0Q240QBU0a2400DDYAS648@DYA24008DY@0448@DYABU6<H2
5:D011245:D@Q1BU0Q240PaS00D8@PaS48@@Q1BU00<<H`0448@DYA245:D248@01ABU48@@Q12436<0
0a240PaS1Q2400<DYA2436<00`aS0Q2400DDYA2436<<Ha24008DY@H<H`0748@<Ha2436<@Q1BU48@0
20aS112410aS00D@Q0aS36<<Ha24008<H`<@Q08HaP0348@<H`aS00<@Q08<H`8@Q00536<@Q0aS36<@
Q00236<0112436<<H`aS1a241@aS00H@Q1BU48@@Q0aS48@236<00a2436<<H`0336<00a245:D@Q007
36<00aBU36<<H`0636<348@01ABU36<<H`aS24800PaS00<DYA2436<00PaS00<@Q0aS48@00a2410aS
00<@Q1BU5:D01Q241PaS0a240PaS00@8@PaS48@@Q0@<H`L@Q08<H`<@Q0D<H`0000D48@0012448@00
00L48@035:DaS2DY00@HaP047>LHaQS66<H37>L01AS67>LHaQBU6<H00acW00<HaQBU6<H01QS60acW
00<Q21cW6<H00QcW0R4800DLiaS67>LHaQBU008HaP057>LHaQcW7>LQ20037>L012489BTU:B481QcW
00DHaQcW8@PLiaS6008DY@036<HLiacW008Li`<DY@046<HLiaS66<H27>L00aS65:DHaP056<H00b48
7>LLi`027>L26<H00aBU6<HLi`037>L00aS67>LLi`037>L01QS67>LLiaBU48@DY@<HaP035:DHaQBU
008DY@036<HLiacW00<Li`046<HDYAS67>L35:D00aS68@PLi`028@P27>L46<H00aBU6<HDY@026<H0
0aBU6<HHaP046<H37>L01AS65:DHaQcW6<H00QBU00<HaQBU6<H00QS600<LiaS66<H01AS60b4800<L
iaS66<H00aS600@LibDY8@PLi`8HaP<Q208Li`036<HLiacW00<Li`048@PYBRU:8@P348@236<010Q2
1248@PQ210@Q00<8@P@Q12401`@Q00<8@P@Q12400P@Q00<000@Q12403`@Q0PQ20`@Q00<8@P@Q1240
0`@Q00<000@Q12400`@Q00L000@Q2488@PaS24800003124224891240100012448@001`@Q0`Q20P@Q
00<8@P@Q12400`@Q00@8@P@Q2488@P@48@04248<Ha2436<412401PQ212448@Q21248@P<48@06248<
H`aS248<Ha2411S60QcW0QS600<LiaS65:D0112411BU0Q2411BU00<HaQBU5:D01ABU00@HaQBU5:D@
Q0@DY@@@Q08DY@<@Q00536<@Q0aS36<@Q0035:D448@45:D00a245:D@Q00448@00aBU48@DY@0448@2
5:D248@436<348@236<348@236<00a2436<@Q00236<010Q236<<H`aS0a240PaS00<@Q0aS48@01124
0`aS00<@Q0aS36<00PaS00<@Q0aS48@00Q240`aS0Q2400<<Ha2436<00Q241@aS00<DYA2436<00PaS
00<@Q0aS36<00PaS00<@Q0aS36<00Q2400<<Ha2448@00a240PaS0a2400@DYA2448@<H`8@Q0@<H`8@
Q00436<8@PaS36<248@010aS48@<Ha241`aS0PQ20a2400<<H`Q224800PaS0Q2420aS00DDYA2448@@
Q0aS00@@Q08DY@0648@<Ha245:D<Ha240PaS00@@Q0aS48@@Q08<H`@@Q00336<8@PaS008<H`@@Q0<<
H`8@Q0055:D<H`aS36<8@P0236<148@136<000848@0300048@@Q00@48@0<00048@@Q6<HaS2DY5:DL
iaS65:DHaQBU0QcW00@HaQcW7>LLi`DHaP047>LHaQBU5:D36<H27>L02AS65:DHaQS68@PLiaS67>LH
aP027>L00aS67>LHaP046<H77>L022487>LLib489BTQ21cW6<H27>L26<H47>L01QS65:DHaQcW8@PH
aP8DY@<HaP8DY@056<HLiacW6<HLi`046<H011BU6<HLib480acW00HHaQBU5:DHaQcW8@P87>L26<H0
0acW6<HHaP025:D26<H25:D26<H01ABU48@HaR487>L00QS600<Lib486<H00aS60aBU00@Lib488@PL
i`8HaP8Li`8DY@0348@DYABU00@HaP037>LHaQS6008HaP<Li`HHaP037>LHaQS600@HaP038@PLiacW
008DY@8HaP067>LQ22487>LHaQBU0aS60acW00DQ21cW7>LQ22DY008Q20047>LQ22487>L26<H01ABU
8@PU:BU:8@P00aS600<@Q0aS24800PQ21`@Q00<8@P@Q12405P@Q00@8@P@Q00048@<8@PD48@032484
8@@Q00<48@0324848@@Q00@48@04248<H`Q22484124010Q212448@Q21@@Q00<000@Q124010@Q00<0
00@Q12402`@Q00D000@Q12448@Q200<48@@8@P051248@PQ236<8@P0512400`Q212448@0212422482
36<01PQ236<@Q1BU6<HDY@8HaP8Li`048@PLiaS648@236<02Q245:DDYABU6<H@Q1BU48@HaQBU0a24
00@HaQBU48@@Q0LDY@0348@DYABU00@DY@036<HDYABU008<H`8@Q0<<H`8@Q0035:D@Q124008@Q08D
Y@0348@DYA2400<DY@0348@<Ha24008@Q0035:D@Q12400<@Q0035:D@Q0aS008@Q00336<@Q0aS00<@
Q0<<H`0548@<H`aS248<H`0248@436<348@336<248@00`aS48@@Q00248@236<00a2436<<H`0436<4
48@436<548@336<00a245:D@Q00936<01Q2436<<H`aS48@<H`<@Q0<<H`0348@<H`aS008@Q0035:D@
Q12400<@Q0L<H`@@Q0<<H`0448@<H`aS248536<01@Q236<<H`aS48@00PaS00@@Q0aS36<8@P8<H`8@
Q0<<H`03248<H`aS00<@Q0<<H`8@Q0035:D@Q1BU008DY@0348@<Ha24008<H`0348@<Ha24008<H`03
48@<Ha2400<@Q00336<@Q0aS008@Q0<<H`8@Q08<H`8@Q0D<H`0348@<H`aS0048@P0000@000@Q1240
00848@0;0008@P@Q124000@Q6<HaS2485:DLi`026<H011BU7>LQ21cW0QS600DLiaS66<HDYAS600@Q
20046<HDYAS65:D27>L26<H011BU6<HLib480QcW00@HaQcW5:DHaP<Li`048@PHaQcW7>L28@P27>L4
8@P27>L29BT01B486<HDYAS68@P011cW00<HaQBU6<H00acW21S600<DYAS66<H011BU00<HaQBU6<H0
0aS61AcW00<HaQcW6<H00QS61acW1QS600<DYAS66<H00QS60aBU00DHaQcW6<HLiaS6008Li`@HaP0:
5:DHaQcW7>LDYAS68@PYBRDY7>L46<H25:D76<H57>L012487>LLiaBU0QS60aBU00<HaQcW7>L00R48
00<LiaBU6<H00QcW0QS600@Lib488@PHaP<Li`8HaP057>LHaQS67>LQ2002:DX38@P00acW6<HHaP03
6<H38@P011cW48@@Q12410Q20P@Q00<000@Q12403@@Q00<000@Q12400`@Q00<000@Q124010@Q00<0
00@Q12401P@Q00L8@P@Q12448@Q21248@P08124324831242248412400`Q21248@P0612400`0036<<
H`02248<12400`Q21248@P041245248010@Q2488@PQ20Q2400<8@P@Q12401`@Q00H8@P@Q12448@00
1242248020aS2488@PaS48@DYAcW5:D27>L26<H011245:DDYAS60QBU00@@Q1S65:DDY@<@Q0@DY@05
48@DYABU5:D@Q0025:D011S65:D@Q1240aBU00<HaQ2448@00Q2400<DYA245:D01Q240`aS00@@Q1BU
5:DDY@@@Q0036<HDYABU008HaP035:D@Q12400D@Q0<DY@8@Q0@<H`8DY@0348@<H`aS00@@Q00336<@
Q12400@<H`0748@<H`aS48@<Ha2436<00a240PaS00<@Q0aS48@00`aS0a2400<<Ha2436<00`aS00<@
Q0aS48@00a240`aS0Q2400@<Ha2448@@Q0<<H`0348@<H`aS00D<H`<@Q0<<H`0448@DYA2448@236<0
1Q2436<@Q1BU48@<H`8@Q00536<@Q0aS36<@Q00236<00`Q236<8@P0236<010Q236<<Ha240`aS00<@
Q0aS36<01`aS0a2400@8@PaS48@@Q08<H`0348@<H`aS008<H`<@Q0<<H`0348@<H`aS008@Q0055:D@
Q12448@DY@0248@236<00a2436<<H`0336<348@236<248@436<248@436<248@01@aS48@<H`aS2480
1@aS000412401@0012448@@Q00000`@Q00@HaS6<9BTHaP8Li`035:DHaQcW008Li`8DY@8Li`046<HL
iaS67>L28@P01acW6<HDYAS67>LQ21cW008HaP<Li`8HaP037>LQ21cW008HaP8Li`048@PHaQS65:D2
7>L28@P37>L28@P27>L00b48:DXQ20026<H37>L00aBU7>LLi`027>L01aBU6<HLiacW8@PLiaS6008D
Y@HHaP035:DHaQBU00DHaP047>LQ21cW7>L26<H27>L012486<HHaQS60QcW0QS60R4800@LiaS66<HH
aP<DY@@HaP055:DHaQBU6<HDY@036<H28@P27>L25:D26<H011cW6<HHaQS60R4800DYBR487>LHaR48
008HaP045:DHaQS66<H25:D011cW6<HLiaS60acW00DQ21cW7>LLiaS600<DY@DHaP037>LQ21cW00<H
aP047>LHaQS67>L38@P27>L021BU6<HLiacW8@PLiaS68@P29BT00acW8@PLi`027>L26<H25:D01AcW
9BTQ21cW5:D00Q240PaS0PQ20P@Q00<8@P@Q12401P@Q00D000@Q12448@0000848@0324848@0000P4
8@0300048@@Q00D48@0324848@Q200848@0524848@@Q24848@02248;12442484124236<01@Q21244
8@@Q24800P@Q0PQ200@<H`@Q124000@48@0500048@@Q00048@0324800`@Q00048@0312400`Q21248
@P0524800`aS48@8@P0312400`Q212448@0312400`002488@P0412400`aS24848@02248010aS5:DH
aQS60acW00XHaQBU5:DDYA246<H@Q1S65:DHaP8DY@8@Q0LDY@0548@DYAS67>LDY@0248@01ABU6<HD
YABU48@011BU00@HaQ2448@@Q0<DY@@<H`8@Q0<DY@<@Q08DY@0548@HaQS66<HLi`0448@011BU36<<
HaBU0QS600@DY@aS36<<H`@@Q00336<@Q12400<<H`<@Q0065:D<H`aS248<HaBU0Q2400@<Ha2436<<
H`D@Q00636<@Q0aS48@<Ha240PaS112410aS0Q2410aS0Q240`aS00<@Q1BU48@01`aS00<@Q0aS36<0
0PaS00D@Q0aS36<@Q0aS00H@Q00436<@Q12448@25:D448@736<448@00`aS48@@Q00348@00`aS248<
H`0536<348@00`aS48@@Q00236<01@Q248@<H`aS48@01@aS0a240`aS00<@Q0aS48@00a2400DDYA24
5:D@Q0aS00@@Q0@<H`8@Q08<H`0748@<H`aS248<Ha245:D00a242PaS0Q240@aS0@Q200000`001240
000612401`0012448AS6<H`Q2124008Li`8HaP<Li`036<HDYAS600<HaP047>LQ21cW6<H27>L46<H0
1QcW6<HHaQS67>LHaPHLi`<HaPDLi`038@PLib4800@Li`8Q208Li`<HaP057>LQ21S66<HDY@026<H0
0aBU6<HLi`027>L25:D46<H011cW6<HHaQ241QBU0QS600@Lib487>LLi`8HaP048@PU:B487>L26<H2
7>L00aBU6<HHaP028@P011cW6<HDYABU11S600<DYAS66<H00aBU00DHaQBU6<HDYAS6008Li`048@PL
iaS65:D26<H01acW6<HHaQBU48@HaRDY008YBP057>LDYAS66<HDY@066<H00aBU6<HLi`026<H00acW
6<HLi`027>L36<H011BU6<HHaQS60QcW0R481AS600<DYAS66<H00QcW00PHaQcW7>LQ21cW6<HDYAS6
0QcW0R480RDY00DQ21S66<HDYAS6008Li`048@PLiacW6<H248@5248212400`0012448@0212400`00
12448@0212401@0012448@@Q00000`@Q00@8@P@Q124000P48@0300048@@Q00848@0324848@@Q00<4
8@0524848@Q224848@0624831243248312400`Q236<8@P041242248512400`Q212448@0312401000
12448@000P@Q00D8@P0012448@000088@P0336<48@@Q00<48@0424848@Q2248336<248@224831240
0`0012448@0<124020Q236<8@PQ21248@PaS5:D248@01aS67>LQ22486<HDYA24008DY@056<HDYABU
5:D@Q0045:D448@75:D011S648@DYA240aBU00@HaQBU5:DDY@<@Q08DY@0448@<H`aS36<25:D848@2
5:D00aS65:DDY@035:D348@35:D248@00`aS48@@Q00348@01@aS48@@Q0aS48@00PaS00@@Q0aS48@@
Q0X<H`8@Q00336<@Q124008@Q0H<H`<@Q0<<H`@@Q0<<H`0348@<Ha24008@Q0P<H`0448@<H`aS2484
36<348@01@aS248<H`aS5:D00`aS00<DYA2448@00a2400@DYAS66<H@Q08<H`8@Q0P<H`0348@<H`aS
008<H`<@Q0@<H`05248<H`aS36<@Q00336<348@236<0112436<@Q0aS112400T<Ha2448@@Q0aS48@<
Ha245:D00a240QBU0Q240PaS00<@Q0aS36<00PaS00@@Q1BU48@@Q0H<H`0348@<H`aS008<H`<@Q003
36<@Q0aS00<<H`8@Q08<H`48@P001@@Q00<000@Q124010@Q00@Lic6<8@PDY@8Li`<HaP8Li`076<HL
iacW6<HDYAS67>L00R480acW0QS611cW0aS61AcW0QS600@LiaS66<HHaP8Li`076<HQ22489BTQ21cW
6<H00QcW00<Q22DY9BT00aS600@Lib487>LLi`<HaP077>LHaQBU7>LQ21cW6<H00QBU00DHaQBU6<HH
aQcW008HaP045:DHaQBU5:D248@01QS67>LLiaBU6<HLi`8Q208Li`088@PLiacW7>LQ21S65:DHaP<Q
20DHaP<DY@8Li`046<HDYABU5:D26<H25:D011S68@PLiacW0aS600DDYAcW7>LLiaS6008DY@077>LU
:Be[:DXQ21BU6<H00QcW00LHaQBU5:DDYAS67>LHaP025:D011S67>LQ22480QcW00<HaQcW5:D00QBU
00THaQcW5:DDYAcW8@PU:AcW6<H00QcW0QS600@DYAcW6<HHaPPLi`8HaP067>LQ22U::DXU:AcW0QBU
0QcW00<DYAcW7>L00QcW0QBU0`aS0PQ20P@Q00@8@P@Q124000T48@0300048@@Q00<48@0324848@@Q
00D48@0300048@@Q00X48@0424848@Q22482124324800`@Q24848@02124010Q212448@Q20P@Q00<8
@PaS36<00`@Q00<8@P@Q12400P@Q10Q22`@Q00<000@Q12400`@Q0PQ210@Q0PQ200<48@Q224800PQ2
00@<Ha245:D<H`@8@P848@0300048@@Q00<48@0524848@@Q1248@P04124010Q21248@PQ20PaS00@@
Q1BU48@HaP<Li`065:D@Q1BU5:DHaQBU0Q240QBU0Q2400@DYAS65:DDY@8@Q0045:DHaQS66<H25:D2
48@00aBU48@DY@025:D011S65:DDYABU0Q2400<DYA2448@00Q240`aS00<@Q0aS5:D00QBU00<@Q0aS
36<00QBU00D<HaBU5:DHaQBU00<@Q00336<@Q12400<DY@<@Q0<<H`0348@<Ha2400@@Q00636<8@PaS
48@DYA2410aS0a240`aS0Q2400<DYA2448@010aS00<@Q0aS36<00PaS0a2400<<Ha2436<01`aS0Q24
0PaS00H@Q0aS5:D@Q0aS48@436<248@636<348@336<748@25:D348@00aBU48@@Q00636<0112436<@
Q1240`aS00<8@PaS36<00Q241`aS00<@Q0aS48@010aS0a2400<<Ha2448@00Q240PaS0Q2400D<Ha24
48@@Q0aS008@Q0035:D@Q1BU008DY@8@Q0<<H`0348@<H`aS008<H`@@Q00336<@Q124008@Q08<H`@@
Q0T<H`8@Q04<H`48@P48@P0000<000@Q00000`@Q00<000Q212400`@Q00DLic6<8@PDYAS600HLi`0;
6<HLib487>LHaQBU6<HLibDY8@PLi`025:D00aS65:DHaP046<H011cW6<HLiacW11S600@LiaS65:DH
aP8Li`046<HLib488@P26<H00acW8@PQ20037>L46<H00acW8@PHaP026<H00aBU6<HHaP037>L35:D0
1Q247>LLiacW6<HDY@8HaP@DY@@HaP037>LQ21cW008HaP035:DLiacW008Q20<Li`036<HDYAS6008L
i`036<HDYABU00<HaP045:DHaQBU5:D36<H011BU7>LLiacW0aBU00<Lib486<H00aS600/LiaS67>LD
YAS67>LHaR489BTQ22DY00LHaP8DY@036<HDYABU008DY@8Li`038@PLiaS6008Li`<DY@8HaP<Li`0>
8@PU:AcW7>LHaQcW6<HDYAS68@PU:B486<HDY@DLi`<HaP037>LQ22DY008Q208HaP<Li`069BTQ2248
7>LHaQBU0PaS0`Q210@Q00<000@Q12406`@Q00D8@P@Q12448@0000H48@<8@P8<H`0324848@@Q0088
@P@48@88@P848@03248<H`Q20088@P@48@0324848@Q200<48@0524848@@Q1248@P0312400`Q21244
8@0512400`001248@P0236<324800`aS24848@02248236<26<H00a2436<48@0=1242248212400`00
1248@P0524802P@Q248<H`aS48@DYAS68@PLiaS60Q2411BU00<@Q1S66<H00QcW0QBU0Q240QBU0aS6
0Q240aBU0Q2400<DYAS66<H00QBU00<@Q1BU5:D00a2400DDYA2448@<H`Q2008@Q0045:D@Q12436<2
48@00`aS5:DDY@026<H25:D011245:DDYA240aBU0a240PaS0Q2400<<Ha2448@00a240`aS00@@Q0aS
36<<H`8@Q00536<8@PaS36<@Q00236<448@01@aS48@DYABU48@00`aS0Q241@aS00<8@PaS48@00Q24
00H<Ha2436<@Q0aS48@236<0112436<<H`aS0Q240`aS0Q240`aS00@8@PaS36<<H`<@Q0H<H`<@Q003
36<@Q12400HDY@0348@DYA2400`<H`0348@<H`aS00<@Q08<H`0548@<H`aS248<H`0>48@236<010Q2
48@@Q1240PaS112400H<Ha2448@DYA2436<348@436<348@236<00a2436<@Q00248@236<348@536<0
1Q2436<<H`aS248<H`8@Q048@P0010@Q00<000@Q12400P@Q00P000@Q124LicW>9BT@Q1cW11S611cW
00HQ21cW6<HHaQBU7>L38@P011S65:DLiacW1QS60acW00<HaQcW6<H00aS600PQ21S66<HHaQcW8@PU
:AcW0QS600<Lib488@P011cW00@HaQcW7>LLi`DHaP035:DHaQBU00<HaP045:DHaQcW7>L76<H00aBU
48@DY@026<H00acW6<HHaP037>L36<H37>L26<H012487>LHaQS60QcW00DHaQBU6<HLiaS600<DY@@H
aP095:DHaQS67>LHaQBU48@DYB48008HaP045:DHaQcW5:D37>L021S65:DHaQcW8@PU:B487>L26<H0
0aBU6<HHaP025:D00aS65:DDY@025:D26<H47>L00aS65:DHaP026<H35:D01aS68@PU:BDY7>LHaQBU
008HaP0548@HaRDY9BTQ20026<H012487>LQ224811cW0QS60acW00HHaQBU6<HLib489BT37>L26<H2
48@00`Q212448@0812400`001240000C12400`0012448@0=124324800`@Q24848@0224800`@Q2488
@P032482124624841242248412400`Q212448@0612400`Q212400007124224800`@Q248<H`022482
124324836<H010Q212448@Q21@@Q0PQ22@@Q0PQ200@<H`Q212448@D8@P045:D@Q1cW7>L26<H248@3
5:D248@011BU6<HQ21S60aBU00L@Q1BU5:DDYAcW6<HDY@0248@25:D348@011BU6<HDYABU212400H<
Ha245:D@Q1BU36<448@236<00a245:DHaP045:D448@01ABU48@@Q1BU48@00PaS00<@Q0aS36<00PaS
00<@Q1BU48@01PaS00<@Q0aS48@00Q240PaS00@8@Q2448@<H`<@Q08<H`0348@DYABU00@<H`<@Q08<
H`0548@<H`aS36<@Q00836<248@736<348@336<224801PaS48@@Q12436<@Q0<<H`04248<Ha2436<6
48@55:D248@636<248@336<248@336<00a2436<<H`0536<00`Q236<<H`0248@336<00aBU48@@Q002
36<01A245:D@Q0aS48@00PaS00<@Q0aS48@00a2400D<HaBU48@DYA2400@<H`03248<H`aS008<H`04
48@DYA2436<224801A2436<@Q0aS48@01`aS00<@Q0aS36<020aS00000`0012448@0212400`001244
8@0412401QcW<H`U:ABU7>LHaP<Li`038@PLiacW00@HaP058@PLib488@PLi`036<H00acW6<HLi`05
7>L00aS67>LHaP047>L46<H00acW6<HLi`038@P00acW6<HHaP038@P011cW6<HDYABU11S600PDYAS6
6<HDYAS65:DHaQBU1AS600HLib488@PLiaS67>L36<H25:D01AS67>LHaQS65:D011S61AcW0R481AcW
0aBU1QS600<DYA246<H00QcW00PHaQBU5:DDYAS67>LHaQBU0aS600<DYAS67>L011S60bDY00<Q21cW
6<H00QS600<DYAS66<H00QS600<DYAS66<H00aBU00THaQBU7>LLib487>LHaQBU6<H00QBU0QS60b48
00LU:AcW7>LHaQBU6<HLi`028@P27>L28@P27>L28@P01AcW6<HHaQcW8@P011cW0QS600dDYAS6:DX]
JbDY7>LDYAS65:D<H`@Q24848@02248212400`001248@P0@12400`Q212448@0212400`Q212448@08
12401@0012448@@Q248010@Q10Q200<48@Q212401`Q200<48@Q212400PQ21P@Q0`Q200<48@Q21240
10@Q00<<H`Q2248010Q200<<H`Q212401`@Q00<8@P@Q248010Q200<000Q236<00QBU00D@Q0Q22484
8@Q200T48@88@P<48@0324848@@Q00848@04248<Ha2436<2124224800`@Q248<H`036<H00acW6<HL
i`035:D248@00aS65:DDY@065:D011S65:DDYABU112411BU0QS60QBU1Q2400<<Ha2448@00aBU1124
0`aS0a2400@DYAS65:DDY@<@Q0@DY@0448@<H`aS36<448@436<248@01`aS248<Ha245:D@Q0aS0088
@P8@Q0@<H`0348@<H`aS008<H`045:D@Q12448@336<348@00`aS48@@Q00336<248@336<348@00`aS
48@<H`0248@010aS48@@Q1240`aS00@@Q0aS36<8@PD<H`0348@<Ha24008@Q0<<H`0648@<Ha2436<@
Q0aS0Q240QBU00D@Q1S66<HHaQBU00D@Q00536<8@PaS36<@Q00236<248@336<01a245:D@Q0aS48@<
Ha2400<<H`8@Q08<H`@@Q00536<@Q12448@<H`0248@236<010Q236<<Ha240`aS0Q2400D<Ha2448@D
YA2400@<H`0348@<Ha2400@@Q0<<H`@@Q00636<@Q0aS48@<Ha2420aS00<@Q0aS36<00@Q2000010@Q
00048@0020@Q00DHaSF]9BTDYAS600<Li`048@PLib487>L36<H47>L01B487>LLiaS65:D00acW00<H
aQcW6<H01AcW1AS60QcW00@HaQBU6<HLi`8U:@8Li`8HaP087>LQ22DY7>LHaQBU6<HLi`8HaP035:DH
aQS600DHaP<DY@036<HLiaS600@Li`8HaP067>LHaQS65:DHaQBU21S61acW00<HaQcW7>L00QcW00@D
YAS65:DHaP@DY@8HaP057>LHaQBU5:DLi`026<H25:D011S67>LLiaS60QBU00HHaQcW6<HLiaS68@P2
7>L012487>LQ21cW0QS600@DYAS66<HHaP8DY@046<HDYABU6<H35:D011S67>LQ21S60QcW00@HaQBU
5:DDY@<HaP8Q20DLi`056<HLiacW8@PLi`058@P011cW8@PLiaS61AcW00XQ21cW7>LHaQ246<HU:C6<
:DXHaP8DY@8@Q00436<8@PQ2000512400`001240000712400`0024848@0312400`Q212448@051240
0`Q212448@0=12401@Q212448@Q236<00PQ200@48@Q22488@P8<H`88@P848@@8@P0336<8@P@Q0084
8@0324848@@Q00@8@P848@03248<H`Q20088@P051248@PaS36<8@P0212400`Q212448@0212400`Q2
1248@P0236<224802`aS24848@@Q36<HaQBU36<8@PaS24800P@Q00@000@Q2488@P<48@0324848@Q2
0088@PL48@8@Q00436<48@Q2248212400`Q236<Li`066<H25:D00a245:DDY@036<H00a245:DDY@02
6<H35:D011S65:D@Q1240QBU00<@Q1BU48@00QS600DDYA2448@@Q1BU00<@Q0036<H@Q0aS008@Q004
5:D<H`aS36<248@236<348@26<H011BU48@@Q0aS0QBU0QS600TDY@aS36<8@PaS48@<Ha2436<00Q24
00<<Ha2448@010aS11240`aS0Q240`aS112400<<Ha2448@00Q2410aS00D@Q0aS36<<Ha2400P<H`03
48@<H`aS00<@Q00336<8@PaS008@Q00436<8@PaS36<248@536<00a2436<@Q00348@736<0112436<@
Q0aS11BU00L@Q1BU5:D@Q1BU36<@Q00536<248@00`aS48@@Q00248@236<00a2436<<H`0636<748@2
36<548@236<010Q236<@Q0aS0Q2400<<Ha2436<00a240aBU00@@Q0Q236<@Q08<H`<@Q00436<@Q124
48@236<00a245:DDY@0348@336<448@336<01@Q236<<Ha2436<00@Q2000412400`0012448@021240
3`0012448AcW<H`Lia246<HLiaS67>LHaR487>LQ20026<H01QcW8@PQ22DY6<HDY@8HaP8Q20DLi`06
8@PLib488@PLib480QcW1AS60QBU00@Lib487>LHaP8DY@8Li`058@PLiacW6<HLi`046<H01ABU6<HD
YABU6<H00QcW0aS600@LiaS67>LLi`8Q208Li`058@PLiaS65:D@Q0046<H25:D46<H77>L26<H01248
7>LLiaS60QBU00D@Q1S66<HLiaS6008DY@036<HLiacW008HaP055:DHaQBU48@DY@037>L011S65:DH
aQBU0aS600/LiaS68@PU:B486<HDYAcW8@PLiaS6008DY@8HaP<DY@8HaP075:DHaQS67>LHaQBU7>L0
0R4800DLiaS66<HHaQBU008Li`0>9BTQ21S66<HLiaS67>LDYA246<HQ22DY7>LHaP8Q208HaP037>LQ
21cW008Li`8Q20077>LHaQS66<HDYAS67>L00R4800<HaQBU48@00PQ200<<H`Q2248030@Q00<000@Q
00001@@Q00D8@P@Q12448@0000P48@0324848@@Q00l48@0324848@Q20088@P031248@P@Q00L8@PX4
8@0424848@Q2248536<00a2436<8@P0224801@aS2488@P@Q248010@Q00<8@P@Q12400P@Q0`Q200P4
8@Q212448@Q248@DY@aS0P@Q0`Q200<<H`@Q12401@@Q00@8@P@Q1248@P<48@0324848@@Q00848@07
36<8@P@Q1248@P@Q24800P@Q00L8@PaS7>LQ21cW6<HDY@037>L00aS65:DDY@0248@25:D00aS65:DD
Y@045:D01A245:D<Ha245:D00aS600<@Q1BU5:D00Q2400@<Ha245:DDY@8@Q0065:D@Q1245:D@Q1BU
2Q240QBU0a240aBU0Q2400<<Ha2448@00`aS00<@Q0aS36<00Q2410aS00@@Q0aS48@<H`@@Q00436<@
Q12448@736<348@336<248@436<00a2436<@Q00248@436<00a2436<<H`0348@00aBU48@@Q00236<5
48@636<248@436<248@236<00a2436<@Q00336<448@00aBU6<HLi`026<H548@00`aS248<H`0436<3
48@236<248@25:D336<00a2436<<H`0348@236<011BU48@<H`aS0a240`aS0Q2400<<Ha2436<00`aS
1Q240`aS00<8@PaS36<00`aS00H@Q0aS48@@Q0aS48@336<25:D448@00aBU48@<H`0236<01A2436<<
H`aS24800Q240PaS000010@Q00048@0020@Q00DLibe[8@P@Q1BU00<HaP8Li`038@PLiacW008Li`8U
:@037>LDYAS6008Li`8Q208Li`8HaP8Q20<Li`048@PLiaS65:D46<H25:D00aS67>LLi`027>L01AS6
5:DHaQcW8@P00QcW21S60QBU0QS60QcW00@HaQBU6<HHaP<Li`8Q208Li`8HaP0348@DYABU008HaP03
5:DHaQBU00@HaP@Li`8Q20046<HLiacW7>L28@P00aBU6<H@Q0045:D36<H35:D36<H25:D00a246<HH
aP027>L00aS65:DHaP046<H37>L01bDY7>LHaQS68@PU:AcW008DY@8HaP055:DHaQBU6<HDY@046<H0
0acW6<HHaP027>L00b487>LHaP036<H37>L00aS67>LQ20027>L02QS65:D@Q1cW8@PU:AcW6<HLib48
0acW00HU:AcW6<HHaQcW8@P37>L011S648@HaQS60RDY00@Q21BU48@<H`<8@P051248@P@Q1240000?
12400`0012448@0212401@Q212448@@Q24802@@Q00<8@P@Q12400`@Q00P8@P@Q12448@Q21248@P@Q
0PQ20P@Q0PQ200<<H`Q224801`Q21P@Q00<000@Q124010Q20PaS112410Q200D<H`Q224848@Q200<4
8@0324848@@Q00@8@P0300048@@Q00848@0336<@Q12400<8@P848@0724848@@Q124000@Q00002P@Q
00<8@P@Q12400PQ200<<H`Q224800P@Q00<8@P@Q12400PaS00XLib488@PLiaBU6<HQ21cW5:D@Q0LD
Y@046<H@Q1BU5:D26<H348@65:D0112436<@Q1240QBU00D@Q1BU5:D@Q1BU008@Q0055:D@Q1BU48@D
Y@0448@55:D348@011BU48@DYA241@aS0Q2400D<Ha2448@DYA2400<<H`035:D@Q12400D@Q0<<H`04
48@<H`aS36<248@236<00a2436<<H`0636<00a2436<@Q00236<348@010aS48@@Q1BU0`aS112400D<
Ha2436<@Q0aS00@@Q0<<H`<8@P8<H`0348@DYABU008@Q08<H`0748@<H`aS36<@Q0aS48@00PaS0Q24
00<HaQBU6<H00aS60QBU00@@Q0aS48@8@PH<H`L@Q00436<@Q1BU48@236<248@336<00a245:D@Q002
36<648@00aBU48@@Q00248@236<348@236<348@236<00a2436<<H`0436<248@336<348@236<848@0
10aS48@<Ha241PaS0@Q200000`0012448@0212400`0012448@0212402`00124HaS6<8@PDYAS67>LH
aQcW8@P00acW00@DYAS68@PQ208Li`0;6<HLib488@PLiaS67>LHaQcW8@PLi`028@P27>L021S67>LL
iacW6<HDYAS65:D36<H00acW6<HLi`037>L56<H27>L26<H25:D86<H37>L011S67>LLib480RDY00<Q
21cW6<H00aBU00<HaQBU6<H00aBU0QS600DDYAS67>LQ21cW008HaP8Li`8HaP047>LHaQcW6<H348@0
11BU6<HHaQBU0QS60acW0QS600DDYA246<HHaQcW008HaP048@PU:BDY7>L26<H01QcW6<HU:BU:9BTL
i`8HaP@Li`046<HDYAS66<H25:D011246<HHaQS60QcW0aS61QcW0aS600@LibDY7>LLi`8HaP057>LH
aQBU5:DLi`028@P00aS67>LLi`087>L46<H02AcW6<HLiacW8@PYBRDY7>LDY@0236<00`Q21248@P03
24800`0012448@0I1242248612400`Q212448@0312401PQ212448@Q21248@P<48@0324848@Q200d8
@P@48@0924848@Q2248<H`Q236<DYAS600<Li`056<H@Q1BU5:D@Q00336<424841242248912422482
48@00`Q212448@0212400`Q212448@0812400`001248@P0;124010001248@PQ20P@Q00D8@Q247>LL
iaS600<Li`036<HDYA24008@Q0@DY@0:48@HaQBU5:D@Q0aS48@HaQBU6<H35:D448@00`aS48@@Q002
6<H25:D00a245:DDY@0348@01ABU48@@Q1245:D00a240aBU0a240aBU0Q2400<DYA2448@00Q240PaS
0Q2400DDYA2448@@Q1BU008<H`8@Q0065:D@Q12448@<Ha240`aS0Q240`aS0Q2400@8@PaS36<@Q0@<
H`0348@<H`aS00<<H`0448@<Ha2448@336<00aBU48@@Q00236<348@010aS48@@Q1BU0Q2400<<Ha24
48@00Q240`aS00@8@Q2448@@Q0<<H`8@Q0<<H`8@Q0@<H`0848@DYA245:D@Q1BU6<HDY@<@Q08<H`@@
Q08<H`D@Q08DY@<@Q08DY@8<H`0348@DYABU008@Q0075:D@Q1245:D@Q1BU48@00PaS00H@Q0aS36<<
Ha2436<348@236<00`Q236<<H`0548@836<01A245:D@Q12436<00Q2400@DY@aS36<<H`8@Q00536<@
Q1245:D@Q00336<248@010aS2488@PaS0@Q2000412400`0012448@0512401QS6;F/LiaBU6<HLi`8H
aP037>LU:B48008Li`038@PLiacW008Li`038@PLiacW008HaP@Li`038@PU:B4800<Li`038@PLiacW
00<HaP035:DHaQS6008DY@057>LQ22486<HDY@056<H27>L26<H011cW6<HHaQBU0QS600<DYAS67>L0
0QcW00PHaQcW7>LLiaS67>LQ22DY0QcW00@Q21cW5:D@Q08DY@046<HDYABU5:D36<H011BU6<HLib48
1aS60acW11BU00@HaQBU5:DDY@@Li`8HaP047>LDYABU48@46<H021cW9BTLiacW5:DLiaS67>L28@P2
9BT00acW6<HHaP028@P01AS65:DDYAcW6<H01ABU0QS600<LiaS65:D00QS60acW00<Q21cW6<H00QS6
0R4800XLiaS66<HHaR486<HDYAS67>LQ208Li`048@PLiacW6<H37>L26<H37>L02aS67>LHaQS67>LH
aQcW:DXU:B4848@01@Q20P@Q00<000@Q12401P@Q00<000@Q12401`@Q00<8@P@Q124010@Q00<8@P@Q
24800P@Q00<8@P@Q12400P@Q00<8@P@Q12400P@Q0PQ210@Q00<8@P@Q12400`@Q3@Q200<48@Q22480
20@Q00@8@Q2448@DY@<Li`036<H@Q0aS008<H`8@Q088@P848@0524848@@Q1248@P0212400`001244
8@0412400`002488@P0236<224801@aS2488@P@Q248010@Q00@000@Q124000D48@0300048@@Q00P4
8@0424848@Q2248212401@Q248@LiacW6<H00acW00<HaQBU5:D00Q2421BU0a240QBU0QS600<DYA24
48@00Q2400<<Ha2448@011BU0Q240QBU00<@Q0aS5:D00QBU00D@Q0aS48@@Q1BU00<@Q08DY@<@Q0<D
Y@0848@<H`aS48@<Ha2436<8@P<@Q0<<H`0348@DYA2400D@Q00336<8@PaS008@Q08<H`8@Q0<<H`03
248<H`aS00P<H`8@Q0<<H`8@Q0D<H`<@Q08<H`T@Q00736<@Q12448@<H`Q212400`aS0Q2400<<Ha24
36<00`aS0Q2400<<Ha2448@00PaS00@@Q0aS5:DDY@8HaP8DY@0448@<H`aS36<248@236<00a2436<<
H`0336<448@35:D010aS48@@Q1BU0Q2400<<Ha245:D00QBU0Q2400@DYA2436<<H`<@Q00436<@Q124
48@236<01A2436<@Q12436<00Q241@aS00D@Q0aS36<@Q0aS008@Q08<H`0448@<H`aS36<348@236<0
0a2436<<H`0448@636<00`Q236<<H`012480000300048@0000<48@0400048@@Q000212401QS6;F/H
aQ247>LQ20<Li`049BTLiacW6<H37>L01QS67>LLiacW8@PLi`8HaPLLi`8Q208Li`036<HLiacW008H
aP035:DLiacW008HaP038@PLiacW00DHaP095:DHaQcW8@PHaQBU48@DYAcW00@HaP035:DLiacW00DL
i`096<HDYAS68@PLiaS65:DHaQcW008HaP045:DHaQS66<H45:D36<H00acW6<HHaP036<H35:D00a24
5:DHaP026<H25:D36<H37>L00aS65:DHaP046<H011cW5:DHaR480RDY00<LiaBU6<H00QcW00TQ22DY
8@PLiaS648@DYAS68@P00QcW00@HaQcW6<HHaP8DY@8HaP037>LHaQBU00<HaP037>LHaQcW008HaP05
5:DHaQS67>LQ20067>L26<H01AcW6<HQ22487>L00QS60R480QcW0QS600<LiaS67>L011S600H@Q1S6
:DXaS2DY5:D236<010Q212448@Q20`@Q00<8@P@Q12400`@Q00@8@P@Q1248@PT48@0300048@@Q0084
8@0600048@@Q248000@Q0PQ200<<H`Q224800PQ20PaS1@Q21P@Q00@8@P@Q12448@D8@P031248@PQ2
00H8@PH48@0C36<@Q1S648@HaS6<AS5:DSW>=JdicSF];F/HaQBU48@DYA2436<00PQ200<48@001240
0P@Q00<8@P@Q12400`@Q00<000@Q12400`@Q0PQ200@48@Q21248@PD48@0500048@@Q124000051240
10Q212448@0010@Q00<8@P@Q24801P@Q00P8@P@Q1248@Q247>LQ21cW0RDY00@LiaBU48@@Q0@DY@@@
Q0035:D@Q1BU008HaP055:D@Q0aS48@DY@0448@25:D01a2436<@Q1BU7>LHaQBU00<@Q0045:D@Q124
48@25:D01A245:DDYABU48@00QBU00<HaQBU5:D00Q2400H<Ha2436<@Q0aS248248@25:D348@25:D3
36<25:D00a2436<@Q00548@00`aS48@<H`0248@236<2248248@436<01PQ236<<H`aS48@<H`8@Q0@<
H`065:D@Q12436<@Q0aS0Q240QBU2A2400H<Ha2436<<H`Q236<448@00`aS48@<H`0436<348@436<0
21BU48@@Q1BU48@<Ha2436<248@01PaS48@<HaBU48@HaP8DY@8@Q00336<DYABU00<DY@0348@DYA24
00<@Q0036<HLib48008Q208Li`@@Q0075:D@Q12436<@Q0aS48@00`aS0Q240PaS00T@Q0aS36<<Ha24
36<@Q0aS24800PaS0Q240`aS0Q2400@<Ha2448@@Q0<<H`0448@<Ha2448@336<01a2436<<H`Q236<@
Q0Q2008<H`4@Q048@P000`@Q00<000@Q12401P@Q00PHaRe[8@PDYAS67>LHaQcW0R480QcW00LHaQcW
8@PQ21cW5:DHaP028@P00acW6<HLi`037>L26<H27>L28@P27>L01aS67>LLiaS65:DHaQcW008HaP@L
i`036<HLiacW00<HaP047>LQ21cW6<H35:D26<H00acW6<HHaP0:7>L00b487>LLi`066<H00aBU6<HD
Y@026<H25:D66<H25:D37>L01AS648@@Q1BU48@01AS600HDYAcW8@PQ21cW6<H25:D36<H01acW6<HD
YAcW8@PYBR48008HaP8Li`036<HQ22DY008Q20045:D@Q1S66<H28@P36<H27>L36<H37>L25:D00aS6
5:DHaP027>L01AS67>LHaQBU6<H00QcW00<Q21cW7>L00QcW00DQ21cW5:DDYAS6008Q20@Li`058@PL
iaS67>LQ20027>L02aS65:DHaQcW5:D@Q1cW:DXaS2U:48@00PaS0`Q20`@Q00<8@P@Q12406P@Q0PQ2
00@48@Q22488@P<48@03248<H`Q20088@P<48@0924848@@Q24848@Q21248@P@Q00X8@P<<H`D48@08
24848@aS48@HaPaS6<HaS096<@8e[@07>LhaS2DY6<HLiaBU48@00`Q200<48@Q2124020@Q0PQ21`@Q
00<8@P@Q12401`@Q00<000@Q00001@@Q00<000@Q12401@@Q00@8@P@Q124000848@88@P0:1248@PQ2
24848@Q236<LibDY8@P29BT011cW5:D<HaBU11240aBU0a240QBU00DHaQBU6<H@Q1BU00@@Q0055:DH
aQS66<HDY@0248@45:D248@35:D0212436<@Q1246<HDYA245:D248@01ABU6<HDYAS648@00`aS0Q24
0PaS00@@Q1BU5:DDY@P@Q08DY@D@Q00336<@Q0aS008<H`0548@<Ha2436<@Q00436<248@536<248@0
10aS48@<Ha240`aS0Q240`aS0Q2400@DYA2436<<H`D@Q00436<@Q0aS248236<248@436<0112436<<
H`aS0Q240`aS0Q240`aS0Q240aBU112400<<Ha2436<011240QBU00<@Q0aS48@00Q240QBU00PHaQBU
5:D<Ha2436<@Q1cW0b4800HLiaS65:DDYA245:D348@236<248@011BU48@@Q0Q20`aS00<@Q0aS36<0
0`aS0Q2400@<Ha2436<8@P8<H`0348@<H`aS00@@Q0@<H`0448@<Ha2448@536<00a2436<@Q00636<1
2480000300048@@Q00848@0300048@@Q00848@0800048AcW;F/Lia247>LQ208Li`038@PU:BDY008L
i`8HaP<Li`038@PLiacW00<Li`038@PLib4800PLi`<HaP<Li`8HaP077>LHaQS67>LQ21cW6<H00QBU
00@HaQcW7>LQ20DHaP@Li`8DY@8Li`068@PHaQBU6<HLib480QS600@Lib487>LLi`<HaP037>LDYABU
008DY@@HaP035:DHaQS600@HaP@DY@8HaP037>LHaQS6008Li`8DY@037>LQ21cW008HaP047>LHaQ24
5:D27>L01AS65:DHaR489BT00QcW0aS600<LiaS68@P00acW00HHaQBU6<HHaR487>L26<H011cW6<HH
aQBU11S600HDYAS66<HLiaS65:D26<H00acW6<HLi`067>L01QS67>LHaQS67>LQ208Li`8HaP8Q208L
i`046<HDYAS66<H27>L02QS65:DHaQS65:DQ22U:;F/YBQS60QBU00@8@PaS2488@PL48@0300048@@Q
00L48@0300048@@Q00P48@88@P0400048@@Q1244248536<224801@aS248<H`aS248020@Q00@8@P@Q
24848@/8@PH48@0;8@Pe[DHa>LhaS3W>E[ES65kgIcUNm`02E[D00c6<9BT@Q00248@00`Q212448@02
12400`0012448@0712401P0012448@@Q00048@<8@P@48@0324848@0000@48@0400048@@Q00031240
0`Q212448@0612422483124324801`@Q24848@@Q36<@Q1cW008U:@8YBP047>LDY@aS48@25:D348@0
1PaS48@HaQBU7>LDY@L@Q0045:DHaQ245:D248@26<H01QBU48@@Q1245:D@Q0@DY@0448@<Ha245:D2
6<H01Q2436<DYAS65:D@Q0<<H`0748@DYA245:D@Q1BU48@011BU00@@Q0aS48@@Q08DY@8@Q0035:D@
Q124008<H`8@Q0035:D@Q0aS00H<H`0348@<H`aS00<<H`0748@<Ha2436<@Q0aS24800PaS0Q240PaS
00<8@PaS48@00PaS00@@Q1BU5:D<H`<@Q00536<@Q1BU5:D@Q00236<00a2436<<H`0236<248@25:D2
48@536<00a2436<@Q00248@236<248@00aBU48@@Q00336<01a245:D<H`aS48@DYAS6008DY@8HaP8D
Y@0548@HaQBU5:DHaP035:D248@03R48:DXicSg_<H`]JbU:9BTYBQcW6<H@Q1BU48@336<348@00`aS
48@<H`0336<00a2436<<H`0236<00a2436<@Q00236<348@636<00a2436<@Q00248@224800`aS48@<
H`0336<0112436<<Ha241`aS0@Q2000412401P0012448@Q2124000848@066<H]JacW48@Lib480QcW
00DQ22DY8@PQ21S6008Li`8HaP038@PLiacW00TLi`8HaP8Li`038@PLiaS600<HaP087>LHaQcW7>LH
aQcW6<HQ20<Li`086<HDYAS67>LQ21cW6<HDY@HHaP037>LHaQS6008HaP8Li`048@PLiacW7>L26<H0
1AcW6<HHaQBU6<H00QcW0QS60aBU0aS600<LiaBU48@00QBU00<HaQcW6<H00aBU00DHaQcW6<HHaQBU
008HaP047>LHaQS66<H27>L00b487>LLi`025:D00aS67>LHaP036<H01QcW8@PQ21cW6<HDY@8HaP03
7>LQ2248008Li`045:DHaQBU6<H37>L26<H011BU6<HHaQS60QcW00<HaQBU5:D00aS600HDYAS66<HQ
21cW6<H67>L01QS67>LDYAS67>LU:@8Li`035:DLib4800@Li`075:DHaQcW8@PLiaS65:D00QcW00<H
aR48:DX00RU:00DHaQBU48@<H`Q200`48@0324848@@Q01448@0324848@Q200@8@PL<H`<8@P8<H`88
@PX48@88@P041248@PQ236<624805@@Q24848@@Q24848AcW<Ha243F]:DXicU:DHaQNmfLiF]IF]E:D
<H`U:@0348@00`aS24848@0712401@Q212448@@Q00002@@Q0`Q22P@Q00<000@Q12400`@Q00<8@P@Q
12401`@Q0PQ20P@Q00T8@P@Q24848@Q2124<Ha246<H00RDY00DYBRDY5:DHaQBU008@Q0<DY@8@Q006
36<@Q1S66<HDYA240QBU0Q2400D<HaBU5:D@Q1BU008@Q0035:DHaQBU008DY@0748@HaQ2448@<Ha24
6<H00Q2400<<Ha245:D01ABU00<@Q1BU48@00`aS0a2400@<Ha2448@HaP8DY@D@Q08<H`0448@DYAS6
5:D336<348@236<248@636<0112436<<H`aS0Q2400<<H`Q224800PaS00@@Q0aS36<@Q0<<H`0348@<
Ha24008@Q08<H`<@Q00636<@Q1BU5:D@Q0aS0a2400<<Ha2448@00PaS0Q2400@DYAS648@@Q08<H`<@
Q0<<H`0348@<H`aS008@Q0055:D@Q0aS36<@Q00436<0112436<@Q1240QBU0QS61A2400HHaQBU6<HH
aQ245:D236<011cW:DXmkcW>0Re[0RU:00<U:AcW5:D0112410aS0Q2400<<Ha2448@010aS00L@Q0aS
48@<Ha2436<@Q00636<010Q236<<Ha240`aS0Q240PaS00<8@PaS48@01A2400D<H`Q236<<Ha2400@<
H`48@P0000<000@Q00000`@Q00<000@Q12400`@Q00@DYC6<8@PHaP8Li`<Q20059BTQ22488@PLi`03
6<H00aBU7>LLi`027>L00aS67>LQ20028@P37>L00aS67>LLi`037>L36<H47>L012487>LHaQS60R48
00@LiaS67>LHaPDLi`086<HLiacW8@PLiaS65:DHaP8DY@8HaP047>LQ21cW6<H25:D47>L011S68@PL
iacW0QBU00@HaQ245:DDY@8HaP8DY@@HaP045:DHaQS67>L25:D26<H01AcW8@PHaQS65:D00QS600@L
iaS67>LLi`@HaP8DY@8Li`038@PLiaS600@HaP<Li`8DY@076<HLiaS66<HDYAS68@P00RDY00DLiaBU
6<HHaQBU008HaP8Li`8DY@036<HDYAS6008HaP8Li`036<HLiacW00<Li`036<HLiacW008HaP047>LQ
22486<H27>L02B487>LQ22DY8@PLiaBU6<HLi`036<H011cW6<HDYBDY0Re[00PQ212448@@Q0aS2484
8@Q22`@Q00<000@Q124050@Q0PQ200D@Q1BU6<HHaQBU008@Q00336<@Q0aS008<H`0348@<H`Q20084
8@<8@PH48@X8@P0336<48@@Q0088@P848@0:36<HaTicDYA6<Cg_@Q1BU6mkMkd2JeX01FLiNmikgUJe
?Nl00PaS0`@Q00L000@Q12448@001240000812400`0012448@0512400`Q212448@0412400`001240
000412400`0024848@0412400`Q212400006124224800`@Q24848@03124224800`aS6<HHaP02:DX0
0bDY7>L@Q00248@010aS48@DYABU11240aBU00@@Q0aS36<@Q0DDY@046<HDYA2448@45:D26<H00aBU
36<@Q00548@25:D00aS67>LHaP025:D248@010aS48@<H`aS0Q2400<HaQBU5:D01Q2400<<Ha2448@0
0QBU00@@Q1BU48@DY@@@Q08<H`<@Q0<<H`<@Q0@<H`0348@<H`Q2008<H`035:D@Q0aS00@<H`0348@<
Ha24008<H`05248<Ha2448@DY@0248@00`aS48@@Q00248@436<01ABU36<<H`aS48@00PaS00@DYA24
5:D@Q0<<H`<@Q0<<H`0348@<H`aS008<H`8@Q08<H`8@Q0@<H`045:D@Q1BU6<H248@011BU6<HHaQ24
0QBU0QS600<DYA2448@00QcW00@icSg_BU9BU0924005>Lhe[CF]9BTLi`025:D248@01@aS248<Ha24
36<00Q2400<<Ha2436<00PaS0Q240PaS0Q240PaS00D8@PaS36<<Ha2400H<H`8@Q00336<8@PaS00@<
H`8@Q0L<H`03248<H`aS00<<H`000`@Q00<000@Q000010@Q00L000@Q5:DaS2486<HLi`048@P00bDY
8@PQ20028@P26<H01QBU6<HLib487>LHaP8Li`039BTQ21cW00<HaPHLi`046<HDYAS66<H67>L38@P2
6<H00aBU7>LLi`037>L00aS67>LLi`028@P01acW6<HLiaS65:DHaQBU00<Li`8HaP8DY@<Li`055:DH
aR488@PLi`025:D26<H011BU6<HLiacW0aBU1QS600PLiaBU5:DHaQcW8@PLiaBU0QS600<DYAS66<H0
1AcW11S611cW00<HaQBU6<H00QS600<LiaS66<H011S60QBU00D@Q1S67>LU:B48008HaP047>LHaQS6
5:D26<H01acW6<HHaQS648@DYAS6008Li`<HaP058@PU:BDY7>LHaP027>L36<H00b487>LLi`047>L0
1248:DXU:AS60QBU00`Q21cW6<HDYAS65:D@Q248;F/aS2DY48@25:D00a2436<8@P0:12400`001244
8@0412400`Q21240000212400`Q212448@0312401@Q212448@@Q248010@Q0Q2400DDYAS65:DDYA24
00@<H`0448@8@PaS36<224801P@Q2488@PQ2124000848@88@P031248@PQ200P8@P031248@PaS0084
8@0;248@Q48@BU9>Ld8@?Nm>Lf]JLia[FP02IcT027_NOomJeSg_48@<H`Q2000312400`0012448@05
1240100012448@000P@Q00<000@Q12400`@Q00<8@P@Q124010@Q00<000@Q124010@Q00<000@Q0000
0PQ21@@Q00<8@P@Q12400P@Q1@Q200<48@Q212400`@Q00T8@PaS5:DHaRe[=JdYBR4836<01a2400HD
YA245:DDYAS65:D348@00aBU48@DY@0248@01QBU6<HHaQBU48@DY@8@Q0045:DHaQS65:D248@00aBU
48@@Q00248@26<H011cW6<HDYAS60QBU00@@Q0aS36<<H`<DY@8@Q0@DY@D@Q00336<@Q12400<DY@03
36<@Q0aS00@@Q00336<@Q0aS008@Q00336<@Q0aS00@@Q00436<@Q12436<224800`aS48@<H`0336<0
0a2436<<H`0536<;48@236<348@336<01Q2436<@Q1S65:D@Q08<H`0448@<H`aS36<248@236<348@8
36<348@010aS48@@Q1240aS600<DYA245:D011BU00DHaQ2448@DYAS6008icP9:DP08@Q0mkcW>>Lha
S2DY7>LDY@8@Q0<<H`0548@<Ha2436<@Q00336<00a2436<@Q00336<02A2436<@Q0aS48@<Ha2436<@
Q00236<548@436<00a2436<<H`0236<348@736<2248136<12480000300048@@Q00T48@077>Le[BDY
6<HLib489BT00R4800@Lib488@PLi`<HaP<Li`<HaPPLi`056<HLiaS67>LQ20026<H00aBU6<HLi`02
7>L26<H011cW8@PQ22480aS600<Lib487>L00QcW00<Q21S67>L00b4800<HaQBU5:D011S600<LiaS6
6<H00aS600<DYAS65:D00QcW00<Q21cW7>L00QcW0QS611BU31S60QcW21S60QcW0QS600<DYAS66<H0
0QS600<DYAS66<H00QcW00DHaQBU6<HDYAS6008Li`036<HDYABU00<HaP045:D@Q1S68@P29BT00acW
6<HHaP046<H45:D36<H27>L26<H01B489BTU:AcW6<H011cW00TDYAS67>LQ21cW6<HDYAcW8@P00QcW
00@Q21cW7>LLi`@HaP085:DHaQS65:DYBS6<9BTLi`88@P0436<8@PQ2248412401@0012448@@Q0000
2P@Q00<8@P@Q12402P@Q0`Q200@<HaBU8@PLi`DQ208Li`046<HDYA2436<324800`@Q24848@081240
10Q212448@aS20Q210@Q01<@Q248<H`YBRe[>LiF]FLiJeYcW6]JIcUS67NmOom_Ne[F6<H<H`031240
1`0012448@@Q00048@0000L48@0500048@@Q1240000612400`0012448@0712400`Q212448@0>1242
2482124010Q212448@Q20P@Q00@8@Q245:DDY@8Li`049BTQ21S65:D248@45:D248@35:D848@25:D4
48@65:D26<H348@01ABU48@DYA245:D00QcW0QS60PaS00<@Q0aS48@00Q240aBU00@@Q0aS48@DY@H@
Q0@DY@0648@<H`aS36<@Q0aS0Q241@aS0a240PaS00<DYA2436<01PaS1A2400<<H`Q236<00PaS00@@
Q0aS36<8@P8<H`@@Q0055:D@Q1BU5:D@Q00336<00aBU36<<H`0536<00a245:DDY@0448@010aS248<
H`aS0a2420aS0a2400D<Ha2448@@Q1BU00<@Q0HDY@036<HDYAS6008@Q00=9BTYBTHaBU9>Le:DBU9>
LdHa@Q0icRU:8@P00QBU00<@Q0aS36<00PaS0Q2400DDY@aS36<<H`Q200H<H`03248<H`aS008@Q004
36<8@PQ2248636<248@236<248@00`aS248<H`0248@00`aS248<H`0536<2248336<000848@080004
8@00124000Q2124000848@0:6<HicRDY5:DLibDY8@PU:B489BT28@P00acW6<HHaP036<H47>L26<H0
12487>LLiacW0QS611cW00HQ21cW6<HHaQBU6<H28@P27>L011S68@PQ21cW0QS600PLib489BTLiaBU
6<HLib480QcW00@U:AcW7>LDY@<HaP035:DHaQcW008Li`@HaP8DY@8Li`058@PLiacW6<HLi`096<H0
3Q246<HLib487>LHaQBU6<HLiaS67>LHaQcW6<H37>L26<H27>L36<H011BU6<HHaQcW0QS60acW11S6
0acW00<HaQBU6<H011S600LDYAS68@PQ22DY8@PLi`076<H25:D021S65:DLiacW8@PLiaS67>L29BT0
12486<HLib480QcW0QS600DLib487>LHaQcW008Q208Li`<Q208HaP8Li`@HaP0648@U:C6<:DXLi`Q2
0PaS0PQ200<48@Q2124010@Q00<000@Q12401P@Q00<8@P@Q12400P@Q00<8@P0012400P@Q00<8@P@Q
12400`@Q10Q20PaS00<DYAcW8@P01B4800DLiaBU5:D<Ha24008<H`88@P<48@<8@P0500048@@Q2484
8@03248236<020Q212448@Q21248@P@Q36<212405@aS7>LaS2e[<H`e[E:DHaQ_Ng>LKg]W>EkgMkek
gW>LHaPLia241240000412400`0012448@0212401@0012448@@Q00001`@Q00H000@Q24848@001243
248F124224800`@Q24848@0212401PQ212448@@Q248<H`8DY@8Li`8U:@8HaP0448@<Ha2448@25:D4
48@25:D348@00aS65:DDY@0348@011BU6<HHaQS60a2400LDYAS66<HDYA245:D@Q0025:D011245:DH
aQBU0QcW0QS60`aS1A2400DDYA2448@@Q1BU008@Q00536<@Q1BU48@DY@0248@011S65:D@Q1240PaS
0a2400<DY@aS48@00PaS212420aS00<@Q0aS48@00Q2400<<H`Q224800PaS00@@Q0aS36<<H`@@Q004
5:D@Q1245:D248@00aBU48@@Q00248@236<00a2436<<H`0248@00aBU48@@Q00248@00`aS48@@Q003
36<0112436<<Ha240PaS00<8@PaS48@00Q2400@<Ha2448@DY@@@Q0035:DHaQBU008DY@0348@DYABU
008DY@8HaP0@5:DLibU:@Q16<DicDYA>Le:DBU9243W>;F/U:AS65:D236<0112436<@Q0aS1A240PaS
00D@Q0aS48@<H`Q2008<H`<@Q0<<H`04248<H`Q236<448@236<00a2436<<H`0336<00a245:D@Q002
48@236<00`Q236<<H`0336<148@136<0000300048@@Q00T48@056<He[BDY6<HLi`038@P012DY8@PQ
22480QcW1AS60acW00<HaQBU6<H00acW0QS60QcW00<Q21S66<H00aS60QcW00@HaQcW8@PLi`8Q20<L
i`038@PLiacW008HaP8Li`058@PU:B488@PHaP025:D26<H01acW6<HLib489BTLiaS600<DY@046<HL
iaBU6<H47>L01B487>LLiaS65:D011S600<LiaS66<H00QS600<LiaS66<H00QS600@DYAS67>LQ208L
i`045:DHaQS67>L26<H25:D00a245:DHaP036<H00aBU6<HHaP027>L76<H00acW8@PHaP035:D011S6
5:DLibDY0RU:00<LiaS66<H01AS600HLiaS65:DDYAS67>L28@P27>L29BT01B487>LHaQcW8@P00QS6
0acW0QS60acW00@U:BU:9BTQ208HaP@Li`046<HDYA247>L29BT00b4848@<H`0336<612401@001244
8@@Q00001@@Q00@000@Q2488@PH48@0324848@@Q00848@0324848@@Q0088@P0>36<@Q1S67>Le[CW>
AS5>LdYBDYA6<CW>;F/HaP<DY@0448@8@P@Q248612402@Q21248@PQ21248@PaS48@<H`0624803`@Q
24848@@Q000DYBU:<H`HaQcW=JeS66LiF]I[FP02Kg/01f<HLiakgW>LHaPQ21BU00@48@88@P848@03
00048@@Q00<48@0300048@@Q00<48@0300048@@Q00848@0600048@@Q124000@Q0PQ20P@Q00<000@Q
12400P@Q00@000@Q2488@PL48@88@P<48@0324848@Q200L48@0336<@Q124008HaP<Li`038@PLiaS6
00@@Q0035:D@Q12400<DY@0548@<HaBU48@DY@0348@00aBU6<HHaP0248@00aBU48@@Q0025:D01Q24
5:D@Q1245:D@Q0<DY@<HaP045:D@Q1245:D548@00`aS48@DY@025:D348@25:D0112436<@Q1BU0QS6
0Q2410aS0a240`aS1A2400@<Ha2448@@Q0@<H`0448@<H`aS36<248@236<348@2248236<01Q2436<@
Q0aS48@<H`<@Q0055:D@Q1245:D@Q00336<348@236<348@00`aS48@@Q00548@236<648@436<248@0
0aBU36<<H`0248@00aS648@<H`0236<01A245:D@Q0aS48@00aBU00H@Q1BU5:DHaRU:<H`2AS402Dic
E[EBU4icAS5243W>:DXQ20025:D248@00aBU48@@Q00248@00`aS48@<H`0336<248@936<01@Q236<@
Q0aS48@01`aS00L8@PaS36<<H`Q236<@Q00236<01@Q236<@Q0aS48@01@aS0PQ2000412400`001244
8@0312401@00124LicF]:DX00QcW1b480QcW1QS611cW00@HaQcW7>LHaP<Li`038@PHaQS600@HaP05
7>LQ21cW6<HLi`028@P27>L28@P37>L00aS67>LLi`027>L012489BTLiaS60QBU00@HaQcW7>LHaP@L
i`036<HDYAS6008HaP055:DHaQBU7>LQ20027>L26<H00acW6<HHaP026<H00aBU6<HHaP036<H00b48
7>LHaP025:D27>L011S67>LLiacW0QS600LDYAcW7>LQ21cW6<H@Q0025:D01QS67>LLiaBU6<HDY@8H
aP065:DHaQS67>LHaQBU11S600<DYAS65:D00aBU00DLibDY:DXYBR48008Li`046<HDYAS67>L26<H2
5:D26<H57>L012489BTU:BDY1acW00<HaQcW6<H00QS600DLibDY:DXQ21cW008HaP037>LQ21cW008H
aP0348@DYB48008U:@078@P<Ha24248<H`Q236<00PQ20P@Q00<000@Q12401@@Q00<8@P@Q12403`@Q
00`8@P@Q24848@Q236<@Q1S67>L]Jc6<AS42BU8025:DAS4icRe[6<HDYA245:D248@010Q212448@Q2
1P@Q00@8@P@Q2488@P8<H`<8@P0736<48@Q21248@P@Q24800P@Q00HDYBU:<H`DYAcW=Jd2IcT02ekg
IcU_Nf]JIcU_NgNmLia[FRU:5:D00`@Q0PQ21@@Q00<000@Q12400`@Q00<000@Q12402@@Q00H000@Q
1248@P@Q248=12401`Q212448@@Q24848@Q200@48@88@P@48@<8@P0448@DYAS65:D27>L28@P01QS6
5:D@Q1BU6<HDY@8@Q0<DY@0348@<HaBU008DY@8@Q00536<@Q1BU6<HDY@0448@00aBU48@@Q0025:D0
11S648@@Q1240QBU0Q2411BU00<@Q0aS36<00Q2400@DYA245:D@Q0DDY@0448@DYA245:D348@35:D2
48@336<00a245:D@Q00248@336<848@01PaS248<Ha2436<8@P<<H`<@Q0P<H`8@Q00336<@Q12400<<
H`0348@DY@aS008@Q0055:D@Q124248<H`0348@336<248@236<548@236<00a2436<<H`0348@010aS
248<H`aS0Q2400<<Ha245:D0112400<DYA2448@00a240aBU0QS600PDYAS69BT]Jd8@AS5BU5Je0U:D
00I:DT8@?NlYBRDY5:D448@436<00a245:D<H`0236<00a2436<<H`0236<248@00`aS48@<H`0236<0
10Q236<<H`aS0Q240`aS00<@Q0aS36<01`aS112400<8@PaS36<00`aS0PQ20@aS0@Q200000`@Q0004
8@0212400`0012448@0412402AcW=JdU:ABU8@PU:BU:9BTQ20047>L00aS67>LHaP027>L36<H28@P0
11cW6<HDYAcW0aS611cW00LHaQcW7>LQ21cW6<HLi`028@P01QcW8@PLiaS65:DHaP<Li`8HaPLLi`8D
Y@066<HLib487>LHaQcW2AS600PLiaBU6<HLib487>LHaQBU11S600<LiaS65:D00QcW0R4800DHaQBU
6<HDYAS6008DY@0:6<HLiaS66<HDYAS67>LHaQBU48@25:D26<H35:D00aS67>LHaP025:D27>L01248
6<HDYAS60QBU0QcW00<HaQBU48@00QS600X@Q1BU8@P]JbU:6<HDYAS67>LQ208Li`<HaP045:DHaQS6
8@P27>L39BT00b487>LQ20027>L00aS67>LLi`067>L012487>LQ21cW124800TLiaS67>LDYAS67>LQ
22U:9BT00QBU0`aS0PQ20`@Q00<000@Q124030@Q00@000@Q1248@P<48@0300048@Q200<48@0<2484
8@@Q124<Ha246<H]JcF]BU9F]F<H0Vmk00IcW6]JG_M>Lbe[7>L336<32484124324800`aS2488@P05
248010@Q24848@Q210@Q00`8@P@Q000@Q248:DXLiaBU9BU244YBCW<2F]H2JeX016mkIcU:DTHa0R48
00P<H`@Q36<YBSW>;F/<H`000`@Q00<8@P@Q124010@Q00<000@Q12401P@Q00<000@Q124010@Q00<<
H`@Q12400P@Q00<8@P@Q12400PQ21@@Q0PQ200D48@Q21248@P@Q0088@P031248@P@Q00848@030004
8@@Q00848@8<H`0848@DYAS6;F/aS2e[:DXHaP8DY@8@Q0045:D@Q1BU6<H348@01ABU6<H@Q1245:D0
0QS60QBU0Q2400<DYA2436<00Q240QBU0a2400<<Ha246<H00QS60QBU0Q2400D<Ha2448@DY@aS008@
Q0035:DHaQBU00<HaP8DY@D@Q08DY@<@Q0<<H`<@Q0@<H`8@Q00536<@Q12448@<H`0348@336<348@2
36<348@336<00a2436<<H`0248@236<248@336<011245:D@Q0aS21240`aS0Q2400HDY@aS36<@Q0aS
5:D348@02`aS48@DYA2436<@Q1BU48@<H`Q236<00QBU00<<Ha245:D02A2400@<Ha2448@HaP<DY@0@
7>LDYAS68@P]Jd8@AS5:DU:DBU9>LdHa?Nle[BDY8@P25:D248@236<348@01`aS248<H`aS48@<Ha24
00@<H`<@Q0D<H`0348@<Ha24008@Q08<H`04248<H`aS36<324800a2436<<H`0236<0112436<@Q124
20aS0000100012448@001@@Q00P000@Q124LicF]9BTDYAcW12DY0QcW00<Q21cW7>L011S600@Q21cW
8@PLi`<HaP035:DLiacW008Q20037>LHaQcW00<Li`058@PLiaS66<HLi`038@P37>L26<H37>L00aS6
7>LLi`027>L56<H01ABU6<HLiacW8@P00acW0QS600LDYAS66<HHaQcW6<HDY@026<H47>L01aS67>LH
aQBU7>LQ21cW008HaP037>LQ21cW008DY@8HaP037>LDYABU008HaP037>LHaQS6008Li`056<HDYABU
5:D@Q0025:D26<H011BU7>LLiaS60aBU00@Lib487>LLi`8DY@8HaP047>LHaQBU5:D26<H00a246<HU
:@02:DX011cW5:DHaQcW0R4800@HaQBU7>LLi`8DY@037>LQ21cW008Li`<U:@8Q208Li`8HaP@Li`06
6<HLiacW6<HLib480bDY00TLiaS66<HLib487>LDYAcW8@P00RDY00<DYA2424800`aS0P@Q00<000@Q
12406@@Q00l8@P@Q12448@Q21248@Q245:D]Jc6<DYA>Lf<HKg/00W>L0Ukg00I>LbU:7>L<HaBU36<2
1243248212400`001248@P0324800`@Q2488@P07248312401PQ212448A249BTYBP8HaP069BU6<Dic
CW=JeUkg0fmk00aW>Dic@Q0Q21cW36<48@aS:DXicRU:248R124224800`@Q24848@05124010Q21244
8@@Q1@Q21@@Q00H000@Q2488@PaS24825:D01RU:<H`YBRDY5:D@Q0<DY@8@Q0@DY@0348@DYABU008D
Y@0448@DYAS66<H25:D648@55:D348@36<H00aBU6<H@Q00248@010aS48@@Q1240QBU00<@Q1BU5:D0
0aBU00<@Q1BU5:D00a240QBU00D@Q1BU48@8@PaS008@Q0035:D@Q0aS008<H`0348@<H`aS008@Q005
5:D@Q0aS36<@Q00236<01@Q236<@Q12436<00Q242`aS0Q240`aS00<@Q0aS48@00PaS0a2400<DYA24
48@01`aS0Q2400XDYA2436<DYA2436<@Q0aS48@DY@<@Q0055:D@Q0aS36<8@P0248@010aS48@<HaBU
0Q2400<<Ha245:D021240QBU11S600HU:BU:@Q1244icDY@2CW<01THa@Q0e[BU:8@PDY@D@Q08<H`<@
Q0<<H`0448@<H`aS248636<248@436<00a2436<<H`0736<00a2436<<H`02248236<01A2436<<H`aS
24801PaS0@Q2000212401P0012448@@Q0008@P@48@067>Le[BDY6<HQ22DY0R4800<Lib488@P00b48
00<HaQBU6<H00R4800<LiaS66<H011cW0aS600<Lib488@P00QS600<Q21cW7>L00acW0R480QcW00DH
aQBU6<HHaQcW008HaP075:DLiacW7>LQ21cW6<H00QBU0QS600<DYAS66<H01AcW00<DYAS65:D00QS6
0QBU00@HaR487>LLi`<HaP8Li`8HaP057>LHaQS66<HLi`029BT00acW6<HHaP066<H01AcW6<HDYABU
6<H00QBU00HHaQcW6<HHaQBU6<H25:D01AS67>LHaQS65:D00QS60R4800HLiaS65:DHaQBU6<H25:D0
1A245:DDYABU6<H00QcW0R480aS60acW00<HaQcW6<H00QBU00HHaQcW8@PLib487>L28@P57>L011S6
8@PU:B480QS600<DYAcW7>L011cW0QS600<Lib487>L00QS600LLiaS67>L]Jc6<:DXHaP0436<22483
12400`0012448@0212400`0012448@0212400`001240000:12400`Q212448@0212422482124020Q2
5:DHaQS6;F/e[F<HKg/2Li`2IcT01FmkOomcW4YB:DX00PaS00@8@P@Q124000D48@0648@Q224848@4
8@Q20P@Q00D8@P@Q24848@Q200P48@03248<HaBU008@Q0045:DU:BDY=Jd2@Q0024icBU8icS6<>Li6
<CW>:DX248@022489BTU:ABU36<8@PaS248312400`Q212448@0312400`0012448@0512400`001240
000212400`Q212448@0<1243248010@Q24848@Q20P@Q00@8@PaS2488@PL48@030008@P@Q00<8@P08
9BTaS4HaCW<]Jb486<H<H`8DY@8@Q0DDY@8@Q08DY@<HaP075:D@Q1245:D@Q0aS48@00QS600<DYA24
36<00Q240aBU00<HaQBU48@00Q2400@DYA2448@<H`8@Q0045:DHaQS65:D26<H00aBU6<H@Q0025:D0
0a245:D@Q0025:D01A2436<@Q12436<00QBU00P@Q1BU36<<Ha24248<Ha240QBU0`aS0Q2400P<Ha24
36<<Ha2436<@Q0aS0Q240PaS00@@Q0aS36<8@P<<H`<@Q08<H`03248<Ha2400D<H`045:D@Q12448@5
36<00a2436<@Q00248@00aBU48@@Q00336<00a245:D@Q00236<00aBU48@@Q00236<00a2436<<H`03
48@336<011BU48@DYABU11240QBU00D@Q1BU6<HHaQcW008DY@046<HQ23W>@Q02AS401cg_@Q0icSW>
;F/LiaBU00<@Q00436<@Q0aS48@336<248@236<248@336<00a2436<<H`0436<2248;36<010Q236<<
H`aS0a240PaS00<@Q0aS24800PQ21@aS0@Q200001@0012448@@Q00001@@Q00H000Q27>Le[BU:6<H3
8@P01bDY8@PQ21cW8@PLib48008HaP047>LQ22488@P26<H57>L26<H67>L012487>LLiaS60R4800DU
:B487>LHaQcW00HHaP<Li`046<HLiaS66<H25:D011S67>LHaQS60acW00<Q21S65:D00QBU00<HaQcW
6<H00QS600<Lib487>L00aS60acW00@HaQcW6<HHaP8Li`048@PU:B487>L25:D00acW6<HHaP025:D4
6<H011BU6<HHaQBU11S600<DYA2448@01QS60R480QcW00<HaQBU5:D00QBU0aS600<DYA245:D00QS6
00HQ22DY9BTQ21S65:D26<H37>L26<H25:D00acW8@PU:@047>L00b487>LLi`027>L02AS67>LQ2248
7>LDYAS67>LQ20026<H47>L032487>LLiacW6<HLiaBU6<HYBS6<;F/HaP88@P8<H`0324848@@Q00h4
8@88@PL48@0324848@@Q00L48@09248<Ha2448@HaS6<>LiS66]J009cW00;HaQW>G>LOom_NdHa:DX<
H`Q21248@P07124011247>LLi`aS0`Q20P@Q00L8@P@Q24848@Q21248@P051242248248@26<H00bDY
;F/icP02@Q02CW<01T8@<H`e[DHa=JdU:@8@Q0067>LU:B485:D<H`@Q10Q22`@Q00<000@Q124040@Q
0PQ210@Q00<8@P@Q12401@@Q0PQ200<<H`Q212400`@Q00@000@Q1248@P848@88@P0:36<U:BU:AS5:
DRe[9BT@Q0aS6<H35:D248@25:D248@011BU6<HHaQBU0QS60QBU0a2400P<HaBU6<HDYA2436<@Q1BU
0Q2400PDYAS66<HHaQBU48@<Ha240QBU00<@Q0aS48@00aBU00<HaQBU5:D00aS60Q240aBU0Q2400<D
YA2436<00PaS0aBU0PaS11240QBU00<@Q0Q236<00Q2410aS00<@Q0aS36<00PaS00H@Q0aS36<@Q0aS
48@436<348@736<0112436<<Ha240PaS112400<<Ha2436<00PaS00<@Q0aS48@011240PaS0Q2411BU
00<<H`Q236<010aS112400@<Ha2448@@Q08DY@0748@DYA2436<@Q0aS5:D00QS600XLiaS65:DDYAcW
8@PicSg_AS5:DP<mk`05>Lhe[AcW5:D@Q0025:D00a24248<H`0236<00a245:D@Q00236<348@636<0
2a2436<<H`Q236<@Q0aS48@<Ha2436<00PQ200<<Ha2448@00`aS00<8@Q2436<00Q242`aS0@Q20@@Q
00000`@Q00048@0212400`0012448@0412402QcW>LhQ21S69BTYBR486<HLib480RDY11cW00HQ21cW
6<HHaQcW6<H57>L26<H00acW8@PU:@028@P01BDY8@PLiaS67>L00b4800DLiaS66<HDYAS600<Li`03
6<HLiacW00@Li`<DY@8HaP035:DHaQcW008Li`8HaP037>LHaQBU00<HaP<Li`8HaP047>LQ22487>L2
5:D01QS67>LLiacW6<HLi`8Q20067>LHaQBU6<HLiaS60aBU00XLiaBU48@DYAS67>LHaQBU6<HDY@@H
aP035:DHaQBU008HaP045:DHaQS67>L86<H35:D26<H00aBU7>LQ20028@P00aS65:DHaP026<H011cW
6<HHaQS611BU00<LiaS67>L00R480QcW00<HaR487>L00QS60QcW0R481AS600@LiaS66<HLi`8Q2004
7>LHaQcW8@P25:D01248;F/YBQcW0QBU00<@Q0aS24800PQ25P@Q00<8@P@Q12400P@Q00<8@P@Q1240
0P@Q00D8@P@Q12448ABU008]J`088@PU:CF]G_MW>FmkLia[FP9S609oo`04HaPmk`Q2248212400`Q2
12448@04124236<00`Q212448@0212400`Q212448@02124010Q21248@PQ210@Q00D8@P@Q1248@PaS
00<@Q00@6<HLib487>LQ22e[7>LDYBU:@Q1:DSF]6<HLibDY8@P27>L00aBU48@@Q00236<312400`Q2
1248@P0812401@0012448@@Q00001`@Q00@000@Q1248@P@48@0424848@Q21243248212400`001244
8@0512400`0012448@0312400`Q21248@P0212401a246<HaS3W>=Jd]JacW008DY@8@Q0055:DHaQS6
5:D<H`0348@35:D00aS65:DDY@0548@35:D00a2436<@Q0035:D26<H25:D236<35:D248@01aBU6<HD
YABU48@DYAS6008DY@036<HDYABU008DY@036<HDYA24008@Q00336<@Q124008DY@0348@<H`aS008<
H`D@Q0<<H`<@Q0@<H`0448@<H`aS248636<248@00`aS48@<H`0248@436<248@336<02a2436<@Q0aS
48@<Ha2436<@Q0aS48@00`aS0Q240`aS00<@Q0aS36<011240PaS0a2400<<Ha2436<00Q2400<DY@aS
36<00Q2400DDY@aS36<@Q1BU00<@Q08<H`0348@DYABU008DY@0648@DYABU6<HU:Be[0SF]0Re[0RDY
00HQ21BU6<H@Q0aS48@436<011245:DDYA240`aS0Q2400<DY@aS48@00`aS0Q240PaS00<8@PaS36<0
0PaS00@8@PaS36<@Q0D<H`0348@<H`aS008<H`8@Q0D<H`03248<H`aS00@<H`000P@Q00P000@Q1244
8@0024848@000P@Q00@LicF]:DXHaP8U:@048@PLiacW8@P29BT00b487>LHaP037>L00aS67>LHaP06
7>L01AS65:DLibDY8@P00QcW00<Q22DY8@P00QcW00<Q22DY8@P00QcW0QBU00<HaQcW7>L00aS600DL
iaS68@PQ21cW008HaP@DY@8Li`098@PLiaS66<HLiaBU6<HDYAS600DLi`<Q20<Li`8HaP8Li`8HaP05
7>LQ22488@PHaP027>L00aS65:DDY@026<H25:D00aS65:DHaP036<H01QBU6<HHaQS67>LHaP8DY@03
6<HLiaS6008DY@037>LU:B48008DY@DHaP035:DHaQBU008HaP055:DHaQcW8@PLi`025:D26<H37>L0
11BU6<HDYABU0aS60acW0R4800THaQcW8@PLiaS65:DLibDY8@P00QcW00`HaQBU6<HLib487>LDYAS6
7>LU:AcW6<H27>L26<H01248:DXYBR480QBU0PaS0PQ210@Q00<000@Q00003@@Q00<8@P@Q12401`@Q
00<8@P@Q124010@Q00dHaRU:;F/LibDY=JeS66LiKg]cW6]JHaQW>@02Ool016<H>Lh<H`Q21@@Q0PQ2
0P@Q00<<Ha2436<01P@Q0`Q210@Q00@8@P@Q12448@88@P848@0636<DYA2448@HaR480QcW00XYBS6<
8@P@Q2DY?Nm>LcW>7>LQ208U:@038@PLia2400<@Q00436<8@P00124224800`@Q00048@0212400`00
12448@0=124010Q21248@P@Q0PQ200<48@Q212402P@Q00<8@P@Q00001`@Q00@000Q22488@P<48@07
48@DYBe[>LhaS2e[7>L00QBU00<<HaBU5:D00QBU11240QS600h@Q1BU5:DLiaS65:D@Q1BU48@<Ha24
5:DHaQBU0Q240aBU00XHaQBU5:D@Q0aS48@DYA245:D@Q08DY@046<HDYABU5:D36<H35:D01A245:DD
YAS65:D00Q2400@DY@aS36<@Q08DY@0348@<Ha24008<H`0548@<Ha2448@<H`0448@236<448@336<3
48@836<248@436<448@436<248@336<348@336<448@00`aS48@@Q00336<248@00`aS48@@Q00248@3
36<248@236<02Q245:D@Q12436<@Q1BU48@DYAS60Q240PaS0QBU0QS60aBU00HHaQBU9BT]JcF]>Lh2
;F/012U:9BTLiaS60QBU112400D<Ha2448@DYA2400<<H`<@Q00336<@Q0aS008@Q0@<H`0348@<H`aS
0088@P0336<@Q1240088@P8@Q00436<8@PaS36<224801PaS5:D@Q0aS248@Q08<H`04248<H`aS36<2
48@136<12480000500048@@Q1240000512401@00124Licg_;F/00acW00<HaQcW7>L00b480bDY00<Q
21S66<H00QS60R4800TLib488@PDYAS67>LQ22DY8@P00bDY0QcW00PU:BU:8@PLiaS67>LHaQBU0QS6
0QcW0QS60QcW0R480QS61ABU00@HaQcW7>LLi`<HaP<Li`8HaP057>LQ21S66<HLi`036<H28@P00aS6
48@DY@067>L00b487>LHaP037>L26<H35:D00aS67>LDY@025:D00aS67>LHaP036<H00acW5:DDY@05
6<H37>L46<H01acW6<HHaQ245:DHaQBU008HaP047>LQ21cW8@P36<H011BU6<HHaQS611cW00@HaQBU
5:DDY@8Li`048@PLiacW5:D26<H27>L03aBU7>LQ22487>LDYAS68@PLiaS65:D@Q1S67>LQ20026<H0
2acW8@PQ21S636<DYBDY=Jd]JaS636<00Q2400<<H`Q212400P@Q00<000@Q12400P@Q00@000@Q1240
00X48@0324848@@Q00@48@88@P0800048@@Q1248@P00124U:@96<@06:DXHaRU:DYA>Lekg0Vmk00][
FVLiOomooeJe;F/<Ha2436<48A24008HaP045:D48@@Q124224800`aS1248@P02248312401@Q21244
8@@Q24800P@Q0PQ20`@Q1@Q20PaS00D@Q1BU6<HHaQBU008@Q0035:DHaQcW00<DY@<HaP06248<HcW>
G_M:DQcW0P@Q00D8@P@Q24848@Q200H48@88@P<48@0300048@@Q00<48@0400048@@Q248412422484
1242248?12401@Q212448@@Q24800P@Q00`<Ha249BTU:BU:?Nle[BDY48@<Ha245:D548@01aBU48@D
YAS65:DHaQBU008HaP@@Q00<5:D@Q12448@DYA245:DHaQcW6<HDYA240aBU0Q240QBU0aS611BU0aS6
00DDYA245:DDYAS6008DY@0348@<H`aS008@Q0046<HDYA2448@236<0112436<@Q1BU0Q240PaS00<@
Q0aS48@00`aS0a240QBU00D@Q0aS36<<Ha2400@<H`0348@<Ha2400D<H`H@Q00736<@Q12448@<Ha24
24800PaS0Q2400D<Ha2448@DYA2400@<H``@Q08<H`8@Q0035:D<Ha2400<<H`@@Q08<H`8@Q0045:D@
Q1245:D248@00aBU48@@Q00248@26<H48@P01acW6<HDYA2436<@Q1BU008@Q00336<@Q12400@@Q0<<
H`0348@DYA24008@Q08<H`<@Q0<<H`8@Q00436<8@PQ236<248@236<00`Q236<8@P0336<00a2436<<
H`0436<00a2436<8@P0236<00a2436<<H`01248000<48@0300048@@Q00H48@078@Q242e[6<HLib48
7>L00R4812DY00<Q21cW6<H00acW00<HaQcW8@P00R480QS60QcW00/Q22DY7>LU:BU:8@PHaQcW8@PY
BRDY008Li`038@PLiaS6008DY@8HaP057>LHaQcW7>LQ20027>L26<H011245:DDYABU11S600<LiaS6
7>L00QcW0QS60acW00LHaQcW6<HLiaS67>LQ20027>L26<H37>L26<H87>L01AS65:DHaQBU7>L01QS6
0QcW00HHaR487>LLiaS65:D36<H37>L36<H37>L01AS65:DHaQS67>L00aS60acW0QS600HDYAS66<HD
YAS67>L29BT011cW6<HDYABU0QS60acW00<Q21cW7>L00QS600@LiaS66<HHaP8Q200:7>LDYAS67>LH
aQcW5:DHaQcW8@P27>L01AS67>LLib487>L00QBU00DYBSF];F/DY@aS008DY@0336<48@@Q00L48@03
24848@@Q00h48@0324848@@Q00<48@0524848@@Q1248@P0212402BDYAS5242485:D]Je:DCW=Nm`02
Kg/03V]JHaQoogooF]He[@aS48@<H`@Q36<DYAcW48@2124224800`aS2488@P0212400`Q21248@P05
124324800`@Q00048@032482124536<00aBU6<HDY@0248@26<H25:D00aS67>LLi`025:D01aS6248<
Hd8@G_M:DQcW00848@0324848@Q200P48@0524848@@Q1240000>1242248412400`Q212448@031240
0`Q212448@0212401@0012448@@Q248010@Q00h8@P@Q2488@PaS48@Q22DY;F/e[C6<9BTHaQ240aBU
00<@Q1BU48@00Q2400<DYAS65:D00QBU00LLiaS65:DDYA2436<DY@0448@00aS65:DDY@036<H25:D0
11S65:D@Q1240QBU00@HaQBU5:D@Q0DDY@8HaPDDY@0348@DYABU008@Q08<H`<DY@0448@<Ha2436<4
48@01@Q236<<Ha245:D00`aS00<@Q0aS48@00QBU00@@Q1BU48@@Q0`<H`8@Q0D<H`<@Q08<H`0348@<
H`aS008<H`<@Q00336<@Q124008@Q0<<H`0648@<H`aS36<DYA240`aS00<@Q0aS48@0112400@<Ha24
36<<H`8@Q0035:D@Q12400<@Q08<H`8@Q0035:D@Q12400D@Q08DY@036<HLib48008U:@038@PHaQS6
008DY@0548@DYA2448@<H`0448@336<00a2436<<H`0248@236<0112436<@Q0aS0Q2400<<Ha2436<0
2PaS00@@Q0aS48@8@P@@Q00336<8@PaS00H<H`8@Q04<H`48@P0000<000@Q00000`@Q00<000@Q1240
0`@Q00DQ23W>9BT@Q1cW008Q20<Li`069BTYBRDY8@PLib4811cW0b4800HLiaS67>LLib487>L38@P0
1BDY8@PQ21cW9BT00RU:00LQ21cW6<HHaQBU7>LQ20057>L01B487>LLiaS65:D00aS60aBU0QcW0QS6
00@DYAcW7>LLi`8Q208Li`@HaP@Li`046<HDYABU5:D37>L011S65:DHaQS60QcW00DQ21cW6<HHaQcW
008DY@036<HDYAS600DHaP045:DHaQS65:D46<H01ABU6<HHaQcW6<H011cW0aS60QBU1aS60acW0aS6
00@DYAS68@PQ208Li`0=6<HLiaS66<HDYAS67>LQ21cW6<HLiaS67>L00QBU00DLib489BTQ21S6008L
i`066<HDYAcW7>LHaQBU0QS600<Q21S66<H00QcW00H@Q1BU8@PYBR486<H25:D0112436<8@PQ21P@Q
00@8@P@Q124000l48@0324848@@Q00L48@88@P0812400248BU96<BDY248HaP8icP=BU006F]IBU5:D
AS4e[BU:0QcW00HDY@Q26<HU:BU:8@P312400aBU7>LDY@02124324800`@Q24848@0312401PQ21244
8@@Q248<H`88@P051248@PQ224848@0224801a2436<@Q1BU48@Q21cW008DY@88@P8<H`055:DLibDY
7>L@Q00536<224801@aS12448@@Q00000`@Q00@000@Q1248@P<48@06248<H`Q2124000Q21P@Q0PQ2
00<48@Q212401P@Q00@8@P@Q124000T48@@8@P0600048@@Q36<@Q0aS0QBU00DYBSF]<H`YBQS600H@
Q0045:D@Q1BU5:D36<H00aBU48@@Q00248@25:D0112436<@Q1241ABU00@HaQBU48@DY@8HaP035:D<
Ha24008DY@036<HLiaS600<DY@8HaP8DY@8HaP<DY@0348@<H`aS008@Q0046<HDYABU5:D348@010aS
48@@Q0aS0a2410aS00<@Q0aS48@0112400@HaQBU48@@Q0D<H`@@Q004248<H`aS36<448@536<248@0
1@aS48@@Q0aS48@00`aS00<@Q0aS36<00a240PaS0Q240`aS00L@Q0aS36<<Ha2436<@Q00236<00a24
36<@Q00348@011BU48@<H`aS0a2400<<Ha245:D011BU00@@Q0aS36<<H`H@Q0036<HDYABU00@DY@8@
Q0045:D@Q12448@336<348@010aS248@Q1BU1A240`aS00<@Q0aS36<010aS0Q240PaS00@@Q0aS36<<
H`<@Q00336<@Q0aS00<<H`8@Q0/<H`0010@Q00/000@Q1248@P@Q00048@Q27>LicRU:008HaP057>LH
aR487>LQ20039BT012487>LLiaS611cW0R480QcW00<HaR488@P00b4800HU:BU:8@PLib489BT2:DX0
1B487>LLiaBU6<H00QcW00PQ21cW6<HDYAcW8@PU:B480QBU00DHaQBU5:DDYA2400<HaP057>LHaQcW
7>LHaP027>L00b489BTQ20026<H00aBU6<HLi`037>L01AS65:DHaQS67>L01QS600DLib488@PLiaS6
008DY@046<HDYABU5:D46<H47>L26<H25:D56<H01QcW6<HLiaS67>LQ208Li`8DY@056<HDYAS66<HD
Y@026<H27>L36<H00aBU6<HLi`028@P26<H01acW8@PHaQS65:DHaQBU008HaP8Li`0:6<HLiacW7>LD
YAS68@PU:AcW6<H27>L36<H01QcW6<HDYAS68@PLi`8HaP057>LHaQBU5:DLi`029BT00acW5:D@Q002
48@2248B12400`001240000612400`Q21240000912401RU:BU96<BDY248DY@8icP04DYAF]E:DG_L2
E[D02dYB=Jd]JaS67>L@Q0Q26<H]JbU:7>L00P@Q00H<HaBU7>LDY@Q21242248312400`Q212448@04
124624801`@Q2488@P@Q248<Ha24008<H`0548@HaQcW7>L@Q002248010aS5:D<Ha240QcW00DHaQ24
36<DYA24008<H`@8@P<48@0300048@@Q00<48@0400048@@Q248412400`Q212448@0312400`Q21244
8@021243248212401@Q21248@P@Q00000`@Q00<000@Q12401`@Q1PQ20Q240QS600HU:CF]>LhYBQBU
36<25:D348@35:D00aS65:DDY@035:D00a2436<DY@025:D00a2436<<H`0248@25:D02A245:DLiaBU
48@DYAcW6<H@Q00236<46<H35:D011246<HHaQBU0QS61ABU0a2400@DYA245:DDY@T@Q0D<H`0448@<
Ha2436<248@01aS67>LDYABU48@<Ha24008<H`0348@<H`aS00<<H`0448@<H`Q236<348@00`aS48@<
H`0536<248@010aS2488@Q240QBU0`aS0Q240`aS0Q240`aS0QBU00T@Q0aS36<@Q0aS48@DY@aS48@0
0PaS1A2410aS0Q240aBU00<HaQBU48@00PaS0Q2400<<Ha2448@0112400<DYAS66<H00QBU00D@Q1BU
48@@Q0aS00H@Q0@<H`0648@DYABU48@<Ha240`aS00H@Q1BU48@<H`Q248@436<00a2436<@Q00D36<0
0a2436<<H`012480000300048@@Q00848@0300048@@Q00848@0700048AcW=JdU:A247>L00b480QcW
00XQ22U::DXQ21S67>LHaQBU7>LQ208U:@037>LHaQS6008Li`038@PLibDY008YBPDU:@<Q208Li`08
6<HLiacW7>LQ21cW8@PU:@8Q20066<HDYAS66<HLiaS60QBU00<HaQcW6<H00acW0aS600<Lib488@P0
0QcW00HDYAS66<HDYAS67>L66<H00aBU6<HHaP046<H011cW8@PHaQS60QBU00<HaQBU6<H01AS600<D
YAcW8@P00QcW00@DYA245:DDY@8Li`065:DHaQcW8@PLiaS60QcW00@HaQcW6<HLi`8HaP8DY@8HaP<L
i`8HaP035:DHaQcW00<Li`046<HLiacW7>L26<H00aBU6<HHaP046<H27>L36<H011cW8@PQ21cW1QS6
00<DYAS65:D00aS600<LiaS67>L00QcW00X@Q1S67>LU:AcW5:D<Ha2436<8@P<48@0300048@@Q00<4
8@0300048@@Q01048@88@P@48@0:24848@@Q1248@P001248@Q247>L35:D27>L2;F/02c6<>LhicR48
7>Lmke[FCW<YBQ246<H00RDY00@HaQ2436<8@PD<H`0324848@Q200<8@P<48@0424848@@Q24821242
24800`aS1248@P0324805P@Q2488@PQ2124<HaBU6<HDY@Q21248@Q245:D<H`Q248@LiaS648@8@P@Q
0`Q200<<H`Q2248030@Q00D000@Q1248@P@Q0088@P848@0300048@Q20088@P848@<8@P@48@052484
8@@Q124000061240100012448@Q20`@Q00@8@P@Q1248@P8<H`04248<H`aS8@P3:DX00acW5:D@Q002
48@35:D26<H35:D011S65:DDYA2411BU00P@Q0aS36<DYA245:DLiaS60Q2400@DYAS65:D<H`8@Q003
6<HDYABU008HaPDDY@0348@DYAS600<HaP<DY@@@Q08DY@8@Q0055:D@Q0aS36<DY@0248@236<01ABU
48@@Q0aS48@00`aS00<@Q1S65:D00Q2400<<Ha2448@00Q2410aS00<@Q1BU36<00`aS00@@Q0aS36<<
H`8@Q08<H`03248<H`aS008@Q0<<H`8@Q08<H`88@P8@Q0045:D<H`aS36<548@010aS2488@PaS1124
00<<Ha2448@00`aS0Q240`aS00<@Q1BU48@00PaS00@@Q1BU5:DDY@8@Q00436<@Q12448@436<548@0
0aBU6<HDY@0348@00aBU48@DY@0348@436<01A2436<@Q1245:D00Q240PaS00<@Q0aS48@00`aS00@@
Q0aS36<<H`@@Q0L<H`0448@<H`aS36<248@010aS48@@Q1241@aS00<@Q0aS36<00@Q2000312400`00
12448@0612400acW>LhU:@026<H01AcW8@PQ21cW8@P00RDY00<YBRDY7>L00aS60R4800@Lib487>LH
aP8Li`<Q20@U:@038@PU:BU:008Q20037>LQ21S600<Li`@Q20HLi`@HaP085:DHaQS66<HDYAS67>LQ
208HaP047>LQ22488@P36<H00acW6<HHaP046<H01ABU6<HLiaS65:D00aS600@DYAS67>LLi`DHaP8D
Y@PHaP087>LHaQS65:D@Q1BU6<HLi`PHaP037>LHaQS600<Li`8DY@8HaP075:DHaR487>LHaQ245:D0
0aS61QcW00DHaQcW6<HDYAS600<Li`8HaP038@PHaQcW008HaP8Q208Li`HHaP055:DHaQS67>LHaP03
7>L01b486<HDYABU7>LU:AcW00<@Q00336<8@P@Q01048@0324848@@Q00<48@0524848@@Q1248@P08
12400`Q212448@0212400a245:DHaP035:D27>L04BDY;F/icT8@>LhU:B48?NmJeTYB:DX@Q1S69BTQ
21cW5:D00PaS00<@Q0aS24800PaS0`Q200<48@Q212400PQ21`@Q00@8@P@Q1248@P@48@D8@P8@Q005
5:D@Q0Q2248<H`025:D01PaS248@Q1S65:D@Q0@8@P0336<8@P@Q00H48@0400048@@Q000712400`Q2
12448@0812400`Q212448@031242248812400`0012448@031243248412400`Q236<<H`0236<00aBU
7>LQ20028@P00acW5:D@Q00248@45:D00a245:DDY@026<H011BU48@@Q1240QBU00<@Q1BU48@00Q24
00<DYAS66<H00QBU00<@Q1BU48@00QBU11240aS600<DYAS65:D00aBU00<HaQBU6<H00aS60QBU00<@
Q0aS48@00a240QBU11240QBU00<@Q0aS36<010aS00<@Q0aS48@0112400DDYA2448@@Q1BU00@<H`03
5:D@Q124008<H`0348@<H`aS008<H`0448@<H`aS48@536<01A2436<<H`aS48@01PaS0a240PaS0Q24
10aS00<@Q0aS48@00Q240`aS00D@Q1BU48@<H`Q2008<H`0348@<H`aS008<H`0748@<H`aS36<@Q1S6
5:D00QS60Q240`aS00<@Q0aS48@01a2411BU1Q2400<<Ha2448@00a240PaS1A2400P<Ha2448@@Q0aS
248<Ha240`aS00L@Q0aS36<<Ha2436<8@P0636<348@236<448@00`Q236<<H`0236<148@136<12480
0009124000@Q124000@Q0008@P0000<48@047>Le[BDY48@27>L38@P29BT00bU:8@PQ20037>L28@P4
7>L01B487>LHaQcW8@P00RDY0b4800<U:B487>L00R480RDY00<Q21S67>L00R480acW124800DLiaBU
5:DHaQcW00<HaP8Li`8HaPDLi`038@PLiacW00<Li`DHaP8DY@036<HLiacW008Li`035:DHaQS600DH
aP@DY@8Li`8HaP035:DHaQcW008DY@066<HU:B486<H@Q1BU0acW11S600<Lib487>L011S600TDYAS6
5:DLiaS65:DHaR487>L00QBU00<Lib487>L00QS611cW0QS60QcW00<HaQcW7>L00QS60QBU0aS600<L
iaS67>L011cW0aS60QBU1AS600HLib487>LQ21S67>L36<H01QcW6<HDYA24248<H`88@PL48@030004
8@@Q00X48@0300048@@Q00l48@0424848@@Q1242248336<25:D00b489BTQ20028@P00aBU6<HQ2002
:DX00acW6<HQ20028@P46<H011BU36<<H`Q20PaS00D8@P@Q2488@P@Q0088@P0336<8@PQ200<48@L8
@P<48@03248<H`@Q00<8@P8<H`88@P031248@PQ200<8@P8<H`88@P061248@P@Q248<H`Q23P@Q00@0
00Q224848@D8@P0336<8@PQ20088@P031248@P@Q00848@0324848@Q200H48@0300048@@Q00@48@88
@P@48@@8@P848@88@P055:DQ22e[<H`U:@026<H65:D26<H00acW6<HDY@0448@35:D248@01@aS6<HQ
22486<H00Q2400<HaQBU5:D00a240QBU0aS60QBU00<@Q1BU6<H00QBU11S60QBU00@@Q1BU5:D<H`8@
Q08DY@L@Q0@<H`@@Q00336<@Q124008@Q00436<DYA2448@336<0112436<@Q1240PaS0Q2400D<Ha24
36<8@PaS008@Q0035:D@Q0aS008<H`0348@<H`aS008<H`<@Q00536<@Q0aS48@<H`0248@011BU48@@
Q0aS0Q240`aS0a240`aS00<@Q1BU48@0112410aS0a2410aS00HDYA245:DDYA245:D548@436<348@2
5:D348@00aBU48@@Q00348@00aBU48@@Q00236<348@01@aS48@@Q1245:D00PaS00H@Q0aS48@<H`Q2
36<248@336<00a245:D@Q00336<00a2436<<H`0236<248@336<248@00aBU48@@Q00248@336<348@1
36<0000300048@0000T48@077>LaS24848@HaR487>L00b4800HU:BU:9BTU:AcW6<H48@P27>L01B48
7>LLiaS67>L00RU:00<]JbU:7>L012480QcW00<Q22DY8@P0124811cW00@Q21cW8@PLi`8HaP045:DH
aQS65:D37>L26<H00acW8@PLi`037>L012487>LLiacW0QS600<DYAS66<H01AS60QcW0QS600<LiaS6
5:D00QS600HLiaS65:DDYAS65:D46<H031BU7>LHaQS65:DLib489BTLiaBU48@DY@8Li`0:6<HDYABU
7>LQ21cW6<HLiaS67>L26<H04aBU6<HHaQS65:DLibDY7>LHaQBU6<HQ21cW6<HDYAS67>LQ21cW008H
aP8Li`096<HDYAcW8@PLiaS65:DHaQBU008Li`8HaP067>LHaQS65:DHaQcW1AS60QcW00DHaQcW7>LQ
21cW008HaP077>LHaQS67>LHaQBU48@00PaS00D8@P@Q12448@Q200L48@0300048@@Q00@48@032484
8@@Q00H48@0324848@@Q00D48@0324848@@Q00@48@88@P0636<8@Q2448@DYAS60acW00DU:B486<HD
YAcW008]J`048@PLiacW9BT27>L01aS65:DHaQBU48@<H`Q2008<H`D8@P@48@<8@P848@D8@P031248
@PQ20088@P031248@PaS0088@P051248@PQ21248@P0236<3248236<224800`aS24848@0424831240
0`001248@P0312401@0012448@@Q24800P@Q0PQ200<48@Q224801@Q22@@Q00<8@P@Q24800P@Q00<0
00@Q12400P@Q00P000@Q24848@Q21248@P@Q10Q200<48@Q224800PQ200H@Q248;F/e[BDY7>L25:D0
11S67>LHaQ240QBU0QS60QBU00H@Q1BU5:DDYA245:D448@01QS68@PQ21cW5:D@Q08DY@8@Q00336<@
Q12400<HaP037>LDYA24008DY@046<HDYABU5:D27>L011S65:DHaQBU0a2411BU0Q240aBU0a240`aS
1Q240PaS00D@Q1BU48@@Q1BU00<@Q00436<@Q12448@236<248@00aBU48@8@P0336<00a2436<<H`03
48@01PQ236<<HaBU48@<H`<@Q00336<@Q0aS008<H`8@Q0035:D@Q0aS00@<H`8@Q0<<H`D@Q00336<@
Q0aS00@<H`0648@<Ha2436<@Q0aS11240aBU00D@Q0aS48@DYA24008<H`8@Q00336<@Q0aS00<DY@03
48@DYA2400<@Q0<DY@D@Q08<H`065:D@Q12448@DYA240`aS00<@Q0aS36<00Q2410aS00@@Q0aS36<<
H`8@Q00436<@Q0aS48@336<00`Q236<<H`0248@00`aS48@<H`0548@010aS48@@Q1240@Q200041240
0`0012448@0212402@0012448B48=JdQ21BU7>LQ20027>L00b489BTU:@029BT;7>L00b489BTU:@06
8@P37>L01B48:DXU:AcW8@P00bDY0QS600DLib489BTU:AcW008DY@056<HQ22487>LDY@056<H25:D0
1AcW8@PQ22487>L00QS60QcW00hHaQ246<HLib486<HDYAS68@PU:B487>LDYAS60QcW2QS60acW00hH
aQ246<HLiaS68@PU:AcW6<HDYAS67>LHaQBU0QS61AcW00<HaQBU5:D00QBU11S600<LiaS66<H00QS6
0QcW0QS60QcW0R4800LLiaS66<HHaQcW6<HDY@026<H00acW6<HHaP026<H57>L00aS67>LLi`046<H0
11cW6<HHaQS60QcW0R4800TU:B489BTHaQ246<HYBRe[7>L00PQ20PaS00D8@P@Q12448@Q200X48@03
24848@@Q00l48@0524848@@Q00048@022483124010Q21248@P@Q0`Q200H@Q1BU;F/aS2486<H236<0
11245:D@Q12411BU0QS600<DYA2436<010Q200<48@Q236<01@Q20`@Q10Q20`@Q10Q200@48@Q22484
8@<8@P848@@8@PP48@H8@Pd48@88@P848@03248<H`Q20088@P0448@DYAcW8@P27>L36<H010aS2484
8@@Q0PQ210@Q00<8@P@Q12400P@Q00<8@P@Q12403P@Q00X8@P0036<HaS6<@Q0e[BU:8@PDY@@HaP8D
Y@0448@HaQS66<H25:D248@011BU48@DYA240QBU00@Lib487>LDY@8@Q0036<HDYABU008<H`<HaP05
5:D@Q1BU7>LHaP035:D011S67>LLiaS60QBU00<@Q1BU48@01Q240aBU00<@Q1BU48@00QBU1Q2400<D
Y@aS48@00PaS0QBU0Q240PaS0Q240PaS00@@Q0aS48@@Q0D<H`0348@<Ha2400<<H`0548@<H`aS36<@
Q00236<00`Q236<@Q00336<00a2436<@Q00448@010aS48@<H`aS1A2400H<Ha2448@@Q1BU36<248@0
0aBU48@<H`0236<0112436<<Ha240PaS0a240PaS0a240PaS00<@Q1BU48@00PaS00<8@Q2436<00PaS
0Q240QBU00@@Q0aS48@DY@8@Q0045:D@Q12448@236<448@010aS48@@Q1240`aS00<@Q0aS48@00Q24
10aS0Q240PaS0a240`aS00<@Q0aS36<00PaS00D@Q0aS36<<Ha24008<H`<@Q08<H`@@Q04<H`48@P00
0P@Q00@000@Q124000H48@097>Le[BDY5:DQ21cW6<HLib4800<U:@047>LQ21cW7>L28@P47>L00b48
7>LLi`028@P00bDY8@PQ20038@P00acW6<HQ20039BT00b487>LQ20029BT01QcW6<HHaR48:DXU:@@H
aP@Li`HHaP@Li`046<HLiaS66<H27>L00aS648@DY@027>L00aS65:DHaP047>L36<H00acW6<HHaP07
6<H01QBU7>LLiaS65:DHaP<Li`8Q20077>LHaQBU5:DHaQcW6<H00QBU00<HaQcW8@P01AS600DDYA24
5:DDYAcW008HaP035:DHaQS6008HaP8Li`<HaP058@PLiaS65:DHaP027>L00aS65:DHaP027>L25:D0
1AS68@PQ21cW8@P00acW00@HaQBU6<HHaP8Li`DHaP8Li`8Q20059BTQ21cW48@HaP02:DX011cW36<8
@Q240PaS00<8@P@Q12400P@Q00<000@Q12402`@Q00<8@P@Q12404@@Q00<8@P@Q12400`@Q0`Q200d4
8A245:DYBS6<:DXLia2436<DYA2436<@Q0045:D00acW6<HDY@0436<324800`@Q248<H`02248336<0
20Q212448@@Q24848@Q2124824801@aS24848@@Q24800`@Q00<8@P@Q24800PQ20`@Q00<8@P@Q2480
10Q200<48@Q224803`@Q00<8@PaS36<00PQ200D<HaBU7>LQ21cW008DY@0448@HaPaS248212400`Q2
1248@P0612400`0012448@0612401@Q21248@P@Q24801`@Q00L@Q1cW:DXicS6<:DXU:@046<H45:D3
6<H011BU48@@Q1BU112400<DYAS67>L00QcW00<HaQ2448@01A2400DDYAS66<HHaQBU008HaP8DY@03
6<HDYABU008DY@036<HLiaBU00<DY@0548@<H`aS48@<H`0248@25:D348@01QBU48@@Q1245:D@Q08<
H`0548@DYA2448@<H`0348@236<248@236<01@Q236<@Q1245:D00Q240PaS0a240PaS0Q241@aS00<@
Q0aS36<020aS00@@Q0aS48@<H`D@Q00336<@Q124008@Q08<H`0:5:D@Q0aS48@DYA2436<8@PaS48@2
36<348@236<248@00`aS48@@Q00548@00`aS48@<H`0248@336<0112436<@Q1240QBU0a240`aS0QBU
0PaS0Q240`aS00<@Q0aS36<00PaS0Q2410aS11240`aS0Q242@aS0Q240`Q200<<Ha245:D00Q240PaS
1a240@aS0000100012448@0020@Q00LQ23W>9BT@Q1cW9BTLi`028@P01BDY:DXU:BU:8@P00RDY0QcW
0QS60R4811cW0R4811cW00DQ21cW7>LLib48008U:@@Q20<Li`<Q20047>LHaQBU6<H27>L00aS65:DH
aP037>L26<H47>L011S67>LLiacW0aS600HDYAS65:DHaQBU6<H47>L01AS67>LLiaS67>L00QS600<D
YAS66<H00aBU0QS60acW0QBU00DHaQcW7>LLiaS600<Li`046<HDYABU6<H27>L00aBU6<HLi`027>L0
0aS67>LHaP035:D26<H00aBU6<HLi`036<H00aBU7>LLi`037>L38@P01AcW6<HHaQS67>L00aS600@D
YAcW7>LQ208Li`046<HLiacW9BT27>L26<H01acW5:DHaQcW8@PU:AcW008HaP047>LQ22U::DX28@P2
5:D01QcW9BTLia2436<8@P8<H`@48@0300048@@Q00848@0300048@Q200<48@0624848@@Q00048@Q2
0P@Q00<8@P@Q12400P@Q00D8@P@Q12448@Q200@48@88@PP48@04248<H`aS36<2248040aS48@<H`aS
5:DHaQ24248<HaS648@48A24:DXaS1cW0P@Q0PQ200@<H`Q21248@P8<H`@8@P041248@PQ224821243
24800`@Q248<H`0424802`aS2488@PaS24848@Q21248@P@Q24800`@Q00<8@P@Q12400`@Q0`Q210@Q
00<8@P@Q12400P@Q00<8@P@Q12400P@Q10Q200H<H`Q248@HaR487>L448@010aS48@@Q1BU0Q2400<<
H`Q236<00PQ230@Q00<8@P@Q248020@Q00T8@P@Q124000@Q36<@Q2DY@Q000THa00@aS2488@PHaP8D
Y@8@Q00336<@Q1BU008HaP035:D@Q124008DY@<HaP<Li`<@Q0@DY@036<HDYABU008HaP8DY@8@Q08D
Y@0348@HaQS600<HaP8DY@0348@DYA24008DY@8@Q0<DY@0448@DYABU5:D348@01ABU48@@Q1245:D0
1A2400<<Ha2448@00Q240PaS1A240`aS00<@Q0aS36<00PaS0a2400<<Ha2436<00Q2400<<Ha2448@0
1PaS00<@Q0aS48@00Q240`aS0Q240PaS0a240PaS0Q2400<DYA2436<01Q2400TDYA2448@<Ha2436<@
Q0aS48@00PaS00@@Q1BU48@@Q08<H`<@Q0<<H`8@Q08<H`0348@DYABU008DY@L@Q0055:D@Q12448@<
H`0448@00`aS48@<H`0248@236<448@436<:48@01@aS248<H`aS48@00PQ200D<Ha2448@@Q0aS00<@
Q0@<H`D@Q048@P0000<48@0012400`@Q00@000Q2124000848@047>Le[BU:6<H58@P012DY:DXYBRDY
0b480QcW0QS600<Lib489BT00QcW00<Q22DY8@P00acW00DQ21cW7>LLib48008U:@<Q20039BTLiacW
00DLi`038@PHaQS6008HaP<Li`<HaP037>LHaQS6008HaP078@PLiacW8@PLiaS67>L00aBU00<HaQcW
6<H00aS60acW00PQ21S66<HHaQcW6<HLiaS611BU0QS60QcW0QS600@DYAS66<HHaP8Li`038@PLiacW
008HaP<DY@056<HDYABU5:DHaP047>L26<H25:D26<H37>L00aS65:DDY@037>L26<H57>L01QS67>LL
iaBU6<HLi`8HaP075:DHaQcW7>LQ21cW6<H00acW0QS600DQ21cW6<HHaQcW00<Q20<HaP038@P]JbU:
008U:@066<HDYAcW8@PU:AS60PQ200<<H`Q224802P@Q00D000@Q12448@0000848@0324848@@Q00D4
8@0324848@@Q00848@0324848@@Q00<48@88@PL48@H8@P0348@DY@aS008<H`0<48@HaPaS248<HaS6
5:D48A249BTaS2480P@Q00<<H`Q224800PQ210aS00@8@PaS2488@P<48@<8@P848@P8@P0336<8@PQ2
0088@P041248@P@Q248:1243248?12400`Q236<<H`0236<00a245:DHaP026<H25:D248@236<248@2
36<4248010@Q2488@PQ21`@Q00<8@P@Q12400P@Q00<8@P@Q24800P@Q00L8@P@Q12448@0024848@02
36<01b48?Nm6<D8@<H`HaQcW008HaP065:D@Q12448@DYA240QBU00HHaQBU48@@Q1BU7>L26<H01acW
6<HHaQS648@DYA24008DY@036<HDYA24008DY@036<HDYABU008DY@8@Q0045:DHaQS66<H35:D348@0
11BU48@@Q1240aBU0Q240aBU112400@DYA245:DDY@8@Q00336<@Q124008@Q08<H`<@Q00836<@Q124
48@<Ha2436<@Q0D<H`8@Q0@<H`0348@<H`aS008<H`8@Q0D<H`<@Q0<<H`0348@<Ha2400<<H`<@Q0<<
H`0348@DYA24008@Q00336<@Q0aS00<<H`<@Q0@<H`8@Q0035:D@Q124008@Q00436<@Q1245:D436<3
48@00`aS48@DY@026<H348@436<011BU48@@Q1240PaS11240PaS11240PaS00D@Q0aS48@<Ha24008<
H`0348@<Ha2400@<H`8@Q08<H`03248<H`Q200@<H`0348@<Ha2400@<H`0348@DYABU008@Q08<H`4@
Q04<H`000`@Q00<000@Q12401P@Q00LQ248@;F/DYAcW8@PU:@02:DX012489BTQ22480QcW00@Q21cW
6<HHaP8Q208Li`048@PLib488@P37>L28@P27>L011S67>LLiacW0R4800HU:B488@PLiaS67>L28@P0
1AcW6<HHaQS67>L00aS60QcW00<Q21cW5:D00QcW00DQ21cW6<HLib48008HaP<Li`036<HLib48008Q
208HaP<Li`076<HDYABU6<HLiaS67>L011BU00<HaQcW6<H011S600<DYAS67>L00R480QcW00XHaQcW
7>LQ21S65:D@Q1BU6<HLi`<HaP037>LHaQS6008HaP045:DLiacW7>L36<H27>L00aS67>LHaP027>L0
12487>LHaQS60QcW00@Q21cW6<HHaP<Li`<HaP047>LQ22487>L28@P46<H38@P37>L29BT01B486<HH
aQS67>L00R4800dLiaBU7>LYBR486<H<H`Q248@<H`Q21248@P0412400`0012448@0A124010Q21244
8@Q20`@Q0PQ21P@Q0PQ20P@Q10Q200H48@Q2248<H`Q2124224800`aS248<H`02248436<00`Q236<<
H`03248020@Q248<H`aS248<H`Q248@236<00`Q212448@032482124424800`@Q2488@P0224800`aS
2488@P0224801@aS24848@@Q24801P@Q00@8@P@Q12448@D8@PD48@88@P848@<8@P<<H`035:D@Q1S6
008Li`078@PLiacW6<HDYAS648@010aS00@8@P@Q12448@88@P0348@<H`@Q00<48@0424848@@Q2483
1242248010@Q24848@Q22P@Q00/<H`Q25:DYBSF]@Q0e[BDY8@PDYAS6008DY@0336<@Q1BU00<DY@04
6<HDYABU48@25:D00aS67>LHaP025:D548@35:D011S65:DDYA240QBU0Q2400@DYAS66<HDY@8@Q08D
Y@0448@DYA2436<35:D0112436<@Q1S60QBU0aS600@DYA246<HDY@<@Q0035:D@Q124008<H`0748@<
Ha2448@<Ha2436<01Q2400<<Ha2436<00PaS00<@Q1BU48@0112400PDYA2436<8@Q2436<8@PaS0Q24
0PaS1A240`aS1A240`aS2Q2400<<Ha2448@00Q2410aS00<@Q0aS36<00PaS00@@Q1BU48@@Q08<H`@@
Q08<H`8@Q08<H`0448@DYABU5:D348@00aBU48@@Q00248@436<448@00`aS48@@Q00648@236<00a24
36<@Q00548@00`aS48@@Q00236<00`Q236<@Q00636<00a2436<@Q00248@00`aS48@<H`0248@00`aS
48@<H`0448@136<000848@0300048@0000L48@058@Q2436<5:DLi`028@P39BT00b489BTQ20027>L0
2b487>LHaQS67>LQ22DY8@PLib487>L00R480acW00<Q21cW6<H01QcW00DQ22DY7>LHaQcW008Q2004
7>LHaQBU5:D26<H27>L25:D00aS67>LLi`067>L00b487>LLi`047>L01AS67>LU:AcW6<H00QBU0QcW
00<Q21cW5:D01QS60aBU1QS600@DYAS66<HHaP@Li`036<HLiacW008Li`0648@DYABU7>LHaQBU0QS6
0QcW00<HaQBU5:D00QcW0aS600DLiaS65:DLib48008Li`036<HLiacW008Q20037>LHaQcW008Li`<H
aP047>LHaQS66<H27>L38@P27>L36<H57>L28@P29BT01R487>LLiaBU6<HLi`8Q20066<HLibDY8@PH
aPQ20`aS00<48@Q212401`@Q00@000@Q1248@P<48@88@P848@88@P@48@<8@P@48@0324848@000084
8@0324848@@Q00D48@88@P061248@PQ236<8@P@Q10Q200H<H`Q22488@PaS248336<00`Q236<<H`03
248010@Q2488@PQ210aS0PQ20P@Q00D8@P@Q12448@Q200@48@88@P041248@PQ2124324800`aS2488
@P031242248312400`0012448@02248010@Q2488@PQ20P@Q0PQ21@@Q00<8@P@Q12400PQ20PaS00D@
Q1BU6<HDYAS600<Li`<DY@8@Q08<H`0424848@@Q1242248236<22482124224800`@Q2488@P051240
0`Q21248@P02124010Q212448@@Q0PQ20P@Q00X8@PaS248DYBDY>Li2436<9BTQ208HaP055:D@Q1BU
48@DY@0248@011BU6<H@Q1240QBU1QS600@DYA2436<DY@8HaP0548@DYABU6<H@Q0045:D01A245:DD
YAS65:D00a240QBU00<@Q0aS48@00aBU0Q240QBU0aS600<DYA2448@00QBU00<HaQBU5:D00Q2400<<
Ha2448@01Q2410aS00<@Q1BU48@00PaS00@@Q0aS36<<H`<@Q08<H`<@Q08<H`0348@<Ha24008<H`<@
Q08<H`@@Q0@<H`D@Q00536<@Q0aS36<@Q00236<00a245:D@Q00236<00a245:D@Q00536<348@00`Q2
36<<H`025:D348@00`aS48@@Q00248@436<01a245:DDYABU6<H@Q1BU008@Q08<H`T@Q0@<H`075:D@
Q0aS48@<Ha2436<00Q240QBU112400<DYA2448@01`aS00P@Q0aS36<<H`Q236<8@PaS112400@<Ha24
48@<H`L@Q04<H`0000<000@Q12400`@Q00@000@Q124000848@077>LicRDY7>LYBRDY7>L00R480Re[
0bDY00@HaQcW5:DDY@8Li`058@PLiacW7>LQ20036<H00acW8@PLi`057>L00aS67>LLi`028@P01AcW
9BTU:B487>L00QS60QcW0aS600HDYAS67>LHaQcW6<H67>L36<H27>L25:D00aS68@PU:@037>L36<H2
7>L011S65:DDYAcW0QS600@DYAS65:DHaP<DY@@HaP8DY@047>LQ21cW6<H25:D76<H00aBU6<HHaP02
6<H011cW6<HHaQBU0aS600@Lib488@PHaP8DY@067>LHaQS66<HLib4811cW0R4800<LiaS67>L01QcW
00@HaQcW7>LQ208U:@038@PLiaBU00<Li`8U:@068@PDYAcW9BTYBRDY0QcW00/U:AcW5:DDYAcW6<HD
YAcW9BTQ21BU00D8@P031248@P@Q00@48@0524848@Q21240000212401@Q212448@@Q00000`@Q00<8
@P0012400P@Q0`Q21`@Q0PQ20`@Q00<8@P@Q12400`Q200<<H`Q224800PQ200@<H`@Q12448@<8@P04
36<@Q0aS36<2248236<624821243248248@00`aS24848@0212422484124324800`@Q24848@0436<0
0`Q21248@P03248212400`Q212448@03124224831242248010@Q24848@Q20P@Q0PQ200H48@Q2248<
Ha246<H25:D02bDY<Ha6<DHa@Q16<Cg_>Lh]Jb487>L00PaS00@@Q0aS36<<H`@48@<8@PD48@032484
8@@Q00@8@P051248@PQ21248@P0212400`Q236<8@P03124324802`@Q248@Q248;F/YBS6<=JdU:AcW
48@01aBU00<HaQBU5:D00QBU0QS600<DYAS65:D00aBU00lHaQ2448@DYAcW6<HDYA245:D@Q1BU48@D
YA245:D00a240aBU00<@Q1BU48@00QBU112400<DYA245:D011BU1a240aBU00@@Q0aS48@<H`D@Q08<
H`8@Q0035:D@Q12400@<H`0348@<Ha24008<H`8@Q0035:D@Q0aS008<H`0448@<H`aS36<248@010aS
48@DYABU0Q240PaS00@8@PaS36<8@P<@Q0<<H`035:D@Q12400<<H`<@Q00336<@Q12400@@Q0<<H`03
48@<H`aS008<H`8@Q0035:D@Q12400<<H`8DY@0348@<Ha24008@Q0055:D@Q0aS48@DY@0348@25:D0
112436<<H`aS112400DDYA2448@@Q0aS008@Q0035:D@Q124008@Q08DY@@@Q0035:D@Q0aS008<H`03
48@<H`aS008<H`06248<H`Q248@<Ha240PaS112410aS0Q240`aS0Q240`aS00000`@Q00048@021240
0`0012448@04124011cW?NlYBQcW0RDY00<Q21cW9BT00RU:00LU:B488@PLiaS65:DHaP037>L00b48
7>LQ20067>L00b487>LLi`067>L28@P29BT28@P37>L46<H011cW6<HLiaS60acW00<HaQcW7>L00QcW
00PHaQcW7>LLiaS67>LDYAS60QcW00@U:B488@PLi`@HaP035:DHaQS600@HaPDDY@<HaP8DY@<HaP8L
i`8Q20LHaP<DY@<HaP037>LHaQS600DHaP<Li`<HaP8Li`<HaP8Li`088@PLib488@PLib487>LHaP@L
i`8HaP048@PLiacW6<H38@P00acW6<HLi`027>L00b489BTLi`027>L01BDY;F/Q21S67>L00R4800TL
iaS67>LHaQ247>L]JbDY5:D00PQ200<@Q0Q212400`@Q00<000@Q24803@@Q0`Q24P@Q00<8@P@Q1240
1`Q200H<H`Q236<48@Q2124324801`@Q36<<Ha2436<8@PaS00L8@P031248@P@Q00<8@P@<H`D48@03
24848@Q200<8@P848@04248<H`aS36<424831243248212422486124010Q236<8@PQ210@Q00@8@P@Q
24848@88@P8<H`0@48@DYAS6:DXaS48@>LhmkdHa@Q0icRU:8@PLiaBU48@336<01@Q212448@Q21240
10Q220@Q10Q20P@Q00@8@PaS36<8@P848@0624848@@Q24848@Q20P@Q00D8@Q246<H]JbU:008aS004
8@PLiaBU6<H25:D01A2436<DYABU6<H00QBU0Q240QS60QcW00HDYA2448@DYAS648@25:D26<H00aBU
48@@Q00448@00aBU48@@Q0055:D448@01ABU48@DYA2436<00Q240aBU00@@Q1BU5:DHaP8DY@0536<@
Q12448@DY@0348@00`aS48@@Q00248@01@aS48@@Q12436<0112400@<Ha2436<8@PP@Q08<H`88@P8@
Q0@<H`0348@<Ha24008@Q08<H`8@Q0@<H`@@Q08<H`<@Q08<H`8@Q00536<@Q1BU5:D@Q00536<448@2
248236<35:D748@236<348@25:D248@236<248@25:D736<448@00aBU48@@Q00748@25:D448@01`aS
48@<Ha2436<@Q0aS0088@PP<H`@@Q00636<@Q0aS36<@Q0aS1A240@aS000312400`0012448@041240
1P00248Licg_;F/HaP8U:@038@PU:BU:008]J`03:DXQ21cW008HaPLLi`8Q20<Li`078@PU:BDY7>LH
aQBU6<H00QcW00<HaQcW7>L00R480RDY00HQ21cW6<HHaQcW5:D27>L28@P00acW8@PQ20047>L01B48
7>LLib486<H00QBU00DHaQcW6<HDYAS6008Li`8HaP048@PLiacW5:D26<H25:D00aS67>LHaP035:D5
6<H01QBU6<HDYABU6<HLi`8Q20037>LHaQBU008HaP065:DHaQcW8@PLiaS60QBU00<HaQBU6<H00QS6
00<DYAS66<H00acW0QS60QcW0QS60QcW00@Q21S66<HQ208U:@068@PLiacW7>LQ22DY0acW11S600<L
iaS67>L00RDY00<Q21S67>L0124800LYBRDY8@PQ21cW8@PU:@028@P03AcW6<HHaQS648@Lib48:DXU
:ABU48@8@P@Q0088@P@48@0324848@@Q00848@0324848@0000<48@0324848@@Q00P48@0324848@Q2
00P48@0424848@Q2124224821242248336<52483124010Q236<8@P@Q0`Q20PaS00D8@P@Q2488@PaS
00P8@P0436<DY@aS36<2124010Q21248@P@Q0PQ20P@Q0PQ200@<Ha2448@@Q08<H`D8@P848@03248<
H`aS00@48@0324848@Q200848@@8@P0L1248@P@Q24848@Q21248@PaS124<Hc6<DYA>Lbe[:DXmkfLi
HaQNmf]JG_MS65:D>Lh]JaS648@236<324861243248512400`Q21248@P032484124324800`@Q2484
8@0312401`Q21248@P@Q36<Libe[009:DP05<H`YBQBU5:DHaP0248@00aBU6<HDY@035:D36<H01QcW
6<H@Q1246<HLi`8DY@0348@DYAS6008HaP035:D@Q124008@Q0DDY@0548@DYAS66<HDY@0248@25:D2
48@00`aS48@@Q0035:D02a245:DDYA245:DHaQBU48@DYA245:D00Q2400LDYA2436<<Ha245:D@Q003
36<448@25:D348@336<648@01@aS48@@Q1BU48@00PaS00<@Q0aS48@00PaS0a2400@DYA2436<<H`88
@P<@Q08<H`8@Q0036<HDYA24008<H`<@Q0@<H`045:D@Q124248236<248@01@aS48@<Ha2436<00a24
0PaS00H8@PaS48@DYAS65:D348@00aBU6<HDY@025:D011245:D@Q0aS0Q2400<DYA2448@00PaS00D@
Q1BU48@DY@aS00H@Q00536<@Q1S65:DHaP025:D648@436<00a2436<<H`0736<00a2436<<H`0236<0
1A2436<<H`aS48@00PaS00<@Q0aS36<010aS00021240200012448@@Q0008@P@Q000212401R48?NlY
BQcW:DXU:@8Q2006:DXaS2e[8@PHaQcW0QS62QcW0b480RDY0QcW00@DYAS66<HHaP8Li`<Q208U:@03
8@PLiaS600<HaP037>LQ22DY00<Li`059BTQ21cW7>LQ20027>L01AS67>LHaQS65:D00QS600@LiaS6
7>LLi`@HaP8Li`<HaP055:DHaQBU7>LHaP055:D66<H00acW6<HHaP037>L36<H00acW6<HHaP027>L6
6<H25:D01QS67>LHaQcW6<HDY@@Li`036<HLiacW008Li`076<HLiacW7>LQ22DY8@P00acW00<Q22DY
8@P00R4800<LiaS66<H00aS600@Q22DY9BTQ208Li`079BTQ21cW7>LU:BU:9BT00R4800DU:B487>LL
ib48008Li`8DY@067>LU:BU::DXDYA2410Q25P@Q0PQ22@@Q00<8@P@Q12400P@Q0`Q20P@Q00<8@P@Q
12400`aS00H8@P@Q2488@PaS24821242248312401PQ236<<H`aS24848@<8@P0536<8@PQ2248<H`04
248236<0112436<48@Q20`@Q0PQ200@48@Q212448@88@P0436<@Q12436<424800`aS24848@032482
124324801@@Q2488@PQ212400`Q200@48@Q22488@P848@@8@P03124<HcF]009:DP8]J`0:@Q1W>Ekg
G_MW>EkgHaQ>Lcg_;F/25:D00`aS2488@P0912400`Q212448@0212400`Q212448@03248212400`Q2
12448@02124424800`@Q2488@P021242248010@Q248LibU:0TYB00DaS2U:48@DYAS6008DY@8@Q004
5:DHaQS65:D46<H01QBU48@DYABU7>LHaP<DY@8HaP8DY@0648@DYA2448@DYAS60QBU0Q240aS600<D
YA245:D00aBU00@<H`Q236<<H`<DY@8HaP0948@DYABU48@DYAS65:D@Q0aS008DY@8@Q00336<@Q1BU
008@Q0035:D<H`aS008@Q0035:DHaQ2400<@Q0<<H`H@Q0035:D@Q0aS00L@Q08<H`04248@Q1245:D4
48@436<248@236<248@00aBU48@@Q00736<348@00`Q236<<H`0336<00a2436<<H`0236<348@01ABU
48@<Ha2436<00aBU00D@Q0aS5:DDYAS6008@Q00636<@Q1245:D@Q0aS0QBU00@@Q0aS36<<H`8@Q004
5:D@Q0aS248248@00aBU48@@Q00348@35:D011245:DDYABU0Q2400<<H`Q236<01PaS0`Q200<<Ha24
48@00`aS112400L<Ha2436<<Ha2436<@Q00336<148@136<0000500048@@Q12400007124011cW?Nla
S1cW0bDY00HYBR488@PU:BU:7>L25:D00aS68@PHaP057>L01QS68@PQ22DY:DXU:@8Q20@Li`@HaP05
8@PU:BU:9BTQ20036<H47>L012489BTQ21cW0aS60R4811cW0aS600DLiaS66<HHaQcW00DHaP067>LH
aQBU48@DYAS60aBU00<@Q1BU5:D01ABU1AS60acW0QS60QBU0QS60acW00<Q21cW8@P00aS600@DYAS6
5:DHaP8Li`046<H@Q1S67>L28@P26<H00acW6<HHaP025:D01QS68@PU:B487>LQ208Li`8Q20039BTQ
22DY008U:@8Q20037>LHaQcW00DQ20DU:@047>LHaR489BT2:DX38@P47>L01QBU48@U:CF]<H`Q2088
@P0336<8@P@Q00@48@0300048@Q200X48@0500048@@Q1248@P0312400`Q212448@0=12422482124=
248010@Q24848@@Q1@Q200<<H`Q2248010Q20PaS00@8@P@Q24848@88@P<<H`@8@P<48@88@P8<H`04
5:DHaQBU5:D236<2248010aS1248@P@Q0PQ200@<H`Q224848@88@P<48@0324848@@Q00H8@P848@04
24848@Q2124248@01b48BU9S65Je@Q0e[DYB00=_N`09JeYW>G_NMkeW>DHa7>LDY@Q200@48@050004
8@001240000812400`Q21248@P04248010aS12448@@Q0PQ20`@Q00<8@P@Q12400`Q20P@Q00d8@QS6
:DY>LdHaBU9>Lc6<:DXDYA245:D@Q0035:D00a245:DDY@026<H01ABU48@@Q1BU6<H00QBU0Q2411BU
00<@Q1BU48@00Q2400H<Ha245:D@Q1BU6<H27>L00aBU48@@Q00548@00aBU48@@Q00248@45:D248@0
0aBU48@@Q00448@25:D26<H25:D248@336<448@00aBU48@<H`0448@736<248@336<011245:D@Q124
0PaS00@@Q0aS36<<H`<@Q08<H`0348@<H`aS008<H`8DY@0648@DYA2436<@Q0Q20PaS00@@Q0aS36<<
H`<@Q08<H`<@Q0<<H`0;48@DYA2436<@Q0aS48@<Ha2436<@Q00236<00a245:DDY@025:D011245:D@
Q1BU0a240`aS0Q240PaS0a240`aS212400@DYA2436<<H`8@Q0035:DHaQ2400H<H`<@Q088@P0436<@
Q0aS36<248@01PaS248<Ha245:D@Q088@P0436<8@Q2448@636<00004124000@Q000812401acW@Q0]
JacW8@PU:B4800@U:@038@PLiacW00<HaP@Li`046<HLiacW7>L39BT38@P47>L00aS67>LLi`027>L0
12DY;F/YBR4811S60QcW0R480QcW00<Q21S67>L00QcW00@Q22DY7>LLi`<HaP035:DHaQS600<Li`05
6<HDYABU5:DLi`026<H011BU48@DYAS60aBU0QS611BU00<HaQBU5:D00QBU0aS611cW0QBU00<HaQcW
7>L00QS600HLib487>LLiaS67>L25:D27>L26<H01QBU6<HHaQS67>LHaP@Li`066<HDYABU6<HLibDY
124800DLib488@PQ22DY00<Q20047>LQ21cW7>L38@P01BDY8@PQ21cW8@P00RDY0R4800<Lib489BT0
0RU:00DQ22DY8@PQ21S6008Li`035:D@Q248008aS0048@P<H`aS36<2248312400`0012448@081242
248:12400`Q21248@P0:124010Q21248@P@Q0PQ20P@Q00<8@PaS24801@Q200<48@Q2124010Q200D4
8@Q22488@PaS0088@P041248@PQ236<3248236<00`Q212448@0236<01A242488@PaS24800`@Q0`Q2
0PaS0aBU00@@Q0Q2248<H``8@P031248@PQ200<48@88@P031248@PQ200P8@P8<H`087>M6<EkgF]I2
43F]BU9[FP9_N`08JeYS67_NMke[FTHa8@PHaP@48@0300048@@Q00D48@0324848@0000848@032484
8@Q20088@P041248@PQ2248612422485124020Q236<48@@Q48@YBTicAS42BU82;F/35:D248@25:D0
0aS65:DDY@036<H01A245:D@Q1BU6<H00aBU00PHaQBU5:D@Q1BU48@DYA240aBU00L@Q1BU5:DHaQcW
6<HDY@0248@01QBU48@DYABU48@<H`<@Q0045:D@Q1BU48@25:D011245:D@Q1BU1A240aBU00@@Q1BU
6<H@Q0<<H`D@Q00436<@Q0aS36<448@00`aS48@@Q00248@00aBU48@<H`0336<0112436<<H`aS1Q24
10aS0a2410aS0QBU00<<Ha2436<00a241`aS00@@Q0aS36<<H`@@Q08<H`0348@DYABU00@<H`0348@<
Ha2400@@Q0035:D@Q1BU008DY@P@Q0D<H`0348@<H`aS008@Q08DY@H@Q0035:D@Q12400T@Q00336<8
@PQ200@<H`88@P0336<@Q12400D@Q00336<8@PaS008@Q0<<H`0348@<H`aS008@Q04<H`001@@Q00<0
00@Q12400P@Q00H000@Q7>Lmkc6<8@P69BT28@P00acW6<HHaP027>L26<H01B487>LLiaS68@P00RU:
0bDY0R480acW00DHaQcW5:DLib48008YBP<Q20@HaP<Q20039BTQ2248008Li`086<HLiacW7>LHaQcW
8@PLi`<HaP8Li`LHaP8Li`8HaPLDY@066<HDYABU5:DHaQBU0acW0aS600<Lib488@P00QS60QBU0QS6
0acW0QS60acW0aS600<LibDY6<H00Q2400@DYB487>LLi`8Q200:7>LHaQBU6<HLib486<HDYAS67>L2
9BT01B489BTU:BU:9BT00R4800HU:BU::DXLiaS67>L29BT022487>LLib489BTQ21cW6<H28@P00aS6
8@PU:@02<H`042DY8@PLiaS68@PLib487>LDYBDY<H`]JacW248<Ha240PQ20P@Q00<000@Q12400P@Q
00<000@Q12404@@Q00<8@P@Q12400`Q21@@Q00L8@PaS36<8@P@Q248<H`0224800`@Q248<H`0236<4
2482124324800`aS2488@P03248010@Q248<H`aS0PQ200@48@Q236<<H`L8@P0436<8@PQ212422480
2@@Q24848@@Q48@HaQcW5:D8@P0236<00`Q236<@Q00236<3248236<0112436<48@Q21`@Q00@8@P@Q
2488@P@<H`0:248<H`Q21248@QS6>Li[FVLiCW<2?Nl00dYBKg]_N`02JeX01fLiJeYcW7_NKg/aS1S6
00848@0524848@@Q1240000412400`0012448@0212400`Q212448@02124224800`@Q2488@P041240
0`Q212448@05124324803@@Q248<HaS6?Nm6<F]JKg]:DSW>6<H@Q1S600@@Q08HaP045:D@Q0aS36<5
5:D01a245:D@Q1245:D@Q1BU00L@Q0055:D@Q1BU6<HLi`026<H45:D648@00aBU48@DY@035:D01124
5:DDYABU0a2400<HaQBU6<H00aBU00<HaQBU48@01a2400<<Ha245:D00Q2400D<Ha2436<DYA2400@<
H`035:D@Q12400D@Q08<H`8@Q00336<@Q0aS00<@Q00936<@Q12436<@Q1BU48@<Ha24008DY@0<48@<
H`aS48@<Ha2436<@Q0aS248<HaBU0Q2400<8@PaS36<00`aS0Q2400@<Ha245:DDY@<<H`0448@<H`aS
36<548@45:D448@436<0112436<@Q0aS1A2400H<Ha245:DHaQBU48@236<01Q2436<<H`aS48@DY@8@
Q00336<@Q0aS00<<H`8@Q0D<H`03248<H`aS00<@Q0<<H`8@Q08<H`<8@PD<H`48@P4<H`4<H`0000D0
00@Q00048@0000L48@067>Lmkbe[7>LU:BU:0bDY00@Q21cW7>LHaPHLi`036<HLiacW008Q20049BTY
BRU:9BT48@P27>L01AS65:DHaQcW8@P00RU:00<Q21cW6<H00QS60QcW0bDY0acW00@Q21cW7>LHaP8L
i`056<HQ22488@PLi`076<H011BU6<HDYAS60QcW00<HaQBU5:D00QS60QBU00@@Q1S66<HHaP@DY@@H
aPDLi`8HaP8DY@046<HLiacW7>L26<H00acW6<HLi`046<H00b487>LLi`035:D00acW6<HLi`038@P2
6<H00acW6<HHaP026<H28@P012U:9BTU:B480RDY0RU:00@Q22DY:DXQ20<Li`8U:@@Q20099BTQ21cW
7>LQ21cW6<HLibDY008aS0038@PLiaS600@Li`065:D@Q2U:=Jd]JacW0PQ20PaS1@@Q00D000@Q1244
8@Q200D48@0324848@@Q00T48@0324848@@Q00848@0524848@@Q1248@P02124224800`aS1248@P03
24821245248010@Q248<H`aS0`Q200@<H`Q224848@P8@P031248@PQ200D8@P031248@PQ200@<H`88
@P848@0924848@Q236<DYAS65:D<Ha2400<8@P0336<@Q0aS00<8@P@<H`0524848@@Q1248@P051240
0`Q236<<H`0236<2248236<030Q2000<HacW=JeW>F<HDYA243W>BU9[FP=_N`07IcU[FW>LNmi[FSF]
7>L00PQ200@48@00124000@48@0300048@@Q00H48@05248<H`Q224848@02248212400`001248@P03
2485124030Q212448@Q236<HaT8@AS5[FVmkBU8icPDDY@0348@DYABU008HaP035:D@Q124008@Q0<D
Y@076<HDYA245:D<HaBU48@00QBU00@<Ha2448@@Q08DY@0648@DYAS66<HLiaBU0a240QBU00<@Q0aS
36<00Q2400LDYA2448@@Q1BU48@DY@0548@00`aS48@@Q0036<H25:D548@25:D00a2436<<H`0436<2
48@011BU48@@Q1240PaS0a2400HDYA2436<@Q1BU48@436<448@236<248@00aBU48@@Q00336<348@0
1ABU48@@Q0aS48@010aS00P8@PaS36<@Q0aS248<Ha240`aS0a2400<DYA2448@00a241PaS0Q2400<D
YA2448@00QBU1Q240PaS0Q2400L<Ha2436<@Q1BU36<8@P0248@011S65:D@Q0aS1Q2400<<Ha2448@0
0QBU0a2400L<Ha2448@<H`Q236<8@P0536<00a2436<<H`0236<248@336<248@00`aS2488@P0336<2
48@136<000H48@040008@P@Q0002124011cW>LhYBR480bU:0R480QcW0R4811cW00HDYAcW9BTYBRDY
8@P39BT012487>LQ22480bDY0QS60QcW00LU:BU::DXYBRDY7>LHaP025:D28@P29BT011cW8@PLib48
0acW1QS60QcW00<HaQcW6<H00QcW0QS600LDYAS67>LLib487>LHaP025:D26<H35:D00a246<HDY@02
6<H25:D26<H37>L01b489BTLiaS65:DHaQcW00<HaP8Li`@HaP047>LHaQcW7>L26<H01AcW6<HHaQS6
7>L00b480acW11S600HLiaS66<HLib489BT38@P01BU:;F/aS2e[:DX00RDY00DLiaS67>LQ22DY008H
aP058@PYBRDY7>LHaP057>L012DY;F/]JbDY0b480acW00`Q21cW5:DQ236<:DXDY@@Q36<HaPaS2485
12400`001248@P091242248812400`Q212448@02124010Q212448@Q20`@Q0`Q20P@Q00@8@P@Q2484
8@H8@P848@0536<@Q0aS24848@0=248236<010Q236<@Q0Q20P@Q00<8@PaS36<010aS00<8@P@Q2480
0P@Q00<<H`Q236<00PaS00<8@PaS36<01`aS0Q2400@8@P@Q12448@88@PL48@0624848@Q2248@Q1BU
0Q2400d8@P@Q248Q248@IcUNmd8@?NlicSg_HaQ[FP02Li`01f<HJeY_Ng_NKg/e[AS60088@P0336<8
@P@Q00P48@0324848@@Q00848@<8@P0336<8@PQ20088@P031248@P@Q00H48@0300048@@Q00<8@P06
1248@P@Q48@e[Cg_0VLi00E243W>6<HDYAS6008DY@0648@DYA2448@<HaBU0Q2400@<HaBU5:DDY@8@
Q08DY@0548@DYA2448@<H`0348@011BU48@@Q0aS0a2400@DYAS67>LHaP@DY@L@Q0035:D@Q12400@D
Y@0348@<HaBU00<DY@0448@HaQS65:D236<00a246<HDY@0248@00aBU48@<H`0336<00a245:D@Q002
48@00aBU48@@Q00348@01aBU48@@Q0aS48@<Ha2400<<H`L@Q0045:D<Ha2436<348@236<448@436<0
1A2436<<H`aS48@00`aS00<8@PaS36<00PaS1A2400H<Ha2436<<Ha245:D248@00`aS248@Q00236<2
48@011BU48@DYABU0Q240PaS00@@Q0aS36<<H`8@Q00:36<@Q1245:D@Q1BU48@<Ha245:D236<548@2
36<248@00aBU48@<H`0236<00a2436<<H`0248@010aS2488@PaS11240`aS0Q240PaS0PQ200D<Ha24
48@@Q0Q200D<H`88@P0000H48@00124000@Q000612402AcW?Nl]JacW9BTYBRDY8@PLi`038@P011cW
6<HLiacW0QS600@LibDY:DXU:@8Q208U:@09:DXQ21cW8@PYBRDY8@PDYAS6008Li`059BTYBRDY9BTQ
20026<H011BU6<HQ22480RDY00HQ21cW7>LLib487>L46<H011BU6<HHaR480QcW00@HaQcW6<HLi`@H
aP068@PLiacW7>LHaQBU1AS600@@Q1BU48@DY@8Li`036<HDYAS6008Li`056<HLib489BTLi`025:D2
7>L01ABU6<HHaQcW6<H011cW0QS600HLiaS67>LLiaS65:D36<H00acW8@PLi`028@P00aS67>LDY@02
6<H47>L01b489BTU:AcW8@PYBS6<008]J`0?:DXU:Be[8@PDYAS68@PYBR487>LQ22U:9BTQ21cW008H
aP057>LQ21cW:DX]J`02:DX00acW8@PU:@037>L02b486<HDYBU:>LhYBQBU124<HaBU36<03`@Q00<8
@P@Q12401@@Q00<000Q2248010@Q0PQ20`@Q0`Q20P@Q0`Q200D48@Q22488@P@Q00D8@P031248@P@Q
00<<H`0524848@Q2248<H`0524800`@Q2488@P04248336<324801@aS248<H`aS24800`aS0PQ200@4
8@Q22488@PD<H`0:248<H`aS248<H`Q236<@Q0aS48@236<00`Q21248@P0312400`0024848@051240
10aS248@Q1BU0Q2400d8@P@Q248Licg_JeYNmdYB?NlaS48@HaQ[FP02Li`026<HJeYcW7ooJeXe[B48
124224800`@Q2488@P0312400`0012448@0224821242248212400`Q236<<H`04248010@Q24848@Q2
0P@Q00<8@P@Q12400P@Q0`Q200H48@Q2248@Q36<@Q02IcT00dHa>LhLi`026<H45:D00a245:DDY@06
48@00aBU48@DY@035:D00a2436<@Q00248@010aS48@@Q1BU0a2411BU0QS61ABU0a240QBU0QS600<D
YA2448@00QBU00H@Q0aS36<@Q1BU6<H25:D00a245:DDY@0548@25:D010aS48@@Q0aS1a2400@DYA24
5:D@Q0DDY@@@Q0<<H`8@Q08<H`<@Q00336<@Q124008@Q08<H`8@Q0035:D@Q1BU00@@Q0D<H`8@Q003
36<8@PaS00@<H`0448@<H`aS36<248@536<448@336<011245:DDYABU1A2410aS0a240PaS0Q2400<D
YA2448@00a2400<<Ha2448@00Q240`aS00<@Q0aS48@00a240`aS00<@Q0aS36<01`aS0Q240PaS00@8
@PaS36<@Q0P<H`88@P<<H`88@P0000<000@Q12402@@Q00TLid8@;F/Lib489BTYBRDY8@P00QcW0b48
00@HaQcW7>LLi`8Q20049BTYBRU::DX29BT28@P01AcW8@PLib489BT00b480QcW0RDY00<Q21cW5:D0
0QcW0QS60R480QcW0R480QS600DLib488@PHaQBU00HHaP037>LHaQcW00<HaP037>LHaQS6008Li`@H
aP035:DHaQS600<HaP035:DHaQBU00<HaP8DY@8Li`078@PLiaS66<HLiaS65:D00aS600<LiaS67>L0
0QS600<LiaS67>L011cW00@HaQBU5:DHaP@Li`038@PLiaS6008Li`068@PLiacW6<HLiaS60acW00PD
YB48;F/mkdYB@Q0icSF]0R4800<HaQcW9BT00RDY0QcW00LU:BU::DXLiaBU6<HLi`028@P01AcW9BT]
JcF];F/00b4800lLiaS67>LU:B486<HQ22U:8@PDY@Q236<@Q0aS248050@Q00P8@P@Q124000@Q2484
8@Q20P@Q1@Q20P@Q1`Q200H<H`Q21248@PaS2483124324800`aS1248@P07248010aS248<H`aS0`Q2
00<<Ha2436<00PQ20PaS1@Q210aS00<8@PaS36<010Q20Q240PaS00@8@PaS48@<H`<8@P<<H`072484
8@Q224848@Q212400PQ220@Q0PaS0PQ20PaS00h48@aS5:DU:E:DF]HmkbDY8@PaS5[FCW=F]F<H0VLi
00EJeU:DAS4YBQcW00@@Q0045:DLiaBU36<212400`Q21248@P03124010aS2488@P@Q0PQ200<<H`Q2
24800P@Q00@8@P@Q12448@88@P848@88@P051248@P@Q24848@0324802Re[?NmW>E[F@Q1:DRU:7>LD
YA2411BU00<@Q1BU5:D011240QBU00LHaQBU5:D@Q1BU48@<H`0948@00aBU48@@Q00348@01QBU6<HH
aQS65:DHaP8DY@H@Q0035:DHaQBU008@Q08<H`0448@DYABU48@25:D26<H25:D348@00aBU48@@Q005
48@00aBU48@@Q00248@45:D248@25:D348@436<448@236<248@011BU48@@Q1BU1a2400P<Ha2448@@
Q0aS48@DYA240PaS00<@Q0aS36<00`aS1a240`aS1Q240PaS112400DDYA2448@@Q0aS00<@Q0<8@P8@
Q08<H`8@Q00336<@Q124008@Q00436<@Q1BU36<248@25:D01A245:DDYA245:D00PaS00<@Q0aS48@0
0Q2400D<Ha2436<<Ha2400@<H`8@Q0<<H`0348@<H`aS00<<H`04248<H`aS48@236<010Q236<<Ha24
0PaS0@Q2000412400`0012448@0212401`0012448ABU>LhaS24800@U:@8Q20057>LQ21cW7>LQ2005
7>L39BT012U:9BTQ22DY0b480RDY0acW00<U:B489BT00RDY00<Q21cW6<H00aS600@Q21cW7>LLi`@Q
20037>LHaR48008Li`076<HDYAS67>LQ21cW6<H00QcW00<HaQcW6<H00aS60QcW0QS60QBU0aS600<L
iaS65:D00aBU00LLiaS65:D@Q1BU6<HQ20027>L28@P011cW6<HHaQcW11S60QcW0aS611cW00DQ21cW
7>LHaQBU00<HaP8Li`038@PLiaS6008HaP8Li`<HaP0<7>LQ22486<HDYAcW:DY244YB@Q0e[Be[0RDY
00<Q21cW7>L00R480QcW00@Q22U:9BTLi`8HaP087>LQ22486<HU:Be[<H`]J`<Q20036<HLiacW008Q
20066<HQ22U:7>LDY@Q20PaS00D8@P@Q12448@0000D48@0500048@@Q1248@P051243248412422483
12400`Q21248@P0212442483124524800`@Q2488@P02248212400`Q236<8@P0624821246248436<3
248336<324800`@Q36<8@P0336<4248236<00`Q236<<H`0336<224801@aS248<H`Q236<00`Q200D4
8@Q224848@Q200H48@0524848@@Q1248@P0236<060@Q36<<H`@Q248<HbDYDYAJeT8@:DXLic6<E[EB
U5JeIcU[FVLiG_MF]DYB;F/Q20<@Q00536<Lib486<H<H`03124324800`@Q2488@P0:2483124010Q2
12448@Q20P@Q00d000@Q24848@Q2124<H`@Q248]Jcg_IcUNm`02@Q0012DY7>LDYA240aS611240QBU
0a240aBU00D@Q1BU48@@Q0aS008@Q0035:D@Q0aS008@Q0055:D@Q1245:D@Q00236<00aBU6<HDY@04
6<H248@00aBU48@DY@0648@00aBU48@@Q00248@25:D348@00aBU6<HHaP0348@26<H00aBU48@<H`02
48@00aBU48@@Q00236<248@25:D648@00aBU48@DY@0248@336<648@011BU48@@Q1240PaS1Q2400@D
YA2448@<H`8@Q00336<@Q12400@@Q00436<8@PQ236<548@00`aS48@<H`0336<248@00`aS48@<H`02
36<010Q248@@Q1240QBU00<@Q0aS36<00Q2400@<H`Q236<@Q08<H`D@Q08DY@0536<@Q12448@DY@04
48@00aBU48@@Q00448@00`aS48@@Q00436<0112436<<Ha242@aS00D@Q0aS36<<H`Q200H<H`0648@<
H`aS248<Ha240@aS00000`@Q00048@0212400`0012448@04124011cW>LhU:AS60b481AcW00DQ21cW
8@PQ21cW008Q20059BTYBRU::DXU:@068@P00bDY8@PQ20038@P02BDY7>LQ22487>LHaQcW6<HLi`02
6<H37>L38@P47>L011S65:DDYABU0aS60QcW00<HaQBU6<H00QS60QcW00<Q21cW6<H00QcW0QS600DD
YAS66<HDYAS6008DY@<Li`<HaP8DY@036<HLib48008HaP045:DHaQS65:D26<H00aBU6<HLi`028@P2
7>L00aS67>LHaP056<H27>L00b487>LLi`027>L28@P011cW8@PLiacW0b4800hLiaBU7>LLiaBU8@P]
Jcg_CW=:DU:DBU9243F]0RDY0b4800HLibDY:DXU:B487>L26<H01AcW8@PU:B48:DX00S6<00<]Jb48
7>L00QcW00@Q21S65:DLi`8]J`049BT@Q1BU48@2248>12422484124010Q212448@@Q0PQ210@Q0PQ2
00@48@Q2248<H`88@P041248@PQ236<3248236<7248010@Q2488@PQ20P@Q1PQ20PaS0`Q200<48@aS
48@00Q2400H<H`Q2248<H`Q236<6248236<2248236<224800`@Q248<H`0336<01PQ236<<H`Q21248
@P8<H`<8@P0436<8@PQ2248336<21240100024848@@Q0PQ20`@Q00<8@PaS24800PQ20PaS01DDYB48
;F/Lia248@Pe[DYB?NlaS48@AS5243F]<H`icSg_>LhYBQcW5:D00aS600<<H`Q224800`Q20`@Q00<8
@PaS48@00`Q20PaS0PQ20P@Q00<8@P@Q24800P@Q0`Q200<48@Q224800PQ200<48@Q236<00P@Q00PL
icF]IcUBU4icHaQ6<C6<0QBU00<HaQBU48@00a2400<DYA2448@00Q240QBU0a2400<<Ha2448@00QBU
0a2400<DYA2448@01A2400<DYA2448@00Q2400<DYAS65:D00QBU00@HaQBU5:DDY@8@Q0<DY@8@Q0<D
Y@@@Q0HDY@0348@DYABU008DY@@@Q0035:D@Q1BU00<DY@036<H@Q124008@Q0035:DHaQBU00h@Q003
5:D@Q12400D@Q00636<@Q1BU6<HDY@aS0Q240PaS00D@Q1BU5:D@Q0aS00<@Q0<<H`03248@Q12400D@
Q0<<H`0348@<H`aS008<H`T@Q0@<H`8@Q0<<H`0348@<Ha2400<@Q0045:D@Q12448@236<348@25:D0
11S648@DYABU1A2400@<Ha2448@@Q0@<H`0348@<H`aS008<H`8@Q0@<H`06248<H`aS36<@Q0aS0PQ2
0PaS0Q240`aS0A240@aS0@aS0000100012448@0020@Q00@HaSW>;F/Li`@Q208Li`046<HLib488@P3
7>L00b489BTU:@029BT012U:9BTQ21cW0R480bDY0R480QcW00@Q21cW8@PQ20<Li`075:DHaQS66<HQ
21cW8@P00acW124800dLiaBU5:DDYAS67>LHaQcW8@PLiaS65:DLi`028@P26<H37>L36<H01aBU7>LL
iacW6<HDYA2400@HaP8DY@@HaP038@PLiacW008DY@046<HLiacW6<H35:D011cW9BTU:B480QS600<L
iaS66<H011S600<Lib488@P01AcW0R4800HLib487>LQ21cW6<H37>L26<H02B48<Ha244icBU9>LdYB
?NlicP029BT47>L01B489BTYBRDY8@P00QBU00PLibDY9BTHaRDY<H`icS6<0QcW0R4800TU:AS648@Q
22U:;F/U:A245:D00PaS00<8@P@Q12401@@Q00<8@P@Q12403P@Q00<8@P@Q24800P@Q00<8@P@Q1240
0PQ200<<H`@Q24800PQ200H48@Q22488@P@Q248336<324831243248010@Q2488@P@Q0`Q20P@Q0PQ2
0PaS0PQ20`aS00@@Q0aS248<H`88@P<<H`0324848@Q200@<H`03248<H`aS00X<H`0624848@@Q248<
Ha240PQ200@<H`Q22488@P8<H`D8@P031248@P@Q00@48@D8@P0A124<H`aS5:DYBRe[9BTDYB48>Li>
LcW><H`mkdYBAS4icP03=Jd01CW>:DXQ21BU6<H00QcW0PaS0PQ200<<H`Q224800P@Q0PaS00<@Q0aS
24800PaS0PQ20`@Q00<8@P@Q12400`Q200@<H`@Q12448@<8@P0?1248@Q2424848B48=JeNme:DCW=W
>DHa<H`HaQ24008HaPDDY@@@Q0HDY@8@Q00636<@Q1245:D@Q1BU0Q2400D<Ha2448@@Q1BU008@Q003
5:D@Q124008DY@056<H@Q1BU5:DHaP025:D348@00aBU48@DY@0248@00aBU6<HDY@0348@01ABU6<HH
aQS65:D0112400<DYA2448@00Q2400<DYA2448@01ABU00H@Q0aS48@DYAS65:D236<01A245:D@Q1BU
48@00PaS1A240QBU00<@Q0aS36<00Q2400<<Ha2448@00QBU0a2400@<Ha2448@@Q0<DY@0348@<H`aS
008<H`03248<H`Q200<<H`8@Q0D<H`<@Q0@<H`06248@Q12448@DYA240`aS0Q2410aS00<8@PaS36<0
1A2400@<Ha2448@DY@8@Q08<H`0348@HaQS6008DY@D@Q0045:D@Q12448@836<248@836<2248=36<1
48@1248000848@0800048@@Q124000Q2124000848@056<HicRe[7>LQ20047>L012487>LQ22480RDY
00DQ21cW7>LQ22DY008]J`<U:@8Li`<Q208Li`048@PU:BDY8@P37>L00b487>LLi`046<H00b489BTQ
20037>L00b489BTQ20027>L66<H01acW9BTLiaS65:D@Q1cW00<Q20047>LHaQS66<H47>L012487>LQ
21S60aBU31S60QBU00@@Q1BU5:DHaPDLi`8HaP045:DHaQS67>L26<H27>L01bDY7>LHaQcW6<HLib48
00<Li`8U:@03:DXQ21cW008Li`<Q20087>LQ21S6:DXicTHaDYA6<@8icP05:DXU:AcW7>LU:@028@P0
1RDY8@PLiaS67>LU:@8Q208Li`049BT]Jbe[:DX27>L01R489BTU:AS65:DU:@8icP058@P@Q1S66<H@
Q00912400`Q212448@07124010Q212448@Q20PaS00<8@P@Q12400PQ200D<H`Q2248<Ha24008<H`88
@P8<H`88@P8<H`057>LicSF]9BT8@P02124324800`@Q2488@P06248010aS2488@PQ21`aS00<8@P@Q
12400PQ200@<H`Q248@@Q088@P848@<8@P<<H`0348@<H`aS00<<H`0348@8@PQ200848@0324848@Q2
00<8@P8<H`<8@P0336<8@PaS008@Q08<H`L48@@8@P0436<8@PQ2248236<00a245:D@Q00248@01QBU
6<HHaQcW8@PU:@<Q200:9BTe[CF]<H`Q21S68@PLiaS65:D248@010aS2488@PQ20P@Q00<8@PaS48@0
112410aS0`Q200L48@Q22488@P@Q248<H`03248010@Q248<H`aS0P@Q00`DYBDYDYA:DU[FIcU:DSW>
7>LDYAS648@35:D448@011BU6<HHaQBU0Q240QBU00@HaQBU48@@Q0<DY@0348@DYA2400<@Q0035:D@
Q124008@Q00436<@Q12448@25:D248@01ABU6<HDYA2436<00Q2400@DYA2448@@Q0<DY@@@Q0@DY@8@
Q08DY@0448@DYA2436<248@25:D011245:DDYABU112411BU0Q2400<<HaBU5:D00QBU00<@Q0aS36<0
0a2400<DYA2448@00`aS00@@Q1BU5:DDY@H@Q08DY@H@Q08<H`8@Q0<<H`H@Q00436<@Q12448@836<0
11245:D@Q0aS0a241PaS0Q2410aS0a2400<<Ha2448@00Q240PaS00<DYA2448@00aBU00<@Q0aS36<0
0Q2400<DY@aS36<00Q2400<<H`Q236<00Q240`aS112430aS0Q241`aS00001@0012448@@Q00001@@Q
00H000@Q6<HicRU:6<H28@P27>L011S67>LLib480RDY00PQ22DY9BTQ22DY:DX]JbU:0RDY00<Q22DY
9BT00R480QcW0R480RDY0R4800<HaQcW7>L00R480QcW00DHaQcW9BTU:B4800<Li`<U:@048@PLiaS6
6<H25:D26<H01AcW8@PQ21cW5:D00QS62AcW0QS60R4800HLiaS65:DHaQBU6<H25:D00aS67>LHaP03
6<H011cW5:DDYABU0QS600@@Q1S66<HQ20HLi`036<HDYAS600<HaP047>LQ22488@P97>L00bDY:DXQ
20026<H00b489BTQ20027>L01b487>LYBSW>BU9F]DHa008icP059BTLiacW8@PYBP039BT012487>LL
iacW1B4801<U:Be[;F/U:B487>LQ21cW8@PHaQBU:DXicS6<9BT@Q1S65:D<H`03248712400`Q21244
8@0212400`Q212448@03124624821242248010aS248<Ha240PaS0PQ20`aS0`Q200HLicF]>LhQ20Q2
000224800`@Q2488@P0924801@@Q2488@PQ248@00PaS0`Q20PaS00@8@P@Q2488@P<<H`H8@P@<H`06
248<H`Q236<8@PaS0Q2400H<H`@Q24848@Q2124224800`aS248<H`0224800`aS248<H`0336<00a24
2488@P0212400`Q212448@02124424801@aS248<H`Q248@00QBU0Q2400<DYAS67>L00QcW00@Q22DY
9BTU:@8Q2005<H`mkc6<9BTHaP027>L011S65:DDYA240PaS00@48@Q21248@P8<H`@@Q0<<H`H8@P84
8@03248<H`aS00848@@8@P0=36<@Q0Q2124DYBDYDYA:DUJeIcU>Ld8@9BT01QBU11240QS600HDYA24
48@@Q1BU6<H348@01ABU48@DYAS65:D00a2400LDYA2448@@Q1BU48@<H`0248@45:D011245:DDYA24
0QBU0a2400@DYA2448@@Q0<DY@<@Q0@DY@0348@DYABU00@DY@0448@<Ha2448@45:D01Q245:DDYA24
5:D@Q08DY@8@Q0<DY@T@Q08DY@0448@DYA2448@236<011245:D@Q1BU1Q2400HDYAS65:DDY@aS48@2
36<0112436<<Ha240PaS21240`aS0a240PaS0a240PaS0Q2400HDYA2436<8@PaS48@536<348@236<2
48@25:D01A2436<@Q1245:D00a240QBU11240PaS0QBU0PaS00H8@Q2448@@Q0aS48@236<0212436<@
Q12436<8@PaS248336<00`Q236<<H`0236<348@336<248@136<00003124000@Q00848@0300048@@Q
00@48@046<HicRU:6<H28@P37>L28@P011cW8@PU:BDY0R4800DYBS6<=Jd]JbU:008Li`038@PLib48
008Li`058@PLib489BTQ20027>L01B489BTLiacW6<H00acW0R4800DU:B489BTU:B48008Li`8U:@08
8@PHaQBU7>LHaQBU6<HLi`8Q208HaP047>LDYAcW8@P29BT00acW5:DHaP067>L01b486<HHaQBU6<HD
YA24008DY@8HaP047>LHaQBU6<H65:D36<H28@P011cW5:DDYAS60QcW0QBU0QS611cW1B4800<LiaS6
7>L00QcW00HQ21cW7>LLib487>L39BT28@P02QcW9BTQ22U:>Li243F]9BTHaQcW12480QS61QcW0R48
00<Lib488@P00RDY0R480acW00/HaQBU<Ha243g_9BT8@PaS48@<H`Q200848@0300048@@Q00@48@03
00048@@Q00@48@88@P848@H8@P031248@PaS008@Q0DDY@0348@<H`aS00<@Q08<H`0548@DYABU5:D<
H`04248212400`Q2124<H`03248010aS24848@Q20PaS10Q20`aS0`Q200<000@Q24800PaS10Q200<4
8@Q2248010aS00D@Q0aS48@<Ha24008<H`D8@P031248@P@Q0088@P<<H`041248@PaS248536<22485
1244248236<01@Q236<<H`aS24800PaS00<8@PaS248011BU00D<Ha246<HDYAS6008DY@056<HLiaBU
5:D@Q0035:D00a2436<8@P0212402@Q236<DYA245:D@Q1BU48@DY@0248@00`aS48@<H`0;24801@aS
24848@Q236<00PQ200T@Q1S6?Nm245[FHaQ>LdHa:DX00QcW00<DYAS66<H011BU0a2400DDYA246<HH
aQcW008DY@0348@DYABU008DY@0548@DYAS66<HDY@0248@00aS65:DDY@0248@236<35:D00aS65:DD
Y@065:D00a2436<@Q00248@45:D00a245:DDY@025:D011245:D@Q1240QBU0a240QBU00<HaQ2448@0
0aBU0Q240aBU0Q240aBU00<@Q1BU5:D00a2400<DYA2436<01a2400@<Ha2436<@Q08DY@@@Q0035:D@
Q1BU00D@Q0@<H`8@Q0<<H`0548@<Ha2436<@Q00236<348@224800`aS48@<H`0436<00a2436<<H`03
48@01@aS248<H`aS48@010aS00H@Q0aS48@<Ha2436<348@26<H248@236<35:D248@010aS48@@Q1BU
0Q240`aS0a240`aS0Q2420aS00@@Q0aS36<@Q0<<H`<@Q08<H`03248<H`aS008<H`000P@Q00<000@Q
12401`@Q00DLicW>9BTLibDY008Q20047>LQ22487>L28@P00bDY8@PQ2002:DX01c6<=JdYBRDY8@PL
ibDY00@Q208Li`8Q20039BTQ21cW008Li`8Q208Li`056<HLib487>LQ20039BT01R487>LQ22489BTQ
20@HaP045:DHaQcW8@P37>L26<H00acW8@PU:@027>L26<H57>L28@P00aS65:DDY@026<H25:D26<H0
0aBU6<HDY@026<H011BU6<HDYA240QBU00<HaQcW7>L00QcW00PHaQBU5:DLib487>LHaQBU0aS60b48
21cW124800DLib487>LLib48008U:@038@PLiacW008U:@07:DY2448@=Jd]JaS67>L00RDY00<Q21cW
6<H00acW0b4811cW00@Q22DY9BTU:@<Q200<7>LQ21BU5:DaS4Ha>LhQ20Q236<@Q0aS0PQ20P@Q00<0
00@Q12402`@Q00<000Q2248010Q200<<H`Q224800PQ200L<Ha2448@DYA245:D@Q00336<00a245:D<
H`0236<01ABU6<HLiaBU36<00`Q200D48@Q224848@Q200848@88@P<<H`<48@8<H`051248@PaS36<8
@P031243248336<00`Q21248@P05248936<01PQ21248@P@Q24848@88@P8<H`04248<H`Q236<22480
0`aS48@<H`0236<324800`@Q24848@0212400`Q236<<H`02248236<5248436<00aBU48@DY@0348@3
5:D01QS67>LLiacW6<HDY@8@Q08DY@0348@<H`Q200848@03248@Q1BU00@@Q0055:D@Q12436<@Q003
36<00`@Q248<H`03248212400`Q236<8@P0324802@aS1248@Q246<HicT8@F]IS6002CW<012e[7>LD
YA240QS60aBU00<@Q1BU5:D011BU00@LiaS66<HDY@8@Q0035:DHaQS600LDY@T@Q0<DY@086<HDYA24
48@<HaBU48@DY@H@Q0<DY@8HaP035:D@Q12400<@Q0<DY@8@Q08DY@8@Q0055:DHaQ245:D@Q0025:D2
48@25:D02A245:D@Q1BU48@DYA245:D@Q00236<00aBU48@@Q00248@00aBU48@@Q00236<248@01AS6
5:D@Q12436<011240aBU0Q2400<<Ha2448@00a240PaS0a240PaS00<@Q0aS36<01PaS0Q2410aS00D@
Q0aS36<<Ha2400@<H`<@Q00636<@Q0aS36<@Q0aS0a2400@<Ha2448@DY@L@Q0055:D@Q12448@<H`04
48@436<00a2436<<H`0236<0112436<@Q1BU3`aS0Q240PaS00<8@PaS36<00@Q200001@0012448@@Q
000010@Q00`000@Q124Q23W>:DXDYB48:DXU:B486<H27>L01R489BTU:BDY8@PU:@8YBP<U:@03:DXU
:B48008Q208Li`8HaP037>LU:B48008Li`036<HQ22DY00<Q20037>LQ224800<Q20067>LQ21cW6<HL
iaS60QcW00@Q21S66<HDY@HLi`8Q20037>LHaQS6008Li`046<HLib488@P36<H57>L25:D01AS67>LL
iaBU6<H00QcW00XHaQBU5:DHaQBU6<HDYA245:DHaP8Li`038@PLiaS600@HaP8DY@046<HLiacW8@P5
7>L26<H00acW8@PQ20028@P27>L00aS67>LLi`058@P2:DX01BDY8@PLib489BT00RU:0QcW0R4800<L
iaS66<H011cW00@Q22U:9BTLi`8HaP035:DQ2248008YBP058@PLiacW7>LQ20027>L01Be[>Lh]Jb48
36<00Q240PQ220@Q00<000Q212401P@Q00<8@P@Q24800P@Q00@8@PaS36<8@P8<H`0648@DYAcW9BTY
BRDY0R4800LLiaS66<HDYA245:D@Q00236<4248010aS5:D@Q0aS0P@Q0PQ200@<H`Q21248@P8<H`03
24848@@Q00H8@P0936<8@PQ224848@Q236<8@P@Q00<8@P848@03248<H`Q20088@P<<H`88@P0336<8
@PaS00<<H`031248@P@Q00848@03248<Ha2400<<H`<8@P<<H`88@P0336<8@PQ200<8@P848@04248<
H`aS48@2248236<424800`@Q2488@P02248248@236<00aBU6<HDY@0248@27>L01aBU36<8@Q245:D@
Q0aS00<48@03248<Ha2400L@Q08DY@8@Q0@<H`0324848@Q200@8@P031248@PQ200<8@P848@0>248<
H`aS<Ha246<HF]I6<E:D>LhU:AS648@HaP8DY@8@Q0<DY@0348@DYABU00<HaP<@Q0065:DHaQ245:DH
aQBU0a240aBU00<HaQBU48@00Q2400@<HaBU5:DHaP8DY@0348@DYA2400<DY@0648@<Ha2448@DYA24
2QBU00<@Q1BU5:D0112400@DYA2448@@Q0@DY@<@Q08DY@0648@<Ha245:DHaQBU0Q240aBU0a2400D<
Ha2448@@Q1BU00<@Q00836<@Q1BU48@DYAS648@<H`8@Q0055:D@Q1BU48@DY@0248@00`aS48@<H`02
48@336<248@436<00a2436<<H`0248@336<00a2436<<H`022480112436<<H`aS0Q2410aS00<8@PaS
36<00Q240PaS00@@Q0aS48@@Q08<H`8@Q0045:D@Q12436<648@011BU48@@Q0aS0a2400<<H`Q236<0
0`aS00<@Q0aS36<00Q241`aS00D@Q0aS48@<Ha2400D<H`0348@<H`aS008<H`0348@<H`aS004<H`00
0`@Q00<000@Q00001P@Q01<Q23W>8@PDYB48;F/U:AcW8@PLiaS67>LU:BU:;F/U:B48:DX]J`02:DX4
9BT00b487>LLi`037>L00b487>LQ20048@P01AcW8@PQ21cW8@P00acW0RDY00@Q21cW6<HLi`8Q20<L
i`056<HDYAS67>LQ20027>L38@P01acW6<HLiacW8@PLiaS6008Li`<HaP037>LQ21cW00<Li`8DY@05
6<HLiacW6<HDY@056<H35:D011245:DDYAS60acW00<Q21cW6<H00QBU0QcW00<HaQcW7>L00QcW0QS6
00@Lib487>LLi`8HaP8Li`<Q208Li`8HaP0@8@PU:BDY7>LQ22DY:DXU:B487>LQ22U:;F/U:B487>L2
8@P01QcW6<HHaQcW6<HLi`HQ20<Li`048@PYBRU:8@P27>L021S68@PLiacW;F/e[Be[7>L336<22480
0`0012448@0412400`0012448@0812400`Q212448@0336<3248248@00aS67>LLi`038@P37>L25:D0
0a245:D@Q00436<224801PaS5:D@Q0aS1248@P848@@8@P031248@PQ200<8@P0336<8@PQ200@8@P06
1248@PaS36<8@PaS0`Q200<48@Q224802@Q200<<H`Q236<00`aS0PQ20`@Q0PQ200D<Ha2448@8@PaS
00848@04248<Ha2436<224800`aS24848@03248010@Q2488@PaS0PQ200<<Ha2448@00PaS00D8@P@Q
1248@P@Q0088@P8<H`88@P0648@DYAcW48@<HaBU0QS600@DY@Q236<<H`8@Q00736<8@P@Q24848@Q2
36<00Q2400LDYA2448@@Q1BU48@DY@0348@236<010@Q248<H`aS0PQ200D48@Q224848@Q2008<H`88
@P0<124<H`Q236<aS48@G_MJeTHaDY@icRDY0QBU00DLiaS65:DDYA2400@DY@0548@DYAS67>LHaP02
5:D011245:D@Q1S60aBU00DHaQBU5:D@Q1BU008@Q0045:D@Q12436<348@65:D00aS65:D@Q0035:D0
112436<@Q12421BU112400DDYA245:D@Q0aS00<@Q0@DY@8@Q0035:D@Q1BU00<DY@0348@DYABU008H
aP8DY@@@Q00436<@Q1245:D248@00`aS48@<H`0348@011BU48@@Q1BU0a240QBU1Q240`aS0Q240`aS
00@@Q0aS36<<H`<@Q08<H`0448@<H`aS248736<248@236<2248236<00a2436<<H`0336<00a2436<<
H`0236<248@25:D748@35:D248@010aS48@DYA240PaS00@8@Q2448@DY@@<H`8@Q00536<8@PaS36<@
Q00536<0112436<<H`aS0a2420aS00000`0012448@0912402BDY>LhU:ABU8@PYBRDY8@PLi`028@P6
9BT01B489BT]JbU:8@P00QcW0R4800LU:AcW5:DLib489BTLi`026<H00acW8@PU:@037>L00bDY8@PQ
20047>L00aS67>LLi`047>L26<H01A245:DLiacW8@P00QcW0RDY00DQ21cW7>LLib4800<Li`035:DH
aQS6008HaP<Li`8HaP8DY@8HaP8Li`8HaP077>LHaQBU5:DHaQcW6<H00aBU00<HaQcW7>L011cW00DH
aQcW7>LHaQBU008Li`059BTQ21S66<HLi`028@P01QcW6<HHaQcW8@PLi`DQ20056<HLiacW7>LQ2003
9BT01R487>LLib48;F/U:@8Li`8U:@047>LHaQS67>L26<H27>L012487>LQ22480QcW00<HaQBU8@P0
0RU:00<Q21S66<H00acW00PQ21cW9BTU:B486<H8@PaS0PQ200<48@Q2124050@Q0PQ20`aS00DHaQcW
<H`icT8@009>L`06DYA6<CW>>LhQ21S60aBU00H@Q0Q22488@P@Q248236<22482124324801P@Q2488
@PaS24848@88@P0436<8@PQ2124324800`@Q24848@0624800`@Q24848@0624800`aS2488@P022482
124010Q236<<H`aS10Q200@<Ha245:DDY@@<H`D8@P<<H`0324848@@Q00<8@P051248@PaS248<H`03
48@324841247248021245:D48@@Q=JeW>EJe8@P212400a2436<8@P0224800`@Q2488@P0336<00a24
36<<H`0336<01ABU48@HaQS648@00PaS0PQ200<48@Q236<00PQ200L48@Q22488@P@Q248<H`052480
2RU:>LiS65[FCW=NmdYB;F/HaQ240QS600<DYA245:D00aBU00D@Q1S66<HHaQBU00<@Q0035:DHaQS6
008@Q0035:DHaQ2400@DY@046<H@Q0aS48@35:D348@36<H55:D00a246<HDY@0348@01QBU48@DYAS6
7>LHaP8@Q0DDY@0348@DYA2400<@Q08DY@0348@DYA2400@DY@8@Q0@DY@0348@DYABU008DY@0348@D
YA2400<@Q08DY@0348@DYABU00<@Q0<DY@<@Q08DY@<@Q0035:DHaQ24008@Q08<H`8@Q0035:D<Ha24
00<@Q0<<H`<@Q0D<H`8@Q00436<8@PaS248336<448@736<00a245:D@Q00336<348@01ABU48@<H`aS
48@00QBU00@@Q0aS36<@Q08DY@D@Q0L<H`0348@<H`aS008@Q0<<H`05248<H`aS36<@Q00236<00a24
36<@Q00636<248@010aS48@8@PaS0@Q200021240100012448@0010@Q00T000@Q7>LicRDY6<HU:BU:
9BT00QcW0R4800PU:B488@PU:BU:;F/U:B480RDY00<Q21cW7>L00b480QS600@Lib489BTQ208HaP04
7>LQ22488@P27>L29BT00b487>LHaP027>L012DY8@PLiacW0aS600DLiaS65:DDYAS6008Q20056<HL
ibDY9BTQ20026<H67>L26<H011BU7>LLib480QcW00<HaQcW6<H00aS60acW0QS600<DYAS65:D00QBU
0Q2400HDYAS66<HLiaS67>L38@P03QS65:DHaQS67>LQ22DY7>LHaQcW8@PU:B486<H47>L38@P37>L0
0b487>LQ20048@P01bDY8@PLiacW9BTYBRDY008Li`038@PLiacW00<Li`066<HLiacW8@PLib480RDY
00/LiaS65:DHaRDY:DXU:B485:DHaQcW00<Q20037>LQ22DY008Li`0348@<H`Q20088@P051248@P@Q
124000021240100012448@Q220@Q0PQ200@48@Q21248@P8<H`056<HQ22e[>Lhmk`03CW<01DHa?Nle
[B486<H00aBU00@@Q0Q236<<H`848@0536<@Q12424848@02248010@Q2488@PaS0PQ200<48@Q236<0
0PaS00X8@P@Q12448@Q236<8@P@Q248<H`<8@P0336<8@PQ20088@P041248@PQ21242248236<72480
20aS48@<H`aS24848@aS48@25:D00a24248<H`0524801`aS248<H`Q21248@P@Q00@8@P091248@PQ2
36<@Q1BU48@<H`Q200<48@D8@P041248@P@Q36<25:D212401c6<HaQJeR481248@Q2400<<H`@8@P03
36<@Q12400<<H`0448@DYA2448@45:D0112436<8@P@Q0PaS00<8@P@Q12400PQ20P@Q01<8@PaS36<<
H`Q236<48@Q2:DXmkfLiF]I:DU[FAS4]JaS648@HaP0:5:D36<H01A245:DHaQS65:D00Q240aBU00@@
Q1BU6<HHaP8@Q0<DY@036<H@Q1BU00<@Q0HDY@0648@DYABU48@DYA2411BU11S611240QS600@DYA24
36<@Q0DDY@0348@DYABU008DY@0348@DYA2400<DY@<@Q08HaP035:D@Q124008<H`<DY@8@Q08DY@8@
Q00336<@Q124008DY@@@Q0<DY@036<HDYABU008@Q00336<@Q12400@@Q08<H`<@Q00336<@Q12400@<
H`<@Q08<H`<@Q0P<H`<@Q08<H`0348@<H`aS00<@Q0<<H`8DY@<@Q00536<@Q12448@DY@0448@011BU
48@@Q0aS0Q2400D<H`Q248@@Q0aS0088@PD@Q0<<H`04248<Ha2448@336<248@236<248@636<148@1
36<136<00005124000@Q1240000712401QS6=JdYBQcW:DXQ20<Li`038@PU:BDY00@U:@8Q20<U:@8Q
20037>LQ21cW008Li`056<HU:BDY8@PLi`026<H58@P01BDY8@PLiacW6<H00QcW00<Q21S66<H00QS6
00@LiaS66<HDY@<HaP8Li`038@PU:BDY008Q208Li`036<HLiaS600<HaP@DY@<HaP047>LHaQS66<H2
5:D26<H01B487>LLiacW48@00QBU00DHaQcW6<HHaQBU008HaP8Li`048@PLiaS65:D26<H27>L01AS6
7>LQ21cW8@P00QcW00<Q21cW7>L00acW0R480QcW0b480QS600DLib488@PQ22DY00DQ208Li`<Q20@L
i`036<HLiacW00<Q20069BTQ22487>LDYAS60QcW0RDY0acW00<Q22DY7>L00QS600XQ22U:9BTHaQBU
248<H`Q21248@P<48@0300048@@Q00@48@0500048@0012400006124424803a245:DYBS6<AS5F]Ekg
JeY_NgNmKg]Nme[F;F/U:@0348@00`aS2488@P022483124010Q21248@PQ21P@Q0PQ200<48@Q22480
0PQ200H48@Q22488@P@Q2483124424800`@Q24848@0324801@aS2488@PQ236<010Q200<48@Q22480
10Q20`aS00<8@PaS36<00`aS00L8@PaS248<H`Q236<8@P0336<4248236<424801A246<HHaQ2436<0
0PQ20`@Q00<8@P@Q248010@Q0`aS00P8@PaS5:D@Q1BU48@8@PaS0PQ21@aS0PQ20PaS0Q2400@<H`Q2
36<<H`8DY@056<HU:B489BTHaP02248010@Q248<H`Q20P@Q00@8@P@Q2488@P8<H`0?248<Ha242484
8B48>LiS65[FAS5JeTic>LhU:A24008DY@8HaP035:D@Q124008DY@036<HDYA2400DDY@036<HDYABU
00@DY@046<HDYABU5:D648@01QBU48@DYABU48@DY@8HaP035:D@Q12400<DY@<@Q0035:D@Q1BU008D
Y@036<HDYABU008DY@0348@DYA2400<DY@0348@<H`aS008@Q0035:D@Q12400@@Q0@DY@0548@DYABU
5:DHaP035:D248@00aBU48@DY@035:D348@55:D011245:DDYA240PaS00<@Q1BU5:D01Q2400<<Ha24
48@00a240`aS00D@Q0aS48@<Ha2400@<H`0348@<H`aS00<<H`88@P<<H`0348@<H`aS008<H`8@Q003
36<@Q124008@Q0<<H`P@Q00336<@Q124008@Q00536<@Q12448@DY@0348@436<0112436<@Q0aS1124
10aS00<8@Q2436<01`aS0Q2400L<H`Q2248<HaBU36<8@P0436<12480000300048@@Q00<48@040008
@P@Q000212402AcW>LhU:AS68@PYBRDY8@PLi`028@P012DY:DXYBRDY124800LYBRDY8@PHaQcW8@PL
i`026<H01AcW8@PU:BDY8@P00QS60QcW00HU:B488@PQ22DY8@P27>L01b487>LHaQS67>LQ21cW008H
aP035:DHaQS6008HaP8Li`<Q208Li`8Q20047>LHaQcW7>L26<H011BU6<HHaQS60QBU11cW00<HaQBU
6<H00QBU0acW00@HaQBU48@DY@<HaP035:DHaQS600<HaP047>LHaQS65:D26<H00aBU6<HLi`027>L0
0b487>LLi`028@P00acW8@PHaP077>L01RDY7>LLiacW8@PU:@8Q20037>LQ2248008Q20057>LQ22DY
9BTQ20037>L26<H47>L01R489BTU:BDY8@PLi`<HaP037>LU:BU:008Q20036<HQ22DY00<Li`068@PU
:BDY7>LDY@aS0`Q23`@Q00<8@P@Q12401P@Q0PQ200LDYA249BTaS4YBE[EJeP02Kg/02gNmJeYNme:D
=JdYBQ2436<8@PaS48@00PQ200D48@Q21248@P@Q00D8@P031248@PQ20088@P031248@PQ20088@P03
1248@PQ200848@D8@P031248@PQ200D8@P041248@PQ21243248236<00`Q21248@P03248236<32480
0`@Q248<H`0236<01124248<H`Q20`aS0`Q20PaS00D8@P@Q1248@PaS00<8@P8<H`0548@DYA245:D<
H`02248212400`Q21248@P021245248236<01@Q248@HaQBU36<00PQ200<<H`Q236<010aS0`Q20a24
00/<Ha24248<Ha2436<HaR48:DXU:AS6008<H`@8@P051248@P@Q1248@P0336<2248030aS24848B48
=JeS65JeBU9JeTic?NlQ208@Q08DY@036<HDYABU00<@Q08DY@8HaP8DY@0448@DYABU6<H25:D021S6
5:DHaQBU6<HDYA2436<248@00aBU48@DY@035:D00a245:DDY@027>L02ABU48@@Q1S648@<Ha245:DH
aP095:D248@01ABU6<HDYA245:D00a240QBU0`aS0aBU112400@<Ha2448@@Q0@DY@8@Q0045:D@Q0aS
48@35:D548@25:D248@35:D348@35:D548@336<011245:D@Q1BU0PaS1Q2410aS0a240`aS0PQ200<<
Ha2436<00`aS00<@Q0aS36<00a2400<DYA2448@00Q240PaS00<@Q0aS36<00Q2400<<Ha2448@00QBU
0Q2400<<Ha2448@00Q2400@DYA2448@@Q0D<H`8@Q0<<H`<@Q005248<H`Q236<@Q00436<00a2436<<
H`0248@236<00a2436<<H`0236<00a2436<<H`01248000848@0300048@@Q00L48@066<He[BDY6<HQ
22DY0R4822DY00<Q22DY9BT01B481AcW0R480acW0b4800PLibDY9BTU:AcW6<HQ21cW11S60QcW0QS6
00@DYAS65:DHaP<Q20<Li`036<HLiacW008HaP8Li`035:DHaQS6008HaP8DY@036<HLiaS600<HaP03
7>LQ21S600HHaP057>LHaQS66<HDY@076<H47>L021S65:DHaQcW9BTQ21cW6<H37>L38@P37>L00b48
7>LLi`0;7>L012489BTYBRDY124800<LiaS67>L00acW00<HaQcW9BT00R4800@U:B488@PLi`@HaP0D
8@PU:BDY8@PLiaS67>LQ22DY7>LHaR48:DX]Jb4836<@Q0Q236<8@PT48@0300048@@Q00848@032484
8@Q200T48@0<248DYAS6<H`icU:DJeY_Ng>LJeYW>F]J0W_N00=>LcW>48@00PaS10@Q00d8@P@Q1244
8@aS48@DY@aS00048@Q21248@P0212432484124010Q236<8@P@Q0`Q20P@Q10Q200@48@Q21248@P84
8@88@P031248@PQ200<8@P041248@PaS36<3248336<01@Q212448@Q2124010aS0PQ20`aS00@8@PaS
36<<H`D8@P0436<8@PaS36<248@436<00`Q212448@0212422482124336<00`@Q248<H`03248236<0
0`Q236<@Q00336<248@236<248@25:D4248236<01aS69BTYBRU:7>LDYA24008<H`88@P848@88@P8<
H`0C48@<H`Q2248@Q0Q2124HaRe[E[EBU4icG_MBU48@;F/DYAS648@05QBU00<HaQBU5:D00QBU0a24
11BU00@@Q1BU5:DLi`8HaPT@Q0065:D@Q12448@DYAS60aBU0QS600HDYA2448@DYA245:D348@00aBU
48@<H`0248@011BU48@DYABU0a2400H<Ha2448@HaQBU6<H25:D448@35:D00a245:DDY@025:D348@2
5:D26<H0212436<@Q1246<HDYA245:D248@00aBU36<@Q00236<448@236<248@00`aS48@@Q00736<0
0a2436<8@P0236<00a2436<<H`0636<448@236<348@00`aS48@@Q00:48@00`aS48@@Q0025:D00a24
36<@Q00248@00`aS48@@Q00248@236<0112436<<Ha241@aS11240`aS0Q240PQ200@<Ha2436<<H`8@
Q0<<H`4@Q04<H`0000H000@Q124000@Q000412402000124LicF]:DXHaR489BT28@P39BT28@P29BT0
0b489BTQ20029BT38@P011cW8@PLiaS611cW0QS60QcW0RDY00@Q22DY:DXQ20DLi`066<HLiacW7>LH
aQcW11S611cW00DQ21cW6<HLib48008Li`<HaP0;8@PLiaS66<H@Q1BU6<HDYAcW8@PLi`026<H00acW
8@PHaP026<H27>L00aS65:DDY@026<H011BU6<HHaQS611cW00@HaQcW7>LLi`@HaP037>LHaQcW008L
i`036<HLiacW00@Q20037>LHaQcW008Q20<HaP<Li`048@PLiacW8@P27>L28@P01BDY8@PLiacW8@P0
11cW0QS600DLib488@PU:B48008YBP8Q208DY@8HaP048@PU:B488@P27>L28@P012DY6<HHaR480RU:
00<U:A2436<00PQ200<<H`@Q12402@@Q00<000@Q12402@@Q01L8@P@Q2488@QBU6<HaS3F]DYA[FVmk
Mke[FV<HIcUkgWooDY@aS0aS48@<H`Q200848@0324848@@Q00848@0536<@Q12424848@0324821240
0`Q212448@03124224821242248412422483124524821246248236<5248010aS248<H`aS0`Q200H4
8@Q22488@PaS248236<248@336<324800`aS2488@P0224800`aS248@Q00348@010aS2488@PQ21`@Q
0PQ200@<H`Q22488@P8<H`<8@P<<H`07248<H`aS48@DYA2424800`aS00<DYA2448@00`aS00@@Q0aS
6<HQ208]J`067>L@Q12436<8@PaS0PQ20P@Q00<8@PaS36<01@aS0PQ200<Libe[DY@00Tic00EJeU:D
BU8aS1S6008@Q0036<HLiaS600<@Q0035:DHaQBU008DY@<HaP@DY@<HaPHDY@@@Q0035:D@Q1BU008D
Y@0348@DYAS6008DY@8@Q08DY@@@Q0<DY@8@Q08DY@036<HLiacW00<@Q0<DY@<@Q00336<@Q12400<@
Q08<H`0348@DYA24008<H`<DY@0648@DYAS648@DYA240QBU0a241aBU00<@Q1BU48@00aBU11240aBU
1Q240PaS0a240`aS0a2400<<Ha2448@00PaS00<8@PaS36<00Q240PaS00@8@PaS36<@Q08<H`0348@<
H`aS00@@Q00336<@Q124008@Q08<H`D@Q00436<@Q1245:D448@236<248@00aBU48@@Q00236<248@5
36<0112436<<Ha240`aS0PQ200@@Q0aS48@<H`D@Q0H<H`<@Q0@<H`48@P0000<48@0012402@@Q00HL
icF]9BTHaRDY:DX29BT00b489BTYBP02;F/012U:9BTQ224812DY00<YBRDY8@P00QcW00<U:B488@P0
0QS60R4800@U:B487>LLi`8U:@038@PLiacW00DLi`046<HLiacW7>L26<H00aBU6<HLi`028@P01AcW
6<HHaQcW6<H00acW00@HaQcW7>LLi`8HaP075:DHaQBU5:DHaQcW8@P011cW0aS60QBU0QS600<LiaS6
5:D00QBU00DHaQBU6<HHaQcW008HaP@Li`8HaP8DY@8HaP037>LQ21cW008Q20057>LQ22489BTQ2002
7>L29BT011cW6<HLibDY0aS600<Q21cW7>L00QS612DY0QcW0R480acW00`HaQcW6<HDYAcW9BTYBRDY
8@PU:B487>L25:D36<H28@P03BDY7>LLibDY:DXQ21S648@DYC6<?NlicQS600848@@8@PD48@030004
8@@Q00@48@0400048@@Q0007124324825:D02Be[>LiBU6LiJeYcW6]JIcUNm`02Ool016LiAS4<H`aS
0`Q20P@Q00@8@PaS24848@88@P0336<48@@Q00@48@0400048@Q224841242248212401@Q212448@@Q
24800P@Q10Q200D48@Q22488@PaS00<8@P@<H`03248<H`aS00<<H`05248HaRU::DXHaP0212422482
12400`Q236<8@P0336<0112436<<H`aS0PQ20`aS00T8@PaS36<<Ha24248<H`Q2124010Q220@Q1@Q2
00L<H`Q21248@P@Q36<@Q00236<224800`aS48@@Q00348@35:D3248010aS48@<H`aS0QBU00@@Q1BU
48@@Q08<H`88@P041248@PQ2248436<224801@aS1248@QcW9BT00e:D00US65:DAS4aS2487>L@Q1BU
48@00QBU0Q240QBU00@HaQBU6<H@Q0<DY@<@Q0046<HDYAS66<H248@25:D011S65:D@Q1240QBU00<H
aQ2448@00QBU00<HaQBU5:D00a2400PDYA2436<@Q1BU48@<Ha240aBU00@@Q1BU6<HHaP8DY@8@Q0<D
Y@<@Q08<H`0648@DYA245:D<Ha2411BU00<<Ha245:D00Q240aBU00<@Q0aS48@01A241QBU00L@Q0aS
5:DLiaS65:D<H`0548@01ABU48@DYA2436<0112400<<Ha2448@00Q240`aS00<@Q1BU48@00`aS0Q24
10aS00<8@PaS24800`aS00<@Q0aS48@00PaS0a2400@<Ha2436<<H`8@Q08<H`H@Q0035:D@Q12400<<
H`03248<H`aS00<@Q00336<@Q0aS008<H`0348@<H`aS008<H`8@Q0@<H`03248<H`aS008@Q0H<H`03
248<H`aS00@@Q00736<@Q0aS48@<Ha2436<00@Q2000312401`0012448@0024848@0000848@035:De
[BU:00<Q20DU:@<YBP058@PU:B488@PU:@02:DX00bDY8@PLi`027>L012489BTQ21cW0QS60b4800<L
ib489BT00RDY0R4800<Lib487>L01QcW00@HaQcW6<HHaPDLi`048@PLiacW6<H57>L28@P01acW6<HD
YABU48@DYAS600DLi`056<HDYABU6<HLi`026<H25:D26<H45:D37>L26<H27>L36<H25:D26<H00b48
7>LLi`047>L01R489BTU:B487>LQ20<Li`8Q20066<HDYAS68@PU:B480acW00<Q22DY8@P00b4800<L
ib487>L01AS600XQ22U::DXU:AcW8@PU:AcW6<HDY@8HaP8Li`089BTQ21cW8@PU:BU:9BTLi`8DY@04
;F/mkcF]9BT6248412400`0012448@0312400`0012448@0:124324825:D03S6<>LiBU6<HJeYcW6mk
IcUNmg_NOomW>DHa48@236<6248010@Q2488@P@Q10Q20P@Q0PQ200<48@Q212400`@Q00@8@P@Q1244
8@<8@PD48@0524848@Q21248@P02124324800`@Q2488@P0436<010Q236<8@PaS0PQ200DHaRe[;F/L
i`Q200848@H8@P0336<@Q12400@<H`03248<H`aS00<<H`88@P8<H`0348@<H`aS008<H`D8@P848@88
@P051248@PaS48@<H`0324800`@Q24848@0336<2248236<00a2436<<H`0248@011BU6<HDYABU0PaS
0PQ20aBU0Q240aBU00<@Q0aS24800PQ200<<H`@Q24800`aS0PQ200<<H`Q236<00PQ200/HaRDYDYAB
U5JeHaQBU4Ha<H`HaQcW008@Q0HDY@<HaPDDY@046<HDYABU5:D36<H011BU6<HDYABU0Q240aBU00<H
aQBU48@00Q240QS600@LiaBU5:DDY@H@Q0055:D@Q12448@HaP025:D26<H00acW6<H@Q00248@00`aS
5:DDY@025:D00`aS48@DY@0248@00aBU48@DY@045:D348@011BU6<HHaQBU212400<HaQBU48@00Q24
00@DYAS66<H@Q0@DY@8@Q08DY@8<H`8HaP035:D<H`aS00@@Q00336<@Q124008@Q0@<H`0348@<Ha24
00H@Q0<<H`0348@<H`aS00@<H`0448@<H`aS36<248@010aS48@@Q1240`aS00D@Q1BU48@<Ha24008<
H`8@Q0055:D@Q12436<@Q002248010aS5:DDYA240PaS00<@Q0aS48@00Q2410aS0Q240PaS00<8@PaS
36<00PaS0a241`aS00@@Q0aS36<<H`D@Q08<H`48@P0000<000@Q12400P@Q00<000@Q124010@Q00DL
icW>9BTHaRDY008YBP8U:@05:DX]Jbe[:DXU:@028@P4:DX38@P012DY:DXYBR480acW00DHaQcW8@PQ
21cW008Q208U:@<Q20039BTQ2248008HaP059BTQ21S65:DHaP067>L012487>LLib480QcW0aS600HQ
21cW7>LLiaS65:D36<H00acW6<HLi`027>L00b487>LHaP046<H00aBU6<HLi`027>L35:D00aS67>LL
i`026<H00acW6<HHaP036<H27>L26<H57>L00b487>LQ20038@P00bDY8@PLi`047>L00b487>LLi`02
8@P01acW6<HLibDY:DXU:AcW008Q208Li`8Q208HaP0748@DYAcW8@PYBRDY8@P00bDY0R480QcW0aS6
00/Q21cW:DXYBRDY:DXQ21cW8@PHaQcW008aS0039BTDY@@Q0088@P0336<8@P@Q00P48@0300048@Q2
00@48@0324848@@Q00848@0324848@@Q00848@0936<DYABU9BTaS4YBDYAJeV]J009_N`0GJeYg_Goo
DY@mka245:D@Q0@Q48@Q22U:7>L8@P@Q000DYBDY7>L@Q000124<H`02124010Q212448@@Q0`Q200@4
8@Q22488@P848@<8@P041248@P@Q1242248010@Q2488@PaS0`Q200H<Ha2448@DYA245:D26<H00aBU
48@@Q0035:D00a242488@P0524800`@Q2488@P0336<00`Q248@<H`04248236<00a2436<<H`0236<2
24800`@Q2488@P0336<00`Q236<8@P03248312400`Q236<@Q004248010@Q24848@Q20Q2400<<H`Q2
24800PQ200D<H`Q236<@Q0aS008@Q00336<8@PQ200@<H`04248<H`aS48@336<010Q236<8@PQ20PaS
0PQ200H48@Q22488@PaS48@236<011S67>M6<Dic0U[F00E6<DYB=JdYBR4800<@Q0035:DHaQBU008D
Y@@HaPHDY@@HaP045:D@Q1BU6<H35:D00aS65:DDY@035:D00a245:DDY@025:D00a245:DDY@0348@2
5:D01A2436<@Q1BU48@00QBU0QS600<DYA245:D00a240QBU0Q240QBU0a2400<HaQBU5:D0112400<D
YA2448@00Q2400@DYA245:DDY@H@Q08<H`@@Q0035:D@Q1BU00<DY@036<HDYA2400`@Q0<<H`@@Q003
36<@Q12400L@Q08<H`0648@<H`aS248<HaBU0`aS00<@Q0aS36<00PaS112400D<Ha2448@DYA24008<
H`@@Q0<<H`8@Q0035:D@Q12400<<H`8@Q0035:D@Q0aS00L<H`<@Q0P<H`0348@<H`aS008<H`8@Q0D<
H`8@Q0<<H`0548@<Ha2448@<H`0124800005124000@Q1240000512402000124LicF]9BTLibDY:DX3
9BT01RU:<H`aS2e[:DXQ208U:@048@PYBRU:9BT38@P29BT00bU:7>LLi`026<H38@P27>L00bDY:DXU
:@028@P00bDY7>LQ20026<H37>L36<H57>L01B487>LLiacW6<H00QcW00<HaR487>L00QcW0aS60aBU
00<HaQcW7>L01AcW0QS600<DYAS66<H00QS60acW11BU0acW1aS60aBU0acW00<HaQcW8@P00b4800HL
ib488@PQ22DY8@P37>L26<H02QcW8@PU:B487>LHaQcW9BTYBR480QcW0R480QcW00<Q21cW6<H00QBU
00@HaQcW9BTYBPDU:@8Li`046<HLiacW8@P27>L28@P00bDY8@PQ20028@P01QBU6<H]JcF];F/Li`84
8@88@P0536<8@P@Q1240000E12402@Q236<@Q1248@P]JdYBDYAF]@02JeX03fmkJeYg_GooE[DmkaBU
48@<H`@Q48@Q22U:7>L8@P02124011BU7>LQ21240P@Q0`Q21P@Q0PQ200@48@Q212448@<8@P<48@07
248<H`Q21248@P@Q24800P@Q00H8@PaS48@@Q1BU48@25:D00aS65:D@Q00248@25:D348@00`aS2488
@P0224801@aS24848@@Q24801@aS0`Q20PaS00<8@PaS36<00Q240PaS1@Q200D<H`Q22488@P@Q00@8
@P041248@PaS36<4248312401@Q248@<H`Q236<00PQ20PaS00<8@PaS36<00PaS0Q240PaS00<48@Q2
36<00PaS00<@Q0aS36<010Q200@<H`Q21248@P<<H`031248@PQ20088@P@<H`046<HLid8@CW<2G_L0
1DYBAS4e[BDY7>L00QBU00<HaQBU5:D00aBU00<HaQBU7>L00QcW0QS60Q242aBU0Q240QS600<DYA24
36<01ABU00<HaQBU6<H00QBU00<@Q0aS48@00aBU00@<Ha2448@DY@8HaP055:D@Q1245:D@Q0025:D0
1A2436<@Q1245:D00a240aBU112411BU00D@Q1BU5:D@Q0aS008@Q0035:D@Q12400@@Q0<DY@8@Q004
5:D@Q12448@35:D0112436<<H`aS0Q240QBU0a2400D<Ha2448@@Q1BU008@Q0<<H`<@Q00436<@Q0aS
36<248@011BU48@<H`Q20`aS0Q2400<<H`Q224800PaS00@@Q0aS48@<H`@@Q08<H`0448@DYA2436<2
48@236<248@25:D336<248@336<00a2436<<H`0236<748@236<02Q245:D@Q0aS248<Ha2436<@Q0aS
0Q241@aS00@@Q0aS48@DY@8@Q00536<@Q12448@<H`01248000848@0300048@@Q00L48@067>LicRU:
6<HQ22DY0R4800@U:Be[;F/]J`8YBP8Q20DU:@8Q20077>LU:BDY9BTQ21cW6<H00R4800DHaR488@PY
BRDY00<Q20039BTYBR48008Li`8Q20DHaP038@PLib4800<U:@068@PLiaS67>LHaQcW0QS600DQ21cW
6<HDYAS600<Li`8HaP8Li`8Q208Li`036<HLiaS6008HaP035:DHaQS600@HaP055:DHaQS67>LHaP04
7>L46<H011BU6<HLib480QcW0R480QcW00<Q22DY8@P00QcW0RDY00DQ21cW7>LQ21cW008Q20<Li`8Q
208YBP049BTQ21cW9BT38@P27>L46<H27>L2:DX00be[:DXQ20047>L36<H00b489BTQ20029BT28@P3
7>L01aBU6<HaS48@;F/DY@@Q00<8@P<48@050008@P@Q1240000512400`0012448@021242248010@Q
00048@Q20P@Q0PQ20Q240QS600<YBSW>AS400U:D019F]E:DDYA:DSF]<H`Lib486<H<HaBU9BT]Jb48
36<48@Q25:D26<H00a24124<H`02248312401@Q236<8@PQ212400PQ200<48@Q212400PQ20P@Q00<8
@P@Q12400`Q201@48@Q236<<H`Q236<DYAcW6<HDYBDY<H`e[BU:9BTYBR487>LHaQBU0Q2400<<H`Q2
248010@Q00@@Q1BU6<H<H`<8@P0536<8@PaS36<8@P0836<2248010@Q248<Ha2410aS00<@Q0Q236<0
0PaS00<8@P@Q12400PaS0PQ20P@Q10Q200<<Ha2448@00PQ200d48@Q236<8@P@Q248<Ha2436<8@PaS
24848@02248336<00`Q236<8@P0224801`aS24848@aS48@DY@aS00848@@8@P<@Q0046<HLid8@CW<2
F]H01THaCW=6<Be[7>L@Q0DDY@056<HDYAS67>LHaP035:D26<H25:D00a246<HHaP026<H248@00aBU
48@DY@026<H448@011BU48@HaQBU0QS60QBU00D@Q1BU5:D@Q0aS008@Q0045:D@Q12448@25:D248@0
0aBU48@@Q0025:D448@01ABU48@@Q1BU6<H00QBU0QS600<DYA2448@01A240aBU00@@Q0aS48@DY@8@
Q00336<@Q12400D@Q08DY@0348@DYA2400HDY@@@Q0036<HDYABU00D@Q00336<@Q1BU008@Q00436<@
Q12448@336<248@25:D236<01@Q236<@Q0aS48@00`aS0Q240PaS00<8@PaS36<0112400L<Ha2448@<
Ha2436<@Q00336<00`Q248@DY@0248@336<020Q248@DYA245:D@Q0aS48@236<00a2436<@Q00248@:
36<448@236<00a2436<<H`0236<248@25:D348@011BU7>LHaQBU0A2400000`0012448@0212401@00
12448@@Q00000P@Q00@HaSW>:DXLi`8U:@057>LU:BU:;F/aS002:DX49BT28@P022U:9BTQ21cW8@PU
:BU:9BT27>L01AS67>LLiaS68@P00bU:0b480RDY00@Q21S67>LQ208Li`045:DLiacW6<H27>L39BT2
8@P37>L01R487>LHaQS67>LQ208HaP045:DLiacW5:D26<H27>L38@P27>L011S67>LHaQBU1AS600<L
iaBU48@00QBU11cW00@HaQBU6<HDY@@HaP057>LHaQcW6<HLi`028@P02QcW8@PQ22487>LQ22DY8@PL
iaS60QcW00<Q21cW7>L00b480QcW00HQ22U::DXU:AcW6<H28@P04QcW8@PLiaBU6<HDYAS67>LQ22DY
;F/YBRe[8@PHaQcW6<HQ20@Li`8U:@DQ20087>LQ21S66<He[D8@;F/HaP848@0336<48@@Q00<48@03
00048@@Q00P48@0324848@@Q00H48@@8@P8@Q0076<HDYBU:=Je:DUJeDY@00UJe01=BU4YB=Jd]JacW
8@PDY@aS5:D]Jc6<8@P<H`@Q248DYAcW6<H@Q00324800`@Q24848@022482124324800`aS2488@P02
24800`@Q2488@P032482124624800`aS5:DLi`025:D01248<H`aS2U:0RDY00<Q21cW48@00QBU10aS
00/48@Q212448A246<HDY@aS1248@Q2400<<H`<8@P8<H`0348@<H`aS00<<H`0924848@Q236<DYA24
36<8@Q24008<H`05248<H`Q21248@P0248@00`aS12448@0424802P@Q36<<Ha245:D<H`Q21248@PaS
0`Q200@<Ha2436<<H`D8@P@<H`05248<H`Q224848@02248010aS48@@Q0aS0PQ200@<H`@Q2488@P<@
Q00<5:DHaT8@CW=Nme[FAS5>Ld8@;F/Q21241ABU0QS611cW00DHaQBU5:DDYAS6008DY@@HaP8DY@8@
Q0@DY@046<H@Q12448@36<H45:D00aS65:DDY@0848@45:D01Q2436<@Q1245:DHaP8@Q0@DY@8@Q004
5:D@Q1BU5:D448@00aBU48@DY@025:D348@25:D548@010aS48@@Q1240aBU0a240QBU00<@Q1S65:D0
1A2411BU00<@Q1BU36<00PaS00@@Q1BU5:D@Q0<<H`045:D<H`aS36<248@010aS48@<Ha2410aS00@@
Q0aS36<@Q08<H`04248<H`aS36<248@636<011245:D@Q1241@aS11240PaS1A240`aS00DDYA2436<<
Ha24008DY@<<H`06248<H`aS48@<Ha2410aS0a240`aS0Q2400D<Ha2448@@Q0aS008@Q0055:DHaQcW
6<HDY@0148@00005124000@Q12400007124011cW=JdYBQcW22DY00<Q21cW8@P00bDY0R4800<U:B48
8@P00RDY00HQ21cW7>LQ21cW6<H27>L00bDY8@PQ20048@P77>L02aS67>LLiacW6<HLibU:;F/YBR48
6<H01QcW0aS60acW0aS60QcW00<HaQcW7>L00aS60QcW00<HaQBU6<H00QS60QBU0QS600<DYAS65:D0
0QS60R4800DLiaS67>LHaQcW008Q208Li`066<HLib488@PLiaS60QcW124800@YBR487>LHaP8Q208L
i`038@PYBR48008Li`8Q208U:@DQ20DLi`066<HDYABU6<HQ21cW0bDY1QcW00PHaQcW6<HDYAcW8@PY
BRDY0R480acW0QS600DYBS6<8@P@Q0@Q00@8@PX48@0500048@Q21240000712400`Q212448@022482
36<248@00aBU7>LU:@02;F/023F]>LhYBQcW=JeF]E:D=Jd25:D01B489BTQ21S65:D00PaS00<@Q0aS
36<00`Q200<<H`Q224800P@Q00@8@PaS24848@<8@P<48@<8@P041248@P@Q124324803@@Q2488@PaS
248HaRU:>LhaS2e[=Je6<E:D009>L`05BU8icSF]7>LHaP0248@00aBU36<48@022482124011BU9BTL
i`aS0P@Q1`aS0PQ210aS10Q200@<Ha2436<<H`<8@P0336<8@PQ200<8@P0436<8@PQ2248412422480
1P@Q248<Ha2436<8@P8<H`041248@P@Q248236<248@224821248248236<3248336<01a242488@PQ2
1248@PaS008@Q00=5:DLiacW?Nm>Lf<HG_M>Le[FDY@e[BDY48@00aBU00@HaQBU5:DLi`LHaP8DY@<H
aP8DY@037>LDYABU008@Q08HaP8DY@0348@DYA24008DY@036<HDYABU00<HaP@@Q0035:DHaQBU00<D
Y@<@Q0046<HDYAS65:D248@011BU48@@Q1240aBU00<@Q1BU6<H00aS600LLia2448@<Ha245:DHaP03
48@00aBU48@@Q00248@25:D00a245:D@Q00448@45:D0112436<@Q12411BU112411BU0Q240QBU1Q24
00H<Ha2448@<Ha2436<248@00`Q236<@Q00348@336<00a2436<<H`0836<01A2436<<H`aS48@00PaS
0a240PaS00D8@PaS36<<Ha24008DY@0448@<H`aS48@536<00a2436<@Q00548@336<248@010aS248<
H`aS1Q241@aS00<@Q0aS48@00Q2400P<Ha245:DQ22U:8@PLiaBU0@aS000212400`0012448@071240
1QS6>LhYBQcW9BTYBP<U:@03:DXU:B48008Li`8Q20@U:@8Q20037>LQ224800@Q208Li`036<HQ2248
008Q20049BTQ21cW6<H27>L00b486<HLi`026<H00acW6<HHaP026<H012489BTU:BU:0R480QcW0QS6
0acW00THaQBU6<HQ22DY7>LDYA246<H00QcW00<HaQcW6<H00aS60acW0aS600@LiaS65:DDY@@HaP03
7>LQ2248008Li`<HaP<Li`036<HLib4800HLi`8Q20057>LU:B489BTQ20047>L58@P27>L01BDY8@PQ
22DY7>L00R4800<Lib487>L00acW00LDYAS66<HLib487>LU:@02:DX00b486<HHaP047>L36<H27>L2
9BT00b487>LQ20027>L01aS67>L]Jc6<9BTDY@@Q0088@PL48@0300048@@Q00H48@0324848@@Q00D4
8@0324848@@Q00848@8<H`8@Q08Li`089BTYBRU:=JdicRDY6<He[@9F]@05=Jd@Q1S6:DXU:@027>L0
0aBU48@DY@0236<62482124424800`aS24848@03248212400`Q21248@P0212400`Q21248@P032480
30aS24848AS69BTe[C6<9BTe[DYBDYA:DP9>L`0;>LhaS1cW6<HDYAS648@<H`Q21248@P02124011BU
8@PLi`aS0P@Q1PaS00@8@PaS36<<H`H8@P0436<8@PQ236<924800`aS2488@P07248212401@Q236<@
Q12436<00PQ200H<Ha242488@P@Q248436<01@@Q24848@Q212401@Q200<<H`Q224800PQ200<<Ha24
36<00PQ20P@Q0188@PaS36<<Ha246<HLiaS6?Nm>Lf<HG_M>LekgCW<e[AcW48@36<H25:D26<H27>L0
1aS65:DDYABU6<HLiaS6008DY@<HaPLDY@046<HDYA2448@25:D00a245:DHaP026<H00aBU48@DY@02
5:D348@00aBU6<HHaP0248@010aS48@@Q1S60QBU00@@Q1BU48@DY@8@Q08DY@<@Q08DY@8HaP0348@D
YABU00@@Q0035:D@Q124008DY@0448@<Ha2448@25:D348@010aS48@@Q1BU1A2400<<HaBU5:D00QBU
0Q2411BU00<@Q1BU48@00QBU0Q2411BU0PaS00@@Q0aS48@@Q08<H`0348@<Ha24008@Q0L<H`0348@<
H`aS00<<H`0348@<H`aS008<H`<@Q003248<H`aS00<@Q0<<H`0348@<H`aS00H@Q08<H`<@Q0<<H`@@
Q00336<@Q0aS00@<H`<@Q0@<H`0348@<H`aS00@@Q08<H`0348@DYA2400<@Q0065:DLibDY8@PLia24
0@aS0000100012448@000P@Q00@000Q2124000848@097>LicRU:7>LQ22DY:DX]JbU:00<Q20<Li`8U
:@038@PLiacW008Q20<U:@@Li`8Q208U:@8Q20047>LQ22DY8@P27>L00b487>LLi`046<H02ABU48@L
ibDY;F/U:B487>LQ20027>L00aS67>LLi`046<H37>L56<H27>L00b486<HHaP026<H011cW6<HHaQS6
0b4800@HaQBU5:DHaP8Li`036<HLiacW008Li`8HaP057>LHaQcW8@PLi`028@P00acW6<HHaP037>L2
6<H01QcW8@PYBRDY8@PDY@8Li`@Q20059BTQ21cW6<HLi`028@P27>L00b489BTQ20027>L26<H27>L2
6<H00aBU6<HHaP049BT00acW8@PHaP026<H27>L28@P01QcW6<HLib48:DXU:@8Q200:6<HQ22486<HD
YBDY;F/Q21BU124224801@aS24848@@Q00003`@Q0`Q200@48@0012448@D8@P0336<@Q12400<DY@0;
6<HQ21S65:DLibe[<H`U:AS67>LU:@027>L36<H248@236<010Q21248@P@Q0`Q200@48@Q22488@P84
8@<8@P041248@P@Q124;24801a245:DQ2248;F/e[E:D009S6009Lia_NfmkHaQF]E:D;F/U:A24008<
H`88@P@48@04248<H`Q22482124436<224801@aS248<H`Q212400PQ200D<H`Q21248@PaS0088@P8<
H`0524848@@Q248<H`0212400`Q236<<H`03248336<4248010@Q248<Ha240PaS0a2400D<Ha2448@@
Q0aS00<8@P0336<8@P@Q00848@@8@P8<H`88@P0436<8@PQ236<248@00`aS2488@P0236<248@031S6
7>LHaSF]AS5S65kgDYAJeUJe?NlYBP8HaP037>LDYAS600<HaP035:DHaQS600DHaP057>LHaQBU6<HL
i`026<H00aBU6<HHaP025:D00a245:DDY@045:D00aS65:DHaP035:D011S65:DHaQBU0PaS00<@Q1BU
7>L011BU00P@Q1BU48@DYA245:D@Q1BU0Q2400@DYA245:DDY@8@Q08DY@046<HDYABU48@25:D00a24
5:DDY@0548@01ABU48@@Q1BU48@00aBU00D@Q1BU48@@Q0aS00P@Q0076<HDYA2448@<Ha246<H00QBU
00@HaQBU5:DDY@L@Q0<<H`@@Q00336<@Q0aS008@Q0@<H`0348@<H`aS008@Q00536<8@PQ236<DY@04
48@336<00a2436<@Q00248@736<00a245:D@Q00348@00`aS48@<H`0536<648@536<248@436<01124
5:DDYA241@aS00/DYA2448@@Q0aS248HaQcW:DXU:ABU008@Q048@P0010@Q00<000@Q12400`@Q00P0
00@Q6<HicRe[7>LQ22DY0bU:00@Q21cW7>LLi`@Q20049BTQ22488@P39BT00b487>LLi`038@P011cW
8@PQ22DY0acW00DU:B487>LLib48008Li`8HaP065:DHaQS66<HLibDY0RU:00@Q21cW8@PLi`<HaP8L
i`036<HLiacW008HaP8Li`066<HLiaS66<HLib480QcW0QBU00DHaQcW7>LHaQcW00<Q20037>LHaQcW
00<HaP8Li`056<HLiacW8@PLi`026<H01QcW8@PQ22487>LHaP<Li`038@PLib48008Li`039BTQ22DY
008Q20@Li`049BTQ22DY8@P37>L28@P01AcW8@PU:BDY8@P01AcW00<HaQcW5:D00QS600<LibDY9BT0
0RDY00@LiaS67>LHaP8Li`8Q20047>LHaQcW7>L39BT00b487>LU:@028@P26<H01BU:<H`U:A241240
0`Q21@@Q00D000@Q12448@Q200H48@0400048@@Q248312422482124424800`aS48@DY@025:D03AS6
7>LQ21cW48@HaRe[<H`U:AS68@PU:AcW00DHaP0548@8@PQ2248<H`0424800`@Q24848@0424831240
0`Q21248@P0824803@@Q36<8@P@Q36<HaRDY7>LYBSF]CW=Nmf<H00=_N`08IcUBU5:D;F/U:A2436<@
Q088@P@48@88@P0336<8@PQ200<8@P0436<@Q0aS48@236<724800`aS248<H`0224800`aS2488@P02
1244248010@Q2488@PaS0`Q200@<H`Q224848@88@P03124<H`aS00<<H`0348@DY@aS0088@P0436<@
Q0aS36<224800`@Q2488@P03248010aS2488@P@Q0PQ200<<H`Q236<00PaS00<@Q0aS36<00`Q2018<
Ha245:DHaQcW6<He[DHaHaQNmdicG_MBU3g_;F/HaQcW5:D36<H00acW6<HHaP025:D01AS67>LLiaS6
5:D01aS61ABU0QS600HDYA245:DDYAcW6<H35:D26<H25:D448@01ABU6<HHaQcW5:D00PaS00<@Q1S6
5:D00Q240QBU00<@Q1BU6<H00QBU0Q2400DDYA245:DHaQcW008DY@0648@DYABU5:D@Q1BU0Q2400HD
YA245:D@Q1BU48@55:D336<00a245:DDY@0448@011BU48@DYABU11240aBU00<HaQBU6<H01ABU1124
00@DYA2448@@Q08<H`0348@DYA24008<H`0548@DYA2436<@Q00236<00a2436<@Q00436<01A245:DD
Y@aS24800Q2400<<H`Q236<00Q2400<<Ha2436<01PaS00@@Q1BU5:DDY@<@Q0<<H`8@Q08<H`<@Q005
36<@Q12448@8@P0236<448@236<0112436<@Q1240`aS00<@Q1BU48@00Q2400DDYA2436<@Q1S6008U
:@036<HDYABU0048@P0000<000@Q00002@@Q00DLicW>9BTHaRU:008]J`039BTQ2248008Li`8Q2005
9BTQ21S66<HQ20039BT37>L28@P00acW6<HLi`029BT01R487>LU:BU:9BTLi`DQ20077>LHaQS66<HD
YAS67>L00R4800<Lib487>L00R480QS600<DYAcW7>L00QcW00<HaQcW7>L00acW0QS600HLib489BTL
iaS67>L26<H031cW8@PQ21cW6<HQ22U:8@PHaQBU6<HLi`8HaP037>LHaQcW00@HaP<Li`048@PLiacW
7>L26<H27>L011S67>LLiaS60QcW00DU:B487>LHaR48008U:@8Q200;9BTQ21cW8@PU:B486<HLib48
9BTYBP028@P77>L48@P00acW8@PU:@029BT01RU:8@PLiacW6<HQ20<Li`048@PYBRDY9BT28@P29BT0
2bU:9BTHaQS6;F/icRe[5:D48@Q236<00`@Q00<000@Q124010@Q00<000@Q124010@Q00H8@P@Q1240
00@Q248412400`Q21248@P0224801@@Q248<HaBU48@00PaS1A240aS600H@Q1BU7>LQ21S648@436<3
248010@Q2488@P@Q0PQ200<48@Q224800PQ200P48@Q224848@Q21248@PaS0`Q20`aS0PQ20PaS00LH
aQcW:DX]JcW>BU9Nm`03Kg/00fLiJeY_N`02Li`00d8@;F/<H`03248712401PQ236<@Q12436<48@88
@P0348@<H`Q200@8@P031248@P@Q00<8@P041248@PQ224841243248312400`Q236<8@P0224800`aS
2488@P0212400`Q236<8@P03248248@00aBU48@DY@0248@3248236<00`Q212448@0324800`@Q2484
8@0236<010Q236<8@PaS0Q2400D<H`Q2248<H`Q2008<H`0348@<Ha24008DY@0;=Je6<EkgHaQ>Lekg
E[E6<C6<6<HLi`066<H00aBU6<HHaP096<H27>L00b487>LHaP036<H448@25:D011S65:DHaQBU0QS6
00<DYAS65:D00QBU00@@Q1BU5:D@Q0<DY@<@Q0045:D@Q1BU6<H45:D36<H01Q245:D@Q1BU48@DY@D@
Q0<DY@0448@<Ha2448@25:D26<H02AcW6<HHaQS65:D@Q1BU48@DY@0248@010aS48@@Q1BU0Q2400@D
YA245:DDY@@@Q0<DY@8HaP8DY@057>LHaQS648@<H`0448@011BU48@@Q1BU0Q2400<<Ha2448@01a24
00<<Ha245:D00Q2400<<Ha2436<00PaS00<8@PaS36<00a241PaS00H8@PaS36<<Ha2436<348@00aBU
48@@Q00336<448@436<348@00`aS48@<H`0236<248@01@aS48@<H`aS5:D0112400<DYA2448@01124
00L<H`Q248@DYB486<HDY@0248@136<000D48@0300048@@Q00@48@087>LicRDY7>LU:Be[:DXU:@8Q
20036<HQ224800DLi`8Q208U:@8Q208Li`048@PLiaS68@P29BT00b487>LU:@029BT48@P00acW6<HH
aP026<H021BU6<HHaQS67>LQ21cW8@P27>L36<H37>L011S65:DHaQS60QcW0aS600<Lib488@P00QcW
11S60QcW00HQ21cW7>LQ22U:8@P56<H00acW6<HHaP026<H35:D00aS67>LLi`028@P011cW6<HHaQS6
0QcW00`Q21cW7>LLiaS68@PU:B486<HLib489BT38@P00bDY7>LQ20028@P37>L00b489BTQ20028@P2
7>L00aS67>LLi`037>L00b489BTQ20038@P39BT00b487>LHaP027>L68@P29BT00b489BTYBP029BT0
2QBU6<H]Jcg_;F/@Q0@Q248<H`Q22P@Q00<000@Q12400P@Q00D000@Q12448@Q200@48@0924848@@Q
1248@P@Q24848@Q2008@Q0095:D<H`aS48@<Ha245:D@Q1BU008HaP8DY@8Li`055:D@Q0Q236<8@P02
36<00`Q21248@P0324821242248312400`aS2488@P0212401@Q212448@Q236<010Q20`aS00P8@QBU
6<HaS2e[=Je6<E[F0fmk0f]J0WNm00=242e[36<00PaS0`@Q00<8@P@Q12400P@Q00@8@PaS48@<H`L8
@P0436<8@PQ2124424821245248312401PQ21248@P@Q248<H`D8@P041248@PQ236<224800`@Q2488
@P0336<00aBU48@DY@0348@010aS2488@PQ20PaS0PQ20P@Q0`Q200@<H`Q2248<H`88@P0436<@Q124
48@836<25:D03124=Je246<HG_MBU5kgE[E6<C6<7>LHaP8DY@@HaP@DY@@HaP037>LHaQS600<Li`03
6<HDYAcW008HaP035:D@Q12400@@Q08HaP055:DHaQBU5:DHaP025:D00a245:DDY@0248@35:D448@2
5:D248@35:D00a245:DDY@045:D00a245:D@Q00248@01ABU48@DYA245:D0112400@DYA246<HDY@@H
aPDDY@0448@DYA2448@236<448@25:D248@01QBU48@DYA245:DHaP8DY@8HaP8DY@H@Q00336<@Q124
00D@Q08<H`0348@DYA24008@Q0<<H`0348@<H`aS008<H`8@Q0@<H`8@Q0<<H`<@Q0<<H`8@Q08<H`08
48@DYABU48@<Ha2436<@Q08<H`0348@<Ha24008@Q08<H`8@Q0<<H`0348@<H`aS008<H`0348@DYA24
00D@Q00336<@Q12400@@Q00536<@Q12436<DY@037>L00aBU48@@Q0012480000500048@0012400005
12402`00248Q248@;F/HaRDY;F/U:B487>L00R4800LLib489BTQ21cW6<HLi`058@P00acW8@PLi`02
7>L48@P29BT38@P00bDY8@PU:@028@P00acW6<HHaP026<H00aBU7>LQ20028@P00acW6<HLi`037>L2
6<H00acW6<HHaP066<H021cW6<HHaR489BTQ21S65:D26<H011BU7>LQ22DY0RU:00<Q21cW7>L00acW
1AS60QBU00<HaQcW7>L00acW0R4800<LiaS66<H00QS600DLiaS65:DDYAcW008U:@058@PHaQS66<HL
i`049BT28@P57>L00b489BTQ20037>L01RDY8@PQ21cW8@PLi`<Q208U:@03:DXU:B48008U:@8Q2005
7>LQ22487>LQ20027>L01aS68@PU:BDY8@PU:BU:008]J`08:DXLiacW;F/icRU:5:D48@<8@Q048@03
00048@@Q00848@0424848@@Q124324831245248436<02`Q248@HaRU:;F/HaQ24248<HaS65:D02PQ2
00<<H`Q224800P@Q10Q21@@Q0`Q200@48@Q236<DY@8@Q00<248<H`aS36<U:C6<>Lhe[C6<@Q1JeV]J
0fmk0VLi00Ug_GooF]Hmk`aS1248@P@Q24800`@Q00T8@P@Q0008@PaS6<HDY@aS24800P@Q3`Q20`@Q
00<8@P@Q12400`@Q0`Q200@48@Q2248<H`<8@P0736<8@PQ2248<H`Q236<00PQ200@<H`Q248@DY@8@
Q08<H`0548@<H`Q2248<H`032482124236<424800`aS248<H`0348@00`aS248<H`0636<248@02C6<
?NmNmf<HDYANme[FBU8icP027>L00aBU6<HHaP025:D96<H011BU7>LLiacW0QS600<Lib487>L00aBU
1A240QBU0QS611BU00<@Q1BU5:D00aS60QBU0Q240QBU00<@Q1BU5:D011240QBU00<HaQBU5:D00QBU
00@@Q1BU48@DY@8@Q0045:D@Q1BU36<35:D00a2436<DY@035:D36<H01aBU6<HHaQS65:D@Q0aS00<@
Q08DY@<@Q0@DY@036<H@Q124008@Q0045:D@Q1245:D36<H00aBU6<H@Q00748@25:D00a245:DDY@02
48@010aS48@@Q1BU0Q240`aS00<@Q1BU36<02`aS0a240PaS00<8@PaS48@00Q240PaS1Q241@aS0Q24
00@<Ha2448@@Q08<H`06248<H`aS48@<Ha240PaS0a240`aS1A2400P<Ha2436<<Ha2436<@Q0aS0Q24
0QBU0a240@Q2000<12401248@Q0]JacW0RU:00@U:AcW8@PU:@8Li`0:8@PYBR487>LHaQcW9BTQ21cW
9BT28@P27>L28@P27>L00b489BTQ20038@P39BT38@P26<H011BU6<HLiaS60QcW0R480QcW0QS600@Q
21cW6<HHaP8Li`<HaP057>LHaQS65:DHaP027>L012487>LLiaS611BU0QcW00DU:BU:9BTU:AcW008H
aP<Li`8HaP8Li`065:D@Q1BU6<HLiaS60QcW00@Q21cW7>LLi`HHaP047>LQ22488@P57>L01B489BTU
:BDY8@P01AcW00<HaR488@P00RDY0R4800<Lib488@P00acW00<Q22DY9BT00RU:00@U:BU:9BTQ20<L
i`@Q20DLi`048@PU:BDY9BT2:DX0336<:DXQ21S6:DXicRU:6<H48@Q236<8@PH48@0300048@@Q00<4
8@0300048@@Q00T48@88@P<48@88@P<48@8<H`88@P0A36<8@PQ248@HaRe[=JdQ2124248<HaS648@<
H`@Q248<H`0224800`@Q2488@P0224801@@Q2488@PQ212400PQ210@Q00<8@P@Q24800PQ200D48@Q2
36<@Q1BU00D<H`078@Pe[D8@=JdaS3g_E[D00fmk00Q[FVLiHaQkgWooF]HicPaS0PQ200D48@Q21244
8@Q200<48@04248@Q1S66<H224801P@Q248<H`aS24848@D8@P031248@P@Q0088@P041248@PQ22483
124224821243248212400`aS248<H`0624800`aS2488@P0336<00a2436<@Q00636<3248312400`Q2
1248@P06248236<248@336<2248336<248@00`aS<H`mk`02G_L035:DG_MJeTYB>LhQ21cW6<HDYAS6
5:DHaP8DY@037>LHaQS600<DY@<Li`8HaP065:DLib488@PLiaBU0a240QBU00<@Q1BU48@00QBU0QS6
00DDYAS66<HHaQBU008@Q0055:DHaQBU36<@Q0025:D448@011BU6<HDYA240QBU00<HaQ245:D00aBU
00P@Q1BU48@@Q0aS48@HaQBU0Q2400<DYA2448@00Q240aBU0aS600<LiaS66<H00QBU00D@Q1BU48@<
Ha2400<DY@<@Q0035:DHaQBU008@Q0055:D@Q0aS48@DY@066<H848@010aS48@@Q1S60QBU1a240`aS
00<@Q0aS36<00PaS0Q241@aS0a240PaS00<@Q0aS24800`aS00<@Q0aS48@0112400<DYA2448@00`aS
0Q240PaS0a242@aS11240PaS21241`aS00@@Q1BU5:DDY@<@Q04<H`0000X000@Q00048@00124000Q2
124000848@048@Q:DS6<6<H39BT58@P29BT01B487>LQ22489BT00b4800<U:B488@P00QcW0R4800<U
:B487>L01BDY0b4800HLib487>LHaQBU6<H37>L011S68@PQ22DY11cW0R4800<LiaS66<H00QS600<L
iaS66<H00QS600<LiaS67>L00QS600<DYAS66<H00aS600PQ22DY:DXYBR487>LQ21cW0b480QcW0QS6
11BU11cW00@Q21cW7>LHaP8Li`038@PHaQS6008HaP037>LQ22DY008Li`036<HLib48008Q208Li`06
8@PU:B487>LHaQcW0RDY00<Q21cW6<H00acW00<Q21cW7>L00R480Re[00PQ21cW8@PU:BU:9BTQ21cW
0b4800@LiaS67>LQ208U:@8Li`048@PYBS6<<H`3;F/02BU:9BTHaQS6=Je6<CW>6<H48@0224881240
1@0012448@@Q000010@Q00@8@P@Q1248@P@48@0324848@Q200@48@0624848@Q21248@P@Q0PQ20P@Q
00@@Q1S6:DXQ208<H`<8@P031248@PQ200L8@P0336<8@PQ200<8@P<48@0324848@@Q00848@082484
8@@Q24848@Q236<@Q08DY@@<H`0:>LiBU5:D>LhU:BU:DYANmf<HKg/3JeX02GNmOom>LcF]36<8@PaS
248@Q0026<H02@aS24848@@Q36<@Q1BU48@8@P0312401@aS2488@PQ212401`Q200@48@Q224848@88
@P@48@0424848@@Q1242248010aS2488@PQ20`aS0Q2400<DY@aS36<010aS00@@Q1BU6<HHaP8Q2007
6<HDY@aS36<8@PaS24800PaS1PQ21PaS0Q2400<<H`Q224800`Q20`aS00@@Q0aS<Ha6<@9S600:DYAN
mekgCW<icRDY7>LHaQcW6<H25:D46<H011BU6<HHaQcW0QS600@DYAS66<HHaP@Li`036<H@Q124008@
Q0045:DHaQBU48@25:D26<H85:D248@011BU48@@Q0aS0a2400<DYA245:D011BU0QS600<@Q1BU48@0
0aBU00<@Q1BU5:D011240aBU00@@Q1BU5:DHaPTDY@d@Q08DY@8@Q0<DY@8@Q0035:DHaQS6008HaP05
48@<H`aS48@DY@0448@00`aS48@@Q0045:D648@236<648@536<010Q236<<Ha241@aS0Q240`aS00D@
Q0aS48@@Q0aS00<@Q00536<@Q0aS36<@Q00336<248@336<01Q2436<<Ha2436<@Q0<<H`@@Q08<H`04
48@<H`aS36<348@00aBU48@@Q00348@536<148@136<136<000`48@048@Q6<CF]7>L29BT00b489BTQ
20038@P29BT00b487>LLi`088@P37>L012DY:DXQ22480RDY0R480bDY00<Q21cW7>L00QcW00@HaQBU
5:DDY@DQ20<Li`8Q20039BTLiaS600<Li`8HaP8Li`8DY@8HaP047>LHaQS65:D46<H00acW9BTYBP02
9BT00acW8@PQ20028@P37>L011S67>LDYA240QBU1AcW00@Q21cW6<HHaP<Li`046<HDYABU7>L29BT0
12486<HHaQS60R4800DLiaS67>LLib4800<Li`048@PU:BDY8@P36<H28@P27>L02B487>LQ22DY;F/Y
BR487>LU:@02:DX28@P00acW8@PQ20027>L031S67>LQ22DY7>LHaR48:DXe[Be[:DXaS08]J`079BTH
aQS6>Li:DSF]6<H00P@Q0PQ210@Q00<8@P@Q12403P@Q00<8@P@Q24801@@Q0PQ20`@Q0PQ200l48@Q2
2488@P@Q5:DHaRDY8@P@Q0aS24848@Q236<01`Q200<48@Q224800PaS0PQ200<48@Q224800`Q21@@Q
00@8@P@Q1248@P8@Q00@5:D@Q0Q236<@Q0Q2<HaBU5[F?NlQ22U:CW=Nmf<HKg/3JeX05gNmNmiBU3W>
48@8@PaS248@Q1S65:D<H`Q200048@aS48@DYA2424848@Q212400`Q20P@Q00<8@P@Q36<00PQ20P@Q
1PQ200D48@Q21248@P@Q00D8@P041248@PQ2248436<348@01`aS48@<H`aS248<Ha24008HaP078@PL
iaS648@8@PaS48@00`aS00<8@PaS24801PQ21@aS0PQ20PaS0148@PaS248<H`Q236<@Q0aS<Ha246Li
HaQBU6<HG_M>Ld8@008Q20@HaP035:DHaQS6008HaP8DY@047>LQ21cW6<H25:D00aS65:DLi`027>L0
11S65:DDYAS60QBU0QS600LDYA2448@HaQcW6<HDY@036<H45:D00a245:DDY@0748@25:D00a245:D@
Q0045:D348@011S65:DDYABU0a2411BU0Q240QBU1AS60QBU00<@Q1BU48@02A2400<DYA245:D01ABU
0Q240QBU0Q2400@DYAS67>LDY@<@Q00636<@Q1245:D@Q0aS0Q2400<DYA2448@00a240QBU00<<Ha24
36<01Q240`aS0a240`aS0a240PaS0Q241PaS0a2400<DYA2448@00Q2400@<Ha2448@@Q0<<H`0348@D
YA2400P<H`D@Q08<H`0448@<H`aS48@25:D00a2436<<H`0236<0112436<<Ha240`aS00@@Q1BU48@<
H`48@P0000D000@Q00048@0000L48@098@Q6<CF]6<HLib487>LU:B48008U:@<Q20049BTQ22DY8@P5
9BT022487>LU:BDY8@PLiaS68@P2:DX01bDY:DXU:B489BTLib48008Li`<HaP057>LQ21cW6<HLi`05
8@P29BT00b486<HLi`067>L00aS67>LLi`037>L011S65:DDYAS60QcW124800<U:B487>L00b4800@U
:AcW6<HHaP8Li`8DY@0348@HaQcW00DLi`8Q20037>LHaQcW008Q208Li`036<HLiacW008Li`8Q208L
i`038@PLiacW008Li`049BTQ22488@P39BT01QcW5:DDYB489BTQ208Li`068@PU:BU::DXU:B480RDY
00DQ22DY:DXU:B48008Li`059BTLiacW7>LQ2002:DX012487>LQ22e[0SF]00<]JbU:9BT00RDY0QS6
00L]JcF]:DXDY@@Q248<H`0512400`0012448@0A12432484124324851242248010aS48@<H`Q20P@Q
0PQ20P@Q0PQ20`@Q1@Q20`aS0PQ21P@Q0`Q20P@Q00@8@P@Q248<H`8@Q08<H`0<5:D<H`@Q9BU:DU:D
<H`DYB48@Q1>LdYB0U[F00INme[FCW=>Lc6<:DX26<H01aBU48@@Q248:DXHaPaS00848@076<HU:BU:
7>L48@Q236<00PQ20PaS1@Q20PaS00X8@P@Q2488@P@Q24848@Q236<48@@8@P<48@@8@P8<H`0?48@H
aQ24124YBTicBU8]J`00124DYA247>LQ21cW008Q20057>LHaQS66<H@Q00336<0112436<<H`Q20`aS
00<@Q0aS48@00a240`aS1@Q200L<H`Q236<<Ha24<Ha6<@02HaP01U:DG_MJeTic>LhU:@8Li`036<HL
iaBU008HaP037>LHaQBU00<HaP047>LHaQS66<H37>L26<H00acW6<HHaP036<H35:D56<H55:D36<H2
5:D00a245:DDY@025:D00a245:DDY@035:D00a245:DDY@036<H45:D01AS65:D@Q0aS48@00aBU00@@
Q1BU5:DHaPHDY@0348@DYA24008DY@0348@DYABU008@Q00336<@Q12400H@Q0@DY@0448@DYA245:D3
48@35:D:48@00`aS5:D@Q0025:D248@01aBU48@@Q12436<@Q1BU00T@Q0@<H`0548@<H`aS36<@Q006
36<348@010aS48@@Q1240QBU0a2410aS0Q241`aS1Q240`aS0QBU0Q240`aS00<@Q1BU48@00PaS0Q24
00<DY@aS36<010aS0a240@Q2000<12402R48AS4aS1cW9BTQ21cW8@PU:BU:0R4800@Lib488@PU:@@Q
208U:@068@PLiacW8@PU:B480QcW0bDY00DQ22DY9BTU:B4800<Li`038@PHaQS600<HaP8Li`DQ20<U
:@037>LHaQcW008Q20037>LHaQcW008Li`036<HLiacW00<HaP085:DHaQBU6<HLib487>LQ20@U:@8L
i`038@PU:BDY008HaP037>LDYABU008@Q08HaP8Q208Li`048@PLiacW6<H67>L48@P27>L38@P27>L0
0aS67>LQ20028@P00acW8@PU:@028@P46<H58@P012DY:DXU:BDY0R480RDY00@YBRDY8@PLi`8Q2004
9BTLiacW7>L39BT02b487>LU:BDY<H`e[C6<:DXU:B489BT00QcW00D]Jc6<9BTDY@Q2008<H`032484
8@@Q00/48@0500048@@Q1248@P02124010001248@P@Q0PQ200@48@Q21248@PH48@D8@P8<H`0348@<
H`aS00L8@P848@D8@P<<H`88@PD48@@8@P<48@0624848@@Q248<Ha240PaS00`@Q0aS248YBTHaDY@i
cQS67>LmkdHaCW<4F]H02E:DBU8aS2e[7>L@Q1BU36<HaP029BT02AS636<48@@Q6<HYBRe[8@P48@04
248336<824800`aS2488@P0212432484124424800`aS248<H`0336<248@01@Q2;F]>Ld8@:DX00P@Q
00<@Q1BU6<H01R4800<HaQBU36<00PaS00H8@PaS36<@Q0aS248236<00a2436<@Q00248@236<32480
0`aS248<H`0224801P@Q248@Q0Q2<Ha2409S6008DYAJeU[FDYA242DY7>LDY@8HaP035:DHaQS600LL
i`8HaP@Li`<HaP037>LHaQS600HDY@0348@HaQS6008HaP8DY@8HaP075:DHaQcW6<H@Q1BU6<H00QBU
0PaS00D@Q1BU6<HDYA24008DY@8HaPDDY@036<HDYA2400L@Q0035:DHaQcW00@DY@<@Q0045:D@Q124
48@25:D0112436<<HaBU1a2400<DYA2448@00QBU0a240QBU00@@Q1BU5:DHaP8DY@0336<@Q124008<
H`H@Q08DY@8@Q08DY@8@Q00436<@Q1245:D648@00`aS248<H`0536<348@436<01Q2436<<H`aS48@D
Y@8<H`0348@DYA2400D@Q0@<H`<@Q0<<H`<@Q0@<H`0548@<Ha245:D@Q00336<00aBU48@@Q00248@0
10aS48@<H`aS11240PaS00D@Q0aS48@<Ha240048@P0000P000@Q00048@00124000Q20P@Q00P000@Q
9BU:DS6<6<HQ22DY0bU:00<Q22DY8@P00RU:00@U:AcW8@PU:@8YBP038@PU:B4800<Q20039BTQ21cW
008Li`<YBP039BTLiacW008Q20039BTQ21cW008Li`@HaP8Q20<Li`8Q20059BTQ22487>LHaP037>L0
0aS67>LLi`037>L012486<HDYABU1AcW1R4800<Lib488@P00R4800@Lib487>LLi`<DY@036<HQ21cW
008Li`038@PLiacW008Li`039BTQ21cW008Li`@Q208HaP048@PU:BDY8@P27>L012489BTU:B480QcW
00lQ22DY9BTQ21S65:DHaQcW6<HLib489BTQ22DY:DX00Re[00DYBR488@PLib48008U:@@YBP039BTQ
224800@U:@047>LQ22DY:DX2;F/29BT02B489BTYBQcW6<HYBSF];F/Li`06248312400`0012448@0;
124224831243248612422483124224800`@Q248<H`02248212400`Q212448@04248010@Q24848@@Q
0PaS0Q240PaS00<8@PaS24801`@Q0`Q200<48@Q224800`aS00H@Q0aS36<<H`Q26<H29BT01aS65:DY
BSg_>LhYBRe[008icP07=JdYBRU:?NmF]DHa<H`00QBU00DU:B486<H@Q0aS008@Q0045:D<H`aS2483
36<00`Q236<8@P0436<00a2436<<H`0524800`@Q2488@P0324800`@Q2488@P022482124010Q236<@
Q1240QBU0QS600TLibDY:DXYBR486<HDYA245:D00Q2400/<Ha245:DDYB489BTQ21cW5:DHaQ24008<
H`0:48@HaQBU48@8@PaS7>LQ22DY8@P236<00`Q236<<H`04248436<248@03C6<BU9S65kgCW=F]E[F
DYA242U:8@PHaQcW008HaP035:DHaQS6008HaP037>LQ21cW00DLi`046<HLiacW8@P37>L25:D00a24
6<HHaP066<H00acW5:D@Q0025:D27>L36<H01A2436<@Q1245:D00a240QBU00DHaQ245:DHaQBU008H
aP0348@DYABU00@DY@0348@DYA24008DY@0348@DYABU008DY@0548@DYABU6<HDY@0248@010aS48@@
Q1BU0Q240QBU0a2400HDYA2448@@Q0aS48@25:D01QS65:D@Q1245:D@Q08DY@8@Q0045:D@Q1BU5:D5
48@00aBU48@@Q0045:D248@00aBU48@DY@0<48@436<348@01PaS48@DYA2436<8@PD<H`0348@DYA24
00L@Q08<H`<@Q08<H`<@Q00336<@Q12400<<H`8@Q00436<@Q1BU48@236<01Q245:D@Q0aS48@DY@@<
H`8@Q00636<@Q12448@<Ha240`aS0A240@aS0@aS0009124020001248@R48@Q0]JaS68@P49BT00bU:
9BTU:@058@P022DY:DXYBRDY8@PHaQcW8@P29BT37>L01248:DXU:BDY124800@Lib488@PQ208Li`05
6<HLiaS66<HLi`038@P00acW8@PQ20029BT00b487>LLi`087>L00b487>LHaP025:D011S67>LHaQS6
0acW124800@Lib489BTQ20@Li`8HaP035:DHaQBU00<Li`8Q20037>LHaQcW00DLi`<Q208Li`056<HQ
22489BTYBP028@P00acW8@PLi`038@P01AcW8@PQ22DY7>L00aS600<Lib487>L00acW00TU:BU:;F/]
JbU:7>LQ21cW8@P00RDY0RU:0RDY124800<U:B487>L00R480bU:00daS2U:9BTQ22DY:DXLiaS6:DXa
S2U:5:D48@0424800`@Q00048@0312400`0012448@051242248312400`0024848@02124224831243
248312402PQ212448@@Q248<H`Q236<8@P@Q0PQ200<48@Q224800PQ200<48@Q212400`Q20`aS00<8
@PaS36<00`Q21P@Q0PQ20`@Q0PQ200<<Ha2448@00Q240PaS01<DYB489BTDYAS6:DY243g_;F/aS3F]
>Lhe[BU:8@Pmke:DBU8]J`025:D00bDY8@PLi`0248@010aS48@DYA240PaS0PQ200<<H`Q236<01@aS
00H@Q0aS248<H`Q236<2248312462483124010aS2488@PaS0Q240QBU00DHaR488@PU:BU:008Q2009
5:D@Q12448@DY@aS48@<Ha24008Q20039BTHaQBU008DY@0336<@Q124008DY@0448@<H`aS6<H28@P0
0aS636<@Q00336<524802PaS248<H`aS48@e[DYBHaQNmdic0U[F00U>Lcg_:DXU:AS67>LHaQBU6<H0
0QcW0QS600<Lib487>L00QS600@LiaS67>LLi`<HaP038@PLiaS6008HaP8DY@<Li`8DY@8Li`046<HD
YA245:D37>L00aS65:DDY@0348@01aBU6<H@Q12436<@Q1S6008DY@8@Q0056<HDYABU5:D@Q0025:D0
0aS65:D@Q00248@25:D00a245:D@Q0025:D248@00aBU6<HDY@025:D248@25:D448@25:D010aS48@@
Q1S60Q2400D<Ha245:DDYAS600<DY@8@Q0065:D@Q1245:D@Q1BU1Q2400<<Ha2448@00aBU00H@Q1BU
48@DYA245:D648@25:D248@00`aS48@@Q00248@236<448@00`aS48@<H`0436<00`Q236<@Q00448@3
5:D548@236<348@436<248@336<00a2436<<H`0236<248@00`aS48@@Q00248@336<348@336<00a24
36<<H`0448@00`aS48@@Q00136<0000500048@0012400007124011S6>Lh]JacW0RDY00@YBRe[:DXU
:@<YBP069BTQ22489BTQ22DY0R4800<Lib487>L00R480acW1R480QcW0R4800@U:B487>LHaP<Li`03
8@PLiacW008Q208Li`048@PU:BDY8@P47>L012487>LLiaS60R4800<U:B487>L011S60b4800@LiaS6
7>LHaP<Li`8Q20037>LQ21cW008Li`<DY@@HaP077>LU:BDY9BTLib487>L00R480acW00@Q21cW7>LH
aP8Q20059BTYBR488@PU:@078@P29BT00acW6<HHaP047>L28@P01QcW8@PYBRe[9BTQ20<U:@0<7>LQ
2248:DXU:Be[=JdaS2DY7>LHaRDY0b480bDY0RU:00D]JbU::DXYBRDY008Q208Li`06;F/e[BU:6<H4
8@Q20PaS00@8@P@Q12448@88@P848@0300048@@Q00T48@88@P<48@88@P@48@<8@P@48@0724848@@Q
1248@PaS248010@Q00<8@P@Q124010Q200@48@Q236<8@P8<H`0548@<H`Q224848@02248312422482
1244248010@Q36<8@PaS0a2400<<Ha2448@0112400@DYAcW8@PLi`8HaP8Q200:6<HQ22e[<H`U:AS6
7>LQ21cW6<H25:D248@236<00`Q236<<H`0236<248@020aS248<H`aS48@<H`Q236<7248236<00`Q2
12448@0324801P@Q248<H`aS48@HaP8U:@8Q2005:DXaS36<<H`]J`028@P00aS648@@Q00348@336<0
10Q236<Lib480RDY00DHaQBU48@@Q1BU008@Q08<H`046<HLiacW6<H336<00`Q236<8@P0436<00`Q2
124<H`025:D01Cg_CW=S65kgDY@00Ukg00ABU4Ha;F/U:@<Li`<HaP067>LHaQcW6<HQ21cW0R480QcW
0aS600DQ21cW6<HLiaS600<DY@DHaP047>LHaQcW6<H45:D27>L01AS65:D@Q1BU48@00QBU00<@Q1BU
5:D00QBU00L@Q1BU5:DDYAS65:DHaP025:D248@36<H011BU36<@Q1240QS600<@Q1BU5:D011BU0QS6
0a240QBU00@HaQBU5:D@Q0<<H`8@Q0055:D@Q12436<@Q0045:D248@25:D248@25:D348@01ABU48@@
Q12436<00a240QBU1Q240QBU0Q240PaS00D@Q1BU5:D@Q1BU00@@Q0@<H`0348@DYA24008<H`8@Q0<<
H`8@Q00336<@Q124008@Q08<H`0648@DYABU5:D@Q0aS0a240`aS00@@Q0aS36<<H`@@Q0H<H`<@Q003
36<@Q0aS008@Q0<<H`03248<Ha2400<@Q00336<@Q124008@Q00336<@Q0aS008<H`002P@Q00P000Q2
8@PicRDY6<HQ22e[12U:00@U:BU:9BTYBP8U:@8Q20<U:@058@PLib489BTQ20027>L48@P00bDY8@PQ
20048@P011cW6<HLiaS611cW0b4800@Lib489BTLi`8Q20069BTLiacW7>LQ21cW0QS600HLib489BTL
ib487>L36<H00b487>LHaP026<H57>L00b489BTLi`027>L28@P00aS65:DHaP035:D01AS67>LQ2248
:DX00RDY0acW0b4800DLiaS66<HLib48008U:@8Q208U:@068@PLibDY8@PU:B480QcW00@Q22DY8@PQ
20@Li`<Q20056<HQ22DY;F/YBP029BT01BU:8@PQ21cW8@P00RDY00HaS3F]:DXU:AcW8@P39BT28@P0
1BDY:DXYBRU:9BT00bU:0bDY00HLiaS6:DX]JbDY6<H5248312401@Q212448@@Q24801@@Q00<8@P@Q
24800`@Q00<8@P@Q12400P@Q00@8@P@Q24848@<8@P<48@030008@PQ200<48@D8@P031248@P@Q0084
8@@8@P031248@P@Q0088@P0636<@Q1BU36<8@P@Q0PQ200D48@Q212448@Q200@48@<8@PD<H`8@Q08<
H`0348@DYABU008@Q08HaP8Li`8HaP8Li`065:DU:BU:<H`YBQcW0R4800DLiaS66<HHaQBU00H<H`04
248<H`aS48@436<00a2436<<H`03248336<224800`@Q2488@P0424801`@Q24848@aS248DYB48008U
:@8Q20089BTaS2e[;F/aS2487>L@Q0<DY@0748@<H`Q2248<HaBU48@00QcW00HQ22DY6<HDY@aS48@2
5:D0212436<<Ha245:DLiaS648@3248236<2248030aS248<H`aS48@HaQBU>Li:DVLiHaQBU09JeP06
E[E6<Be[:DXHaQcW0QS600<LiaS66<H00QS600<Q21cW7>L00QcW00LQ21S65:DHaQcW9BTQ20027>L0
1QS65:DDYABU6<HLi`8HaP035:DHaQcW008HaP8DY@8HaP037>LHaQS6008DY@8@Q0046<HDYAS65:D2
48@25:D01AS648@DYABU6<H00QBU00<@Q1BU5:D00QBU0Q240aBU0Q2400<DYA245:D00Q240QBU00@H
aQBU48@@Q0<DY@0448@DYABU5:D348@45:D348@01QBU48@DYA245:DHaP<DY@@@Q0035:D@Q124008@
Q00536<@Q12448@DY@0248@25:D348@25:D448@00`aS48@@Q0025:D348@010aS48@@Q0aS0a2400@<
Ha245:D@Q0D<H`0348@<H`aS00@@Q08<H`<@Q08DY@0448@<H`aS36<248@636<248@436<248@236<2
48@236<348@010aS48@@Q12410aS11240`aS00<@Q0aS36<00@Q200002P00124000@Q00048@002484
8@000P@Q00PHaSW>:DXLibU:;F/YBRDY1BU:00@U:B488@PU:@8YBP@U:@<Q20039BTLiacW008Li`08
9BTQ21cW7>LHaQcW8@PLi`8HaP<Li`8Q20059BTLiacW7>LU:@038@P67>L38@P27>L012489BTYBR48
0QcW0b480QcW00@HaR488@PLi`8HaP8Li`039BTQ21cW00<Li`046<HDYABU6<H27>L00aBU6<HLi`02
8@P00acW6<HLi`038@P011S67>LQ21cW0QS600HLib489BTQ22DY:DX29BT28@P00bDY8@PQ20037>L0
22487>LLiaS67>LQ22DY8@P27>L00bDY:DXYBP02:DX01BDY:DXQ21cW8@P00QcW00XU:BU:;F/YBRDY
8@PU:B489BTLi`<Q20039BT]JbU:008U:@04:DX]JbU:9BT28@P27>L012U:;F/YBQcW0PaS0`Q22`@Q
00<8@P@Q12400P@Q00<8@P@Q12400`@Q00<8@P@Q12400P@Q00D8@P@Q12448@Q200848@0324848@@Q
00<48@@8@P051248@PQ224848@0224821242248236<224801@aS48@@Q12424800`@Q00<8@P@Q2480
10@Q0`Q200@<H`Q22488@P8<H`0348@<H`aS008<H`8@Q0<<H`<@Q00436<@Q12448@35:D248@65:D0
0a2436<8@P0324800`aS48@<H`0236<020Q236<8@PaS248<H`Q236<6248236<00a2436<8@P042480
50@Q2488@PQ248@DYBDY;F/e[CW>?Nm6<DicE[EBU5JeDY@e[C6<7>L25:D01Q245:D<H`aS248<H`88
@P0748@HaRe[<H`YBRDY6<H00QBU10aS112400<<Ha2436<00PaS0Q240`aS01<@Q0aS36<HaR48CW=J
eVLiJeYNmfLiHaQJeTYB;F/U:AcW8@PLi`036<H37>L01QS67>LLiacW6<HDY@8HaP8Li`036<HLiaBU
00<DY@8HaP065:DHaQS65:DHaQBU0QcW00<DYAS67>L00QcW00@DYA245:DDY@8HaP8DY@066<HDYABU
48@DYAS60Q2400<DYAcW5:D00QBU00<HaQBU48@00QBU0QcW0a2400<<HaBU5:D011BU0Q2400DDYAcW
7>LHaQBU008@Q08DY@<@Q0035:D@Q1BU00D@Q08DY@8@Q00436<DYABU5:D248@011BU48@@Q1BU0Q24
0PaS0aBU00@@Q0aS48@DY@P@Q08<H`8@Q0035:D@Q124008@Q08DY@@@Q00336<@Q0aS00D@Q0045:D@
Q0aS248636<348@010aS48@DYA240`aS0Q2400<DYA2436<010aS0a240PaS00D@Q0aS36<@Q0aS008@
Q08<H`@@Q0@<H`<@Q0@<H`0348@<H`aS008@Q0<<H`4@Q04<H`0030@Q00@Licg_;F/Li`@YBP039BTY
BRU:00<YBP039BTQ22DY00<YBP038@PU:B4800DQ20@Li`8Q208Li`088@PLib487>LHaQBU6<HLi`8Q
208Li`<Q208Li`8Q208Li`036<HQ21cW00<Li`038@PLibDY008YBP038@PLiaS6008Q208Li`036<HL
ib48008Li`8HaP047>LQ22DY8@P27>L01B486<HDYABU48@00acW00<HaQBU7>L00RDY00@Q21cW7>LL
i`@Q20DLi`049BTLib489BT2:DX28@P39BT28@P01AcW8@PQ21cW6<H00QcW00<U:AcW7>L00b4800<U
:BU::DX00RU:0RDY00TLiaS67>LLibU:9BTYBRe[:DX00RDY1B4800@U:BU::DXYBP8U:@<YBP8U:@0:
8@PLiacW:DXaS2e[7>L<Ha2436<512401@Q212448@@Q24800`@Q00<000Q224803P@Q0PQ20`@Q0PQ2
0P@Q00<8@P@Q12400PQ200<<H`Q212400`@Q00@8@P@Q12448@88@P8<H`031248@PaS00@@Q0@8@P05
1248@P@Q1248@P0312400`Q236<8@P0224800`aS248<H`0236<01A2436<@Q0aS248010aS0Q240QBU
00@@Q1BU48@DY@8@Q08DY@0>7>LDYABU5:DHaQBU48@8@PaS248<Ha2436<@Q0D<H`04248<H`aS36<2
248010@Q2488@PaS0a240`aS20Q20QBU00PU:Be[=JdicSg_AS5:DU[F0e:D00<icRe[7>L011BU00<<
H`Q236<00PaS00<8@PaS48@00be[00PYBQS65:D@Q0Q248@8@PaS0Q2400<DYA2436<00`aS00<@Q0aS
36<00`aS00L@Q0aS48@Lib48BU9F]@02JeX01ekgJeYS65[FAS4aS2U:008Li`@HaP037>LHaQcW00<L
i`<HaP8DY@8Li`8Q208HaP@DY@@HaP035:DHaQcW00<HaP037>LQ21S600LDY@8HaP055:D@Q1BU5:DH
aP055:D00aS65:DDY@025:D00a246<HDY@025:D348@25:D548@46<H248@00aBU48@@Q0045:D348@2
5:D01A2436<@Q1245:D00Q240aBU00<@Q1BU48@00Q2400<DYA245:D00aBU0Q2400<DYA2448@00Q24
00DDYA2448@<Ha24008DY@T@Q08DY@<@Q00336<@Q0aS008<H`8@Q00436<@Q12448@336<00a2436<<
H`0336<448@010aS48@@Q1BU0Q240PaS00@@Q1BU48@@Q0@<H`0348@<Ha24008@Q0<<H`@@Q08<H`8@
Q0<<H`8@Q00436<@Q12448@236<248@536<00a2436<<H`012480000500048@001240000712400acW
@Q0e[@038@P012DY:DXYBRDY0Re[00@U:AcW8@PU:@8]J`8U:@8YBP03;F/U:B48008Q20037>LHaQcW
008U:@098@PLib488@PU:B486<HDYAS6008Q20047>LQ22489BT68@P00acW8@PQ20037>L00b489BTU
:@028@P39BT012487>LHaQcW0R480QcW0aS600@LiaS67>LHaP8Q20039BTQ21S600<Li`045:DHaR48
7>L26<H01QcW9BTU:BDY8@PLi`<Q20037>LQ2248008Q208HaP047>LQ22DY9BT38@P00bDY:DXU:@03
8@P39BT28@P37>L022489BTU:B487>LQ22DY;F/2:DX69BT012489BTQ22DY12U:00DU:B488@PQ22DY
008]J`059BTLiacW8@PYBP069BT28@P2:DX01C6<;F/DY@aS12400PQ20P@Q00<8@P@Q24802@@Q00D8
@P@Q12448@Q200H48@0324848@Q200<48@88@P031248@P@Q00D48@05248<H`Q224848@0324821242
248248@236<224825:D021242488@P@Q24848@Q2124224801@@Q2488@PQ212400PQ21`aS00@8@PaS
2488@P<<H`88@P0536<@Q0@Q124Li`02>Lh011S612448@aS0`Q200d@Q2DY:DXHaPQ21248@PaS124<
HaBU48@<H`0212400`Q236<<H`0524800`@Q248<H`025:D636<224803@aS2488@PQ236<Lib48;F/a
S3F]@Q1BU6Li009_N`08JeYcW7_NHaQBU2DY8@PDY@8@Q08<H`<8@P8<H`03124LibU:0092408Li`03
5:D<H`aS00<@Q08<H`0448@<H`aS48@236<248@336<348@03RU:<HaJeV<HJeY_Nf<HIcUS65[FBU8]
JbDY7>L28@P00aS67>LLi`027>L26<H01B487>LLiaBU6<H00QBU00@Q21cW8@PLi`@DY@8HaP045:DH
aQcW6<H35:D00aS65:DHaP027>L26<H00aBU6<H@Q0035:D26<H00acW5:DDY@045:D26<H00aBU48@D
Y@026<H25:D011246<HDYABU0Q240aBU00<@Q1BU5:D00Q2400@DYAcW7>LLi`<DY@0348@DYABU00<D
Y@<@Q0<DY@<@Q00336<@Q12400@DY@0448@DYABU5:D348@00aBU48@@Q00248@45:D011245:D@Q1BU
1Q2400H<Ha2448@@Q1BU48@55:D00a2436<<H`0248@011BU48@<H`aS11241`aS00@@Q0aS48@<H`D@
Q00436<@Q1245:D348@636<348@336<548@25:D348@436<348@536<00aBU48@@Q00236<00a2436<<
H`01248000T48@0800048@@Q6<I2436<8@PU:@8Q208YBP8]J`07:DXU:AcW8@PU:BU:9BT00bU:00@]
JbU:9BTU:@8Q208HaP8Q20039BTQ2248008Li`048@PLiacW6<H27>L01QS67>LLib489BTQ208Li`07
8@PU:B487>LQ21cW9BT00QcW0R480RDY00<Q21cW8@P00RDY00@Q21cW7>LHaP@Li`@HaP<Li`8Q208L
i`066<HLiaS66<HDYAS611cW00<Q22DY9BT00QcW00@HaQcW8@PLi`@Q20<HaP058@PU:BU:9BTLi`03
8@P012DY8@PQ21cW0bDY00DQ21cW6<HHaQcW00<Q20067>LQ22488@PU:BU:0RDY0R480RDY00TQ21cW
6<HQ22DY;F/YBRDY:DX00RDY0R480RDY00<YBRDY9BT00b4812DY0RU:0QcW00LU:BU:;F/U:ABU48@4
8@03248212400`Q212448@0212400`Q212448@0512400`Q212448@04124010Q212448@Q20P@Q00D8
@P@Q12448@Q200H48@D8@P<48@0524848@@Q1248@P0336<00`Q2124<H`0248@236<4248212442480
0`@Q2488@P02248836<01`Q236<<H`Q236<8@P@Q0088@P0436<8@P007>L2=Jd00b480008@P0336<0
1PQ236<U:Be[7>L<H`848@88@P@@Q088@P0<36<8@PaS24848@Q21248@P@Q248<Ha240PaS00<@Q0aS
36<00PQ200D<H`Q224848@Q2008<H`076<HU:Be[;F/e[Cg_DY@00V]J00UcW6]JKg]g_F<HDY@]Jb48
5:D00PaS0`Q200<<H`Q224800PQ200TLibe[?NlicR485:D@Q0aS48@00`aS0a2400@<Ha2436<@Q0<<
H`8@Q00A36<@Q0aS48@U:Be[F]IS66LiKg]S66]JG_MJeTYB<H`]J`037>L26<H27>L26<H27>L01b48
7>LHaQS65:D@Q1S6008U:@037>LDYABU008HaP8DY@<HaP047>LHaQBU6<H25:D47>L01ABU48@@Q1BU
6<H00aBU00<LiaS66<H01aBU00<HaQ245:D00aBU00<@Q1BU48@00Q240aBU0Q2400<DYA245:D00Q24
00@DYAS67>LLi`<DY@0548@<Ha245:DHaP025:D248@25:D348@01QBU48@DYABU48@DY@<@Q00336<@
Q12400H@Q0DDY@0348@DYA24008@Q0035:D@Q12400<@Q0035:D@Q12400D@Q0065:D@Q12448@<Ha24
0`aS0Q2400<<Ha2448@00Q241PaS00P@Q0aS36<<Ha2436<@Q0aS11240`aS0Q2400H<Ha2448@<Ha24
36<248@236<010Q248@@Q1240PaS00@@Q1BU48@@Q0<<H`0348@<H`aS00H<H`8@Q0<<H`0348@<H`aS
008@Q04<H`0000H48@00124000@Q000612402R48AS4aS1cW9BTYBRDY:DX]JbU:0RDY00@Q22U::DXU
:@<YBP05;F/YBRDY9BTYBP029BT01R487>LLiacW9BTQ208Li`8Q208Li`036<HLiacW00<Q20087>LQ
22489BTQ21cW6<HLi`8Q20066<HLiacW8@PLib480RDY00HQ22DY:DXYBRDY8@P36<H012487>LLiaS6
0QcW0QS611cW0RDY00<LiaS65:D00QcW00@HaR489BTU:@8Li`<Q20<HaP068@PU:BU:9BTLib480QS6
00<Lib488@P0124800PU:B48:DX]JbDY8@PLib481BDY0acW00HYBRDY7>LLibDY:DX28@P012DY:DXY
BRDY0R4800/Lib489BTYBRDY7>LQ22DY;F/YBRDY00HQ20<U:@8Q20049BTYBRDY9BT2:DX38@P01BDY
>LhmkbDY5:D00P@Q00<8@P@Q12403`@Q00<8@P@Q124010@Q0PQ200<48@Q212400`@Q00@8@P@Q1244
8@<8@P<48@88@P031248@P@Q0088@P051248@PQ2248<H`0248@636<3248010@Q248<H`Q20P@Q00D8
@PaS24848@Q200@<H`04248<H`aS36<524800`aS248<H`0236<3248010aS48@@Q0aS0PQ200<<H`Q2
24800P@Q0`aS0PQ200D48@aS36<48@Q2008@Q00324848@Q2008<H`P8@P0436<DYAS65:D236<03@Q2
36<<H`Q236<@Q0aS248<Ha24;F/icT8@008mk`03AS5JeVmk009_N`08IcU[FW>LKg]cW48@<H`HaP8@
Q0<48@0=248<H`Q224848AS68@PicSg_9BTLia2436<01Q2420aS01@@Q1BU5:D@Q0aS48@YBS6<G_MW
>FmkLiaW>FmkHaQF]D8@;F/U:AcW11S600<DYAS66<H00QcW00@Q21S66<HDY@8HaP@Li`THaP087>LH
aQS65:DHaQcW6<HLi`8HaP0348@DYA24008HaP035:DHaQS6008Li`8HaP8@Q0035:D@Q1BU008DY@04
48@DYABU6<H25:D248@00aBU48@DY@025:D348@00`aS48@DY@0248@011BU7>LLiaS60Q240aBU00DH
aQBU5:D<Ha24008DY@0348@<Ha24008@Q0045:D@Q12448@35:D448@00aBU48@@Q0035:D248@00aBU
48@@Q0045:D00`aS48@@Q0025:D00a245:D@Q00848@25:D00a2436<@Q00248@00`aS48@<H`0348@0
10aS48@@Q1241PaS00@@Q0aS48@<H`<@Q00536<@Q0aS48@DY@0248@00`aS48@@Q00336<00`Q236<@
Q00448@236<248@00`aS48@@Q00248@00`aS48@<H`0436<448@336<748@236<0000300048@@Q00T4
8@047>M6<C6<8@P29BT2:DX00be[:DXU:@028@P39BT012U:;F/]Jbe[0RU:00DU:BU::DXU:B48008L
i`039BTYBRDY00<Li`8Q20<HaP8Q20039BTQ224800@Q20037>LQ224800TQ20037>LQ22U:00<YBP04
7>LHaQS66<H67>L26<H011cW8@PLib480RU:00PQ21S66<HHaQcW6<HLib4811cW00HU:AcW7>LHaQcW
8@P29BT01b487>LHaQcW6<HLib48008U:@8Q20<U:@03:DXU:B48008Li`068@PU:BDY8@PYBR480QcW
0R4800<U:AcW8@P00RDY0R4800dU:BU::DXU:B489BTQ21cW8@PYBRDY8@PU:@03:DX48@P29BT02248
9BTYBRDY8@PLibDY:DX29BT00bU:;F/U:@038@P013W>@Q0YBQS60P@Q00<8@P@Q12401`@Q00<000@Q
12400PQ230@Q00<8@P@Q12400P@Q00D8@P@Q24848@Q200<48@0324848@@Q00<8@P031248@P@Q0088
@P061248@PQ248@DYA240`aS00<@Q0aS24800PaS0PQ200@48@Q224848@88@P0336<8@PQ2008<H`<8
@P0548@<H`aS248<H`04248436<224800`aS2488@P0436<324801@aS2488@PQ236<00Q240P@Q0PQ2
00D48@aS48@@Q0aS00T8@P051248@PaS248@Q0026<H00aBU2488@P0436<021242488@PaS48@]JcF]
@Q02?Nl00dHaF]I_N`02Kg/2JeX2Li`01VmkAS4]JaBU36<@Q0H8@P848@086<HQ23W>?NlU:AS648@<
H`8@Q08<H`0348@<Ha2400D<H`0>248<H`aS5:D@Q1BU36<@Q2DY<HaNmfLiKg]cW09[FP05IcUF]DHa
;F/YBP047>L01QS65:DHaQcW8@PLi`8HaP037>LHaQS6008HaP@Li`046<HLiaS66<H35:D36<H00aBU
6<HDY@026<H27>L26<H45:D26<H01ABU6<HQ21S65:D00Q240aS60QBU00D@Q1S66<HDYAS6008DY@8@
Q0055:DHaQ245:D@Q0025:D248@010aS5:D@Q1BU11S60aBU00<HaQBU6<H00a240aBU00<<Ha2448@0
0aBU0a241ABU0a2400DDYA2436<<HaBU008@Q0045:D@Q1BU6<H448@25:D648@00aBU48@@Q00236<5
5:D448@336<00a245:D@Q00348@336<0112436<<H`aS1a2400<<Ha245:D0112410aS0a240PaS0Q24
0`aS0Q2400DDYA2448@@Q0aS00<@Q0<<H`0448@<H`aS48@236<0112436<8@PaS0QBU0Q240PaS0@Q2
00021240200012448@@Q0008@P@Q000212401B48AS4e[B48:DX00be[00<YBRDY8@P00b4812U:0be[
1RU:0R480QcW0R4800@Lib487>LLi`<Q20047>LQ21cW7>L39BT28@P29BT00b487>LHaP027>L02248
7>LLiacW6<HLiaS68@P39BT011cW6<HHaQS60QcW00DHaQcW8@PLib48008HaP047>LU:BDY8@P27>L0
32486<HHaQcW8@PU:AcW6<HLiaS67>LHaPHLi`<Q20047>LHaQcW8@P37>L012489BTU:BDY0R4800<U
:B487>L00R4800TU:B488@PQ22U:9BTQ22DY:DX00RDY00@Q22DY9BTQ20<YBP039BTQ21cW00<Q2004
9BTQ22DY:DX38@P00acW8@PU:@048@P00bDY8@PQ20027>L00b487>LQ2002:DX012DY8@PLib480QcW
00De[CW>:DXHaP@Q00<8@P031248@P@Q00@48@0324848@@Q00T48@0324848@@Q00848@0324848@@Q
00848@<8@P031248@P@Q00P48@88@P031248@PQ200848@88@P0436<8@PaS36<348@00`aS2488@P04
24821245248010aS48@@Q0aS0`Q210aS0PQ200@48@Q212448@88@P8<H`8@Q00536<8@PQ224848@03
24821244248010@Q2488@P@Q10Q20PaS0PQ200D<H`Q236<8@PaS0088@P0536<8@PQ2248<H`0248@5
36<22480312424848A246<I6<EJeCW=243F]?NmBU09[FP9_N`9W>@09MkeooeJe<H`@Q0aS48@8@P@Q
0088@P8<H`0424848ABU7>L2<H`02AcW6<H@Q0aS48@<Ha2436<8@P0436<224800`aS2488@P0348@0
1ABU48@@Q2e[=Jd00VLi00U_Ng>LJeYW>EkgCW=242U:9BT00QcW0aS600<DYAS67>L00QcW1AS600<Q
21cW8@P00QcW00<HaQcW7>L011S60QcW00DHaQ2448@DYAS6008Li`8DY@0348@HaQcW00<DY@DHaP03
5:D@Q12400<HaP035:D@Q1BU008DY@036<HDYA2400@DY@8@Q0035:D@Q1BU00D@Q0045:DLiacW5:D2
48@45:D01Q245:D@Q1245:D@Q08<H`0448@DYA2448@25:D348@00aBU6<HDY@025:D011245:D@Q124
0PaS00@@Q1BU5:DDY@<@Q0035:D@Q1BU00<@Q0035:D@Q124008@Q0<DY@8@Q00436<@Q1BU6<H25:D6
48@336<348@010aS48@<H`aS11241@aS00<@Q1BU5:D00a240`aS00D@Q1BU5:D<H`Q2008@Q0<<H`8@
Q08<H`0348@<H`aS00@@Q00536<@Q12436<@Q0025:D0112436<<H`aS0Q240PaS00<8@PaS48@00a24
10aS00001@@Q00048@@Q00001`@Q00DU:DHa<H`LibU:008aS003;F/YBRDY008U:@038@PU:B48008U
:@03:DX]Jc6<008]J`@YBP039BTQ21cW00<Q20059BTQ21cW6<HLi`098@P01BDY8@PQ22487>L00R48
00@Lib487>LLi`@Q20046<HLiacW7>L48@P27>L01QS67>LLib487>LQ20DLi`<Q20DLi`<Q20<Li`8H
aP8Li`8Q208Li`078@PU:BDY7>LHaQcW8@P00acW00@Q22DY9BTU:@8Q20049BTQ21cW7>L29BT38@P5
9BT38@P012DY:DXU:B480RU:00HU:B488@PQ21cW8@P29BT00bU:9BTU:@028@P29BT28@P011cW8@PU
:B480QcW0R4800@U:AcW8@PU:@8YBP0:8@PLibDY8@PLicW>@Q0]JaS61246248<12401@Q212448@@Q
00000P@Q00@8@P@Q1248@P@48@0424848@@Q1242248010@Q2488@PQ210@Q00@8@PaS24848@@8@P8<
H`0448@<H`aS5:D236<010@Q36<<H`aS0PQ200L<H`Q21248@P@Q36<8@P0536<00`Q236<<H`0236<3
248236<224800`@Q248<H`0248@00aBU36<<H`0224800`aS2488@P0224801@aS2488@PQ212401PQ2
00<<H`Q236<00Q2400<<H`Q224800PaS0PQ200<<H`Q212400PQ200H<Ha2448@@Q0aS248536<03`@Q
248@Q1S6@Q1>Le:DAS4icSg_DYA[FVmkLia[FP02IcT02GNmOomF]CF]48@<Ha24248<H`02248236<0
3@Q2124@Q248>Lhe[AcW5:D@Q0Q248@<Ha24008<H`0448@<Ha2436<3248336<248@01QBU48@@Q2U:
>LiS609[FP06MkeW>FmkG_M>Ld8@0Re[0QcW0aS60QcW00@HaQcW7>LQ208Li`066<HLiaS66<HLib48
0QcW0QBU1QS600LLiaS65:DDYAS68@PLi`045:D26<H35:D46<H55:D00aS65:DDY@025:D011S65:DD
YABU0a2411BU0Q2400<DYA245:D00Q240QBU0QS611BU00@HaQBU6<H@Q0@DY@8@Q0<DY@0448@DYABU
5:D248@25:D00aS65:DDY@025:D00a245:DDY@0348@01QBU48@DYA245:D@Q0<DY@0548@DYABU48@D
Y@0848@011BU48@@Q1BU1Q2400<<Ha2448@00Q2400<<Ha2448@00a2400<<Ha2448@010aS0Q240`aS
0Q240QBU0Q240`aS0Q2410aS0Q2400<<Ha2448@00Q2400<DYA2436<00PaS0a2400DDYA2436<@Q0aS
00@@Q08<H`03248@Q0aS00<@Q00436<@Q12436<12480000400048@@Q000612401P00124Lid8@;F/Q
20<YBP@U:@06:DXQ22488@PYBRe[0bU:00<aS3F];F/00RU:00@U:BU:9BTU:@8Li`8Q20049BTQ22DY
8@P29BT28@P01bDY8@PU:B487>LQ22DY008YBP8Q208Li`<Q208Li`036<HLib48008Li`<HaP@Li`0;
8@PLiacW8@PLib489BTQ21cW6<HLi`029BT28@P011cW8@PU:B480QS600HLib486<HHaR489BT28@P2
7>L28@P37>L01R487>LLiaS67>LQ20<Li`8Q20049BTLiacW8@P39BT27>L48@P00bDY:DXU:@058@P0
0bDY:DXYBP049BT00b489BTU:@027>L01248:DXYBRDY0QcW0b480QcW00@HaR488@PQ20<Li`8U:@06
:DXQ22489BTLibDY0R4800DmkdHa<H`Q20@Q008<H`D48@0300048@Q200848@0300048@@Q00L48@88
@PD48@0324848@@Q00<48@0324848@@Q00L48@L8@P0536<8@PQ2248@Q00236<2248336<01PQ236<<
H`aS24848@@8@P8<H`8@Q08<H`04248<H`aS2482124010Q236<<H`@Q0`Q200<<H`Q236<0112400L8
@PaS12448@Q2124<H`0724831242248010aS248<H`aS0Q242@aS0`Q20PaS0PQ20`aS00h8@PaS48@8
@P@Q48@DYD8@F]I:DSW>9BT]JdYB0U[F0VLi00Ug_G_NJeY[FSF]:DXHaQ246<H00Q240R4800THaQ24
12448AS6;F/icS6<5:D0112400<<H`Q224801@aS0PQ200H<H`Q248@<Ha2436<25:D01aS6<H`icV<H
IcU[FW>L009[FP04G_M:DSg_:DX38@P011cW5:DHaQcW0R4800<HaQcW7>L00acW0QS60acW1aS600@D
YAS65:DHaP8DY@036<HLiaS600<DY@036<HDYA24008DY@8HaP057>LHaQBU6<HDY@0248@55:D36<H0
11BU48@@Q1S60QBU00<<Ha245:D00aBU00<@Q1BU48@00QBU0QS600<LiaBU5:D00QS600<DYA2448@0
1ABU0Q2400<<Ha245:D011BU0a2411BU1a2400<DYA2448@00Q2400@DYA245:DDY@8@Q0065:D@Q124
5:D@Q1BU0Q2400@DYA245:D@Q08<H`0348@DYA2400<DY@8@Q00536<@Q1245:D@Q00336<01ABU48@@
Q0aS48@00PaS00<@Q1BU48@01@aS00<@Q1BU48@00`aS00D@Q0aS48@@Q0aS00@@Q00336<@Q124008@
Q00636<@Q0aS248@Q1BU0Q241PaS0a240`aS00D@Q0aS36<<Ha24008<H`03248<Ha24008<H`48@P00
1@@Q00<000@Q124010@Q00HLicg_;F/U:BU:;F/2:DX59BT01B489BTU:BU:;F/00bU:0S6<00D]JbDY
9BT]JbU:008Q20067>LQ22DY9BTQ21cW0b480RDY00<Q22DY8@P00R480QcW0bDY00<Q21cW8@P01248
0QcW00<HaQcW8@P00R4800HHaQcW7>LHaQcW6<H27>L01B487>LLib489BT00R4800DHaQcW8@PQ22DY
00DQ20<Li`036<HLiacW00LLi`038@PLiacW008Li`058@PLiacW7>LQ20027>L28@P022DY8@PQ21cW
9BTYBRDY8@P27>L00b489BTU:@029BT2:DX29BT27>L29BT3:DX29BT28@P39BT28@P2:DX00bDY7>LL
i`028@P01bDY7>LLiacW8@PU:B48008Li`8Q208U:@8Q208Li`<Q2008@Q1>Lc6<6<H48@Q248@<H`@4
8@0324848@@Q00D48@0400048@@Q12422489124010Q21248@PQ20`@Q0PQ21P@Q00<8@P@Q12400P@Q
00<<H`Q236<00PQ20PaS00<@Q0aS36<00PQ20`aS1@Q200<48@Q224800PQ21@aS1@Q20PaS0`Q200D4
8@Q2248<H`Q2008<H`8DY@@<H`X8@P051248@P@Q24848@02248236<348@336<010Q236<<H`Q20PaS
10Q20PaS00<8@PaS36<00PQ20PaS00/8@P@Q36<@Q48@E[E>LcW>:DX]JdYB009JeP9W>@0;MkekgVmk
IcTe[Be[6<H@Q1BU48@DY@027>L03QBU36<48@@Q7>LU:CW><H`HaQBU48@<Ha2436<224800`aS48@@
Q00236<3248236<00a2436<@Q0035:D00bU:>LiS6002JeX02G>LIcU[FUkgCW<mkbU:9BTLi`036<H2
7>L00b487>LLi`037>L00b486<HLi`037>L00aS65:DDY@086<H35:D26<H25:D00a245:DDY@045:D6
6<H45:D36<H85:D00aS65:D@Q00348@00aBU48@DY@045:D46<H55:D01QS65:DDYA245:DHaP8DY@04
48@<Ha2448@25:D00a245:DDY@0248@35:D248@00aBU6<H@Q00448@011BU48@@Q1240aBU00@@Q0aS
36<<H`<@Q00336<@Q12400D@Q08DY@0348@DYABU00<DY@0348@<H`aS00<@Q08<H`H@Q0@<H`0348@<
H`aS00L@Q0<<H`@@Q00336<@Q0aS00<<H`<@Q00336<@Q0aS008@Q00336<@Q1BU00@<H`L@Q0L<H`03
48@<H`aS00@<H`0000<000@Q00000`@Q00X000Q2124000@Q248U:DHa<H`Li`8YBP0:8@PLib489BTQ
21cW:DX]Jc6<:DX29BT0136<?NlmkcF]0RU:0Re[00HYBR488@PLibDY8@P27>L00b489BTYBP029BT2
8@P00bDY:DXYBP028@P00acW8@PQ20048@P27>L01B489BTLiaS67>L00R481AS600DLiaS67>LQ21cW
00DQ208Li`066<HQ22DY:DXQ21cW0b481AcW00@HaQBU7>LQ208U:@8Li`038@PLiaS6008HaP8Li`05
6<HLib489BTQ20037>L012DY:DXU:BDY0R480RDY124800<Lib488@P0124800<LibDY9BT00RDY00`Q
22DY8@PQ22DY:DX]JbU:8@PU:BU:;F/29BT58@P00bDY8@PQ20037>L68@P01BDY8@PQ21cW8@P00RDY
00HQ23F]@Q0aS1S6124236<010Q212448@Q20`@Q00@000Q22488@P@48@88@P@48@0324848@Q200D4
8@0324848@@Q0088@P041248@P@Q1243248212400`Q236<8@P0724800`aS2488@P0236<00`@Q2488
@P0236<00`Q236<<H`0624801@aS48@@Q12436<010Q200<48@Q224800PQ20`@Q00D8@P@Q2488@PaS
00@@Q00536<8@PQ224848@0424800`@Q24848@0224800`@Q24848@0424801@aS248DYABU6<H00QcW
00HDYA246<HLiaS65:D224800`aS2488@P0224800`@Q24848@0624802PaS8@Pe[CF]:DXHaQcW<Ha2
44Ha0U:D00Q>Le:D@Q0mkbe[:DXQ21cW0QS600DLib488@PHaQBU0088@P049BTe[Cg_<H`448@836<0
0`Q236<<H`0436<248@25:D00acW=Je24002HaP026LiLia[FV]JG_M:DSF]9BT28@P27>L00aS67>LQ
20038@P00aS67>LLi`027>L02AS67>LLiacW5:DHaQcW6<HLi`046<H00acW5:DHaP025:D00aS67>LH
aP025:D00a246<HDY@045:D26<H25:D01aS648@@Q1245:DHaQBU008HaP035:DHaQBU00<DY@8@Q003
5:DHaQS6008DY@0348@DYAS6008DY@0348@DYAcW008HaP8DY@0548@DYABU6<H@Q0025:D26<H548@3
5:D248@010aS48@DYA240QBU112400<DYAS648@021240aBU00D@Q0aS36<DYA24008DY@D@Q0065:D@
Q12448@DYA2411BU0a2400D<Ha2436<@Q1BU00<@Q0<<H`8@Q0<<H`0348@DYA2400<@Q0045:D@Q124
36<248@00aBU48@@Q00248@01@aS48@<Ha2436<0112400<<Ha2448@00Q2400@<Ha2448@@Q0<<H`<@
Q08<H`8@Q0@<H`03248<H`aS008@Q0@<H`000`@Q00<000@Q12401P@Q00@Q24YB;F/Li`8YBP038@PL
iacW008Q200=9BTYBRe[;F/aS2U:9BTaS3W>?Nle[BU:9BT00RU:00<]JbU:8@P00R4800@U:B488@PQ
208U:@048@PLib489BT2:DX01BDY7>LQ22487>L00RDY00<Q22DY7>L00QcW0bDY00DLiaS66<HLib48
008Li`<HaP<Li`048@PU:B488@P27>L032486<HHaQcW9BTYBRDY8@PLib489BTQ20PLi`058@PLiacW
7>LQ20027>L011S67>LLiaS60QcW0b4800HLib489BT]JbU:9BT27>L012DY:DXYBR480QS600<Q22DY
9BT00RDY0RU:00HU:B488@PU:BU:9BT28@P012DY8@PU:BU:1BDY00DYBRe[:DXU:B48008Li`8Q2006
9BTQ22487>LQ21cW0b4800DU:B489BTU:AcW008Q208U:@058@PicTHa<H`Li`0224801a2436<48@@Q
24848@Q200P48@0524848@001248@P0912400`Q212448@021242248412401PQ21248@P@Q248<H`X8
@P8<H`03248<H`Q200@8@P0336<8@PQ20088@P0336<8@PaS008<H`0548@<H`Q2248<H`0624821245
24802P@Q36<<H`aS48@<H`Q236<8@P@Q1@Q20P@Q0PQ200@<H`Q212448@<8@P@<H`035:DHaR48008L
i`056<HDYAS65:D@Q00236<72482124224804`aS248<H`aS8@PaS3F]:DXHaQcW<Ha244HaE[E>Le:D
E[E243W>008YBP099BTLiaS65:DHaR489BTHaQ240088@P048@PaS3g_=Jd25:D02A2436<<H`aS248<
H`Q236<8@P0336<2248236<248@01PaS5:DHaQS6=Jdmk`9S6007IcU_NfLiJeYNmdYB?Nl00RDY00<L
ib486<H00acW00<Q21cW6<H00QcW00@HaQcW7>LHaP8Li`@HaP067>LHaQBU6<HLiaS60aBU11S600@D
YAS65:DHaPDDY@HHaP@DY@056<HDYABU5:DHaP065:D011S65:DDYABU0a240aBU0QS60QBU0aS61ABU
00HHaQBU5:DDYA245:D248@00aBU48@DY@025:D348@00aBU48@@Q0035:D0112436<@Q1BU1Q240aBU
00<<Ha2448@00Q240PaS1A240QBU11240aBU00@@Q1BU6<HHaP8@Q00336<@Q1BU008@Q0<<H`<@Q005
36<@Q1245:D@Q00336<248@35:D448@01@aS48@@Q1245:D00a2410aS1A2400<<Ha2448@00a2400L<
Ha2436<<H`Q236<DY@0548@536<548@336<0000500048@@Q1240000712401QcW@Q0aS1cW9BTQ20<L
i`049BTQ22DY;F/2<H`01BU:;F/aS3W>=Jd00Re[0RU:00@]JbU:9BTQ20DU:@058@PU:BDY8@PU:@03
8@P29BT28@P37>L012489BTLiaS60QcW00@YBR488@PLi`8Q20047>LQ21cW7>L36<H27>L28@P01AcW
6<HLib489BT00QcW0QS600`Q22DY9BTQ21S67>LU:B487>LHaQcW6<H27>L26<H28@P01AcW6<HQ22DY
8@P00aS60acW0b480QcW00HQ22U::DXU:B489BT2;F/00bDY7>LQ20038@P02AcW9BTYBRU:9BTQ21cW
8@PU:@02:DX00bDY7>LQ20028@P29BT00bU:9BTQ20049BT48@P022DY8@PQ22489BTQ22DY7>L48@P0
0acW8@PQ20029BT28@P022U:8@PQ22e[>Lh]JacW248236<3248412400`Q212448@06124224891240
0`Q21248@P031242248212422483124536<0112436<<H`aS0`Q20PaS10Q200D48@001248@P@Q0088
@P@<H`06248<H`aS5:D@Q0aS1`Q200<48@Q224800P@Q00@8@P@Q2488@P<<H`03248<H`aS0088@P8<
H`0324848@Q20088@PD48@0524848@Q21248@P0236<01Q2436<<Ha2436<@Q08<H`<@Q0D<H`<8@P04
1248@P@Q2482124224800a24248@Q0026<H00aBU6<HQ2002;F/01BDY;F/e[CF];F/00RU:00@icTic
AS4aS08HaP039BTYBR48008DY@077>LQ23W>?NlaS2U:5:D00Q240PQ200<<Ha2448@00PaS00<8@PaS
24800`aS00<8@PaS36<00Q2400TDYAS67>LmkdYBIcU[FVLiJeX00VLi00=JeT8@<H`00b480QcW00<H
aQcW7>L01acW00@DYAS66<HHaP8Q208Li`086<HLiacW6<HLiaBU6<HDY@8HaP8DY@8HaP045:D@Q124
5:D26<H25:D248@36<H011BU6<HDYAS60QBU00<HaQBU5:D021BU0Q2400HDYAS66<HDYA246<H35:D3
6<H35:D00a246<HDY@045:D00aS648@<H`0248@011BU48@@Q1BU212400<DYA245:D00a240QBU0a24
0QBU00D@Q0aS48@@Q1BU00@@Q0<DY@0536<@Q12448@DY@0236<00a245:D@Q0025:D011S65:DDYABU
0Q2400@DYA2436<<H`@@Q00736<@Q12448@<Ha2424800`aS00@@Q1BU6<HLi`8DY@8<H`<@Q0045:D@
Q12436<348@236<348@236<248@236<448@336<00a2436<@Q00336<348@00`aS48@<H`0236<00`Q2
36<<H`0248@236<00003124000@Q00848@0500048@Q21240000212401b48@Q0aS1cW8@PU:AcW00<Q
208U:@04:DX]JbU:9BT2:DX013F]>LhaS2e[1BU:00DQ21cW8@PQ22U:00<U:@038@PU:B4800<Q2003
9BTQ224800<Li`038@PLiacW00<Li`8U:@038@PLiacW008Q20049BTQ21cW7>L46<H011cW8@PLib48
11cW0R4800<HaQBU7>L00RU:00HQ21BU7>LU:B487>L26<H37>L00aS67>LQ20027>L011S67>LU:B48
0QS60QcW00<HaR488@P00R480QcW00LQ22e[:DXU:B487>LU:@02:DX01R487>LLiacW8@PLi`8Q20@U
:@058@PU:BU:9BTQ20027>L39BT2:DX29BT012489BTU:BDY0R4800<U:B489BT00R4800LLib489BTU
:B487>LQ20029BT03QcW6<HQ22DY8@PLibDY:DXU:AcW;F/e[Be[7>L336<00`Q212448@0612400`Q2
12448@0212400`Q21248@P0512400`Q212448@021242248010@Q24848@Q21@@Q00@8@P@Q24848@88
@P@<H`0348@8@PQ20088@P0336<8@PQ20088@P0536<48@Q224848@0424801PaS248<H`aS248<H`<@
Q00636<8@PQ21248@PaS0PQ20P@Q0`Q200@48@Q236<8@P<<H`0448@<H`Q2124224800`aS2488@P02
248020@Q24848@Q21248@P@Q24821242248436<01Q2436<<Ha245:D@Q0<<H`8@Q08<H`D8@P<48@<8
@P051248@Q245:DLi`026<H01B48;F/aS2U:;F/00cF]00<YBR48=Jd00TYB00He[AcW6<HU:BU:9BT4
6<H0136<@Q0e[BU:0Q2400<DY@aS36<00PaS0Q2400D<Ha24248<H`Q200D<H`0@5:D@Q1BU6<HLicW>
AS5W>F]JHaQ_Nf<HJeYNmdHa=Jd38@P57>L022487>LLiacW8@PLiaS65:D26<H47>L26<H37>L26<H0
11BU6<HHaQS60QBU00DHaQBU5:DDYAS600<DY@8HaP<DY@8HaP035:D@Q1BU008DY@036<HDYAS600<D
Y@036<HDYA24008@Q0035:D@Q1BU008HaP035:D@Q1BU008DY@<@Q0@HaP0548@DYABU5:DHaP065:D0
1Q2436<@Q1BU6<HDY@P@Q00636<@Q1245:D<Ha240QBU00L@Q0aS36<DYA2436<@Q0035:D01A2436<<
Ha245:D01A2400@DYA2448@<H`@@Q0045:D@Q1BU6<H25:D01Q2436<@Q1245:D@Q0<<H`8@Q0045:D@
Q124248236<348@25:D01Q245:D@Q1BU48@<H`8@Q00336<@Q124008DY@l@Q08<H`0348@DYABU00@<
H`<@Q0<<H`8@Q00636<8@PQ236<@Q1BU0`aS00031240100012448@001@@Q00HLicg_;F/LibDY8@P3
7>L29BT4;F/00bU:;F/aS002<H`00be[:DXYBP02:DX012DY8@PQ22480bU:00<U:B489BT00RU:0R48
00HU:B489BTQ22DY8@P27>L00aS67>LLi`028@P00bDY8@PU:@028@P00acW8@PQ20027>L01R486<HL
iacW6<HQ20<Li`085:DLiacW8@PLiaBU6<HLi`8Q20<HaP8Q20087>LU:B487>LHaQBU7>LQ208Li`04
6<HLiaS67>L28@P37>L28@P27>L00b489BTQ20028@P01RU:8@PQ22489BT]J`<YBP8U:@8Q208Li`8Q
2004:DXU:AcW7>L39BT00acW8@PQ20038@P29BT012489BTYBRDY0R480RDY00<Q21cW8@P00bDY00<]
JbU:8@P00QcW0R480QcW0bDY0R480RDY00LYBR487>L]Jc6<=JdYBP0236<00`Q21248@P0;12400`Q2
12448@031242248212400`Q21248@P0212400`Q212448@03124224800`@Q2488@P0224801@aS2484
8A249BT00SF]00hHaPaS36<<HaBU36<8@P@Q248<H`Q236<8@P@Q0PQ200H48@Q22488@PaS124236<0
21245:D@Q12436<48@Q2124824831245248436<7248412400`Q21248@P03124010Q236<DYABU0Q24
10Q20PaS00<8@PaS36<00`aS0`Q20`@Q00<8@P@Q12400P@Q0PQ201D<Ha2436<@Q0aS5:D@Q1S6@Q1B
U4Ha:DX<HaS68@PHaQcW8@PYBRDY8@P00RDY00`LiaS66<HHaSW>@Q1:DTHa8@PHaPaS248336<32484
36<2248436<248@25:D011cW9BU6<Dic0f]J00I_NfLiIcUF]Cg_;F/27>L38@P011cW5:DHaQS611cW
11S61acW00LHaQcW6<HHaQBU6<HDY@026<H25:D00a245:D@Q00248@01aBU48@DYABU6<HDYA24008D
Y@<HaPLDY@046<HDYABU48@35:D00aS65:DDY@026<H25:D011245:DHaQS60Q240QBU00<LiaS65:D0
0QBU0Q2411BU00D@Q0aS48@DYA24008<H`0548@HaQ2436<@Q0035:D00a2436<@Q00248@00aBU48@@
Q00248@00aBU48@@Q00248@35:D248@011BU48@@Q0aS0Q2400<<Ha2448@01A240QBU0Q2400<DYA24
5:D00QBU0Q2400D<H`Q236<<HaBU00<@Q08<H`0348@<HaBU008<H`0448@DYABU48@45:D236<348@2
5:D248@01@aS48@@Q0aS48@00QBU00<@Q0aS36<00Q2400L<Ha2448@@Q0aS48@<H`0648@236<00a24
36<<H`0348@336<00a2436<<H`0248@136<000848@0300048@@Q00L48@0:7>M242e[7>LU:B487>LH
aQcW8@P3;F/3:DX01C6<=JdaS36<:DX00Re[0RU:00@Q22DY8@PU:@<YBP@U:@078@PU:BDY8@PU:B48
9BT0124800<LiaS66<H00QcW0RDY0b4800<LiaS67>L00R480aS60QcW00HHaQcW7>LHaQcW6<H47>L0
1ABU6<HQ22487>L00QS600<Lib488@P00R480aS60QcW00DQ21cW5:DHaQcW00<Q208Li`036<HLiacW
00<Q20037>LQ2248008U:@<Q20079BTYBRU::DXU:B487>L00b4800<LiaS68@P01RDY0R4800@Lib48
8@PQ20@U:@098@PU:BDY9BTQ22DY8@PU:B48008Li`059BTYBRU::DXQ20027>L012489BTQ22DY0R48
0QcW00/Q22DY:DXYBR486<H]JcW>=JdYBPaS00@8@P<48@0324848@@Q00@48@0424848@@Q24821240
0`Q212448@0312422482124010Q212448@@Q0`Q20P@Q10Q20PaS00<8@QBU8@P00S6<00PLia242488
@PaS48@<H`@Q1PQ200<48@Q2248010Q20`aS00@DYA2448@<H`<8@P051248@PaS36<8@P0312401`Q2
1248@PaS24848@Q200<<H`03248<H`aS00<<H`H8@P031248@P@Q00D48@05248<HaBU5:D@Q00236<0
20Q236<<H`Q236<8@PaS48@236<224800`aS2488@P02248412400`Q21248@P02248236<03Q245:D@
Q1S6?NmBU48@9BT@Q1S69BTHaQcW8@P29BT38@P03QcW8@PHaQcW>Li244icAS4Q21S648@8@Q2436<2
248236<010Q236<<H`aS0PQ210aS00T@Q1BU48@DYAcW9BU:DTicIcT00V]J00McW6LiIcUF]Cg_<H`H
aP037>L012487>LLiaS60acW00<Q21cW6<H00aS600@LiaS66<HQ208Li`036<HLiacW008Li`<DY@08
6<HDYAS648@DYA245:DHaP<DY@0:6<H@Q1BU48@DYAS65:DHaQcW5:D248@00aBU6<HDY@025:D01Q24
5:DDYABU48@DY@8HaP<DY@036<HDYABU008DY@036<HDYABU008DY@036<HDYAS600@@Q0036<HDYABU
008DY@<@Q0045:D@Q12448@45:D548@00aBU48@<H`0348@01`aS48@@Q1245:D@Q0aS00@@Q0045:D@
Q12448@236<011245:DDYABU212421BU00@@Q0aS36<8@P8@Q00436<@Q12448@236<348@00`Q236<@
Q0025:D248@00aBU48@@Q00448@00aBU48@@Q00548@010aS48@HaQ240PaS112400<DY@aS48@00PaS
00<DYA2448@00Q2400@<Ha2448@@Q0P<H`<@Q0<<H`0000D000@Q12448@0000@48@0:00048@@Q7>Lm
kc6<7>LU:B487>L38@P00bU:;F/]J`02;F/00cF]<H`]J`03:DX29BT28@P2:DX022DY8@PU:Be[:DXQ
22DY:DX2;F/39BT28@P00acW8@PQ20038@P26<H011cW8@PU:BDY0R480QcW0b4800DHaQcW6<HHaQcW
008U:@047>LHaQcW8@P37>L26<H27>L01B486<HHaQBU6<H01AcW00HHaQBU6<HHaR487>L36<H01BDY
:DXQ21cW8@P00RDY0QcW0R480acW0bDY0QcW00<Q22U:;F/00R4800@LibDY:DXU:@<Q20<U:@8YBP03
9BTQ224800<Q208U:@03:DXU:BDY00<Q20047>LQ22DY9BT27>L00b489BTQ20028@P2:DX00bDY8@PQ
20027>L01BDY8@PQ22DY8@P01BDY00DQ21cW7>LQ22DY008aS0057>LDY@@Q124<H`02248612422484
12401@Q212448@@Q24801@@Q00@8@P@Q12448@@8@P031248@PQ2008<H`0;248<Ha246<H@Q248:DX]
JbDY5:D<H`0348@336<348@00`aS2488@P0236<2248010@Q2488@PQ20`aS0Q240PaS10Q200@<H`Q2
2488@P848@03248<H`Q200L8@PD<H`L8@PD48@0724848@@Q1248@PaS48@00PaS00H8@P@Q24848@aS
248236<348@236<412401@Q212448@Q2124010Q20PaS112400<DYAcW7>L00QcW00L@Q1BU5:DHaQcW
6<HDY@036<H27>L02BDY>Lhmkd8@>LhU:BU:6<H@Q003248336<3248336<00a2436<<H`0236<248@0
1aBU48@DYBU:<HaJeV<H009_N`08JeY_Nf]JIcUBU3F]:DXHaP8Q20<Li`@HaP038@PLiacW00<HaP8L
i`036<HQ2248008Q20036<HLib48008Li`<HaP065:DHaQBU6<HDYA240aBU00P@Q1BU5:DDYA245:DH
aQBU0a240QS600<DYAS65:D00QBU00<@Q1S65:D00QBU00L@Q1BU48@DYAS65:DHaP055:D011245:DD
YA240aS600<DYA2448@00QBU0QS600DDYA245:D@Q1BU00@@Q0<DY@@@Q0@<H`0348@<HaBU008DY@03
48@<H`aS00L@Q0035:D@Q124008<H`<@Q00436<@Q1245:D648@35:D248@25:D248@01aBU36<<H`aS
248@Q1BU008@Q08<H`0348@DYA2400<<H`0648@DYABU5:D@Q0aS112400<<Ha2448@02A2400D<Ha24
48@@Q0aS00D@Q00336<@Q12400<@Q08<H`0548@<H`aS36<@Q00536<248@636<00004124000@Q0002
12400`0024848@0312400acW@Q0aS0058@P00acW9BTYBP02;F/01BU:<H`aS3F]<H`00bU:00TU:BU:
9BTYBRDY:DXU:B489BT00RU:0R4800LU:Be[<H`]JbDY8@PLi`028@P00acW8@PQ20028@P27>L28@P0
1RDY8@PQ21cW9BTQ208Li`@HaP035:DLib48008U:@058@PLiacW7>LQ20036<H00acW8@PLi`026<H0
11cW6<HHaQcW1AS60acW00DQ21cW6<HHaQcW008U:@057>LQ22489BTQ20027>L98@P01BDY:DXYBRDY
7>L00bDY0R480QcW00<U:BU::DX00RDY12481RDY00@Q22DY9BTU:@8Q20059BTQ22488@PLi`028@P2
9BT3:DX012486<HLiacW0R4800DLib489BTLib48008YBP0;9BTQ21S68@PU:B48;F/e[B486<H48@05
248312400`0012448@0224851242248010@Q24848@@Q0PQ200<48@Q212400`@Q0`Q200<48@Q22480
0PaS112400DLibe[<H`]JaBU00<<H`075:D<H`Q236<@Q1BU48@00PQ20`aS00D8@P@Q1248@PaS00<8
@P0448@DYA2448@224800`@Q2488@P02248236<01`Q212448@Q236<8@P@Q00D8@P<<H`@8@P061248
@P@Q24848@Q210@Q00<8@P@Q12400PQ20Q240`aS00h8@P@Q2488@PaS248<Ha245:D@Q0Q21248@P@Q
0PQ210@Q10Q20PaS00<8@PaS48@00Q2400PDYAcW8@PQ21S648@DYAcW1AS61AcW00Pe[Cg_AS4icRDY
:DXHaQ240PQ200<<H`Q224800PQ20`aS00<@Q0aS24800PaS0Q24018<Ha246<H@Q1S6:DXaS5JeF]I[
FVmkIcUcW6]JIcU>LcF]:DX57>L01B487>LHaQBU7>L00R4800@LiaS66<HHaP8Li`046<HLib489BT6
7>L26<H25:D011S67>LHaQBU11240aBU00@@Q1BU5:D@Q0<HaP035:D@Q12400<HaPPDY@8@Q0@HaP<D
Y@0848@DYABU6<HDYA245:DLi`8HaP8<H`0348@DYABU00DDY@L@Q0<DY@0648@DY@aS36<@Q0aS0a24
00<DYA2448@00Q2400@DYA2448@<H`8@Q00336<@Q12400<DY@<@Q08DY@<@Q00436<@Q12436<248@0
1AS65:DDYABU48@00aBU0Q240PaS00@@Q0aS36<<H`8@Q0<<H`035:D<H`aS00<@Q0065:D@Q1BU48@D
YA240`aS00<@Q1BU5:D01Q240QBU00<<Ha2448@00PaS00<DYAS648@00PaS00<@Q1BU48@010aS00<@
Q0aS48@00Q240PaS00H@Q0aS48@<Ha2436<548@136<000D48@0300048@@Q00848@0600048B48AS4a
S1cW0RDY0R4800@U:BU:;F/]J`8YBP04;F/aS36<;F/59BT00b489BTU:@02:DX29BT01Be[:DXU:B48
9BT00Re[00@YBRDY9BTQ20<U:@058@PLiaS66<HQ20029BT01R486<HLibDY8@PLi`@Q208HaP057>LU
:BDY8@PLi`028@P26<H37>L26<H27>L25:D00aS67>LLi`066<H00acW6<HLi`046<H011cW9BTU:B48
0QcW00XYBR486<HHaR489BTQ21cW8@PU:@8Li`058@PYBRe[9BTQ20029BT27>L58@P4:DX00b487>LQ
20048@P29BT00bU:8@PQ20029BT01B489BTQ22489BT00b480QcW00HU:BU::DXU:B487>L28@P27>L2
8@P27>L03R489BTU:BDY8@PU:AcW6<HLiaS6=Je2436<7>L2124236<00`Q21248@P02124010Q21244
8@000P@Q00<8@P@Q12400`@Q00<8@P@Q12400P@Q0PQ200H48@Q212448@Q2124424800`aS48@@Q002
6<H01BDY:DXYBRU:8@P011S600hDYA2436<<H`Q236<8@P@Q36<YBSF]8@P8@P@Q0PQ200H48@Q2248<
H`Q236<248@010aS24848@aS0`Q200<<H`Q224801`Q20P@Q0PQ200<<H`Q236<010Q200@48@Q22488
@P@48@88@PH48@88@P8<H`03248<H`Q200@8@P0436<@Q0aS36<22484124010Q212448@@Q0`Q21@aS
00H@Q1S648@8@PaS5:D448@04B48:DXaS36<:DXU:BU:;F/e[Cg_=Jd]JbU:9BT]JacW5:D01@aS10Q2
00<<H`Q224800Q240`aS0Q2400LDYA245:DDYAcW<H`mk`02HaP02f]JKg][FVmkHaQJeTHa;F/U:AcW
8@P00QcW0QS600DLiaS67>LLib48008Li`0>6<HLib488@PU:AcW8@PU:AcW8@PHaR487>LHaP<DY@8H
aP<DY@8HaP0348@DYABU008DY@0348@DYAS6008DY@0348@DYABU00<HaP<DY@8HaP<DY@0348@DYAS6
00<DY@8HaP<DY@046<HLiaS65:D248@00aBU7>LHaP075:D248@011BU48@DYABU1Q240aBU00@@Q0aS
36<@Q0@<H`0348@DYABU00T@Q0035:D@Q0aS008<H`8@Q0045:D@Q1245:D848@01ABU48@@Q1BU48@0
0QBU00<HaQBU48@00PaS00<@Q0aS48@00a2400D<Ha2448@@Q0aS00@@Q0<DY@0348@<H`aS00D@Q003
36<@Q124008<H`H@Q0<<H`8DY@@@Q00336<@Q0aS00<@Q0<<H`0348@<H`aS00<<H`<@Q00336<@Q124
00D<H`0000@000@Q124000P48@077>LicS6<7>LYBR487>L00R4800H]Jc6<<H`YBRDY:DX2<H`012e[
9BTU:BDY0RU:0R4800@U:Be[:DXQ208U:@03:DXU:BDY008YBP03;F/YBRU:008U:@8Q20067>LQ2248
6<HDYAS60RDY00@Q21cW7>LQ208Li`<Q20037>LHaQS6008Q20039BTQ224800<Q20<Li`@HaP8Li`06
6<HLiacW5:DHaQBU0aS600<LiaS67>L00aS600HLiaS67>LQ22U:8@P27>L38@P00acW8@PQ20038@P0
12DY7>LLibDY0RU:00@U:B489BTU:@<Q20089BTQ22488@PU:BU:;F/U:@<Q200=9BTQ21cW7>LQ22DY
:DXU:B487>LQ22DY8@P00RDY0R4800<Lib488@P00R480bDY0R4800@U:B487>LLi`<Q20057>LU:BU:
9BTLi`028@P021S67>LHaQBU=Je6<CF]9BT2124010Q21248@PQ20P@Q00D8@P@Q12448@Q200H48@<8
@PD48@<8@P<48@D8@P0536<@Q1BU7>LQ20029BT01B489BTU:BDY7>L00QS60Q2400X<H`Q236<@Q0aS
000@Q2DY=JdQ20848@0324848@@Q0088@P@<H`0648@DY@aS36<8@P@Q0`Q210aS00<8@P@Q124010Q2
00<48@Q224800`aS00@8@PaS1248@P848@@8@P031248@P@Q00@48@0724848@@Q248<H`Q236<00PQ2
0P@Q0PQ211240`Q200<48@Q212401@@Q00<8@P@Q36<00Q240PaS112401<<Ha2448@<HaBU48@U:BU:
<H`]JbDY:DX]Jc6<=JdicSF]<H`]J`029BT27>L010aS2488@PQ20PaS0PQ200<<H`Q224801PaS0Q24
0QBU00PHaQBU8@PaS3g_F]IS66mk0V]J00U_NfLiF]I242e[:DXHaQcW8@P00acW00<HaQcW7>L01AcW
00<Q21cW7>L00QcW00DU:AcW8@PLib48008Li`036<HLiaS600<HaP0;5:D@Q1BU5:DHaQBU48@DYAS6
48@DY@026<H448@00aS65:DHaP035:D021S65:DHaQS65:D@Q1S65:D248@00aBU6<HHaP035:D26<H2
7>L25:D011245:DDYAS60QBU0Q2400<DYA245:D00QBU112400HDYA245:D@Q1BU48@45:D01A2436<<
H`aS48@00PaS1a240PaS0Q2400<DY@aS36<01Q2400D<Ha2436<@Q1BU00D@Q0<DY@8@Q0<DY@8@Q003
5:D@Q12400@@Q0<<H`@@Q08<H`<@Q0035:D@Q1BU008@Q00336<@Q124008<H`P@Q08<H`0348@<H`aS
00<@Q0035:D<H`Q2008<H`@@Q0@<H`<@Q0@<H`L@Q08<H`48@P000P@Q00P000@Q124000@Q24848@00
0P@Q00XQ248@;F/Lib489BTQ22DY:DX]J`@YBP07;F/YBRDY9BTYBRe[:DX00R4800DU:BU:9BTQ22DY
008YBP<U:@03;F/YBRe[00<]J`039BTQ22DY008Q20056<HLiacW7>LQ20029BT00b487>LLi`028@P3
7>L01AS67>LQ22489BT0124800<U:B487>L00QcW00DQ21cW6<HDYAS6008DY@8HaP8Li`8HaP8Li`05
6<HLiacW7>LQ20036<H022489BTU:AcW8@PU:B487>L28@P00bDY8@PLi`038@P00acW8@PU:@02:DX0
12DY8@PLiacW0bDY00<Q21cW8@P00RDY0bU:00<U:B488@P00RDY0QcW00@Q22DY:DXU:@8Li`038@PU
:BDY00DU:@038@PU:BDY008YBP059BTQ22489BTQ20037>L00b487>LQ20028@P27>L29BT27>L021S6
7>LLiaS6:DXe[BU:7>L224800`aS2488@P0612400`Q212448@0512400`Q212448@0312400`Q21244
8@0312401@Q212448@Q212400Q2400DDYAcW7>Le[CW>009BU005CW=F]Cg_>LhU:@055:D00`aS2488
@P02248010aS5:DDYA241@Q200@48@Q22488@P8<H`0648@<H`aS248<H`Q20PaS00<8@PaS24801@Q2
00<48@Q224801`Q200H<H`Q22488@P@Q248412400`Q236<8@P02248312422482124010aS2488@P@Q
0PQ200<<H`Q236<00`aS0PQ20`@Q00@8@P@Q1248@P848@06248<HaBU6<HDYA240PQ200D@Q1BU5:DD
YA24008<H`0448@DYBDY:DX2<H`3:DX29BT01R489BTQ22485:DHaP<@Q00436<8@PQ236<624801@aS
48@@Q12424800Q240aBU010HaR48:DY6<DYBIcU[FVmkMke[FVmkG_M>LcW>:DXU:@8Q20037>LHaQcW
00<Q20@HaP057>LQ22488@PLi`038@P012DY7>LQ21S60QcW0QS60QcW0QS600<DYAS65:D00QBU0QS6
00<DYA245:D00aS60QBU00<@Q1BU5:D00aS60aBU0QS60QBU0a2400PDYAS66<HHaQBU6<HDYAS60QcW
00@HaQBU5:D@Q0<DY@076<HDYA2448@DYAS65:D00Q240aBU0PaS0Q240QBU00@@Q1BU5:DDY@<@Q004
36<@Q0aS36<348@00`aS48@@Q00448@011BU48@@Q0aS0Q2400<<Ha2436<01Q2400HDY@aS48@<Ha24
5:D648@010aS48@DYA240QBU00<@Q0aS36<00QBU0Q2400<<Ha2448@00Q2400<DYA2448@00Q240QBU
0Q240PaS00@@Q0aS5:D@Q08<H`0648@<H`aS48@DYA240PaS00@8@PaS36<<H`8@Q0035:D@Q0aS00<<
H`0348@<H`aS008<H`8@Q08<H`<@Q08<H`8@Q0@<H`<@Q04<H`4@Q00000D000@Q12448@0000L48@07
7>Lmkc6<7>LQ22DY8@P00RDY12U:00D]JbU::DXYBRDY00<YBP8Q20039BT]JbDY008Q20<U:@038@PY
BRU:008YBP8aS005:DXQ22DY9BTQ20027>L00aS67>LLi`048@P01QcW6<HLiacW8@PLi`<HaP@Q2006
7>LQ22488@PU:B4811cW11S600@DYAS67>LLi`<HaPDLi`036<HLiaS6008HaP078@PU:AcW7>LQ22DY
8@P00QcW00DQ22DY8@PQ21cW00<Q208Li`03:DX]JbU:008Q20039BTQ22DY008Li`8Q2003:DXU:BU:
008YBP039BTQ21cW00<Li`<Q20039BTQ21cW008Li`@U:@<Q208U:@04:DXU:BDY9BT28@P27>L28@P0
1QcW6<HLiacW8@PU:@8Li`8Q208Li`086<HLiacW6<H]JcF]:DXLi`H8@P041248@PQ2248312400`Q2
12448@02124224831242248212422483124524801PaS6<HLiacW<H`icP9BU005CW=BU48@<H`U:@04
5:D03a2436<<H`aS24848@Q248@HaQ241248@PaS24848@0224800`aS248<H`0336<00`Q236<<H`02
36<00`Q236<8@P04248212400`Q212448@0212400`Q236<8@P0236<324800`@Q2488@P0612400`Q2
1248@P03248212400`Q236<8@P0324801@@Q2488@PaS48@00`aS00D8@P@Q12448@Q200H48@0336<8
@QBU008DY@0648@<H`aS5:DHaQ240QBU00H<H`Q248@@Q2DY:DX2<H`00bU:;F/YBP028@P39BT00b48
6<HHaP0348@436<224802P@Q2488@PQ248@<Ha2436<@Q0aS0Q2400LHaQBU6<HHaRU:@Q1:DP02JeX0
1fmkLia[FVmkG_M>Lcg_008U:@8Q208Li`036<HLiacW00<HaPHLi`8Q20047>LQ22488@P26<H77>L2
5:D00a245:DDY@045:D01QS65:DDYABU6<HDY@<@Q0076<HLiaS67>LDYA245:D00QS600DDYA245:DD
YAS6008DY@<HaP035:DHaQcW008Li`8HaP8@Q08DY@036<HDYA24008@Q08DY@8@Q0035:DHaQBU00@@
Q00336<@Q12400<DY@8@Q00336<@Q12400@<H`0648@<Ha2436<@Q1BU0Q240PaS00L@Q1BU5:D@Q0aS
48@<H`0248@00`aS48@@Q00348@00aBU48@@Q00248@011BU48@<Ha240QBU0a2400DDYAS66<H@Q0aS
00@@Q00336<DYA2400`@Q0<<H`H@Q0@<H`8DY@<<H`04248@Q12448@236<248@00aBU48@<H`0336<0
0a2436<<H`0336<00a2436<<H`0348@00aBU36<<H`0636<00003124000@Q00<48@0:00048@@Q1240
00Q29BUBU3W>6<H28@P01BDY:DXYBRU:;F/00S6<00<YBRDY9BT012U:00@U:Be[:DXQ208Li`DU:@06
:DXU:Be[:DXaS2e[0RU:00<U:B488@P00R480QcW0R4800<U:AcW7>L00b480acW0aS600<Lib488@P0
11cW00<Q22DY9BT00R4811cW0QBU0QS61AcW0QS600@Lib488@PQ208HaP8Li`038@PLiacW008Li`03
8@PU:B4800<Li`048@PLiacW9BT37>L00b48;F/U:@028@P01RDY7>LLiacW8@PU:@8Q20039BTYBRU:
008Q20039BTQ224800<Li`@Q208U:@<Li`8Q20047>LQ22DY:DX59BT01b487>LLib48:DXU:B48008H
aP8Li`039BTQ21cW00<Li`038@PLiacW00<Q20076<HU:Be[:DXQ20aS24800PaS0PQ20P@Q00D8@P@Q
12448@Q200@48@88@P031248@P@Q00848@<8@P031248@P@Q00@48@88@P0848@DYAcW<H`icUJeF]IW
>@9_N`07Mke[FU[F?NlU:AS636<00Q2400<<H`Q236<00PQ20P@Q00D<Ha245:D@Q0aS00848@<8@P03
36<8@PaS0088@P8<H`0348@<H`aS00D8@P@48@@8@P041248@PQ2248348@00`aS2488@P0212400`Q2
1248@P02124224801PaS248<H`aS1248@P848@88@P0748@<H`@Q1248@PaS24800PaS00<8@PaS2480
2P@Q0Q240QcW0Q240PaS00<@Q1BU6<H00QBU00H@Q1BU48@<HaBU6<H38@P27>L25:D00a245:DDY@02
5:D348@010aS48@@Q0aS0PQ200@<H`Q236<@Q08<H`0348@<H`aS008<H`0=48@DYABU5:DLibe[=JeN
mf<HLia_Nf]JLi`00Vmk00A>LcW>:DXLi`<Q208Li`046<HLiacW7>L26<H00acW6<HLi`027>L48@P0
1AcW9BTLib486<H00acW0QS600<DYAcW6<H00QBU00@@Q1BU6<HDY@<Li`046<HDYABU5:D26<H01ABU
48@DYABU7>L00aS60aBU00<@Q1BU48@021S60QcW00<HaQBU5:D00aBU0Q2400@DYAS66<HDY@8@Q0DD
Y@8@Q08<H`0348@DYABU008@Q0<DY@<@Q08<H`H@Q08DY@0348@<H`aS00<@Q00336<@Q12400P@Q003
5:D@Q12400@@Q00<5:D@Q1BU5:D@Q0aS48@<Ha245:DHaQBU0Q2400<DYA2448@00PaS00H@Q0aS48@D
YA245:D448@01aBU48@@Q12436<@Q0aS008@Q00336<@Q0aS008<H`8@Q08DY@D<H`0448@<H`aS36<4
48@00`aS48@@Q00336<00a2436<<H`0248@236<848@336<148@136<136<000848@0300048@000084
8@0:24848@@Q1248@Re[DY@e[AS68@P29BT032U:9BTU:Be[=JdicRe[:DXU:BU:;F/YBP8U:@8YBP03
9BTQ224800<U:@DYBP@]J`8YBP048@PLiacW7>L28@P00acW8@PLi`048@P47>L011S65:DHaQcW0R48
11cW00@Q22DY9BTQ20DLi`8HaP035:DHaQS6008Li`8Q208HaP047>LU:BDY7>L26<H27>L28@P27>L5
8@P00acW8@PQ20028@P27>L00aS67>LU:@02:DX28@P012DY8@PHaR480RDY00@Q21cW9BT]J`8YBP06
9BTQ22488@PU:AcW0R4800<Lib487>L00b480QcW00@Q21cW8@PQ208U:@038@PU:BDY008U:@077>LH
aR488@PYBRDY8@P00QS600DLib488@PQ21cW00<Q20@Li`079BTLiaS69BT]JbU:8@P00Q2400@<H`Q2
2488@PL48@0424848@@Q248412402@Q21248@P@Q24848@Q21248@P02124424801a245:DLic6<>LiB
U5[F009[FP09Liag_FLiG_LmkbU:7>L<Ha24008<H`D8@P848@0436<@Q12436<8248836<00`Q236<<
H`02248212442482124224801`aS48@DYABU48@8@P@Q0088@P@48@88@P<<H`T8@P041248@PQ22483
36<5248010@Q2488@PQ21@@Q00H8@PaS6<HQ21S65:D236<35:D011S65:DDYABU0Q240QBU124800@H
aQBU5:D@Q0<DY@@@Q0<<H`0348@<H`aS00<8@P8<H`066<HDYA2436<8@PaS0QBU00PHaQBU7>LYBSW>
F]IS67>L0V]J00Qg_FmkJeY>LcW>;F/Q22DY0R480QcW00<HaQcW7>L00acW00<HaQcW7>L00QcW0R48
00<U:AcW8@P00R480acW0R480aS600DDYAS65:DDYAS6008DY@8HaP037>LHaQS6008DY@8HaP<DY@<H
aP037>LHaQS600<HaPLDY@8HaP065:DHaQS66<HLiaBU0QS600@DYA245:D@Q08HaP8DY@8@Q0035:D@
Q1BU00<DY@0548@<Ha2448@DY@0348@01ABU48@DYABU48@00`aS0Q240QBU00<@Q1BU48@00Q2400LD
YA2436<<Ha245:D@Q00336<248@236<00a2436<<H`0348@02@aS48@@Q1245:D@Q0aS48@DY@0248@0
0`aS48@DY@026<H248@010aS48@@Q1S60Q240PaS0QBU1Q2400@DYA2436<<H`<@Q08<H`8@Q00436<@
Q12448@236<00a2436<<H`0236<02A2436<@Q12436<@Q0aS48@DY@0348@236<648@236<248@00aBU
48@<H`0336<248@236<0000300048@@Q00848@0300048@@Q00<48@06248U:DHa<H`DYAcW0RU:00@a
S2e[:DXaS08e[@04<H`U:BU::DX2;F/29BT01bU:;F/U:B487>LU:BU:00<]J`8YBP8]J`8YBP<U:@@L
i`039BTQ22DY00<Q20<Li`046<HLiacW7>L25:D01AS67>LQ22487>L00b4800<U:B487>L00acW0R48
00<LiaS67>L00QS60QcW00@Q21cW7>LLi`8Q20047>LQ22488@P27>L01B487>LDYAS67>L00R480QcW
0R480QcW0R480QcW00<Q22DY9BT00R4800<U:B488@P00R480QcW00<Q21cW9BT00RU:00<]Jb487>L0
1B480QcW00<Q21cW8@P0124800HHaQcW7>LU:BU:9BT38@P00bU:8@PQ20027>L39BT01b487>LQ2248
:DXU:B48008Li`078@PU:B487>LHaR489BT00R480QcW00TQ22DY9BTHaQ2436<8@PaS24800P@Q00<8
@P@Q12400`@Q00<8@P@Q12400P@Q00<8@P@Q248010@Q00<8@P@Q24800P@Q00<8@P@Q12400PQ2010@
Q1BU8@PicSg_IcU[FWNmLiaS66LiLiakgVLi?NlQ208<H`88@P@48@0724848@Q248@HaQ2424800P@Q
0`Q200D48@Q22488@PaS00<8@P0436<@Q0aS248812400`Q21248@P022482124010aS48@HaQBU0PQ2
00@48@Q22488@P<48@88@P0536<8@PaS36<8@P0312400`Q236<<H`03248336<00`Q236<8@P062480
0`@Q2488@P0424800`aS5:DDY@025:D011245:DDYAS60QcW00<DYA2448@01@aS00@@Q0aS48@@Q08<
H`H@Q00436<@Q0aS36<2248236<448@00aBU48@@Q00236<00a245:DHaP026<H01aBU8@PaS48@IcU[
FWNm00=_N`04HaQF]Cg_;F/48@P46<H01aBU6<HQ21cW6<HDYAS6008Li`046<HLib488@P37>L00b48
7>LLi`036<H00acW5:DDY@0248@25:D96<H35:D26<H25:D011S67>LLiacW0QBU0aS60QBU00L@Q1S6
5:DDYA245:DHaP027>L01AS65:DHaQBU6<H00QBU00<@Q1BU5:D00aBU0a241ABU0Q240QBU00D@Q1BU
5:D@Q0aS008@Q0055:D@Q0aS248<H`0748@00`aS48@@Q00248@236<01Q245:D@Q1BU48@DY@<@Q0@<
H`0448@DYAS65:D348@00aBU48@<H`0248@236<248@00aS65:DDY@0248@01`aS48@<Ha2436<@Q0aS
008@Q0065:D@Q12448@<HaBU0a2400<<Ha245:D00Q2400D<Ha2448@@Q0aS00@@Q0<<H`035:D@Q0aS
008<H`8@Q08<H`@@Q00336<@Q1BU00@@Q0@<H`8@Q00436<@Q0aS36<248@00`aS48@@Q001248000<4
8@0500048@@Q0008@P0212401`00248U:DYB;F/HaR48008]J`06<H`U:BU:<H`icSF]0Re[00<YBRe[
;F/00bU:00H]JbU:9BTQ21cW9BT2:DX01Re[:DXYBRU:;F/YBP8]J`<U:@8Q20067>LQ22487>LQ22DY
0R4811cW00<Q21cW7>L00aBU00DLib487>LQ21cW008Q20057>LQ22DY7>LQ20067>L36<H38@P01aS6
7>LQ21cW8@PLib48008Li`8Q20067>LHaQS67>LU:B480QcW0R480QcW0R4800<LiaS66<H00R480RDY
1B480acW00@U:BU::DXU:@<Q20069BTQ22487>LHaQcW12480acW0R4800<Lib487>L00b4800DLibU:
:DXYBR48008Li`088@PU:BDY8@PU:AcW8@PLi`8Q208Li`039BTYBR48008HaP8Q20039BTQ21cW008L
i`8U:@037>LHaPQ20088@P031248@P@Q00848@88@PL48@88@PH48@0324848@@Q00848@0;24848@@Q
248@Q1S68@PicSg_IcU[FP02Li`01f<HJeYcW7_NJeY24248008<H`0324848@Q200848@88@P031248
@Q24008DY@0336<48@Q200848@03248<H`Q200<8@P8<H`0548@<H`Q2248<H`022483124224801P@Q
24848@@Q248<H`88@P0448@DYAS65:D22482124524800`@Q248<H`0336<824800`@Q248<H`0336<5
24821243248010@Q2488@P@Q0PaS00<@Q1BU5:D011BU0QS60aBU00DHaQ2448@<H`Q2008<H`T@Q08<
H`<@Q0<<H`0548@<Ha2448@<H`025:D011245:D@Q0aS0Q2411S600lLic6<?NmW>F]JLia_Nf]JKg]S
65kg?Nl]JbDY7>L00R4800DLiaS66<HHaQBU00<Li`@HaP035:DHaR48008U:@038@PHaQcW00<Li`03
6<HDYAS600<HaP8DY@0348@DYAS600<HaP085:DHaQS66<HDYAS65:DHaPDDY@8Li`<HaP055:DHaQS6
5:D@Q0025:D26<H35:D46<H45:D011S65:DDYA241ABU0Q240aBU11240aBU1A2400<DYA2436<00PaS
0Q240QBU00P@Q0aS48@@Q1BU36<@Q0aS0Q2400<<Ha245:D00QBU1A240PaS212400TDYA2448@DYA24
36<@Q0aS5:D00QS60Q2400H<Ha2448@@Q0aS48@236<248@35:D236<01a245:DDY@aS248@Q1BU008@
Q08<H`0348@<Ha2400<<H`0348@<Ha2400<<H`0448@<Ha2436<>48@236<748@011BU48@<Ha240PaS
0@Q200001@0012448@@Q00001`@Q00@U:DYB<H`HaP<U:@03:DX]Jc6<008icP03<H`YBRDY008aS007
:DXU:BDY:DX]JbU:9BT00b4800@U:BU:<H`aS08YBP8U:@8YBP04;F/U:AcW8@P29BT011cW6<HLib48
0RDY00DQ21cW6<HLib48008Li`066<HDYAcW7>LQ22DY0R4800DU:B487>LLib48008U:@8Li`038@PL
iacW008Li`8HaP067>LQ22DY9BTQ21cW12480QcW0R4800<LiaS66<H00QS600<Lib489BT00R480QcW
0RDY0QcW00LHaR489BTQ21cW8@PU:@028@P27>L28@P29BT00bU:9BTQ20028@P37>L28@P012DY8@PL
iacW124800<Lib488@P00bDY124800@U:BU:9BTU:@8Li`058@PU:BDY9BTLi`028@P00bU:9BTQ2003
8@P37>L38@P27>L02QS67>LHaRDY<H`U:AcW36<8@PaS0PQ210@Q0`Q22@@Q00<8@P@Q12400P@Q0PQ2
00@48@Q212448@88@P0748@DYAcW=Je246<HJeX00W>L00QW>F<HKg]oogNmDY@YBPaS10Q200@48@Q2
248<H`848@03248<H`Q200@8@P0336<8@PQ200848@88@P0336<8@PQ200@8@P0336<48@@Q0088@P84
8@<8@P041248@PQ236<4248236<00`Q212448@0212401@Q21248@PQ212400PaS00<@Q0Q2124010Q2
00<48@Q224800`Q200@<H`Q22488@P@48@88@P051248@P@Q24848@0324800`aS48@@Q0076<H00acW
6<HDY@0236<0112436<<H`aS0a2410aS00<8@PaS36<00PaS0PQ200<<H`Q236<00`Q200<@Q0aS36<0
0Q2400<HaQBU5:D00a2400LHaQBU7>LLibe[?Nm>L`02JeX03G>LKg]_Ng>LF]I:DRe[9BTQ21cW8@PH
aQcW00<HaP8Li`066<HLiacW6<HLib4811cW00<Q21cW7>L00QcW00@Q21S67>LHaP<DY@036<H@Q124
00DDY@DHaP035:DHaQS6008DY@0348@HaQS600@HaP8DY@8HaPPDY@<HaPDDY@036<HDYA2400<DY@8@
Q0065:DHaQS65:D@Q1BU0a240QBU0a2400DDYAS65:D@Q0aS00H@Q0045:D@Q1245:D248@00`aS48@@
Q00348@01QBU48@@Q1BU48@DY@8@Q0035:D@Q0aS008<H`<@Q0035:D@Q1BU008@Q08<H`@@Q08<H`03
5:DHaQBU008@Q08<H`8@Q00436<@Q1245:D448@236<248@25:D00a245:D@Q00648@010aS48@@Q124
0`aS0Q2400<DYA2436<00PaS0Q2400@<Ha2448@@Q08<H`<@Q00336<@Q124008<H`8@Q0@<H`<@Q0L<
H`000P@Q00<000@Q124010@Q00X000@Q124Lid8@;F/HaR48:DXU:@8]J`04<H`e[CF];F/2:DX2;F/0
136<:DXU:BDY0RU:00DU:B487>LU:BU:00<]J`8YBP8U:@0?:DX]JbU:8@PLibDY:DXQ21cW6<HLib48
7>LQ22DY008Li`046<HLib487>L25:D01AS68@PLib487>L012480RDY00@Q21cW7>LLi`8Q20<Li`04
6<HLiacW8@P29BT48@P02BDY8@PLiacW6<HLib487>LHaP027>L01R489BTQ22487>LQ20DLi`<Q2003
7>LQ21cW00DQ208Li`058@PU:BDY:DXU:@028@P00acW8@PQ20037>L58@P00bDY7>LLi`027>L00bDY
:DXU:@048@P01bDY;F/YBR487>LHaR4800<U:@038@PLib48008Q208U:@<Q208Li`046<HLib488@P2
7>L26<H01BU:<H`YBQcW24800`aS00<48@Q212403`@Q0PQ210@Q00<<H`@Q24800`Q20Q2400DLicF]
>LiNmf]J009cW003IcUS66]J009oo`04DY@]J`Q248@224800`@Q2488@P0224801@@Q24848@Q236<0
0PQ20P@Q0PQ200P48@Q2248<H`Q21248@PaS10Q200<48@Q2124010@Q00<8@P@Q12400P@Q0PQ21@aS
0PQ21P@Q00D8@P@Q248<Ha24008<H`@48@88@P051248@PQ236<8@P0436<3124824801PaS248<H`aS
48@DY@8HaP037>LHaQS6008DY@@HaP0348@<H`aS008@Q0h<H`03248<H`aS00H<H`0348@DYA2400<@
Q08DY@8@Q0076<HLibe[@Q1:DVLiJeX00W>L00E[FW>LG_M:DS6<008Q20@Li`8HaPDLi`066<HLiacW
7>LHaQcW0b4800@U:AcW7>LHaP<Li`<HaP@DY@0448@DYABU5:D36<H25:D011246<HHaQS611BU00<H
aQBU6<H011S60aBU0aS600@DYAS66<HHaP8DY@8HaPTDY@056<H@Q1BU5:DHaP055:D011245:DDYABU
0a240aBU11240`aS11BU1Q2400LDYA245:D@Q0aS48@<H`0248@01QBU48@@Q12436<@Q0<DY@0348@D
YABU00<@Q00336<@Q0aS008@Q0<<H`045:DHaQS65:D236<448@00`aS48@@Q00248@236<848@00`aS
48@<H`0248@336<248@636<448@00`aS48@<H`0236<248@01QBU48@@Q0aS48@DY@@@Q0<<H`8@Q0H<
H`0348@<Ha24008<H`000`@Q00<000@Q12401@@Q00H8@R48?NlYBQS67>L2:DX2<H`01BU:;F/]Jbe[
<H`00RU:0RDY00<YBRDY9BT01RDY0RU:0Re[00@YBRDY8@PQ20<U:@8Li`038@PU:BDY00<Li`8U:@03
8@PLiacW00@Li`8HaP8Li`039BTQ21cW008Li`038@PU:BDY008Q208Li`8Q200:7>LHaQS66<HLib48
7>LQ22U:9BT28@P00acW8@PQ20037>L011S67>LHaQcW0aS600LLibDY:DXYBRDY8@PHaP028@P011cW
8@PQ22480QS600HQ22U:9BTQ21cW8@P27>L012489BTU:BU:0b4800<Lib488@P0124800<U:B488@P0
0b4800<U:BU:9BT01B480RDY12480bDY0R4800<U:BU:9BT00bDY0R4800LYBRe[:DXQ21cW6<HQ2002
9BT00b487>LLi`027>L01QS68@P]Jbe[8@P@Q08<H`041248@P@Q24861243248312400`Q212448@02
12400`Q212448@0212400`Q212448@0224801A245:DHaRe[>Lh00U:D00UW>FmkJeY[FVmkNmi[FTHa
:DX00QBU00`8@P@Q6<HU:B485:D48@00248@Q1BU48@3124224800`aS24848@0212400`Q236<8@P02
1244248312432483124;24801@@Q24848@@Q24800P@Q00L8@P@Q36<@Q0aS24848@03248212400`Q2
1248@P0524831246248030aS248<H`Q236<8@P@Q36<DYB486<HDY@8Li`8DY@0548@DYABU5:D<H`02
48@25:D02Q2436<<Ha2436<@Q0aS248<H`Q20Q2400D<H`Q22488@PaS00<8@P0536<8@PaS48@DY@02
6<H03A245:D@Q1245:D@Q248:DXicU:DF]I_Nf]J009cW005Kg][FTYB>LhYBP028@P27>L36<H011cW
6<HLiaS60QcW00DQ21cW6<HDYAcW008Q20087>LHaQcW7>LHaQcW6<HLi`@HaPDDY@056<HDYABU5:DH
aP025:D56<H25:D02AS65:DHaQS65:D@Q1BU6<HLi`026<H45:D248@25:D00aS65:D@Q0026<H00aBU
48@DY@025:D00aS65:DDY@0248@25:D00a245:DDY@025:D02Q245:DDYABU48@<Ha245:D@Q1BU0a24
00<<Ha2448@00a2400<DYA2448@00Q2400D<Ha245:DDYA24008<H`045:D@Q12448@35:D00a2436<<
H`0548@00aBU48@@Q00236<011245:DDYA240PaS0Q2400@DYA245:DDY@<@Q00536<8@Q2448@DY@05
48@01ABU48@@Q12436<00Q2400<DYA2448@00Q2400L<Ha2448@@Q0aS48@<H`0348@236<248@01ABU
48@<H`aS48@00`aS0a2400@DYA245:DDY@8@Q08<H`8@Q0<<H`0448@<H`aS36<348@00`aS48@<H`02
36<00003124000@Q00848@0300048@@Q00@48@0;7>Lmkbe[6<HQ22U:;F/aS2e[:DX]J`02<H`01Be[
:DXU:BDY:DX00RDY0R480bDY00DQ22DY9BTYBRe[00<YBP8U:@038@PU:BDY008Q208U:@058@PLiaS6
7>LU:@038@P27>L01B487>LHaQS67>L01B4800@U:B488@PQ20<U:@8Q20@Li`036<HLib4800@Q208Y
BPHQ208Li`036<HLiaS6008HaP8Li`049BTYBRe[:DX38@P021cW6<HLibDY8@PLiaS67>L29BT27>L2
8@P011cW8@PU:BU:0R4800DLib488@PQ21cW00<Q208U:@@Q20079BTQ22488@PU:B489BT00b4800<U
:B488@P00R480bDY0R4800@U:BU::DXU:@8Q20<U:@8YBP069BTLiacW7>LQ22DY0R480QcW00LQ21cW
9BT]JbDY8@P@Q00436<00`Q212448@0:12400`Q21248@P0412400`Q21248@P0212402@Q21248@PaS
48@DYAcW;F/aS002DY@00f<HKg][FP02Kg/037_NKg]>Lbe[5:D@Q0Q2124HaRDY8@PDY@848@05248<
HaBU36<8@P02124424801`@Q2488@PQ236<8@P@Q00@8@P848@<8@P848@<8@P848@0324848@@Q00<8
@P0336<8@P@Q00848@88@P<48@03248<H`aS008<H`88@P031248@PQ20088@P848@<8@P8<H`031248
@P@Q00<48@0324848@@Q0088@P0936<8@PQ2248<H`Q248@DYAS600<DY@8HaP<DY@8@Q0045:D@Q1BU
5:D248@436<0112436<<H`Q210aS00<@Q0aS36<00PQ20PaS00L8@PaS36<<Ha245:DHaP025:D04Q24
5:DDYABU6<HU:CF]CW=JeVmkJeY_Ng>LJeY_NdYB>LhYBP8Q208Li`@HaP047>LHaQcW7>L36<H27>L0
12487>LLib481acW00<HaQBU6<H00QS600@DYA2448@HaP8DY@0348@DYABU008HaP035:D@Q1BU008H
aP057>LDYABU6<HDY@076<H55:D00aS65:DDY@036<H35:D01A245:D@Q1BU6<H00QBU00D@Q1BU6<HD
YA24008DY@8HaP8@Q0035:D@Q1BU00DDY@0348@<H`aS008@Q0055:D@Q1245:D@Q0025:D;48@00aBU
48@@Q00248@011BU48@DY@aS1Q240QBU0PaS0Q2400<DYA2436<0112411BU0Q240`aS0Q2400<DYA24
36<01A240PaS0Q240QBU0PaS1Q240`aS00H@Q0aS48@<Ha245:D248@236<0212436<<H`aS48@DYA24
36<248@00aBU48@@Q00448@00`aS48@@Q00336<448@010aS48@<H`aS0@Q200000`00124000031240
100024848@000P@Q00HQ248@;F/Lib48:DX3;F/2:DX2;F/2:DX01bDY:DX]JbDY8@PHaQcW008U:@08
8@PU:BDY9BTQ22DY:DXU:@<Q20069BTLiacW9BTQ22DY1QcW00<Q21cW7>L011cW00<Q21cW8@P00RDY
00PYBRDY9BTLib489BTYBR4811cW00<Q21cW7>L00QS600DLib489BTQ21cW008U:@048@PLiacW7>L2
8@P87>L012487>LHaR480bDY00LLib487>LQ22DY:DXU:@027>L011S68@PU:BDY0acW00DQ22DY9BTQ
22DY008Q20037>LQ22DY008Q2007:DX]JbDY8@PLib489BT00QcW00@Q22U:9BTQ20<Li`088@PYBRU:
9BTQ21cW8@PU:@<Q20DU:@<YBP<U:@<Q20099BTYBRU::DXQ21cW8@PYBRDY008Li`078@PYBRe[7>LD
Y@aS24800PaS0PQ21P@Q00<8@P@Q12400P@Q00@8@P@Q12448@88@P051248@PQ21248@P04124020aS
48@DYAcW8@Pe[Cg_E[D2DY@04E[FE[E>Ld8@=JdYBQS67>L@Q0aS8@P]JbU:7>L48@Q248@00aBU00@<
H`@Q12448@<8@P031248@PQ200D8@P@48@0524848@@Q24848@03248412400`Q21248@P0224801@@Q
2488@P@Q248010@Q0PQ200<48@aS36<00PaS00<48@Q224800`@Q0`Q200D48@Q22488@PaS0088@P04
36<8@PQ2124324801@aS2488@PaS48@010aS00<DYAS65:D00QS60QBU00<<Ha2436<00PaS0Q2400@D
YA2448@@Q08<H`8@Q0055:D<H`Q2248<H`02248336<224800`aS248<H`02248236<25:D051S65:D@
Q1246<HDYBDY<Ha246<HIcUcW6]JKg]cW6<HG_LicS6<9BT28@P27>L46<H27>L00aS67>LHaP027>L0
1QS67>LLibDY8@PLi`8HaP057>LQ21cW7>LDY@036<H00acW6<HDY@045:D26<H01QBU6<HHaQS65:D@
Q08DY@056<HDYABU5:D@Q0056<H00acW6<HHaP025:D26<H55:D011245:DDYA241ABU0Q240QBU1124
00<DYAS66<H01ABU00@@Q1BU5:DDY@H@Q0<<H`0448@DYABU5:D348@236<01Q245:DDYABU48@<H`8@
Q08DY@@@Q00336<@Q12400D@Q00436<@Q12436<448@236<248@00aBU48@@Q00336<348@236<35:D0
112436<<Ha240QBU0Q240PaS00@@Q1BU48@@Q08<H`H@Q0045:D@Q12436<448@236<248@011BU48@@
Q1BU0Q2400<<Ha2436<01Q240`aS0Q240PaS00<@Q1BU48@00`aS0Q240@aS000412400`0012448@05
12402B48@Q0aS1S67>LU:BU:<H`]J`029BT3;F/01RU:8@PU:BU:9BTQ208Li`8U:@04:DXU:B489BT3
:DX29BT38@P011cW8@PQ22U:0R4800<HaQcW8@P00R480acW0R480QcW1B480RU:00<U:B487>L00bDY
00<Q21cW8@P011cW00HHaQcW7>LLib487>L29BT012U:9BTLiacW0b480QcW00DHaQcW7>LLib4800<L
i`058@PLibDY8@PLi`038@P031cW8@PU:BDY8@PHaQcW8@PU:B489BTLi`8Q20059BTQ22489BTQ2002
7>L00b489BTQ20028@P01BU:9BTQ22489BT00b4800@U:BU:8@PQ20<Li`048@PU:BU:8@P27>L28@P0
2AcW8@PQ22DY8@PU:BU:;F/YBP028@P49BT00acW8@PQ2002:DX38@P00bDY:DXU:@027>L01R48:DXY
BR485:D<H`D8@P848@88@P<48@0324848@@Q00X48@88@P031248@P@Q0088@P0736<DYAcW7>Le[Cg_
DY@00UJe00IJeU:DE[E6<C6<:DX27>L01Q2436<Lic6<:DXHaP848@0648@DYAS648@8@P@Q0PQ20`@Q
00@8@P@Q248<H`<8@P031248@PQ20088@P031248@PQ20088@PD48@88@P<48@<8@PX48@05248<Ha24
36<8@P0212432483124424800`aS2488@P07248236<42480112436<@Q1240QBU0QS600@DYAS65:D@
Q0<<H`0448@<HaBU48@25:D336<00a245:D<H`02248236<010Q236<@Q0aS0`Q200D<H`Q22488@PaS
00D@Q0035:D@Q1BU008DY@0>8@PaS4HaG_MW>G>LJeY_Ng>LHaQJeSg_=Jd]J`8Q208Li`056<HDYAS6
6<HQ20037>L56<H27>L012487>LLiacW0QS600<LiaS66<H00QS600@DYAS65:DDY@8HaP8DY@0448@D
YAS65:D26<H45:D36<H45:D26<H00aBU6<HHaP025:D00a246<HDY@025:D46<H95:D00aS65:D@Q004
48@01AS65:DDYAS65:D00a240QBU00@@Q1BU5:DDY@8@Q0@<H`0348@DYA24008@Q0035:D@Q0aS008@
Q0035:D@Q12400@@Q00436<@Q12436<748@010aS48@<Ha240QBU0Q2400@<Ha2448@@Q08<H`P@Q0<<
H`0348@<Ha2400P@Q08<H`8@Q0055:D@Q12448@<H`0448@01@Q236<<H`aS5:D00a2400<<Ha2448@0
0Q2400<<Ha245:D01A240PaS0a2400@<Ha2448@@Q0<<H`0348@<H`aS00@@Q08<H`<@Q048@P0000@0
00@Q124000H48@070008@R48?NlYBQcW:DX00SF]00D]JbU::DXU:BU:008]J`8YBP038@PU:B48008Q
20056<HQ22DY:DXU:@078@P01BU:;F/YBR487>L00R4800DU:B487>LLiaS600HLi`@Q20079BT]JbU:
9BTQ22DY8@P00RDY124811cW00@HaQcW7>LLi`@Q20037>LU:B48008Q20067>LQ22DY9BTQ21cW0QBU
0QcW0R480QcW00/Q21cW6<HQ22DY7>LHaR48:DX]JbDY008Li`039BTQ2248008U:@<Li`0@8@PU:BU:
9BTQ21S68@PU:AcW8@PYBRe[:DXQ21S67>L28@P01BU:9BTU:B487>L00RDY0R480QcW0bU:00@U:AcW
7>LQ20<U:@8Q20059BTYBRU::DXU:@028@P29BT00acW8@PQ20028@P29BT03B487>LU:BU:8@PLiaS6
7>L]JcF]:DXQ212400H8@P05124000@Q1248@P041242248412400`Q212448@051243248010aS48@D
YABU0QcW00laS3F]=JdicRe[8@PYBTHaE[E242485:DLibU:9BT00QS60Q240QBU00<@Q0aS24800`@Q
00<8@P@Q12400PQ200<<H`Q224802@Q200<48@Q2248010Q20`@Q00<8@P@Q24801P@Q00<8@P@Q1240
0P@Q0`Q20Q2400<<H`Q212401@Q20P@Q0`Q200@<H`Q236<8@P<<H`<8@P@<H`8@Q0035:D@Q0aS0088
@P@DY@8<H`0348@<H`aS0088@P8<H`0648@DYA2448@<H`Q21@aS1@Q200@<Ha242488@P<<H`072484
8@@Q36<@Q1S65:D00Q2400/DYA246<HHaRe[?Nm>Lf]JIcUcW6]J009S6005CW=242e[:DXU:@057>L2
5:D47>L01AS67>LLiacW6<H00QcW0R4800<LiaS66<H011cW11S60aBU00@HaQBU6<HDY@@HaP8DY@04
7>LHaQBU5:D26<H011245:DLiacW0QBU00<HaQcW5:D021BU00<@Q1BU5:D00QBU0Q2400HDYA245:D@
Q1BU6<H35:D011245:DDYA240aBU00<@Q1BU48@01ABU112400D<Ha2448@<Ha2400<DY@<@Q08DY@<@
Q0035:D@Q124008<H`0448@DYA245:D248@00aBU48@DY@0236<548@00`aS48@@Q00548@00aBU48@@
Q0025:D248@436<248@00`aS48@<H`0648@00`aS48@@Q00648@00`aS48@<H`0248@25:D00a245:D@
Q00848@25:D248@011BU48@<H`aS0Q240PaS1A240PaS0Q2400D<Ha2448@<Ha2400<<H`@@Q04<H`00
00<48@0012400`@Q00@000Q2124000848@089BU242e[7>LYBS6<;F/YBP<U:@03:DX]Jbe[00HU:@03
7>LQ2248008Q208U:@058@PU:B487>LQ20039BT012489BTU:B480bDY00@Q21cW6<HHaP8Li`8Q2009
9BTLiacW6<HLibDY:DX]JbU:00@U:@@Q20049BTQ22486<H57>L38@P27>L01B48:DXQ21cW6<H00b48
00<LiaS66<H00QS600<Q21cW7>L00acW00<HaQcW7>L00R4800<Lib48:DX00RU:0QcW00<Q22DY:DX0
1B4800HLib48:DXU:B487>L28@P01QcW8@PYBRe[:DXQ208Li`8Q208U:@<Q208U:@8Li`036<HLibDY
008U:@038@PLib48008Q20049BTQ22DY8@P29BT012U:9BTQ22480RDY00dQ21cW6<HQ22DY:DXU:B48
7>LQ22DY:DXU:@027>L02b48<H`e[BU:9BT@Q0Q236<8@PaS248020@Q00L000@Q12448@Q21248@P04
124010Q212448@@Q0`Q200L<H`Q248@DYAS67>LQ2002;F/03c6<=Jd]Jb48:DY6<EJe@Q0Q20aS7>LY
BRDY7>LDY@0248@00aBU48@<H`0224801@@Q2488@P@Q24800P@Q20Q20P@Q00H8@P@Q2488@P@Q2489
12442485124010Q212448@@Q0PQ200@<H`Q236<<H`88@P848@88@P0336<8@PQ200<8@P03124<Ha24
008<H`03124<H`aS0088@P8<H`0548@<Ha246<H@Q00236<011245:DDYABU0Q2400<DYA2436<00`Q2
00@<H`Q248@DY@8@Q003248<Ha24008<H`88@P0336<8@PaS008<H`88@P0336<@Q0aS0088@P0336<8
@PQ2008<H`<@Q00C5:D@Q0aS6<HLibe[?Nm:DVLiJeYcW6mkG_MW>Dic@Q0]JbU:9BT011cW0QS600PL
iaS67>LLiaS68@PHaQcW0QS60QcW00<Q21cW6<H00QBU0QcW00<HaQcW6<H00QcW00<DYAS65:D00QBU
00@HaQBU48@DY@<HaP@DY@8HaP<DY@8HaP065:DHaQBU5:DHaQcW0aBU00@@Q1BU5:D@Q08HaP8DY@8@
Q0045:D@Q12448@35:D00aS65:DDY@0348@011BU6<HDYABU0Q240QBU0Q240QBU00<@Q1BU48@01124
0PaS0Q2400<DYA2448@00a2400@<Ha245:DDY@d@Q00336<@Q124008@Q08<H`0648@<H`Q236<@Q1BU
0Q2400<<Ha2448@02A240PaS11240PaS1a240aBU0Q240PaS0Q240PaS00<@Q1BU48@011240PaS0Q24
00@DYA2448@DY@<@Q00336<@Q12400<@Q0<<H`<@Q0D<H`0348@DYA2400@<H`<@Q04<H`000`@Q00<0
00@Q00001@@Q00H8@R48AS4YBQcW:DX2;F/01RU:9BTU:Be[<H`YBP8U:@8YBP069BTQ22489BTLib48
0RU:00@U:AcW8@PQ208U:@048@PU:B488@P27>L00b487>LQ20029BT011cW6<HHaQcW0b4800<U:B48
8@P00R4800<U:BU:9BT00R480bDY00<Q21cW8@P00R4800DLiaS66<HHaQcW00HQ20037>LQ224800<Q
20057>LQ21cW7>LHaP027>L26<H00acW6<HU:@029BT012487>LLiacW0R480bDY0R480RDY00@Q21cW
8@PU:@<Q2009:DXU:AcW7>LQ22U:9BTQ21cW00@U:@8Q20@Li`<U:@<Q208U:@038@PLib48008YBP8U
:@8YBPPQ20049BTQ22U:9BT38@P39BT00b489BTU:@036<H39BT01B489BTQ21cW9BT00RU:00DQ21BU
5:D@Q0aS00@8@PH48@88@PH48@0324848@Q200848@0324848@@Q00848@<8@P0336<DYABU008@Q00;
6<HLib487>LDYAS69BT]JbU:8@PLi`038@P021BU248Q25:DG_LicPQ21242248212400`Q212448@02
12400`Q236<8@P022482124424800`@Q2488@P0236<31244248312400`Q21248@P0312401`Q21248
@P@Q24848@Q2008<H`0424848@@Q1242248636<448@25:D248@236<031245:D<H`aS5:DLid8@AS4U
:A241248@P8@Q0@<H`0348@<H`Q2008<H`8@Q0085:DHaQBU48@<H`Q236<8@P8<H`04248<H`aS36<2
248336<00`Q236<8@P0236<2248236<25:D03A2436<@Q1247>LQ23W>CW=F]FmkIcU[FVLi009Nm`0>
?NlaS2488@PU:B487>LHaR486<HDYAS67>LQ208Li`036<HLiaS600<Li`8Q20<HaP<Li`HHaP045:DH
aQcW6<H25:D00aS65:DDY@026<H011cW6<HDYABU0QS600<DYA245:D00QS600HLiaS67>LLiaBU6<H5
5:D26<H01aBU48@DYABU6<HDYA24008DY@0748@DYA2448@DYAS65:D00a241QBU00<HaQ245:D00QBU
00@HaQBU48@DY@8@Q08<H`P@Q00336<@Q12400<@Q0055:D@Q12436<@Q0025:D01Q2436<<Ha245:D@
Q08<H`0348@DYA2400<<H`D@Q00436<@Q1245:D348@00`aS48@<H`0248@336<248@00`aS48@<H`02
48@01QBU48@@Q0aS48@DY@@@Q0035:D<H`aS008@Q08DY@<@Q0035:D@Q124008<H`0648@HaQBU5:D@
Q1BU0a240PaS0Q241@aS0a2400@<Ha2436<8@P8<H`8@Q00336<@Q0aS008@Q0D<H`000P@Q00<000@Q
12401`@Q00DQ23g_:DXLibDY008aS006;F/U:BDY9BT]JbU:0bDY00<Q21cW7>L012480RDY0b4800<U
:B487>L0124800<Lib487>L00R480RDY00<Q21cW6<H00QcW124800LLib488@PQ22U:;F/U:@038@P0
12U:8@PQ22481AcW0QS600@Lib489BTQ20<Li`8Q20067>LQ21cW8@PLib480QcW11S60QcW00TU:BU:
9BTLiaS65:DLib487>L00RDY0RU:0b4812DY0QcW00<Q22U:9BT00QcW00@U:BU:9BTLi`<Q20<U:@<L
i`036<HU:BDY008U:@038@PU:B4800<Q200:9BTYBRU:8@PLib489BTYBRDY7>L48@P01acW8@PU:BDY
8@PU:AcW00<Q20069BTYBRDY9BTQ21cW0R4800<Lib488@P0124800DU:BU:9BTU:AcW008@Q08<H`88
@PT48@0324848@@Q00@48@88@PP48@88@P8@Q0<HaP045:DHaR488@P26<H01B48:DXYBQcW6<H00QcW
00TU:ABU248U:DicG_LicPQ212400PQ200D48@Q212448@Q200<48@04248<H`Q21244248010@Q2488
@PaS0PQ200D48@Q224848@Q200<48@0524848@@Q1248@P091242248236<224800`@Q2488@P022482
48@010Q236<<HaBU0a240aBU10aS00<@Q0aS48@00QBU00@mkdYB:DXDY@848@035:D<H`aS00@<H`88
@P8<H`035:D<HaBU00<DY@0536<8@PQ21248@P0336<00`Q21248@P02248010aS2488@PQ20`aS0`Q2
00D<Ha245:D@Q1BU008@Q0077>LQ23F]CW=JeV]JIcT00V]J00ENme[F?NlicRDY008Q20<Li`DHaP03
7>LQ21cW008HaP8Li`038@PLib48008Li`046<HLiacW7>L26<H00acW6<HDY@025:D011cW6<HHaQBU
1AS600@DYAcW6<HHaP@DY@8HaP8DY@@HaP<DY@<HaP<DY@036<HDYAS6008@Q0065:D@Q1BU5:D@Q1BU
0Q2400<DYA2448@00a2400<DYAS66<H00QBU00L@Q1BU5:DDYA245:DHaP035:D448@010aS48@@Q124
0QBU00H@Q0aS36<@Q1S65:D848@00aBU48@DY@0248@01@aS48@@Q1BU48@00PaS00<@Q1BU48@01A24
00@<Ha2448@DY@<@Q0055:D@Q0aS48@<H`0448@00`aS48@@Q00648@236<348@25:D248@336<00a24
36<<H`0248@011BU48@DYABU0Q2400H<Ha245:D@Q1BU48@25:D01A2436<<Ha245:D00Q240PaS0Q24
0PaS00H@Q1BU36<<H`Q236<348@336<248@00`aS48@@Q00136<0000500048@@Q1240000512401P00
124Licg_<H`U:@<YBP099BTQ22DY9BTYBRe[9BTQ22DY008Q20077>LQ22DY8@PU:B489BT00R4800<L
ib489BT00R4811cW00LHaQcW7>LU:BU:9BTLi`026<H00acW9BTLi`037>L28@P39BT28@P021cW8@PQ
22489BTQ22DY7>L36<H37>L00bDY:DXU:@027>L29BT00acW8@PU:@029BT37>L26<H47>L01248:DXY
BR480QcW00DU:AcW8@PLib4800<U:@038@PU:B4800<YBP038@PLib48008YBP0:8@PLib488@PLib48
9BTQ21cW9BT2:DX012DY7>LLib480QcW00@Q22DY:DXYBP8Li`8Q2006:DXU:B489BTYBRDY0R480bDY
00<Q21cW9BT00R4800HU:B489BTU:B487>L28@P29BT28@P01BDY8@PU:B489BT00b4800@U:BU:9BTU
:@8Q20067>LQ22e[;F/Q21240`aS00<8@P@Q36<00PQ21P@Q00<8@P@Q24800`@Q00<8@P@Q24801@@Q
1PQ20PaS00<@Q1BU48@00`aS0Q240QBU00@@Q1BU5:DHaP8DY@0648@DYAS67>LDYA240PQ21@@Q00@8
@P@Q1248@P8<H`0324848@@Q00H8@P031248@PaS0088@P848@04248<H`aS248212401@Q212448@@Q
248020@Q1PQ200<48@Q224800PaS00<@Q1S65:D00PaS00HQ22U:=JdYBQBU6<H35:D248@00`aS48@8
@P0336<0112436<<H`Q20PaS10Q21@aS00<@Q1BU6<H00aBU0PaS0PQ200@<H`Q21248@P8<H`032484
8@Q200@8@P<<H`04248<H`Q236<35:D348@00bDY<Ha:DP02G_L02FLiHaQS65kgCW=:DS6<:DXU:@02
8@P47>L00aS67>LLi`037>L00aS67>LLi`026<H38@P00aS67>LLi`027>L26<H01ABU6<HHaQS67>L0
2aS611BU0QS60aBU1aS631BU00<@Q1BU5:D00aBU1A2400<DYA245:D011BU00@HaQBU5:DDY@<@Q0@D
Y@0348@DYABU00@@Q00336<@Q0aS00<@Q0055:D@Q12448@<H`0248@25:D01A2436<@Q1245:D01A24
00@DYA2436<<H`<@Q00436<@Q0aS36<248@25:D748@336<948@010aS48@DY@aS11240`aS00T@Q0aS
48@<Ha2436<@Q0aS48@00QBU00<HaQ2436<00Q240aBU0Q240PaS0Q2400@<Ha2436<@Q08<H`<@Q004
36<@Q0aS48@336<248@00aBU48@<H`0236<648@124800006124000@Q00048@001P@Q00@Lid8@<H`Q
208YBP058@PU:B489BTYBP02;F/012U:9BTQ21cW0R480QcW00@Q22DY9BTU:@<Q20079BTQ22488@PU
:AcW6<H00QcW0b480RDY00<Q21cW6<H00QcW00<Q21cW6<H00QcW00<U:B488@P00RDY00HQ21cW8@PQ
22DY8@P37>L00aS65:DDY@027>L012489BTU:BDY1R480RDY0R480acW00XHaR488@PQ21S67>LU:BU:
9BTLi`<Q20067>LQ22489BTYBR480QcW00<Q22U:9BT01RDY1b4800DLib488@PU:BU:008Q208Li`05
8@PLib48:DXU:@028@P00acW9BTU:@028@P39BT28@P012DY:DXYBRDY11cW0bDY00<Q21cW8@P00RDY
124800HU:B489BTQ21cW8@P39BT28@P03BDY8@PU:B487>LQ22e[<H`Q212436<@Q0aS0088@P051248
@P@Q1248@P051242248412400`Q212448@0312401@Q212448@@Q24800PaS00<@Q0aS48@00PaS1124
00D<Ha2448@HaQBU008@Q0046<HDYA245:D36<H00`aS2488@P0412432483124224800`aS2488@P02
124224800`aS2488@P05248;12422485124:24801@aS5:DHaQS65:D00Q2400DLibU:<H`]JacW008D
Y@0348@DYA2400@<H`06248<HaBU48@<H`Q20`aS00D8@PaS36<8@PaS0088@P8<H`8@Q0055:DHaQBU
48@<H`0>24800`aS248<H`0736<248@25:D01`aS7>LaS4YBHaQNmfLi00=S6005DYA:DRe[:DXU:@02
8@P00acW6<HLi`047>L01b487>LLiaBU6<HLiaS6008Q20049BTLiacW6<H27>L00b487>LLi`026<H0
0acW6<HDY@026<H00acW6<HHaP056<H45:D00aS65:DHaP045:D00aS65:DHaP026<H35:D00aS65:DD
Y@025:D00aS65:DDY@035:D00a246<HDY@075:D00a245:DDY@055:D00aS65:DDY@035:D348@00`aS
5:DDY@0248@236<448@011BU48@<H`aS0QBU112400<DYA2448@01A240PaS0Q2400<DYA2448@00Q24
00<<Ha2448@00PaS0a2400<DY@aS48@00a241@aS11240PaS00<@Q1BU48@00Q2410aS0Q240`aS00HH
aQBU48@8@PaS5:D548@00aBU48@DY@0548@00aBU6<HDY@0248@00`aS48@<H`0448@336<448@00`aS
48@<H`0236<448@00`aS48@<H`0448@236<000`48@058@Q:DSF]9BTYBP029BT28@P00bDY:DXYBP04
:DX012DY8@PQ22480RDY1B4800DU:B488@PU:B4800<Li`056<HLiacW8@PU:@028@P36<H01QcW9BTQ
22DY8@PLi`8Q20039BTQ2248008Q20039BTQ2248008Li`076<HQ21S65:DHaQcW9BT00R4800<U:BU:
8@P00QcW00LU:BU:9BTQ22U:9BTQ20046<H27>L012489BTU:BU:0RDY0b4800@U:B488@PU:@8YBP05
8@PLib489BTYBP029BT28@P00bDY:DXU:@088@P00bDY8@PQ20029BT00b487>LHaP037>L29BT02BU:
8@PQ22489BTQ22DY8@PYBP029BT3:DX00b487>LLi`038@P37>L48@P00acW8@PLi`028@P39BT28@P0
0acW8@PU:@03:DX58@P01QBU8@P]JcW><H`Li`8@Q00436<8@PQ2248412401@Q21248@P@Q24801`@Q
00D8@P@Q12448@Q200D48@<8@PD<H`8@Q00336<8@PaS0088@P0336<@Q12400@<H`<8@P0436<8@PQ2
1242248212400`Q21248@P02248010aS24848@Q20`aS00<8@PaS36<00`Q200@<H`Q236<<H`<8@P<4
8@<8@P<48@X8@P061248@P@Q248<H`Q20Q2400TLicF]@Q0icRU:9BTaS48@?Nl00S6<0R4800<HaQ24
48@00`aS00D8@P@Q1248@P@Q00@<H`0424848@Q2248336<00a245:D@Q00248@00aBU6<HHaP0236<3
248236<424800`aS248<H`0436<00`Q236<<H`0248@01@aS48@DYABU48@00QS600<]JcW>BU800U[F
00]Nme[FE[EF]Cg_=JdU:AcW8@PLib48008Li`8Q208Li`046<HLiacW6<H47>L011S68@PQ22480aS6
00<Q21cW7>L00aBU0QS60QBU00<HaQBU6<H011cW0QS600<DYA245:D011BU0QS600<DYAS66<H00QS6
00<DYAS66<H00QS611BU00DHaQBU5:DDYA24008DY@036<HDYAS600<DY@8@Q08DY@056<HDYA245:D@
Q0075:D01A245:DHaQS65:D00Q2400HDYA2448@<Ha245:D448@00aBU48@DY@0248@010aS48@@Q1BU
1A2400<DYA245:D0112400<DYA2448@0112400<<Ha2436<00Q2400<<Ha245:D00a2400<<Ha2448@0
0Q240PaS0Q2400<<Ha2448@011240PaS0Q2400<DYA2448@01@aS00H@Q0aS36<<Ha245:D448@00aS6
5:D@Q00336<548@00`aS48@<H`0436<348@236<00a2436<@Q00436<00a2436<DY@0348@336<01124
5:D@Q0aS0@Q200021240200012448@@Q0008@P@Q000212401B48BU8e[AcW:DX01RDY12U:0bDY1248
00<U:B488@P00R480QcW124800DLiaS67>LLib48008U:@038@PLiaS600<Li`038@PU:BDY00<Q2003
9BTQ224800TQ208Li`<HaP037>LQ2248008U:@038@PLib48008YBP8Q20059BTYBRDY7>LHaP027>L0
0aS67>LQ20029BT2:DX28@P27>L38@P00bDY:DXU:@027>L28@P01RDY8@PU:BDY:DXU:@8Q20@U:@03
8@PLib4800<U:@<Q20<Li`048@PLiaS68@P39BT00acW9BTQ20028@P29BT28@P012DY;F/YBR4811cW
0R4800DLiaS68@PQ22DY008Q20057>LQ22489BTYBP039BT00b487>LQ20029BT00bU:9BTU:@028@P2
9BT02AS67>LaS3W><H`Q21245:D<H`04248=1242248010@Q00048@Q20P@Q10Q20P@Q0PQ210aS0PQ2
0`aS0PQ20PaS00<@Q0aS36<01@aS10Q20P@Q00D8@P@Q12448@Q200<<H`H8@P0336<8@PQ200@8@P@<
H`<8@P041248@PQ22483124010Q212448@@Q1@Q200<48@Q236<00`Q200/48@Q248@@Q1cW>Li243W>
:DXU:C6<00924007=JdaS1cW7>LHaQBU48@00PaS1@Q200@48@Q2248<H`L8@P8<H`0348@DYA2400@D
Y@0348@<H`Q200L8@P0336<8@PaS00@<H`0348@<H`aS0088@P8<H`8DY@8@Q0055:DHaRe[=Je:DP02
F]H01V<HF]IF]EJe@Q0icPDQ20@Li`0?8@PLiacW8@PHaQcW6<HLib487>LQ21cW8@PLib48008Li`<H
aP047>LHaQS65:D26<H01ABU6<HHaQS67>L01AS600<DYAS66<H00aBU00LHaQBU5:DHaQBU6<HLi`02
6<H00aBU6<HHaP025:D011245:DDYAS60QBU00@@Q1BU5:DDY@@HaP<DY@8@Q0035:D@Q1BU008HaP8D
Y@8HaP<DY@046<HDYA2448@35:D01Q2436<@Q0aS5:D<H`8@Q0035:D@Q12400L@Q0065:D@Q12436<@
Q1BU0a2400<DYA2424800Q240QBU00<@Q0aS48@00a240`aS00<@Q0aS48@00a240PaS212400@DYA24
36<<H`H@Q08DY@8@Q0@<H`0348@<Ha24008<H`0348@<Ha24008@Q0@DY@0348@<H`aS00@@Q00336<@
Q12400<@Q0<<H`0348@<H`aS00H@Q08<H`0448@DYA245:D336<348@436<0000500048@@Q12400007
124012DYCW<e[AcW0bDY0RU:00<U:BU:9BT00RDY00P]Jc6<;F/YBQcW8@PU:B480RDY00D]JbU:9BTQ
22DY008Q20037>LHaQcW00<Q20037>LQ2248008Li`036<HQ2248008Q20039BTQ2248008Q20069BTQ
22489BTYBRDY0R480QcW00<Q21cW7>L00QS600DLibDY:DXYBRDY008Q20037>LQ2248008Q20067>LU
:BU::DXQ21cW11S60QcW00@U:BU:9BTU:@8Q20049BTLiacW8@P2:DX28@P022DY8@PLib489BT]JbDY
8@P39BT28@P012DY8@PLib480RDY0R4800DU:BU:8@PLiaS600HLi`068@PU:B489BTQ22DY124812DY
00<Q22DY7>L01acW0R4800<Lib489BT00RU:00DU:B488@PQ22DY008Li`038@PU:BDY00DQ20<Li`04
8@PU:B489BT2;F/011cW5:D<Ha240PaS0`Q20`@Q00<8@P@Q12401@@Q00<000@Q24800PQ210@Q10Q2
0`@Q0`Q20`aS0`Q200<<H`Q224801PQ20P@Q00<8@PaS24800P@Q10Q200D<H`Q22488@P@Q0088@P@<
H`0=248<H`aS36<DY@aS248<HaBU7>LDY@Q212403`Q200<<H`Q224800PQ200<48@Q212400PQ200X4
8A24=JeJeUJe>LhaS4HaE[EJeP9S609JeP03@Q0e[B48008@Q08<H`H8@P031248@PQ200D8@P<<H`@D
Y@0448@DYABU5:D248@00`aS2488@P0336<2248;36<348@02PaS5:D@Q1247>LU:Cg_BU96<Dic0dYB
00A243g_:DXU:@8HaP8Li`078@PLiaS68@PU:AcW6<H00QcW00HQ21cW6<HDYAS67>L29BT01AcW6<HH
aQS67>L00QS60QBU0QS611BU0aS600TQ22U:9BTQ21S67>LHaQBU48@00QBU00@@Q1BU6<HLi`8HaP8D
Y@076<HDYAS66<HDYAS65:D00Q2400<DYAS67>L00aBU00<@Q1BU6<H00QS60QBU00<HaQBU5:D00QBU
0QS611BU00<@Q1S65:D00aBU00P@Q1BU5:DDYAS648@DYAS60Q2400<<Ha245:D01A2400<DYA2448@0
0a2400<<Ha2448@00QBU1A2400D<Ha2436<@Q1BU00H@Q00436<@Q12448@25:D648@236<0112436<<
Ha240QBU0PaS00PDYA2448@@Q0aS48@DYA240QBU0PaS00<8@PaS36<010aS0a240aBU00@HaQBU5:D@
Q0H<H`0448@<H`aS36<248@336<248@436<348@336<00a2436<<H`0236<248@00`aS48@<H`0436<1
24800006124000@Q00048@001P@Q00@Q24YB=JdLi`<U:@@YBP04;F/YBRDY:DX2;F/01RDY8@PU:BDY
8@PU:@@YBP059BTQ21cW6<HLi`058@P00bDY8@PQ20047>L28@P012DY8@PQ21cW0RDY0b480bDY0R48
0RDY00<Q21S66<H00QS600@U:BU::DXYBPDQ20039BTQ22DY008Q2005:DXU:BDY7>LDY@026<H011cW
8@PLibDY0RU:00XU:B489BTU:B487>LQ22DY;F/YBP8Q20057>LU:BDY9BTQ20029BT00bU:9BTU:@02
8@P29BT011cW8@PU:BDY0R4812DY0QcW00LHaQcW6<HHaQcW8@PU:@028@P39BT48@P01QcW9BTU:BDY
8@PLi`<Q20<Li`038@PU:B4800<Q20039BTQ22DY008Q20079BTQ22488@PU:B489BT00R4800@Lib48
9BTQ20<Li`<U:@04<H`]Jb485:D436<224800`@Q24848@05124224821242248512401PQ21248@P@Q
24848@<8@P0336<8@PQ2008<H`88@P<<H`0524848@@Q24848@0324801PaS248<H`Q21248@P848@88
@P0336<8@PQ200D8@PH<H`0;248<Ha2436<8@PaS5:DHaQBU24848@052482124324821242248236<6
24801P@Q248<H`@Q48@aS09F]@0<=JdaS4HaF]IF]F<HG_MJeUkg@Q0icQcW0QBU00D<Ha242488@P@Q
0088@P041248@PQ2248236<3248236<00`Q248@DY@025:D011246<HDYAS60Q2400<<H`Q236<00PQ2
00@<H`Q236<8@P8<H`0548@<Ha2436<@Q00436<248@02QBU6<HDYA246<HLicW>AS5:DTic0TYB0THa
00I242e[9BTHaQcW8@P87>L01B487>LLiacW6<H00acW0b480QcW00@HaQcW6<HDY@<HaP8DY@066<HD
YAS65:DHaQcW0bDY00PQ21cW7>LHaQBU6<HDYAS60aBU0QS60QBU0aS61QBU00DHaQBU5:DDYAS6008D
Y@8@Q0076<HDYAS65:DHaQBU6<H00QBU00<@Q1BU5:D00QS61ABU00HHaQBU5:DDYA245:D248@45:D4
48@25:D448@00aBU48@<H`0548@00aBU48@DY@025:D348@00`aS48@@Q00248@00aBU48@<H`0448@2
36<021245:DDYABU48@DYA2436<848@25:D648@00`aS48@@Q00248@236<248@236<248@00`aS48@@
Q0035:D26<H25:D0112436<<H`aS0Q240`aS0Q240`aS0a2410aS00<@Q0aS48@01Q240`aS00<@Q1BU
48@00`aS0Q240@aS000:12402000248Q24Ha<H`LibDY:DX39BT5:DX012e[<H`aS2e[0bU:0RDY0RU:
0RDY0R480acW0b480RDY0R4800<LiaS67>L00b4800@U:AcW7>LQ208U:@03:DXU:BDY00HU:@04:DXQ
22DY7>L26<H012489BTU:B480RDY00DQ21cW8@PQ22DY008Q20<U:@068@PLiacW6<HLib480RDY0R48
00<YBRDY9BT00b4800DU:BU:;F/]JbDY00<Li`8U:@8Q20039BTYBRe[00<U:@8YBP058@PLiacW7>LH
aP058@P29BT01B487>LLiacW8@P00QcW0b4811cW00TQ21cW8@PU:Be[:DXU:AS67>L00b480QcW00@H
aQcW7>LQ208YBP088@PLib488@PYBRe[9BTQ20@Li`<U:@8Li`098@PU:BDY8@PHaQcW9BTQ22DY008a
S004;F/HaQ245:D248@5248412400`Q212448@0312400`Q21248@P0324861242248212400`Q236<8
@P02124010Q21248@P@Q10Q200D48@Q22488@PaS0088@P051248@PQ224848@0224801@aS2488@PQ2
36<00`Q200<<Ha2436<00PaS00`DYAS68@PU:ABU248@Q248;F/Q20aS1242248336<00`Q236<8@P02
124524800`aS2488@P04124020Q21248@P@Q7>M245JeDY@2>Lh04E:DKg]_NfmkIcU[FWooLiaS63F]
6<H@Q0Q21248@PaS248010@Q00@8@PaS24848@@8@P8<H`0448@<Ha2448@25:D26<H00aBU48@<H`02
36<3248336<00`Q236<<H`0836<02a245:DDYABU48@DYBDY=Je6<DYB@Q000THa0T8@00DaS2U:7>LL
iaS6008Li`8HaP097>LQ22487>LHaQcW6<HLiaS6008Li`036<HLib48008Q208Li`8HaP035:DHaQS6
00<DY@8HaP8DY@0836<DYAcW8@PYBRDY7>LQ208Li`8HaP035:DHaQS6008DY@<HaP047>LHaQS65:D3
6<H25:D26<H65:D248@65:D46<H35:D01a245:DHaQS65:D@Q1BU00@@Q0046<HDYAS65:D448@00aBU
48@DY@0348@00`aS48@@Q0025:D00a2436<<H`0548@26<H011BU48@@Q1240`aS00<@Q1S65:D010aS
00<DYA245:D00Q2400<<Ha245:D00aBU0Q2400<<Ha2448@00PaS00<@Q1BU5:D011240PaS1a240QBU
112400<<Ha2448@00aBU00@HaQBU5:DDY@8@Q0<<H`8@Q0@<H`8@Q0085:D@Q12436<@Q0aS48@DY@8@
Q00336<@Q124008@Q0@<H`8@Q00336<@Q124008@Q0<<H`4@Q04<H`000P@Q00@000@Q124000H48@04
8@Q6<CF]7>L39BT00bU:9BTU:@04:DX01be[<H`]Jbe[9BTYBRDY008Q20069BTYBRU:9BTLib480QcW
00<Q21cW8@P00bDY00<Q21cW7>L011cW00<U:B488@P00b4800<YBRe[:DX00b480RU:0bDY0R4811cW
1BDY00<Lib487>L00bDY0R480bDY00@Q21cW7>LLi`8Q20039BTQ22DY00<Q20039BTQ22DY008U:@8]
J`038@PLiaS6008U:@087>LQ22DY:DX]JbU:9BTQ20<U:@@Li`038@PU:BDY00<Q208U:@8Q20<Li`8Q
20<Li`048@PLiacW7>L38@P39BT28@P00acW8@PLi`028@P00acW8@PQ20048@P011cW8@PQ22DY0RU:
00HQ22DY7>LHaQcW8@P2:DX012487>LLib480RDY00<Q21cW7>L00b4800@]Jc6<:DXQ208DY@0348@<
H`Q200<8@P@48@0424848@@Q1242248312401@Q21248@P@Q248010@Q00H8@P@Q2488@P@Q24821247
2484124524801@@Q2488@PaS24800P@Q00<8@PaS24800`Q21@aS010@Q0aS36<DYAS68@PLia24248@
Q1cW:DXLi`aS248<H`88@P<<H`0324848@@Q0088@P0436<8@PQ236<224821243248212401PaS124D
YCW>F]IF]@8icP0?E[E_NfmkKg]W>F]JNmicW6Li=JdHaQ24124<H`Q200D48@@8@P0436<48@@Q2484
36<00a245:DDY@025:D00a245:DDY@0536<3248236<00`Q236<<H`0836<248@021BU48@DYA24:DXe
[DHaCW<3AS40148@?Nl]JbU:0acW00<HaQcW7>L00acW00DHaQcW7>LQ21cW00<HaPDLi`8Q20037>LH
aQS6008HaP0448@HaQS67>L45:D00a245:DHaP029BT48@P00acW6<HHaP025:D02AS65:DHaQS67>LH
aQBU6<HDY@046<H01ABU6<HDYABU6<H01QBU0Q240QBU00<HaQBU5:D00QS60aBU00<HaQBU5:D00Q24
0QBU00<HaQBU5:D01aBU1A240QBU2A240PaS0a240PaS00<@Q1BU5:D00Q2400PDYA2436<@Q1BU48@D
Y@aS11240PaS0Q241aBU00<@Q0aS36<02a2400<DYA245:D00Q2400<<Ha2448@00a240`aS00DDYA24
36<<Ha24008DY@036<HDYAS6008@Q08<H`0348@<H`aS00@@Q0<<H`0448@<Ha2436<248@01PaS48@@
Q1BU48@<H`<@Q0<<H`0348@<H`aS008<H`0348@<H`aS00@<H`0000D000@Q12448@0000L48@0:7>M6
<CW>8@PYBR487>LQ22DY:DX4;F/00bDY8@PU:@02:DX01BDY8@PQ22DY:DX00bDY0QS600<Lib489BT0
0R4800<U:B488@P011cW00<Q21cW8@P00QcW00<Q21cW9BT00RU:0RDY0Re[00DYBRDY8@PQ22DY008Q
20<Li`038@PU:BU:008U:@036<HLiacW008Q20057>LU:BU::DXU:@037>L011S67>LLib480bU:00<U
:AcW8@P00b4800<Lib48:DX00RU:00HU:AcW8@PU:B489BT38@P4:DX012DY8@PU:B480QcW00DHaR48
9BTU:BU:008Li`038@PU:BU:008Q20047>LQ22487>L26<H011cW8@PQ21cW0QS600<Q21cW8@P00RDY
0R4800DLiaS67>LLib4800@Li`8Q20089BTQ22487>LU:BU:;F/YBP8Li`048@PLib489BT58@P3:DX0
22DY8@PU:BDY7>LQ21cW8@P2:DX012DY7>L<H`aS0PQ200<<H`Q212400P@Q00<8@P@Q24801@@Q00<8
@P@Q12400P@Q0`Q20`@Q0PQ20P@Q0`Q20P@Q0PQ200P48@Q212448@Q21248@P@Q10Q200H48@Q21244
8@Q2124224800`@Q2488@P0336<02PQ236<<HaBU48@DYB489BT]JbU:0QcW00@DYA2448@@Q08DY@09
36<8@PQ2248<HaBU48@DYAS6008<H`H48@88@P041248@P@Q2483124224800acW:DXmk`02?Nl014ic
F]I_Nfmk16]J00McW7ooE[D]Ja241248@P081249248236<01Q2436<@Q1246<HDY@<@Q00436<8@PQ2
248336<00`Q236<@Q00236<2248636<348@011S67>Le[D8@0TYB00M244YBAS4e[BU:7>LHaP037>L2
6<H00acW8@PQ20067>L36<H01AcW5:DLiacW9BT00QcW00HDYAS66<HHaQBU6<H35:D36<H348@011BU
7>LYBRDY0QcW00<HaQcW6<H00QBU00<@Q1BU6<H00QS600<DYAS66<H00aBU0QS60a241ABU00<HaQBU
5:D00a2400DDYA245:DDYAS600LDY@0348@DYA2400<DY@036<HDYABU00<@Q0045:D@Q1BU5:D348@0
0aBU48@@Q00248@00aBU48@@Q00548@00aBU48@@Q00248@25:D00a245:D@Q00948@00`aS48@<H`05
48@25:D00aS65:DDY@025:D00a2436<8@P0348@45:D00a245:D@Q00648@011BU48@@Q0aS0a2400@<
Ha2448@DY@<@Q0@DY@8@Q00436<@Q12448@236<00a245:D@Q00536<0112436<DYABU0Q240PaS1124
1PaS00<@Q1BU48@01@aS0Q240@Q2000010@Q00048@000`@Q00<8@P@Q00000P@Q00DQ24YB>LhQ22DY
008Q2004:DXU:BU::DX2;F/3:DX00bDY:DXU:@038@P29BT012489BTQ21cW0QS600HLib487>LQ22DY
8@P97>L28@P00acW9BTYBP06:DX00bDY8@PU:@048@P00acW6<HQ20029BT00bU:7>LLi`027>L28@P0
1QcW9BTYBRU:9BTLi`8Q20<HaP068@P]JbU::DXQ21cW1R4800<U:Be[:DX00b480QcW00<Q22DY:DX0
0RDY0RU:00@Q21cW8@PU:@<Li`038@PU:B48008Q208U:@<Q208U:@8Li`056<HLiacW6<HLi`038@P0
1acW6<HHaQcW8@PU:B48008U:@8Li`036<HQ21cW00DLi`<Q20039BTQ22DY00<U:@038@PLiacW00<Q
20059BTQ22DY:DXU:@03:DX022DY8@PQ22489BTQ21cW8@P2;F/012DY6<H<Ha240PaS00D8@P@Q1244
8@Q200<48@0424848@@Q124224800`@Q0008@P0224821243248512400`Q21248@P0224800`@Q2484
8@02248010@Q2488@P@Q0PQ200D<H`Q224848@Q200848@88@P041248@PQ2248236<01@Q236<<Ha24
5:D00Q2400LQ22DY<H`YBQcW6<H@Q0035:D03A2436<<H`Q21248@PaS5:D@Q1S65:D<H`Q200848@03
24848@@Q00<8@P848@0324848@Q200848@88@P036<HYBSg_008mk`04BU9NmfmkKg/2JeX02FLiJeYg
_GooF]H]J`aS1248@P0412401PQ212448@@Q248<H`88@P848@88@P8<H`<@Q00;36<@Q12448@DYA24
36<8@PaS248<H`03248436<0112436<<H`aS0PQ20`aS00<@Q1BU48@00QcW00TicT8@AS5:DT8@BU92
43F]:DX00QcW0QS60QcW00@HaQcW7>LLi`8Q208Li`DHaP065:DHaQcW8@PLib480aS600DDYAS66<HD
YAS6008DY@086<HDYABU5:D@Q1S65:DHaP8Q20049BTQ21cW6<H35:D00aS65:DHaP055:D011S65:DH
aQS60QBU0Q2411BU00@HaQBU6<HDY@<@Q0DDY@8HaP055:D@Q1BU6<HDY@0248@02QBU6<HHaQBU48@D
YA246<HDYA240QBU112400@DYA245:DDY@<@Q00736<@Q0aS36<DYA245:D00Q240PaS00LDYA2436<@
Q0aS48@DY@0248@00`aS48@@Q0025:D01@aS48@<Ha245:D00Q2400@<Ha2448@@Q0@DY@<<H`8@Q08<
H`<DY@8@Q00436<DYA2448@35:D00a2436<@Q00248@01ABU6<H@Q12436<01A240aBU0Q2400<<Ha24
48@0112400<DYA2448@00PaS00@@Q0aS36<<H`8@Q0<<H`8@Q08<H`0348@<Ha24008<H`03248<Ha24
008<H`0348@<H`aS008<H`8@Q08<H`001@@Q00<000@Q124010@Q00DLidHa>LhQ22DY008Li`038@PU
:BU:00<U:@03:DXU:BDY008Q208U:@048@PU:B488@P27>L56<H012489BTU:B481AcW0R4800HLib48
7>LQ22DY:DX39BT012U:;F/U:BDY0bU:00LU:AcW6<HU:BU:<H`]J`039BT28@P01AS67>LLib48:DX0
0RDY0R4800<YBRDY8@P00acW00<Q21cW8@P00RDY0R480bDY00HQ22DY:DX]JbU:9BT28@P01bDY:DXU
:AcW6<HLibDY008YBP049BTYBRU:9BT28@P02AcW9BTYBRU:9BTQ21cW8@PU:@02:DX012DY8@PQ2248
0QcW00<HaQcW7>L00QcW0b480QcW00@Q22DY9BTU:@@Li`048@PLib489BT28@P27>L00b489BTU:@02
6<H01BDY:DX]JbU:7>L00RDY0R4800XLib489BTU:B487>LU:C6<;F/YBP8Li`058@PLiacW7>LQ2002
:DX00acW6<H@Q00248@00`aS2488@P0224800`@Q2488@P03124010Q212448@@Q0PQ210@Q0`Q21@@Q
00L8@P@Q24848@Q21248@P0412400`Q21248@P0724800`@Q2488@P03248212400`Q236<8@P025:D2
6<H01B48:DXaS3W>=Jd00Sg_0S6<00<Q21cW5:D00a240`aS0P@Q00@<HaBU6<HDY@8<H`0324848@@Q
0088@P<48@<8@P848@0424848@Q248@27>L00bDY<H`mk`02DY@016LiJeY_Nfmk0VLi00UcW7ooHaPa
S1241248@PaS24800P@Q10Q200<48@Q2248010Q200D48@Q236<8@PaS008@Q00336<@Q1BU008@Q088
@P0336<8@PQ200H<H`0748@<H`aS36<8@PaS48@00`aS00H@Q1BU5:DU:Be[@Q02AS4014icBU9243F]
0QcW0QBU00<LiaS66<H00aS61AcW0aS60QcW00<DYAS66<H011S600<LiaS66<H01ABU0aS60aBU00X@
Q1BU48@DYAcW8@PLiaS65:DHaP8DY@0448@DYABU48@25:D36<H00aBU48@DY@025:D348@35:D00aS6
5:DDY@0548@35:D00aS65:DDY@025:D248@00`aS48@DY@025:D011245:DDYAS60QBU1a240QBU0Q24
00D<Ha245:DDYA24008<H`@@Q0@DY@0348@<Ha24008@Q0035:D@Q124008@Q00336<@Q12400<@Q0<<
H`H@Q00536<@Q1S65:D@Q00236<00aBU48@@Q00848@00`aS48@DY@0348@00aBU48@DY@0448@01QBU
48@@Q1BU48@<H`8@Q0<DY@0448@<H`aS36<348@236<00a245:D@Q00436<00a245:DDY@0248@00`aS
48@<H`0236<348@236<248@236<348@010aS48@<H`Q20PaS0A240@aS000212400`00124000071240
1B48AS4aS1cW8@P01RDY00@YBRDY:DXU:@DQ20059BTQ22488@PU:@027>L011S67>LHaQS60R480RDY
0QcW00<HaQcW8@P00acW00<HaQcW7>L00RDY00@YBRDY9BTYBP<U:@07:DX]JbU:9BTHaQcW8@P00bU:
0RDY00@Q21cW6<HLi`<Q20039BTQ22DY00<U:@038@PLiacW008Li`036<HLib48008YBP049BTQ22DY
9BT38@P02BDY;F/]Jb487>LQ22DY:DXU:@027>L28@P2:DX29BT012U:9BTQ21cW0R4800LLibU:;F/Y
BR487>LU:@02:DX01B487>LQ21cW8@P011S600HQ21cW7>LLib487>L28@P29BT57>L01R489BTU:B48
7>LHaP8Li`0:8@PU:B487>LHaR48;F/aS2DY7>L39BT01B487>LQ22489BT00R4800@YBRe[<H`U:@8Q
20039BTLiacW008Li`8YBP038@PHaQ2400<<H`03248<H`Q200848@88@PL48@<8@PD48@0424848@@Q
12422485124224801P@Q24848@Q21248@P848@D8@P031248@PQ20088@P041248@PaS248212400`Q2
5:D@Q0026<H01B48:DX]Jc6<=Jd00SW>00@e[C6<8@PQ208DY@8@Q08<H`0724848@@Q36<@Q1cW6<H0
0PaS00D8@P@Q24848@Q200<48@88@P848@0@24848@Q236<@Q1S67>LQ236<?Nm>LeJeIcU_Ng>LJeX2
IcT027NmOomNmcF]48@48@Q21242248010@Q2488@PQ20P@Q0`Q20P@Q0PaS0PQ200@<Ha2448@DY@8<
H`0348@DY@aS00<8@P8<H`@8@P8<H`@8@P8<H`88@P8<H`0648@DYA249BT]Jd8@0THa00A>LdHa@Q0a
S08Li`035:DLiacW00<HaP8Li`036<HLiaS600<Li`LHaP@Li`<DY@046<HDYAS66<H45:D26<H448@0
1ABU7>LLiacW6<H00aBU00@@Q1BU5:DHaP8DY@0448@HaQBU5:D26<H25:D021245:DDYABU48@DYAS6
5:D748@36<H75:D348@00aBU48@HaP035:D248@00aBU48@DY@0248@00aBU6<H@Q00448@01ABU48@@
Q12436<0112400@<Ha2448@DY@8<H`<@Q08<H`@@Q08<H`<@Q08<H`8@Q0035:D@Q12400<@Q0<DY@8@
Q00336<@Q124008<H`0548@DYA2448@<H`0248@00aBU48@<H`0248@01ABU48@@Q1245:D00a2400<D
YA2448@00a2400@DYA245:D@Q08DY@0548@<Ha2448@DY@0248@336<00a2436<<H`0548@01ABU48@<
H`Q236<01Q241@aS0aBU0`aS0Q2400<<Ha2436<00@Q200000`0012448@0312402P0012448@@Q0004
8AcW@Q0]JacW0bDY124812DY00<YBRDY8@P01AcW00@Q21cW8@PLi`@HaP8Q20037>LQ21cW00<Q20<L
i`076<HLibDY;F/aS2e[8@P00RDY00<Q22U::DX00RU:12DY00HQ22U::DX]JbU:8@P29BT28@P00acW
8@PQ20039BT012489BTQ22480acW00<Q22U:9BT00b4800<U:B488@P00R4800TU:BU:;F/YBRDY8@PL
ib489BT00RU:00<U:AcW7>L00RDY0bU:014U:B488@PU:B487>LQ22U:9BTQ21cW9BTYBRDY7>LQ22DY
008Li`<Q20<Li`HQ208U:@038@PLib4800@Q20039BTQ224800<Q20049BTLiacW7>L28@P01AcW9BTY
BRU:9BT00QcW124800@LibDY:DX]J`@YBP03;F/U:B48008Li`<U:@<Q20039BTLiaBU00@<H`88@P<4
8@0424848@@Q12422488124324800`@Q00048@0224821242248212432482124324821242248436<0
0a242488@P02124030Q236<<H`Q27>M245[FAS4]Jcg_F]I[FP=JeP04DYAJeSW>;F/36<H236<42480
1`@Q2488@PaS48@<H`Q2008<H`D8@P848@88@P<48@8<H`8DY@8Q2007:DXicTHaF]IF]FLiJeX00W>L
00]S65kg?NlYBQBU1248@Q245:DU:B48008<H`848@T8@P<<H`05248<Ha2448@DY@0248@336<62482
36<00a2436<<H`0336<02A24248<H`aS48@Lib48>Li24002BU80248@CW=2436<8@PDYAS67>L26<H0
11BU6<HLiacW0aS600@LiaS66<HDY@8HaP045:DHaQcW7>L66<H35:D00aS67>LHaP026<H00aBU6<HD
Y@025:D01Q245:DDYABU6<HDY@8HaP<DY@0348@DYA24008@Q0<DY@036<HDYABU008DY@0348@DYA24
008@Q0<DY@L@Q0075:D@Q1BU48@DYA245:D00a2400@<Ha2436<@Q0DDY@8@Q0075:D@Q12436<@Q1S6
5:D00Q240QBU00<HaQ2436<0112400@<Ha2448@@Q08<H`0348@DYA24008@Q0055:D@Q1BU48@DY@07
48@010aS48@@Q1240`aS1A240QBU00<@Q1BU48@00PaS00<@Q1BU48@00`aS112400H<Ha245:DDYA24
5:D26<H25:D448@00aBU48@@Q00248@25:D00aS648@@Q00236<011BU48@DYABU2A2400@DYA2448@@
Q08<H`04248<Ha2448@436<0212436<<Ha246<HDYA2436<25:D00`aS48@@Q0025:D148@136<00005
124000@Q1240000212400`Q212448@0212401248@Q0aS1cW0RDY00@Q21cW7>LQ208U:@038@PU:B48
00<U:@8Li`076<HLib486<HLiaS67>L00aS60QcW0R480acW0b4800PLiaS66<HHaRDY:DX]JbU:0R48
12DY0RU:00<]JbU::DX00R4800@U:BU::DXYBP8U:@<Q208Li`8Q20039BTQ2248008Q20<Li`8Q20<U
:@8Q208Li`0:8@PLibDY8@PYBS6<;F/U:AcW6<H28@P29BT01bU:7>LLiacW9BT]JbU:00<U:@<Q20<U
:@<Q20<U:@LQ20037>LQ21cW008Li`088@PU:AcW6<HLibDY:DXU:@8Q20037>LQ2248008Q20049BTQ
22DY8@P37>L29BT032487>LLib489BTYBRDY8@PLib487>LU:@8Li`038@PYBRe[00<U:@04:DX]JbDY
8@P27>L28@P022DY8@PLibDY8@PLiaS6248336<524831243248010@Q24848@000P@Q0PQ20P@Q0`Q2
0P@Q00<8@P@Q24800PQ200@48@Q21248@P@48@0324848@Q200<8@P@<H`P8@P0:124Lid8@E[E242U:
>LiNmf]JF]H2E[D2F]H00cW>;F/HaP025:D236<6248336<0112436<<H`Q20`@Q00@8@P@Q12448@<8
@P<48@0<248@Q1S69BTLibDY=Je:DUkgE[ES66]J0W>L0V<H00LmkbDY5:D8@PaS48@DY@028@P01a24
36<48@@Q36<8@PaS00L8@P0336<@Q0aS008<H`0448@<H`aS48@336<4248010aS2488@PaS0PQ200<<
H`Q236<010aS0Q240QS600/icSg_BU9BU4HaCW<mkbe[8@PDYAS600<DY@046<HLiacW7>L:6<H01aBU
6<HLiaS67>LHaQcW008DY@056<HLiaS65:D@Q0036<H75:D01a245:DHaQS67>LHaQBU008@Q0<DY@06
48@DYABU48@DYA241aBU00<@Q1BU5:D011BU00@@Q0aS36<@Q0DDY@0448@DYA245:D448@35:D248@0
21BU6<HDYABU36<@Q0aS5:D248@00aBU48@DY@025:D00a245:D@Q00248@011BU48@@Q0aS0Q2400<8
@Q245:D00QBU00<<Ha2448@00PaS00<@Q1BU5:D00a241@aS0a2400<<Ha2448@01A240QBU00D@Q0aS
36<<Ha24008DY@0348@<Ha24008@Q08<H`0348@DYABU008@Q0@DY@0348@DYA2400@@Q08<H`0348@D
YAS6008DY@0348@<Ha24008<H`<@Q0075:D<Ha2448@<Ha2436<01Q2410aS112410aS1a2400@DY@aS
36<<H`8@Q04<H`000P@Q00@000@Q124000H48@099BU242U:6<HYBRe[8@PLib48008YBPDU:@067>LQ
21cW7>LQ21cW0R480QS600@DYAS65:DLi`8Q208Li`8U:@048@PLib488@P27>L012DY:DX]JbU:0bDY
00@YBRDY9BTQ20@U:@8YBP8U:@038@PU:BDY00<U:@038@PLib48008Q20079BTQ22488@PLib487>L0
0b480bDY00<YBRDY9BT01R48018U:BU:9BTU:AcW8@PLibDY:DX]Jb486<HQ22DY:DXU:AcW8@P39BT0
0b487>LU:@02:DX29BT00b489BTU:@038@P37>L012487>LLib480RDY0R4800<U:BU:9BT00R4800DU
:AcW7>LLib48008U:@<Q20069BTYBR487>LHaQcW0R4800PYBRDY7>LHaQcW8@PU:BU:1b480bU:00L]
JbDY9BTYBRe[<H`YBP028@P39BT28@P39BT00bU:6<H@Q00224800`aS24848@0612400`Q212448@02
1242248412400`Q212448@031242248512400`aS2488@P0412400`Q21248@P05248236<324803@aS
2488@QS68@Q>Le[FDYA6<Cg_BU9S67>L009[FP08IcUg_G_NG_M:DQcW5:D<H`88@P031248@P@Q0084
8@070008@PQ29BTicRe[6<H00P@Q0PQ200H48@Q21248@P@Q248512401`Q236<@Q1BU6<HQ22U:008m
k`04DYAF]DYBBU82?Nl01C6<;F/Q21S67>L00QS600@LiaBU36<<H`88@P8<H`<8@P031248@PQ2008<
H`0724848@aS48@<Ha245:D00Q2410aS0PQ200<<H`Q236<00PQ210aS0PQ200L<H`Q236<<Ha24:DXa
S003AS4014icBU8mkbe[0QcW0QBU0QS60R4800<LiaS65:D01AS600<LiaS66<H00aS600@LiaS66<HD
Y@<HaP@DY@8HaP045:DHaQcW6<H35:D011cW6<HHaQS60QBU00@HaQBU48@DY@8HaP055:D@Q0aS5:D@
Q0026<H35:D36<H45:D248@35:D01a245:DDYA2436<@Q0aS00<DY@0448@<Ha245:D848@00aBU48@@
Q0026<H011BU48@<H`aS0aBU0a240QBU00<@Q1BU48@00QBU11240`aS00P@Q1S648@<Ha245:D@Q0aS
0Q2400<DYA2448@0112400D<Ha2448@DYA24008<H`D@Q08DY@0548@<H`aS48@DY@0248@010aS48@@
Q0aS0a240PaS00<@Q1BU5:D00aBU0aS600<DY@aS36<0112400D<Ha2448@@Q1BU00@@Q08<H`0348@D
YAS6008DY@0348@DYA24008<H`055:D@Q1245:D@Q00436<548@336<00a245:DDY@0248@02@aS48@D
Y@aS48@DYAS648@<H`012480000300048@@Q00<48@0@0008@P@Q124000Q29BU242e[5:DU:Be[9BTQ
22DY:DX49BT00bU:8@PQ20028@P47>L28@P26<H00aBU6<HLi`048@P29BT37>L01B487>LLiacW8@P0
0Re[00LYBRDY8@PU:BU:9BTQ20099BT01B489BTYBRU:9BT011cW1B4800@U:B488@PLi`8Q20039BTY
BRDY008YBP048@PLiacW9BT38@P012DY:DX]JbDY124800<]JbU:9BT00QcW00DU:BU:9BTLib4800<U
:@8Li`058@PYBRe[9BTLi`038@P00bDY8@PLi`047>L28@P012DY8@PQ22480RU:0RDY00<Q22DY8@P0
1B4800LLib488@PU:BU:8@PLi`038@P012DY8@PLib4811cW0RU:0bDY11cW00@U:BU::DXYBP8U:@8]
J`8YBP037>LQ22DY008U:@088@PLib489BT]JbDY6<HDY@<<H`<8@PH48@88@P041248@PQ224831240
0`Q21248@P0312400`Q21248@P0412400`Q21248@P04124010Q21248@P@Q0PQ200@<H`Q236<8@P8<
H`0J24848@aS24848A247>M:DUkgE[E:DSg_AS5Nmg>LKg][FVLiLiakgV<HBU8LiaS636<48@88@P@4
8@0:24848@@Q8@PmkcF]7>L000@Q36<224871242248010@Q2488@QBU0QS600@Q22DY>Li2409BU09:
DP8mk`03=JdYBR4800HHaP0448@<H`Q2248336<5248436<224801@aS48@DY@aS48@00`aS10Q200<<
H`Q236<00PaS0`Q210aS0a2400TYBS6<BU96<D8@DYA6<CW>:DX00QcW00@DYAS66<HHaP@Li`<HaP04
5:DHaQcW7>L26<H00aBU6<HHaP026<H35:D36<H45:D36<H25:D00aS67>LHaP026<H011BU48@HaQBU
0QS60QBU00LHaQBU48@@Q1BU6<HDY@0248@00aS65:DDY@045:D00aS65:DDY@025:D011245:D@Q1BU
0a240QBU0a240aBU1A240QBU00<@Q1BU5:D00Q240QBU00<@Q1BU5:D00Q2411BU0a2411BU1A2400D<
Ha2436<@Q1BU00<@Q0065:D@Q12436<@Q1BU0a2400@DYA2436<8@P8<H`8@Q00336<@Q0aS008@Q003
5:D@Q12400<@Q00536<@Q12448@DY@0248@236<348@010aS48@@Q1BU0Q2400<DYA245:D00QBU00DH
aQBU48@@Q0Q200D@Q08DY@8@Q0035:D@Q12400@@Q08DY@0348@DYA2400T@Q0@<H`8@Q0<<H`<@Q08<
H`8@Q08DY@0348@<Ha24008@Q04DY@4@Q04<H`0000D48@0012448@0000L48@0;8@Q242e[7>LU:BU:
8@PU:Be[<H`]J`029BT01BU:9BTU:B489BT00R4811cW0aS600@DYAS68@PQ20@Li`039BTQ224800<L
i`038@PU:BU:008YBP<U:@DQ208U:@06:DXU:B489BT]JbU:0R480RU:00HQ21cW8@PYBRDY8@P26<H2
8@P29BT27>L28@P4:DX00bDY7>LLi`027>L01RDY8@PYBRU:9BTQ208Li`059BTQ22487>LQ20039BT7
8@P27>L012DY:DXYBRU:0R480RU:00@U:AcW7>LU:@<Li`8Q20<Li`068@PU:B488@PU:BU:0RDY00<Q
21cW8@P00bDY00<Q22DY:DX00RDY1R480RDY00DQ21cW7>LQ21cW008Q20049BTYBRDY9BT28@P49BT0
2248;F/aS2e[:DXQ22DY;F/29BT2:DX022DY8@PQ21S6:DXaS2U:7>L336<5248612400`Q212448@02
12400`Q212448@0312422482124010002488@PQ210@Q00@8@P@Q12448@88@P041248@P@Q12422480
0`@Q2488@P0236<2248212401248?NmW>Ekg0SW>00A245:DIcUcW09[FP0=HaQcW7NmKg][FS6<6<H<
H`@Q24848@Q200000`@Q00H8@P@Q48@LiaS624821242248312400`Q212448@05124424804PaS6<HL
ibDY7>LU:C6<;F/YBR48:DXe[D8@>Lh]JacW6<HQ208Li`8DY@8@Q00536<8@PQ224848@0524800`aS
2488@P0224800`aS5:DDY@0248@236<3248236<3248736<020Q236<LibDY@Q0mkdHaCW<2AS401Re[
9BTHaQBU7>LHaP<DY@047>LHaQS66<H25:D00aS65:DHaP036<H00aBU6<HLi`027>L35:D26<H25:D0
0a246<HDY@046<H35:D00aS65:DDY@025:D00aS65:DDY@035:D011S65:D@Q1241aBU0QS60QBU00<@
Q1BU5:D011BU00<HaQBU5:D00a2400DDYA245:DHaQBU00D@Q08<H`@@Q0035:D@Q12400DDY@<@Q08D
Y@076<HDYA245:D@Q1BU48@011BU1A2400@<Ha2448@@Q08DY@D@Q0<DY@0348@<H`aS008DY@0648@<
H`aS36<@Q1BU2Q2400<DYA2436<00`aS00D@Q0aS48@@Q0aS008@Q00336<DYABU008DY@0336<@Q1BU
00@DY@0536<8@Q2448@DY@0336<248@00`aS48@DY@0448@45:D<48@236<248@336<00a2436<<H`02
48@00aBU48@@Q00248@236<448@336<000848@0300048@@Q00@48@0700048@@Q8@Q6<Be[6<H00RDY
00HQ22DY:DXaS2e[:DX29BT00bU:9BTQ20027>L28@P47>L011S65:DDYAS60QcW0R4800DLib488@PU
:B48008Li`036<HQ22DY008YBPDU:@058@PU:BDY9BTQ20029BT00b489BTQ20029BT01B489BTYBRU:
9BT00QcW0b480QcW0R4800LU:B487>LQ21cW8@PU:@02:DX29BT27>L01aS67>LU:BDY:DX]JbDY008L
i`039BTYBR48008HaP8U:@8Li`8U:@8Li`068@PU:BDY8@PLib480RU:00<]JbDY8@P00bDY0R480QcW
12480QcW00<HaR489BT00RU:00<U:B489BT01B4800PU:B487>LU:BU:;F/U:B480QcW00@Q22DY9BTQ
208Li`8Q20047>LQ22488@P2:DX29BT012486<HQ22DY0RU:00HU:BU:<H`aS2U:8@P3:DX29BT00bU:
9BTYBP027>L012DY;F/YBR480`aS0PQ200<48@Q224801@@Q0PQ210@Q00<8@P@Q12400P@Q0PQ200P4
8@Q21248@P@Q24848@Q210@Q00<8@P@Q12400P@Q00@8@P@Q12448@<8@P8<H`88@P0K124@Q0Q2124L
icW>HaQNmcg_>Li245:DIcUcW6mkJeYS66mkNmicW6mk<H`Li`Q2124<H`Q200<48@0800048@Q2124@
Q1cW5:D<H`848@0336<48@@Q00@48@0524848@@Q1248@P031242248020aS5:DLib487>LQ22U:;F/3
9BT02CF]AS4mkc6<7>LHaQcW8@PHaP025:D00a2436<8@P0224800`@Q24848@02248336<010Q236<4
8@@Q0PaS0QBU0PaS00H8@PaS2488@P@Q248336<00`Q236<<H`0436<010Q248@HaR480Sg_00Y:DTic
AS5243F]:DXQ21BU6<HDY@8HaP045:DHaQS67>L26<H25:D56<H021cW6<HDYABU6<HLiaS65:D248@0
0aBU6<HHaP045:D00aS65:DHaP025:D26<H35:D00a245:DDY@025:D01QS65:DHaQBU48@DY@8@Q08D
Y@076<HDYABU5:D@Q1BU48@00QBU11S600<DYAS648@00a2400@DYA245:D@Q0<DY@0348@<H`aS00L@
Q0075:D@Q1BU6<HDYAS65:D00a240QBU00H@Q1BU5:D@Q1BU48@65:D248@236<548@00aBU48@DY@02
48@00aS648@@Q00248@00aBU48@@Q00248@336<01A245:D@Q12436<01Q240PaS00D@Q0aS48@@Q1BU
00<<H`0348@DY@aS00D@Q0@DY@8@Q08<H`075:DHaQ2436<8@PaS5:D00Q2400@<Ha2448@DY@8@Q006
248<HaBU48@HaQBU0Q2400@<Ha2448@<H`<@Q00336<8@PQ200<@Q00436<@Q12448@236<448@01aBU
48@@Q0aS48@<Ha24008<H`<@Q04<H`0000@000@Q124000848@030008@P@Q00<48@048@Q6<CF]7>L2
9BT00b48:DXYBP02:DX012DY;F/]JbDY0b4800LU:B487>LLiaS65:DHaP027>L01AS67>LHaQcW8@P0
0RDY00@Q21cW7>LQ208Li`039BTYBRU:008Q208YBP069BTLiacW8@PLib480RDY00@Q22DY8@PU:@<Q
20<U:@8Q20039BTQ22DY00DLi`058@PLib489BTQ2004:DX012DY7>LLiaS60b4800PYBS6<9BTLiaS6
7>LYBRDY0b4800`LiaS6:DXe[C6<9BTLibDY;F/YBRDY8@P29BT02bU:9BTU:B489BTYBR489BTYBRDY
8@P00QcW00<Q22DY9BT00R4800@HaR488@PLi`@U:@<Q20037>LU:BDY008YBP8U:@03;F/YBRDY008L
i`@U:@068@PLiaS66<HLib480bDY00<Q22DY9BT00bDY00<YBRDY8@P00RDY0c6<00<]JbDY:DX00bU:
0RDY0b4800PLibDY9BTYBRe[9BTLi`aS0PQ200H48@Q22488@P@Q248612400`Q212448@0212403`Q2
12448@@Q24848@Q21248@P@Q24848@Q21248@P02124010Q212448@Q21P@Q1`Q20P@Q00TQ24HaIcUB
U2DY:DY6<E:DF]H00fmk00=W>FmkLi`00W>L00<icR4824800P@Q00<8@PaS24801@@Q0PQ21@@Q00<8
@P@Q12401@@Q00<8@P@Q12400`@Q0PQ200d<H`Q236<Lib489BTLia245:DHaQBU6<HDY@026<H00acW
6<HDY@025:D26<H248@00`Q21248@P0324800`@Q2488@P0336<3248010aS48@HaQBU0`Q20`aS00<8
@P@Q24800PQ200<<H`Q248@00PaS00P8@PaS5:DLicg_@Q1:DT8@0SW>00@aS2e[7>LHaP<DY@036<HD
YAS600@HaP057>LHaQS66<HDY@026<H02aBU6<HHaQBU6<HDYAS65:D@Q1BU6<H00QBU0Q2400@DYAS6
6<HLi`8HaP8DY@0448@DYABU6<H348@65:D00a245:DDY@075:D00aS65:DHaP025:D011245:D@Q1BU
0aS600<DYAS65:D01A2400@DYAS65:D@Q0@DY@<@Q0<DY@0648@DYABU5:DHaQBU0Q240QBU0Q2400DD
YA2448@DYA24008HaP0348@DY@aS00@@Q00536<@Q12448@DY@0348@00aBU48@@Q00248@25:D01124
5:D@Q0aS0a240`aS0Q2400@DYA2436<<H`<@Q0<DY@8@Q00336<@Q12400<@Q00436<@Q0aS48@25:D2
6<H011BU48@<H`aS1A240PaS00<@Q1BU48@00PaS00@@Q1BU48@<H`@@Q08DY@0648@DYA245:D@Q1BU
1a240`aS1Q240PaS0Q2400<DYA2448@00a2400<<Ha2448@00PaS0Q240ABU0@aS0@aS000412400`00
12448@021240200012448AcWAS4icR489BT28@P29BT4:DX00be[:DXYBP038@P00bDY8@PLi`025:D0
11cW6<HLiacW0aS600@Q22DY9BTU:@8Li`088@PLib489BTYBRDY8@PU:@8YBP069BTQ22488@PLib48
0bDY0b4800<U:B489BT00bDY00DQ22DY9BTU:B48008Li`<Q208Li`8Q20049BTYBRDY9BT2:DX06248
7>LLiacW9BTLibDY:DXU:B487>LQ22U:9BTLib489BTQ21cW:DXaS3F]:DXQ208YBP099BTQ21cW8@PY
BRDY:DXU:B48008U:@03:DXU:B4800<Q20047>LQ22489BT38@P37>L01BDY:DXYBRU:8@P00QcW00dQ
22DY:DXYBRDY8@PYBRe[:DXQ21S68@PU:@028@P29BT47>L00bDY8@PQ20028@P012DY:DXU:BDY0RU:
0bDY00DYBS6<=Jd]JbU:008U:@8YBPDU:@048@PLib489BT2;F/011cW6<H<H`aS1PQ200D48@Q21244
8@0000P48@0424848@@Q124324801P@Q2488@PQ21248@P848@0524848@@Q24848@02248412422483
36<020Q236<48@@Q6<HmkfLiDY@2:DX00d8@BU9JeP02Kg/3JeX2Li`01WNm?NlU:@Q2124<H`@8@P<4
8@<8@P031248@P@Q00<48@0324848@@Q00L48@0300048@@Q00@8@P0536<Lib489BTLi`0348@26<H2
5:D27>L011S65:D@Q1BU0QS600D@Q0aS12448@Q200<48@P8@P03124@Q1BU008DY@0348@<H`aS008<
H`@8@P8<H`0B248<H`aS36<@Q0aS48@DYAS6>Li244ic@Q0e[Cg_<H`]JacW0QS600<DYAS66<H011S6
00TDYAS68@PLiaS648@DYAcW5:D00QS600<DYAcW6<H00QS611BU00<HaQBU5:D00QBU0aS600@DYAS6
7>LHaP<DY@0348@DYABU00@DY@056<HDYABU5:D@Q0075:D00aS65:DDY@065:D26<H45:D00aS65:DD
Y@0236<01A245:DDYABU48@00QBU00<<Ha2436<00QBU00H@Q1BU5:DHaQBU48@65:D00`aS48@DY@02
5:D248@00aBU6<HDY@0848@01PaS48@@Q1BU6<HDY@8@Q00436<DYA245:D448@25:D00`aS48@<H`02
48@010aS248@Q1BU0Q2400<<Ha2448@0212400<<Ha2448@00Q2400<<Ha2448@00aBU00<HaQBU48@0
1A2400<<Ha2448@01A240PaS0a240PaS0Q240aBU0Q240aBU1Q240`aS00D@Q0aS36<<Ha24008DY@03
48@<H`aS00@@Q00336<@Q0aS008@Q00336<@Q0aS00@@Q04<H`0000<000@Q000010@Q00<8@P@Q1240
0P@Q00@U:Dic<H`HaP8Q20037>LU:Be[008]J`@YBP@Q20039BTLiacW008HaP8Li`038@PLiacW00<Q
20<U:@<Q20@U:@@YBP039BTQ21cW008Q208Li`058@PYBR487>LQ20029BT01B489BTQ22487>L00R48
0RDY0R480QcW12480RDY00LQ22U:=JdaS2DY7>LHaP039BT012U:;F/YBRDY0R480RDY00<Q22DY9BT0
0acW00LU:BU::DXYBRe[:DX]J`049BT2:DX02Re[9BTQ22DY<H`YBR487>LQ22DY0acW00@Q22U:9BTU
:@8Li`048@PU:B488@P39BT01acW6<HLib48:DXU:B48008U:@03;F/YBQcW008Li`048@PYBRU:9BT2
8@P00acW8@PLi`027>L00b48:DXYBP02:DX01Re[:DXYBRU:;F/YBP<U:@8aS003;F/YBRDY008YBPLU
:@03:DXU:B4800<U:@068@PDYA2436<8@PaS0PQ210@Q0PQ21@@Q00<8@P@Q12400`@Q00@8@P@Q1248
@P@48@0324848@Q200<48@0324848@Q200848@<8@P848@88@P<<H`0M48@8@P@Q7>LicTic?NlLib48
>Li244YBF]INmfmkJeYcW6mkF]IF]Be[9BT@Q0@Q36<Libe[9BT@Q002124224800`aS1248@P022484
1242248512400`Q21248@P04124324802A245:DU:BU:7>LDY@aS248@Q00336<348@011BU48@@Q0aS
1@Q20`@Q0`Q20PaS00<8@PaS36<00PaS00<DYA2424800PQ20`aS1PQ20`aS00L@Q1BU5:DHaRDY<Ha2
4002?Nl02D8@=JdaS2DY7>LDYA246<HDY@066<H011BU6<HLiacW0QBU0QS600@LiaS65:DHaP<Li`03
5:D@Q124008DY@046<HDYABU48@35:D26<H00aBU48@@Q0045:D00a245:DDY@025:D01a245:DHaQS6
5:D@Q1BU008HaP<DY@@HaP035:DHaQBU00<DY@0<6<HLiaS65:D@Q1BU6<HDYA245:D@Q1S60QBU00D@
Q1BU5:D@Q1BU008@Q0046<HDYA245:D26<H248@00aBU6<HDY@0248@25:D448@00`aS48@@Q0035:D2
48@25:D648@45:D248@00aBU6<HDY@0348@01aBU48@@Q12436<@Q0aS008@Q0035:D@Q124008@Q005
5:D@Q1BU48@DY@0248@01ABU48@@Q12436<00a2400<DYA245:D00a240aBU00<@Q0aS48@01A240`aS
00D@Q1BU5:D@Q1BU008@Q00336<@Q12400@@Q0035:D@Q1BU00<@Q0045:D@Q0aS36<348@00`aS48@<
H`0548@45:D748@010aS248<H`aS0a240@aS0A240@aS000512400`0012448@0212401P00248U:Dic
>LhLi`<Q2003:DX]Jc6<00DYBP059BTQ22DY9BTQ20056<H27>L28@P27>L38@P79BT5:DX01BDY7>LQ
22489BT00QcW00<Q22DY8@P00QcW00<Q22DY9BT00R4800<Lib489BT02B4800HLib488@PU:B48;F/2
<H`01RDY7>LLib489BTQ20<YBP059BTQ22489BTQ20039BT00b487>LQ20029BT00b48:DX]J`02;F/0
2R489BTU:BDY:DX]JbU:9BTQ22DY0RU:00@U:B488@PU:@8Q20077>LQ22DY9BTQ21cW6<H0124800<U
:B488@P00acW00PU:BU::DXQ22DY;F/YBRDY0QcW0b480RU:00@U:B488@PQ208Li`048@PYBRe[:DX4
9BT00bU:;F/]J`02:DX00bDY;F/]J`03;F/3:DX29BT01248:DXU:BDY0RU:00<U:B488@P00RU:00@U
:ABU5:D<H`88@P051248@PQ224848@022483124010Q212448@@Q0PQ20P@Q00D8@P@Q1248@P@Q0088
@P061248@PQ224848@Q22`@Q00D8@P@Q248<Ha24008<H`848@0J7>Le[Dic>LhLib48=JdmkdYBF]IN
mf]JKg]cW6mkF]IF]C6<:DXDY@Q236<HaRDY8@P@Q0848@D8@P031248@P0000848@0324848@@Q00H4
8@0D24848@@Q1248@P@Q24848@Q236<@Q2DY:DXLiaS6248<Ha2436<@Q08<H`8@Q0045:D@Q12448@2
2482124324800`@Q2488@P0436<00`Q236<8@P0348@236<2248436<00`@Q2488@P0536<248@01AS6
9BT]Jd8@>Lh00T8@00@e[CW>9BTQ208HaP035:DHaQS6008DY@8HaP<Li`@HaP035:DHaQS600<HaP<D
Y@036<HDYABU00<DY@066<HDYAS65:DHaQBU0QS61QBU00H@Q1BU5:DDYAS648@35:D00aS65:D@Q003
5:D01AS65:DHaQBU6<H00QBU0aS60QBU0QS611BU00D@Q1BU48@DYA2400DDY@8@Q0035:D@Q1BU008D
Y@8@Q0035:DHaQS6008DY@036<HDYA24008@Q0035:D@Q124008DY@<@Q08DY@036<H@Q0aS008@Q003
5:DHaQ24008@Q00736<@Q1245:DHaQBU48@00QBU00<@Q1BU5:D00a2400@DY@aS48@DY@8@Q0<<H`<@
Q0056<H@Q12448@DY@0548@00`aS48@@Q00348@00`aS5:D@Q0035:D00a245:D@Q00548@00aBU36<<
H`0236<00aBU48@@Q00248@01`aS48@@Q1BU36<@Q0aS008DY@8@Q0045:D@Q12448@25:D348@011BU
48@<Ha240`aS0Q2400<DYA2448@02A2400<DYA2448@00PaS0a240ABU0A240@Q200001@00124000@Q
00001`@Q00@Licg_<H`Li`<Q208U:@<YBP8U:@058@PLibDY9BTQ20036<H28@P011cW8@PLiaS60acW
0RDY00@YBRDY8@PLi`8Q208U:@038@PU:BU:008U:@LQ20047>LQ22489BT28@P00bDY:DXU:@028@P3
:DX28@P01BU:9BTU:B489BT00b4800TU:BU::DXYBRe[8@PLiaS67>L00RDY00DQ22U:;F/]JbU:00<U
:@038@PLiacW00@Q20059BTYBRDY9BTYBP029BT02b487>LU:BU:;F/U:B489BT]JbU:8@P00QcW00HU
:B488@PQ21cW8@P47>L88@P27>L00aS68@PU:@02:DX012489BTYBRDY0R480RDY00<Lib489BT00RDY
0QcW00XQ21cW6<HLibDY:DXU:B489BTYBP8U:@07:DX]Jbe[:DXU:B48:DX00Re[0RDY0RU:00@U:B48
7>LQ208U:@05:DXU:B489BTQ20027>L29BT011cW48@<Ha240`Q200<48@Q212400`@Q00@8@P@Q1248
@P848@88@P848@0424848@@Q248212401@Q21248@P@Q24800P@Q0`Q20P@Q00@8@P@Q12448@<8@P03
1248@PaS0088@P0436<@Q2489BT27>L021BU6<HU:BU:<H`mkd8@DY@2CW<01TYB?Nm2436<:DXLi`8H
aP8Q20037>L@Q0Q200H8@P848@88@P031248@P@Q00D48@0324848@@Q00@48@0324848@Q200@8@P04
48@HaQBU5:D26<H00aBU36<<H`0236<348@00`aS2488@P022483124224800`@Q2488@P04248636<2
248336<5248020aS248<H`aS48@LibDY;F/3<H`02CF]>Lhe[BU:8@PHaQBU6<HDY@026<H011cW6<HD
YAS60QcW11S61ABU0QS600@DYAS67>LHaP8DY@0448@DYABU6<H35:D011S65:DDYABU0a240QBU00<H
aQBU5:D021BU0aS60QBU00@@Q1BU5:DDY@<HaP0:5:DHaQS65:D@Q1BU6<HLiaS648@:5:D248@25:D0
11S648@@Q1240QBU0Q241aBU00@@Q1BU5:DDY@<@Q0035:D@Q1BU00@DY@0648@DYA245:D@Q1BU1a24
00<DYAS648@00a2400<<Ha2448@00Q2400TDYA2448@<Ha2436<8@PaS48@00QBU1A2400<DYA2448@0
0a2400@<Ha245:D@Q08DY@0348@DYA24008@Q00336<@Q12400H@Q0035:D@Q12400<<H`045:D@Q1BU
5:D348@236<248@01QBU48@@Q1BU48@DY@H@Q00336<@Q0aS008<H`0348@DYA2400<<H`0448@<Ha24
48@25:D336<00a245:D@Q00336<448@236<000X48@090008@R48AS4]JaS68@PU:B48008YBP8]J`<U
:@<Q2003:DXQ21cW008HaP038@PLib48008Li`DQ20<U:@<Li`@U:@03:DXU:BDY008Q20<U:@<Q208L
i`<Q20047>LQ22U:9BT28@P00bDY;F/YBP028@P29BT012U:9BTQ22480RDY12U:00HU:B487>LLib48
9BT28@P01BU:=JdaS2DY7>L00RU:00@Q21S67>LU:@8Li`038@PU:Be[008YBP039BTQ22DY008Q2006
9BTYBRe[9BTLibDY0Re[00<U:AcW7>L00R4800DLib488@PLib4800DLi`<Q20047>LU:B488@P37>L5
9BT00bU:9BTQ20027>L00bDY8@PU:@029BT28@P011cW9BTQ21cW0R4800<YBRDY9BT01BU:00<]Jc6<
;F/00R4800DU:BU:;F/YBRDY008YBP059BTQ22488@PU:@02:DX39BT01acW6<HLibDY:DXQ2124008<
H`<8@P0436<8@PQ21242248512400`Q212448@0412401@Q21248@P@Q24801P@Q00<8@P@Q12401`@Q
0PQ200<48@Q224800PQ20Q240b480aS600<U:BU:<H`00T8@0U:D00U:DTHa@Q1243F];F/Lia246<H0
0R4800HLia242488@PaS248236<00`@Q24848@021243248312400`Q212448@0512400`Q21248@P03
24800`@Q36<<H`0248@01QBU7>LHaQS636<8@P<<H`0648@<H`aS36<48@Q20P@Q1PQ20`aS0`Q200@<
Ha2448@<H`@8@P@<H`88@P8<H`@@Q00:6<HU:C6<<H`YBSF]?NlicSF]8@P27>L36<H25:D56<H011cW
6<HHaQcW0QS600LDYA245:DHaQcW6<HDY@036<H01QBU48@@Q1BU6<HLi`8DY@0648@DYABU5:D@Q1S6
0QBU00@@Q1S65:D@Q08DY@8Li`LDY@066<HDYABU6<HDYA240QBU00<LiaS65:D00QS611BU0QS611BU
0QS60Q240QBU00<HaQ2448@00Q240QBU00H@Q1BU48@DYAS65:D248@02QBU6<HDYABU48@DYA245:D@
Q1BU0a240aBU00@HaQBU48@DY@D@Q08DY@0348@<Ha2400<DY@0636<@Q12448@DYA240PaS00D@Q1S6
48@@Q0aS00<@Q0<<H`0348@DYA24008@Q08DY@8@Q00336<@Q1BU00<@Q0055:D@Q1BU48@DY@0548@0
0`aS48@@Q00448@236<548@010aS48@@Q0aS0a2400HDYA2448@DYA2436<248@00aBU48@@Q00248@0
10aS48@@Q1BU0PaS00H8@PaS5:DDYA245:D348@01ABU48@@Q12436<0112410aS00@@Q1BU48@<H`8@
Q048@P0000P000@Q00048@00124000Q210@Q00DQ248@;F/HaR48008U:@03:DX]JbU:008U:@078@PU
:B487>LQ21cW8@P00acW00DQ21cW7>LQ22DY00@Q20049BTQ22DY8@P47>L01BDY:DXU:B489BT00R48
00DU:BU::DXU:AcW00<Q20049BTQ22487>L38@P00acW8@PYBP05:DX00be[9BTQ20027>L2:DX0136<
:DXU:Be[0R4800<HaQcW7>L00QcW00DU:Be[:DXU:B4800<U:@<Q20047>LQ22DY9BT28@P012DY:DX]
JbU:0QcW0R480RU:1RDY1b480RDY00HQ21cW6<HLib489BT27>L28@P37>L00b489BTU:@02:DX01BDY
8@PQ22DY8@P00QcW00@Q22DY9BTQ208Li`048@PU:B487>L28@P2:DX49BT012U:8@PQ22DY0RU:0RDY
00LQ22U:9BTYBRDY:DX]J`02:DX00bDY8@PQ20029BT2:DX28@P27>L00b487>LQ2002:DX012485:D8
@PaS1@Q20P@Q00D8@P@Q24848@Q200L48@@8@P041248@PQ2000312400`Q212448@0312401PQ21244
8@@Q24848@<8@P0636<8@PaS248<HaBU0Q240PaS00hDYAS67>LQ21cW9BTaS2U:6<H]Jd8@DYA6<BDY
0b4800LU:AcW5:D@Q1S636<8@P0212400`Q21248@P0324800`@Q2488@P02248212400`Q212448@03
124010Q212448@@Q0PQ200<48@Q236<00`Q210aS2@Q20`@Q00<8@PaS248010Q200@<H`Q224848@H8
@P0336<8@PQ20088@P0836<8@PaS248<H`Q25:D@Q08HaP8Q20079BTaS36<=JdaS2U:9BT00QS60QBU
00HHaQ246<HHaQcW6<H25:D26<H00aBU6<HLi`026<H00a245:DHaP076<H00acW5:DDY@025:D011cW
8@PHaQBU0Q2400@DYAS648@@Q08DY@0348@DYABU008HaP035:D@Q1BU008DY@046<HDYAS66<H25:D0
2A245:D@Q1BU48@HaQBU7>LHaP075:D26<H25:D26<H45:D00aS65:DDY@0348@45:D00aS65:DDY@02
5:D00aS65:D@Q00248@01ABU6<HHaQS65:D00PaS0QBU00<@Q1BU5:D00QBU0Q2400DDYA245:D@Q0aS
008@Q0035:D@Q124008DY@<@Q0035:D@Q0aS00D@Q0045:D@Q0aS36<248@336<248@35:D248@25:D2
48@236<021BU48@@Q12436<DYA245:D248@00`aS48@@Q00348@236<011245:D@Q0aS312400@DYA24
48@DY@<@Q0035:D@Q124008@Q0045:D@Q12436<248@00aBU48@<H`0248@01`aS48@@Q12436<@Q0aS
00@@Q0035:D<H`aS008<H`0448@<H`aS36<348@136<000`48@098@PmkbU:6<HQ22U:9BTYBRe[008Y
BP8U:@8Q20037>LHaQcW00DLi`PQ20049BTQ22488@P47>L00bDY8@PU:@029BT27>L01B489BTYBRU:
8@P011cW12480QcW00<Q21cW:DX00Re[00/YBRDY;F/YBRDY8@PHaQcW9BTYBRe[008U:@8YBP078@PL
iacW9BTHaQcW:DX00Re[00TU:B488@PU:BU:9BTQ21cW6<H00R4800@U:B488@PU:@8YBP049BTLib48
8@P39BT28@P29BT012U:8@PHaQcW0RDY0b480RDY00@Q21S67>LLi`<Q20@Li`038@PLib4800@U:@04
8@PU:BDY9BT28@P011cW9BTU:BU:0b4800<Lib487>L00R4800<U:BU:;F/00RDY0R4800HU:B488@PY
BRe[:DX29BT5:DX01BDY:DXYBRDY:DX00b4800HYBRe[9BTLib486<H37>L01B48:DXU:AcW5:D00`aS
10Q20`@Q0`Q21P@Q00<8@P@Q12402@@Q00@8@P@Q12448@88@P@48@0324848@@Q00848@<8@P8<H`03
48@<H`aS00@@Q00=6<HLib488@PU:C6<:DXHaRe[?NmBU4YB:DX00R4800<LibDY7>L00QBU00<@Q0aS
36<00P@Q0PQ200@<H`Q224848@@8@PP48@0424848@@Q12422482124010Q236<@Q0Q20P@Q00<@Q0aS
36<010Q200<<H`Q212400PQ20P@Q00<8@PaS24800PQ200<<H`Q236<00PQ20PaS0`Q20PaS10Q20PaS
00@8@PaS36<8@P8<H`8@Q08HaP8Q2005:DXaS36<=JdaS0029BT00acW6<HDY@026<H25:D01QS67>LL
iaBU6<HDY@DHaP8DY@0348@DYABU00<HaP035:DHaQS600<DY@056<HDYABU5:DHaP025:D248@25:D0
1A2436<@Q1BU6<H00aBU00<HaQBU5:D00Q240QBU00<HaQBU5:D00QBU00D@Q1BU48@HaQBU008HaP09
5:DHaQS66<H@Q1BU48@DYA24008DY@056<HDYABU5:DHaP035:D01AS65:D@Q0aS48@01aBU00@@Q1BU
48@DY@8@Q08DY@8HaP035:D@Q124008@Q0@DY@8@Q0@DY@L@Q0@DY@0348@DYA2400@@Q08<H`@@Q0<<
H`0348@DYA2400D@Q0<HaP065:D@Q1BU48@DY@aS0a2400@DYA2448@@Q08<H`<@Q08DY@0348@<H`aS
008<H`L@Q0055:D@Q0aS36<@Q0025:D348@236<01A245:DDYABU36<03a2400@<Ha2448@DY@D@Q0D<
H`8@Q00336<@Q124008@Q04<H`0000@48@00124000H48@0700048AS6?NlaS248:DX00RDY0RU:0RDY
00LQ21cW8@PLib487>LHaP027>L00b487>LLi`058@P29BT48@P37>L38@P29BT28@P29BT012U:8@PQ
22DY0R480QS6124800<U:AcW7>L00R480RU:0Re[0bU:0QcW00<Q22U:;F/00RU:00<]JbU:9BT00acW
00@HaQcW9BTYBP8]J`049BTQ21cW8@P2:DX01R487>LLib489BTQ208U:@8YBP8Q20047>LQ21S68@P2
:DX00bDY8@PLi`029BT00b487>LLi`029BT28@P00acW8@PQ20047>L28@P47>L28@P27>L01RDY8@PU
:BDY:DXQ208Li`PQ208Li`068@PU:BDY8@PU:B480RDY00<Q22DY9BT00bDY00<YBRDY9BT00RU:00<a
S2e[9BT00R4800<U:C6<;F/00RU:00<U:AcW7>L00R480RU:00DU:B487>LU:BU:00<Q20059BTYBR48
6<HDY@0624841242248010@Q24848@Q20P@Q0`Q20P@Q00<8@P@Q12400P@Q00<8@P@Q12400P@Q00<8
@P@Q12400P@Q00<8@P@Q124010Q20P@Q10aS0PQ200@<H`Q236<<H`8DY@0348@DYAS6008DY@0348@D
YAcW00@Li`066<HDYAS67>LDYA240PQ20P@Q0`Q200@<H`Q224848@<8@P848@<8@P@48@88@P031248
@PQ20088@P848@@8@P031248@PQ200<48@0324848@Q200@8@P041248@PaS48@236<324800`aS2488
@P02248236<4248010aS2488@PQ20`aS00<8@Q245:D00b4800DYBRDY:DXU:BU:00<U:@8Li`@DY@03
48@DYABU00<HaP077>LDYABU5:DHaQcW6<H00QBU00@HaQBU6<HDY@8HaP055:DHaQBU5:D@Q0025:D3
6<H00aBU48@DY@026<H348@25:D01Q245:DDYA245:D@Q08DY@0348@DYABU00<DY@036<HDYABU00@D
Y@0448@DYABU5:D26<H00aBU48@DY@035:D00aS65:DDY@045:D00aS65:DDY@025:D26<H25:D01124
5:DDYABU0a240aBU0Q2400@DYAS66<HDY@8HaP045:D@Q12448@45:D01a245:D@Q1BU6<H@Q0aS008@
Q0035:D@Q124008DY@0648@DYABU5:DHaQBU0Q2400<<HaBU48@0112400D<Ha2448@@Q0aS008@Q006
5:D@Q1BU5:DHaQBU1a2400<DY@aS48@0112400@<Ha2448@@Q0@DY@8<H`045:D@Q12436<248@25:D3
48@01aBU48@@Q1245:D@Q0aS00<@Q0035:D@Q12400T@Q08DY@0348@<H`aS008@Q0055:D@Q12448@<
H`0248@011BU48@@Q0aS0a240`aS1A240@aS0@Q200000`0012448@0212400`0012448@04124011cW
?Nl]Jb480bU:00<U:BU:;F/00R4800DLib488@PLib48008Li`038@PLiacW008Li`039BTQ22DY00HQ
20037>LHaQcW00<Q20067>LQ22488@PLibDY0RU:12480QcW00<HaR487>L0124800PU:B488@PYBRe[
<H`YBRDY0RU:0b480RU:00<U:BU:;F/00RDY0b4800@Lib488@PU:@8aS004:DXLiacW8@P29BT47>L2
9BT01R489BTYBRDY8@PHaP<Li`0@9BTYBRe[8@PHaR48:DXU:AcW6<HLibDY:DXU:B486<H28@P27>L0
0aS68@PQ20028@P00acW6<HLi`027>L00b489BTQ20038@P00bDY8@PQ20027>L26<H012489BTU:BDY
0QcW00HQ22DY9BTU:B487>L39BT38@P01BDY:DXYBRU:9BT012U:00HaS2U:9BTQ22DY:DX2;F/00bDY
8@PLi`038@P2:DX00b487>LQ20029BT00b487>LLi`029BT00b486<HDY@0336<42482124224831242
2485124224800`@Q24848@0312400`Q212448@0312400`Q212448@0412400`Q21248@P05248336<2
24801PaS48@DYABU48@DY@8HaP0348@DYABU00<Li`058@PLiaS65:DHaP035:D224800`@Q2488@P08
24800`@Q2488@P05248512432482124224841244248010@Q00048@@Q0`Q200<48@Q224800PQ200<<
H`Q224801PQ200<<H`Q224800PQ20PaS10Q200@<H`Q2248<H`8@Q0058@PU:BU::DXU:@03:DX29BT0
0b487>LLi`035:D01A245:DDYAS67>L01AS600<DYAS66<H00QS60aBU00LHaQcW7>LLiaS65:DHaP04
5:D26<H65:D00aS648@DY@0248@35:D00aS648@DY@0248@01QBU48@@Q1245:DHaPDDY@046<HDYABU
48@35:D26<H55:D011S67>LHaQBU0Q240aS600<DYA245:D011BU00<@Q1BU48@00a240QBU0a240QBU
00<HaQBU6<H01QBU112400DHaQBU5:DDY@aS00D@Q08DY@8@Q0035:DHaQBU008DY@@@Q00336<@Q124
00<@Q0035:D@Q0aS008@Q0045:D@Q0aS36<25:D011S65:DDYA240aBU00<@Q0aS36<0212400<<Ha24
48@00QBU2a2400@<Ha2448@@Q08DY@0448@<H`aS5:D248@011BU48@DYA240aBU0a2400<HaQ2448@0
0Q2400@DYA2448@8@P8@Q08DY@D@Q08<H`0348@<Ha2400<@Q08<H`@@Q08<H`000P@Q00<000@Q1240
10@Q00T000@Q124HaSg_;F/Q22U:;F/00bDY00HQ22DY8@PLib487>L36<H58@P39BT48@P01acW8@PU
:BDY8@PLiaS600<Q208YBP039BTQ22DY008YBP049BTLib488@P37>L98@P00bDY8@PYBP02<H`012e[
9BTLib480RDY00DYBRDY9BTU:B48008HaP0:7>LU:AcW6<HU:Be[:DXLiaS68@P39BT01RU:9BTQ21cW
8@PU:@HQ208Li`8Q20DU:@048@PLiacW7>L39BT01AcW8@PU:BDY8@P00QcW1B4800<Lib488@P00R48
00HLib487>LU:B489BT28@P27>L01QS68@PQ21cW8@PU:@8Q20037>LQ22DY008U:@8Q20@U:@8Q2005
9BTQ22DY9BTYBP028@P00bDY;F/]J`039BT012U:;F/]JbU:1BDY0RU:00@U:B488@PQ208YBP8U:@03
7>LQ2248008Q208YBP047>LHaPQ236<524800`@Q24848@02124424800`@Q2488@P0412400`Q21248
@P0212400`Q21248@P0712400`Q212448@042482124324800`aS248<H`03248010aS48@DYA242PaS
0Q2400<DYA2436<00P@Q0PQ20Q241PaS0PQ200<48@Q2248010Q210@Q00D8@P@Q24848@Q200<48@<8
@P031248@PQ200848@080008@PQ224848@Q21248@P848@88@P8<H`<8@P0336<8@PQ200<8@P@<H`@8
@P8<H`8@Q00336<HaQcW008aS0<]J`8YBP038@PU:AcW00<HaP@@Q08DY@8HaP<DY@<Li`046<HDYAS6
6<H35:D36<H00aBU6<HDY@0248@36<H00a245:DHaP045:D011S65:DHaQ241ABU00<@Q1BU48@00QBU
00@HaQBU5:D@Q08DY@036<HDYABU00LDY@8HaP035:D@Q12400<DY@<HaP8DY@0348@DYAS600<DY@03
6<HDYAS6008HaP8DY@0348@DYABU00<DY@@@Q08DY@8HaP8DY@8@Q0<DY@0548@<Ha2448@HaP025:D3
48@25:D348@25:D00a245:D@Q0025:D00a245:DDY@0348@01@aS48@@Q12436<02Q2400@DYAS65:DD
Y@D@Q00536<@Q1246<HDY@0248@01@aS48@DYABU36<00Q240QBU00<@Q0aS48@01A2400<DYA246<H0
0a2400@<Ha2448@DY@8@Q0HDY@<@Q08DY@0348@<HaBU008DY@8<H`045:D@Q12436<448@00`aS48@@
Q00348@00`aS48@<H`0236<248@236<348@136<124800005124000@Q1240000712401AcW@Q0aS248
:DX00bDY00<Q22DY8@P01B480QcW00DHaQcW8@PQ21cW008Q208U:@PQ20057>LQ21cW7>LU:@02:DX0
1bDY8@PQ22e[:DXQ21S600@Li`038@PLib48008Q20039BTQ2248008Q208U:@04:DX]Jbe[:DX49BT2
:DX05RDY8@PQ21cW8@PLib487>LHaQcW9BT]JbU:8@PLib489BTQ22DY:DXU:B480QcW1BDY00HQ21cW
6<HLib489BT4:DX01bDY8@PQ21cW8@PU:B48008U:@<Q20@Li`DQ20049BTLiacW6<H48@P01RDY:DXU
:B487>LHaP8Li`HQ20079BTQ22489BTYBRDY8@P00RDY00HYBRDY9BTQ22DY8@P3:DX00bDY8@PYBP03
;F/012489BTYBRe[0S6<0bDY00@Q22U::DXU:@8Q20079BTQ22DY9BTYBRDY8@P00QcW00HQ22DY<H`Y
BQcW48@2248236<01@Q21248@P@Q24800P@Q00<8@P@Q24801@@Q0PQ20`@Q00<8@P@Q12400P@Q00<8
@P@Q12401P@Q0PQ21@@Q00<8@P@Q24800PQ200<<H`Q212400PQ200<<Ha2448@00Q2400<<Ha2436<0
20aS0a2400D<H`Q224848@Q2008<H`8@Q08<H`D8@P051248@P@Q24848@05248312400`Q21248@P02
24800`@Q24848@022487124010Q21248@P@Q0`Q200D<H`Q22488@P@Q00<8@P8<H`H8@P0336<8@PaS
00<8@P0:36<@Q1246<HQ22U:<H`]Jc6<;F/3:DX00b486<HHaP035:D348@01QS65:DHaQBU6<HDY@8H
aP8Li`056<HDYABU6<HDY@066<H25:D01A245:D@Q1S65:D00QS611BU00HHaQBU6<H@Q1BU48@25:D2
48@35:D00a245:DDY@035:D011245:DHaQS60QBU00@@Q1S66<HHaP<DY@036<HDYA24008DY@036<HD
YABU00<HaP0348@DYAS600@DY@@HaP<@Q0045:DHaQBU5:D548@011BU48@DYABU0QS611BU00<@Q1BU
48@00Q240aBU0a2411BU11241ABU00@HaQ2448@@Q08<H`8@Q0035:D@Q12400P@Q0035:D@Q1BU00<D
Y@8@Q00336<@Q1BU008<H`0948@DYA245:D@Q1S648@<Ha24008DY@/@Q08DY@P@Q0045:DHaQ2448@2
5:D00aS648@DY@035:D236<01ABU48@DYA245:D00Q240PaS00D@Q1BU5:D@Q0aS00@@Q00636<@Q124
36<@Q0aS112400D<Ha2448@@Q0aS0048@P0000<000@Q12400P@Q00<000@Q124010@Q00LLicg_<H`Q
22DY:DXU:@03:DX012487>LLib480QcW0QS60QcW00<Q21cW9BT00bDY124800@Lib487>LLi`8U:@04
8@PU:BDY9BT38@P01RDY:DXYBR487>LHaPDLi`048@PU:BU:9BT27>L38@P29BT012U:<H`]Jbe[12DY
00@Q22DY9BTQ20<Li`038@PLiacW00<U:@038@PLiacW008Q20<U:@037>LQ2248008YBP@U:@8Q208L
i`036<HU:BU:008YBP8Q20039BTQ224800<Li`058@PU:B487>LU:@027>L01AS67>LQ22487>L00R48
0RDY00DQ21cW6<HLib48008U:@03:DXQ21cW008HaP057>LQ21cW8@PU:@038@P27>L01B489BTU:B48
9BT00bU:0RDY0R480RDY00@Q22DY9BTQ208U:@03;F/YBR48008U:@04;F/aS2U::DX28@P00bDY:DXY
BP02:DX00b489BTQ20089BT021cW8@PQ22DY;F/YBQcW6<H336<010Q21248@PQ20`@Q00D8@P@Q2484
8@Q200@48@0524848@Q21248@P061243248612422484124824800`@Q248<H`0336<2248336<22480
0`aS2488@P03248312400`aS248@Q0035:D336<224800`@Q24848@031243248412432482124010Q2
1248@P@Q1@Q220@Q00<8@P@Q12400PQ200D<H`Q224848@Q200848@0536<8@Q2448@<H`0424801@aS
2488@PQ248@00QS600D@Q1cW9BTe[Be[008U:@06:DXU:BDY7>LQ21S60QBU00<HaQBU5:D00Q240aBU
0aS600<DYAS67>L00QS600<DYAS65:D021S60QBU00<@Q1BU5:D00QBU00<HaQBU5:D00QBU00<LiaS6
48@01ABU0QS60aBU00<HaQBU5:D011240QBU0QS600<DYAS65:D01Q240QBU00<HaQBU5:D01QBU0Q24
0QBU00<HaQBU5:D00QS600HDYA2448@HaQBU48@45:D448@25:D011S65:DDYAS60QBU1Q240aBU1124
0aBU00<@Q0aS5:D00aBU11240QBU1Q240PaS00<@Q1BU48@00Q240PaS0Q240QBU0a2400<DYA2448@0
0Q240QBU11240aBU00<@Q0aS5:D00Q2400<<Ha2448@00a2400<DYA2436<00Q240QBU00L@Q0aS36<@
Q1BU48@DY@0248@25:D26<H55:D248@01ABU48@@Q0aS48@00QBU0`aS00<DYA2448@01a240PaS00@@
Q0aS48@@Q0<<H`0348@<Ha2400<<H`000`@Q00<000@Q12400`@Q00L000@Q124HaT8@<H`Q20039BT2
:DX022DY8@PQ22487>LQ21cW6<H47>L38@P39BT01B487>LQ22U:8@P00acW0RDY0R4800<U:AcW8@P0
0R480RU:0R480QS60QcW00DQ21cW7>LQ22U:008Q208Li`@Q2005:DX]Jc6<;F/U:@02:DX042487>LL
ibDY:DXU:AcW8@PLiaS67>LQ22U:9BTQ21S60acW00<Q22DY8@P00QcW00<U:BU:9BT00R4800<YBRDY
9BT00acW00DQ22U:;F/YBRDY008Q20039BTLiacW008Li`059BTQ22489BTQ20037>L01R487>LQ2248
9BTQ208Li`058@PU:B487>LHaP028@P29BT00b487>LHaP026<H00acW8@PU:@028@P00bDY8@PQ2002
8@P00bDY8@PU:@029BT3:DX01bDY8@PU:BDY8@PU:B4800<U:@8YBP@U:@8aS005;F/YBR488@PU:@02
:DX01bDY8@PQ22DY8@PU:B4800@U:@0::DXU:B487>LQ22DY<H`]JacW6<H4248236<010Q212448@@Q
0PQ20`@Q0PQ200<48@Q212400`@Q00<000@Q12400P@Q0PQ20`@Q00<8@P@Q124010@Q0`Q200<48@Q2
12400`@Q1`Q20`aS00<@Q0aS24800PQ200<<H`@Q12401PQ200D48@Q22488@Q24008HaP035:D<H`aS
008<H`88@P031248@P@Q00<8@P848@88@P<48@0424848@Q2248312400`Q212448@03248010@Q0004
8@Q21@@Q00<8@P@Q124010Q20`@Q10Q20PaS0`Q200/<H`Q236<48@Q236<@Q1S65:DLibU:008aS005
9BTYBRU::DXQ20027>L25:D26<H01ABU36<<HaBU6<H00QBU00D@Q1BU6<HHaR48008Li`036<HDYABU
00HDY@036<HDYABU008DY@036<HDYAS6008HaP0448@DYABU6<H25:D011S67>LDYA240QBU00<LiaS6
5:D00a240QBU0Q2400HDYA2448@HaQcW6<H55:D548@00aS65:DDY@025:D36<H011BU48@DYA240QBU
00<HaQBU48@00QBU00<HaQBU5:D00QBU00D@Q1BU48@@Q1BU00<@Q08DY@036<HDYA2400@DY@<@Q003
5:D@Q0aS008@Q08DY@@@Q0035:D@Q1BU008@Q0<DY@0448@<Ha245:D>48@236<548@45:D348@336<0
0a245:DHaP0448@00aBU36<@Q00248@236<25:D00a2436<@Q00248@010aS48@@Q1BU0Q2400D<Ha24
48@@Q1BU00@@Q0HDY@066<H@Q12436<@Q1BU11240`aS0Q240QBU00@@Q0aS48@DY@8@Q00436<@Q124
36<248@336<248@011BU48@@Q0aS0@Q20000200012448@@Q00048@00248212401`00124Q23g_;F/L
ibDY00<YBP07<H`]Jb487>LDYAS67>L00R480QcW00LQ22DY7>LQ22U:;F/YBP028@P00bDY7>LLi`02
8@P2;F/012DY:DXQ21cW0RDY00PYBRDY9BTQ22DY8@PHaQcW0RDY00HQ21cW8@PYBRDY8@P37>L00b48
9BTU:@039BT2:DX2<H`2;F/29BT00acW6<HLi`028@P011cW6<HHaRDY0RU:00HQ21S66<HLib487>L4
8@P29BT3:DX00b486<HLi`038@P00bDY:DXU:@038@P3:DX28@P011S68@PQ22480RDY0b4800<Lib48
7>L00R480bDY0R4800HLib487>LLib48:DX29BT02acW6<HLiacW9BTQ21S67>LQ22DY8@P00QcW0R48
00<U:BU::DX00RU:0RDY1R480bDY00HQ22DY9BTU:B487>L2:DX01Re[:DXLib48:DXU:@8YBP069BTL
iacW7>LQ22U:0R480RDY0R480RU:00XU:AcW6<HLibDY:DXU:B485:D@Q0@<H`@8@P848@0324848@@Q
00848@0324848@@Q0088@P@48@0824848@@Q1248@P@Q24848@88@P848@0324848@@Q00848@042484
8@Q2124524821243248010@Q2488@PaS0P@Q0`Q20P@Q0`Q200X48@Q224848@Q236<DYAcW6<HDY@8<
H`0348@<H`@Q00848@@8@P061248@PQ21248@P@Q0PQ200@48@Q212448@<8@P@48@@8@P848@<8@P03
1248@PQ200<8@P8<H`88@P031248@P@Q0088@P0536<8@PaS36<8@P0236<224800`aS48@DY@036<H2
7>L58@P27>L45:D011245:D@Q1240QBU00<HaQBU5:D00QBU0QS60QcW0QBU00@@Q1BU6<HDY@<HaP/D
Y@066<HDYABU48@DYAS60QBU00<@Q1BU5:D00QBU00<HaQBU5:D01aBU0QS600<@Q1BU5:D01QBU00@@
Q0aS48@@Q0HDY@046<HDYAS65:D248@25:D00a245:DHaP026<H35:D448@25:D011245:D@Q12411BU
0aS60QBU0Q2400<<Ha2436<00Q240QBU3Q2400<DYA2448@00aBU00D@Q1BU48@@Q0aS008@Q08DY@8@
Q00436<@Q1BU48@45:D448@00aBU48@DY@0448@00aBU48@@Q0035:D01AS648@@Q0aS48@00QBU00@@
Q0aS36<<H`H@Q0<DY@8@Q0045:D@Q12448@85:D348@35:D248@00`aS48@@Q00548@00`aS48@@Q002
5:D01@aS248<Ha245:D01Q2400<<Ha2436<00Q240@aS0@Q2000212400`0012448@0712401R48@Q0]
JacW9BT]J`8U:@05:DXaS2U:7>LDY@037>L48@P27>L01BDY:DX]Jbe[9BT01R4800LYBRe[;F/U:AcW
8@PU:@03:DX28@P02BDY7>LLiacW8@PU:B487>LQ20029BT78@P29BT01RU:9BT]Jbe[<H`]J`<U:@03
8@PLiacW008Q20@Li`8U:@048@PLiaS66<H47>L48@P00bDY:DXU:@028@P47>L28@P01Be[:DXYBRDY
8@P012DY00LQ21cW7>LQ22U:9BTQ20037>L28@P00acW8@PQ20029BT00b487>LLi`028@P27>L00b48
9BTU:@037>L48@P00acW8@PQ20048@P89BT012489BTQ22481bDY00/YBRDY7>LLib48;F/aS2e[9BTQ
22DY008YBP8U:@048@PLib489BT38@P012DY:DXU:BDY0RU:00PU:AcW6<HLibU:9BTYBRDY0QBU00<<
H`Q236<010Q20P@Q00<8@P@Q24800P@Q00<8@P@Q12401`@Q00P8@P@Q1248@P@Q24848@Q20P@Q00@8
@P@Q1248@P848@0324848@Q200@48@D8@P071248@P@Q24848@Q212400PQ20`@Q0PQ200<48@Q21240
10@Q00<<H`Q248@00QcW00<HaPaS36<00PaS00@8@P@Q2488@P<48@88@P<48@0324848@@Q00D48@04
24848@Q2124324800`@Q24848@0424831243248236<8248236<00`Q236<<H`0324800`aS48@@Q002
5:D27>L68@P01AcW8@PLiacW6<H00aBU00L@Q1BU5:DDYAS65:D@Q0025:D26<H27>L26<H01AcW6<HD
YA245:D00QcW00<HaQBU6<H01QBU0QS60aBU00<@Q1BU5:D0112400@DYAS67>LHaP8DY@0448@DYA24
5:D248@45:D01aS65:DDYAS65:DHaQBU00<@Q0035:D@Q124008DY@8@Q0PDY@0448@DYABU6<H25:D2
6<H00aBU48@DY@025:D00a245:DDY@0248@010aS48@DYAS60aBU0aS600@DY@aS48@<H`<@Q0@DY@8<
H`<@Q08DY@0548@<H`aS48@DY@0348@55:D<48@236<00a245:DDY@0248@236<248@00aBU48@@Q007
48@00aBU48@@Q00348@25:D648@00`aS48@@Q0035:D00a2436<@Q00748@00aBU6<HHaP025:D248@0
1ABU48@DYA245:D01A240PaS00D@Q1BU48@@Q0aS008@Q0065:D@Q12436<@Q1BU1a240`aS0@Q20@aS
0@Q200001@@Q00048@@Q00001P@Q00L8@RDYBU8e[AS68@PYBP02;F/00bU:8@PLi`037>L38@P022DY
8@PLib48:DXaS2e[9BT38@P29BT00b489BTU:@02:DX00bDY:DXU:@028@P39BT48@P011cW8@PU:BU:
0RDY00DQ22DY9BTU:B48008Li`<Q208U:@8YBP8]J`05:DXU:BDY8@PU:@026<H06QcW9BTU:AcW6<HU
:BU:9BTQ21S67>LHaQcW8@PU:B486<HLibDY<H`YBQcW8@PU:B487>L26<H011cW8@PYBRU:0R4800@L
ib489BTU:@8Q20039BTQ22DY00<Q20039BTQ21cW008Li`058@PU:BDY9BTYBP029BT01AcW8@PLiaS6
9BT00RU:00<U:AcW7>L01B4800LLiaS67>LQ22U:9BTLi`028@P6:DX01BDY7>LQ22DY:DX00R480RDY
1B480RDY00@Q22U::DX]J`<YBP8U:@05:DXU:BDY8@PU:@038@P00acW9BTQ2002:DX39BT01B489BTU
:BDY8@P00QcW0bDY00DHaQ2436<<Ha24008<H`0324848@Q200<48@0324848@Q200848@0300048@@Q
0088@PD48@0524848@@Q1248@P0612401`Q21248@PQ2124000@Q00@8@P@48@0324848@@Q00@48@04
24848@Q2124524800`@Q24848@02248248@00`aS48@@Q00236<224841247248010@Q24848@Q20P@Q
10Q200<000@Q12401@Q200@48@Q224848@88@P071248@PQ2248<Ha2436<01`Q200H48@Q236<8@PaS
248236<02A245:DHaQcW6<HLiaS67>LHaP037>L26<H35:D348@26<H35:D00a245:DDY@035:D36<H2
5:D00a246<HHaP026<H25:D36<H00aBU48@DY@036<H01ABU48@DYABU6<H00QBU00P@Q1BU5:DDYAS6
5:DHaQBU11241aBU00@@Q1BU48@@Q08DY@036<HDYA24008DY@8@Q08DY@8@Q0<DY@8@Q0<DY@8@Q08D
Y@0848@HaQBU6<HDYA245:DHaP<@Q0035:D@Q12400<DY@8@Q0045:DHaQBU5:D36<H01ABU48@@Q0aS
48@011BU00<@Q1S65:D00Q240PaS0Q2400<DYA245:D00Q2400<DYA2448@0112400HDYA2448@@Q1S6
48@236<448@010Q248@DYAS60QBU00<@Q1BU48@01a2400<DYA2448@011240QBU00D@Q0aS48@DYAS6
00<@Q08DY@<@Q0<DY@H@Q00436<@Q1245:D26<H01ABU48@DYA245:D0112400<DYA245:D01Q2400DD
YA245:D@Q0aS00<DY@0348@<Ha2400@@Q0035:D@Q0aS008<H`8@Q00336<@Q0aS0048@P000`@Q00<0
00@Q12400`@Q00P000@Q124Q24Ha<H`LibDY12U:00<Q21cW7>L00QcW0RDY00@Q21cW7>LLi`8U:@03
:DX]JbU:008Q20037>LU:B48008Q20039BTYBRe[008U:@048@PLib489BT2:DX00bDY8@PLi`027>L0
0b487>LLi`039BT28@P00bDY8@PQ20027>L39BT01B489BTYBRU:;F/00RU:00TU:AcW8@PLiaBU7>LQ
22DY6<H00QcW0RU:00<Q21cW6<H00QcW0R4800LLiaBU8@PU:C6<:DXQ20029BT28@P26<H011cW9BTY
BRDY1R4800<U:B488@P00R4800@Lib488@PU:@8Li`036<HLibDY008Q20049BTYBRU:8@P27>L26<H0
12DY:DX]JbU:0QcW00HQ21cW8@PLib487>L78@P29BT5:DX00bDY7>LQ20039BT01AcW8@PU:BDY8@P0
12DY00/Q21cW:DX]Jc6<:DXQ22DY:DX]JbU:00<Q20<U:@047>LQ22489BT2:DX58@P01BDY8@PQ21cW
8@P00bDY00HDY@aS36<8@Q2436<4248612400`Q212448@03124224841242248312401@Q212448@@Q
24801P@Q0PQ200<48@Q224800PQ20P@Q00<8@P@Q00000P@Q00<8@P@Q12400PQ20`@Q00D8@PaS2484
8@Q200848@88@P0336<@Q12400H<H`88@P031248@PQ200@8@P<48@88@P031248@PQ200<8@P<48@05
24848@Q224848@0324800`@Q2488@P05248236<4248010aS2488@PQ20PaS00@8@PaS2488@P8<H`8D
Y@8HaP8Li`<HaP047>LQ21cW6<H25:D011S65:D@Q12411BU00<HaQBU5:D00QBU00<HaQBU5:D011S6
1ABU00PHaQBU5:DHaQBU6<HDYA240QBU00@HaQBU5:DHaP8DY@0348@DYA2400XDY@0348@DYA24008D
Y@0348@DYABU008HaP045:D@Q1245:D26<H00aBU48@@Q0025:D00aS65:D@Q00448@45:D00a245:DD
Y@025:D01AS65:D@Q1245:D00aS60Q2400D<Ha2448@@Q1BU00<@Q08DY@<@Q0035:DHaQS6008DY@03
36<@Q124008DY@0448@DYABU5:D248@01ABU48@<Ha2436<00Q2400HDYA2448@@Q0aS48@25:D01124
36<@Q1BU0Q2400DDYA2448@@Q0aS00<@Q00336<@Q124008@Q0035:D@Q12400D@Q0055:D@Q1BU5:D@
Q0025:D348@25:D348@25:D02Q245:D@Q0aS5:D@Q1BU48@<Ha240aBU00<<Ha2448@01Q2400DDYAS6
6<HDYA24008DY@<@Q0035:D@Q12400D@Q08DY@@@Q0075:D@Q12448@<Ha2436<00a2400<DYA2436<0
0a240PaS0Q240@aS0@Q200000`0012448@0212400`001248@P0412401BDYBU8aS1cW:DX00Re[0bDY
0acW00<Q22DY9BT00RDY0R480bU:00@U:B488@PU:@8Q20039BTYBRe[00<YBP049BTQ22489BT2:DX2
9BT00b486<HLi`039BT28@P39BT012487>LQ22DY0RU:00<U:B48:DX00RDY00<Q22DY8@P00QcW1248
0QcW00<HaR488@P00R480RU:00<Q21cW6<H00acW0aS600@Lib488@PQ208U:@8Li`045:DHaQS67>L5
8@P00bU:9BTQ20028@P01RDY8@PQ21cW8@PU:@8Q20047>LQ22489BT28@P012DY:DXU:B4811cW0R48
00<Lib488@P00b4800PU:B488@PQ21cW8@PHaQcW0b4800<U:B48:DX00RU:00DaS2e[9BTU:AcW008U
:@098@PU:BDY;F/YBRDY8@PU:B48008U:@048@PU:BU::DX39BT2:DX2;F/01BU:9BTU:B489BT00b48
00<Lib488@P00RU:00<U:B488@P00R480bU:00LU:AcW8@PYBRe[9BTHaP0236<00a2436<<H`0236<2
24800`@Q24848@022489124010Q212448@@Q0PQ200@48@001248@P@48@88@P848@0424848@@Q2482
12400`Q21248@P0712422482124010Q236<<H`Q20PaS00H8@P@Q12448@aS248336<01P@Q248<HaBU
6<H@Q088@P@48@<8@P<48@0324848@Q200848@03248<H`Q200@48@05248<H`Q224848@03248010@Q
248<H`aS0PQ200L<H`Q236<8@P@Q248<H`03248336<224800`aS48@DY@035:D26<H25:D26<H00acW
6<HDY@025:D26<H00aBU48@@Q0025:D01AS65:DDYABU6<H00QBU00@@Q1S66<HHaP<@Q0045:DHaQS6
5:D26<H00aBU6<HDY@045:D00aS65:D@Q0025:D26<H25:D248@25:D26<H011BU48@HaQBU0Q240QS6
00<DYA2436<00QBU0QS600<DYA2448@01aBU0Q240aBU0Q240QBU0a240QBU00<HaQBU5:D01ABU00<@
Q1BU5:D00QBU00D<Ha2448@@Q1BU008@Q0<DY@0348@DYABU008DY@0448@HaQBU6<H248@00`aS48@@
Q0035:D00a245:DDY@035:D248@00aBU48@DY@025:D348@01ABU48@DYA245:D0112400@DYA245:D<
H`8@Q0045:D@Q0aS48@35:D248@236<248@25:D01Q245:DDYA245:D@Q0<DY@0348@<Ha24008DY@8@
Q08DY@0448@<Ha2448@25:D00a245:DDY@0248@00`aS48@<H`0248@011BU48@@Q12411BU0Q2400<D
YA245:D00Q240aBU1A240aBU0Q240PaS00@@Q1BU5:DDY@P@Q0<<H`@@Q04<H`48@P0000D48@001244
8@0000L48@078@Q>LcW>7>LU:BU:9BT00RU:00HU:B487>LLib489BT2:DX29BT01B489BT]JbU:9BT0
0R4800HU:AcW7>LLib48;F/2:DX00bDY8@PQ20028@P00bU:9BTU:@038@P27>L00b489BTU:@028@P0
0bDY8@PU:@028@P39BT021cW9BTYBRDY8@PLib489BT37>L28@P00aS67>LLi`047>L012DY;F/YBR48
0aS60QcW00DHaQBU5:DLibDY008Q2005:DXU:B486<HDY@026<H011cW8@PQ22480RDY0R480RDY1248
00@U:B488@PQ208U:@058@PLiacW8@PYBP049BT27>L38@P27>L01bDY:DXU:B487>LQ22DY008Q2003
7>LHaQcW008Q20039BTQ2248008U:@06:DX]JbU::DXU:B4812DY00DQ22U::DXYBR48008U:@<Q2003
9BTYBRDY008U:@8YBP8]J`03:DX]JbU:00@U:@8Q20047>LQ22488@P29BT022U:9BTQ21cW8@PU:BU:
9BT38@P012U:;F/Q21cW0a240PaS00<8@PaS36<00PQ200<48@Q236<010@Q0PQ21`@Q00@8@P@Q1244
8@88@P031248@P@Q00D48@0524848@@Q24848@0224800`@Q24848@0412400`Q212448@0312400`Q2
1248@P0236<224800`@Q2488@P04248020aS2488@PQ248@DYAS636<3248212422484124324831244
2482124524800`@Q2488@P0324821243248236<3248010@Q36<8@PaS0`Q200D<H`Q236<@Q1BU008H
aP055:D@Q1BU6<HLi`025:D01QcW6<HHaQ245:DHaP8DY@0348@DYA2400@DY@036<HDYAS6008DY@04
48@DYAS66<H95:D011S65:DHaQ240aBU00<@Q1BU5:D00QBU00DHaQBU5:DDYA2400<DY@046<HDYAS6
6<H25:D548@011BU6<HDYA2411BU00@@Q0aS5:DDY@8Li`@@Q0036<HDYA24008@Q0045:D@Q12448@2
5:D01A2436<@Q1246<H00QBU00D@Q1BU6<HHaQBU00<@Q0045:D@Q1BU5:D248@65:D02AS65:DDYABU
48@DYA245:D@Q0065:D011245:DDYABU0Q2400H<Ha2448@@Q1BU6<H248@010aS48@DYABU0Q2400DD
YA245:D@Q1BU00<@Q0035:D@Q0aS008<H`065:DHaQS65:D@Q0aS0a2400HDYA245:DDYA246<H25:D0
112436<@Q1BU112400<DYAS66<H0112400@DYA2448@@Q08DY@8@Q0065:D@Q0aS36<@Q1BU11241ABU
0Q2400D<Ha2448@HaQBU00@@Q00436<@Q1245:D248@01@aS48@@Q1245:D01a2400D<Ha2448@DYA24
00<<H`0348@<Ha240048@P000P@Q00<000@Q12401@@Q00L000Q28@Q:DSF]8@PYBP03;F/00bU:9BTL
i`028@P00bDY;F/aS0029BT01B489BTYBRU:9BT01R4800@U:BU::DXYBP<U:@07:DXU:B487>LU:Be[
9BT00QS600@Q22DY8@PLi`<U:@048@PU:Be[9BT28@P00bDY:DXU:@038@P39BT47>L02B487>LLiaBU
6<HLiaS68@PU:@028@P00aS67>LLi`027>L26<H00acW6<HU:@039BT28@P031cW6<HHaQcW8@PLiaS6
7>LQ22DY8@PU:@8YBP039BTQ2248008Q20039BTQ224800DQ20DU:@038@PU:B4800<Li`<Q200;7>LQ
21cW6<HLib489BTYBRDY7>LQ20027>L02B489BTQ22489BTYBSF]<H`]J`039BT01BU:9BTU:BDY:DX0
0Re[0RU:0bDY00@Q22DY8@PU:@<YBP8U:@8YBP06;F/YBRU::DX]Jc6<0RU:0acW124800HU:BU::DXU
:B487>L28@P79BT012U:9BTQ22480QBU00H<H`Q22488@PaS24821245248212432489124324841240
0`Q212448@03248412401@Q212448@@Q248010@Q00<8@P@Q24800`Q20PaS00@8@PaS36<<H`848@0<
248<H`Q224848@Q248@DYA2436<8@PaS0PQ20P@Q1`Q200@48@Q212448@<<H`0324848@@Q00848@H8
@P031248@PaS00<8@P8<H`@8@P0336<8@PQ2008<H`0448@<H`aS36<248@01`aS48@DYAS67>LHaQ24
008DY@8HaP085:D@Q1245:D@Q1BU48@DY@8@Q08DY@046<HDYA2448@25:D00aS65:DDY@085:D36<H0
11cW5:DDYA241ABU00<@Q1BU5:D00QS61ABU00<@Q1BU5:D00QS60QBU00D@Q1BU5:DDYA2400<DY@06
6<HDYA245:D@Q0aS0Q2400<DYAS65:D00a240QBU0a240QBU0a2400<HaQBU48@00Q2400DDYAS66<H@
Q1BU008@Q08DY@036<HDYA24008@Q0035:D@Q124008DY@096<HDYABU5:DHaQBU48@DYA24008DY@03
48@DYA2400<DY@0548@DYAS66<HDY@0248@00aBU48@@Q00348@00aBU48@@Q0025:D26<H348@00`aS
48@DY@025:D01A2436<@Q1245:D01A240aBU0PaS00<@Q1BU48@01ABU00<@Q1BU48@00QBU0Q240QBU
112400<DYAS65:D00a240aBU2Q241aBU0Q2400<DYA2448@00Q2400DDYA2448@@Q1BU00P@Q0055:D<
Ha2448@HaP025:D00a245:D@Q0035:D548@00`aS48@<H`0236<0000300048@@Q00848@0300048@@Q
00@48@049BU>LcF]8@P3;F/2:DX01R487>LLib489BT]J`8YBP058@PU:BU:;F/YBP038@P011cW8@PQ
22480RDY00<YBRDY9BT012DY0R4800<U:BU:8@P00QcW00@Q22U:8@PQ208U:@8Q20039BT]JbU:00<Q
208U:@038@PLib48008U:@048@PLib489BT28@P00aS65:DHaP037>L00b489BTU:@057>L01AS65:DL
iaS67>L00R480RDY0R480QcW0aS60QcW0b4800<LibDY:DX00RU:00@Q21cW8@PU:@8YBP069BTLib48
8@PLib4812DY00DQ22DY7>LQ21S600<Li`038@PLiacW00<Li`8Q20@U:@038@PLib48008Li`8U:@8Y
BP03;F/aS2e[008YBP038@PU:BU:008YBP039BTYBRDY00<YBP039BTQ2248008U:@<Q20049BTYBRU:
;F/2:DX29BT01BU:<H`aS36<9BT00QcW0R480QcW00LQ22U:9BTU:B487>LU:@028@P29BT38@P022DY
:DXU:BDY:DXQ21cW48@436<4248212401@Q212448@@Q24800`@Q00<8@P@Q12400P@Q00<8@P@Q1240
0P@Q00<8@P@Q12400`@Q0PQ210@Q00@8@P@Q12448@<8@P<48@<8@P<48@04248<H`aS248336<010Q2
1248@PQ20P@Q10Q200<<Ha2448@00`aS00<8@P@Q124010Q20P@Q00<8@PaS24800`@Q00<8@PaS36<0
0`Q200<48@Q224800`Q200D48@Q22488@P@Q00<8@P041248@PQ2248236<01`Q236<<H`Q236<8@Q24
008<H`8@Q0035:D@Q1BU008DY@046<HDYA2448@36<H448@011BU6<HDYABU0PaS00<@Q1S66<H00QBU
00<@Q1BU5:D01ABU0Q2400HDYAS65:DHaQBU6<H25:D02A245:DDYABU6<HDYA245:D@Q0055:D01QS6
48@@Q1BU6<HLi`8DY@086<H@Q0aS36<@Q1S65:D@Q08DY@8@Q0@DY@8@Q0045:DHaQcW5:D248@25:D2
48@35:D01A2436<@Q1245:D00a240QBU0a240QBU0QS600D@Q1BU36<<HaBU008@Q08DY@@@Q0@DY@06
48@DYA2448@DYA240aBU0Q2400<DYAS65:D011241ABU00@@Q1BU48@@Q0@DY@<@Q0<DY@0348@<Ha24
00@@Q00336<@Q124008DY@8@Q0045:D@Q12448@25:D01a245:DLiaBU48@<Ha2400<DY@8HaP@@Q0@D
Y@0348@DYA2400D@Q00436<@Q1245:D336<35:D348@35:D248@00aBU48@DY@0248@00`aS48@@Q002
48@00`aS48@@Q00648@00aBU48@DY@025:D548@01ABU48@@Q1245:D00a240PaS0@Q200001@@Q0004
8@@Q00000P@Q00<8@P@Q12400P@Q00@U:DYB>LhU:@8aS005;F/U:BDY:DXQ20029BT00bU:;F/YBP02
:DX012DY:DXU:BDY0R4800<U:B488@P00R480RDY00@YBRe[9BTU:@8Q20059BTQ21cW7>LQ20027>L0
11S67>LQ22DY12480RU:00HU:B489BTU:B489BT28@P02AS68@PQ22DY8@PLibDY:DXQ20025:D27>L0
1AS67>LLibDY:DX00R480aS600DDYAS66<HDYB48008U:@038@PLib48008Q20057>LHaQcW6<HLi`02
8@P01BDY7>LLiacW9BT00RU:00LQ21S68@PYBR487>LQ2002:DX28@P00bU:9BTU:@028@P022U:9BTQ
22487>LQ21cW8@P47>L01AS68@PQ22DY:DX00RDY0R4800<Lib487>L00RDY00`YBRDY:DXYBS6<=Jda
S2U:8@PU:Be[:DX28@P2;F/01BU:9BTYBRU:9BT00R480bDY0bU:0RDY0bU:00@]Jc6<<H`YBP@U:@03
8@PLiacW00<Q20DU:@038@PU:BU:008U:@8Q20<YBP8U:@8YBP059BTQ21S65:D@Q00436<2248010@Q
2488@PQ21P@Q0PQ21@@Q0PQ21`@Q00<000@Q12401@@Q00<8@P@Q12400`@Q00<8@P@Q12400`@Q0PQ2
0`aS00<48@Q236<00`aS00@48@Q212448@88@P0336<8@PQ200848@@8@P848@<8@P0536<@Q0Q22484
8@03248236<224801P@Q2488@PQ236<48@88@P0536<8@P@Q1248@P0236<4248536<00`Q236<<H`02
48@25:D011245:D@Q1BU0Q240aS600<DYA245:D0112400LDYA2448@@Q1BU48@DY@0348@25:D26<H0
11BU48@DYAS60QBU0Q2411S600@DYAS65:DDY@8@Q0045:D@Q1BU48@35:D00a245:D@Q0045:D00aS6
5:DHaP035:D00a245:DDY@055:D248@25:D011S65:DDY@aS0Q240QBU00<HaQBU5:D00a240aBU00<@
Q1BU48@01aBU0QS60aBU00@@Q1BU5:DDY@8@Q00436<@Q12448@75:D00a245:D@Q0025:D948@00aS6
5:DDY@035:D248@011BU48@@Q1240QBU0Q240QBU0Q240QBU0Q2400<<Ha245:D00a2400<<Ha245:D0
11240aBU00<@Q0aS48@00Q2411BU00<@Q1BU6<H00QBU00D@Q1BU48@DYA24008DY@0348@DYABU00@@
Q0045:D@Q1245:D548@336<00a245:DDY@0348@01ABU48@DYA245:D0112400<DYA2448@010aS00H@
Q1BU48@<Ha2436<448@011BU48@DYA240QBU00P@Q1BU48@@Q1BU48@DYA2410aS0Q240PaS00021240
0`0012448@0412401`001248@R48DY@icRDY008aS08YBP069BTYBR489BTQ22U:0S6<00<]JbU:8@P0
0bDY124800<U:B489BT00RDY0bU:0b4800<U:B488@P00R480QcW0QS600<Q22DY:DX00R4800<YBRDY
9BT00R480bDY1B480RDY00@Q22DY9BTU:@8HaP085:DLiacW6<HLib489BTYBP8Q20037>LDYAS600@H
aP057>LQ22DY7>LQ20029BT00acW6<HHaP037>L012489BTQ22480QcW00<Q22DY9BT00R4812DY00@Q
22DY9BTU:@8Q20049BTQ22U:;F/29BT27>L38@P87>L01RDY:DXYBRDY8@PHaP<Q20@U:@06:DX]Jbe[
=Jd]JbU:0RDY00<YBRe[9BT00RDY1BU:0RDY0R4800<U:BU::DX00RDY00@YBRe[;F/YBP8U:@04:DXa
S2e[;F/49BT28@P27>L00b489BTU:@059BT01bU:9BTQ22DY:DX]JbU:00<U:@04:DXU:B487>L26<H2
48@00`Q236<8@P0224800`aS2488@P031242248412422484124010Q212448@@Q0`Q210@Q00<8@P@Q
124010@Q00D8@P@Q24848@0000<48@0324848@Q200@8@P0336<8@PaS00<<H`<8@P041248@PQ21248
248412400`Q236<<H`0236<01PQ21248@P@Q36<8@P8<H`0424848@@Q124224801P@Q2488@PQ21248
@P<<H`@8@P8<H`0748@<H`Q2248<Ha2436<00a2400@DYA2448@@Q08DY@<HaP035:D@Q12400<@Q003
36<DYA24008DY@8@Q00436<@Q1BU6<H25:D00aS65:DDY@025:D00aS65:DDY@025:D46<H011BU6<HH
aQS61ABU00<HaQBU5:D01ABU0aS60QBU00@@Q1BU6<HHaP8DY@8@Q0LDY@H@Q0DDY@<@Q0055:D@Q124
5:DHaP025:D00a245:DDY@025:D011245:DDYABU0QS600H@Q1BU48@@Q1BU6<H348@00`aS5:DDY@02
5:D00a245:DDY@0348@45:D548@35:D00a245:DHaP055:D011245:DDYABU0a240QBU0Q240QBU00<@
Q1BU48@01A2400@<Ha2448@@Q0@DY@8@Q0<DY@D@Q08DY@036<HDYA2400<@Q0035:D@Q0aS008@Q003
5:D@Q124008DY@0348@<Ha24008@Q0035:D@Q1BU008@Q00436<@Q1245:D448@00aBU48@DY@0848@0
0aBU48@DY@0348@236<?48@25:D448@01aBU48@@Q12436<@Q0aS00<@Q04<H`0000@000@Q12400084
8@0300048@@Q00<48@089BU:DSF]9BT]Jc6<;F/YBP8U:@8YBP03;F/YBRU:008U:@8YBP039BTQ21cW
008Q20039BTQ22DY008Q20DU:@03:DXU:B48008Q20039BTQ21cW008HaPDLi`<Q20@U:@8Q20049BTQ
22487>L48@P39BT012487>LHaQS60acW0b4800LLiaS67>LQ21cW6<HDY@027>L38@P49BT02B487>LL
iaS68@PLib489BTYBP028@P01AS67>LQ22DY8@P00acW00<U:B487>L00R480bDY00<Q22U::DX00RDY
00@Q21cW8@PLi`<Q20037>LQ21S600<Li`099BTYBRU:9BTQ21cW8@PU:B48008YBP8Q20059BTYBS6<
<H`]J`02:DX00bDY:DXU:@039BT2:DX39BT2:DX01RDY8@PQ22DY:DXU:@<YBP8U:@03:DX]JbU:008Y
BP05;F/YBR488@PYBP038@P79BT00b489BTU:@02:DX00bDY8@PQ2003:DX00bDY:DXYBP028@P01bDY
:DX]JbDY8@PLiaBU008@Q08<H`<8@P031248@PQ200@48@88@P031248@P0000<48@88@PX48@030004
8@@Q00@48@0324848@@Q0088@P@48@D8@P848@04248<H`aS2482124324831242248312400`Q21244
8@04248010aS48@DY@aS0PQ200H48@Q2248<H`Q236<324800`@Q2488@P032482124010Q236<@Q0aS
0PQ21`aS0Q2400@DYAS67>LLi`8HaP045:D@Q12448@26<H45:D348@35:D36<H01ABU48@@Q1BU6<H0
1ABU00@HaQBU6<HHaP8DY@0448@DYABU6<H85:D011S65:DDYA240QBU00D@Q1BU48@HaQBU00<HaP03
5:DHaQBU00@DY@8@Q0TDY@8@Q0085:D<H`aS48@DYAS65:D@Q0PDY@8@Q0055:D@Q1S65:DHaP025:D2
6<H25:D248@35:D548@35:D46<H00a2436<@Q0025:D0112436<@Q1BU0PaS0Q240QBU00<@Q0aS48@0
1QBU00H@Q1BU48@DYA245:D248@35:D01a2436<<Ha245:DHaQBU00D@Q0@DY@0348@DYA24008<H`@@
Q0@DY@<@Q00336<DYA2400<@Q0<DY@0348@DYABU008@Q0035:D@Q1BU00<@Q08<H`T@Q08DY@0448@<
Ha2436<248@011BU48@<Ha240QBU00P<H`Q2248@Q1BU36<@Q0aS0a2400<<H`Q248@00Q240PaS0a24
00@DYA2448@<H`<@Q08<H`0448@DYA2436<248@136<000@48@0400048@@Q248212402@00248Q24YB
=JdYBSF]<H`YBP029BT01RU:9BTYBRU:;F/YBP8U:@05:DXU:BDY8@PLi`028@P39BT28@P01RDY:DXY
BRDY8@PU:@<Q208U:@058@PLiaS67>LHaP037>L28@P02RDY:DX]JbU:9BTQ21cW8@PU:B480QcW0R48
00@U:B489BTU:@8Q208Li`8HaP8Li`8Q20<Li`068@PLiacW6<HDYAS60R4800<U:BU:9BT00R4800DY
BR487>LDYAcW00<Q208U:@048@PHaQcW8@P29BT011cW6<HHaR480RDY00<Q21cW8@P012DY00PQ22U:
;F/YBR487>LQ21cW0b481QcW00@Q22DY9BTU:@8Q20099BTQ22DY8@PU:B487>LYBRe[008aS0DYBP<U
:@8YBP039BTYBRU:008YBP<U:@038@PU:BDY00LYBP049BTYBRU:;F/2:DX49BT022489BTYBRU:8@PL
ib489BT2:DX49BT6:DX39BT28@P29BT2:DX012DY7>LDYABU0`aS0PQ200@48@Q21248@PD48@88@PD4
8@0424848@Q2124224800`@Q00048@0?124224800`@Q24848@0424800`@Q2488@P0224801`aS1244
8@@Q248<H`Q200848@0424848@@Q124224831242248736<424800`aS48@8@P0212401PQ236<@Q0Q2
1248@P848@D<H`03248<H`Q200<<H`@@Q0045:DHaQS67>L35:D00a245:DHaP036<H021245:D@Q1BU
48@<Ha245:D36<H248@01PaS48@DYABU7>LHaP8DY@036<HDYAS600@DY@0348@DYAS600<HaP@DY@8H
aP<DY@<@Q0035:D@Q1BU008DY@8HaP055:DHaQBU5:D@Q0025:D348@00aBU6<HHaP035:D01A245:D@
Q1BU48@00QBU00<@Q1BU5:D00QBU00<@Q1BU48@00Q2400<DYA245:D00QBU00<@Q0aS5:D00aBU0QS6
1aBU112400@<Ha245:DHaP<DY@046<HDYA2448@35:D548@236<00a245:DDY@0348@35:D348@011BU
48@@Q1240QBU00@<HaBU6<HHaP<@Q0045:D@Q1BU36<248@00aBU48@DY@0348@011BU6<HDYABU0Q24
00D<Ha2436<@Q1BU008@Q08HaP0748@<Ha2448@DYA2436<00a240QBU00<HaQBU48@00a2400<<Ha24
48@01Q2400<<Ha2448@0212400@DYA2448@<H`8@Q08DY@8@Q00336<@Q0aS00<<H`0448@<H`aS36<=
48@00aBU48@@Q00648@636<0000300048@0000848@0300048@@Q00@48@068@QBU3g_9BTYBRDY0bU:
0RDY00<YBRe[:DX012U:0R4800<Lib489BT00RDY00<Q22DY8@P00RDY0RU:00<U:B488@P00b480QS6
00<Lib488@P00acW00@Q21cW8@PQ20DYBP039BTQ21cW00<Li`8U:@038@PLib4800<Q200:6<HLib48
8@PLiaS67>LQ22DY8@P27>L28@P031cW6<HDYAS67>LU:Be[9BTQ22DY8@PLi`8HaP8Li`8U:@<Q2003
7>LQ21cW008Q208Li`039BTQ21cW008HaP048@PLib489BT2:DX00b489BTYBP029BT27>L48@P47>L0
1b486<HHaR489BTYBR48008Li`039BTQ224800DU:@03:DX]Jbe[008YBPDU:@03:DX]JbDY008U:@8Y
BP<Q208YBP<U:@8YBP04;F/U:BDY9BT3:DX69BT28@P79BT28@P01RDY;F/YBRDY:DX]J`8YBP8U:@@Y
BP8U:@07:DXU:B489BTYBR487>L0112400<DYA2436<01@Q210@Q00D8@P@Q12448@Q201848@040004
8@@Q124:24800`@Q24848@02248236<01@Q212448@@Q24800`@Q0PQ21@@Q10Q200H<Ha245:DHaQ24
36<3248348@010aS248<H`aS0Q2400@<H`Q212448@D8@P<<H`0448@<H`aS48@26<H01QBU7>LQ22DY
8@PHaP<DY@8HaP035:D@Q1BU00<DY@@@Q0045:D@Q12448@55:D01a245:D@Q1S65:DHaQBU008HaP<D
Y@0448@DYAS65:D36<H011BU48@@Q1S61aBU00DHaQBU48@DYA2400PDY@036<HDYA2400@DY@0448@D
YABU48@25:D448@00aBU48@DY@035:D248@01PaS5:DDYAS65:DHaPTDY@8HaP@DY@<@Q0075:D@Q1BU
48@<Ha245:D00QS600<@Q1BU6<H00QBU00@@Q1BU5:D@Q08DY@8@Q00336<@Q12400<@Q0035:D@Q0aS
008DY@036<HDYA2400@@Q0056<HDYABU5:D@Q0035:D00a245:DDY@0248@35:D01A245:D@Q12436<0
0QBU00@HaQBU48@@Q0@<H`8@Q08DY@0348@DYABU008@Q08<H`8DY@0448@DYA2448@25:D01aS65:D<
H`aS48@DYA2400@<H`@@Q08<H`8@Q0<<H`8@Q0035:D@Q12400@<H`<@Q0035:D<H`aS008<H`0348@<
Ha2400<@Q0<<H`<@Q08<H`P@Q00436<@Q1245:D248@236<348@136<000H48@040008@P@Q00021240
22DYE[E242489BTQ22U:;F/29BT012U:;F/YBRU:0RDY00<YBRe[9BT00QcW00<Q22DY9BT00R4800DU
:B489BTYBRe[008YBP8Q20047>LQ21cW8@P27>L01R487>LHaR489BTQ208Li`038@PYBRU:008YBP<U
:@0;8@PLib488@PU:B489BTQ21cW8@PU:@027>L00aS67>LLi`027>L01AS67>LU:BDY7>L00QS60acW
00DDYAS67>LQ22U:00<U:@057>LHaQS66<HLi`028@P29BT00b487>LQ20029BT00acW6<HLi`028@P0
1acW6<HHaQS67>LU:B4800@U:@8YBP039BTQ21cW008Q208U:@097>LHaQcW8@PU:B487>LHaRDY008Y
BP038@PLiacW008Q208Li`038@PYBRDY008YBP8]J`05:DXU:BDY8@PU:@02:DX00be[:DXYBP03:DX2
9BT28@P3:DX012DY8@PU:BU:0Re[00<YBRDY:DX00Re[00<YBRDY8@P00RDY0R480RDY00<Q22DY9BT0
0bDY0R4800<YBRe[;F/00RDY00<YBRe[:DX00RU:0RDY00@YBRDY9BTYBPDU:@038@PLiaBU008@Q003
5:D@Q124008<H`D8@P@48@88@PH48@0524848@@Q1248@P0212400`0012448@0612400`Q212448@03
124524800`@Q24848@02124010Q236<8@PQ20P@Q0`Q21`@Q0`Q200<48@Q224800Q240QBU00<@Q0aS
36<00PQ20PaS0Q2400H<H`Q236<8@Q2436<324801@@Q2488@P@Q36<00a240PQ20Q2400DHaQcW6<HL
ib48008U:@037>LHaQBU008HaP@DY@8HaP065:D@Q0aS48@DYA240aBU0Q2400<<HaBU5:D011BU00<L
iaS66<H00QBU0QS60aBU00D@Q1BU6<HLiaBU008@Q0DDY@056<HDYABU5:D@Q0025:D248@00aBU6<HH
aP025:D01Q246<HHaQBU48@DY@8@Q0DDY@036<H@Q124008@Q0055:D@Q0aS48@DY@026<H00a245:D@
Q00348@00aBU6<HHaP025:D00a245:DDY@025:D248@00aS67>LHaP0248@25:D011245:D@Q1BU0a24
0QBU00<HaQBU5:D00QBU00<HaQBU5:D00Q2400<DYA2448@00PaS1A2400<DYA2448@00Q240QBU0Q24
11BU00H@Q1BU5:D@Q1BU48@25:D011S65:D@Q1240aBU0Q2400@<Ha245:DDY@8@Q08DY@8@Q00436<@
Q12448@45:D248@25:D348@011BU48@@Q1241ABU1Q2400<<Ha2448@01A2400<<Ha245:D00Q240PaS
0QBU00<@Q1BU5:D00Q2400<<Ha2448@00QBU0`aS00<@Q0aS36<01A2400HDYA2436<<HaBU48@336<0
0aBU48@@Q00648@336<248@236<348@0000500048@001240000612401PQ29BUBU3W>7>LU:@8YBP03
<H`]Jbe[008aS00:;F/YBRU:;F/YBRDY7>LHaQcW8@P2:DX39BT2:DX012e[9BTQ22DY0R4811cW00<Q
21cW7>L00acW0R4800@U:B488@PQ20<YBP059BTQ22488@PU:@028@P27>L012489BTYBRDY0acW00<Q
22DY8@P00QS600@LiaS66<HLi`8Q20047>LHaQS68@P47>L01R489BTU:B486<HLi`8HaP8Q208U:@05
8@PLib487>LQ20047>L28@P47>L01b487>LLib489BTYBRDY008Q20@Li`8U:@@Q208Li`@Q208U:@8L
i`038@PU:BDY00<Q208U:@8]J`8YBP<U:@8Q200;9BTYBRU::DXU:BU:9BTYBRDY8@PU:@02;F/00bU:
9BTU:@03;F/2:DX29BT28@P00bDY8@PU:@029BT012489BTU:BDY0RU:0bDY00@LibDY8@PYBP8U:@03
8@PU:BU:008YBP8U:@8]J`059BTQ22e[<H`YBP038@P00bDY8@PLi`047>L01QS67>LQ21cW5:D<H`D8
@P848@0324848@@Q00848@0324848@@Q0088@P@48@0324848@@Q00848@0300048@@Q00D48@042484
8@@Q124424800`@Q24848@03248212432482124010Q21248@P@Q0`Q200D48@Q21248@P@Q0088@P07
124@Q2DY;F/U:ABU24801@aS0Q240QS600D@Q1BU36<8@PaS00@8@P@<H`0748@<HaBU6<HLib487>L0
1QS600<DYAS66<H00QBU0Q2411BU0PaS0aBU0Q240QBU0Q2400@DYAS66<HHaP<DY@036<HDYABU008D
Y@046<HDYABU5:D46<H45:D248@25:D00aS65:DDY@0448@45:D01A245:D@Q1BU6<H00aBU0Q2400<D
YA2448@00aBU0Q240aBU00<@Q0aS5:D00QS600DDYA2448@DYA24008DY@0548@DYABU6<HDY@026<H3
5:D00a245:DDY@065:D248@021BU48@DYA2436<@Q1BU6<H35:D011S648@DYA240QBU00THaQ2436<<
Ha245:D@Q0aS48@00aBU11240QBU00D@Q1BU48@@Q1S6008DY@8HaP8DY@0336<@Q12400@@Q00336<@
Q12400@@Q0035:D@Q12400<DY@046<H@Q12448@236<00a2436<<H`0448@00aBU48@@Q00248@25:D2
48@00aBU48@DY@0248@00aBU48@DY@0348@00`aS48@<H`0248@336<448@236<548@00aBU36<<H`02
36<00a2436<@Q00348@336<01`Q248@DYABU6<H@Q0aS00@@Q08<H`<@Q08<H`0548@DYA2448@<H`05
48@010aS48@@Q1240@aS000<12401BDYDY@icR489BT00RU:00H]Jc6<;F/aS3F];F/5:DX01AcW8@PQ
22489BT00RU:00<U:B489BT00RU:00DU:B488@PQ21cW00<Q20<Li`038@PLiacW008Li`8U:@8Q2005
9BT]Jc6<;F/U:@038@P00bDY8@PQ20037>L39BT022486<HLib489BTQ21cW6<H27>L011S67>LQ21cW
0QS600@Q22DY8@PQ208Li`@U:@087>LHaQBU6<HLibDY:DXQ208Li`8Q208Li`038@PLib4800PLi`8Q
20099BTYBRDY8@PU:AcW6<HLib48008U:@8Q20039BTQ2248008Li`8Q20<U:@038@PLiacW008Q20@U
:@03:DXU:BDY00<U:@8Q20039BTYBRU:00<U:@DYBP058@PU:BU:;F/YBP039BT2;F/2:DX00bDY8@PU
:@069BT012489BTU:BDY0RU:00<U:B488@P00bDY00DQ22DY9BTYBRDY00<YBP049BTYBRU::DX29BT0
2BU:;F/U:B487>LQ22U:9BTLi`026<H27>L26<H27>L00aS648@8@P05248212400`Q21248@P061240
10Q21248@PQ210@Q00<8@P@Q12401P@Q00@8@P@Q24848@88@P0436<8@P@Q12422483124624841240
0`Q21248@P0424802P@Q2488@P@Q48@Q22U:9BT@Q0Q20PaS0Q2400<<Ha245:D00QS600HDYA2436<<
H`Q236<3248636<26<H00acW6<HHaP025:D27>L01QS65:DDYAcW6<HDY@8@Q0HDY@<@Q08DY@0448@D
YABU36<248@26<H25:D26<H00aBU6<HDY@025:D348@25:D36<H00acW5:DDY@0248@01AS648@DYABU
6<H00QBU00<@Q1BU48@01QBU00<LiaS66<H00a2400@DYA2448@@Q0DDY@0348@DYABU00<DY@0348@D
YAS6008@Q0035:D@Q1BU008@Q0DDY@036<HDYAS6008@Q08DY@0648@DYABU6<HLiaBU11240QBU00L@
Q0aS48@@Q1S65:D@Q0035:D01a245:DHaQS65:D@Q0aS008@Q0045:D@Q12436<25:D00aS648@DY@02
48@35:D248@45:D00aS65:DDY@0248@25:D648@011BU48@@Q1240QBU00H@Q0aS48@DYAS65:D248@2
36<00a2436<<H`0:48@011BU48@DYA240QBU00D@Q1BU48@@Q0aS008@Q08DY@0348@<Ha2400@@Q0@<
H`0448@<H`aS36<45:D748@00`aS48@<H`0236<00a2436<@Q00248@00aBU48@<H`0348@236<00a24
5:D<H`0236<00a245:D@Q00336<448@236<348@236<0000800048@00124000@Q0008@P848@080008
@RU:DY@aS1S69BTe[@8aS0@]J`8aS006;F/YBR488@PU:B480RU:00<]JbU:;F/00Re[0RDY0R4812DY
0QcW00DQ21cW8@PLib4800<Li`<Q20@YBP<U:@LQ20047>LQ22489BT28@P27>L012489BTU:B481aS6
0QcW0QS600LLib48:DXYBRDY7>LHaP037>L01b487>LQ22489BTLib48008Li`038@PLiacW00<Li`04
8@PLiacW7>L28@P37>L29BT2:DX012486<HHaQS60QcW00@Q21cW8@PU:@8Q20HLi`<Q208Li`@U:@03
:DXU:B48008U:@8YBP079BTQ21cW9BT]JbU:8@P00RDY0RU:00@U:B488@PQ20DYBP04;F/aS2e[:DX5
9BT012489BTU:BU:0RDY00PYBRDY:DXQ22DY:DXU:B480QcW00@U:BU::DXU:@<Q208U:@8YBP<U:@<Y
BP039BTQ22DY008Q20037>LQ21cW00<Li`8U:@038@PU:AcW008DY@8<H`8@Q08<H`<8@P<48@032484
8@@Q01848@0324848@Q200<48@<8@P05124000@Q1248@P04124224800`@Q24848@02124010Q21248
@P@Q10Q200X48@Q2248<Ha245:DHaQBU48@8@PD<H`0448@DYAS65:D348@236<00`Q248@@Q00236<0
0aBU6<HHaP037>L00b486<HHaP055:D36<H00a245:DHaP026<H011245:DDYABU112400D<HaBU5:DH
aQBU008@Q08DY@046<HDYAS66<H27>L01AS648@@Q1245:D00QS60aBU0Q240aBU0Q240QBU0aS600<D
YA246<H00aBU00<@Q1BU5:D011BU0QS600@DYA245:D@Q0HDY@0:48@DYA2448@DYAS65:D@Q1BU6<H2
5:D00a245:DDY@0348@011S65:DDYA240QBU00<HaQBU5:D00QBU0QS60aBU00/@Q1BU5:DDY@aS48@<
Ha245:D@Q1BU008HaP@DY@@@Q0045:D@Q1245:D436<00a245:DDY@035:D348@35:D348@65:D00a24
5:DDY@0248@236<35:D248@00`aS48@DY@035:D248@011BU48@@Q0aS112400@DYA2448@<H`8@Q003
36<@Q1BU008DY@0336<@Q1BU00<@Q0035:D@Q124008<H`0448@DYA2448@236<348@00`aS48@@Q003
48@00`aS48@@Q0045:D0112436<@Q1240`aS0Q2410aS00D8@Q2448@@Q1BU008@Q08<H`8@Q08<H`H@
Q00536<@Q12448@DY@0348@236<01A2436<@Q1245:D00@aS000812402`Q200048@Q2;F]BU3F]6<HU
:C6<;F/00c6<00<]JbU:;F/00Re[00<YBR488@P00R480RU:12e[00<aS2e[:DX01BDY0R4800DLiaS6
7>LLib4800DLi`068@PU:Be[;F/YBRDY0R480RDY0b4800@Lib487>LLi`8U:@8Q20047>LQ22DY9BT2
8@P37>L00aS67>LHaP026<H27>L011S67>LLiacW0RDY0R481AcW0b4811cW00<Q21S67>L00QcW0R48
00<LiaS67>L00R480acW00DQ22U:9BTU:B48008Li`8HaP047>LHaQcW8@P29BT48@P27>L78@P00acW
8@PU:@02:DX012489BTU:Be[0RU:0R480RDY00<YBRDY9BT00R4800XU:BU::DXYBR489BTYBRe[:DX]
J`<YBP8]J`8U:@048@PU:BU::DX38@P032DY:DXYBRU:9BTYBRDY:DXU:B487>LQ20@U:@8Q20049BTY
BRDY9BT5:DX01Re[9BTQ22DY:DXQ208Li`8Q20047>LHaQcW8@P39BT00acW5:D@Q00248@00aBU36<8
@P02248010aS2488@PQ20P@Q00<8@P@Q12400`@Q00<8@P@Q12404P@Q00<8@P@Q248020@Q0`Q200@4
8@Q21248@P848@<8@P041248@PaS36<324801@aS5:DLiaS648@01PaS0Q2400<DYAS65:D00Q240PaS
00@@Q0aS36<<H`8@Q0<Li`078@PLiaS67>LHaQcW48@00aBU00DHaQBU5:DHaQBU008HaP<DY@0<6<HD
YA2436<@Q1BU6<HDYAS648@DYA241QBU00DHaQcW6<HLiaBU00<@Q0056<HDYABU5:DHaP025:D348@2
5:D248@01ABU6<HDYABU6<H01ABU00@@Q1BU5:D@Q08DY@036<HDYABU008DY@@@Q08DY@0448@DYA24
48@25:D011S65:DDYA240QBU0Q2400DDYA2448@<Ha24008DY@036<HDYABU008HaP8DY@<@Q0@DY@@@
Q0055:D@Q1245:D@Q0075:D248@35:D348@00`aS48@@Q00448@00aBU6<HDY@0548@25:D348@00aS6
5:DDY@025:D348@011BU48@<H`aS0a2400<<Ha245:D021BU0a2400<<Ha2436<02a2400<DYA2448@0
0aBU0a2400D<Ha2448@@Q0aS008@Q00336<@Q124008@Q00336<@Q124008@Q0<<H`H@Q08DY@0348@<
Ha24008@Q00436<8@PaS36<348@236<01A2436<@Q1245:D00Q241PaS1A240`aS0Q2400<DYA2436<0
0PaS00<@Q1BU48@00@aS00001@00124000@Q00001`@Q00TU:DYB>LhLib48;F/aS3W><H`00RU:00Da
S2e[:DXU:BU:00<U:@8YBP8U:@04;F/aS36<:DX49BT012U:9BTQ22DY0b480QcW00<Q22U:8@P00acW
00HYBRDY;F/aS2e[:DX48@P39BT02b489BTU:B489BT]JbU:9BTLib489BT00R480acW0QS60QcW00<D
YAS66<H00RDY00<Q22DY:DX00RU:00@Q21cW6<HLi`TQ20037>LHaQcW00<Li`8HaPHLi`068@PU:BU:
8@PLiaS61QcW00<HaQcW8@P00bDY0b480RDY0QcW0b4800TLib488@PU:B489BTYBRe[:DX00bDY0RU:
0RDY0RU:0bDY0RU:0b480RDY22U:1RDY0b4800@U:BU::DXU:@<Q2004:DX]JbDY7>L28@P2;F/01RU:
9BTQ21cW9BTQ208U:@<YBP039BTYBRU:00@U:@8Q208U:@078@PLib488@PU:B487>L0124800<HaQBU
36<00`aS00H@Q0Q236<<H`Q236<324800`@Q2488@P0312400`Q212448@0A12400`Q212448@051240
100012448@@Q1@Q200<48@Q212400PQ20`@Q0PQ200<<H`Q236<01@aS00@8@PaS36<DY@8@Q00936<@
Q1245:D@Q1BU48@DYA24008DY@0;6<HLiacW>Li6<EJeG_LmkbU:5:D8@P045:D00aS65:DDY@025:D0
0aS65:DHaP046<H011245:D@Q1240QBU0QS600<DYA2448@011BU0QS60acW00HHaQBU48@@Q1BU6<H3
5:D00a245:D@Q0025:D0112436<@Q1240aS60aBU00HHaQBU48@@Q1BU6<H35:D36<H01acW5:D@Q124
5:D@Q1BU00<@Q0035:D@Q124008@Q0DDY@0448@DYABU5:D248@00`aS5:DDY@045:D00aS65:D@Q003
48@25:D348@00aBU6<HDY@025:D648@35:D00aS648@@Q00748@236<248@01@aS48@@Q1245:D00Q24
1QBU00<@Q1BU48@00Q2400HDYAS65:DDYA2436<248@00aBU48@@Q00248@00`aS48@@Q0045:D011S6
5:D<H`aS2Q2400<DYA2448@00a2400<DYA2448@00a241QBU0a2411BU0Q2400<DYA2448@011240PaS
00D@Q0aS36<@Q1BU00<@Q0055:D@Q12436<@Q00436<00a2436<<H`0336<248@336<348@336<248@4
36<248@00`aS48@@Q00248@336<011245:DDYA240@aS000512400`0012448@0212402`00248U:DYB
<H`LibDY<H`icSF];F/00RU:00<aS2e[;F/00bDY00<Q22DY:DX00RU:00<]Jc6<<H`00Re[00@U:BU:
9BTQ20@U:@<Li`036<HQ22DY008U:@038@PLib48008U:@8]J`04:DXU:B487>L28@P29BT58@P012DY
:DXYBRDY0R480RDY00@Q21cW7>LHaP<Li`8DY@8HaP8Q20DU:@048@PLiaS66<H27>L012489BTQ2248
11cW00<Q21S65:D00QS600DQ21cW7>LLib4800@Li`@U:@057>LDYAS66<HQ20027>L26<H01B489BTQ
22487>L00R4800<U:AcW8@P00QcW00@Q21cW7>LQ208U:@038@PYBRU:00<YBP8U:@8YBP8U:@<YBP8U
:@08:DXU:BDY8@PLibDY:DX]J`8YBP039BTYBRe[008YBP038@PU:BDY008YBP099BTQ22488@PU:BU:
9BTQ22DY008Q208YBP8U:@8Q20039BTYBRU:008U:@8Q20@U:@04:DX]Jbe[:DX29BT00bU:8@PU:@05
8@P27>L29BT02AcW6<HLibDY8@PLiaS65:D@Q00236<00a2436<@Q009248612400`Q212448@0:1240
10Q212448@001@@Q00<000@Q12401@@Q10Q200D48@Q21248@P@Q00<8@P0336<8@PQ200848@D<H`04
248<H`aS36<348@011BU48@@Q1240QBU00@@Q1BU48@DY@8HaP8Li`09>Li245JeG_LmkbU:6<H@Q1BU
008HaP035:D@Q1BU008HaP8@Q0035:DHaQS600<HaP<@Q0045:DHaQBU5:D36<H35:D011S65:DDYABU
11cW0QBU00<@Q1BU5:D00QBU00<@Q1BU48@011BU0Q2400DHaQcW6<HDYA24008DY@036<HDYABU00<@
Q0@DY@<HaP@@Q0045:D@Q12448@85:D011245:D@Q1BU21240QBU00<HaQBU48@00QBU00<HaQBU5:D0
0a240aBU1a2400<<HaBU5:D00QS600<DYA245:D00QBU00@@Q0aS48@DY@8@Q00436<@Q0aS36<348@0
0aBU6<H@Q00236<01A245:DDYABU48@00QBU11240aBU00<@Q1BU48@00Q2400@<Ha245:D@Q08<H`03
48@DYAS6008DY@L@Q0035:D@Q1BU00<@Q0035:D@Q124008@Q0035:D@Q12400<@Q00436<@Q1BU48@2
5:D348@00`aS48@@Q00248@35:D448@011BU48@<H`aS0a2400<DYA2448@00Q2400<DYA2448@00PaS
0a2400@8@PaS36<<H`/@Q00536<@Q0aS36<@Q00436<848@00`aS48@<H`0248@15:D148@136<00003
00048@0000T48@079BU6<C6<7>LaS3W>=Jd00be[0bU:0bDY0R4800@U:Be[<H`]J`8YBP03<H`]JbU:
00<U:@058@PU:B488@PLi`028@P01RDY8@PLibU:;F/U:@8Li`058@PYBRDY9BTYBP029BT68@P01RDY
:DXYBRe[:DXU:@8YBP04;F/U:B488@P29BT02AcW6<HHaR487>LHaQBU6<HLi`048@P29BT01RU:9BTL
iacW6<HLi`<Q208Li`048@PU:B487>L26<H27>L36<H00b487>LQ20026<H27>L00b489BTQ20028@P3
6<H01AcW9BTU:B487>L00b4800@U:B489BTU:@8Q208Li`8Q20<U:@8Q20037>LU:BU:008YBP049BTQ
22DY;F/2:DX00bDY:DXQ20029BT01B489BTU:BDY8@P00bDY00<YBRDY9BT00RDY00@]JbDY9BTQ208U
:@04;F/YBRDY8@P29BT00b489BTQ20029BT58@P00bDY8@PU:@028@P59BT02R48:DXYBRU:8@PU:BU:
<H`]JbDY0RU:00<]JbU:8@P00R480bDY00@Q21cW7>LLi`LQ208Li`066<HDYA2448@DYA240aBU00<@
Q0aS36<00PaS00H8@PaS24848@Q21242248K1244248212400`Q212448@0424800`@Q2488@P031245
248436<00a245:DHaP026<H011BU6<HQ22DY0RU:00TaS3W>AS5244HaDYA243W>9BT00QcW0QS60aBU
00@@Q1BU6<HHaP<DY@8HaP037>LDYA24008DY@056<HDYABU6<HLi`026<H051245:DDYAS65:DHaQBU
6<HU:BU:8@PHaPaS48@HaQ245:D@Q1S65:D248@00aBU48@@Q0025:D01AS648@DYABU6<H02ABU00<@
Q1BU5:D00QS60aBU00@@Q1BU5:D@Q08DY@D@Q0DDY@0348@DYA24008@Q00636<@Q12436<@Q1BU0QS6
0QBU00@HaQBU5:DDY@<@Q0035:D@Q12400<@Q0045:D@Q1BU36<248@35:D26<H25:D448@021BU48@@
Q12436<@Q0aS48@336<548@35:D00a245:DHaP025:D236<248@25:D01@aS48@DYABU48@00PaS0Q24
00DDYA245:D@Q1S600@DY@0348@DYA2400<@Q00336<DYA2400h@Q0055:D@Q1BU5:D@Q0025:D348@2
5:D548@01ABU48@@Q0aS48@010aS00<@Q0aS36<00Q2400@DYA2448@@Q0D<H`8@Q08<H`03248<Ha24
008@Q0075:D@Q12436<@Q0aS48@00PaS0a240`aS112400<<Ha2448@00Q240PaS00D@Q0aS48@@Q1BU
004<H`001P@Q00<000Q212400P@Q00H8@RDYAS4aS248<H`2>Lh2<H`012U:9BTYBRU:0Re[00LYBR48
7>LU:BU:<H`]J`02:DX01Re[:DXU:BDY8@PU:@8YBP0;9BTQ21cW8@PU:B487>LQ22DY:DXU:@027>L0
1248:DXYBRDY0RU:00<U:B488@P00R480RDY00LQ22U:;F/]JbU:9BTYBP02;F/01RU:8@PLib48:DXU
:@8HaP037>LQ21S6008HaP8Li`039BTLib4800@U:@067>LHaQS67>LU:B480acW00DU:B488@PLiaS6
00<Li`8HaP047>LQ22487>L26<H00acW8@PQ20029BT28@P26<H01AcW8@PQ21cW6<H01B4812DY0R48
00<Lib488@P01B480RDY0RU:00<Q22DY:DX00bU:0RDY00<Q22DY:DX00RDY00<Q22DY9BT00R4800<U
:BU::DX00RDY12U:0RDY00<Q22U:9BT00RDY0R4800@U:B488@PQ20<U:@038@PU:B4800<U:@038@PU
:BDY00<U:@@YBP07;F/U:B489BT]Jc6<;F/00RU:00<]JbDY9BT00R4800DU:BU::DXU:AcW00DQ2004
7>LU:BDY9BT27>L00aS67>LHaP025:D00a245:D@Q00548@00`aS248<H`0324800`@Q24848@071240
0`Q212448@0@12400`0012448@052483124224800`aS24848@03124424800`@Q2488@P0436<01124
5:DHaQS60QBU00hHaR48:DXU:BU:=JdmkdYB@Q16<E:D@Q0mkbU:0QcW00HHaQcW5:DDYA245:D36<H0
0aBU48@DY@026<H00aBU6<HHaP025:D248@01AS67>LLiaBU48@00QS600<DYA245:D00aBU00TQ22e[
8@PHaPaS5:DHaQBU48@00QBU0QS600<DYA245:D011BU0aS600<DYAS65:D01ABU00LHaQBU5:D@Q1S6
7>LHaP035:D00a2436<@Q0035:D01A245:DDYA245:D00QS600@DYA2448@DY@<@Q0035:D@Q0aS008@
Q0036<HDYABU008HaPHDY@0348@DYA2400<@Q0<DY@0348@<Ha24008DY@0348@DYABU008DY@0348@D
YA24008@Q0065:D@Q12448@<Ha2410aS0Q2400DDYA2448@<Ha2400@DY@L@Q0035:DHaQBU008@Q003
36<DYABU008@Q08<H`<@Q0035:D@Q124008DY@0448@DYA2448@25:D00a245:D@Q0025:D248@00`aS
48@@Q0025:D948@01ABU6<HDYABU48@00QBU00@@Q0aS48@DY@L@Q00336<@Q124008@Q08<H`0348@<
HaBU00D@Q08<H`04248<H`aS48@336<0112436<<H`aS11241@aS0a240`aS0a2400dDYA2436<<H`Q2
36<@Q0aS48@<Ha246<HDY@0136<0000500048@001240000512401P00124Q24YB<H`]J`8mk`05<H`U
:BU:<H`]J`02:DX00be[<H`aS002:DX012DY:DX]Jbe[12U:00@]JbDY8@PQ208U:@8Q20039BTQ2248
008Q20049BTQ22487>L38@P3:DX012DY8@PU:BU:0bDY00L]Jb488@PQ22DY<H`]J`02:DX01R489BTU
:BDY:DXQ208Li`058@PLiaS65:DHaP027>L38@P012DY8@PU:BU:0acW00<Q22DY9BT00RDY00LQ21S6
7>LHaR487>LHaP027>L46<H01QcW8@PQ22486<HLi`8Q208U:@<Q20097>LDYAcW7>LU:B487>LQ22DY
00<Li`038@PU:BDY00@Li`@U:@8Q20<U:@8YBP0:9BTLibDY:DXaS2e[9BTQ22DY8@P59BT28@P00bDY
:DXYBP039BT00bU:;F/YBP038@P2:DX29BT01BU:9BTLiacW8@P00RDY0b480bU:00<U:B488@P00R48
00HU:B489BTYBRDY8@P29BT3:DX012DY8@PYBRe[0S6<22DY00DYBR488@PLibDY00<YBP059BTYBQcW
7>LHaP047>L46<H35:D37>L26<H248@00`aS48@8@P0224800`@Q24848@0212400`Q212448@051242
2483124010Q212448@000`@Q00@8@P@Q12448@D8@P<48@05248<H`Q21248@P0412401PaS2488@PQ2
36<HaP8Li`056<HDYABU7>LHaP047>L29BT01Be[@Q16<D8@>Lh00b4800<LiaS66<H00aBU00hHaQBU
48@@Q1BU8@PLiaBU48@DYAcW8@PLiaS60QBU00PHaQcW6<HDYAS65:DHaQ240QBU11S60QBU00LQ22DY
8@PDY@aS48@HaP035:D011S65:DDYABU0a240QBU00<HaQcW6<H00aBU00DHaQ245:D@Q1BU00<HaP08
48@HaQS67>LHaQBU48@DY@<@Q0055:D@Q1245:DHaP045:D011S65:D@Q1240QBU00@@Q1BU5:DDY@<@
Q08DY@8@Q0045:DHaQBU5:D448@25:D348@25:D548@00aBU48@DY@025:D348@011BU48@@Q0aS0a24
00<DYA2436<01`aS1A240aBU00<@Q0aS36<0112400<<Ha245:D00QBU0Q2400DDYA245:D@Q0aS00<@
Q0<DY@<@Q0056<HDYA2448@<H`0248@00aBU48@@Q00248@011BU48@@Q1240QBU1A240QBU00@@Q1BU
36<<H`@DY@0448@<Ha245:D248@00`aS48@DY@0436<01ABU48@@Q12436<00Q2400<DY@aS48@00`aS
0a2410aS0Q2400<<H`Q236<00Q240PaS00@@Q0aS248<H`<@Q00336<@Q12400@@Q00436<@Q0aS36<2
48@436<35:D148@000D48@0300048@@Q00@48@048@Q:DS6<:DX2>Lh0136<:DX]Jc6<0Re[0RU:00<]
Jc6<:DX00R4800DYBS6<;F/YBRe[008YBP05;F/U:BDY9BTYBP029BT00acW8@PU:@028@P00bDY8@PQ
20037>L29BT012U:9BTU:BU:0RDY0R4800@U:BU::DXU:@8Q20049BT]Jbe[:DX39BT2:DX00bDY7>LL
i`027>L022486<HHaQS67>LHaR487>L28@P01bDY:DXU:B487>LHaQcW008YBP049BTQ21S66<H57>L0
11S67>LLiaS60QcW00@Q21cW8@PHaP8Li`038@PU:BDY008U:@0;8@PLiaS66<HLib489BTQ21cW8@PU
:@028@P00acW8@PQ20028@P00bDY8@PLi`027>L012489BTYBRDY0R4800<U:BU::DX00b4800<YBRe[
;F/00RDY0R4800<U:BU:9BT00b480RDY00<YBRDY9BT00RDY0RU:00<U:B488@P00RDY00@YBRDY8@PU
:@8Q20037>LQ22DY008U:@8Q20089BT]JbDY8@PLibDY:DXU:@8Q208U:@8YBP8U:@<YBP8U:@05:DXa
S3F]<H`YBP038@P01RU:9BTQ22489BTYBP8Q20037>LYBRU:008YBP038@PLiacW00DLi`048@PHaQcW
6<H35:D01aS67>LHaR487>LDYA240088@P0336<8@PQ200@8@PP48@<8@PD48@0300048@@Q00L48@<8
@P848@88@PL48@H8@P0636<DYAcW9BTLiaBU11S600XLib487>LQ22DY;F]244Ha@Q0icP8Q20<Li`06
6<HDYAS66<HDYA240QBU0QS611BU00<HaQcW7>L00QS600<DYAS66<H00QS600<DYAS65:D01AS60QBU
00HHaQcW9BTYBR486<H248@00aBU48@HaP026<H25:D248@01aBU48@DYAS67>LDYA2400<HaPHDY@08
6<HDYA245:DHaQcW6<H@Q08DY@8@Q08DY@056<HDYABU5:DHaP0248@00aS67>LDY@0248@01QBU48@D
YABU48@DY@8@Q00836<@Q1BU5:DHaQBU48@DY@<@Q08DY@<@Q08DY@8@Q0035:D@Q12400@@Q0045:D@
Q1BU6<H248@00`aS5:DDY@0248@00`aS48@@Q00348@336<348@010aS48@@Q1BU0Q240QBU00<HaQ24
48@00Q2400<DYA245:D0112400@DYA2448@DY@8<H`8@Q0035:DHaQS6008DY@D@Q0055:D@Q12448@D
Y@0948@00aBU48@@Q00448@01ABU48@@Q0aS48@00QBU00D@Q1BU48@@Q1BU008@Q0045:D@Q1BU5:D2
48@020aS48@@Q12436<@Q0aS48@336<00aBU48@<H`0436<248@336<00a2436<<H`0236<348@236<0
0a245:D@Q00336<248@00`aS48@<H`0648@236<548@25:D148@00003124000@Q00T48@078@Q>LcW>
:DXaS2e[:DX00RDY00HYBRDY9BTYBRe[:DX29BT2;F/29BT2:DX39BT3:DX01B487>LQ22489BT00acW
0R4800PU:B488@PLib48:DXaS2e[0RDY00D]Jc6<:DXQ22DY008YBP<Q20039BTQ22DY00HU:@8Q208L
i`8Q208Li`8DY@037>LQ22DY008U:@8]J`07:DXQ21BU6<HLib489BT00b4800@U:B487>LLi`DHaP<L
i`098@PLiacW6<HLib489BTYBRDY00<Li`<HaP077>LQ21cW8@PU:BU:8@P00QcW00<Q21cW6<H01acW
00DQ22U:9BTQ22DY00<YBP039BTQ2248008U:@037>LQ22DY008YBPDU:@8Q20079BTYBRe[9BTQ21cW
9BT00bU:00@U:B487>LU:@8YBP049BTLib489BT38@P39BT01R489BTU:BDY;F/YBP8U:@048@PLib48
9BT2:DX29BT00bU:;F/YBP02:DX29BT022U:9BTYBRe[:DXU:B489BT2:DX012DY8@PU:B480bDY00DY
BRe[<H`YBRDY008Q20037>LQ2248008Li`0:6<HU:BU:9BTQ21S648@DYAcW:DX2=Jd022e[8@PU:Be[
9BTLi`Q2124624800`@Q2488@P02248010@Q2488@PQ20P@Q00<8@P@Q12400P@Q00<8@P@Q12400P@Q
00H8@PaS2488@P@Q24831242248010aS2488@PQ20`aS00T@Q1BU6<HDYAS6:DXe[CW>=Jd00QS600<@
Q1BU6<H00QBU00HLib488@PLib487>L28@P00acW6<HDY@026<H25:D00`aS48@@Q0036<H00aBU6<HH
aP026<H37>L00aS65:DDY@025:D36<H35:D011S65:DDYABU1AS60QcW00DHaQcW5:D@Q1BU008HaP8D
Y@8HaP8DY@0348@DYAS6008DY@046<HDYABU6<H85:D26<H02ABU48@@Q1S67>LHaQBU48@DY@0248@2
5:D348@01ABU6<HDYABU6<H00QBU112400DDYA2448@@Q1BU00@@Q0045:DHaQBU48@25:D448@45:D2
48@236<248@25:D748@00`aS48@DY@0348@436<00a2436<@Q00236<448@010aS5:D@Q0aS0a2400<<
Ha245:D0112400dDYA245:D@Q1BU48@DYA2436<@Q0aS5:D@Q0025:D011245:DDYABU0Q2400<<Ha24
48@00Q240aBU0a2400PDYAS648@HaQcW6<HDY@aS0Q2400<DYA2448@00a241ABU00@@Q1BU5:DDY@<@
Q0055:D@Q12448@DY@0248@00`aS48@<H`0348@236<00a2436<@Q00348@00`aS48@@Q00236<01A24
36<@Q1245:D00Q2400@<H`Q236<<H`H@Q08<H`0748@<Ha245:D<Ha2436<00Q2410aS00<@Q1BU48@0
0@aS00002P0012448@@Q00048@0024848@000P@Q00HLidYB>LhYBSF]<H`39BT00be[:DXYBP03:DX3
9BT00bU:;F/YBP02:DX00bDY:DX]J`02:DX00bDY8@PU:@048@P011cW8@PQ22DY0R4800@U:B487>LY
BP8aS0099BTQ236<<H`U:AcW8@PYBRDY00HQ20049BTYBRDY8@P39BT00b487>LLi`029BT012486<HD
YABU0R4800LU:B489BT]Jc6<:DXQ20026<H01AcW9BTYBR487>L00b480acW00<HaQcW6<H00QS600<D
YAcW7>L00acW00<HaQcW8@P00RDY00<Q21cW7>L01QcW00PU:BU::DXQ21cW6<HLiaS60acW00@Q22DY
7>LLi`8Q208U:@8Q208U:@03:DXU:BDY00HU:@04:DXU:BDY8@P49BT28@P00bU:9BTU:@028@P01BDY
:DXYBRU:9BT00R4800DU:BU:;F/U:AcW008Q20037>LU:BDY008YBP8Q20057>LQ22DY;F/YBP029BT2
8@P39BT2:DX00b489BTYBP02<H`012U:8@PU:BU:0Re[00<YBRDY9BT00bDY0RU:00@U:B487>LLi`8U
:@03:DX]JbU:008YBP038@PLib4800<Q208Li`098@PU:BDY8@PHaQ246<HQ22DY008icP06;F/YBRDY
;F/U:AcW0`Q200@48@Q22488@P848@88@P0336<8@PQ200P48@<8@P<48@0524848@Q2248<H`042480
1@aS2488@PQ236<00`Q20PaS00<DYA246<H00QBU00@YBS6<?Nle[@8Li`0:5:D@Q1S648@DYAcW8@PU
:AcW6<H57>L36<H35:D01Q245:DDYABU48@HaP8Li`036<HDYAS6008Li`036<HDYAS6008DY@<HaP05
5:D@Q1BU6<HDY@026<H011BU6<HDYAS60QcW00@HaQcW7>LDY@8@Q0055:DLiaS648@DY@026<H25:D0
11S65:DHaQS60QBU0aS600<DYA245:D00aBU00<@Q1S65:D011S60aBU0a240QBU0a240QBU0QS60aBU
00H<Ha2448@@Q1S65:D448@011BU48@DYA2411BU0Q240QBU0Q240QBU00<HaQBU5:D00Q2400DDYA24
48@@Q1BU008@Q00336<@Q12400H@Q0@<H`035:D@Q12400D<H`075:D@Q0aS48@<Ha245:D00a2400DD
YA2436<@Q0aS00<@Q0035:D@Q1BU008HaP<@Q08<H`0348@DYABU00<DY@0648@DYABU48@DYA240PaS
00<@Q1BU5:D0112400LDYA245:DDYAcW6<HDY@0248@00aBU48@@Q00248@236<01QBU48@DYA2436<@
Q0<HaP045:D@Q0aS48@236<01Q245:D@Q12436<8@PD@Q0<<H`<@Q0P<H`<@Q0<<H`8@Q0<<H`<@Q08D
Y@0336<8@PaS008@Q08<H`0348@<Ha24008<H`0348@<Ha24008DY@4<H`000P@Q00<000@Q12401`@Q
00<Q25:D@Q000RU:00<U:BU:;F/012U:00HU:BU:;F/aS2e[:DX28@P00bDY8@PYBP02:DX29BT00b48
9BTQ20038@P47>L38@P29BT2:DX01be[:DXaS36<;F/YBR4800<U:@8YBP079BTQ22487>LQ22DY8@P0
0bDY00<]JbU:8@P00QcW0R4800<LiaS67>L00QcW0R4800DYBS6<<H`aS248008Li`0;6<HLibDY9BTQ
21cW6<HLibDY:DXQ20027>L01ABU6<HHaQS67>L00QS600@Lib487>LHaP8Li`048@PLib488@P27>L2
6<H011cW8@PU:BDY0b4811cW0R480QcW00HHaQcW8@PLib489BT28@P29BT00bU:9BTQ20029BT38@P2
9BT28@P00bDY;F/U:@028@P2:DX00bDY:DXU:@029BT01R489BTYBRe[:DXU:@8Q20049BTQ22488@P2
9BT37>L28@P39BT012489BT]Jbe[0RU:0QcW0R4800<U:BU::DX00Re[00<YBRDY9BT01RDY0R4800@U
:BU::DXYBP<U:@03:DXU:BDY008Q20049BTYBRe[:DX39BT28@P00acW8@PQ20028@P00acW8@PU:@03
9BT27>L00aS67>LQ20029BT27>L28@P00acW5:D@Q00348@00`aS2488@P0436<0112436<<H`aS0Q24
00@<H`Q22488@P8<H`<8@P0436<@Q0aS248836<348@00aBU6<HHaP028@P00acW8@PLi`027>L0136<
>Lhe[Be[0a240QBU00<@Q1BU7>L00R4800<LiaS66<H021S600<DYA245:D00QS600<LiaS65:D00QS6
00<DYAS66<H00QcW2AS60aBU1AS60QcW1aS60QcW00@HaQBU5:DDY@<HaP<DY@0436<DYAS67>L25:D0
11246<HLiaS611BU11S600DDYA245:DDYAS6008DY@8@Q08DY@0348@DYA2400<DY@0348@DYABU008D
Y@0348@DYA2400<DY@D@Q0045:D@Q1245:D26<H011BU48@<H`aS0aS600<DY@aS48@00QBU0a2400@D
YAS65:D@Q08<H`035:D@Q124008@Q00436<@Q0aS48@236<448@236<548@00`aS48@@Q00248@236<3
48@00`aS48@DY@0348@25:D348@00`aS48@@Q00248@35:D348@236<348@00aBU48@@Q00348@00`aS
48@DY@025:D01A245:DDYA2436<01A2400<<Ha2448@00Q2400@DYA245:DDY@<@Q0065:D@Q1BU48@D
Y@aS0Q240aBU11240QBU00@@Q0aS36<<H`8@Q00536<@Q12448@DY@0248@536<00a2436<@Q00436<0
0a245:D@Q0025:D448@00aBU36<<H`0236<01A2436<<Ha2436<00a240ABU0@aS00000`@Q00048@02
12400`0012448@0412401B48BU8mkbDY;F/00RU:00<U:BU::DX00bDY00<YBRe[;F/00RU:0b480RDY
00<YBRDY9BT00R4800DLibDY:DXYBRDY00@Li`059BTLiacW9BT]J`02:DX2;F/023F]<H`YBRU:9BTQ
22DY8@P29BT00bU:9BTLi`027>L48@P01RDY;F/YBQcW6<HLi`8U:@057>LHaR487>LHaP027>L01Re[
=JdaS2e[9BTHaP<Li`038@PU:B48008Li`038@PU:B48008Q20<HaP045:DHaQS66<H28@P011cW6<HH
aQBU0QcW00<Q21cW7>L00R480acW00<Q22DY8@P00b480QcW00@HaQcW7>LHaP8Li`048@PLiacW6<H2
8@P2:DX49BT012489BTU:BDY0b4800<U:B489BT01BDY00<Q22DY9BT00RU:00@U:AcW8@PU:@<YBP8Q
20037>LQ224800<U:@067>LQ21cW8@PU:BU:0bDY0R480RU:00@]JbU:8@PQ208U:@04:DXQ22489BT3
:DX03BDY:DXYBR489BTYBRDY7>LQ22DY:DX]JbU:00<U:@8Q208U:@8Q2004:DX]Jbe[:DX29BT02B48
7>LQ22489BTLiaS68@PU:@028@P29BT012487>LHaQS60R4800PU:B487>LQ21cW8@PHaQBU0PaS0Q24
00D<Ha2436<<H`Q2008<H`0548@<H`Q236<@Q00236<4248236<248@020aS2488@PQ236<@Q0aS2482
36<00a245:D@Q00248@25:D26<H01B487>LQ21cW8@P00S6<00De[Be[6<HDYA24008DY@0536<@Q1S6
9BTQ20025:D26<H011cW6<HDYAS60QcW00DHaQBU48@@Q1BU00HHaP055:DHaQS66<HLi`036<H011BU
6<HHaQBU0aS600DDYA245:DHaQBU008HaP037>LHaQcW008Li`<DY@046<HLiacW6<H35:D26<H25:D0
0aS65:DHaP035:D00aS65:DDY@025:D00acW6<HHaP065:D01A245:DDYABU48@01aBU11240QBU0Q24
0aBU00<@Q1BU48@00QBU00D@Q0aS36<DYAS600@@Q0035:D@Q1BU00<@Q0055:DHaQS66<HDY@0348@0
11BU48@@Q1BU0a2410aS112400D<Ha2436<@Q0aS00<@Q0<<H`<@Q0045:D@Q1BU48@336<011245:D@
Q0aS2A2400<DYA2448@00Q2400@DYA245:DDY@8HaPH@Q00436<@Q0aS36<248@01@aS48@@Q1246<H0
0QBU00<<Ha245:D00QS610aS0a2400H<Ha2448@DYA245:D248@75:D01a2436<@Q1BU6<HDYA24008<
H`0648@DYA2448@<Ha2410aS1A241@aS0a2410aS00<@Q0aS48@00QBU0Q2400<<Ha245:D00Q2400<<
H`Q236<00Q2400<<Ha2448@00PaS0Q240@aS0000100012448@001P@Q00D000@Q7>M>Lcg_008]J`8U
:@<YBP8U:@04:DX]Jbe[:DX29BT28@P29BT3:DX01BDY8@PQ22U:9BT00QcW0b480QcW00@Q21cW8@PQ
20DYBP089BTYBRDY8@PU:BU:;F/YBP<U:@0;8@PLib488@PU:B489BTYBRe[:DXQ20037>L022486<HL
iacW6<HQ22DY:DX29BT01be[<H`YBQcW6<HLiaS6008Li`<HaP<Q20049BTLiacW7>L26<H00acW6<HL
i`026<H67>L26<H37>L011S67>LLibDY0b4811cW00DQ21cW7>LHaQcW008Q20@Li`038@PU:BU:00<U
:@8YBP8U:@06:DXU:B488@PU:B4812DY00PQ22DY8@PQ22U:;F/YBRDY0R4800HU:Be[:DXYBR487>L2
8@P29BT011cW8@PLibDY0R480QcW00PQ22DY9BTQ22U:;F/aS2e[0RDY0b480bDY12U:0RDY0R4800<U
:B489BT00b4800LYBRe[9BTQ22DY:DXU:@028@P00bDY:DXYBP029BT2;F/032U:8@PQ2248:DX]JbU:
8@PU:B487>LQ208YBP039BTQ21S600@Li`<Q20<Li`058@PLiaBU5:D<H`0548@224800`aS48@DY@03
48@25:D0112436<8@PaS0Q240PaS0a240`aS00D8@PaS48@<Ha24008<H`D@Q0055:DHaQcW7>LHaP02
7>L28@P01acW6<HDYABU6<HDYAS6008DY@046<HDYABU6<H25:D011S65:DHaQBU1AS60QBU1AS60QBU
00PHaQcW6<HLiaS67>LHaQBU1AS600@DYAcW6<HLi`PHaP8DY@<HaP045:DHaQS67>L46<H00aBU6<HH
aP025:D00a245:DDY@026<H55:D00aS65:DDY@0<5:D448@45:D01Q245:D@Q1245:D@Q0<DY@D@Q08D
Y@0348@DYABU008DY@046<H@Q12436<35:D00a245:D@Q00248@01@aS48@@Q1245:D01A2400<DYA24
48@00PaS0a240`aS2a2400D<Ha2448@@Q1BU00H@Q00336<@Q0aS00D@Q08DY@0348@<H`aS008DY@03
6<HDYA24008@Q08DY@8@Q00436<@Q1BU48@236<011245:DDY@aS1A240QBU00D@Q1BU5:DDYA24008<
H`D@Q0065:D@Q1BU48@DYA240QBU00D@Q1BU5:DDYA24008DY@066<HDYABU6<H@Q1BU0PaS11240PaS
0Q2400<<Ha2448@00a240QBU00<@Q0aS36<01`aS00<@Q1BU48@01A2400@<Ha245:D@Q08<H`<@Q0D<
H`<@Q0000P@Q00H000@Q124000@Q248312401P007>M:DT8@:DX]J`8U:@<YBP@U:@<YBP039BTQ2248
008U:@05;F/YBRDY8@PLi`029BT28@P27>L012487>LLibDY124800DU:Be[:DXYBRDY00<YBP<U:@08
:DXU:BDY8@PU:AcW8@PLi`<Q208YBP04;F/YBRDY9BT28@P27>L26<H011BU8@PYBRe[0RDY00HicSF]
:DXHaQBU6<H27>L36<H00acW8@PLi`048@P011cW6<HHaQS60QcW00DDYAS67>LQ21cW00@HaP8Li`03
8@PLiacW008Li`8Q20049BTQ21cW8@P37>L26<H37>L01B486<HLiaS67>L00RDY00<YBRDY9BT00bU:
1RDY00HQ22DY9BTU:BU:9BT38@P032DY:DXU:BDY:DXU:B489BTYBRe[:DXQ208Li`8Q20<U:@048@PL
ibDY8@P27>L01R48:DXQ22489BT]J`8aS08U:@037>LQ22DY00<U:@048@PU:BU::DX49BT38@P01BDY
8@PU:BU:;F/00RU:00@U:BU:9BTU:@8Q208U:@05:DX]JbU:;F/YBP028@P00bDY:DX]J`039BT00b48
7>LLi`02:DX02RDY7>LLiacW6<HDYAcW8@PU:B480QcW0R4800DLiaS65:D@Q1BU008<H`88@P8<H`<@
Q0065:D@Q1245:D@Q1BU0`aS11240`aS00<@Q0aS36<00`aS00H@Q0aS36<<Ha245:D348@00aBU6<HL
i`057>L01B486<HDYA245:D00QS600<DYAS66<H011BU0QS60aBU11S600@DYAS65:DHaP8DY@8HaP03
5:DHaQS6008DY@DHaP037>LHaQBU00@HaP035:DHaQS6008HaP0348@HaQS6008Li`8DY@8HaP035:DH
aQBU00PHaP8DY@8HaP8DY@8HaP<DY@<HaP0348@DYABU00<HaPDDY@0548@DYABU5:DHaP085:D01124
5:D@Q1240QBU11240aBU0Q2400@DYA2448@@Q0<DY@8@Q00336<@Q12400@DY@@@Q08DY@X@Q08<H`<@
Q0<<H`065:D@Q0aS36<@Q0aS1A240aBU1Q240PaS00@@Q1BU48@<H`8@Q0035:D@Q12400<<H`<DY@09
6<HDY@aS36<@Q1BU6<HDYA24008<H`0548@DYA2448@<H`0348@35:D01@aS48@DYABU6<H00Q2400D<
Ha2448@@Q1BU00@@Q0DDY@0348@DYABU00@DY@0648@DYABU6<HDYA240PaS00<@Q1BU48@00a2410aS
00D@Q0aS48@DYA24008<H`8@Q0<<H`8@Q0<<H`D@Q00336<@Q12400<@Q0<<H`03248<H`Q200<<H`<@
Q04<H`48@P0000<000@Q12400`@Q00<000@Q12400P@Q00P8@RU:CW<e[AcW:DXaS2U:0RDY00<YBRDY
:DX00bU:0RDY00HYBRDY9BTU:B489BT2:DX29BT00b489BTQ20068@P27>L29BT00be[:DXU:@029BT2
:DX012DY8@PU:BU:0RDY0Re[00<YBRDY8@P00R4800<LibDY9BT00Re[00PYBRDY7>LQ22DY8@PLiaS6
0QcW0RDY00LQ22U:<H`]Jb486<HLi`028@P47>L01aS68@PQ22DY8@PLib4800<Li`8HaP037>LQ2248
00HLi`<HaP037>LHaQS6008HaP8U:@048@PLiacW7>L29BT38@P37>L01b487>LLiacW6<HU:B48008Y
BP059BTYBRU:9BTYBP049BT3:DX012DY8@PU:BDY0R4800@U:B48:DXYBP8U:@078@PU:BDY9BTYBRe[
:DX00b4800@YBRDY7>LQ20<U:@038@PLib48008Q20@U:@<aS005:DXQ22DY9BTQ20059BT2:DX59BT4
8@P29BT02RU:;F/U:BDY;F/aS2e[9BTQ21cW0RU:00@]JbDY8@PU:@8YBP039BTQ224800<U:@058@PL
ibDY:DXU:@047>L00b487>LHaP026<H27>L38@P012DY7>LLiacW0b4800DHaQBU5:D@Q1BU008@Q08<
H`0448@<H`aS48@336<010Q236<<H`aS0PQ20PaS0Q2400<<Ha2448@00`aS0Q240PaS00@@Q1S65:DD
Y@@HaP<DY@036<HDYAS6008DY@036<HDYABU008HaP8DY@0>48@DYAcW7>LHaQ245:DHaQcW6<H@Q1BU
6<HLi`@HaP8Li`056<HDYAS66<HDY@046<H012486<HHaQ2411S600HLiaS66<HHaQcW8@P26<H011BU
6<HLiacW0QS600HDYAS66<HHaQBU6<H25:D36<H25:D00a245:DHaP025:D011S65:DHaQS611BU11S6
11BU00<HaQBU48@00QBU00D@Q1BU48@DYAS6008DY@<@Q0045:D@Q1BU5:D248@00`aS48@@Q0025:D0
0a245:DDY@035:D448@01QBU48@DYA2436<DY@8@Q0055:D@Q1BU48@DY@0548@010aS48@<H`aS1a24
00<<Ha2448@01A240`aS00D@Q1BU48@DYA2400<DY@8@Q00336<DYABU008@Q08<H`0348@DYA24008@
Q08DY@<@Q0035:D@Q1BU008@Q0<DY@066<HDYABU48@DYA240`aS00<@Q0aS48@00aBU0Q2400LDYA24
5:DDYA245:D@Q0045:D248@00aBU48@@Q0035:D011S65:DHaQBU0Q241ABU112400<DYA2436<01a24
1@aS0a240`aS0QBU00H@Q0aS248<Ha245:D248@00`aS48@DY@025:D648@00`aS48@<H`0336<00a24
36<<H`0348@000@48@0400048@@Q2484124012DYDY@icR480Re[2BU:12DY0R4800@YBRe[:DXU:@@Q
20039BTQ22DY00<Q20087>LHaR487>LQ22U:;F/YBP8Q2007:DXU:B488@PU:BU:9BT012U:00<U:B48
9BT00b4800@U:Be[:DXYBP8U:@068@PLib488@PHaQBU0QS60RDY0Re[00HYBR487>LLib487>L26<H2
7>L00aS67>LQ20029BT57>L00aS67>LLi`077>L00aS67>LLi`027>L36<H021cW8@PQ22487>LHaR48
9BT28@P27>L01aS67>LQ22487>LHaQBU00<Li`049BTYBRe[;F/29BT00bU:8@PU:@029BT2;F/29BT6
8@P3:DX39BT00b489BTU:@03;F/03RDY8@PQ22489BTQ22DY8@PU:B487>LU:B487>L28@P012U:9BTU
:Be[0S6<00<YBRDY9BT00b480bDY0RU:0bDY00<Q22DY8@P00b4800<U:B489BT00bU:00DU:Be[<H`]
JbDY008Li`069BTYBRe[:DXU:B480bDY00DQ21cW9BTYBRDY00<Q208U:@8Li`8Q20<Li`8HaP047>LQ
22DY8@P27>L00b487>LLi`037>L01AS65:D@Q12436<00aBU00<@Q0aS36<00PaS0Q2410aS00@8@PaS
36<<H`<8@P@@Q0L<H`0548@DYAS67>LHaP035:D26<H00aBU6<HHaP025:D011245:DHaQcW0QS611BU
00@HaQBU6<HDY@8HaP035:DHaQBU00DHaP8Li`036<HDYAS600HHaP057>LHaQS648@HaP027>L26<H0
1AcW8@PLiaS67>L01AS600HLiaBU6<HDYAS65:D36<H011BU48@DYAS60aBU00D@Q1BU5:DHaQcW008H
aP8DY@8HaP055:D@Q1BU48@DY@046<H248@00aBU6<HDY@0448@011S65:DDYABU0a2400@DYA245:D@
Q0<DY@@@Q00336<@Q1BU008DY@8@Q08DY@0448@DYABU5:D248@00aBU48@DY@035:D348@01QBU48@<
H`aS48@DY@<@Q08<H`<@Q08DY@0348@<H`aS008@Q08<H`D@Q0035:D@Q0aS00<DY@<@Q0035:D@Q0aS
008@Q00436<@Q12448@25:D00a2436<<H`0348@35:D01Q245:D@Q1BU48@DY@H@Q00336<@Q124008<
H`0448@DYAS65:D248@011BU48@@Q1BU2Q240QBU00<@Q1S65:D00QBU0Q241aBU0Q240`aS0a241@aS
0a2400<<Ha245:D00Q2400D8@PaS48@<Ha2400L<H`8@Q0065:D@Q0aS36<@Q1BU0Q2410aS0Q2410aS
00<DYA2448@00@aS00001P@Q00048@00124000H48@049BU6<C6<8@P3;F/00bDY:DXU:@029BT28@P0
0bDY:DXYBP04:DX022DY8@PQ22DY8@PU:B489BT88@P29BT012U:9BTU:AcW12DY00<Q22DY:DX00RU:
00LU:BU:;F/YBRDY8@PU:@028@P2:DX01Be[:DXQ22489BT00RU:0R4800@HaQcW9BTU:@8YBP059BTQ
22488@PU:@028@P02acW8@PQ21cW8@PLibDY:DXU:B486<H00QcW0b480QcW00<Q21cW7>L00QS611cW
00<Q21cW6<H00QS600<Lib489BT00R480acW00DQ22DY8@PU:B4800<Li`058@PLiaS66<HLi`038@P4
:DX2;F/00bDY8@PU:@02:DX29BT012489BTYBRU:0b4800HU:Be[:DXU:B489BT3:DX00bDY:DXU:@02
9BT00b489BTQ20028@P29BT28@P011cW8@PQ22480RDY0RU:00H]JbU:9BTQ21cW8@P5:DX29BT3:DX3
9BT012487>LQ22480bDY00LQ22U::DX]Jc6<;F/U:@028@P3:DX00b489BTU:@029BT2:DX39BT01bU:
9BTLib489BTYBRDY00<Li`065:DLiacW9BTQ21cW0R480RDY0QcW00<HaQcW7>L00R480aS61AcW00<H
aQcW5:D00a2400DDYA245:D@Q1BU008@Q00336<@Q12400D@Q0035:D@Q0aS008@Q0036<HDYABU00<D
Y@8HaP085:DHaQS65:D@Q1BU7>LHaP<@Q0046<HLiaS65:D248@011BU6<HHaQS60QBU0aS60aBU0QS6
0QBU0QS600<LiaS66<H00QS600@DYAS67>LLi`8DY@046<HLiacW6<H25:D27>L00b487>LHaP026<H0
1AcW8@PHaQS648@00QBU00@LiaS66<HDY@@HaP0948@HaQS66<HDY@aS48@DYAS600TDY@@HaP@DY@03
48@DYAS6008HaP8@Q08DY@0448@DYABU5:D248@45:D02A245:D@Q1BU48@DYA2436<@Q0035:D348@2
5:D011245:D@Q1240aBU00D@Q1BU48@DYA2400<DY@0448@<Ha245:D248@00`aS48@@Q00248@01@aS
48@@Q1BU48@00PaS00<@Q1BU48@00Q240`aS312400<DYA2448@02Q240PaS00<@Q1BU5:D01ABU0Q24
0aBU1A2400<<Ha2448@00aBU0a240aBU0PaS0Q240aBU00H@Q0aS36<@Q1BU48@35:D26<H65:D01AS6
5:D@Q12436<00Q240PaS00T@Q0aS36<@Q0aS48@<Ha245:D0112400@<Ha2448@DY@<<H`8@Q0<<H`D@
Q0<DY@D@Q08<H`H@Q0<<H`<@Q00000<000@Q12401`@Q00P000Q29BU:DRe[7>L]Jc6<0bDY00P]JbDY
9BTQ22DY:DXU:Be[0bU:0RDY0R4800DLib489BTU:B48008U:@038@PU:AcW008Li`048@PU:BDY:DX2
9BT28@P39BT012489BTU:BU:0RDY00<YBRe[:DX00RDY00@YBRDY8@PU:@8]J`039BTLib48008U:@<Q
20047>LQ22488@P2:DX00bDY:DXQ20047>L48@P011cW8@PQ22DY0R4800HLiaS67>LLibDY8@P37>L0
0b487>LLi`027>L01aS67>LLiacW6<HLiaS600<Li`048@PU:B488@P27>L48@P00acW8@PLi`038@P0
0aS67>LQ20038@P3:DX00bDY:DXYBP069BT00b487>LQ20029BT38@P3:DX29BT00b489BTYBP02:DX4
9BT00b489BTQ20058@P37>L012489BTQ22480RU:00<]JbU:9BT00RDY00<Q22DY9BT00bU:0bDY0RU:
0RDY1b4800@U:B489BTYBP8]J`8YBP8U:@038@PU:BDY00<U:@8Q20039BTYBRDY008Q20<U:@058@PU
:B488@PLi`036<H01QcW8@PQ21cW6<HLi`8U:@<Li`038@PHaQcW008Li`048@PLiaS67>L26<H011cW
8@PQ21cW0a240PaS0aBU0PaS00DDYA2448@@Q0aS008@Q0055:D@Q12436<@Q0025:D011245:DDYABU
0aS600<DYAS66<H00aS60QBU00@@Q1BU48@DY@DHaP@DY@@HaP8DY@036<HDYAS600<DY@<HaP<DY@@H
aP097>LHaQS65:DHaQcW6<HLiaBU00<HaP<Li`085:DHaQS67>LHaQBU48@DY@@HaP@DY@0648@DYABU
6<HLiaS60QBU00@@Q1BU5:DDY@8HaP@DY@8@Q0065:DHaQS66<HDYAS60aBU0QS60QBU0a2400<DYA24
5:D00Q2400@DYA246<HHaP8DY@<@Q0035:D@Q0aS008<H`0448@DYA2448@45:D00aS648@@Q00248@2
5:D248@35:D548@01PaS48@<H`aS48@DY@8@Q00636<@Q1245:D@Q0aS0a240PaS1A2400@<Ha245:D@
Q08<H`0348@DYABU008@Q0035:D@Q12400D@Q0<<H`0548@DYA2448@<H`0248@65:D00a245:DDY@02
48@011BU6<HDYA240PaS11240QBU0Q2400@<Ha2448@DY@H@Q00436<@Q12448@25:D00a2436<DY@02
5:D00aS648@@Q0065:D336<011245:D@Q1241@aS2Q2400D<Ha2436<<Ha2400<<H`0548@<H`aS36<@
Q0025:D448@00aBU36<<H`0236<01A2436<<H`aS48@00`aS00<@Q1BU5:D00@aS0002124020001244
8@@Q0008@P@Q0002124012DY@Q0]JacW0Re[00@YBR489BTYBP8U:@048@PU:BU:;F/29BT00acW9BTU
:@028@P00aS67>LLi`038@P011cW8@PLiacW0RDY00DYBRDY9BT]JbU:008U:@@Q20<U:@8Q2003:DX]
JbDY00@U:@078@PU:BU::DXU:AcW9BT00b480Re[00DQ21cW7>LU:BU:00<U:@8Q20037>LQ22DY008U
:@<Q20037>LQ224800<Q20<Li`038@PLib48008Q20<Li`8Q208Li`8U:@038@PLiacW008Li`038@PL
iacW00@Li`<Q20047>LQ22489BT87>L00bDY8@PYBP02:DX39BT2:DX29BT012U:9BTQ22480RDY00HQ
21cW8@PQ22DY8@P6:DX59BT2:DX00bDY8@PQ20028@P01RDY8@PLib489BTYBP<Q20059BTYBRe[:DX]
J`038@P012DY;F/YBRDY0RU:0RDY00<Q22DY8@P00R4800XU:B488@PQ22DY8@PLib489BTYBP8]J`09
9BTQ22489BT]JbU:9BTYBRDY008Q20049BT]JbU:8@P39BT28@P00bDY:DXU:@028@P37>L01QS67>LQ
22DY:DXU:@DQ208Li`8Q208Li`8HaP8Li`<HaP047>LHaQS648@25:D01A245:DHaQS67>L00QS600<D
YAcW6<H011S611BU00@@Q1BU5:DLi`<HaP035:DHaQS600<Li`<HaPPDY@0648@DYABU5:DHaQBU0aS6
0QcW1AS60QBU1AS600HDYAcW7>LQ22U:7>L36<H012487>LLiaS60QBU2aS600@LiaS65:DDY@8HaP07
7>LHaQS65:D@Q1S65:D00QS60QBU0Q2400@HaQBU5:DDY@8HaP045:D@Q1245:D36<H01QBU6<HHaQS6
5:DHaPDDY@0348@DYAS600@DY@8@Q0DDY@<@Q0045:D@Q1BU36<348@01ABU48@@Q0aS48@00QBU00<@
Q1BU48@00Q2400<DYA245:D00Q240QBU0Q240aBU1A240`aS0Q2400<DYA245:D00a2400<<Ha2448@0
0Q2400@<Ha2436<<H`8@Q0035:D@Q124008@Q0035:D@Q12400P@Q00936<@Q1245:D@Q0aS48@DYAS6
00<@Q0045:D@Q12448@36<H25:D348@336<25:D01A245:DDYA2436<00aBU112400<DYA245:D00a24
00<<Ha2448@00Q2400DDYA245:DDYA2400<HaP055:D@Q1BU5:D@Q00236<00a245:D@Q00=48@00aBU
48@@Q00248@236<00a2436<<H`0436<0112436<@Q1240QBU11240QBU1Q2400D<Ha2436<@Q1BU00<@
Q00000D48@0012448@0000H48@05248Lid8@<H`U:@02;F/39BT012U:9BTQ22DY0RU:00@Q22DY9BTU
:@@Q20037>LQ224800<Q208Li`038@PU:BDY00<U:@8YBP06;F/U:B487>LYBRDY0R480RDY00DQ22DY
9BT]JbU:008U:@0<:DXU:B489BTYBRe[:DXU:B489BTQ22DY0RU:00DU:B487>LU:BU:008Q2004:DXU
:B486<H28@P012DY8@PQ22DY0b4800DLib488@PLib4800<Li`8Q20039BTQ21cW008Li`058@PLiaS6
6<HLi`029BT011cW5:DLiacW0R4800@LiaS68@PQ208Li`8U:@058@PLib489BTQ20067>L012487>LQ
22U:0be[0RDY00@YBRDY9BTU:@<Q20<U:@<Q20<U:@8Q208U:@04:DX]JbU::DX39BT00bU:9BTU:@02
8@P39BT37>L01B48:DXYBR487>L00RDY00@YBRe[:DXU:@8Q20039BTYBRU:00<YBP039BTQ22DY00<U
:@<Q20<U:@8Q208U:@07:DX]Jbe[:DXU:B489BT012U:0RDY00@Q22U::DXU:@8Q208U:@037>LQ22DY
008U:@<Q20@Li`098@PU:BDY8@PLib489BTYBR4800<Li`8Q20037>LHaQS600<Li`075:DHaQcW8@PH
aQBU48@00QBU0aS600@DYAS66<HQ208Li`035:DHaQS6008DY@0348@DYABU00THaP8Li`DHaP035:DH
aQBU008DY@0448@HaQS66<H45:D86<H00aBU7>LHaP036<H01AcW6<HHaQBU6<H00QcW0RDY00DQ21cW
5:DHaQcW008Q20<DY@066<HLiaS65:DHaQcW0QS600@DYAS65:DLi`DHaP035:DHaQBU00DDY@8HaP8@
Q0@DY@0348@DYABU00<HaP0748@HaQS66<HDYAS65:D00QS60aBU0QS60QBU00D@Q1BU5:DDYAS600<D
Y@8@Q0<DY@0448@DYA2448@35:D448@00aBU48@@Q00248@25:D00a2436<@Q0035:D248@45:D348@0
11BU48@<H`aS0Q2400<DYA2448@00a2400DDYA2448@@Q0aS00D@Q00436<@Q12436<248@021BU48@@
Q1245:D@Q0aS48@35:D448@00`aS48@@Q0025:D0112436<@Q1241QBU0Q240aBU00DHaQBU5:DHaQBU
00@@Q00436<@Q12448@25:D548@00aS65:D@Q00336<0112436<@Q0aS0Q2400<DYA245:D00QBU00HH
aQBU48@@Q1BU6<H25:D010aS48@@Q0aS1A2400@<Ha24248<H`8@Q0045:D@Q12448@25:D248@236<0
0a2436<<H`0436<00a2436<@Q00;48@01QBU48@<H`aS48@DY@8@Q0045:D@Q12448@136<000040004
8@@Q000612402000124Q248@<H`Q22U:;F/4:DX01B489BTQ22DY:DX00RDY00<YBRDY9BT00acW1248
00@Lib488@PLi`8Q200>9BT]JbU:9BTQ22U:;F/YBRDY8@PLib489BT]J`<YBP8U:@038@PU:BDY008U
:@8Li`059BTYBRU:9BTLi`028@P49BT38@P01acW8@PU:BDY8@PLiaS6008Q20<YBP049BTQ21cW8@P3
9BT00b487>LQ20037>L28@P87>L01BDY:DXU:B486<H00R4800<LiaS66<H00R480QS600<Lib487>L0
1B4800<Lib486<H00QcW00HU:B487>LQ22DY:DX39BT01BU:9BTU:B489BT00R4800@LibDY9BTU:@<Q
20@U:@8Q208U:@06;F/aS2e[9BTLib480RDY0bU:00HU:AcW7>LLibDY8@P29BT00b489BTU:@03:DX0
12DY8@PU:B480bDY0bU:0R480RDY0b480RDY0b4800<U:B488@P00R4800@YBRe[:DXU:@<YBP039BTQ
224800<U:@03:DXU:B48008Q208U:@038@PLib4800<U:@LQ2003:DXU:BDY008Q20049BTYBR487>L2
6<H37>L29BT28@P27>L022486<HQ22DY8@PLiaBU48@35:D36<H27>L01QS67>LLiacW6<HDY@DHaP04
5:DLiacW7>L36<H00acW6<HDY@046<H27>L26<H25:D36<H25:D00aS65:DHaP026<H37>L021S65:DH
aQcW8@PLiaS65:D46<H02ABU6<HHaR489BTQ21cW5:DHaP047>L86<H031BU6<HHaQS67>LDYAS65:DH
aQcW8@PLi`@DY@8HaP035:DHaQS600PDY@046<HDYAS66<H25:D26<H01acW6<HHaQBU7>LHaQ24008D
Y@036<HDYABU008HaP0348@DYA2400@DY@0348@DYABU00@@Q0<DY@<@Q00336<DYABU008@Q00436<@
Q1BU5:D948@011BU48@DYA240QBU00D@Q1BU48@@Q0aS008@Q0035:D<H`aS008@Q08DY@0336<@Q124
008@Q0<<H`0448@<HaBU5:D248@236<00aBU48@DY@0248@236<248@25:D348@010aS48@@Q1BU0a24
0QBU00D@Q1BU5:D@Q1BU008@Q0@DY@8@Q0075:DHaQBU48@DYA2436<00QBU00<HaQBU48@01A240QBU
00@@Q0aS36<<H`@@Q00336<@Q124008DY@<@Q0<DY@<@Q08DY@8@Q00436<@Q1BU48@336<00a2436<<
H`0348@01QBU48@@Q0aS48@<H`P@Q0L<H`0348@DYA24008@Q0035:D<H`aS008@Q0045:D@Q1245:D3
48@25:D448@136<000D48@0300048@@Q00@48@057>M:DS6<8@PYBP02;F/3:DX01bDY8@PU:BU:9BTQ
22DY008YBP038@PHaQcW00<Li`038@PU:BDY008Li`8Q20037>LQ22U:00HYBP039BTQ2248008U:@8Y
BP<U:@068@PU:BDY9BTQ22DY0QcW00@U:Be[;F/U:@8Li`8U:@05:DXU:B488@PU:@028@P2:DX02BDY
7>LDYAcW9BTQ22DY:DXU:@028@P011cW8@PU:BDY1B480acW0R480QcW00<Q21S67>L00QS600<Q22DY
9BT00acW0R4800LLib488@PQ21cW6<HLi`028@P01RDY8@PQ21cW8@PLi`8HaP047>LQ22488@P27>L5
9BT022U:9BTQ22489BTQ21cW8@P39BT28@P49BT28@P00bDY:DXU:@03:DX29BT00b48:DXYBP02:DX0
12e[9BTLiacW0RDY0R480RDY00<Lib489BT00RU:00DQ22DY:DXYBR48008U:@06:DX]JbDY8@PU:B48
0RU:0R4800@LibDY9BTU:@8Q208U:@088@PU:BDY:DX]JbU:9BTYBPDU:@038@PU:BDY00<U:@<YBP<U
:@<Q20037>LQ21cW00<Q208U:@8YBP@U:@8Li`8HaP<Li`048@PU:B487>L38@P37>L26<H45:D26<H0
0aBU6<HLi`057>L011S65:DDYABU1AS60acW1QS600HLiaS65:DHaQcW6<H248@01ABU7>LHaQBU6<H0
0QBU00<HaQBU5:D00QS60QcW0QS600<DYAS67>L00acW00<HaQBU6<H00aS600<DYAS67>L00R4800<L
iaS67>L011cW2aS600@DYAS65:DDY@<HaP047>LHaQS65:D36<H01QBU6<HHaQS65:D@Q0HDY@0548@D
YAS67>LHaP025:D27>L26<H00acW5:DDY@025:D26<H25:D348@35:D021S648@@Q1246<HDYA2436<2
48@25:D00a2436<@Q0025:D248@010aS48@@Q1BU212400/DYA2448@DYA245:D@Q0aS48@<HaBU008@
Q00436<@Q1245:D648@010aS48@DYA240`aS1a2400@DYA245:DDY@@@Q0035:D@Q1BU00D@Q0055:D@
Q1BU48@<H`0248@011BU6<HDYABU0Q240aBU0a240QBU00D@Q1BU5:DDYA24008<H`0448@DYAS65:D2
48@25:D01PaS48@HaQBU48@<H`H@Q00436<@Q12448@25:D01A245:D@Q1245:D00Q240aBU0Q2400HD
YA2448@<Ha2436<448@010aS48@@Q0aS0Q2400<DYA2448@01Q2400@<Ha2436<<H`8@Q0<<H`0448@D
YA2448@236<00a245:DDY@0448@010aS48@@Q1BU0Q240QBU0Q240@aS00000`001240000812401@Q2
9BU:DSF]8@P012U:0RDY00<Q22DY9BT00RU:0RDY0R4800DU:B488@PQ21cW008Q20059BTQ21cW7>LQ
20039BT28@P00bDY8@PU:@029BT022U:8@PLibU:<H`e[C6<9BT48@P01BDY8@PQ22489BT00bU:1248
0RDY0R4800DU:B489BTU:B48008U:@8Li`8HaP05:DX]Jbe[;F/Q20027>L58@P00acW8@PU:@038@P3
9BT012487>LQ22DY1B480RDY00<Q22DY8@P00QcW0b480QS60acW00@Q22U:9BTQ208HaP8Q20047>LQ
22489BT2:DX00b489BTU:@039BT2:DX38@P01BDY:DXYBR487>L00R480RU:00PU:B488@PQ21cW9BT]
JbU:0R4800@U:BU:9BTU:@<YBP038@PLiacW008Q208U:@8Q20039BTYBRU:008U:@@YBP<U:@8YBPDU
:@068@PU:BDY9BTQ21cW0b4800<U:B489BT01BDY0RU:00<U:BU:9BT00bU:00<]Jb488@P00b481bDY
00<LiaS68@P01B480RU:0RDY0R4800@U:B488@PQ208Li`066<HLibDY8@PLiaS60acW0R481AcW0QBU
00PHaQcW7>LHaQcW9BTYBR480QS600/LiaS67>LLiaS67>LQ21cW6<HDYAS6008Li`@HaP037>LHaQS6
00LHaP045:DHaQcW6<H25:D26<H35:D27>L01QBU6<HHaQcW6<HDY@8HaP055:DHaQS67>LQ20027>L0
11S67>LLiacW0QS60QcW00DHaQcW7>LLiaS6008DY@046<HLiaS65:D56<H011cW6<HHaQBU0QS60QBU
00<@Q1BU6<H01AS60Q240QBU00<HaQBU5:D00aBU00<HaQBU5:D00aS61ABU0aS600<DYA246<H00QS6
1QBU0Q241ABU00P@Q0aS48@@Q1BU48@<Ha240QBU00H@Q0aS36<DYA245:D248@00`aS5:DDY@0248@2
36<35:D348@021BU48@@Q12436<@Q1BU48@35:D00a245:D@Q00248@011BU48@<H`aS212400@<HaBU
48@DY@@@Q0035:D@Q12400D@Q0035:D@Q1BU00<DY@0448@DYAS66<H348@011BU48@@Q1240QBU1124
00D<Ha245:DHaQBU008@Q0045:DHaQS65:D348@35:D011245:DDYA240`aS00<DYA245:D00Q240QBU
112400<DYA2448@00Q2411BU0a240PaS0Q2400<<Ha245:D00QBU1a2400L<Ha2436<@Q0aS48@<H`03
48@236<348@436<00a2436<@Q00548@236<248@236<25:D548@000<48@0300048@0000<48@070004
8@@Q8@Q:DSF]8@P01BU:00<U:B488@P00RDY00<YBRDY8@P00RDY0b4800@U:B488@PQ208U:@@Q208U
:@<Q20DU:@8Q2008:DX]JcF];F/U:BU:9BTLi`8Q20049BTQ22489BT2;F/00bDY7>LU:@038@P01BDY
:DXU:AcW8@P00bDY0b480acW00DQ22e[<H`YBR48008Li`8Q20049BTQ22488@P27>L48@P02RDY8@PL
ibDY:DXU:AS67>LQ22U:0R4800<LibDY8@P012480QcW00<Q21cW7>L00QcW00LQ22DY:DXQ21cW6<HL
i`038@P00acW8@PQ2002:DX01BDY8@PU:BDY:DX00bDY224800@U:BU:9BTU:@@Q20<U:@038@PU:BDY
008YBP8U:@03:DXU:BDY00@Q20<U:@078@PU:BU:;F/YBRDY8@P01bU:1BDY00<Q22DY7>L00R4800@U
:B487>LQ208U:@8Q2003:DX]JbU:00<U:@8YBP8U:@03:DXaS2U:00<Q200B:DXU:BDY8@PYBRDY8@PU
:BU:9BTQ21S67>LQ21cW8@PLibDY0bU:124800DU:B488@PQ21S6008Li`068@PU:BDY7>LHaQcW0R48
0acW00<HaQcW8@P00aS600dLiaS65:DQ22DY:DXU:AS67>LHaQcW8@PHaP057>L26<H27>L01B487>LL
iacW6<H00QBU00DHaQcW6<HHaQBU00PHaPDDY@8HaP037>LHaQS600<DY@037>LHaQS6008HaP<Li`04
6<HLiaS67>L26<H01ABU7>LQ22486<H00QcW0QS600<DYAS66<H011S600<DYAS66<H00QS600<DYAS6
6<H00QS600<DYAS65:D01ABU0Q2411BU0QS600<DYAS65:D00aBU11S60aBU0QS60aBU00<HaQBU5:D0
0QBU0a240QBU00H@Q1BU5:D@Q1BU48@35:D0112436<@Q0aS0Q240aBU0Q2400<<Ha2448@00Q2400HD
YA2448@DYA2436<35:D348@01ABU48@<Ha2436<00a2400DDYA2448@@Q1S6008DY@0336<@Q12400@@
Q00336<@Q124008@Q00336<@Q1BU00<DY@<@Q0035:D@Q12400<DY@0748@<Ha2448@DYA245:D00Q24
0QBU00P@Q1BU5:D@Q1S648@<Ha240aBU0Q2400<DYA2448@011BU0Q240QBU00@HaQBU48@@Q08DY@05
48@DYA2448@DY@0648@00`aS5:DDY@0248@00`aS48@DY@0248@00aBU48@DY@0548@01ABU6<HDYA24
36<00a2400<<Ha245:D00Q2400@<Ha245:DDY@8@Q08<H`8@Q0035:D@Q12400D@Q0<<H`0348@<H`aS
00@@Q08<H`0448@DYA2448@236<448@01@aS48@DYABU48@00@aS00000`0012448@0912401248AS4a
S1cW12U:0RDY0RU:00@U:B488@PQ208YBP048@PLib488@P2:DX012487>LQ21cW0b4800@U:C6<:DXQ
208Li`049BTYBRU::DX38@P4;F/00bDY8@PU:@029BT00acW8@PU:@02<H`00bU:9BTQ20049BT01B48
7>LLib48:DX00bDY0RU:00<U:B489BT012DY0b4800<Lib488@P00b4800@Lib488@PLi`8Q200=9BTQ
22489BT]JbDY7>LHaQcW8@PU:B489BT01B4800<U:BU:7>L00acW00DU:B487>LQ22DY008Q20<Li`08
8@PLib488@PU:BU:<H`YBP8U:@08:DXaS2U:9BTQ22DY7>LQ20<U:@<Q20DU:@<Q2004:DXU:B488@P2
:DX00be[8@PU:@029BT00bU:8@PQ20027>L28@P2:DX29BT00b48:DX]J`03:DX29BT01RU:9BTU:BDY
:DXU:@<Q2004:DXU:B488@P37>L01B487>LQ22DY:DX00RDY0RU:0RDY00@YBS6<:DXYBP8U:@05<H`]
JbU::DXU:@028@P022DY8@PQ22489BTYBRe[9BT28@P27>L38@P00bDY:DXU:@028@P00bDY:DXU:@02
8@P011cW8@PLib480QcW1AS60acW0QS600<Q22DY8@P011cW124800DLib48:DXU:B4800<HaP8Li`03
8@PLiaS6008HaP055:DHaQcW8@PLi`046<H01AcW6<HLiaS65:D00acW00<HaQBU5:D00aS60QBU00D@
Q1BU6<HHaQcW00<HaP8Li`076<HDYABU5:DLiaS67>L00QS600<Q22DY8@P00QBU00<HaR486<H00QS6
0acW0QS611BU0QS60aBU00<@Q1S65:D00QS60QBU0QS60aBU11S600<LiaS65:D00QBU00<HaQBU48@0
0QBU0aS60aBU00@HaQBU48@@Q08HaP077>LHaQBU6<HDYAS65:D00Q2400DDYAS66<HDYA24008DY@8H
aP8DY@046<HDYABU6<H248@01`aS48@DYABU48@DY@aS008@Q00336<@Q12400<@Q08<H`0348@<Ha24
008DY@0348@<Ha24008@Q0035:D@Q1BU00@@Q0DDY@0448@<Ha245:D436<01ABU48@<Ha2436<01a24
0QBU00@@Q1BU48@DY@D@Q0055:D@Q12448@DY@0248@55:D00a245:D@Q00248@02ABU48@DYA245:D@
Q0aS48@DY@026<H248@00aBU48@DY@025:D00a2436<@Q0035:D348@236<348@011BU48@@Q1240QBU
0PaS00H@Q1BU36<@Q0aS48@25:D248@011BU48@@Q1BU0`aS00H@Q1S648@<Ha245:D248@236<00a24
36<<H`0248@236<00a2436<@Q00248@336<248@536<348@25:D248@236<348@236<0112436<<Ha24
0PaS000312400`001240000612402RDY@Q0]JacW9BT]JbU:8@PU:BU:0bDY00DLibDY:DXU:B4800<L
i`039BTYBRDY00DQ20039BTQ22U:00<U:@058@PLibDY9BTYBP039BT00bU:;F/YBP02<H`02bU:8@PL
ibDY:DXQ21cW9BTYBRe[:DX00RDY0R4800HU:BU:9BTQ21cW8@P29BT012489BTQ22U:0bDY0R480RDY
00<YBRDY8@P00QcW00@Q22DY9BTQ20@Li`@Q20067>LU:BU:9BTQ21cW12480QcW0RDY0b4800DU:B48
8@PHaQcW008Q208U:@<Q208Li`046<HLib488@P2:DX2;F/012DY8@PQ22U:0Re[0bDY0R4812DY0b48
12DY0QcW00@U:BU::DXU:@8Q2003:DXU:BU:00<U:@05:DXU:B488@PU:@027>L01RDY;F/]JbDY8@PY
BP8]J`03:DXU:BU:008U:@05:DXU:BU::DXQ20027>L012489BTYBRDY0R4800@Lib488@PQ20<U:@05
8@PU:BDY:DXU:@02:DX2;F/00bU:9BTU:@02;F/00c6<;F/Q20038@P39BT4:DX03B487>LLiacW9BTL
ibDY:DX]JbDY8@PLib48008U:@03:DXU:B4800HLi`036<HLiaS600DLi`048@PU:B488@P26<H01b48
7>LQ22489BTQ21cW00<U:@038@PHaQS6008Li`078@PLiaS66<HLiaS65:D00QcW0R480aS600DDYAS6
8@PLiaS6008DY@066<HLiacW6<HLiaS60QBU00D@Q1S65:DDYAS6008Li`035:DHaQcW008HaP035:DH
aQS6008DY@8HaP8Li`8Q20037>LHaQS600HLi`8HaP8Li`046<HDYABU6<H35:D00aS65:DHaP045:D0
11S67>LHaQS60aBU00<HaQBU6<H00QcW00<HaQBU5:D00aBU0QS600@DYA245:DDY@8HaP8DY@056<HD
YA2448@DY@036<H45:D00a245:DDY@045:D00a246<HHaP025:D248@011S65:D@Q1BU0Q2400D<Ha24
48@HaQBU008@Q00336<@Q124008@Q0055:D@Q1BU48@<H`0248@00aBU48@@Q00648@35:D0212436<@
Q1246<HDYA245:D248@236<448@010aS48@@Q1BU1Q240aBU11240PaS0Q2400<<Ha2448@00QBU00<@
Q1BU5:D00Q240aBU00@@Q0aS48@@Q0<DY@D@Q0HDY@0448@DYA245:D448@35:D448@236<00a2436<@
Q00248@00aBU48@@Q0025:D448@25:D00a2436<@Q0025:D00aS65:D<H`0248@011S648@<H`aS0aBU
0PaS00D@Q1BU48@@Q0Q2008<H`8@Q00436<@Q0aS48@336<248@00`aS2488@P0236<00aBU48@@Q003
48@011BU48@@Q0aS0Q240PaS0a2400<<Ha2448@00@Q200000`0012448@0712401P00248U:DYB:DXL
i`8aS0039BTQ22DY008]J`049BTQ22U::DX39BT48@P00bU:9BTU:@029BT01aS65:DU:C6<>LhaS1cW
008Q20@U:@058@PU:BU::DX]J`03:DX29BT38@P03QcW8@P]JcW><H`Q21cW9BTYBRDY7>LQ22DY8@P3
9BT2:DX00bDY:DXQ20038@P012DY8@PQ22DY0R480QcW00DQ22DY8@PQ21cW008HaP037>LQ22DY008U
:@8YBP<Q20039BTQ21cW008HaP8Q20069BTQ22488@PU:B480acW00@U:B488@PQ20@U:@<Li`056<HL
ib488@PYBP02;F/00bU:9BTQ2002:DX2;F/012U:8@PQ22480RDY00@YBRDY9BTQ208U:@8Q20039BTY
BRDY008U:@07;F/YBRDY8@PU:BU:;F/00RU:00@Q22DY8@PLi`DQ20DU:@038@PU:BU:00<YBP049BTY
BRU::DX79BT012487>LQ22DY0b480RDY00LQ22DY:DXYBR489BTYBP02<H`00be[:DXYBP04:DX39BT2
:DX01RDY8@PU:BDY:DXU:@8Q208Li`8Q208U:@<Q20047>LQ22488@P2:DX00bDY8@PHaP038@P00aS6
5:DLi`037>L01aS67>LU:AcW5:DLib48008aS003:DXU:BDY00<]J`03:DXLiacW008HaP<Q20047>LH
aQcW8@P27>L00aS65:DHaP047>L00b486<HHaP026<H011cW5:DHaQBU1AS611BU00<HaQBU48@011BU
00<HaQcW6<H01AS600XDYAS66<HDYAS68@PU:B487>LDY@@HaP037>LHaQcW00<Li`@HaP@DY@066<HD
YABU5:DHaQcW11S600HLiaBU48@@Q1BU7>L26<H35:D01AS65:DDYABU6<H011BU0QS621BU0QS60QBU
00<HaQBU5:D00Q2400HDYA245:D@Q1BU48@35:D36<H011BU48@DYABU112400<DYA2448@00QBU00D@
Q0aS48@<Ha24008<H`0548@<Ha2448@<H`0248@021BU48@@Q0aS48@DYA245:D848@45:D448@32480
0`aS48@@Q00648@00aBU48@@Q0035:D948@35:D248@236<011245:DHaQBU0Q240aBU0Q2400D<Ha24
48@<Ha24008DY@8@Q0035:DHaQ24008@Q0<DY@8@Q0035:D@Q12400@@Q00536<@Q12448@DY@0248@2
5:D00a245:DDY@0248@236<01ABU48@DYA245:D01a240aBU0Q240`aS0QBU0Q240PaS0Q240QBU0a24
0PaS11240PaS0a2400@DYA2448@<H`<@Q00336<@Q12400<@Q0<<H`<@Q048@P000P@Q00H000@Q1244
8@00248312401@Q2:DY:DRe[7>L00S6<00TU:B48:DXaS2U:8@PU:Be[:DX00RDY00@YBRDY8@PQ208U
:@0?:DXU:BU:9BTLiaBU9BTaS3W>:DXLib489BTLibDY008YBP069BTQ2248:DXaS2e[12DY0b4800LH
aR48<H`e[Be[8@PLi`029BT38@P012DY8@PU:B4812U:00<U:B487>L00R480RDY0b480acW0R4800<U
:AcW8@P00QS60QcW0RDY00@Q22DY8@PU:@<Q20@Li`038@PU:B48008Q20039BTQ2248008Li`<Q2003
9BTQ22DY00<U:@058@PLiaS67>LU:@028@P012DY:DXYBRU:0R4800@U:Be[;F/]J`DQ20059BTQ22DY
9BTQ20027>L01b489BTYBRU:8@PLibDY008YBP8Q20039BTYBRU:00<U:@048@PLib488@P27>L28@P4
9BT38@P4:DX29BT3:DX00bDY8@PU:@039BT012489BTU:BDY0b480RDY00HQ22DY:DXU:BU:9BT3:DX0
1Be[:DX]JbU:9BT00bU:00@U:B489BTYBP8U:@088@PYBRDY:DXQ21cW6<HLi`8Q20@U:@<Q20077>LQ
22U:;F/YBQcW6<H00R4800@LiaS66<HLi`<HaP8Q208Li`046<HQ22DY;F/3:DX01Re[:DX]Jbe[:DXQ
208Li`036<HLib48008Li`8HaP8Q20057>LDYABU6<HLi`028@P27>L26<H00aBU6<HHaP027>L26<H2
5:D01AS67>LHaQBU48@011BU1AS600<LiaS66<H00QBU00@HaQBU6<HDY@<HaP<Q20<HaP057>LHaQcW
6<HLi`056<H01aBU6<HLiaS65:D@Q1S600<DY@0448@HaQS66<H27>L26<H45:D76<H011BU6<HDYA24
0QBU0QcW00DHaQBU5:DDYAS600@DY@036<HDYAS600DDY@0448@DYABU6<H25:D011246<HDYAS60a24
0QBU00<@Q1BU6<H00a2400@DYA2448@<H`@@Q00336<@Q124008@Q00336<@Q124008<H`0348@DYA24
008<H`0348@DYA2400<DY@D@Q0035:D@Q12400D@Q0<<H`@@Q00436<@Q1BU5:D448@25:D248@236<0
1a245:DDYA2436<@Q1BU00D@Q0035:D@Q124008DY@0748@DYABU48@DYA245:D01Q2400<DYA2448@0
0aBU00<@Q1BU5:D01A2400<DYA2448@0112400<<Ha2436<0112400<DYA245:D00a2400<DY@aS48@0
0QBU00D@Q0aS48@@Q1BU00@@Q0035:D@Q124008@Q0045:D@Q0aS36<248@00`aS48@<H`0248@00aBU
48@DY@0848@336<248@010aS48@@Q1BU0a2400DHaQ2448@<H`Q200@@Q0D<H`48@P0000D48@001244
8@0000L48@059BU6<C6<7>LU:@05;F/29BT01248:DXYBRU:0b480RDY0b4800<YBRDY9BT00QcW00<U
:BU::DX00b480RDY0R480RDY00DYBRDY9BTQ22DY008YBP0:8@PU:AcW7>LU:Be[<H`e[C6<9BT28@P0
1bDY;F/YBQcW6<HLibU:008aS0069BTYBRU:9BTQ22DY0RU:00@U:B488@PU:@8Q20037>LQ2248008Q
208Li`046<HLiacW8@P49BT012489BTQ22DY0R4800<Lib487>L00QcW00@Q22DY8@PLi`8Q20@Li`DQ
20089BTLib488@PLibDY8@PU:@8YBP07;F/YBRU:8@PU:BU:;F/00RU:00PU:B487>LLib489BTYBRDY
0b4822DY00HQ22DY8@PU:BU:;F/2:DX00bDY:DXYBP078@P39BT012487>LQ22DY0RU:1bDY00LQ21cW
8@PYBRe[:DXLi`038@P39BT28@P02BDY:DXYBRDY8@PLibDY:DX]J`02:DX2;F/012DY8@PQ22480bDY
00<YBRDY8@P00b4800@U:B488@PQ20<Li`069BTYBR488@PU:BU:0R4800@U:BU:<H`YBP8Li`078@PU
:BDY7>LHaQcW8@P00acW00DHaQcW7>LLib48008Li`<Q20<U:@068@PU:BU::DXU:AS60QcW00DQ22DY
7>LHaQcW00<HaPDLi`056<HDYAS66<HDY@036<H25:D46<H00aBU48@DY@056<H01AcW6<HLiaBU6<H0
0QBU0QS600<DYAS66<H02QS60QBU0acW0QS600<DYAS66<H00QS600@DYAS67>LHaP<DY@037>LHaQBU
00<HaP077>LHaQcW6<HDYAS67>L00aBU00<@Q1S66<H00QcW00<DYAS66<H00QS611BU0aS611BU00@@
Q1BU5:DHaP8DY@0348@DYAS600@DY@0348@DYABU00<DY@8@Q0HDY@0348@DYABU008@Q08<H`0348@D
YA24008<H`8@Q00436<@Q0aS48@236<348@010aS48@@Q1BU0a2400<<Ha245:D00aBU0a2400<DYA24
48@0112400<<Ha2436<010aS112400@<Ha245:DDY@@@Q08DY@0448@DYA2448@35:D348@00aS648@<
H`0448@01QBU48@DYABU48@DY@8@Q00336<@Q124008@Q08<H`8@Q0HDY@<@Q08DY@P@Q0045:D@Q124
48@25:D248@35:D448@01aBU48@@Q1245:D@Q0aS00D@Q00436<@Q1BU5:D548@01ABU48@@Q1245:D0
0a2400DDYA2448@@Q0aS00@@Q0<<H`@@Q0<<H`8@Q0055:D@Q1245:D@Q00336<01A2436<<H`aS48@0
0@aS000312400`0012448@0412402000248U:DYB<H`Q22U:<H`3;F/2:DX49BT00b489BTQ20039BT2
8@P39BT38@P012DY8@PU:BDY124800<U:B488@P00bU:0RDY0RU:12DY00<LibDY:DX00SF]00D]JbDY
8@PQ22DY008YBP058@PLiacW9BT]J`03:DX00be[9BTQ20029BT00bU:9BTQ20058@P47>L28@P27>L0
1aS68@PU:BU:8@PLib4800<U:@8Q20037>LHaQcW008Li`058@PLib487>LU:@028@P37>L00b487>LU
:@029BT00acW6<HLi`028@P27>L00bDY:DXYBP02;F/39BT00bU:;F/]J`039BT38@P=9BT01BU:9BTU
:BDY8@P00bU:0RDY00@Q22DY9BTU:@@Q20@U:@037>LQ2248008U:@<YBPHU:@048@PU:BU::DX29BT0
2QcW8@PQ22DY:DXQ22DY8@PU:BU:0RDY0R4800@U:BU::DX]J`DYBP059BTQ22DY8@PU:@02:DX01BDY
8@PQ22DY:DX00RDY0R480QcW124800DU:BU:8@PQ22U:008aS004:DXQ21cW7>L28@P01AcW6<HLib48
7>L00QS60R4800<Lib488@P00R4800@Lib488@PU:@8Q208U:@03:DXU:B48008Li`@Q20057>LHaQS6
6<HLi`026<H27>L032487>LHaQS65:DHaQcW6<HLiaBU6<HDY@8HaP8DY@046<HDYABU5:D26<H25:D3
6<H01QBU6<HHaQS65:DHaP8DY@8Li`046<HDYABU6<H37>L00aBU6<HHaP027>L26<H00aBU6<HHaP02
6<H00aBU6<HHaP026<H25:D01AS67>LHaQS65:D00QS60acW0QS600<DYAS66<H00aBU00<HaQcW6<H0
0QS600<@Q1BU5:D00aS600<@Q1BU5:D00QBU00@HaQBU48@@Q08DY@046<HDYA2448@65:D011S65:DD
YAS60aBU00<@Q1BU5:D00QBU00L@Q1BU5:DHaQ2436<@Q0025:D948@236<00aBU48@DY@0336<25:D0
1A2436<@Q1BU36<00Q240QBU0a240QS63a2400<<Ha2436<00a2400<DYA2448@00QBU1a2400<DYA24
48@00a2400<DYA2448@00aBU0Q2400DDYA245:D@Q1BU008@Q00536<@Q12436<@Q0035:D01Q2436<@
Q1BU6<HDY@8@Q08DY@8@Q0035:D@Q0aS008@Q0045:D@Q12436<248@011BU48@<Ha240QBU0Q2400LD
YA2436<<Ha245:D@Q00236<25:D01A2436<<Ha2436<00QBU0Q240PaS0a2400<DYA2448@00aBU0a24
0PaS0Q2400<DY@aS36<00PaS0Q2400<<H`Q248@011240aBU00<@Q0aS48@00Q240`aS00<@Q1BU48@0
0@aS00000`0012448@0212400`0012448@0412402B48BU8icRDY<H`]Jc6<:DXU:@028@P3:DX01Re[
<H`YBRDY7>LQ208U:@0?:DX]JbU:9BTLib48:DXU:B489BTYBRe[:DXQ21cW008Q20<YBP069BTQ22U:
;F/aS2e[0b4800LLibe[=JdicSF]:DXQ20039BT38@P03RDY:DXYBRU:;F/YBRDY8@PU:Be[:DXQ21cW
8@P69BT38@P00bDY8@PQ20027>L00bDY:DXU:@029BT01b487>LQ22DY;F/YBR4800@Li`088@PLib48
7>LQ21S67>LHaP8Li`<Q20037>LQ21cW00<Q20057>LQ22DY8@PU:@03:DX29BT3:DX00bDY:DXU:@03
8@P01BU:9BTQ22489BT00R4800<U:BU::DX00bDY0bU:00<U:B489BT00RU:00@U:BU:;F/YBP<Q2005
:DXQ21cW7>LQ20029BT38@P00acW8@PU:@02:DX01RDY:DX]JbU:9BTQ208U:@<YBP8U:@038@PU:BDY
008U:@0;8@PU:BDY9BTYBRe[9BTQ21cW8@PYBP02;F/01BU:9BTU:BDY:DX00RDY0R4800<U:Be[:DX0
0RU:00TU:AcW8@PQ22DY:DXU:AcW6<H00R4800<]JbU:9BT00RDY00<Q22DY;F/00S6<00@YBQcW9BTQ
208Li`038@PU:AS6008HaP8Q20@Li`8Q20<Li`098@PU:BU:8@PLibDY:DXU:AcW008HaP038@PLiacW
00<Li`036<HLiacW00<HaP8Li`048@PHaQS66<H27>L011S65:DDYABU11S60QBU00THaQcW6<HDYA24
6<HLiaS65:D01QS600LDYAS66<HHaQcW6<HDY@026<H35:D36<H45:D01QS65:DHaQBU6<HDY@@HaP03
7>LDYABU008DY@<Li`036<HLiaS600<DY@036<HDYABU00<DY@046<HLiacW6<H35:D26<H00aBU6<HD
Y@025:D27>L25:D00a246<HDY@035:D00aS65:DDY@025:D02A245:DDYABU48@<Ha245:DHaP0348@2
5:D26<H25:D01A245:DDYABU48@00PaS00<@Q0aS48@00Q240`aS00<DYA2436<00Q2400<DYA2448@0
0PaS11240QBU0QS60a2400DDYA2448@@Q0aS00@@Q0D<H`@@Q08<H`<DY@8@Q0035:DHaQBU00@@Q003
36<@Q12400@DY@046<HDYABU48@25:D448@25:D00aS65:DHaP0948@010aS48@@Q1240QBU0QS60QBU
0a2400<DYA2448@00Q2400HDYA245:D@Q0aS48@25:D00aS65:D<H`0248@00aBU48@@Q00348@02ABU
48@@Q0aS48@DYAS65:D@Q00236<248@25:D01A245:D@Q1245:D0112400@DYA2448@<H`8@Q08<H`8@
Q0<<H`0348@DYA2400<<H`04248<H`aS48@35:D348@436<248@236<148@136<00004124000@Q0002
1240100024848@000P@Q00hQ24ic=JdQ22e[<H`]JbU:8@PU:B489BTYBRDY0Re[00<YBRDY8@P012DY
0RU:00<U:B487>L00RDY0R4800HU:Be[;F/Q21cW8@P29BT2:DX28@P01BDY;F/]JbU:8@P00RDY00DQ
22DY=JdicRe[008Q208YBP059BTQ22489BTQ20029BT012e[<H`aS2DY0R480RU:0b4800LU:B488@PU
:B486<HLi`028@P29BT021cW6<HLib48:DXU:B489BT38@P2:DX00bDY7>LLi`028@P47>L00bDY8@PL
i`027>L00b489BTQ20038@P011cW8@PQ22480QcW00DQ22DY8@PQ22DY008YBP8U:@8YBP8U:@<YBPDQ
20049BTQ22DY8@P29BT00bU:9BTU:@02:DX03B489BTQ22DY:DX]JbDY:DXU:Be[:DXU:AcW008U:@@Q
20<U:@038@PLib48008U:@03:DXU:BDY008YBP8U:@8Q2005:DXU:BU::DXU:@038@P29BT00b489BTU
:@039BT00bU:9BTQ20028@P4;F/00bU:9BTU:@039BT01b489BTYBRDY:DXU:BU:008U:@@Q20079BTL
iaS66<HU:BU:9BT00R4800@]JbDY8@P]J`8aS003:DXQ2248008Li`8Q208Li`<HaP088@PU:B487>LH
aQcW8@PLi`8HaP0:8@PU:BDY8@PLib48:DXU:AcW6<H27>L26<H47>L26<H00acW6<HLi`037>L26<H0
0acW6<HLi`026<H00aBU6<HHaP036<H25:D26<H00acW6<HDY@046<H00aBU6<HHaP046<H011BU6<HH
aQS60aBU0aS600@DYAS66<HDY@8HaP037>LDYABU00<DY@DHaP8DY@046<HDYAS65:D36<H011cW6<HD
YABU0aS600HLiaBU48@DYAS67>L36<H00acW6<HHaP065:D01AS67>LHaQBU48@021BU00<@Q1BU48@0
1ABU0Q2400HDYA245:D@Q1BU48@25:D01QS65:D@Q1BU48@DY@D@Q00536<@Q1BU5:D@Q00336<248@3
5:D00a2436<@Q00648@26<H25:D011245:D@Q1BU0Q2400XDYA2448@<Ha2436<@Q0aS48@DY@8@Q08<
H`8@Q08DY@0348@DYABU008DY@0348@DYA24008@Q0045:D@Q1BU48@45:D348@00aBU48@@Q00248@5
5:D248@00`aS48@@Q00948@25:D36<H0112436<@Q1240QBU0Q2411BU0Q2400HDYA245:DDYA246<H2
5:D01A2436<<Ha2436<00Q2400<DYA2448@00a2400@DYA2448@<H`8@Q08DY@0348@<Ha24008@Q004
5:D@Q1245:D848@00`aS48@<H`0236<248@336<348@236<01ABU6<HDYA2436<00Q2410aS0a240@aS
0@Q2000412400`0012448@05124012DYBU8e[BU:0S6<00@YBRDY9BTYBP8Q2006<H`icS6<8@PHaR48
0bDY0bU:0RDY00<YBRDY8@P00R4800DYBRe[:DXU:B4800@U:@038@PYBRDY008YBP039BTQ22DY008Q
2005:DXaS3F]<H`YBP048@P00bU:9BTU:@039BT03BU:;F/]JbU:9BTQ22DY;F/aS2e[9BTLibDY00@Y
BP049BTQ21cW7>L69BT28@P00bDY8@PLi`028@P00be[9BTU:@048@P27>L01AS67>LLiaBU6<H00QcW
00<U:B488@P00R4800LU:AcW8@PHaQcW8@PLi`029BT00bU:9BTQ20028@P29BT00bU:9BTU:@028@P2
9BT48@P011cW8@PLibDY0RU:00@U:B488@PU:@<YBP039BTQ22DY008YBP039BTYBRDY008YBP0:9BTQ
22488@PU:AcW6<HLib48:DX29BT28@P49BT3:DX39BT4;F/28@P39BT27>L01248;F/YBRDY0R4800<U
:BU:9BT00RDY00@YBRe[:DXU:@8YBP039BTQ224800@U:@8YBP038@PLib4800<U:@8Q20@Li`049BTQ
22U:;F/2:DX29BT01BU:;F/YBRDY8@P00QcW00DU:B488@PQ21cW008HaP<Q20037>LHaQcW008HaP05
5:DHaR488@PU:@028@P012DY8@PU:B480aS600<Lib489BT00QS600<DYAS68@P011cW00<HaQcW6<H0
0QS60acW0QBU0QS60aBU1aS600@DYAS65:DDY@<HaP055:DHaQS65:DHaP025:D36<H25:D011S67>LH
aQBU0QS611BU0QS600<DYAS66<H01aS60QBU0QS600DLiaS66<HHaQBU008HaP055:DHaQS65:DHaP05
5:D00aS65:DHaP025:D26<H00acW6<HDY@036<H021cW6<HDYABU48@HaQ2436<35:D348@00aS65:DD
Y@0348@00aBU48@@Q0025:D00aS65:DHaP085:D00a245:D<H`0348@25:D248@00`aS48@DY@0448@2
5:D548@00aBU6<HHaP025:D00aS648@DY@0348@01QBU36<<H`aS48@DY@8@Q00336<@Q124008@Q003
5:D@Q0aS00@@Q0035:D@Q12400<DY@H@Q00536<DYABU6<HLi`026<H45:D00a245:DDY@035:D00aS6
5:D@Q00248@011BU48@@Q0aS0Q2400<DYA2448@00Q2400LDYAS66<HHaQBU48@DY@0348@011S65:D@
Q1240QBU2a2400@DYA2436<<H`<DY@<<H`P@Q0035:D@Q12400<@Q08DY@0348@DYA2400H@Q0<<H`@@
Q00436<8@PaS48@436<;48@336<010Q248@@Q1240@aS000212400`0012448@0712401248BU8icRDY
0S6<00@YBRDY9BTYBP8Q2004:DXaS36<9BT27>L00bDY7>LYBP02;F/012U:8@PQ22U:0RDY00<Lib48
:DX00RU:00<U:B488@P012DY00HQ22U::DX]JbU:9BT28@P01acW:DX]Jc6<=JdYBRDY008Q208U:@<Q
20059BTYBRe[<H`YBP029BT012489BTYBRe[0RU:0RDY0RU:00<U:BU:9BT00R4800HLib488@PQ22DY
:DX29BT02AcW8@PQ22489BTYBRDY:DXU:@027>L38@P00acW6<HLi`027>L011S65:DLiacW0R4800@L
ibDY8@PU:@8Li`@Q208YBP059BTQ22489BTYBP029BT00bU:9BTQ20038@P012DY8@PQ22480QcW0b48
0bDY0b4800<YBRe[8@P00R4800LU:BU:9BTYBRe[:DXU:@028@P012DY7>LLiacW12480RDY00DYBR48
8@PQ22DY00<YBP099BTYBR488@PYBS6<;F/YBR4800<U:@<Q208U:@8YBP<Q208YBP8U:@8YBP<U:@8Y
BP038@PLiacW008U:@8YBP<U:@038@PU:B48008Q20059BTQ21cW7>LHaP028@P012DY:DXYBRU:0RDY
0RU:00@]JbU:9BTLi`<Q208U:@8Li`8HaPLLi`8HaP8Li`038@PU:B48008U:@8Q20047>LHaQcW7>L2
8@P01QS65:DHaQS68@PLi`8HaP8Li`036<HDYABU00<HaP037>LHaQS6008DY@@HaP8DY@<HaP065:DH
aQBU5:DHaQBU0QS600<LiaS65:D00QBU1QS60QBU0QS600@DYAS66<HHaPDDY@@HaP8DY@8HaP037>LH
aQS6008HaP047>LHaQS65:D36<H25:D36<H00aBU48@DY@025:D01AS65:DHaQ245:D011S600DDYAS6
5:DHaQcW008DY@8HaP045:D@Q1245:D448@25:D248@01ABU48@@Q1245:D0112400HHaQBU5:DHaQBU
48@25:D00aS65:DHaP0348@010aS5:DDYA240`aS212400<DYA2448@00PaS00<@Q0aS48@00aBU0Q24
00@DYA245:D@Q0<<H`0748@<H`aS48@DYA2436<00Q2400LDYA2448@@Q1BU48@DY@0248@00aBU6<HD
Y@0248@00aBU48@<H`0236<00aBU48@@Q00248@011BU6<HDYABU0Q2411BU0Q2400<DYA245:D01Q24
00PDYA245:DDYA2436<@Q1BU0QS600PDYA245:DDYAS65:D@Q1BU0Q2400<DYA2448@00Q2400LDY@aS
48@<Ha245:DHaP0348@01@aS48@@Q12436<01A2400<DYA2448@00PaS00P@Q1BU48@<Ha245:D@Q0aS
212400<<Ha2448@00`aS0a2410aS1A240`aS0QBU112400<DYA2436<00PaS00<@Q0aS36<00PaS0@Q2
0000100012448@000P@Q00@000Q2124000848@077>M>LcW>:DXicRe[:DX00RDY00`YBRDY:DXaS3F]
<H`YBQcW8@PU:B48:DX2;F/01bU:8@PU:BU:9BTLibe[008e[@06;F/HaR488@PU:BU:0RDY00<Q22DY
9BT00RU:00@U:B489BTU:@8YBP<]J`<YBP069BTQ21cW7>LU:Be[0SF]0be[00PU:B489BTYBRDY8@PL
ib480RU:00L]JbU::DXYBRDY8@PLi`028@P00bDY7>LU:@039BT28@P00bDY8@PU:@02:DX012DY8@PL
iacW124800@HaQcW8@PHaP8Li`8Q20039BTQ22DY008Q208Li`8Q208U:@03:DXQ22DY008U:@<Q20<Y
BP8U:@@Q20039BTQ2248008Li`058@PU:BDY9BTQ20039BT012U:9BTQ22DY1RU:00<aS2U::DX00R48
0RDY0R480RDY00<Q22DY8@P012DY0R480RDY00<YBRDY9BT00R480RU:00P]JbU:8@PQ22DY8@PU:B48
0RU:1RDY00@Q22DY9BTU:@8YBP0:9BTQ22DY;F/U:B487>LU:BU:;F/29BT011cW8@PQ22DY0R480RDY
0b480acW00@Q22U::DXU:@<YBP069BTQ21cW8@PU:B480acW00@U:B487>LHaP<Li`048@PLiacW7>L3
6<H01aBU7>LQ22DY8@PLib48008U:@057>LHaQcW7>LQ20027>L35:D01AcW8@PLiacW5:D011cW0QS6
00LQ21cW6<HDYAS67>LHaP035:D37>L01QS65:DDYAS65:DHaP8DY@036<HLiacW008DY@@HaP047>LH
aQS65:D26<H25:D66<H35:D26<H37>L26<H35:D02AcW8@PQ21cW5:DHaQcW8@PLi`026<H00a245:DD
Y@026<H35:D26<H00aBU6<HDY@056<H01QBU6<HHaQcW6<HDY@8HaP@DY@0348@DYABU00<DY@8@Q0DD
Y@8@Q0045:D@Q1BU5:D26<H55:D00aS65:DDY@0848@00`aS48@@Q00<48@01@aS48@DYABU6<H00a24
00<DYA245:D0112410aS0a2400<DYA2436<0112400<<Ha2448@00Q240QBU0Q2400<<Ha245:D00Q24
00DDYA245:DDYA24008DY@8HaP045:D@Q12448@35:D01a245:D@Q1BU48@DYAS6008@Q00736<DYABU
5:D@Q0aS48@00aBU00@@Q1BU6<H@Q08DY@0548@HaQBU5:DHaP0448@25:D348@35:D348@25:D;48@2
36<00a2436<@Q00548@00aBU48@DY@035:D848@00`aS5:D@Q00448@00`aS48@@Q0025:D236<648@0
0`aS5:D@Q00436<548@136<00003124000@Q00848@0300048@@Q00@48@0:7>M:DSW>;F/aS2e[:DXU
:BU:;F/29BT01Be[>LhaS2U:7>L0124800HU:BU:9BTU:B48:DX28@P01S6<=Jde[Be[8@PLi`8U:@05
:DXU:B488@PU:@02;F/012U:8@PLib480RDY00@YBRe[;F/]J`<YBP8Q208Li`0<:DX]Jc6<<H`YBS6<
:DXU:B489BTYBRDY0R4800HLibU:;F/]JbU:8@P29BT28@P02AcW9BTQ22489BTYBRDY8@PLi`039BT0
1R489BTYBRDY8@PLi`8Q20<Li`068@PLiaS67>LHaQcW0b4800@U:B488@PQ20<Li`068@PU:BDY8@PU
:B480bDY00HQ22DY9BTU:B489BT2:DX29BT48@P011cW8@PU:BDY0Re[00DU:B488@PQ22U:008U:@8Q
208U:@05;F/YBRU:;F/YBP059BT28@P39BT012489BTU:BDY0R480bDY0bU:00DU:B489BTYBRDY008]
J`039BTLiacW00<U:@8Q20039BTYBRDY008U:@8Q20039BTYBRDY00<U:@8YBP059BTQ22489BTQ2002
:DX01bDY8@PLibDY:DXU:AcW00<Q20039BTQ2248008Li`8Q2004:DXU:BU:;F/2:DX02RDY8@PQ2248
7>LQ21cW8@PU:B481AcW00<Q21cW6<H011cW00HHaQBU7>LQ22U:8@P27>L01BDY8@PHaQS67>L00R48
0QcW00@HaQBU6<HLi`8Q208Li`<HaP<Li`8HaP8DY@8Li`066<HDYABU6<HLiaS60QcW00HDYAS65:DH
aQcW5:D26<H00acW6<HHaP025:D00aS65:DHaP0;6<H25:D01QS65:DDYAS65:DLi`8HaP8Li`8HaP8D
Y@8Li`058@PLiaS66<HDY@046<H35:D011S65:DDYABU11S600<DYAS67>L00aS600<DYAS67>L00acW
0aS61ABU00@@Q1BU5:DDY@8@Q08DY@036<HDYA24008@Q0045:D@Q12448@25:D01AS65:DDYABU48@0
0QBU00DHaQBU48@@Q1BU00H@Q08<H`8DY@<@Q00436<@Q1BU5:D248@236<011245:DHaQBU0a2411BU
0Q2410aS00D@Q0aS48@@Q1BU00D@Q00336<@Q1BU008DY@@@Q0<DY@@@Q08DY@8@Q08DY@046<HDYABU
48@25:D01QS648@@Q1245:DHaP8@Q0<DY@<@Q08DY@8@Q00336<@Q1BU00DDY@8@Q0035:D@Q1BU00<D
Y@8@Q0035:D@Q124008@Q0035:D@Q1BU00@DY@0648@<Ha2448@DYA240PaS1A2400H<Ha2448@<Ha24
36<448@01PaS5:DHaQS65:D<H`H@Q00536<@Q12448@DY@0248@01QBU48@@Q0aS48@DY@8@Q0045:D@
Q1245:D248@00`aS48@<H`0448@00`aS48@@Q00348@1248000848@0300048@@Q00D48@080008@RDY
DY@mkbDY;F/YBP8]J`8U:@04;F/e[CW><H`28@P00acW8@PYBP02:DX022DY8@PU:BU:;F/YBRe[:DX2
;F/03RU:9BTQ21cW9BTQ22DY7>LQ22U:<H`]JbDY7>L28@P01QS69BT]Jc6<;F/Q208U:@038@PHaQcW
008U:@058@PYBRe[=JdaS002:DX00bDY8@PU:@039BT02b487>LLibDY:DX]JbDY7>LQ22DY8@P00QcW
00@Q22DY:DXU:@<Q20049BTQ22DY9BT2:DX00bDY8@PQ20049BT01B487>LLiacW8@P00acW1R4800<L
iaS67>L00RDY00<YBRe[:DX01RDY00HQ22DY:DXYBRDY8@P29BT02B489BTU:B487>LQ22DY;F/U:@03
:DX00bDY8@PU:@038@P02BDY:DXYBRU:;F/aS2e[:DXQ20069BT38@P00bDY:DXQ2002:DX00be[:DXU
:@04:DX28@P01BDY:DX]JbU:8@P012DY00<Q22DY:DX00RU:00<U:B488@P0124800DU:BU::DXYBRDY
008YBP8U:@058@PU:BDY8@PU:@02:DX012DY8@PQ22DY124800<U:B488@P00QcW00@Q22DY9BTU:@8Q
20039BTQ224800<Li`068@PU:B488@PLiaS60acW00DQ21cW6<HDYAS6008Li`058@PDYABU6<HLi`02
9BT01b487>LHaQcW8@PLiaS600<Li`8HaP8Li`8HaP8Li`8Q20086<HLiaBU5:DLib487>LHaP8@Q08L
i`048@PHaQS65:D27>L00aS65:DDY@046<H00aBU6<HHaP026<H27>L00aS65:D@Q0026<H00acW6<HL
i`096<H00aBU6<HDY@025:D01QS67>LLiacW6<HLi`8HaP8DY@036<HLibDY008Li`8HaP<Li`DDY@03
6<HDYAS600DDY@076<HLiacW5:D@Q1BU6<H00QcW0QS611BU00<HaQBU5:D011BU0Q241aBU0a2400DD
YA245:DHaQBU008HaP045:DHaQBU48@25:D011S648@@Q0aS0a2400@DYA245:DDY@D@Q08DY@0548@<
Ha2448@DY@0448@00aS65:DDY@0348@00aBU48@<H`0448@236<011245:D@Q1240`aS00<@Q1BU5:D0
1ABU0a240QBU0a2400<DYA245:D011BU00<HaQBU5:D01A240aBU0Q240QBU00DHaQBU48@@Q0aS00L@
Q0@DY@8@Q0035:D@Q12400<HaP8DY@036<HDYABU00<DY@8@Q08DY@8HaP8@Q00436<@Q1245:D448@0
0aBU48@<H`0248@00aBU48@<H`0248@25:D348@00aBU48@DY@0648@01@aS48@@Q12436<0212400<D
YA245:D011BU112400<DYA2448@00PaS0a240PaS00<@Q1BU48@00@aS00000`0012448@0212400`00
1248@P0412401B48DY@mkbDY:DX00be[0RDY00@]JcF]>Lh]J`8U:@8Li`078@PYBRe[:DXQ22DY;F/0
12U:00DaS2e[:DXQ21cW00<U:@8Q20059BTYBRU:;F/YBP028@P00aS67>LYBP03;F/39BT00aS67>LL
i`029BT01AcW9BT]JcF]<H`00RDY00DQ22DY9BTQ22DY00<Q20067>LU:BU::DXU:B480bDY00@Q21cW
8@PQ208YBP058@PLib489BTQ20029BT3:DX012489BTQ22480RDY00<Q21cW6<H01AcW0R4800@Lib48
9BTU:@<Q20059BTYBRU::DXU:@02:DX29BT00b489BTU:@029BT00bU:9BTU:@029BT2:DX01RDY8@PL
iacW8@P]J`<YBP<U:@8YBP<Q208YBP059BT]Jbe[;F/YBP028@P29BT2:DX01RDY8@PLibDY;F/YBP8Q
2003:DX]JbDY008U:@<YBP079BTQ22DY:DX]JbU:9BT01B480RU:00<]JbU:9BT00R480RDY0b4800<U
:BU::DX00RDY0RU:00@U:B489BTQ208U:@03:DXU:B48008Q208U:@038@PLib4800DQ200;7>LU:BU:
:DXQ21cW8@PU:B487>LHaP028@P011cW8@PQ22481QcW0aS60QcW0QS600DDYAS67>LQ22DY00<Q208L
i`@HaP8Li`@HaP057>LHaQcW8@PLi`026<H00aBU6<HLi`037>L25:D011S67>LQ21cW0QS600DLiaS6
5:D@Q1BU00DHaP055:DHaQS66<HLi`046<H01ABU6<HDYAS65:D00aS600@LiaS65:DDY@8HaP8Li`8H
aP055:DHaQcW7>LHaP027>L26<H25:D37>L012486<HHaQS60QcW0QS600<@Q1BU5:D00QBU00<HaQBU
5:D00QBU0aS60QcW11S611cW11BU0QS60QBU0Q240QBU00DHaQBU5:DDYA2400<DY@@@Q0076<HDYAS6
7>LHaQBU48@00aBU0Q240aBU0a2400<<Ha2448@00a2400<<Ha245:D00Q2400P<Ha2448@@Q1BU48@D
YA240QBU00<@Q1BU48@00Q2411BU0Q2400<DYA2436<00PaS00@DYA2448@<H`8@Q00436<@Q1BU5:D3
48@00aBU48@@Q0035:D548@55:D011245:D@Q1BU0Q2411BU1A2400<HaQBU48@00PaS0aBU0Q2400D<
Ha2448@DYA24008DY@@@Q0<HaP045:D@Q1BU6<H25:D348@35:D00a2436<@Q00248@021BU48@@Q0aS
48@<Ha2436<348@00`aS48@<H`0748@00aBU48@@Q00448@01aBU48@@Q12436<@Q0aS008@Q0065:D@
Q12436<@Q1BU112400HDYAS66<HDYA245:D348@00`aS48@<H`0248@436<248@236<00007124000@Q
124000@Q000010@Q00H8@RDYCW<aS1cW9BT2:DX00be[:DXYBP03:DX012e[8@PQ22480RU:00<U:B48
9BT012U:0Re[00<YBRDY8@P00QcW00@U:BU:9BTQ208Li`039BTYBRU:008U:@077>LHaR489BTYBRDY
8@P00bDY00<Lib488@P00QcW00<Q22DY;F/00RU:00<]JbDY9BT00R480RDY0R4800DU:B488@PQ22DY
008YBP098@PLib487>LQ22DY8@PU:B4800<U:@8Q20039BT]Jc6<008YBP8Q20039BTQ224800<U:@03
8@PLiacW00<Li`8Q208U:@048@PLiacW7>L28@P2:DX2;F/3:DX012DY:DXQ22480bDY0b480bU:00HU
:B488@PU:BU:;F/2<H`01RU:9BTQ22DY:DXU:@<Q20049BTYBRDY9BT2:DX2;F/29BT00b489BTYBP02
:DX01bDY8@PU:BU:9BTQ22DY00<]J`8U:@DYBP<U:@03:DXU:BDY008Li`059BTYBRe[;F/U:@02:DX2
9BT27>L28@P3:DX49BT48@P3:DX02R487>LQ22DY:DXU:B487>LHaQcW0b4800<U:B488@P00RDY00DY
BRDY7>LLib4800@Li`058@PU:AcW7>LHaP027>L46<H011cW6<HLiacW11S600@Q22DY9BTQ208Li`06
8@PHaQS66<HLib480acW0aS60QcW00HQ21S67>LQ21S65:D26<H00acW6<HHaP036<H02QcW6<HHaQBU
6<HQ21cW6<H@Q1BU0QS60aBU0QS60acW0aBU0QS60aBU00PHaR487>LLiaBU48@HaQBU21S600<DYAS6
6<H00acW0QS60QBU00<LiaS68@P01QcW1QS600@DYA245:DDY@<HaP045:DHaQS67>L36<H37>L25:D0
0aS65:DHaP025:D36<H011BU48@@Q1240aBU00D@Q1BU6<HHaQBU008@Q08DY@036<HDYABU00<HaP05
5:D@Q12448@DY@0348@01ABU48@DYA245:D00a240QBU3Q2400<DYA2448@00aBU00<<HaBU5:D00Q24
00<<Ha2448@00Q2400@DYA2448@<H`D@Q0<DY@0348@DYA24008HaP045:D@Q1246<H248@010aS48@H
aQBU11S60Q2400@DYA2448@DY@8@Q00436<@Q1BU5:D348@011BU48@@Q1240QBU00@@Q0aS48@HaP<@
Q0035:D@Q12400@DY@8@Q0047>LU:BDY7>L35:D00a245:D@Q00448@00aBU48@@Q00248@011BU48@@
Q0aS0Q2400DDY@aS48@<Ha24008DY@0948@<Ha2448@DYA2436<@Q1BU00@@Q0035:D@Q12400<@Q0<<
H`L@Q0036<HDYABU00DDY@@@Q00436<@Q0aS48@236<01a245:D@Q0Q236<@Q1BU004@Q0000P@Q00<0
00@Q12400P@Q00<8@P@Q00000P@Q00HYBTic=JdLibDY;F/5:DX01Re[:DXYBRDY8@PU:@8YBP039BTQ
22DY00@YBP03;F/YBRDY008U:@<Q20039BTYBRDY008Li`059BTYBRDY:DXU:@027>L00b489BTYBP04
9BT02B487>LQ22487>LHaQcW9BTaS002;F/012U:9BTQ22480RDY1B4800HLibDY9BTU:B487>L38@P0
3BDY7>LQ21cW9BTQ22DY8@PU:BU:;F/YBS6<008YBPDQ20<U:@038@PLib4800@Li`038@PYBRDY008Q
20046<HLib488@P8:DX59BT28@P39BT00bU:9BTU:@028@P2:DX01BDY;F/]Jbe[9BT00R4800DU:B48
8@PQ22DY008Q20039BTYBRe[008]J`03:DXU:B4800@U:@03:DXU:BDY00@U:@8YBP03;F/YBRDY00<U
:@03:DXU:BDY008U:@8YBP049BTQ21cW7>L29BT012U:9BTYBRDY0RU:00LU:B488@PQ21cW:DX]J`02
:DX00b489BTU:@039BT01B489BTYBRU:9BT0124800<U:B487>L00acW00<Q22DY8@P0124800<U:B48
8@P00b480acW0R4800DU:B487>LLiaS6008Li`8HaP055:DHaQS66<HLi`036<H012489BTU:B481QcW
0aS61AcW00LHaR487>LQ21cW6<HDY@026<H27>L76<H27>L26<H00acW6<HHaP026<H35:D00aS67>LH
aP046<H01aBU6<HDYAS65:DHaQBU008Li`058@PHaQS66<HLi`026<H25:D26<H37>L36<H47>L01AS6
7>LHaQS67>L00QS611cW00DHaQcW7>LHaQBU008@Q0035:DHaQBU00<DY@037>LHaQBU008HaP8DY@06
6<HLiacW6<HDYAS60aBU0QS600<DYAS648@00QBU00@HaQBU5:D@Q08DY@046<HDYABU5:D348@00aBU
6<HDY@046<H01A245:DDYA245:D00Q2400<DYA245:D00a240QBU112400<DYA2448@01a2400<DYA24
48@0112400<DYA245:D01Q2400<DYA2448@02Q2400@DYA245:D@Q0HDY@H@Q0035:DHaQS600<DY@<@
Q0045:D@Q12436<248@011BU48@DYA240QBU00D@Q0aS48@@Q1BU00<@Q00336<@Q124008DY@H@Q08D
Y@8Li`038@PLiaBU00<DY@8@Q00436<@Q1245:D648@25:D02A2436<@Q1BU48@<Ha245:D@Q00536<5
48@25:D248@00`aS48@@Q00248@00aBU48@@Q00436<01Q2436<<HaBU48@HaP8DY@8@Q0045:DHaQS6
5:D548@00`aS48@<H`0448@00`aS48@@Q00148@0000500048@@Q1240000712401B48AS4aS248;F/0
0bU:00@]Jc6<;F/YBP8U:@068@PU:BU::DXU:BU:0bDY00@YBRe[;F/YBP8U:@8Li`8Q208U:@058@PU
:B489BTQ20029BT01AcW6<HLibDY:DX00RDY12480QcW00XHaQcW7>LLib489BT]JbU:8@PU:@<Li`04
8@PU:BDY9BT48@P2:DX28@P00acW8@PU:@038@P29BT28@P00acW8@PQ20029BT00be[:DXYBP029BT0
1R489BTYBRDY:DXU:@@Q20077>LHaQcW8@PYBRDY8@P00acW0QS600DLibU:;F/aS2e[008U:@03:DXU
:BDY00<Q20<U:@8Q20047>LQ22488@P3:DX2;F/2:DX49BT38@P29BT01R489BTQ22U:;F/YBP8aS08Y
BP039BTYBRe[00<U:@@YBP039BTYBRU:00DYBP049BTYBRU::DX29BT48@P01RDY8@PYBRe[<H`]J`<Y
BP8U:@8Q20049BTYBRU::DX39BT2:DX01BDY8@PQ22DY:DX00bDY00DQ22DY8@PU:B48008Li`036<HL
ibDY008U:@038@PU:BDY008U:@077>LQ21cW6<HLiaS67>L00QS600<Lib487>L00QS600<Lib487>L0
0QS600TLiaS67>LLib486<HDYAS67>L00RDY0acW00<HaQcW8@P00R480acW00<HaQcW6<H00QcW00PQ
21cW8@PLiaS67>LHaQBU0acW0QBU00<Lib487>L00QS600<LiaS67>L00QcW00DHaQBU5:DHaQcW00LH
aP037>LHaQS6008DY@8HaP8Li`8HaP045:DLiacW6<H35:D37>L00aS65:DHaP037>L01aS67>LLib48
7>LHaQBU00<HaP8Li`<Q208Li`@DY@046<HDYABU48@26<H02acW6<HHaQS67>LHaQBU6<HDYAS67>L0
0QS60QBU0aS600<DYA245:D00QBU0a2400DDYA245:DDYAS600@DY@0448@DYABU5:D26<H55:D01124
5:DDYABU0a240aBU0Q240aBU0Q240aBU00<@Q0aS36<00a2400<DYA2436<00a240QBU00<@Q1BU48@0
0aBU00<@Q1BU48@00Q2400<<Ha2436<00Q2400<DY@aS36<00Q2400@DYA245:DHaP8DY@0348@DYAS6
00HDY@<@Q0055:DHaQS65:DHaP035:D00a2436<<H`0448@01QBU6<HDYABU48@DY@P@Q08<H`8DY@05
48@DYA2436<DY@026<H35:D01AS68@PU:AcW5:D00Q2400@DYA2448@@Q08DY@8@Q08DY@8@Q00336<@
Q12400@@Q00336<@Q12400@@Q08DY@0548@DYA2436<DY@0248@236<01A2436<@Q1245:D011240PaS
0Q2400HDYA2448@<Ha245:D26<H25:D00a2436<<H`0248@25:D01Q2436<<H`aS48@DY@@@Q04<H`48
@P000`@Q00D000@Q124000Q200848@0800048BDYBU8e[B48:DX]J`8U:@04:DX]JbU::DX39BT01248
9BTU:BU:0RDY00@Q22U::DX]J`8YBP8U:@058@PLib488@PYBP059BT38@P01QcW6<HLiacW:DX]J`8U
:@047>LQ21cW8@P27>L00b487>LLi`028@P2:DX01BDY8@PLiacW8@P00QcW0bDY0R480RU:00<U:B48
8@P00b480QcW00@Q22DY8@PQ208Li`038@PU:BU:008U:@8YBP8U:@038@PYBRDY008U:@038@PU:B48
00DLi`039BTQ224800HLi`055:DU:Be[=JdaS0029BT00bU:9BTU:@039BT00b489BTU:@058@P01RDY
8@PYBRe[<H`]J`8YBPDU:@037>LQ224800DU:@03:DXU:Be[008aS005:DXU:BDY9BTYBP029BT012U:
9BTU:BDY1RU:00DaS2U:9BTU:BU:008]J`049BTQ22DY9BT28@P00bDY:DXYBP05:DX02RDY8@PQ2248
:DX]JbU:9BTLib480bU:0RDY00<LibDY:DX00RU:00<U:B488@P00RDY0R4800<LiaS68@P00R4812DY
00<Lib487>L01QcW0aS60R480aS600<Lib486<H00QS611cW00DDYAS67>LLibDY00LLi`<Q20<Li`03
6<HLiacW00@Li`038@PLiaS6008DY@<Li`8DY@0:7>LQ21cW6<HDYAS67>LQ21cW6<H25:D011S65:DH
aQcW0QS60QBU0QS600<LiaS65:D011S600DDYAS66<HDYAS6008Li`045:D@Q1245:D27>L56<H77>L3
6<H011cW5:DHaQcW0RDY0R4800<LiaBU5:D00aBU00@HaQBU48@DY@8HaP057>LHaQS66<HDY@036<H0
11cW6<HDYAS60aBU0QS611BU00@HaQBU48@DY@@@Q0035:D@Q1BU00@DY@046<HDYABU48@55:D348@2
5:D248@25:D00a245:D@Q00348@011BU48@@Q1BU0a2400<<Ha2448@00QBU112400PHaQBU5:DDYA24
5:D@Q1BU0Q240aBU00<@Q0aS48@00QBU00@@Q0aS36<@Q0@DY@8@Q0035:D@Q1S6008HaP095:D@Q1BU
6<HDYA2436<@Q1BU008@Q0@DY@036<HDYA24008@Q00436<@Q1245:D248@35:D348@00aBU48@DY@07
48@01aBU48@DYA245:D@Q1S6008DY@8HaP8Q20037>LHaQ2400<@Q00336<@Q1BU008DY@0348@DYA24
008@Q08<H`0448@DYA2448@236<248@00aBU48@<H`0236<01a245:D@Q1245:D@Q1BU00<@Q00336<@
Q124008@Q00736<@Q1245:D@Q1BU48@00PaS0a240QBU0QS6212400HDYA2448@<Ha245:D448@336<0
000300048@@Q00848@0300048@@Q00@48@047>M>LcW>9BT2:DX2;F/00bU:9BTQ20029BT01248:DXY
BRDY0R4800<U:Be[:DX01RDY00HQ21cW8@PU:BU:9BT38@P39BT02B487>LLiacW:DX]JbU:9BTLi`02
8@P37>L012487>LHaQcW0RDY00@Q21cW8@PQ20DLi`8Q20049BTQ22DY9BT2:DX00bDY8@PQ20048@P0
0bDY8@PQ20029BT28@P29BT01BU:;F/YBRe[:DX012DY00@YBRDY:DXU:@8Q20@Li`038@PLib4800DL
i`075:DLiacW:DXaS2e[:DX00RDY00H]JbU:9BTU:B489BT58@P27>L29BT012e[:DXYBRU:0Re[0RDY
00@Q22DY8@PQ208U:@<Q20039BTYBRU:00DYBP06;F/YBR489BTQ22U:22DY00@]Jc6<;F/YBP8U:@03
:DXQ2248008U:@03:DXU:B48008U:@058@PU:BU::DX]J`03:DX39BT2:DX00be[:DXU:@069BT01B48
:DXYBRU:8@P012DY00@Q21cW7>LHaP8Li`048@PU:B489BT38@P67>L00aS67>LLi`046<H57>L011S6
7>LLiacW0aS60QcW00PHaQcW8@PLiaS65:DLib480acW00@U:B487>LHaP<Li`036<HLib48008Li`03
8@PLib48008Li`036<HLiaS6008HaP<Li`DHaP035:DHaQcW008HaP055:DHaQS66<HDY@026<H00aBU
6<HLi`028@P00acW5:DDY@025:D47>L46<H011cW6<HHaQS60QcW0QS600@LiaS66<HHaP<Li`8HaP05
8@PLiaS65:DHaP037>L00b487>LLi`036<H35:D011245:DHaQS60QBU0QS60aBU00@HaQcW8@PLi`@H
aP<DY@8HaP8DY@056<HDYAS65:D@Q0045:D00a2436<DY@036<H248@00aBU6<HDY@0248@011BU6<HH
aQ240PaS0aBU0a240QBU00<HaQBU5:D00QBU00@HaQBU48@@Q0<DY@@@Q0035:DHaQBU008@Q0035:D@
Q1BU00@DY@H@Q08DY@<@Q0035:D@Q12400@DY@0548@DYA245:D@Q0025:D26<H00aBU6<H@Q0025:D0
1A245:DDYABU6<H011BU00D@Q1BU5:D@Q1BU00<@Q08DY@8@Q08DY@8@Q00636<@Q12436<@Q1BU2A24
0QBU00DHaQBU5:DDYA24008DY@8@Q08DY@8@Q00336<@Q12400<@Q0045:D@Q0aS48@25:D00a245:D@
Q00548@00aBU48@<H`0248@25:D248@00aBU48@@Q00248@25:D248@236<348@01ABU48@@Q12436<0
0a241ABU00<@Q1BU5:D00QBU21240PaS11240@Q200001@@Q00048@@Q00001`@Q00@Q24ic>LhU:@<]
J`04:DXU:B488@P39BT00bU:;F/Q20028@P00bDY:DXYBP049BT01BU:8@PU:B486<H00RDY00DYBRDY
7>LQ22DY008Q20047>LQ22488@P29BT012U:9BTQ22DY0R481QcW00<U:B488@P00acW00<Q21cW7>L0
0QcW124800DLibDY:DXYBRDY00@Q208U:@8Q20047>LU:BU:9BT27>L01R48;F/]JbU:;F/U:@8YBP<U
:@<YBP8U:@038@PLiacW008Li`8Q20037>LHaQcW00DLi`05:DX]Jbe[;F/U:@02:DX29BT012489BTQ
22480RDY00@Q21cW7>LQ208U:@04:DX]JbU:;F/3:DX00bDY:DXQ20028@P2:DX00bDY8@PLi`039BT3
:DX00bDY:DX]J`02:DX29BT2:DX022DY8@PQ22489BTYBRDY:DX2;F/012U:9BTU:BU:1RDY0b4800@U
:BU::DXYBP8]J`03:DXU:BDY00@YBP03;F/U:BDY008Q20<U:@038@PU:BU:008YBP039BTQ22DY008U
:@037>LQ21cW00<Li`038@PU:BDY008U:@<Q20LLi`<HaP057>LQ22486<HDY@027>L012487>LLiacW
11S61acW00@HaQcW7>LLi`<U:@057>LHaR487>LHaP027>L38@P27>L01AS67>LLiacW5:D00aS600HL
ib488@PLiaS65:D36<H011cW6<HLiaS60aBU0aS600@DYAS66<HHaP<Li`8HaP045:DHaQcW6<H27>L8
6<H27>L00aS65:DHaP057>L26<H27>L46<H37>L01AS67>LLib486<H01QBU0QS600@DYAS66<HHaP8@
Q0045:DHaQcW7>L26<H01ABU6<HDYAS65:D00QS60aBU0QS60QBU00DHaQ2436<@Q1BU008HaP8@Q004
6<HDYAS65:D248@35:D448@01ABU48@DYABU48@00aBU00@@Q0aS48@DY@8@Q08HaP045:D@Q1BU5:D3
48@01ABU48@@Q1BU48@00aBU00<@Q1BU48@00Q2400DDYA245:DDYA2400<DY@8@Q0<DY@0748@DYABU
5:D@Q1BU6<H00aBU00<@Q1BU6<H00QS611BU0Q240QS600@@Q1BU5:DHaP8DY@0348@DYA2400<@Q005
36<@Q12448@DY@026<H011BU48@<Ha240PaS0Q2400<DYA2436<00Q2400<<Ha2448@01QBU0a2400@D
YAS65:DDY@<@Q0035:D@Q1BU00<@Q00336<@Q12400@@Q00436<DYABU5:D336<00a245:D@Q00236<0
0a245:DDY@035:D01QS648@<H`aS48@DY@@@Q0045:D@Q1BU48@336<348@00`aS48@@Q0025:D011S6
5:DDYABU0Q2400<DYAS65:D00PaS0a2400<<Ha2436<00a240PaS000312400`0012448@0412401P00
248Q24ic>LhU:@@YBP8U:@8Q2006:DX]JbU:9BTQ22DY0RU:0RDY0R4800@U:B488@PU:@8Q20039BTQ
2248008Q20049BTQ22DY9BT48@P39BT00acW8@PLi`038@P37>L38@P00acW8@PQ20029BT012486<HH
aQS60b4800@U:B489BTQ208U:@03:DX]Jb4800<Q208U:@04:DXQ22487>L49BT4:DX00be[:DXU:@03
8@P3:DX01RDY8@PQ22487>LQ208Li`8Q20@HaP8Li`0>8@PU:Be[;F/U:B489BTQ22U:9BTQ22DY8@PU
:@8Q20039BTQ2248008Q20@YBP03;F/YBRDY008]J`049BTQ21cW8@P29BT38@P011cW8@PQ22480bU:
00LQ22DY:DX]JbDY8@PU:@02:DX00bDY8@PU:@029BT01RU:9BTaS36<;F/YBP8U:@8YBP@U:@068@PU
:B489BTQ22DY0Re[00XYBRDY8@PQ22DY:DXaS2e[:DXU:@8Q20099BTYBRe[:DXQ22DY:DXU:B48008U
:@DQ20<Li`038@PLiacW00LQ20<Li`038@PLiacW008DY@8HaP048@PLiaS67>L26<H27>L012486<HH
aQBU0aS600<Lib487>L00aS60acW0R480QcW00@DYAS67>LLi`8Q208Li`036<HQ22DY00@Q20047>LH
aQS66<H27>L26<H00aBU6<HQ20037>L76<H011BU48@DYAS61AcW0aS600TDYAS66<HHaQcW6<HLiaS6
5:D01AS600DLib486<HHaQBU00DHaP8Li`8HaP8Li`046<HLiaS65:D36<H01QBU6<HHaQS65:D@Q0<D
Y@8HaP@DY@<HaP035:DHaQBU008HaP8DY@036<HLiaS6008HaP045:DHaQBU5:D26<H00acW6<H@Q002
48@45:D00aS65:DDY@045:D248@25:D01AS65:DHaQBU48@01ABU0a2400DDYA246<HLiaS6008DY@03
48@DYA2400<@Q0065:D@Q1BU48@DYAS6112400<HaQBU48@00Q2400TDYA245:DDYA2436<@Q1BU6<H0
21241QBU00XHaQBU6<HDYAS65:D@Q0aS48@HaP<DY@0448@DYABU5:D348@00aBU48@DY@0248@011BU
48@@Q1240aBU00<@Q0aS48@00PaS1A240`aS00D@Q1BU6<HHaQBU008<H`8DY@036<HDYA2400<@Q003
5:D@Q12400<@Q08DY@8@Q0036<HDYABU008@Q0045:D@Q0aS36<248@01@aS5:DDYABU48@00PaS00<@
Q0aS48@011BU0Q240QBU1A2400D<Ha2436<@Q1BU008@Q00536<@Q1245:D@Q0035:D348@00aBU48@D
Y@025:D236<448@236<00aBU48@@Q00236<12480000300048@0000<48@030008@P@Q00<48@04:DYB
U3g_7>L5:DX012DY8@PQ22DY0Re[00<U:B488@P00bDY0R4800<Lib489BT00b480RDY00DQ22DY7>LQ
21cW00LQ208U:@DQ20057>LHaQcW7>LQ20037>L38@P00bDY8@PDY@026<H011cW9BTU:BDY0b4800@U
:BU::DXU:@8Q20@U:@03:DXU:B48008Li`058@PYBRDY:DXU:@02:DX01Be[:DXU:BDY:DX00QcW00@U
:BU:;F/U:@8Li`@Q20039BTQ21cW008HaP085:DLiaS67>LQ22DY;F/YBP<Q20049BTYBRDY9BT28@P0
1AcW8@PQ21cW8@P00QcW00<U:BU:;F/00bU:0bDY00DYBRDY8@PLib48008U:@8Li`038@PLib4800<U
:@04:DXU:BDY9BT2:DX01RDY8@PYBRU:9BTQ20<U:@038@PU:BU:00@]J`8U:@03:DXU:BDY00@U:@04
7>LQ21cW8@P2:DX2;F/00bU:8@PU:@029BT2;F/2:DX00b487>LU:@02:DX00b489BTQ2002:DX01BDY
8@PQ22DY8@P01QcW00<Q21cW8@P00QcW0bDY00<Q21S66<H00acW00HQ21cW6<HDYAS67>L28@P01QcW
8@PHaQBU6<HLi`8Q208HaP065:DLib488@PHaQBU0QS61AcW00HQ21cW6<HHaQcW8@P27>L00b487>LH
aP027>L28@P27>L00b487>LLi`027>L46<H27>L011S67>LHaQBU0QS60acW00DHaQBU6<HHaQcW008H
aP8Li`036<HDYABU00<HaP065:DHaQcW7>LHaQBU1QS600@DYAcW7>LLi`8HaP8Li`8HaP@Li`<HaP<L
i`8HaP055:DHaQcW7>LHaP055:D01AS65:DDYABU48@00QS600<LiaS66<H00aBU00<HaQBU48@00QBU
00<HaQBU5:D00QS611BU00@LiaS65:DDY@8@Q0065:D@Q1BU6<HDYAS60QBU00<HaQBU5:D00Q240QBU
00<HaQBU48@00aBU0Q2400DDYA2448@<Ha2400<DY@<HaP<DY@0336<@Q12400D@Q0055:D@Q1BU48@<
H`025:D00a245:D@Q00448@236<00a245:DDY@0348@010aS5:DDYABU0Q240QBU00@HaQBU5:DDY@@H
aPD@Q08DY@036<H@Q124008@Q00336<@Q12400D@Q0036<H@Q1BU008DY@0348@DYA2400<@Q08<H`8@
Q0095:D@Q0aS36<@Q0aS5:D@Q1BU00<@Q08DY@0648@DYABU48@<Ha240QBU0Q2400<<HaBU48@00Q24
0QBU112400<DYA2448@0112400<<Ha2436<00Q240`aS00@@Q1BU5:D@Q08DY@@@Q08DY@0348@DYA24
008@Q00336<@Q124008DY@0348@<Ha2400@@Q0035:D@Q1BU00<DY@H@Q08DY@8<H`@@Q08<H`48@P00
10@Q00<000@Q124010@Q00D8@Re[F]He[B48008aS0039BTLib48008]J`0::DX]Jbe[8@PHaQcW:DX]
JbU:7>L28@P29BT02R489BTQ22DY:DXU:BU:9BTYBR480RDY00DYBRDY8@PLib4800@U:@8Q20@Li`8H
aP8Li`<Q20069BTQ21cW8@PLiaS6124800@U:B488@PQ20<U:@0<8@PU:BDY7>LU:Be[<H`Q21cW6<HQ
22DY0b4800HYBRe[;F/YBQcW6<H28@P01RDY8@PQ22DY:DXU:@8Li`099BTQ21cW7>LQ22DY8@PLiaS6
008Li`038@PU:B48008U:@@Q20039BTQ224800<U:@<Q208U:@@Q2005:DX]Jbe[:DXU:@02:DX2;F/0
12DY8@PQ22480bDY0acW00<Q22DY9BT012DY0be[00@YBRDY8@PU:@8Q20047>LQ22489BT5;F/3:DX0
0bDY:DXYBP029BT011cW9BTQ21cW0R480RU:12DY00<YBRe[:DX00RU:0R4800<U:BU::DX012DY0RU:
0RDY1R480QcW00LHaR488@PQ21cW6<HLi`028@P29BT28@P00aS67>LLi`036<H47>L00aS67>LHaP03
7>L01R487>LLiaS65:DHaP<Li`0:6<HDYAS67>LHaQcW6<HLib487>L26<H00aBU6<HLi`037>L38@P3
7>L012DY:DXU:AcW0QS600<Lib487>L00aS600<DYAcW7>L00R481QS600<LiaS65:D02QS600@DYAS6
5:DHaP8Li`035:D@Q1BU008Li`HHaP8Li`<HaP055:DHaQcW8@PLi`066<H011BU6<HHaQBU11S600DD
YA245:DHaQBU008HaP<DY@<HaP055:DHaQcW7>LHaP045:D00aS65:DHaP026<H01acW5:DDYABU6<HL
iaS600LDY@046<HDYABU48@25:D00a245:DDY@035:D26<H00aBU48@DY@026<H00aBU48@DY@0248@2
5:D26<H45:D00a245:D@Q00248@45:D011245:D@Q12411BU1a2400<DYA2448@011BU00<HaQBU48@0
0Q2400DDYA245:D@Q1BU00HHaP037>LDYA24008@Q08DY@0348@DYABU00<DY@H@Q0<DY@0548@DYA24
48@<H`0448@25:D336<011245:D@Q0aS0Q2400<DYA2448@00QBU00<HaQBU48@00Q240QBU11240QBU
00@@Q1BU5:DDY@8@Q0<DY@0548@DYA2448@<H`0248@011BU48@@Q1240PaS00@@Q0aS48@@Q0PDY@04
48@DYABU48@236<348@236<548@25:D01a245:D@Q1BU48@DYAS600H@Q0045:D@Q0aS36<348@010aS
48@<H`aS0@Q2000010@Q00048@0010@Q00/8@P001248@Re[E[DicQcW;F/aS2U:008Q208U:@8YBP05
;F/Q22488@PU:@02;F/59BT38@P49BT01bU:9BTU:BU:;F/YBR48008Li`058@PU:BU:9BTQ20037>L2
8@P67>L48@P57>L00b489BTU:@028@P29BT00b489BTYBP029BT27>L02RU:;F/YBRDY7>LHaR489BTQ
22DY0bU:00@U:BU:9BTQ208Li`099BTQ22489BTYBR487>LHaR4800<Li`059BTQ21cW7>LHaP027>L3
8@P39BT01QcW8@PQ22U:8@PLi`8Q20059BTYBRDY8@PLi`028@P00acW9BTU:@02:DX3;F/3:DX00bDY
8@PQ20028@P00bDY:DXU:@037>L00bDY:DXU:@049BT00be[:DXYBP039BT00bU:8@PQ20039BT01248
9BTYBRe[0bU:00<]JbU::DX00RDY1B4800HLib489BTU:Be[:DX28@P012DY;F/YBRe[0RU:00<U:B48
9BT00RU:00<U:B488@P00bU:0bDY00@Q22DY8@PQ20<Li`8Q20039BTLiaS6008Li`058@PLib489BTQ
20057>L01QS67>LLiaS67>LHaPDLi`068@PLiacW7>LHaQBU0QS60QcW00<HaQcW7>L00aS600@Lib48
8@PHaP8DY@036<HLib4800@Li`8Q208Li`@Q200:7>LHaQBU6<HLib487>LHaQBU6<H37>L26<H27>L0
0aBU6<HDY@035:D26<H01AcW6<HHaQBU6<H00QBU00DHaQcW6<HDYAS6008Li`035:D@Q1BU00LHaP8L
i`@HaP047>LHaQS66<H27>L26<H27>L00aBU6<HDY@036<H27>L25:D00a245:DHaP026<H35:D01AS6
7>LHaQS65:D00aS61ABU0aS600HDYAS65:DHaQBU7>L<5:D011S65:D@Q1BU0QS61aBU00D@Q1BU5:D@
Q1BU008@Q0035:D@Q1BU008HaP035:D@Q1BU008DY@046<H@Q1BU48@25:D348@011BU48@@Q1BU0Q24
0QBU112400D<Ha245:D@Q1BU00@@Q0036<HDYAS600@@Q0045:D@Q1BU6<H25:D36<H011cW5:DDYABU
0Q240QBU11240QBU0a2400<<Ha245:D0112400LDYA2436<<Ha245:D@Q00236<748@00aBU48@DY@03
5:D01A245:DDYA245:D011240QBU00<@Q1BU5:D00a2400DDYA2448@@Q1BU008HaP0348@DYA24008@
Q00636<@Q12448@DYA240`aS1A2400<DYA2448@00aBU112400D<Ha2436<@Q0aS008@Q08DY@8@Q08D
Y@0448@DYABU5:D248@35:D548@336<248@436<248@136<0000300048@@Q00848@0300048@@Q00@4
8@049BU>LcW>8@P2:DX012DY:DXYBRe[0RDY00LQ22DY9BTQ22U:;F/YBP029BT2:DX38@P29BT2:DX0
0bDY:DXYBP029BT00acW8@PQ20028@P39BT38@P27>L01aS67>LQ22489BTQ22DY00DQ20049BTLiacW
7>L38@P27>L01R48;F/]Jbe[8@PLi`8Q20066<HLibDY:DX]JbU:0RDY00<Q22DY8@P00bDY0RU:00<U
:B487>L011cW0bDY00@Lib488@PQ208Li`@Q20<Li`038@PU:B48008Q20039BTQ22DY00HU:@047>LQ
22DY9BT2:DX012489BTQ22480RDY00X]Jc6<<H`]JbDY:DX]JbU:9BTQ208U:@8Q208U:@037>LHaQcW
008Q20037>LQ22DY00<U:@04;F/YBRU:8@P29BT38@P00bDY:DXU:@03:DX00be[:DXYBP02:DX00bDY
7>LLi`028@P37>L012489BTQ22DY0R480bDY00@YBRe[:DXYBP8U:@03:DXU:BDY008Q20039BTQ22DY
00<U:@068@PU:BDY8@PU:AcW0QS600<Lib486<H00QS600<Lib488@P00R480QcW12480acW1QS61AcW
00hQ21S66<HHaQBU6<HLib487>LHaQBU7>LQ21S60acW0QS60QBU11cW00@HaR488@PU:@<HaP078@PY
BRU:8@PHaQBU7>L00R4800<LiaBU5:D00QcW0R4800@LiaS66<HDY@8HaP<DY@<HaP047>LHaQBU5:D2
6<H00acW6<HHaP056<H011BU6<HHaQBU0aS600@Q21cW6<HHaP8DY@<Li`8HaP035:DLiaS600@HaP04
7>LDYAS65:D76<H00aBU6<HDY@036<H011BU6<HLiacW0QS600<DYAS65:D00aS600@LiaS65:DHaPDD
Y@036<HLiaS6008@Q0035:DHaQBU008@Q08DY@036<HDYABU008DY@0348@DYABU00<DY@0348@DYABU
00@DY@0448@DYABU5:D36<H25:D01Q245:DDYABU6<HDY@@@Q0035:D@Q1S600@DY@036<HDYA24008@
Q0035:D@Q124008DY@086<H@Q1245:DHaQBU48@<H`<@Q0045:D@Q1BU5:D248@011BU6<HHaQBU0Q24
0QBU00LHaQ245:D@Q1BU6<HDY@0248@45:D348@00`aS48@DY@0448@010aS48@@Q1BU0Q240aBU00D<
Ha2448@DYA24008<H`8@Q0<DY@0348@DYABU00@DY@8@Q08DY@<@Q0@DY@0548@DYABU5:D@Q0025:D0
0aS648@@Q00248@236<448@00`aS48@@Q00348@010aS48@DYABU0a2400HDYAS65:DDYA245:D248@0
0`aS48@DY@0348@00aBU48@@Q00248@25:D011245:DHaQBU0QS600<DYA2448@00PaS00<@Q0aS48@0
0Q2400@<Ha2436<@Q0D<H`0010@Q00@000@Q0008@P@48@048@Q>LcF]7>L2;F/29BT01BU:<H`]JbDY
8@P00bDY00DYBRe[:DXYBR48008YBP099BTQ22488@PU:B48:DXU:BU:008U:@06:DXU:B488@PLib48
0bDY0QcW0R4800HLiaS67>LQ21cW8@P29BT28@P00acW8@PQ20047>L02QS68@PU:BDY7>LQ22DY<H`]
JbDY11cW00<U:B48:DX00bU:00<U:AcW8@P00RDY00@YBRDY9BTYBP8U:@<Li`078@PU:BDY9BTLib48
6<H00QcW00@HaR488@PU:@8Q208Li`038@PU:B48008Q20049BTQ22DY8@P59BT38@P012DY;F/]JbDY
1B4800DU:BU:<H`aS2U:008U:@03;F/YBRDY008Q208U:@038@PU:AcW008Q20046<HLib489BT3:DX0
0bDY:DXYBP02:DX29BT58@P3:DX00be[:DXU:@04:DX012DY8@PQ21cW0b480QcW00<Q22DY9BT00RDY
00@Q22DY:DXU:@8YBPDU:@@Q20<U:@<Q20<U:@057>LHaQcW7>LHaP057>L011S67>LLiacW0RDY0R48
1AcW00<HaQcW6<H00QS60QcW00@Q21cW7>LQ208Li`<HaP067>LQ21cW7>LDYAS60QcW0QBU0acW0QBU
0QS60QcW00THaR488@PQ21cW6<HDYAcW9BT00RU:00<LiaS66<H00QcW00@Q21cW6<HHaP8Li`8Q208L
i`056<HDYAS66<HDY@026<H00aBU6<HDY@025:D=6<H35:D26<H01QcW6<HHaQS65:DHaP<Li`035:DH
aQS600<HaP047>LHaQS66<H27>L35:D36<H00aBU6<HDY@025:D01QcW6<HHaQBU6<HLi`HHaP8Li`8D
Y@0548@DYAS66<HDY@026<H021BU6<HLiacW5:D@Q1BU6<H25:D00a245:DDY@025:D00aS65:DHaP08
5:D011245:DDYABU0Q2411BU0QS600@@Q0aS36<DY@8HaPDDY@0348@DYA2400@DY@0348@DYABU00@@
Q0@DY@046<H@Q1BU48@35:D02A2436<@Q1245:D@Q0aS48@DY@0448@00aS65:DHaP085:D248@65:D3
48@25:D336<011BU48@@Q1240QBU00<@Q0aS48@00aBU1Q2400<<Ha245:D011BU0a240aBU0a241ABU
0Q2411BU00@@Q1BU5:D@Q08DY@8@Q00336<@Q124008DY@8@Q00336<@Q0aS00<@Q08<H`0448@DYABU
48@35:D248@25:D00a2436<<H`0248@25:D348@35:D248@45:D01QS65:D@Q124248<H`<@Q08<H`H@
Q08<H`48@P0000<48@0012401`@Q00H000Q29BUBU48@8@P29BT01be[<H`YBRDY:DX]JbU:008Q2009
9BTaS36<;F/YBRDY8@PYBRDY00<YBP<U:@09;F/aS2U::DX]JbU:8@PLib4800<U:@<Li`8Q208Li`03
6<HQ2248008U:@057>LQ22DY9BTQ20037>L01B489BT]JbU:9BT00R480RDY00<Q21cW7>L00QcW0QS6
00@LibDY;F/U:@8Q20<U:@<Q20039BTQ224800DLi`038@PU:B4800<Li`0:8@PLib487>LU:BU:9BTQ
21S67>L38@P29BT28@P02BDY8@P]JcF];F/YBQcW9BT]J`029BT28@P2:DX012DY:DXU:B480RU:00H]
JbDY9BTU:BU:9BT38@P29BT38@P00acW8@PLi`027>L00b489BTYBP02:DX29BT00b489BTU:@04:DX0
0b489BTU:@04:DX012DY:DX]JbU:12DY00DQ21cW7>LQ21cW008Q20<U:@<Q20069BTYBRe[;F/YBRDY
0R4800HU:BU::DXYBQcW8@P39BT2:DX00bDY8@PLi`027>L01R487>LLiacW8@PLi`<HaP059BTQ21cW
7>LQ20027>L38@P00acW6<HHaP027>L26<H01aBU7>LHaQcW6<HLib4800<Li`036<HLiacW008Q200=
7>LHaQS67>LQ21cW6<HDYAS68@PLiaS65:D00aS6124800@LiaS66<HHaP8Q20049BTQ21cW6<H27>L0
11S67>LQ21cW0QS60b4800@LiaS67>LHaPDDY@PHaP057>LHaQS67>LHaP027>L011S65:D@Q1BU0aS6
00@LiaS66<HHaP8Li`036<HDYAS6008HaP8DY@036<HLiacW00@HaP<DY@@HaP055:DHaQBU5:DHaP02
5:D46<H01ABU6<HDYAS65:D011S600<DYAS65:D01AS600@DYAS65:DDY@<HaP@DY@076<HDYABU5:DH
aQBU6<H00QBU00<HaQcW5:D00Q240aBU0a2400LHaQBU5:DDYA245:D@Q0025:D248@00aBU6<H@Q004
5:D00a245:D@Q0065:D00a245:D@Q0035:D00a245:DHaP0248@25:D26<H25:D748@236<011245:DH
aQBU112400<DYA245:D00QBU00H@Q1BU5:D@Q1BU6<H25:D01A245:DDYA245:D00a2400<DYA2436<0
0QBU00@HaQBU48@<H`8@Q0DDY@@@Q0035:D@Q12400@DY@<@Q08DY@<@Q08DY@056<HDYA2448@DY@02
6<H25:D00a245:D@Q0035:D248@00`aS48@@Q00348@01@aS48@@Q1245:D0112400@DYA2448@@Q0@D
Y@D@Q0035:D@Q12400@DY@<@Q0<DY@0348@DYABU00@DY@8@Q0035:DHaQ2400<<H`8@Q00436<@Q0aS
36<248@22480000400048@@Q000812402RDYDYA242489BTYBRDY:DX]JbU:0Re[0R480RDY0S6<0RU:
00<U:BU::DX00RDY0bU:00PQ22U:;F/]JbU:9BT]JbU:0b480RDY0R4800<Lib488@P00QcW0QS600<U
:BU::DX00acW0RDY00<Q21cW7>L00R480bU:00<U:B488@P00RDY00@Q21cW8@PHaP<Li`@U:@8Q208U
:@03:DXU:B4800<Q20DLi`@Q208Li`<Q208Li`048@PYBRDY8@P27>L00bDY8@PQ20039BT38@P012e[
=JdaS2e[0R4800<U:B488@P022DY12U:0RDY00<YBRDY:DX00RDY00LQ22DY9BTU:AcW9BTQ20037>L2
8@P00bDY:DXYBP029BT28@P39BT2:DX022DY8@PQ22U:<H`]JbU:9BT28@P01RDY:DXYBRe[9BTQ20<L
i`0?9BTQ22488@PU:B489BTQ22DY8@PU:BU:;F/YBRDY008Q20039BTYBRU:00@Q20049BTYBRU::DX2
9BT37>L031S68@PLiacW8@PLiaS65:DLib489BTQ208Li`058@PHaQcW7>LQ20047>L00aBU6<HDY@03
6<H00acW8@PLi`027>L28@P26<H01QcW9BTLiaS65:DHaP<Li`8HaP055:DLiaS66<HDY@026<H37>L0
0b489BTLi`036<H012489BTQ22480QcW0QS600<Q21cW6<H00QS60b480QcW0QS60QBU0Q2400<DYAS6
6<H00aBU0QS600DLiaS65:DHaQcW00<HaP037>LHaQS6008DY@8HaP8DY@077>LHaQS66<HDYAS65:D0
0QS600<DYAS66<H011S611BU1QS60aBU0QS600LLiaS66<HDYAS67>LHaP035:D00acW6<HDY@056<H0
11BU7>LHaQS60aBU00<HaQBU5:D00aBU0Q2400<DYAS66<H00QBU00<@Q1S66<H01AS611BU0a240aBU
0Q240aBU00<@Q0aS48@011BU00L@Q1BU5:DDYAS648@DY@0248@011BU6<HDYABU0Q2400HHaQBU48@@
Q1BU6<H85:D348@35:D248@236<248@85:D348@35:D01A245:DDYABU6<H01A240aBU0Q2400@DYA24
48@@Q08DY@<@Q08DY@0348@DYA2400<@Q0035:D@Q1BU00DDY@0448@DYABU5:D248@35:D248@25:D2
48@25:D26<H01A2436<@Q1245:D00a2400<DYA2448@01Q240PaS00D@Q0aS48@DYA24008<H`0348@D
YABU008DY@0348@DYA2400@@Q0DDY@8@Q0035:D@Q1S600<DY@0348@DYA24008DY@<@Q08DY@D<H`07
48@<H`aS36<@Q0Q236<00@Q200021240100012448@000P@Q00P8@P001248@Re[E[DicQcW0bU:00@]
Jc6<<H`YBP8U:@DYBP8]J`8YBP8U:@8YBP03<H`]Jbe[00<]J`0<<H`YBRU:9BTQ22DY:DX]JbU:8@PH
aQcW0b480acW00LQ22DY8@PU:AcW8@PU:@028@P27>L01BDY8@P]Jbe[:DX00R4800@U:BU:9BTLi`8H
aP037>LHaR48008Q208Li`038@PYBR48008Li`039BTQ22DY00@Li`<Q20<Li`8Q20<Li`038@PLib48
008U:@8Q20@Li`8U:@08:DX]JbDY7>LYBSF]<H`YBP8Q208YBP<U:@<Q20HU:@DYBP039BTQ2248008Q
200@9BTYBRU:9BTQ21cW8@PHaQcW6<HQ22e[<H`]JbU:8@P39BT00bU:9BTU:@02:DX29BT01RU:;F/Y
BRDY8@PU:@@YBP<U:@037>LU:B48008U:@<Q20067>LQ22489BTYBRe[0RU:1RDY00<Lib488@P00RDY
1BU:00@U:AcW6<HHaP<Li`<Q20@Li`038@PU:B4800<Li`<Q20036<HLiaS600DHaP038@PLiaS6008L
i`8Q20<HaP067>LQ22486<HLib481AcW0QS600<Q21cW6<H00QS60acW0b4800<LiaBU6<H00acW0R48
0QcW00@HaQcW7>LHaP8Q20067>LHaQS67>LU:B480acW0QBU0Q2400@DYAS67>LLi`8HaP035:DHaQS6
00@HaP038@PLiaS600<Li`8HaP065:D@Q1S67>LHaQcW11S600<LiaBU5:D00QBU00<LiaS66<H00aS6
00HDYAS67>LLiaS65:D36<H35:D46<H37>L011S65:DHaQS60QBU00<HaQcW6<H00aBU00<LiaS65:D0
11S600HDYAS66<HHaQBU6<H348@00aBU6<HHaP025:D46<H35:D26<H00aBU48@@Q0035:D248@00aBU
48@DY@0648@011BU6<HHaQS60aBU0a240QBU0aS60a240aBU00HHaQBU5:D@Q1S648@35:D01QS65:D@
Q1BU48@DY@8@Q00436<@Q1245:D248@85:D00a245:D@Q00248@45:D348@35:D011245:DDYAS61124
00HDYA245:DDYAS65:D248@35:D01a245:D@Q1245:D@Q1S600@DY@@@Q08DY@<@Q0045:DHaQBU48@4
5:D248@35:D00a2436<@Q00348@236<248@336<248@236<01a245:D@Q12436<@Q0aS00X@Q0065:D@
Q1245:D@Q1BU0Q2400<DYA245:D00Q2411BU00H<Ha2448@DYA2436<35:D0112436<@Q1241@aS0Q24
0PaS00000`0012448@0312400`0024848@0212401PQ2:DYF]CW>6<HU:@8YBP05;F/aS36<;F/YBP02
9BT00bU:9BTYBP05:DX01Be[9BTYBRU:;F/0136<00<]JbU::DX00RU:00<Q22DY;F/00RU:0QcW00DQ
21cW8@PLiaS6008Li`8U:@038@PLib4800@U:@<Li`068@PYBRe[:DXU:B480RDY0R4800<HaQcW7>L0
1QcW00DQ22DY9BTQ22DY00<Q20037>LQ21cW00LLi`038@PLiacW008Li`078@PLiacW7>LQ22DY8@P0
0acW0R480bU:00<U:B48;F/00SF]00HYBQcW9BT]JbU:9BT28@P011cW9BTU:B480RDY00<Q22DY9BT0
0bU:0bDY12480RU:0RDY0QcW0QS60QcW00<Q22U:;F/00RU:0R4812U:0RDY00@YBRDY8@PU:@<YBP<U
:@<YBP059BTQ21cW8@PLi`038@P011cW8@PU:BDY0R4800<U:BU::DX00RU:0bDY12U:0RDY00@Q22DY
:DXU:@<YBP8Q208Li`8HaP@Li`058@PLiacW7>LQ20037>L01AS67>LU:B487>L00QS600@LiaBU6<HD
Y@HHaP@Li`036<HLiacW00<Q208Li`048@PLiaS67>L25:D27>L022487>LDYABU7>LHaQBU7>L29BT0
1QcW6<HHaQS67>LQ208Li`8Q20047>LHaQBU6<H37>L26<H01AcW8@PLiacW6<H01ABU0QS60QcW00@H
aQ245:DDY@8HaP8DY@036<HLiaS6008Li`<HaP065:DHaQS66<HDYAS60acW1QS600TDYAS65:DHaQBU
7>LDYAS65:D01aS600@DYA246<HDY@<Li`8DY@8HaP067>LHaQBU5:DHaQBU0aS60aBU00<HaQcW6<H0
0QS60QBU00<HaQBU6<H00QS60Q240aBU00@@Q1BU5:DHaP@DY@076<HDYABU5:DHaQ245:D00Q2400@<
HaBU48@DY@<@Q0035:D@Q124008@Q0036<HDYABU008DY@0648@DYA245:D@Q1BU0Q2400<HaQBU5:D0
0QBU00D@Q1BU5:DDYA2400@DY@0548@DYAS65:DHaP0348@00`aS48@@Q00248@011BU48@@Q1240QBU
00<HaQBU48@00aBU00D@Q0aS48@@Q1BU00@@Q0085:D@Q12448@DYAS65:D@Q0<DY@<@Q0/DY@8@Q003
36<DYA24008@Q08HaP065:D@Q1245:D@Q1BU11240QBU11241QBU00D@Q1BU5:DDYA24008<H`D@Q08<
H`05248<H`aS48@DY@0348@00`aS48@@Q00748@01ABU36<<H`aS48@00QBU1a240QBU00<HaQBU48@0
0Q240QBU0Q2400@<Ha245:DDY@D@Q0<<H`8@Q0<<H`48@P0000D48@0012448@0000D48@070008@RU:
DY@icQcW9BT00S6<00@]JbU:9BTU:@<YBP049BTYBRU:;F/5:DX2;F/01C6<;F/aS36<;F/00RU:00@a
S2e[:DXU:@<YBP039BTQ2248008Li`048@PU:BDY8@P49BT00b489BTU:@029BT47>L01BDY;F/]JbDY
8@P00RDY00<Q21cW7>L00R4800LLiaS66<HHaQcW9BTQ20049BT00b486<HHaP027>L012486<HHaQS6
0acW00<Q21cW8@P00b480RDY0QcW00HQ22DY8@PLiaS67>L38@P03RU:;F/YBRDY8@PU:Be[<H`YBR48
7>LYBSF];F/39BT00b487>LQ20049BT00b48:DXU:@03:DX01RDY8@PQ22489BTYBP8U:@<Q208Li`03
6<HQ22DY008YBP049BTQ22489BT2:DX00bDY8@PLi`029BT5:DX29BT2:DX00be[:DXYBP029BT28@P0
0acW9BTU:@059BT48@P2:DX29BT00bU:9BTU:@02:DX02R487>LQ22DY;F/U:B48:DXU:B480acW0b48
00HLib488@PU:B487>L38@P00acW8@PQ20037>L02AS67>LLiacW8@PLiaS65:DHaP027>L011S67>LL
ib480QS60acW00<Q22U:9BT00acW0R4800HLiaS66<HLiaS67>L28@P00acW6<HHaP038@P27>L26<H0
0aBU6<HHaP036<H27>L00b486<HHaP025:D37>L01B486<HHaQS67>L00aS600@@Q1BU48@@Q08HaP09
7>LHaQS66<HDYAS67>LHaQcW008HaP037>LHaQS6008HaP037>LHaQcW008HaP037>LHaQS600<Li`DH
aP035:DHaQS600<HaP8DY@0648@HaR487>LHaQBU0aS600<DYAS65:D011S60acW00HHaQBU5:DDYAS6
5:D26<H00aBU6<HDY@026<H00aBU6<HDY@025:D00aS65:DDY@026<H45:D011245:DDYAS60aBU0QS6
0QBU00T@Q1BU5:D@Q1BU6<HDYAS648@00QBU00@HaQBU5:D@Q08DY@0548@<Ha2448@HaP025:D00a24
5:DDY@035:D248@00aBU48@HaP026<H35:D00aS65:DDY@025:D00a245:DDY@035:D00aS65:D@Q003
48@00aBU48@DY@0248@01ABU48@DYABU48@00PaS0aBU112400<DYA245:D00a2400H<HaBU6<HHaQBU
48@26<H348@021S65:D@Q1246<HLiaS65:D26<H248@00`aS48@DY@075:D00a245:DDY@035:D348@0
11BU48@DYA240aBU0Q240QBU0Q2400<<Ha245:D0112400@<Ha2448@@Q08<H`D@Q08<H`0348@<H`aS
00<<H`H@Q0065:D@Q12448@<Ha240QBU0Q240PaS0Q240QBU00@HaQ2448@@Q08DY@H@Q08DY@0448@<
H`aS36<248@00`aS48@<H`0236<348@000848@0300048@@Q00H48@06248YBUJe>LhLibU:0c6<00<]
JbU::DX01RU:00DU:Be[:DX]JbU:00<]J`05:DX]Jc6<=JdaS002:DX2;F/00bU:9BT]J`02:DX00bDY
7>LQ20028@P00bDY8@PQ20028@P29BT28@P00bDY:DXU:@038@P27>L01BDY:DXYBRDY8@P00RDY00DQ
21cW7>LLib48008Li`046<HLib489BT28@P00bU:9BTU:@047>L00b487>LLi`057>L01AS67>LLiacW
8@P00RDY0R480QcW00<U:AcW7>L00QcW00<U:B488@P012U:0RDY00H]Jc6<;F/U:B489BT2;F/39BT0
11cW8@PQ22480RU:0RDY0R4800DYBRe[:DXU:B48008Li`8YBP03;F/U:AcW008Q20<Li`039BTYBRU:
008YBP038@PLib4800<YBP0:7>LQ22DY:DX]JbU:9BTYBRe[:DX29BT012U:;F/YBRDY0RU:0R4800DL
ibDY9BTU:B4800<U:@<Q20039BTYBRU:00<YBP@U:@<Q20039BTYBRDY00<U:@038@PLiacW00HLi`8Q
20069BTQ22488@PLib482QcW0QS600<LiaS66<H00aS60acW00DHaQcW7>LLib48008U:@068@PLiacW
8@PU:AcW0QS600DLiaS67>LQ21cW008DY@076<HLibDY7>LQ21cW6<H00QBU0aS600<LiaS67>L00acW
00<HaQBU6<H00QS60acW0aS600<Q21S65:D00aBU0QS600<LiaS66<H00QS600@LiaBU5:DHaP8Li`03
6<HDYAcW00DLi`8HaP8DY@036<HLib4800<Li`036<HLiacW008HaP8DY@8Li`036<HDYABU00<HaP03
7>LHaQS600@HaP0;5:DHaQS66<HLiaS67>LHaQBU6<HDY@026<H00aBU6<HDY@046<H25:D56<H02ABU
6<HHaQBU48@DYAcW6<HDY@0248@01ABU6<HHaQS65:D00aS60aBU00@@Q1S65:D@Q0<DY@0548@DYABU
6<HDY@0348@00aBU48@@Q00248@35:D00a245:D@Q0045:D01Q245:DDYABU6<HLi`8DY@0548@DYABU
5:D@Q0025:D011S65:DDYAS60Q2400@<Ha2448@@Q0<DY@0448@DYA2448@35:D348@011BU48@DYA24
11BU00<@Q1BU5:D0112400<HaQBU5:D011240QBU00<HaQBU5:D011BU00DHaQBU5:DDYA2400@DY@05
48@DYAS67>LHaP025:D01aS65:DDYA245:D@Q0aS008@Q0<DY@0548@DYA2448@DY@0248@00`aS48@D
Y@045:D00`aS48@<H`0236<00a2436<<H`0536<248@011BU48@@Q0aS312400@<Ha2448@DY@@@Q005
5:D@Q12448@DY@0248@35:D248@00aBU48@@Q00348@236<:48@12480000400048@@Q000212403`00
1248@P001248@RDYDY@icR48:DX]Jc6<;F/YBP029BT2:DX29BT00bU:;F/]J`03:DX2;F/2:DX02be[
<H`]JbU:9BTYBRe[:DX]JbU:;F/00S6<00<]Jb488@P0124800@U:BU::DXYBP8U:@0;:DXU:BDY9BTQ
22DY7>LHaQcW9BTYBP049BT00bU:9BTQ20027>L01B487>LHaQS67>L00RDY11cW0RDY00@Q21cW7>LH
aPDLi`048@PU:B487>L26<H012489BTYBR480QcW0RDY00lQ21cW7>LHaQcW8@PLib489BT]JbDY7>LQ
22DY:DX00RDY00<Q22DY9BT00RDY00@YBR489BTLi`8Q20037>LU:BDY00<Q20059BTYBRU:9BTLi`02
8@P00bU:;F/YBP028@P27>L00b487>LQ20069BT28@P00bDY:DXYBP038@P2:DX02bDY;F/aS2e[9BTL
ibDY:DXU:BU:;F/00RU:1AcW0RDY00HYBR488@PQ22DY:DX39BT00b489BTYBP02:DX00bDY8@PU:@03
9BT00b489BTYBP029BT01R486<HHaQS67>LQ20<Li`@Q208U:@8Q208Li`036<HLiacW00DLi`058@PL
iaS65:DHaP027>L00aS67>LLi`027>L02AS67>LQ22DY:DXU:B487>LQ20087>L46<H37>L29BT27>L2
5:D26<H00acW6<HHaP036<H00acW5:D@Q0025:D01AcW6<HHaQS67>L011S611BU0QS600<LiaS65:D0
1QS60QcW00HHaQcW7>LHaQcW8@P27>L26<H37>L00aS67>LHaP026<H022487>LHaQS67>LHaQBU6<H2
7>L01AS65:D@Q1BU7>L00aS600<DYAS66<H01AS600<LiaS68@P01AS600<@Q1BU5:D00QS60aBU0QS6
00<LiaS65:D00QBU11S600/DYAS648@@Q1BU6<HLiaBU6<HDYAS600TDY@8@Q08HaP055:D@Q1BU5:DH
aP035:D011245:D<Ha2411BU00<@Q1BU5:D00Q2400<<HaBU5:D00QBU00DHaQBU5:D@Q1S6008DY@03
48@DYABU00<DY@036<H@Q12400/@Q0055:D@Q1245:D@Q0025:D011245:D@Q1BU0a2400<DYA2448@0
112400<DYA2448@00QBU00LHaQ245:DDYA245:D@Q0025:D36<H25:D26<H01ABU48@<Ha246<H00QBU
00@@Q1BU6<HLi`8HaP8@Q0035:D@Q124008DY@0448@<Ha2448@25:D248@00`aS48@@Q00448@00`aS
48@@Q00648@336<01A2436<@Q0aS48@00PaS11240PaS0Q2400L<Ha2448@@Q0aS48@DY@0548@00`aS
48@<H`0348@25:D748@25:D0112436<<H`aS0Q240QBU0Q2400<<Ha2436<00Q2400@<Ha2448@DY@4@
Q00010@Q00@000@Q1248@P@48@09;F]BU3W>7>L]Jc6<;F/YBR48008U:@04;F/YBR48:DX3;F/6:DX0
12e[<H`e[Be[0RU:0be[00<U:BU:;F/00S6<00@U:B487>LQ208Li`059BTYBRU:9BTQ20029BT2;F/0
1BDY8@PU:BDY8@P00QcW00<Q22U::DX00RDY00<Q22DY8@P00R481AcW00DQ21cW8@PLib4800<U:@8Q
208Li`046<HLiacW8@P27>L01b489BTQ22485:DHaR4800<U:@037>LQ2248008Q20037>LHaQcW00@Q
20039BTYBRU:008Q208YBP069BTQ22DY:DXU:B480bU:00<U:B488@P01bDY0RU:0RDY00<Lib489BT0
0bU:00@U:B488@PU:@@Li`038@PU:BU:00<Q20039BT]JbU:008U:@8Q20039BTQ22U:008aS00:;F/U
:BDY:DXU:B489BTYBRe[:DX38@P01QcW6<HLibDY:DXU:@@Q20049BTYBRDY8@P39BT01RU:9BTU:BDY
7>LQ208U:@05:DX]JbU:;F/Q20026<H011BU6<HLiaS612480QcW1B480acW00<HaQcW7>L00acW0aS6
00<LiaS67>L011cW00DQ21cW8@PHaR48008U:@038@PLiacW00<Q20@Li`056<HDYAS66<HLi`036<H0
2AcW9BTYBR486<HDYAS67>LDY@036<H00acW6<HHaP045:D36<H021BU6<HHaQcW6<HLiaBU6<H35:D3
6<H00aBU6<HLi`027>L00aS67>LLi`066<H57>L00aS65:DHaP027>L00aS65:DHaP028@P26<H011BU
7>LLiacW0aS60QBU00@@Q1BU6<HLi`8DY@0648@HaQcW7>LHaQ240QBU00DHaR487>LLiaS600@DY@DH
aP035:DHaQBU00<HaP8DY@@HaP045:DHaQBU6<H25:D00a245:DHaP026<H00aBU6<HHaP065:D00a24
5:DDY@025:D00a245:DDY@026<H25:D448@00aBU48@@Q0045:D011245:D@Q1BU0a240QBU00THaQBU
5:DDYA245:D@Q1BU6<H00QBU00<@Q1BU48@00a2400<HaQ2448@00a240aBU0Q240aBU0Q2400DDYA24
48@<Ha24008DY@8@Q08DY@8@Q0045:D@Q1245:D26<H25:D00a245:D@Q00348@36<H65:D00a245:DD
Y@045:D00a246<HLi`026<H448@25:D348@00`aS48@@Q00748@01ABU48@<Ha245:D01Q2400<<Ha24
36<00PaS00<@Q0aS48@00Q240`aS0Q2400<<Ha2436<00PaS0Q240PaS0Q2400@DYA2436<<H`D@Q0<D
Y@D@Q0035:D@Q12400@@Q003248<Ha24008DY@<<H`0548@<H`aS36<@Q00236<248@136<000030004
8@0000848@0300048@@Q00848@090008@RDYDY@e[B48;F/aS2e[008U:@05:DXU:BDY:DX]J`08:DX3
<H`00be[:DXU:@049BT01b48:DXaS2e[:DXQ22DY008YBP039BTQ2248008Li`8YBP<]J`@YBP8U:@8L
i`<U:@038@PU:BDY008YBP<U:@8Q20046<HLib488@P29BT01AcW6<HLib489BT00R480QcW0bDY00<Q
21cW7>L00R4800<U:B488@P0124800<Lib488@P00b4811cW0R4800<U:BU::DX00RDY00<Q21cW8@P0
0R481BDY0b481BDY00<YBRDY9BT00R481BDY0RU:00@]JbU:8@PU:@DLi`068@PU:B488@PLib480RDY
00@YBRe[:DXYBP8U:@@YBP8U:@048@PU:BU::DX29BT2:DX00bDY8@PLi`027>L01B489BTU:Be[:DX0
0b480RDY0b4800<U:BU:;F/00RDY00<Q22DY9BT00RDY00/Q22U::DXYBR487>LHaQcW6<HLiaS6008L
i`8Q20067>LQ22489BTQ21cW0b480acW00@Q21cW7>LQ208Li`8HaP037>LHaQS6008HaP8Q208Li`04
6<HQ22DY9BT28@P27>L012489BTLiacW0aS60QcW00@HaQcW7>LLi`<Q208U:@037>LDYABU008Li`03
6<HDYAS6008Li`8DY@036<HDYABU00LHaP045:DHaQS67>L35:D26<H00aBU6<HHaP056<H37>L26<H5
7>L36<H01QcW8@PQ21cW6<HLi`8HaP8Li`058@PLiaBU6<HLi`026<H00aBU6<HDY@056<H01AcW6<HQ
22486<H00QBU00<HaQcW7>L00QcW00<HaQBU6<H00QBU11S600DDYAS66<HHaQBU00HHaP047>LHaQS6
6<H95:D00aS67>LLi`046<H35:D011cW5:D@Q1BU0QS600<DYA245:D011BU00D@Q1BU48@DYA2400<D
Y@0348@DYABU008DY@8@Q0035:D@Q1BU00DDY@0348@HaQ2400@DY@0448@DYABU6<H25:D248@00aBU
48@@Q0045:D011245:D@Q1BU0Q2400<<HaBU5:D00aBU11240QBU00@@Q1BU5:D@Q08DY@036<HDYABU
008DY@056<HDYABU5:D@Q0025:D01Q245:DHaQBU6<H@Q08DY@0448@DYA245:D348@00aBU6<HHaP02
5:D348@010aS48@@Q1BU11240QBU00H@Q0aS48@@Q1BU48@236<0112436<@Q1BU1Q240`aS00D@Q0aS
48@<Ha2400@<H`0348@<Ha2400<@Q0<<H`0448@DYAS65:D248@336<248@00aBU48@@Q00248@236<0
11245:D@Q1240QBU0Q2400<DYA2448@00PaS0Q2400D<Ha2448@@Q1BU008@Q00536<@Q1245:D@Q001
36<000H48@030008@P@Q00848@05248U:Dic=JdLi`02;F/39BT2:DX01bDY:DXYBRe[:DXU:Be[00<Y
BP079BTYBS6<=JdaS2U:8@P01BDY00HYBRe[<H`]JbDY8@P39BT28@P03QcW8@PU:BDY;F/aS2e[:DXU
:BU:;F/U:B487>L28@P00bDY8@PU:@028@P29BT012U:9BTQ22480acW00LQ22DY8@PLiaS67>LQ2002
9BT012487>LHaR480RDY0R4800HLiaS68@PU:BU:8@P27>L39BT02QcW6<HQ22DY8@PLiaS68@PU:B48
0QcW00HQ22U:;F/YBR486<H38@P39BT2:DX29BT01AcW8@PU:BDY:DX00RDY0RU:00@U:B488@PQ20@U
:@06:DX]Jbe[;F/U:B481AcW00<Q21cW8@P00b4800PU:AcW9BTYBRe[9BTQ22DY0bU:00<U:BU:9BT0
1RDY0RU:00LU:B487>LLiaS67>LU:@02:DX00bDY8@PU:@028@P01AcW8@PQ22489BT00bU:0b480RDY
00<YBRDY9BT00RU:00<Q21S67>L00QcW00<HaQcW6<H0124800<Lib489BT00R4800<Lib487>L00QcW
00<Q21cW6<H00QS600HLiaS66<HLib487>L26<H47>L01QS67>LLibDY:DXU:@LLi`048@PLiacW6<H4
7>L02aS67>LQ22U:9BTQ21S65:DHaQcW6<H00QBU00@LibDY7>LHaPDDY@<HaP@DY@036<HLiaS600<D
Y@036<HLiaS600PHaP077>LHaQS67>LHaQcW6<H00QcW0aS600<Lib488@P00QcW00<HaQBU6<H00QcW
00<HaQBU6<H00QcW00@HaQ246<HLi`8HaP0648@DYABU6<HQ22DY0QcW0QBU0QS60acW1AS60aBU00HL
iaS66<HDYAS65:D26<H011cW6<H@Q1S60QcW00<HaQBU7>L00QS600@@Q1BU6<HHaP<DY@076<HLiaS6
6<HDYAS67>L01ABU11S60aBU0QS611241aBU00D@Q1BU5:D@Q1BU00@@Q0<DY@8@Q0DDY@<HaP045:D@
Q1BU48@35:D248@25:D348@00aS648@DY@0448@35:D248@00aBU6<H@Q00348@011BU48@@Q1240QBU
0QS60QBU0a240QBU0Q240QBU00<HaQBU48@01Q2400<DYA245:D00QBU00<@Q1BU5:D00QS60Q240PaS
0Q240QBU0`aS1Q2400@DYA2448@<H`D@Q00336<@Q12400H@Q00636<@Q0aS36<@Q0aS1a241PaS0Q24
00HDYA2448@<Ha2436<248@02QBU48@DY@aS48@DYA245:D@Q1BU1Q2400<<Ha2448@00Q240`aS0Q24
00<DYA2436<00PaS0A240ABU0@aS00001@00124000@Q00001`@Q00DU:DYB=JdLib48008U:@HYBP04
;F/YBRe[:DX29BT00b489BTU:@03;F/01BU:9BTQ22DY:DX00bDY0RU:00<U:B488@P00RU:00<U:B48
7>L00R4800@U:BU::DX]J`8aS004:DXU:BDY9BT38@P49BT28@P00bDY:DXYBP039BT38@P39BT28@P0
2AcW6<HLib489BTLiaS67>LQ20039BT28@P00bDY8@PQ20028@P012DY:DXU:B480QcW0b4800@LiaS6
8@PQ20<U:@8YBP<Q208U:@<Q20DU:@8Li`098@PU:BU::DXU:B489BTQ22U:00<U:@048@PLibDY9BT2
:DX01R48:DXYBRU:8@PHaP8Li`@Q20047>LQ22DY:DX4;F/49BT00bU:;F/YBP038@P01bDY:DXU:BDY
8@PU:BU:008U:@0<8@PLibDY9BTQ22U:;F/YBR487>LQ22DY0b480bDY0Re[00DYBR488@PU:BU:008U
:@04;F/YBRU:8@P27>L00aS67>LQ20047>L58@P29BT01B489BTQ22486<H011cW00<HaQcW6<H00QS6
0QcW11S600@Lib487>LLi`8Q20069BTQ22488@PU:B4811cW0aS600XLiaS67>LHaR487>LQ21cW8@PL
i`8Q20<HaP@Li`8HaP045:D@Q1S65:D96<H00aBU6<HHaP026<H01ABU6<HHaQS67>L00QS600@DYAS6
6<HLi`8HaPDLi`036<HDYABU008HaPLLi`8HaP8Li`038@PLiaS6008HaP8Li`036<HDYAS6008HaP05
5:DHaQS67>LQ20027>L36<H01aBU6<HHaR487>LHaQBU008HaP055:DHaQBU5:DHaP025:D36<H011cW
6<HHaQcW0aS600<LiaS65:D00QBU00DHaQBU5:D@Q1S600<DY@8HaP0348@DYABU008Li`@HaP035:DH
aQS600<DY@076<HDYABU5:D@Q1BU48@00QBU00@@Q1BU48@@Q08DY@0348@DYABU008DY@0448@<Ha24
48@65:D36<H65:D011S65:DDYA240QBU00<@Q0aS36<011BU1Q2400@DYA245:DDY@8@Q08DY@8@Q006
36<@Q12436<DYAS60QBU0Q2400<DYA2448@00aBU0Q2400LDYA245:D@Q1BU48@<H`025:D011S65:D@
Q12411BU00<HaQ2448@00Q2400@DYA2448@DY@@@Q0<DY@<@Q0035:D@Q12400<@Q0035:D@Q124008@
Q00536<@Q1245:D<H`0448@336<348@00aBU36<<H`0236<348@010aS48@<H`aS0Q240QBU0a2400D<
Ha245:DDYA2400<<H`@@Q00:36<@Q1BU5:D@Q0aS48@<Ha2436<348@00aBU48@@Q00248@01PaS48@<
HaBU48@DY@4@Q0002P@Q00H000Q28@Q:DSF]6<H39BT00b489BT]J`04:DX012e[:DXYBRU:12DY00DY
BRe[;F/YBR48008U:@DYBP8U:@068@PU:BU::DXU:B480QcW0RDY00<]JbU::DX00Re[00@YBRDY9BTU
:@<Q20<U:@8Q20039BTYBRU:008Q208U:@8Li`048@PU:BU:9BT47>L38@P011cW8@PLib480bDY0R48
1BDY00@Q22DY9BTQ208Li`XQ20<U:@8Q2004:DXU:B488@P39BT00b489BTQ20037>L00bDY:DXYBP02
:DX38@P00bDY:DXU:@038@P01BDY;F/U:BDY8@P00bDY0acW00<Q22DY8@P00QcW00@Q22DY9BTYBP<]
J`049BTQ22489BT2;F/00bU:9BTQ20029BT03BU:9BTQ21cW9BTYBRe[:DXQ21cW8@PLibDY00<YBP8Q
20039BTQ22DY00@Q20<YBP8U:@048@PU:B488@P2:DX00be[:DXQ20027>L00aS67>LLi`027>L00aS6
7>LQ20028@P01AcW8@PQ22489BT00R481AcW00DQ21S66<HHaQBU00<Li`036<HDYAS6008Li`038@PL
iacW008Q20039BTQ21cW008U:@048@PLiacW8@P27>L01AS67>LHaQBU6<H00QcW00<Q21cW8@P00b48
0aS600LLiaS66<HHaQcW8@PHaP025:D00a246<HHaP026<H00aBU6<HHaP026<H00aBU6<HDY@076<H0
0acW6<HHaP036<H27>L26<H27>L012487>LLiaBU0QS60acW00@HaQcW8@PLi`<HaP@Li`035:DHaQS6
008HaP035:DHaQS600@HaP045:DLiacW7>L46<H25:D01QcW8@PLiacW6<HDY@DHaP8DY@056<HLiaS6
5:DHaP027>L26<H37>L01ABU6<HHaQBU6<H011BU00@HaQBU6<HDY@8@Q08HaP8Li`8HaP055:DHaQcW
7>LHaP025:D00aS65:DHaP025:D00aS65:DDY@0248@00aBU48@@Q0025:D01aS65:DDYA245:D@Q1BU
00<@Q0066<HDYA2448@DYAS61QBU00<@Q1BU5:D011BU00P@Q1BU5:DDYA2436<@Q1BU0QS6112400<H
aQ245:D011BU1Q2400<DYA245:D00aBU00<@Q1BU48@011240aBU00@@Q1BU5:DDY@@@Q0046<HDYABU
5:D448@35:D348@011BU48@@Q1240QBU21240QBU0Q2400@<HaBU5:DDY@8@Q0<<H`045:D@Q12436<3
48@336<348@236<011245:D@Q0aS0Q240PaS00X@Q1BU48@@Q0aS48@DYA2436<@Q08DY@8@Q0@<H`05
48@DYA2448@DY@0248@236<011245:D@Q1240PaS00<@Q1BU5:D00QBU00<@Q0aS48@00Q240ABU0A24
0@aS0000100012448@001@@Q00P000@Q124Q248@;F/Lib480RU:0Re[00/YBRe[;F/YBRDY:DX]JbU:
9BTQ22DY008YBP8U:@05:DXU:BU:8@PU:@028@P01BU:;F/]JbU:9BT00RU:00@U:B488@PU:@8Q208U
:@04;F/aS2e[;F/39BT00b489BTU:@03:DX02bDY:DXQ22489BTYBRe[:DXU:B48:DX00RDY00@YBRe[
9BTQ208Li`048@PU:B488@P27>L28@P01bDY;F/]Jbe[:DXU:B4800HU:@HQ208Li`038@PU:BU:008U
:@@Q20047>LQ22DY:DX29BT28@P29BT28@P00acW8@PU:@03:DX27>L01248:DXaS2U:0R4800<U:B48
9BT00R480RDY00<]JbU:9BT00b4800@U:B487>LLi`8Q20039BTYBRU:008]J`0<:DX]JbU:8@PU:Be[
<H`YBQcW8@PYBRDY0R480RDY0R480bDY00DQ22DY9BTU:B4800<U:@<Q20039BTYBRDY008Q20089BTY
BRU:8@PLib489BTQ20@]J`038@PU:AcW00TLi`086<HQ22489BTQ21cW8@PYBP8Q20036<HLib48008L
i`<HaP037>LQ224800<Li`058@PLiacW7>LHaP027>L01R489BTU:BDY8@PLi`<HaP057>LHaQcW5:DH
aP027>L26<H01QcW8@PQ22487>LQ20DLi`0B6<HLiacW6<HDYA245:DHaQBU6<HDYAS67>LHaQcW8@PL
iaS60QBU1AS600HDYAS66<HLiaS67>L25:D00aS67>LLi`067>L36<H01ABU7>LLiacW8@P00QcW0QS6
0QcW00@HaR488@PLi`<HaP067>LQ21cW6<HDYAS60QcW0QBU0QS600<DYAS66<H00QcW0QS60QBU00@H
aQcW6<HLi`8HaP035:DHaQS6008HaP<DY@036<HLiacW008HaP087>LHaQS66<HDYAS648@DY@8HaP<D
Y@8HaP8DY@8HaP8DY@8HaP8DY@056<HLiacW5:DHaP027>L011S65:DHaQS61QBU00T@Q0aS5:DDYAS6
5:D@Q0aS48@00QBU00@HaQBU5:DDY@8@Q0<DY@036<HDYAS600<DY@0348@DYABU00@DY@0348@DYABU
008@Q00336<@Q1BU008@Q0055:DHaQBU48@<H`075:D00a245:DDY@025:D348@25:D00a245:DDY@03
6<H01ABU48@@Q1BU48@00QBU0a2400HDYA2448@@Q1BU48@26<H01ABU6<HHaQBU36<00Q240QBU00@@
Q1BU48@DY@D@Q0045:D@Q1BU5:D<48@01@aS48@<Ha2436<00a240QBU00@@Q0aS36<<H`8@Q0075:D@
Q0aS48@<Ha2436<00Q240PaS0Q2400TDYA2448@DYA245:D<Ha2436<01Q2400<DYA2436<00a2400@D
YA2448@@Q08<H`D@Q0035:D@Q12400<@Q08<H`0348@DYABU004<H`0000<48@0012400P@Q00<000@Q
124010@Q00HQ248@<H`HaR48:DX3;F/00bDY:DX]J`05:DX39BT3:DX29BT00bU:;F/U:@028@P00bDY
;F/]J`02:DX01RDY:DX]JbDY8@PLi`@Q20059BT]Jc6<<H`YBP028@P39BT00bU:;F/YBP038@P012DY
8@PU:Be[0RU:00HQ22DY9BTU:B489BT3:DX38@P011cW8@PQ22480acW00HU:Be[<H`aS2e[8@P39BT2
:DX00bDY8@PQ20038@P012DY8@PQ21cW0R4800<U:B488@P00R4800<U:B488@P00bDY0b4812DY00/Q
21cW8@PU:BU:<H`YBR487>LU:BU:008]J`@Q20HU:@03:DXU:B48008Q20<U:@068@PLiaS67>LU:BU:
0S6<00LYBRDY8@PU:BU:;F/YBP029BT012489BTYBRDY0R480QcW00<U:BU::DX00b4800<YBRDY9BT0
12DY0R4800<U:B489BT00bDY0bU:00DU:B488@PQ22e[008aS003:DXLiacW00@Q20@Li`078@PLiaS6
7>LQ22DY7>L00R4800<U:B487>L011cW00DHaQcW6<HHaQcW00DQ20<Li`056<HLiacW7>LU:@038@P2
7>L022486<HHaQS68@PLiaS65:D27>L36<H58@P47>L66<H01QcW5:D@Q1BU6<HQ208Li`096<HLiacW
6<HLiaBU6<HDYAS6008Li`<HaP037>LHaQS600@HaP<Li`036<HLib48008Li`086<HDYAS65:DLiaS6
8@PLi`DHaP<Li`036<HLiaS600@HaP037>LHaQS6008HaP8Li`036<HDYABU00@HaP8Li`8DY@056<HL
iaS66<HDY@026<H011cW6<HLiaS60aBU00DHaQcW7>LHaQcW00HHaPTDY@8HaP@DY@DHaP055:DHaQS6
7>LHaP035:D00acW6<HDY@036<H35:D448@01AS65:DDYABU48@00QBU0Q240QBU00D@Q1BU48@@Q1BU
00<HaP<@Q08DY@8HaP<@Q0<DY@8@Q0@DY@0448@DYAS65:D348@00aBU48@@Q0055:D00aS65:D@Q002
48@011BU6<HDYABU0Q240QS600DDYA2448@@Q1BU008HaP035:D@Q124008DY@0448@<Ha2448@46<H0
0aBU48@@Q0025:D00a245:D@Q00948@01aBU48@DYA245:D@Q0aS008@Q08<H`<@Q0035:D@Q124008<
H`0348@<Ha2400H@Q00336<@Q124008@Q0035:D@Q0aS008<H`<@Q0035:D@Q12400<@Q0045:D@Q1BU
48@236<248@01ABU36<<H`aS5:D00a2400@<Ha245:D@Q0<<H`035:D@Q124008<H`8@Q0075:DHaQBU
48@<Ha245:D00a240ABU0@aS000212400`001240000712401b48?NlYBQcW:DXaS3W>008e[@03;F/U
:BDY00@YBP@U:@04:DXU:BDY:DX49BT01b489BT]Jc6<;F/YBR48008U:@8YBP<Q20039BTYBRU:00<Y
BP<U:@8Q20057>LU:BU:;F/U:@028@P00bDY;F/]J`02:DX00bDY:DXU:@039BT01RU:;F/]JbU:9BTQ
20<U:@8Q20037>LQ2248008Li`089BTYBRe[;F/YBRDY8@PU:@8YBP049BTQ21cW7>L28@P021cW8@PU
:B487>LQ21cW9BT28@P27>L01248:DXU:B480QcW00DQ22DY9BTU:AcW00<Q20DU:@038@PLibDY008]
J`039BTLibDY008YBPDQ20<U:@<Q208U:@@Q20039BTYBRU:008YBP8U:@8YBP<U:@0;8@PU:BU:;F/Y
BRDY7>LQ22DY8@PU:@02:DX00bDY8@PU:@029BT00b487>LQ20038@P01BDY8@PU:BDY8@P012DY00LY
BRDY9BTYBRDY;F/YBP029BT00b487>LQ20038@P67>L011S67>LQ22480QcW00DU:BU:9BTLiaS600DQ
208Li`056<HLib489BTQ20036<H01AcW8@PLib489BT00R480QcW00<U:B487>L021cW0aS611cW00HQ
21cW7>LLiaS65:D47>L35:D021S67>LLiaS65:DHaQcW6<H37>L26<H01a246<HLib487>LHaQBU00@H
aP0648@HaQS69BTQ21cW0QS60QcW00DHaQBU48@DYAS6008Li`046<HDYAcW7>L36<H011cW6<HHaQS6
0QcW00<HaQcW8@P011S60acW0QS60aBU0QS600@LiaS65:DDY@THaP035:DHaQS600<HaP0348@DYA24
008HaP045:DLiaS67>L46<H25:D00a245:DHaP027>L55:D011S67>LHaQBU2AS60aBU00HHaQcW6<HD
YA245:D448@45:D00a245:DHaP046<H01QBU6<HHaQS65:D@Q0<DY@<@Q0046<H@Q1BU5:D26<H25:D0
0a245:D@Q00348@35:D00`aS48@@Q0025:D248@25:D00aS65:DDY@025:D26<H00aBU6<H@Q0025:D2
6<H25:D01aS65:D@Q1245:DHaQBU00H@Q0045:D@Q12448@26<H011BU48@@Q1240QBU0a2400<HaQ24
48@00PaS0Q2400@DYA2448@@Q08DY@8@Q0065:D@Q12436<@Q1BU21240`aS0Q2400<DYA2436<00PaS
00@DYA2436<<H`<@Q00336<@Q0aS00<@Q0<<H`0548@DYABU36<@Q0035:D236<548@236<648@336<0
0a245:D@Q00236<01A245:DDYABU48@00aBU00@@Q0aS36<@Q08DY@4@Q00000<000@Q12401P@Q00P0
00@Q124LicW>:DXLibU:136<00@]JbDY9BTU:@8YBP039BTQ22U:008YBP8U:@05:DXQ22DY9BTYBP03
9BT00bU:;F/]J`049BT00bU:9BTU:@038@P012DY;F/U:BDY0bU:00@U:B487>LLi`8Q208U:@038@PU
:BU:008YBP039BTYBRU:008U:@047>LQ22DY9BT2;F/00bU:8@PQ20029BT00b487>LLi`048@P29BT0
12U:;F/]JbU:0b4800<U:BU:9BT0124800DU:B489BTQ21cW008Q20059BTQ22487>LHaP027>L01248
9BTU:B480QcW00<Q22DY9BT00b4800<LibDY9BT00bDY0QcW00@U:BU::DXU:@8Q20039BTQ2248008Q
20049BTQ22DY8@P49BT47>L28@P012DY:DXYBRU:0RDY00<YBRDY:DX00bDY00HQ22DY:DXaS2U:9BT2
8@P00bDY7>LU:@02:DX00bDY8@PQ20039BT48@P012DY8@PU:BDY0R480RDY0bU:0b480bU:00DU:B48
8@PQ22DY00<Li`048@PLiaS66<H27>L00aS67>LLi`068@P00acW8@PLi`026<H00acW8@PQ20037>L2
9BT01R487>LHaQS67>LQ208Li`039BTQ21cW00LLi`<Q20047>LDYABU6<H27>L26<H01QcW9BTQ21cW
6<HLi`8HaP045:DLiacW7>L26<H00aBU6<HLi`056<H011cW8@PHaQS60QBU0aS600<LiaS67>L01aS6
0QcW00<Q21cW7>L00QS60QcW00@DYAS66<HHaP8DY@036<HLiacW008Li`036<HDYAS6008Li`056<HD
YABU6<HLi`036<H01AcW6<HHaQS67>L00QS60QBU00HHaQBU6<HHaQBU6<H25:D00aS65:DHaP025:D5
6<H00acW6<HHaP035:D27>L36<H01AcW6<HHaQBU6<H011BU0aS61QBU00<@Q1BU5:D00aS600@LiaS6
5:DDY@8HaP<DY@086<HLiaBU5:D@Q1BU6<H@Q08<H`0348@DYA2400DDY@<HaPHDY@8@Q0035:D@Q1BU
008DY@0648@DYABU5:D@Q1BU0Q2400<DYA2448@00Q2400<DYAS65:D00Q240QBU112400<DYAS66<H0
0aBU00<HaQBU5:D00aBU00@@Q1S66<HLi`8DY@8HaP035:D@Q124008DY@036<H@Q1BU00<DY@<@Q0DD
Y@<@Q08DY@H@Q00436<@Q12448@25:D248@236<35:D0112436<@Q1240QBU00T@Q0aS36<@Q0aS48@<
Ha2436<02A2400@<Ha2448@@Q0<<H`0348@<H`aS008@Q0<<H`<@Q08DY@<@Q0065:D@Q0aS36<8@PaS
0Q2400<DYA2448@011240PaS0a2400H8@PaS48@DYA2436<248@00aBU48@<H`0236<00a245:D@Q001
36<00008124000@Q124000@Q0008@P848@070008@QcW@Q0]Jb48:DX00S6<00D]Jc6<;F/YBRe[008U
:@8Q2003:DXU:BU:00<YBP8U:@@YBP08;F/aS2e[:DXU:BU:;F/U:@<Q208YBP8U:@058@PU:BU:;F/Y
BP029BT05R487>LQ22489BTYBRDY8@PU:B487>LYBRe[=JdaS2487>LQ22U:<H`]JbU:0RDY00<Q22DY
:DX00RDY0R4800HU:B488@PQ21S67>L29BT2:DX39BT2:DX022DY8@PQ22DY8@PU:B489BT28@P2:DX2
8@P011cW6<HLiacW1BDY00DLiaS68@PYBRe[00<U:@8YBP@Q20037>LU:BU:008]J`039BTQ22DY00<U
:@038@PU:BDY008Q20059BTYBRU:9BTQ20029BT28@P012DY:DXU:BDY124800PU:BU:;F/]JbU:9BTQ
22DY0RU:12DY00<Q22DY8@P012U:00<U:B488@P01R4800DU:BU::DXYBRDY00<Q208YBP8U:@058@PY
BRU::DXU:@057>L38@P37>L28@P37>L38@P02acW8@PQ22489BTQ21cW8@PLib489BT00R481acW00DH
aQcW7>LQ22DY008Q208Li`038@PLiacW008Li`048@PLiacW6<H27>L36<H77>L28@P46<H012487>LD
YABU0QS60acW00<DYAS66<H00acW11S600LLibDY8@PQ21S65:DHaP035:D00aS68@PQ20028@P011cW
8@PLiaS60QBU0aS600@LiaS67>LLi`8HaP045:DLib488@P26<H27>L36<H27>L36<H37>L26<H25:D2
6<H25:D011S67>LHaQS60QBU0QS600<LiaS66<H011S600HDYAS65:DDYAS67>L26<H25:D46<H35:D0
0a245:DHaP036<H00aBU6<HHaP0=6<H35:D66<H01ABU48@@Q0aS48@01ABU00<@Q1BU5:D00QS61QBU
00<@Q1BU6<H00QS600XDYA2448@@Q1BU48@DYA246<H@Q08DY@<@Q0045:DHaQS65:D248@45:D248@6
5:D26<H35:D36<H47>L00aBU6<HDY@065:D00aS65:DHaP075:D248@00aBU48@DY@0348@00aBU48@@
Q00248@00`aS48@@Q00248@25:D248@25:D02a245:D@Q12436<8@Q245:DHaQ2424800PaS00<DY@aS
48@00QBU00D<Ha2448@DYA24008<H`8@Q0035:D@Q0aS008<H`D@Q0<<H`0448@DYA245:D248@021BU
48@@Q0aS48@DYA2436<248@01ABU48@@Q12436<0112400L<Ha2448@@Q0aS48@<H`0348@00aBU48@@
Q00548@00aBU48@<H`01248000848@0300048@@Q00L48@098@Q242U:7>L]JcF]<H`]JbU:00<]J`03
:DXU:BDY008U:@078@PYBRU::DXU:B489BT01BU:00L]Jc6<;F/]JbDY:DXU:@028@P012DY:DXYBRU:
0RDY00DYBRe[:DXU:B48008U:@057>LHaR48:DXU:@028@P29BT00b489BTYBP02;F/02R487>LQ22DY
<H`]JbU:8@PU:BU:0bDY00<Q22DY8@P00b480QcW00DQ22DY9BTYBRDY008Q20<YBP038@PLiacW00@Q
20037>LU:BDY008YBP049BTQ21S66<H38@P29BT032489BTLiacW8@PYBRe[9BTQ22U:;F/U:@8Q2005
:DXQ21cW8@PU:@02;F/01BDY8@PQ22489BT00b480RDY00DQ22DY:DX]JbDY00<Q20037>LQ22DY008Y
BP8Q20039BTQ2248008U:@8YBP@U:@<YBP<Q20@U:@@YBP8U:@0:8@PU:BDY9BTQ21cW8@PU:BU:9BT2
8@P39BT01B489BTQ2248:DX00Re[00HU:AS67>LQ21cW8@P29BT00b487>LLi`038@P47>L38@P00bDY
8@PQ20027>L00b487>LLi`058@P011cW8@PLib480acW00HHaR488@PQ21cW6<H37>L00b487>LLi`05
7>L26<H27>L36<H57>L00b487>LLi`026<H37>L36<H00aBU6<HHaP026<H01ABU7>LQ21cW6<H00QBU
0acW0R4800PLiaS66<HLiaS65:DHaQBU0QcW00<Q22DY8@P00QcW00<HaQcW7>L00QS60QcW00@HaQcW
7>LLi`<HaP8Li`036<HLiacW008Li`036<HLiaS600@HaP@Li`8HaP8DY@@HaP8Li`046<HDYAS65:D2
6<H01AcW6<HHaQBU7>L011BU00<LiaS65:D01AS600DLiaS66<HDYAS6008DY@0548@DYAS66<HDY@02
6<H00acW6<HHaP056<H01acW6<HHaQBU6<HDYAS600@DY@8HaP8DY@036<HDYABU008DY@8@Q0035:DH
aQBU00<DY@8Li`036<HDYA2400HDY@8HaP8DY@8@Q0055:D@Q1245:D@Q0025:D01A245:DDYA245:D0
0QS60QBU00@@Q1BU48@DY@<@Q00336<DYAS6008HaP<DY@8HaP<DY@036<HLiacW008Li`056<HDYABU
48@HaP055:D548@00aBU6<HDY@025:D248@01QBU48@DYA245:D<H`8@Q0035:D@Q12400<@Q0055:D@
Q1BU48@DY@0248@25:D248@236<01a245:DDYABU48@<Ha24008<H`H@Q0035:D@Q12400P@Q08<H`04
48@DYA2448@236<35:D348@25:D248@010aS48@@Q1240PaS00@@Q1BU5:D<H`8@Q0055:D@Q0aS5:D@
Q00336<248@01QBU48@<H`aS48@HaP8@Q08<H`<DY@4@Q048@P0000@000@Q124000D48@0800048@@Q
7>M2436<8@PYBP<aS004;F/U:BDY:DX49BT2:DX49BT022e[:DX]Jc6<=JdicS6<:DX29BT00bU:9BTQ
20028@P01bU:;F/]Jbe[9BTYBRe[008YBP039BTYBRDY00<Q20039BTQ2248008U:@068@PLibDY:DX]
JbU:12DY00@YBS6<;F/]J`DU:@<Q20067>LQ22DY9BTQ21S60QcW00PU:BU:9BTLib48:DX]JbU:0b48
00@Lib487>LQ20<U:@<YBP039BTYBRDY00<Q20@U:@058@PU:BU::DX]J`06:DX01RDY:DXYBRDY8@P]
J`8aS08U:@06:DX]JbDY8@PLib480RU:00LU:B489BT]JbU:9BTLi`028@P00acW8@PU:@02:DX02248
7>LHaR489BT]JbU:9BT38@P3:DX38@P01AcW8@PQ22489BT00bU:00@U:B487>LQ208Li`048@PU:BDY
8@P29BT00bU:9BTU:@038@P012DY:DXYBRU:0RDY00<YBRDY7>L00QcW124800@U:AcW7>LHaP<Q2009
7>LQ22488@PLib489BTLib4800<Li`038@PLiaS6008Li`038@PLiacW00DLi`066<HLiacW8@PU:B48
0QS60R4800<LiaS68@P00RDY0QcW00<Q21cW7>L02acW00<HaQcW6<H011cW00<HaQBU6<H00QS60QBU
00<HaQcW6<H01AS600@DYAcW6<HLi`<Q208Li`@HaPLLi`046<HDYABU5:D26<H01QBU6<HLib487>LH
aP8Li`046<HDYAcW9BT28@P00aS65:DHaP026<H25:D00aS67>LLi`076<H25:D46<H00aBU6<HHaP06
5:D26<H00acW6<HDY@026<H00aBU6<HDY@026<H00acW6<HHaP025:D36<H35:D26<H00acW6<HHaP05
6<H011BU6<HLiacW0aBU00<HaQBU5:D00QBU00<HaQcW6<H00QBU00DHaQBU5:DDYA2400@DY@<@Q0@H
aP8DY@036<HDYABU00<DY@056<HDYABU5:D@Q0035:D348@35:D01A2436<@Q1BU6<H01ABU00T@Q1BU
5:D@Q0aS48@HaQcW5:D00QS600@LiaS65:D@Q0<HaP037>LHaQcW008HaP047>LDYABU5:D26<H25:D0
11245:D@Q1BU0aS600@DYA2448@DY@<@Q00:5:D@Q1BU48@DY@aS48@<Ha245:D348@011BU48@@Q124
0QBU00D@Q1BU48@DYA2400<<H`0348@DYA2400<<H`045:D@Q1BU48@336<00a245:D@Q00348@00aBU
48@@Q00248@236<348@236<548@25:D00a245:D@Q00448@01QBU48@@Q1BU36<@Q0<DY@0348@<HaBU
008@Q0045:D@Q12448@336<248@336<248@01ABU48@<Ha2436<00Q240PaS000412400`0012448@05
12401QcW?Nl]Jb48:DX]J`8aS004;F/U:B48:DX29BT01bU:;F/YBRDY7>LQ22DY00@YBP04<H`e[CF]
=Jd2:DX012489BTU:B480RDY0be[00<YBRe[;F/00Re[0RDY00<YBRDY8@P00QcW0bDY00<Q22DY8@P0
0R4800<U:Be[;F/00RU:00HU:B48:DXaS3F];F/28@P59BT27>L00b489BTYBP028@P01QcW8@PQ22DY
8@PLi`8U:@8]J`8Q20047>LQ22489BT38@P00bDY:DX]J`02:DX01RDY8@PQ21cW8@PU:@8Q20039BTQ
22U:008YBP049BTYBRU:<H`3;F/2:DX012e[9BTQ22U:0SF]00d]Jb48:DXYBRDY8@PHaR489BT]JbU:
8@PU:@02:DX01R487>LQ22DY8@PU:@<YBP039BTLiacW008U:@8]J`<U:@037>LQ22U:008YBP038@PL
ibDY008Li`059BTYBRU::DXQ20029BT012487>LLib480RDY00<Q21cW8@P00RU:00LU:B488@PU:B48
9BTQ20039BT2:DX01BDY8@PLiacW8@P00RDY00@Q21cW7>LQ20<Li`038@PU:B48008Li`@Q20057>LH
aQcW7>LQ20037>L01R486<HLiaS67>LQ20<Li`<Q208U:@8Q208HaP038@PHaR48008U:@<Li`8Q2003
7>LHaQS6008Q20037>LQ21cW00<HaP058@PLiacW7>LHaP047>L01AS65:DDYABU7>L00QS600@DYAS6
6<HLi`8HaP045:DHaQS66<H48@P011cW6<HLiaS60QcW00<HaQcW8@P00R4800<LiaS66<H011BU11S6
11cW00<HaQBU7>L00QcW00<Q21cW7>L00QS60QcW00<HaQBU6<H02AS600@DYAS66<HLi`LHaP045:DH
aQBU5:D36<H00acW6<HDY@025:D00aS67>LLi`026<H011BU6<HHaQS611BU0aS60QcW0QBU00DHaQcW
7>LHaQ24008HaP047>LHaQS66<H25:D00aS65:DDY@026<H01ABU6<HHaQS65:D00QS60QBU00D@Q1BU
5:DDYA2400<DY@036<HDYAS600<HaP8DY@8@Q0@DY@0348@DYABU008DY@036<HDYA2400D@Q0055:DH
aQS65:D@Q0035:D548@01aBU48@HaQBU6<HLiaS600<DY@066<HLiacW8@PLiaS60QcW00DHaQBU6<HD
YAS6008DY@0348@DYABU008DY@8HaP055:D@Q1245:DHaP0348@011S65:D@Q1BU0Q240`aS00@@Q1BU
48@DY@@@Q0095:D@Q12448@DYAS65:D<Ha24008<H`<@Q00436<@Q0aS36<348@236<35:D248@00aBU
48@@Q00336<248@336<248@336<00a245:DDY@025:D01A245:DDYABU48@00PaS0a240QBU112400LD
YA2448@@Q0aS48@DY@0248@236<348@01`aS48@@Q1BU48@<HaBU00D@Q04<H`0000<000@Q00000P@Q
00<000@Q124010@Q00HU:DYB<H`U:Be[<H`4:DX38@P012DY;F/YBRU:0R480RDY0RU:00<]JcF]>Lh0
0SW>00<]JbDY8@P00bU:0RDY00DQ22U:<H`aS2U:008U:@03:DX]JbU:00<U:@8Q20049BTQ22487>L3
9BT02B489BTYBRe[:DXQ21cW8@PU:@03;F/39BT012U:9BTLiacW0R480QcW0R4800<LiaS66<H00b48
00<U:B489BT00bU:11cW00LQ21cW7>LQ22U:;F/YBP039BT00bU:9BTU:@028@P59BT01Be[<H`]JbDY
:DX00S6<00@]JbDY:DX]J`8U:@08;F/e[CF]:DXU:BU:;F/YBP8U:@<Q208U:@8YBP038@PU:B4800HQ
20<U:@@Q208U:@05:DXU:B488@PU:@02:DX38@P27>L29BT00bU:9BTU:@02:DX00bDY7>LHaP028@P6
9BT012489BTU:BU:0bDY1BU:0RDY00@Q21cW7>LLi`@U:@<Q20HLi`<Q20<Li`048@PLiacW8@P27>L2
6<H27>L36<H00acW8@PQ20027>L00b489BTYBP028@P29BT00b487>LQ20048@P27>L00b487>LLi`04
7>L012487>LHaQcW0R480QcW0QS60acW1QS600HDYAS66<HHaQBU6<H27>L26<H02acW8@PQ22487>LQ
21cW8@PLiaS65:D00aS60QcW0R4800@LiaS65:DDY@DHaP067>LQ21S66<HDYAS60QcW0QS60acW0QS6
00DDYAS66<HHaQBU00HHaP0;7>LHaQBU6<HDYAS67>LQ21cW6<HDY@046<H45:D26<H25:D01A245:DD
YAS65:D011S60QBU00<HaQBU6<H00QBU1AS600<LiaBU5:D00QS600<LiaS66<H00QS600<DYAS66<H0
0aS600@DYAS65:DDY@8HaPLDY@8@Q0<DY@0348@<H`aS008@Q0@HaP035:DHaQ24008@Q08DY@<@Q0@D
Y@@@Q0065:D@Q12448@DYA240QBU00T@Q1BU5:DDYA245:D@Q1BU48@00QS600<LiaS66<H00QcW00<H
aQ245:D00QS611cW00<HaQBU6<H00aS600<DYAS65:D00aBU00<HaQBU5:D00a2400@DYAS65:DDY@8@
Q08DY@<@Q0035:D@Q12400<@Q0035:D@Q124008@Q0035:D@Q1BU008@Q0065:D@Q12448@<Ha240PaS
00T@Q0aS48@@Q0aS48@<Ha245:D00a241QBU0Q240PaS0Q240PaS112400<<Ha2448@00a240QBU0Q24
00<<Ha2448@01Q2400@DYA2448@DY@@@Q0075:D@Q12436<@Q0aS48@010aS0Q240QBU00D@Q0aS36<<
HaBU00<<H`001P@Q00@000Q2124000848@049BU6<C6<8@P2<H`01Be[9BTYBRe[9BT00R4800<U:BU:
:DX00RDY00@Q22DY:DXU:@8]J`<e[@8aS08YBP039BTYBRDY008Q20049BT]Jc6<;F/39BT3;F/00bU:
9BTQ20029BT01b489BTLib489BTYBRDY008Q20039BTYBRU:00<Q20039BTYBRe[008YBP8Q2004:DXU
:B487>L26<H27>L28@P26<H021cW9BTQ21cW8@PYBRe[9BT58@P29BT37>L00bDY:DXYBP02;F/29BT2
8@P29BT01QcW8@PQ22489BTYBP8]J`<YBP0<<H`]JbU::DX]JbDY8@PYBSF]<H`]JbDY0bU:00<U:B48
9BT00RDY0b480RDY00@Lib488@PU:@<Li`DU:@<Li`039BTYBRU:00<Q208YBP039BTLiacW008Q200;
7>LQ22489BTQ22DY:DXU:B487>LHaP028@P29BT28@P39BT012489BTU:BU:0bDY0bU:00@U:B489BTQ
208Li`058@PU:BU:9BTQ20027>L38@P87>L01b487>LLiacW8@PHaQcW008HaP037>LHaQcW008HaP@L
i`048@PLib489BT38@P012DY8@PQ21cW0b4800<LiaS67>L00QcW00@Q21cW7>LHaP8Q20057>LDYAS6
6<HQ20047>L00aS65:DHaP027>L00aS65:D@Q0076<H27>L36<H011cW8@PLib480RDY00@Q21cW6<HL
i`<HaP037>LQ21S600DLi`055:DHaQBU5:DHaP037>L00aS65:DHaP027>L26<H00aBU6<HLi`037>L2
5:D00aS65:DHaP066<H00aBU6<HHaP026<H01A246<HLib486<H00QBU00<LiaS66<H011BU11S60QBU
00@HaQ245:DDY@@HaP<DY@036<HDYABU008HaP8DY@036<HLiaS6008DY@056<HLiacW6<HDY@026<H0
1AcW6<HDYABU6<H00aBU00<HaQBU6<H01aBU00<@Q1BU48@00Q2400@DYA245:D@Q08DY@8HaP8DY@03
48@DYABU008@Q0035:D@Q1BU008@Q08DY@036<HDYA24008@Q08<H`8@Q0<DY@0448@DYA246<H25:D3
48@00aBU48@DY@026<H011cW6<HHaQBU0aS600<DYAS67>L00QcW00<HaQBU5:D00aS600@DYA245:DH
aP<@Q0056<HDYA2436<@Q0025:D548@75:D248@01@aS48@@Q1245:D01A2400@DYA2448@DY@@<H`8@
Q0D<H`8@Q0<<H`0348@HaQBU00<DY@0348@DYA24008@Q08<H`8@Q08<H`X@Q08DY@D@Q00336<@Q0aS
00D@Q0055:D@Q12448@<H`0248@236<348@236<248@011BU48@DYA2410aS0a2400001@00124000@Q
00000`@Q00X8@P@Q1248@Re[E[DicQS69BTYBP@U:@<Q2004:DXU:BDY9BT2:DX29BT01RU:<H`e[CF]
>Lh]J`8U:@8Q20099BTQ22DY8@PU:BU:;F/U:BU:008]J`03<H`YBRU:00LU:@04:DX]Jbe[;F/29BT3
:DX29BT01R487>LQ22DY:DXU:@8Q2004:DXU:B487>L28@P00bDY8@PHaP037>L012487>LHaQS60QcW
00DYBRe[:DXYBQcW00LQ20049BT]JbU:;F/29BT2:DX59BT00bU:9BTU:@04:DX29BT03RU:<H`aS2U:
8@PU:BU:9BTYBSF]>Lhe[BDY8@P2;F/012DY8@PYBRU:0b4800<YBRDY8@P00R480RDY00@Q22DY7>LL
i`8U:@05:DXQ22487>LQ2003:DX28@P022DY:DXYBRDY8@PU:B489BT28@P00bDY:DXYBP028@P01bDY
8@PHaQcW8@PU:B48008Li`038@PU:B48008Q2006:DX]JbU:9BTQ22U:0Re[0bU:00@U:B487>LQ208U
:@8]J`059BTQ22487>LQ20027>L00aS67>LQ20028@P01RDY8@PLiaS67>LQ20<Li`8HaP037>LHaQS6
00<HaP8Li`036<HLiacW008U:@058@PLiacW7>LQ20029BT00acW8@PLi`027>L011S67>LLib480acW
00DU:B488@PDYAS600PLi`<HaP035:DHaQS600<HaP047>LHaQcW7>L28@P57>L38@P012DY8@PLiaS6
0QBU0QS60QcW00@HaQcW7>LLi`@HaP085:D@Q1BU6<HLib485:DHaP8Li`036<HDYAS6008Li`8HaP03
7>LHaQcW008HaP055:DHaQS66<HLi`026<H00aBU6<HDY@035:D26<H37>L36<H011cW5:DDYABU0QS6
00<DYAS66<H00QBU00<@Q1BU6<H00QS60aBU00<HaQBU6<H00QS611BU00@HaQBU5:DDY@@HaP057>LD
YABU5:DHaP027>L25:D00aS65:DDY@035:D00a246<HHaP045:D46<H011BU48@@Q1240QBU00D@Q1BU
48@HaQcW008HaP035:D@Q1BU008@Q00536<@Q1BU48@DY@0248@01QBU48@DYABU48@DY@<@Q08DY@03
48@DYABU008DY@0348@DYAS600<DY@PHaP8DY@036<HLiacW008HaP057>LHaQS65:DHaP035:D46<H3
5:D021245:DDYABU48@DYA246<H45:D021245:DLib487>LDYA245:D448@011BU48@@Q0aS0Q2400<D
YA2448@00a240PaS00D@Q0aS36<@Q0aS008@Q00536<@Q12448@<H`035:D00aS648@@Q00348@00`aS
48@@Q00348@336<448@00`aS48@@Q00248@336<00a2436<@Q00448@011BU6<HDYABU0`aS0Q2400<<
Ha2448@00Q2400<<Ha2448@00a2400<<Ha2436<0112410aS0A240@aS0009124020001248@RU:E[Di
cQcW9BT4:DX00bDY8@PQ20029BT00bU:9BTU:@059BT00be[<H`aS002<H`01BDY8@PQ22489BT00R48
0bU:00@U:BU::DXYBP@]J`0;:DXQ22488@PU:BU:9BTQ22U:;F/YBP039BT2:DX29BT37>L00bDY:DXU
:@028@P012DY8@PLib480RDY00@LiaBU7>LQ20HLi`066<HLibU::DX]JbDY0QcW00LQ22DY8@PQ21cW
8@PU:@03:DX00bDY:DXYBP02:DX49BT00bU:9BTYBP03:DX29BT00bU:;F/]J`03:DX01bDY:DXU:BU:
=JdicS6<008U:@03:DX]JbU:00@U:@038@PU:BDY00@Q20<U:@@Q208U:@<Q20059BTYBRU::DXU:@02
8@P012DY:DXU:BDY0R480RDY00<Q22DY9BT00RDY12480QcW00<U:B489BT00R4800<Lib489BT00RDY
0RU:0RDY00<YBRe[:DX00RDY0RU:00@U:B487>LU:@8]J`03:DXU:BDY008Q20HLi`8Q20047>LHaQcW
7>L48@P26<H011cW6<HHaQcW0QBU0QS60acW0R480RDY00<Q21cW8@P00RDY00@Lib489BTQ20@Li`8Q
20<Li`049BTQ21cW5:D26<H37>L00aS67>LQ20027>L00aS65:DHaP027>L01aS65:DDYAS67>LHaR48
008Li`<Q20077>LQ22DY8@PLib487>L00QS600HDYAS67>LHaQcW6<H57>L01aS65:DDYAS65:D@Q1BU
008Li`036<HDYAS600<HaP8Li`8HaP<Li`8DY@8HaP055:DHaQS67>LHaP025:D01QS65:DDYABU6<HL
i`DHaP035:DHaQS600<HaP8DY@0548@DYAS66<HDY@0248@26<H00aBU6<HDY@045:D26<H00acW6<HD
Y@035:D26<H00acW6<HDY@036<H35:D46<H25:D01Q245:D@Q1BU48@DY@8HaP8DY@<HaP8DY@036<H@
Q1BU008@Q0055:DHaQBU5:D@Q0036<H25:D00a245:D@Q0025:D248@01PaS48@DYA245:DHaP8DY@<@
Q0@DY@0448@DYABU48@55:D011S65:DHaQBU11S60QBU0QS600<LiaS67>L01aS60aBU0QS600HDYAS6
6<H@Q1BU48@35:D00a245:D@Q0025:D348@01AS68@PU:B486<H01Q240aBU00<@Q1BU48@00a240`aS
00<@Q1BU48@00`aS00D@Q0aS36<@Q0aS00D@Q0045:D@Q1BU5:D448@00aBU48@@Q00436<248@00aBU
6<H@Q00248@00`aS48@@Q0025:D0112436<<H`aS21240PaS0Q2400PDYA2448@<Ha2436<@Q0aS1124
00<DY@aS36<00PaS0Q2400@<H`Q236<@Q08<H`0000<000@Q00000P@Q00<000@Q248010@Q00DYBUJe
?NlQ22DY008Q20@U:@03:DXU:BDY008YBP089BTQ22489BTYBRe[<H`]J`8YBP049BTQ21cW8@P2:DX3
8@P00bU:;F/]J`03:DX3;F/2:DX59BT012U:;F/]Jbe[0bU:00@]JbU:8@PQ208U:@8Q20067>LU:BU:
:DXU:AcW0R4800<YBR487>L00QcW00@HaQcW7>LQ208Li`8HaP048@PYBRe[:DX68@P39BT8:DX00b48
9BTU:@02:DX39BT01RU:9BTU:BDY:DX]J`8YBP03;F/YBRe[00<U:@8aS005;F/U:BDY;F/YBP029BT3
:DX022DY8@PU:B489BTQ22DY8@P29BT00bU:9BTU:@038@P27>L28@P00bDY8@PU:@049BT01B489BTQ
22DY8@P01BDY0R480RDY0R4800@Lib489BTU:@8Q208Li`048@PU:BDY8@P29BT022489BT]Jbe[:DXU
:BU:;F/2:DX48@P01BU:9BTU:BDY8@P00RDY0R4800@HaQcW7>LLi`@Q20047>LHaR488@P27>L26<H0
0acW6<HLi`046<H27>L26<H00acW8@PU:@029BT28@P39BT01BU:8@PLiacW6<H011cW1B4800PLiaS6
6<HLib487>LHaQcW0RDY00@Q21cW6<HDY@<Li`035:DHaQS6008HaP077>LQ21cW7>LQ22DY8@P00acW
00DQ21cW6<HLib48008HaP8DY@036<HLiaS6008HaP<Li`035:DHaQS600@HaP<Li`<HaP057>LQ2248
7>LHaP037>L011S65:DDYABU0QcW0QBU00<HaR487>L00QcW0QS600<DYAS66<H00QS600@DYAS67>LH
aP8Li`8HaP035:DHaQS600<@Q08DY@0436<@Q1BU6<H35:D00aS65:DDY@046<H01ABU6<HDYABU6<H0
0QBU00<HaQBU6<H00QS600DDYAcW7>LLiaS600<DY@056<HDYABU5:D@Q0035:D011S65:DHaQS60aBU
00<@Q1BU5:D00QS600<DYAS67>L00QS60QBU00@HaQBU6<HDY@8@Q0035:D@Q1BU008DY@0348@DYABU
008@Q0035:D@Q1BU008DY@@@Q08DY@8HaPPDY@046<HDYAS67>L26<H00aBU48@DY@026<H00aBU6<HL
i`027>L00aS65:DHaP025:D00aS65:DHaP045:D248@01PaS48@DYABU6<H@Q0@DY@8@Q08DY@086<Hi
cT8@<H`Li`Q248@DY@<@Q00336<@Q1BU008DY@0648@<Ha2448@DYA241`aS00@@Q1BU36<<H`8@Q08D
Y@0348@DYA2400<@Q0035:D@Q124008<H`0448@<Ha2436<648@00aBU36<@Q00248@00aBU48@@Q003
48@00aBU48@@Q00248@00`aS48@@Q00248@01@aS48@@Q1BU48@00`aS0a240PaS00<DYA2436<00PaS
0Q2400<<Ha2448@00`aS0A240@aS000312400`0012448@0412401P00248U:E[F@Q0Li`<U:@04:DXU
:BDY9BT2:DX79BT01BU:;F/]Jc6<;F/00RDY00<Q22DY8@P0124800<U:BU::DX01BU:0Re[0RU:00@U
:B489BTU:@<YBP8]J`<U:@06;F/YBRDY7>LQ22U:0RDY00LLib488@PYBRDY8@PLi`048@P26<H27>L0
12487>LLiacW0QS600@Q22U:<H`YBPPQ20049BTYBRe[;F/2:DX2;F/00bU:9BTQ20029BT012U:9BTY
BRDY0RU:0RDY0bU:00D]JbU:;F/]JbU:008U:@03:DXaS2e[008U:@03:DX]JbU:00<U:@03;F/YBR48
008Q208U:@038@PU:BDY008U:@@Q20039BTQ224800@Q208U:@8YBP@Q2003:DXU:BDY00DU:@8Q208U
:@048@PLib487>L48@P011cW8@PU:BDY0RU:0R4800@U:Be[<H`]J`@YBP<Q20069BTQ22DY:DXU:BU:
0b4800@HaQcW7>LLi`@Q208Li`056<HLib487>LQ20057>L26<H01aBU6<HLiacW5:DHaQBU00<Q2004
9BTQ22489BT38@P29BT00acW6<HHaP057>L48@P00acW6<HHaP027>L36<H01AcW8@PQ21cW5:D00QS6
00<Lib487>L00aS600<Lib488@P011cW00<Q21S67>L00R4811cW00<HaQBU5:D00QcW0QS600<DYAS6
6<H00QcW00DHaQBU6<HDYAS600@Li`@HaPHLi`<HaP035:D@Q1S6008Li`046<HDYAcW7>L36<H01248
7>LHaQBU0aS600<DYAS66<H00QcW0QS600@DYAS65:DHaP8DY@0348@DYA24008@Q0035:DHaQS6008D
Y@046<HDYAS65:D26<H00aBU6<HDY@025:D248@56<H35:D26<H00acW6<HHaP025:D00aS648@DY@03
5:D01AS65:DDYAS65:D01AS600<DYAS648@00aBU00<LiaS66<H00QBU00DHaQBU6<HDYA2400<DY@8@
Q0DDY@0448@DYA2448@55:D00a245:DHaP025:D00a245:DHaP026<H00aBU6<HDY@026<H01ABU6<HD
YABU6<H00aBU00DHaQcW7>LLiaS600<DY@8HaP065:D@Q1BU5:DHaQBU0Q2411BU1A241ABU00P@Q1S6
>Li243F]7>L8@Q240QBU1A2400@DYA2448@DY@<<H`<@Q0@<H`@@Q0035:D@Q124008@Q0045:D@Q1BU
5:D248@010aS48@DYA240PaS0a2400<<Ha2448@01A2400<<Ha2448@00a2400D<Ha2448@@Q0aS008@
Q08DY@0548@<Ha2448@<H`0348@00aBU36<@Q00236<348@010aS48@@Q1BU0Q2420aS0A240@aS0000
1@0012448@@Q00000`@Q00L8@P@Q1248@Sg_OomNm`027>L28@P2;F/2:DX39BT00bU:9BTU:@039BT0
0bU:9BTYBP02;F/012DY8@PLib4812DY00<YBRe[;F/00bU:0be[00@U:B489BTYBP8U:@038@PU:Be[
008aS003:DXU:BU:008]J`8U:@038@PYBRU:008U:@038@PU:BU:008YBP8Q208U:@058@PLiacW8@PU
:@027>L00b489BTLi`026<H00b489BTU:@028@P00acW8@PU:@029BT28@P01BDY:DXYBRU:<H`00SF]
00<]JbU::DX00RDY1B4800H]Jc6<:DXU:B489BT4;F/2:DX3;F/49BT2:DX29BT01BU:<H`aS2U:9BT0
0R4800DU:BU:9BTQ22DY008YBP039BTQ22DY00@U:@038@PLib4800DU:@038@PU:BDY00<Q208U:@8Q
208YBP039BTLiacW008Q20077>LQ22DY;F/U:B487>L00b4812U:12DY0be[0S6<0RDY00<Lib488@P0
12DY00@Q22DY8@PU:@<Li`<Q208Li`8HaP<Q20049BTLiacW6<H37>L01AS65:DHaQcW6<H01AcW1248
0QcW0RU:0RDY00DHaQcW8@PLibDY008Li`036<HLib48008Q20@Li`<HaP8Li`048@PLiacW6<H27>L2
8@P47>L28@P57>L00aS67>LQ20028@P77>L26<H01aBU6<HHaQS67>LQ21cW008HaP<Li`036<HDYAS6
00@Li`036<HLiaS6008Li`058@PLiaS66<HDY@026<H00aBU6<HHaP037>L00aS67>LLi`026<H00aBU
6<HHaP066<H011cW6<HHaQcW0QS600<DYAS65:D00QBU00@@Q1BU5:D@Q08DY@8HaP@DY@8HaP065:DH
aQcW6<HDYA240QS60aBU0QS60QBU0aS600<LiaS66<H00QS62aBU31S61aBU0Q2400@DYA2448@@Q0@D
Y@<@Q0<DY@8@Q0066<H@Q12448@DYAS611BU00<@Q1BU6<H01QS600<LiaBU5:D00QBU0QS600<DYAS6
6<H021S60QBU00@@Q1S65:DDY@8@Q0045:D@Q0aS48@25:D248@45:D02Q246<H<HaBU<Ha:DSW>8@P<
Ha240QBU00<@Q1BU48@01A240PaS0Q2400DDYA2448@<H`Q2008@Q08DY@<@Q0055:D@Q1BU48@<H`03
48@45:D248@00aBU48@@Q00236<00a245:D@Q00548@00aBU48@@Q00:48@436<348@011BU48@@Q124
0`aS0a2400<<Ha2436<00a240PaS00<@Q0aS48@01A240@aS000212401@0012448@@Q00000PQ200P0
00@Q248icWooHaPQ22DY0QcW0RU:00@U:BU::DXQ20LU:@8YBP8]J`<YBP8Li`038@PU:BU:008U:@<]
J`05:DX]Jbe[;F/YBP039BT01R489BTYBRU:8@PU:@8aS005:DXU:BU:=Jd]J`028@P00bDY:DXU:@03
9BT4:DX012DY8@PQ22DY0R4800<Lib487>L00QS60R4800<LiaS67>L00b4811cW00TU:BU:9BTU:B48
9BT]JbU:;F/00c6<00<]JbU:9BT00RDY00@YBR488@PQ208YBP06;F/YBRDY8@PU:BU:0Re[0RU:00<U
:Be[;F/00Re[00<YBRDY9BT00bU:00<U:BU:;F/00Re[0R480bDY12U:0RDY0R4800<U:BU:9BT00b48
00<U:B489BT012DY0b480RDY0b480bDY0R480RDY0R4800@LibDY9BTU:@8Q20@U:@<YBP039BTQ22DY
008YBP08<H`]JcF]<H`YBRDY7>LQ20@U:@@Q20047>LHaQS67>L29BT011cW6<HLiacW0QS600@LibDY
9BTQ208Li`036<HLiaS600<HaP0>7>LQ21cW7>LHaQcW8@PYBRDY8@PLiaS67>LQ20<U:@037>LHaQS6
008Li`098@PLiacW7>LQ22DY8@PLiaS600@Li`036<HLib4800<Q20<HaP8Li`038@PHaQS6008HaP03
7>LQ2248008Li`066<HLiacW6<HLib480QcW0QS60acW00<HaQBU5:D00QBU00DHaQcW8@PLiaS6008D
Y@067>LHaQS66<HLiaS60acW00@Q21S67>LHaP<Li`8HaP<DY@046<HDYAS66<H37>L26<H00b487>LH
aP025:D26<H27>L46<H00acW6<HHaP026<H00aBU6<HDY@035:D01a245:DDYA246<HDYAS600@DY@HH
aP045:D@Q1BU5:D66<H00a245:DHaP027>L46<H35:D00a245:DDY@026<H25:D36<H00aBU6<HLi`02
5:D26<H00acW6<HDY@085:D011245:D@Q1240aBU0a240QBU00@HaQ2448@@Q0<DY@0348@DYAS600<H
aP045:DHaQS66<H25:D36<H01acW6<HDYABU48@DYAS600<DY@<HaP8DY@046<HLiaS67>L35:D00a24
5:D@Q0025:D348@00aBU48@@Q0035:D04A245:DDYA245:D@Q1BU=Je243W>7>L8@QBU6<HDYA2436<0
0Q240aBU00P@Q0aS36<<HaBU48@<Ha240PaS0Q2400<DYA2448@00a2400LDYA2448@@Q1BU6<HDY@09
48@236<0112436<@Q1BU11240QBU0a2400<<Ha2448@00Q2400H<Ha2448@DYA2436<848@436<248@0
0aBU48@DY@0348@01`aS48@@Q12436<8@PaS008@Q04<H`448@000`@Q00<000@Q12400P@Q00d8@P@Q
000<HcW>OomS61cW8@PHaQBU8@PU:@02;F/29BT3:DX01RDY8@PU:BDY;F/aS08]J`HU:@8YBP039BTY
BRU:00<aS003;F/YBRDY00<U:@@YBP8U:@DYBP<Q208U:@03:DXU:BDY008Q2005:DX]Jbe[:DXU:@02
8@P00bDY8@PQ20067>L00aS67>LLi`027>L38@P27>L01b489BTU:B487>LQ22U:008U:@04;F/aS36<
;F/49BT2:DX99BT3:DX01Be[:DXYBRU:;F/00S6<00T]Jb488@PU:C6<;F/U:B48:DX00S6<0RU:0RDY
00@]JbU:9BTQ20DU:@068@PLib48:DX]JbU:0R4800@U:B488@PU:@8YBP039BTLiacW008Q20<U:@03
8@PU:B4800HQ20037>LU:BDY00<U:@@Q20<YBP039BTQ2248008U:@<]J`04:DXU:B489BT27>L28@P2
9BT01AcW8@PLib489BT00R4800@U:B488@PQ208Li`036<HLiacW008Q20039BTQ21cW00@HaP037>LH
aQBU008HaP038@PLib48008Q208Li`046<HLiacW7>L39BT01b487>LLiacW6<HLib48008U:@048@PL
ib488@P:7>L00aS67>LHaP026<H57>L01BDY8@PLiacW8@P00acW00<HaQcW7>L01QcW21S600PDYAS6
7>LLiaS65:DHaR480QcW00LDYAS69BTU:BU:9BTHaP037>L26<H65:D00aS67>LHaP046<H01QcW8@PL
iaBU6<HDY@@HaP045:DLiaS67>L26<H00acW6<HHaP035:D26<H011BU6<H@Q1240aBU2aS60QBU00@H
aQcW6<HDY@@HaP045:DHaQS66<H27>L01aS67>LDYABU6<HDYAS600<DY@<HaP035:DHaQcW00@HaP04
5:DHaQBU6<H25:D36<H35:D248@01QBU48@DYA245:DHaP<DY@0;48@DYABU5:D@Q1BU48@DYA245:D@
Q0026<H01acW6<HDYABU6<HLiaS6008DY@0648@HaQcW8@PLiaS61aBU00@HaQcW7>LHaP8Li`056<HD
YABU5:DHaP045:D00a2436<@Q0025:D00a2436<@Q0035:D348@36<H248@01acW9BTQ21S636<@Q1BU
008@Q00636<@Q12448@DYA240PaS0Q2400LDY@aS48@DYA245:D@Q0025:D00a245:DDY@025:D01124
36<<Ha240QS600<DYA2448@00QBU112400HDYA245:D@Q1BU48@25:D00a2436<@Q00348@236<448@0
0`aS48@<H`0348@011BU48@@Q0aS112400<<Ha2436<01Q2400D<Ha245:D@Q1BU00<<H`0448@DYABU
48@236<124800003124000@Q00848@0400048@@Q2482124010Q2>LioofLi0QcW00LDYA249BTYBRe[
:DXU:@03:DX29BT2:DX01B48:DXaS3F];F/00R4800@YBRDY8@PU:@8YBP8U:@04;F/aS2e[;F/4:DX0
1RDY8@PQ22U:;F/YBP<U:@07:DX]JbU:9BTLibDY8@P00RDY00DYBRDY:DXU:B48008YBP03;F/YBRDY
008U:@8Q20DLi`058@PLiacW7>LHaP038@P01BDY8@PQ22487>L00R4800XU:B488@PU:B48:DX]JcF]
<H`]J`@U:@8YBP8U:@038@PU:BU:008U:@058@PU:BDY:DX]J`04:DX2;F/00cF]<H`U:@028@P02S6<
;F/U:B489BT]Jc6<;F/YBRDY0RU:12DY0RU:0RDY0b4800<U:BU:9BT00RDY0R481BDY00LQ21cW8@PU
:BU:9BTQ20039BT48@P00acW8@PU:@039BT2:DX29BT28@P00bDY:DXYBP038@P3:DX2;F/2:DX28@P2
7>L01R489BTU:BDY8@PLi`<Q20039BTQ21cW00HLi`056<HLib489BTQ20027>L00b486<HHaP026<H3
7>L38@P27>L01B486<HLiacW8@P00QcW00HQ22U:9BTQ21cW6<H27>L00b487>LQ20048@P27>L00aS6
7>LLi`057>L01B487>LHaQBU6<H00acW00<DYAcW9BT00RDY1AcW00@HaQcW7>LQ20DLi`046<HLiaBU
6<H27>L011S65:DDYABU0acW00DHaQBU6<HQ21cW008HaP037>LQ22DY008Q20037>LQ21cW00<HaP8L
i`036<HDYAS600DHaPLLi`035:DHaQBU00HHaPDLi`086<HDYABU6<HLiaS65:D@Q0@DY@0648@DYAS6
6<HLiaS60QBU0QS600<LiaBU6<H00QBU1AS600@DYA245:DDY@DLi`<HaPDDY@046<HLiacW6<H25:D0
1AcW6<HLiaS65:D00aS600<DYAS66<H00QS60aBU0a240QBU00<@Q1BU5:D00QBU0Q241ABU0a2411BU
1AS61QBU00@HaQcW7>LHaPHDY@0448@HaQS67>L36<H011cW6<HDYABU0QS600@DYA245:DDY@<@Q003
5:D@Q12400<@Q0DDY@0:48@DYA2436<@Q1cW9BTQ21S648@25:D0112436<@Q1BU112400<<Ha2448@0
0Q2400<DYA2448@01QBU1Q2400<<Ha2448@00QBU00<@Q1BU48@00Q240QBU11240QBU0Q240PaS0Q24
00<DYA2448@00`aS0Q2400@<Ha2448@@Q08<H`0448@DYABU48@236<0112436<@Q12410aS0Q2400DD
YA2448@@Q0aS00D@Q00336<@Q124008@Q04<H`48@P0000<000@Q000020@Q00/8@Re[E[DmkaBU8@PU
:B489BTQ22DY008YBP8U:@8YBP8]J`8U:@04:DXaS36<;F/39BT01Re[:DXYBRDY:DX]J`8aS08]J`08
:DX]JbU:9BTYBRDY:DX]J`8YBPDU:@8Q20049BTQ22488@P29BT38@P012DY:DXYBRe[0bDY00<Q22DY
8@P00QcW00@Q21cW7>LHaP8Li`8HaP068@PU:B487>LHaRDY0R4800@U:Be[:DXQ208Li`05:DX]Jbe[
=Jd]J`029BT28@P39BT00b489BTYBP02;F/01RU:9BTU:AcW9BT]J`<aS006:DXU:Be[=JdicRe[0RDY
00`YBRe[:DXQ21cW:DXaS3W><H`U:BU:9BT28@P011cW9BTU:BDY0RU:0R4800DLib489BTQ22DY008Q
20049BTYBRe[:DX49BT28@P01acW8@PU:BU:9BTQ22DY00<Q20079BTQ22489BTYBRe[9BT00R4800LU
:BU:9BTU:B489BTQ20029BT01BU:9BTU:BU:;F/012U:0R480QcW0R480RU:00<U:B488@P00R480acW
0b480QS60QcW0RDY0R4800DHaQcW7>LLiaS6008Li`<Q20047>LQ22489BT28@P57>L01QS68@PYBRU:
8@PHaPDLi`038@PLiacW00<Li`8Q208Li`036<HQ2248008Q20037>LDYAS6008Li`039BTQ21S6008L
i`<Q20036<HLiaS600<Li`<HaP037>LHaQS6008HaP<Li`8HaP047>LHaQBU6<H27>L00aS65:DDY@04
7>L012486<HHaRDY0RU:00@Q21cW7>LLi`@HaP085:DHaQS66<HLiaS65:DLi`<HaP037>LQ21cW008H
aP8DY@046<HDYABU5:D86<H37>L00aS65:DHaP026<H25:D248@01aS67>LLib487>LHaQcW00<HaP03
5:DHaQBU00LHaP045:DHaQBU6<H25:D36<H00acW6<HDY@025:D86<H00aBU6<HHaP026<H00aBU6<HH
aP026<H25:D46<H45:D348@00aBU6<HDY@0248@00aBU6<HHaP035:D010aS48@@Q1S60QBU00@HaQcW
7>LHaP8@Q0035:DLiacW008DY@0548@HaQS65:DHaP045:D00a246<HDY@025:D66<H00aBU6<HDY@03
5:D00a245:D@Q00248@010aS48@@Q1BU0a2400<DYAS65:D00QBU1A240QBU00<@Q1BU48@00a2400<<
Ha245:D00Q2400<<Ha2448@0112400<DYA2448@00Q240QBU0Q2400<<Ha2448@011240QBU0a240aBU
112400<DYA2448@00a240QBU0Q240PaS0a2400<DYA2448@00a2400@DYA2436<@Q0<DY@8@Q0@<H`04
48@<Ha2448@25:D848@01ABU48@@Q0aS48@00QBU0A240@aS000412400`0012400002248020001248
@S6<DY@e[ABU7>L29BT2:DX00bDY:DXYBP039BT05bU:;F/U:BDY8@PYBRe[<H`]JbDY8@PU:BU:<H`Y
BR48:DX]JcW>=JdYBRe[:DX00Re[00PU:B488@PQ22U:9BTYBRDY0R480RDY00<YBRDY8@P012480bDY
00HLibDY9BT]JbU:9BT28@P29BT00b489BTQ20047>L36<H012489BTU:BDY0acW00@U:B48:DXYBP8U
:@8Li`099BTYBS6<<H`]JbU:8@PLib4800DU:@05:DX]Jbe[:DXU:@038@P2;F/2<H`00bU:9BT]J`02
>Lh00be[9BTQ2003:DX02R487>LYBS6<=Jd]Jb489BTYBRDY0R480bDY0bU:0bDY12480RDY00<YBRDY
8@P00bDY1R4800DU:BU:9BTQ21cW008Q20049BTQ21cW9BT2:DX00bDY8@PQ2002:DX00bDY8@PU:@02
9BT012U:9BTU:BDY0bU:0Re[00<U:B487>L00R4800<LibDY:DX00RU:1B480QcW124800<Lib486<H0
0QcW00DQ22DY8@PLiaS600HLi`HQ20049BTQ21cW6<H27>L48@P00acW8@PHaP067>L28@P26<H27>L0
12487>LLib481AcW0aS60R4800<LiaS66<H00QcW0b480acW00@HaR487>LLi`8HaP8Li`8HaP<Li`@H
aP035:DHaQS6008Li`8HaP<Li`058@PLiacW7>LU:@02:DX012DY6<HHaQS60QcW00<Q21S65:D00QBU
0QcW00@HaQcW7>LQ20HLi`035:DHaQS6008HaP035:DHaQBU008HaP047>LHaQS66<H37>L011S65:DH
aQS611BU11S60QcW00@Q21cW6<HDY@@HaP045:DHaQBU7>L36<H25:D56<H00aBU6<HLi`027>L26<H0
1ABU6<HHaQS67>L01aS600DDYAS66<HDYAS600<DY@<HaP8DY@0348@DYABU008DY@8@Q08DY@8@Q08D
Y@046<HDYA245:D248@35:D00aS65:DHaP026<H02QcW5:DDYABU6<HLiaS648@DYAS60aBU0QS600<D
YA245:D00QBU0aS600@LiaS67>LLi`8HaP065:DHaQBU5:D@Q1BU112400dDYA2448@@Q1BU48@<Ha24
5:DLiaS648@<H`0348@00aBU48@DY@035:D01A2436<<H`aS5:D00Q2400@<Ha2448@@Q0@DY@0448@D
YA245:D348@35:D448@35:D00a245:D@Q00:48@01QBU48@@Q1BU48@DY@8@Q0045:D@Q0aS36<248@0
0`aS48@@Q00248@236<45:D348@010aS48@@Q0aS0Q2400DDYA2448@@Q1BU00<@Q08<H`P@Q0<<H`00
00<000@Q12402@@Q00@U:Dic=JdHaPDU:@03:DXU:BDY00<YBP<U:@04;F/aS36<;F/2:DX01Re[:DXY
BRU:;F/aS08]J`09:DX]Jc6<;F/YBRDY8@PYBRe[008YBP<U:@03:DX]JbU:008U:@068@PU:BDY:DXU
:BU:0RDY124800PYBRe[9BTU:B489BTYBRDY124821cW0RDY0R4800<HaQcW9BT00bU:1B4800@U:Be[
;F/YBP8U:@<Li`058@PYBRU:9BTYBP029BT01bU:8@PYBRDY:DX]Jc6<00@]J`8aS008;F/YBR48:DXa
S2e[9BTYBP<]J`039BTYBRU:008U:@078@PU:B487>LQ22DY:DX00RDY0R4800@U:B489BTU:@8Q2004
9BTYBRU::DX89BT012U:9BTU:BDY124800@LibDY8@PQ20HU:@037>LQ22DY008U:@8Q208YBP03;F/U
:BDY00@U:@048@PLiacW7>L28@P39BT38@P011cW8@PU:BDY0R480QS60R480Re[00DYBRDY7>LLib48
00<Li`<Q20057>LHaQcW8@PU:@068@P27>L28@P00bDY8@PLi`027>L00aS67>LLi`039BT00b487>LQ
20028@P27>L28@P01BDY8@PLiacW6<H00acW0R482QcW00<Q21cW7>L00QS60QcW00DHaQcW6<HHaQcW
008HaP8Li`8Q20036<HDYABU008Li`8HaP057>LQ22487>LHaP037>L01B487>LQ22DY7>L00aS600@L
iaBU6<HDY@8Li`DHaP035:DHaQcW008HaP047>LHaQS66<H35:D36<H37>L01b486<HDYABU6<HLiaS6
008DY@8HaP035:D@Q124008HaP077>LHaQS67>LHaQcW6<H011BU0QS600<DYAS66<H00aS600HLiaS6
6<HDYAS65:D36<H47>L36<H01AcW6<HHaQBU6<H00QcW00<HaQBU5:D00QS600@DYAS65:DDY@LHaP<D
Y@0448@DYABU48@25:D011S65:DDYABU0Q240QBU00DLiaS65:DDYAS600@DY@8HaP<DY@<HaP8DY@05
6<HDYABU5:D@Q0055:D00aS67>LHaP026<H01AcW5:DDYABU48@00QS600@DYA2448@@Q0<DY@0348@D
YA24008DY@0448@DYABU6<H35:D011S65:D@Q0aS0Q240QBU0a2411BU0Q240aBU00<@Q0aS36<00QBU
0Q240QBU0Q2400@<Ha2436<DY@<@Q08DY@D@Q0035:D@Q1BU00@@Q0045:D@Q1245:D448@00aBU48@@
Q00236<348@336<00a245:DDY@0548@35:D348@336<448@00`aS48@@Q00248@00`aS48@<H`0948@1
5:D136<000<48@0300048@0000@48@060008@RDYCW<icQcW0RDY00@Q22DY:DXYBP<U:@8YBP8U:@05
:DX]Jbe[<H`]J`04:DX2;F/012U:;F/aS2e[0RU:00<]Jc6<:DX00RDY1BU:0bDY0bU:0RDY0RU:00LU
:BU::DXYBRDY8@PLi`028@P59BT2:DX01BDY8@PLiacW8@P00QcW00DQ21cW6<HHaQcW00<U:@8Q2003
7>LQ22U:008YBP0<9BTLibDY8@PLib48:DX]Jc6<:DXQ22DY0QcW00<Q22DY;F/012DY0R4800DU:BU:
:DXU:Be[008aS08YBP04;F/e[CF];F/29BT00bU:<H`]J`039BT3;F/01BU:9BTU:B489BT01B4812DY
0R4800@U:B488@PQ208U:@8YBPHU:@8Q20037>LU:BDY008U:@<Q20037>LQ2248008U:@8Q208YBP04
9BTLib488@P29BT28@P29BT022e[:DXU:BDY8@PU:BU:9BT27>L28@P00acW9BTYBP029BT27>L29BT4
8@P02AcW8@PQ22487>LQ22DY:DXU:@027>L28@P37>L00b487>LLi`027>L38@P27>L38@P00acW8@PQ
20038@P67>L01b489BTU:B487>LHaQcW00DQ208Li`058@PLiaS66<HLi`028@P00acW6<HHaP027>L0
1B487>LHaQS67>L011S611cW11S600<DYAS67>L00b4800<HaQBU5:D00QS600<LiaS67>L011cW00<H
aQcW6<H00acW00@U:B488@PLi`@HaP035:DHaQS600LHaP8DY@036<HLiaS6008DY@8HaPDDY@056<HL
iacW7>LDY@046<H00acW6<HDY@025:D00aS65:DDY@025:D46<H01AcW6<HHaQS65:D00QS60QBU0aS6
00<LiaS67>L00QS600DDYAS66<HHaQBU00DHaP8Li`<HaP047>LHaQBU5:D26<H00aBU48@DY@056<H0
1Q245:DHaQS67>LHaP8DY@036<HDYABU00<DY@036<HDYABU008@Q0TDY@8HaP055:D@Q1BU5:DHaP02
5:D01AS65:DDYABU48@00QBU0aS60a2411BU11S60QBU00<HaQBU5:D00a2400HHaQBU5:D@Q1BU48@4
5:D748@25:D348@011BU48@@Q0aS0Q240QBU2A2400D<Ha2448@@Q1BU008@Q0035:D@Q124008@Q005
5:D@Q12448@DY@0648@010aS48@@Q0aS0a240aBU0Q2400<<Ha2448@01Q240`aS0a240`aS0Q2400<D
YA245:D011BU11240`aS0a240PaS0Q2400D<Ha2448@@Q1BU00<<H`0348@DYA2400<@Q04<H`0000<4
8@0012402@@Q00@YBTYB<H`Li`8YBP8U:@8]J`<U:@8YBP068@PU:Be[<H`]JbDY12U:00<]Jc6<:DX0
0RDY00<YBRe[:DX00RU:00DU:B488@PQ22DY00<YBPD]J`059BTYBRDY8@PU:@04:DX28@P27>L01248
9BTYBRDY0bU:00<U:B487>L01b480acW00<Q22DY8@P00R480RDY00DQ22DY:DXU:B48008Li`8U:@<Y
BP<U:@<Q20@YBP098@PU:B488@PU:B489BT]Jc6<008]J`0=:DX]JcF]<H`YBRDY8@PU:Be[:DXQ22DY
:DX00Re[0RU:1BDY0R4800<Lib489BT00RU:00<U:B489BT00RDY0R480RDY1bU:12DY00<Q22DY9BT0
12DY12481bDY00HQ22DY8@PYBRDY7>L2:DX01Be[:DXQ22DY:DX012DY0acW00<U:B488@P00b4800DL
ib489BTU:B48008Li`<Q20047>LQ22488@P2:DX29BT01B487>LLib489BT00QcW00HHaR488@PLibDY
8@P2:DX01RDY8@PLiaS67>LQ208U:@038@PLib4800<Q20047>LU:BDY9BT27>L01AS67>LQ22489BT0
0R4800LU:AcW7>LLiaS68@PHaP027>L38@P011S67>LLib480QcW0QS621cW0QS600DLiaS65:DHaQcW
008Q20037>LHaQS600HHaP047>LQ22488@P27>L00aS67>LLi`028@P00acW8@PHaP026<H00aBU6<HD
Y@026<H00acW6<HHaP027>L02QS65:DDYAS67>LHaQBU6<HLiaS60QBU00<HaQBU5:D00QBU11cW00DH
aQ245:DHaQcW00<DY@PHaP045:DHaQS67>L46<H45:D:6<H00aBU6<HHaP036<H00aBU6<HLi`027>L2
6<H37>L26<H25:D00aS648@DY@026<H00a245:DDY@027>L56<H35:D00a245:DDY@026<H00aBU6<HH
aP025:D0112436<@Q1BU0QS600<DYAS66<H00Q2400@DYAS65:DDY@8@Q08HaP035:DHaQBU00LDY@04
48@DYAS65:D26<H011BU6<HHaQS60QBU00<@Q1BU5:D00a240QBU00@@Q1BU48@@Q08DY@046<HDYABU
5:D26<H00aBU48@@Q00448@25:D248@55:D848@010aS48@<Ha2411BU11240QBU0QS600<DYA2448@0
11240PaS00@@Q1BU5:DDY@8@Q08<H`D@Q0085:D@Q12448@<HaBU48@<H`8@Q00936<@Q12436<@Q1BU
48@DYA2400<DY@<@Q0<<H`03248<H`aS00D@Q00336<@Q124008@Q0<<H`@@Q00336<@Q124004@Q000
0P@Q00@000@Q124000D48@0@248YBU:D<H`HaRU:;F/YBRDY:DX]JbDY8@PU:BU:;F/2:DX00be[<H`Y
BP029BT01RU:;F/]Jc6<;F/YBP8U:@04;F/YBRDY:DX2;F/012DY8@PQ22DY0Re[00<YBR48:DX00S6<
00<YBRDY9BT00RU:00<U:B489BT00bU:00<U:B489BT00R480RDY12U:0RDY0b48010U:B488@PQ21cW
6<HLib489BTQ21cW8@PU:BU:8@PU:@8YBP039BTQ2248008Q20079BT]JbU::DXU:AcW8@P00RDY0RU:
00<U:BU:9BT00RDY00@Q22DY9BTU:@8]J`0<<H`YBRe[;F/aS3F];F/U:B48:DX]JbU:0RDY0bU:00@U
:BU::DXYBP8U:@8Q208U:@8Q20039BTYBRU:008U:@037>LQ22DY008U:@058@PU:BDY:DX]J`03:DX0
0bDY:DXU:@028@P00bU:;F/U:@028@P29BT032487>LHaR489BTYBRDY8@PU:BU:9BTQ208U:@078@PU
:BDY;F/YBRDY8@P00RU:00<U:B489BT00R481AcW00<Q22DY9BT00QcW00<U:BU:8@P00QcW0R4800TU
:AcW7>LQ22DY;F/YBR489BT00acW00<Q22DY8@P01QcW00<U:BU::DX00b480QcW0RDY0b4800DU:B48
6<HLib48008YBP8U:@058@PLiacW8@PLi`039BT00b487>LQ20027>L26<H00acW8@PQ20027>L26<H4
8@P011cW6<HHaQS60QcW00@HaQcW7>LLi`8HaP035:DHaQBU008HaP8Q20057>LHaQBU6<HLi`026<H0
0aBU6<HLi`037>L00b487>LLi`026<H011cW8@PQ21cW0QS60QBU00<HaQBU7>L00QcW0aS600DLiaS6
6<HHaQBU00LHaP@DY@<HaP8Li`DHaP8DY@0448@HaQS67>L26<H25:D011S67>LHaQBU0QS600PDYAS6
6<HLiaS65:D@Q1BU1aS60aBU11S600<DYAS66<H011S60acW0aS60QcW00HHaQ246<HHaQBU6<H35:D0
0aS67>LHaP027>L26<H55:D26<H45:D01QS648@@Q1246<HDY@8HaP057>LHaQBU5:D@Q0025:D011S6
5:DDYAS611BU00`HaQBU5:DDYA245:D@Q1BU6<HDYA245:D26<H25:D011245:DDYA240QS60QBU00<@
Q1BU48@00a2400<DYAS66<H00aBU00<@Q1BU5:D00QS60Q240QBU1A240aS600<@Q1BU5:D00QBU2A24
11BU11240QBU00<@Q1BU5:D00QS60Q240PaS2A2411BU00@@Q0aS48@@Q08DY@8@Q00436<@Q1BU48@3
36<01Q2436<<Ha245:DHaPHDY@<@Q0@<H`0348@DYA2400@@Q08<H`0648@<H`aS36<@Q0aS0Q240QBU
0A240@Q20000100012448@001P@Q00P000Q2:DY>LcF]7>LU:BU:0be[0RU:00T]JbDY9BTU:Be[<H`Y
BRDY:DX00RDY00<Q22DY:DX00bDY00LYBRDY8@PU:BU:;F/YBP038@P00bDY:DX]J`02;F/01RU:;F/]
Jbe[9BTQ208U:@03:DXU:BU:00<YBP8U:@8Li`038@PU:BDY00DU:@@Q20037>LQ22DY00<Q20<YBP@Q
20039BTQ22DY008Q20059BTYBRU:9BTQ20069BT28@P00bU:9BT]J`02:DX01bDY8@PLib487>LU:C6<
008e[@08;F/U:BU:<H`e[C6<;F/U:@8YBP039BTYBRDY00<YBP<U:@038@PU:BDY008YBP8U:@8Q20<Y
BPHU:@048@PU:BDY:DX29BT01bU:9BTU:BU:9BTYBRe[008YBP@U:@8Q20087>LQ22DY8@PU:B487>LQ
20<U:@058@PLib488@PU:@02:DX01RDY8@PYBRe[<H`YBP@Q20059BTQ22487>LQ20027>L00b489BTQ
20048@P00bDY8@PLi`038@P01RDY8@PU:BDY8@PU:@8Li`068@PLib488@PLib480QcW0b480RDY0b48
00<Lib487>L012480QcW0R4800dU:B488@PU:Be[:DXQ21cW6<HQ21cW8@PLi`028@P011S67>LHaQcW
0QS600@Q22DY9BTQ208HaP<Q20037>LHaQcW008HaP037>LHaR4800@Li`096<HLiacW7>LHaQBU6<HL
ibDY008Li`056<HLiaS65:DHaP027>L26<H27>L26<H37>L011S67>LQ21cW0aS60QcW0QS600DDYAS6
7>LLiaS6008DY@036<HDYAS6008HaP8Li`8HaP035:DHaQS600HHaP045:DHaQS66<H27>L02ABU6<HH
aQcW6<HLiaS67>LDY@026<H25:D56<H00aBU6<HDY@026<H01ABU6<HHaQS65:D021S60QBU0QS60acW
00@Q21cW6<HDY@<HaP8DY@LHaP055:DHaQS66<HDY@066<H01ABU6<HDYABU48@01ABU0a240aBU00<H
aQBU5:D00aS61QBU00@HaQBU6<H@Q0DDY@0748@DYABU6<HDYA245:D00aS61QBU0aS600<DYA2448@0
0QS60aBU00<HaQBU5:D00QBU00@HaQcW6<HLi`@DY@8@Q0045:D@Q1BU48@75:D01A2436<@Q1245:D0
0Q2400@<Ha2448@@Q08DY@@@Q0055:D@Q1245:DHaP025:D348@25:D548@00`aS48@@Q00648@55:D3
48@25:D248@00aBU48@<H`0236<25:D011S65:DDYABU0QS600<DYA2448@00`aS00<@Q1BU48@01@aS
0a240PaS0Q2400<DYA2448@011240PaS000512401@0012448@Q200000P@Q00PYBUJe>LhLibDY;F/Y
BS6<0Re[00<YBRe[9BT00RDY00<YBRe[;F/00RDY00<Q22DY:DX00RDY12U:00LU:B488@PU:Be[:DXU
:@027>L00bDY;F/]J`02:DX2;F/0136<:DXYBRDY12U:00TQ22DY9BT]JbU:9BTLib489BT00b4800@Y
BRDY9BTU:@@Q20<U:@8Li`048@PU:BU:9BT38@P00bDY8@PQ20029BT01B489BTYBRU:9BT00R480RDY
00@YBR489BTQ208U:@05:DX]Jbe[9BTYBP048@P00bDY;F/aS002<H`00bU:9BT]J`02<H`012e[9BTU
:BDY1RU:12DY00<YBRDY9BT00RDY00@Q22DY9BTU:@<YBP069BTLib488@PLib4812DY00PYBRe[9BTQ
22DY;F/aS2U:1bDY0b4800<Lib488@P00RDY0R4800PU:B488@PQ22DY8@PYBRDY0RU:00PQ22DY:DXY
BRe[8@PU:B480RDY00HQ21cW7>LLib487>L48@P47>L00b487>LQ20048@P39BT00b487>LLi`037>L2
8@P02QcW6<HHaQcW8@PU:B489BTQ21cW1R4800TU:B487>LQ22DY8@PLib489BT00RU:00@U:B488@PL
i`8Q20037>LQ2248008Li`<HaP075:DLib48:DXU:AcW6<H00acW00<Q21cW7>L011S611cW00@HaQcW
7>LDY@8HaP037>LHaQBU00<Li`8DY@056<HLiaS66<HDY@077>L011S67>LHaQcW0R480QcW00DHaQBU
6<HHaQcW00@HaP8Li`8DY@036<HLiacW008HaP8Li`048@PHaQ246<H25:D00aS65:DHaP026<H01AcW
6<HHaQS67>L00QS60aBU0QS600<LiaS66<H00aBU00DLiaS65:DHaQcW00@HaP8DY@<HaP035:DHaQS6
008Li`036<HDYABU00@HaP035:DHaQS600LLi`HHaP8DY@087>LDYABU5:D@Q1S67>LHaP8DY@8HaP03
7>LHaQS600<DY@056<HDYABU5:DHaP0248@01PaS48@DYA246<HDY@DHaP8DY@8@Q0055:DHaQBU5:D@
Q0035:D011S65:DDYA240aBU00DHaQ245:DHaQcW008DY@066<HLiaBU5:D@Q1BU0QS600LDYA245:DD
YAS65:D@Q0065:D01AS65:DDYABU6<H01ABU0a240QS600<DYA2448@00aBU00@@Q0aS36<@Q08DY@<<
H`<@Q0035:D@Q1BU00D@Q0055:DHaQBU5:D@Q0025:D248@01ABU48@@Q12436<021240PaS00<@Q1BU
6<H011BU00@@Q1BU48@DY@D@Q08DY@056<HDYABU5:DHaP025:D348@00`aS48@DY@0248@336<548@0
10Q248@DYA240`aS1A240@Q200000`001240000812401`Q2:DY>LcF]7>LYBRe[008YBP8]J`8YBP06
9BTYBS6<<H`]JbDY0R4800@U:AcW8@PQ208YBP8U:@8YBP039BTYBRU:008U:@8Li`8U:@<YBP<]J`8Y
BP069BTYBRU::DXU:B480RDY00<YBRDY9BT00b4800@U:BU::DXYBP<Q20047>LU:B489BT28@P39BT0
12489BTYBRe[0b4800@YBRDY:DXU:@8Q20DYBP049BTQ22488@P2:DX29BT01RU:;F/aS36<;F/U:@<Q
20049BTQ22DY:DX2<H`00be[:DX]J`03;F/012DY8@PU:Be[0RU:0S6<00<YBRDY8@P012DY0RU:00<U
:B489BT00RU:2bDY00DYBRDY9BTU:BU:008U:@8YBP03;F/YBRU:00@YBP<Q20039BTYBRDY008Q208L
i`8Q20039BTYBRDY00@U:@8]J`8YBP<U:@038@PU:B48008U:@<Q20047>LQ21cW8@P27>L01B487>LU
:B489BT0124800LLib488@PQ22DY:DXQ20037>L01R487>LLiacW8@PLi`8HaP037>LQ21cW008Q20<L
i`038@PU:B48008Q20069BTQ21cW7>LQ22U:0R4800<]JbU:9BT00QcW00LQ22DY8@PU:B487>LHaP03
7>L01R487>LLiacW8@PU:@<Li`8Q20<HaPLLi`@HaP077>LQ21S66<HDYAS69BT00R480aS600DLiaS6
6<HLib48008Li`<HaP057>LQ21cW6<HLi`029BT011cW6<HLiacW11S600<DYAS66<H00QcW00<HaQcW
7>L011S600<LiaS66<H00QBU00@HaQBU6<HHaP<DY@<HaP8Li`096<HDYAS65:DHaQcW6<HLiaBU00PH
aP077>LHaQBU5:DHaQBU6<H00QBU00@HaQBU7>LLi`<HaP035:DHaQS600@HaP045:DHaQBU6<H27>L0
0b487>LHaP066<H01ABU6<HHaQS65:D00QS611BU0aS600DDYAS66<HHaQBU00<HaP035:D@Q12400<D
Y@0348@DYABU00<DY@037>LHaQS6008@Q08DY@<HaPLDY@<HaP035:DHaQBU00<DY@8HaP035:DHaQS6
008HaP8DY@8HaP8DY@036<HLiaS6008HaP8Li`8DY@0348@DYABU00<DY@8HaP8DY@036<HDYA24008@
Q08DY@0348@DYABU00<DY@036<HDYA2400X@Q0<DY@8@Q00436<@Q1245:D26<H01ABU48@@Q0aS48@0
11BU0Q240PaS0a240QBU112400<DYA245:D01aBU212421BU0Q2400<<Ha2448@00a240PaS0a240`aS
00D@Q0aS48@<Ha2400<<H`<@Q08<H`000`@Q00D000@Q124000Q200<48@06248]Je:D=JdHaRDY0be[
1RU:00D]Jc6<;F/U:AcW008U:@8Q20099BTYBR488@PU:Be[:DXU:B48008YBP039BTQ2248008U:@8]
J`03:DX]Jc6<008YBP8Q20049BT]JbU::DX29BT3:DX38@P29BT012489BTYBRDY2B4800@U:B487>LU
:@<YBP8Q208U:@05:DXU:BDY:DXU:@03:DX:9BT0136<>Lhe[C6<124800@U:B489BTYBP@]J`03:DX]
Jbe[00<Q20049BTYBRU::DX3;F/01BDY8@PU:BU:9BT00bU:00DU:B489BTU:BU:008U:@8Q20037>LU
:BDY008U:@8Q20<U:@03:DXU:BDY008YBP03;F/YBRe[00DU:@<Q208U:@8Q208Li`<Q20069BTQ22DY
9BTQ22U:0Re[0bU:0RDY00<Q22DY8@P00b480RDY00<Q21cW7>L00b480QcW0b4800DLib488@PQ21cW
008Q208Li`8Q20039BTQ21cW008Q20<Li`038@PLiacW008HaP067>LQ22488@PLiaS60QcW0RDY00<Q
21cW8@P00b4800<U:B488@P00RDY00<YBRDY8@P00b4800<U:B488@P00QcW0QS600<LiaS67>L00QcW
00<Q21cW7>L00QcW0R4800@LiaBU6<HHaP@Li`036<HLib48008Li`8HaP058@PLiaBU5:DHaP027>L0
11S67>LLiacW0aS60acW0aS60acW0QS60R4800@U:AcW7>LLi`<HaP067>LHaQS66<HDYAcW0QS621cW
00@HaQBU5:DDY@<HaP8DY@046<HDYAS67>L26<H25:D36<H00aBU6<HHaP046<H27>L011S65:DHaQcW
1AS600<DYAS66<H00QS600<DYAS67>L00QBU00DHaR486<HHaQBU00<HaP065:D@Q1S66<HLib480QcW
0QS600<DYAS66<H02AS600<DYAS65:D011S600@DYAS66<HLi`<HaP<DY@8@Q08DY@8@Q08DY@8Li`@D
Y@056<HDYA2448@DY@026<H021BU48@@Q1BU7>LHaQBU48@25:D00aS65:DDY@025:D00aS65:DDY@05
6<H35:D:6<H01ABU48@DYA245:D00QS600<DYA245:D011BU0a2400@DYA2448@DY@8HaP035:D@Q1BU
008@Q08<H`0648@<Ha245:D@Q1BU1Q2400<<Ha245:D01QBU0Q2400<DYA2448@00Q2400@DYA2448@@
Q08DY@<@Q00636<@Q12448@DYA240aBU00@HaQBU5:DDY@8@Q00436<@Q12448@55:D00a245:DDY@02
48@00`aS48@@Q00348@336<00a2436<<H`0248@436<348@236<448@12480000500048@@Q12400005
12402000248YBTic<H`HaRDY;F/3:DX4;F/00c6<;F/YBP02:DX29BT00b489BTQ20027>L00bDY;F/Y
BP028@P2:DX012DY8@PQ22DY0bU:00@U:BU:;F/YBPDU:@05:DXU:BU::DXU:@02:DX012DY8@PQ22DY
0bU:00HU:B488@PQ22DY7>L38@P01BDY8@PQ22489BT00bU:00<U:B489BT00RU:0RDY00HQ22U::DXY
BR48:DX3;F/28@P02BDY;F/]JbU:9BT]JcF]>LhaS0029BT00b489BTYBP039BT012U:<H`]Jbe[0RU:
00<aS2e[8@P00RDY00DYBRDY:DXYBRe[008YBP058@PYBRDY8@P]J`02<H`00be[8@PQ2004:DX012DY
8@PU:BDY1RU:00DU:B489BTYBRDY008YBP<]J`05:DXU:BDY8@PU:@02:DX012DY8@PQ224812DY0QcW
0R4800@U:BU:9BTU:@<YBP<]J`03:DXU:BDY00DQ208U:@038@PLib48008U:@8Li`8Q208Li`8Q2003
7>LQ21cW008Q20XLi`8Q20037>LHaQcW00<Li`036<HLiaS600<Li`036<HQ2248008Q20039BTQ22DY
008Q20067>LQ22489BTYBRDY0R4800@Lib488@PLi`8Q200:7>LQ21cW8@PLiaS67>LQ22DY8@P26<H0
1AcW9BTLiaS67>L00QS600<Lib488@P00aS600<Q21cW6<H00QcW00<Q21cW6<H00QBU00DHaR488@PL
iaS600<Li`086<HLiaS67>LHaQcW6<HLi`<HaP<Li`036<HLib4800<HaP8Li`046<HDYAS67>L36<H2
7>L46<H012487>LLiaBU0aS60QBU0aS600<DYAS66<H01QS600HDYAS66<HHaQcW6<H45:D26<H00acW
6<HHaP026<H25:D86<H47>L01aS65:DDYAS67>LHaQ24008DY@037>LHaQcW00<Li`076<HDYABU5:DH
aQcW6<H00QBU1AS600<LiaS66<H00QS60acW0QS60acW00@HaQBU48@DY@<@Q08DY@0348@DYAS6008D
Y@0548@DYAS65:DHaP0348@35:D00a245:DDY@055:D00a246<HDY@025:D01A245:DHaQS67>L00QS6
21BU0QcW0QS600<DYAS66<H00QBU00<@Q1BU6<H00QS600<DYA245:D00aBU00@@Q0aS48@@Q0<DY@05
48@DYAS67>LDY@0248@00`aS48@@Q00248@00`aS48@@Q0035:D01Q2436<@Q0aS48@<H`<@Q08DY@<@
Q08DY@X@Q00336<@Q124008DY@8@Q08DY@0648@DYAS65:DHaQBU0Q240QBU00<@Q0aS36<00aBU0a24
00@DYA2448@DY@D@Q00336<@Q1BU008@Q08<H`@@Q00336<DYABU008@Q08<H`<DY@8<H`48@P000P@Q
00H000@Q12448@00248412401Re[DY@e[AcW:DX]J`8U:@09;F/aS2e[:DX]Jc6<=JdaS2DY00<Q2003
9BTQ2248008Q20<U:@068@PU:BU:;F/U:B4812DY00@Q22U:;F/]J`8YBP069BTYBRU:9BTQ22DY1RU:
00@U:B488@PU:@8YBP049BTQ22DY9BT28@P00acW8@PQ20038@P27>L00bDY:DXYBP028@P00bDY:DXY
BP049BT2:DX012DY:DXYBS6<0Re[0bDY00T]JbDY:DXaS3F]>Lh]Jb489BT00R480RDY00@YBRDY:DXY
BP8]J`8YBP04;F/U:BDY8@P3:DX012DY:DX]JbU:0RDY00TYBRDY8@PYBSF]<H`]JacW8@P00RU:00<]
JbDY9BT00RDY0bU:00@]JbU::DXU:@8YBP8Q20039BTYBRe[00TYBP049BTQ22488@P29BT01BU:8@PQ
22489BT00R480RDY12U:0Re[1BU:00@Q21cW7>LQ208U:@058@PLib488@PU:@048@P47>L29BT01248
7>LLiacW0R480acW00<Q22DY8@P00acW0R4800XLiaS67>LLib487>LDYAS67>LU:@<Li`049BTQ2248
8@P39BT28@P01AcW8@PU:BDY8@P00acW0b4800<U:B488@P01AcW00HQ22DY9BTLiaS67>L28@P00acW
6<HHaP025:D021cW8@PQ21cW5:DLib487>L36<H28@P46<H00b487>LLi`046<H57>L01AS67>LHaQcW
6<H00QcW00LHaQcW7>LQ21cW8@PLi`036<H27>L011S65:DHaQS60QcW11S600<Q21cW7>L00QS600<D
YAS65:D00QS600<LiaS65:D00QS60QcW0aS600@DYAS66<HDY@<HaP035:DHaQS600@DY@8Li`<HaP@D
Y@@HaP037>LHaQS600DHaP035:DHaQS600<DY@<HaP<Li`046<HDYA245:D27>L011S65:D@Q1BU0QcW
11S600@LiaS65:DHaP<Li`<HaP037>LHaQBU00<DY@<@Q0<DY@0548@DYABU48@HaP025:D011S65:DD
Y@aS0QBU00<HaQBU5:D011BU11S600<DYAS66<H011BU0QS600<LiaBU5:D00QBU00@HaQBU5:DDY@<H
aP037>LHaQcW008HaP<DY@066<HDYAS65:DHaQBU11240QBU00H@Q1BU5:DDYAS65:D26<H55:D248@0
0`aS48@@Q00248@25:D00aS648@@Q00236<00a245:D@Q00348@25:D248@25:D248@25:D248@00`aS
48@@Q00448@010aS48@@Q1BU0Q2411BU11S60a2400<<Ha2448@00Q2400HDYA245:D@Q1BU48@236<0
1A245:DDYA245:D01@aS0Q2400<<Ha2436<00`aS1Q2410aS000312400`0012448@05124020Q29BU6
<Be[6<HU:Be[:DX2;F/00c6<;F/]J`02<H`012e[:DXQ22DY124800<U:BU::DX00RU:0bDY00<YBRDY
9BT00bU:00<Q22DY9BT012U:0bDY00<YBRe[9BT00R4800HU:BU::DXYBRDY:DX49BT2;F/012U:9BTL
iacW0b480RDY0QcW00<Q22DY:DX012DY00@Q22DY:DXYBP8U:@8Q20059BTYBRe[;F/YBP029BT2;F/0
2BU:9BTU:C6<>Lhe[BU:9BTQ2002:DX00acW9BT]J`02<H`2:DX00c6<:DXYBP03:DX29BT5:DX012e[
:DXU:B480RDY00DYBS6<=Jd]JbU:008U:@0<:DX]JbU:9BTQ21cW9BT]JbU:<H`]JbU:0RDY00<YBRe[
:DX00RDY00DYBRe[;F/]JbU:008U:@8YBP8U:@038@PU:BU:008U:@8Q208U:@048@PLib489BT2;F/3
:DX29BT012e[<H`]JbDY1R4800HU:B488@PLib487>L48@P27>L38@P00acW8@PU:@028@P01AcW6<HL
iacW8@P00QcW00<HaQcW8@P00b4800@Lib486<HHaP8Li`048@PLiacW9BT28@P57>L38@P27>L00aS6
8@PU:@029BT78@P37>L28@P27>L01R487>LLib486<HLi`<Q20057>LHaQS67>LHaP027>L46<H27>L0
11S67>LQ22481AcW00HHaQcW8@PQ21cW6<H27>L011S67>LLiacW0aS600<Lib487>L00QcW00@HaQcW
7>LLi`8HaP<Li`036<HDYAS600HHaPTLi`056<HDYAS66<HLi`026<H011BU6<HHaQBU1QS600@LiaS6
6<HHaP8DY@@HaP037>LHaQS6008DY@HHaP<Li`036<HLiacW008HaP055:DHaQS66<HDY@046<H00aBU
6<HDY@0;6<H011BU6<HHaQBU0QS60acW0aS600HLiaS65:DHaQBU7>L46<H00aBU48@DY@025:D248@0
0aBU6<HHaP025:D00a245:DDY@035:D01AS65:DDYABU48@01QBU00<HaQBU5:D01ABU00@@Q1S66<HH
aPHDY@<HaP035:DHaQBU008HaP035:DHaQBU008HaP8DY@046<HDYAS66<H448@00aS65:D@Q00448@0
0aBU6<HLi`026<H35:D248@00`aS48@DY@0248@35:D248@02aBU48@<H`aS48@DYA245:D@Q0aS48@0
0QBU2A2400<<Ha2448@01A2400TDYA2448@@Q1BU6<HDYAS648@00QBU00<HaQBU48@00PaS00X@Q1BU
5:D@Q0aS48@DYA2436<@Q0<DY@0348@<Ha24008@Q08<H`0548@DYA2436<@Q0025:D010aS48@DYABU
1A2400<<Ha2436<00@aS00000`@Q00048@0212400`0012448@0412401248@Q0]JacW0bU:00<U:BU:
;F/00RU:00H]JcF];F/YBQcW8@P39BT00b489BTU:@02:DX29BT01R48:DXYBRU:9BTQ20DU:@<YBP<U
:@<YBP038@PU:BDY008YBP039BTQ2248008U:@038@PU:BDY008YBP<U:@<Q20049BTYBRU:8@P27>L0
12DY:DXU:B4812DY00<YBRDY9BT00bDY00TYBRDY:DX]JbU:9BTQ22U:;F/00bU:00`]Jc6<<H`]JbU:
9BTQ22DY8@PU:Be[<H`3:DX2;F/2:DX00bDY:DXYBP029BT00bU:9BTU:@03:DX28@P39BT012e[<H`]
Jbe[0RDY0bU:00@U:B488@PU:@8YBP8]J`06:DXU:BDY:DX]JbU:0RDY00L]Jc6<<H`YBRDY8@PU:@02
:DX01B489BTQ22DY8@P00RDY00DYBRDY8@PU:B4800DU:@<YBP8Q200;:DXaS36<9BTLib489BTLib48
9BTYBP058@P01acW8@PQ21cW8@PLib48008U:@038@PLiacW00XLi`058@PU:B488@PLi`056<H47>L2
8@P01QcW6<HHaR487>LHaP8Li`8Q208Li`8Q20059BTQ21cW7>LU:@038@P00acW8@PQ20028@P57>L0
0b487>LLi`027>L01bDY8@PLiaBU6<HLib48008Li`8HaP047>LHaQcW7>L26<H28@P021cW6<HLiacW
5:DHaR489BT28@P011BU6<HDYAS60QcW00@HaQBU6<HHaP8Q20037>LHaQcW00<HaP047>LHaQcW5:D5
6<H27>L00aS65:DHaP037>L36<H012486<HHaQcW0QS600@DYAS66<HLi`<HaP8Li`046<HDYAS65:D7
6<H01QBU6<HHaQBU6<HDY@<HaP<DY@8HaP035:DLiaS6008Li`8HaP065:DHaQcW7>LHaQBU0QS600<D
YAS65:D00QS60QcW0QS60QBU21S600@DYAS66<HHaP8Li`@HaP<Li`065:D@Q1S65:DHaQ243ABU00<H
aQBU48@00QBU0Q2411BU00@HaQBU5:D@Q08DY@<@Q0046<HDYABU48@25:D01aS65:DHaQS65:DHaQBU
008HaPHDY@8HaP035:DHaQS6008HaP045:D@Q1245:D26<H248@00aBU6<HHaP0348@010aS48@<Ha24
0QS600@LiaBU5:DHaP8DY@<@Q08<H`0348@HaQBU008@Q00336<@Q12400@<H`0348@DYA2400<@Q003
5:D@Q1BU00H@Q08<H`@@Q00336<@Q124008DY@0436<8@Q2448@26<H011245:DDYABU0Q2400@DYA24
36<<H`<@Q08<H`0348@<Ha2400<@Q0@<H`8@Q0045:D@Q12448@336<00a2436<<H`0248@01AS648@@
Q1245:D00Q240@aS0A240@Q200000`001240000712401P00248Q24YB=JdQ208YBP059BTYBRU:;F/a
S002;F/00bU:9BTQ20049BT28@P01RDY;F/aS2e[:DXU:@@YBP039BTYBRDY00@U:@03:DXU:BDY00DU
:@8YBP048@PU:BDY:DX28@P012U:;F/YBRU:0RDY0be[00LYBR487>LU:BU:;F/U:@058@P00bDY:DXU
:@028@P2:DX29BT01B489BTU:B48:DX00Re[00<YBRDY;F/012U:00D]Jc6<<H`aS2e[008YBP<U:@03
:DX]Jc6<00DaS00:;F/YBR488@PU:BU:;F/YBR489BT5:DX28@P012U:;F/aS2e[0b4800@U:BU::DXY
BP8U:@03;F/aS36<008YBP04<H`]JbU:9BT2:DX39BT00bU:;F/]J`02:DX00bDY:DXU:@029BT01248
9BTQ22DY0RU:00HQ21cW7>LQ22U:8@P3:DX29BT012U:;F/]JbDY0RU:00<]JbDY8@P00R4800<U:B48
8@P00QcW0R480RDY00@Q22DY9BTU:@@Q208Li`8U:@8Li`056<HLib488@PLi`026<H00acW8@PU:@02
8@P26<H37>L012487>LU:BDY0b4800HHaQcW7>LQ21cW8@P27>L01AS67>LLiacW9BT012480RDY00DQ
21S66<HLib4800<Li`036<HLiacW008Q20077>LHaR489BTYBR487>L00aS61AcW00@HaQcW7>LLi`8H
aP047>LHaR488@P27>L26<H011cW8@PQ224811cW00<HaQcW7>L00QcW0QS600<Lib488@P012480acW
0aS600<LiaS67>L00QS60acW00HHaQcW7>LHaQcW5:D26<H47>L36<H00acW5:DHaP027>L012487>LH
aQBU0QS60acW00<HaQcW6<H01AS600@DYAS67>LLi`<HaP8DY@DHaP067>LHaQBU5:DHaQcW11S60aBU
1aS600<LiaS66<H00QS600@LiaS66<HLi`8HaP8DY@067>LQ22488@PLiaBU0QS600HLiaS65:DHaQBU
6<H25:D011245:DDYAS60Q2400DDYAS66<HLiaBU008@Q0<DY@8@Q0<DY@046<HDYABU6<H25:D01`aS
48@DYABU48@DYA2400@DY@036<HDYAS6008DY@056<HDYABU48@DY@036<H35:D00a246<HHaP036<H3
5:D011S65:DHaQBU0a2411BU00<@Q0aS36<00Q240QS60QBU0Q2400<DYA2448@00Q2400<<Ha2448@0
0Q2400@<Ha2448@DY@H@Q08DY@0548@DYABU48@DY@0>48@011BU48@@Q0aS0a240QBU0aS600HDYA24
48@@Q1BU48@236<011245:D@Q0aS11240`aS00D@Q0aS48@@Q0aS008@Q0035:D@Q0aS00<@Q00336<@
Q0aS008@Q0@DY@@@Q08<H`0010@Q00@000@Q0008@P@48@079BU6<C6<6<HU:Be[:DX00Re[00HYBS6<
<H`]JbU:9BT2:DX00bDY8@PQ20028@P012DY;F/]Jbe[0RU:00@U:BU::DXU:@8Q20049BT]JbDY9BT3
:DX01BDY8@PU:BDY8@P00RU:0RDY00<Q22DY9BT00b480Re[00DYBRDY9BTYBS6<008YBP8Q20<YBP06
9BTQ22488@PU:B480bDY0R4800DU:BU:8@PLib4800@U:@03:DX]JbU:008YBP04;F/U:BU::DX4<H`0
0be[:DXYBP028@P29BT3<H`00cF];F/aS003;F/29BT012489BTYBRU:0bDY00@YBRe[:DXYBP8Q2004
;F/aS36<;F/38@P29BT2:DX28@P00bU:<H`aS002;F/00c6<;F/YBP02:DX012e[:DXU:BU:0Re[0RU:
0bDY00@YBRDY9BTQ208U:@03:DXU:BDY00@Q20059BTYBRU:;F/YBP029BT00bU:;F/YBP02:DX00be[
:DXU:@058@P01BDY8@PQ21cW8@P00bDY00DQ22DY9BTU:B48008Li`038@PU:B48008Li`8HaPLLi`04
8@PU:B487>L26<H47>L48@P012DY8@PQ21cW0QS60QcW00@HaQcW7>LLi`DQ20067>LQ22DY:DXQ21cW
0QS600HLib488@PQ21cW6<H27>L012486<HHaQcW0RDY00<Q21S66<H00QBU00DLib488@PLiaS600<L
i`076<HDYAS66<HLib489BT00QcW0QS600HLib488@PLiaS65:D37>L00aS67>LHaP026<H011cW8@PH
aQcW0RDY00DQ21S67>LQ21cW008HaP8Li`046<HDYAS66<H57>L00aS67>LHaP036<H00aBU7>LLi`02
7>L36<H01QcW6<HHaQcW6<HLi`<HaP8Li`056<HLiaS65:DHaP027>L00aS65:DDY@066<H25:D00aS6
5:DHaP047>L66<H011BU6<HLiacW0QBU0QS60QBU00<HaQcW6<H00aS60acW11S600<@Q1BU5:D00QcW
00<Q21cW6<H01AS60QBU00@HaQBU5:D@Q0<DY@0348@DYA24008DY@8HaP<DY@0348@DYA24008DY@<H
aP035:D@Q124008DY@@@Q00:5:DHaQBU6<HDYAS65:DHaQBU6<H25:D26<H45:D36<H25:D00a245:DH
aP026<H01AcW5:DDYABU6<H00QcW00@HaQ2436<@Q08DY@0448@<HaBU5:D248@010aS5:DDYABU0Q24
00@DYAS65:D@Q08<H`0448@<Ha2448@35:D448@01ABU48@<Ha245:D01A2400<DYA2436<00Q2400<D
YA2448@00`aS0Q2400@DYA2436<@Q0<DY@0648@<HaBU5:DHaQcW0QS600HDYA245:D@Q0aS48@35:D2
36<248@011BU48@@Q0aS212400<<Ha245:D00QBU00<@Q0aS48@00PaS0Q240QBU1Q240@aS0@Q20000
0`0012448@0812402`Q2:DY:DRe[8@P]JcF]:DXU:BU:<H`00Re[0RDY00<Q22DY:DX00RU:00@U:BU:
;F/aS08YBP04;F/aS2e[:DX:9BT00b489BTYBP028@P01RDY:DXYBRU:8@PLi`8Q20<U:@03;F/aS2U:
008YBP03;F/aS2e[008U:@@YBP048@PLib487>L68@P29BT48@P00bDY:DXYBP04:DX29BT2;F/2:DX0
1cF]?Nle[Be[:DX]JbU:00<U:@03:DXaS36<00<]J`03<H`e[C6<008]J`8U:@<YBP8U:@088@PYBRU:
:DXU:B489BTYBP8]J`<U:@8]J`03:DXU:B48008U:@0>:DX]Jc6<=JdaS2e[:DX]JcF]<H`YBR489BT]
J`8YBP039BTYBRU:00<YBP038@PU:B48008Q20<YBP069BTLiacW8@PU:Be[0RU:00@U:BU:9BTYBP8U
:@<YBP039BTQ224800@U:@<Q20<U:@0;8@PLib489BTQ22U:9BTQ21cW6<HLi`028@P00acW6<HLi`02
7>L28@P01AcW6<HLiacW9BT00b480QcW00<Q21cW7>L00b481QcW00@Q21cW6<HLi`8HaP8Q20039BTQ
21S6008Li`039BTQ2248008Li`038@PLib4800LLi`<HaP057>LYBRU:9BTQ20025:D28@P012DY7>LH
aQcW0b4800DLiaS67>LHaR4800DLi`036<HLiacW00LLi`038@PLiacW008HaP<Li`8U:@8Q20<Li`08
8@PHaQS66<HDYAcW6<HLi`8HaP035:DHaQS6008Li`036<HDYAS600LHaPDLi`056<HLiaS67>LHaP02
7>L26<H57>L36<H011BU6<HHaQcW0QS600<DYAS66<H00aS600@LiaS67>LLi`8HaP8DY@8HaP037>LH
aQS600DHaP075:DLiacW6<HLiaS65:D00QS60QcW00<HaQcW7>L00QcW00HDYAS65:DHaQcW8@P27>L0
21S65:DHaQS65:DHaQcW5:D248@00aBU6<HDY@0248@00aS65:DDY@025:D00aS648@@Q0035:D348@2
5:D01QS65:DDYABU48@DY@8@Q0035:D@Q1BU00DDY@8HaP<DY@8HaP8DY@8@Q0<DY@<HaP055:DHaQS6
7>LHaP027>L36<H011BU48@@Q1240QBU00<@Q1BU48@01a2411BU1Q240QBU00<@Q1BU48@0112400<<
Ha2448@00Q240QBU112400<DYA2448@01a2400<DYA2436<00a2400<DYA2436<011240aBU0aS611BU
00L@Q0aS48@DYAS65:D<H`0648@010aS48@<H`aS0Q2400<HaQ2436<00Q2400<<Ha2448@01Q241QBU
0Q240`aS000312400`0012400003124030001248@RU:BU8YBQS6:DXaS2e[:DXU:@<]J`8YBP<U:@04
:DXU:BDY9BT3;F/2:DX00be[<H`aS002:DX28@P29BT00bU:;F/U:@079BT02R489BTU:B489BTQ21cW
9BTQ22U:0S6<00<]JbDY:DX00S6<00@YBR488@PU:@<YBP059BTLiacW7>LQ20049BT01R489BTQ22DY
8@PLi`8Q20039BTYBRU:008]J`0?:DXQ22DY:DXaS2DY:DXaS3W>?NlaS2e[:DXU:BU:008U:@05;F/a
S36<<H`]J`04<H`012e[:DXU:BU:12DY1BU:12DY0RU:00PU:B489BTU:Be[:DXU:BU:0bDY00X]Jc6<
=JdaS2e[:DXaS3F]<H`YBP8Q2003:DXU:BU:008YBP<U:@03:DXU:BDY008Li`8U:@04;F/YBR487>L3
8@P01BDY:DXYBRU:9BT022U:00@U:B488@PU:@8YBPPQ20069BTQ22488@PU:B480acW0b480QcW00<H
aQcW8@P00R4800DLib489BTU:B4800@Li`038@PLiacW008Q20037>LHaQcW00<Q20037>LHaQS600<L
i`8HaP077>LQ22488@PLib487>L00RDY00<Q21cW6<H00QcW00@Q21cW7>LQ208Li`8HaP037>LHaQcW
00<U:@057>LHaQS67>LU:@028@P26<H27>L01R487>LLiaS67>LHaP8Li`038@PLiacW00@Li`8HaP<L
i`049BTQ22487>L26<H00acW6<HQ20058@P00acW8@PLi`027>L46<H27>L36<H37>L00aS65:DHaP04
6<H011cW6<HLiaS60QcW11S60acW0QS61QcW0aS60QBU0QS60QcW0QS600<DYAS67>L00aS60QcW1QS6
00<DYAS66<H00QcW0QS600<LiaS67>L00aS60QcW00<HaQBU6<H00QcW00<HaQBU7>L00aS60QcW0QBU
00<HaR488@P01AS60aBU00<@Q1BU5:D01QBU00<HaQBU6<H011BU0Q2400DDYA245:DDYAS6008DY@8@
Q0045:D@Q1BU5:D248@00aBU6<HLi`035:D36<H25:D00a245:DDY@0348@00aBU6<HDY@036<H25:D8
6<H45:D248@45:D648@25:D00aS648@@Q00248@01QBU48@@Q12436<DY@<@Q08DY@8@Q08<H`<DY@03
48@<Ha24008@Q0035:D@Q12400D@Q00536<@Q1BU5:D@Q00336<00aBU6<HDY@0236<011245:D<HaBU
0acW00HDYA245:D@Q1BU48@45:D<48@336<348@236<00a2436<@Q00248@236<01QBU6<HHaQBU48@H
aP8DY@0348@<Ha24004<H`0000<48@0012402@@Q00@U:DYB<H`Li`<]J`04:DXaS36<;F/39BT28@P0
0bDY8@P]J`02<H`2:DX00be[<H`]J`02:DX012e[:DXYBRDY12U:00<U:B488@P00RDY00DYBRDY9BTU
:B48008U:@07:DXU:B487>LQ22U:;F/00bU:0be[00<U:BU::DX00RDY0RU:00DU:B486<HQ21cW008Q
20077>LU:Be[:DXU:AcW6<H00R480RDY1BU:00<U:BU::DX00RU:00<]Jc6<=Jd01C6<0bDY00@]JcF]
<H`aS0<e[@03<H`]JbU:00<YBP8]J`8U:@04:DX]JbU:9BT2:DX012489BTU:BDY1BU:0Re[00<YBRDY
8@P00RDY12e[1C6<00<]JbU:9BT00RU:0R4800DLibDY9BTQ22DY008YBP<Q208YBP8Q20049BTQ2248
9BT2:DX28@P012DY;F/YBRU:0be[00<YBRDY9BT00R480bU:00<U:B488@P00R4800LU:B488@PLib48
9BTQ20029BT00b487>LQ20038@P67>L28@P012DY8@PQ22480QcW0R4800PU:B487>LLiaS67>LQ21cW
0R4800<Lib487>L011cW0QS600@Q22DY:DXQ208HaP097>LQ22487>LHaQcW8@PLib4800DLi`8HaP03
5:DLiacW00<Q208Li`8HaP047>LQ22487>L26<H47>L01R486<HDYAcW8@PU:@8HaP037>LQ224800<H
aP8Li`038@PLiacW00<Li`@HaP048@PU:BDY8@P27>L28@P27>L26<H00acW5:DDY@025:D01QcW6<HD
YABU6<HLi`8HaP8DY@056<HLiacW6<HLi`026<H47>L28@P27>L26<H67>L35:D27>L46<H77>L01AS6
7>LLiaS67>L01aS60QcW00<HaQcW6<H00QcW00HDYAS66<HLiaS65:D26<H27>L26<H011BU6<HHaQBU
0aS600DLiaS66<HHaQBU00@HaP035:D@Q1BU008@Q08DY@036<HDYABU00<DY@0548@DYAS65:DHaP02
48@25:D348@00aBU6<HDY@025:D248@011BU48@DYA240QBU00<HaQBU5:D00QBU0aS60QBU00<HaQBU
5:D00aBU00<HaQBU6<H00QS611BU0QS600@DYAcW6<HHaP8DY@0548@DYABU6<HDY@0348@45:D348@0
0aBU48@@Q00648@236<00aBU48@HaP025:D00a2436<@Q00248@00aBU36<@Q00248@01ABU48@@Q124
5:D00Q240aBU1a2400<DYA245:D011240PaS00HDYAS67>LLiaS65:D348@00aBU48@@Q00348@01ABU
48@@Q1245:D0112400<DYA2448@00`aS0Q2400<DYA2436<0112400L<Ha2436<<Ha245:DHaP045:D4
48@136<000848@0600048@@Q124000Q20P@Q00X000Q29BU6<Be[7>L]JcF]:DX]J`8aS003;F/U:AcW
00DU:@06:DX]Jbe[<H`]JbU:0Re[00@aS2e[:DXYBP8U:@<YBPTU:@038@PU:BDY008U:@05:DXQ21cW
8@PU:@02<H`00bU:9BTU:@02:DX00be[:DXU:@029BT012U:9BTQ21cW0b4800@U:B487>LYBP8]J`04
9BTHaQcW9BT28@P2:DX2;F/012U:9BTYBRe[0bU:00<]Jc6<<H`00SF]0S6<00L]JbU::DXYBRe[<H`]
J`02<H`2=Jd3<H`00bU:9BTU:@02:DX01BDY:DX]Jbe[:DX00RDY00LYBRDY9BTQ22DY:DXU:@02:DX2
;F/2:DX39BT00bU:;F/]J`03;F/3<H`00be[:DXYBP03:DX00bDY:DXU:@049BT01BU:9BTQ21cW9BT0
0bU:0RDY0R480RU:0RDY00<Q22U::DX00RDY0RU:00<U:BU:9BT012DY00<YBRDY9BT0124800@U:B48
7>LQ20<U:@068@PU:AcW7>LHaQcW0b480acW224800<Lib489BT00R481QcW124800HLiaS66<HQ21cW
8@P27>L48@P37>L00b487>LLi`037>L28@P27>L012487>LQ21cW11S60R4800<U:B486<H00QS600@Q
21cW8@PQ20DLi`8Q20036<HDYAS6008Q20037>LDYAcW00<Li`<HaP047>LQ21cW8@P27>L01R486<HH
aQS67>LQ208U:@8Q208Li`048@PLiacW8@P26<H35:D00aS65:DDY@026<H27>L00aS65:DHaP026<H3
7>L36<H37>L012487>LLib4811S600<Lib488@P00QS60QBU00<LiaS67>L011cW0aS60acW00@HaQcW
6<HHaP8DY@066<HLiacW6<HDYAS60QcW00DQ21S66<HHaQcW008HaP045:DLiacW5:D26<H01acW6<HD
YAS67>LHaQBU00DHaP045:DHaQcW7>L26<H35:D36<H011BU48@@Q1240QS600@DYA245:DDY@8HaPDD
Y@<@Q0HDY@0348@DYABU008DY@0448@HaQBU6<H25:D011245:DHaQBU0aS600<DYA245:D00aBU0Q24
00@DYAS66<HHaP8DY@0<48@DYAS66<HLiaS65:D@Q1BU48@DYA241aBU11240QBU0Q2400D<Ha2448@@
Q1BU008<H`8@Q08DY@0448@HaQBU48@236<00a245:D@Q00548@00aBU48@DY@0348@26<H01A2436<8
@Q245:D0212400@DYA2448@@Q08DY@8HaP045:DHaQBU5:D448@00`aS48@@Q0045:D348@010aS5:D@
Q1BU0a2400P<Ha2448@DYA2436<@Q0aS11240PaS00@DYAS66<HDY@8@Q0055:DHaQBU5:D@Q00136<0
000500048@@Q1240000712401BDYDY@icR48;F/00SF]0Re[00<YBRDY9BT00bDY00<Q22DY:DX00S6<
00`]JbU::DXU:BU:;F/aS2e[9BTQ22U:<H`2:DX29BT38@P00bDY8@PQ20049BT012489BTU:BDY0R48
00@U:BU:;F/]J`8YBP05;F/U:B487>LQ2002:DX39BT00acW8@PQ20029BT28@P01BDY:DX]JbDY8@P0
0QcW0RDY0RU:00<aS2e[;F/012U:00<aS2e[:DX00Re[00@aS2e[<H`aS0@YBP03<H`]Jbe[00<aS0<]
J`06:DXU:B489BT]JbU:0bDY00<YBS6<<H`00RU:0R481BDY00@YBRe[;F/]J`<U:@048@PU:BU::DX2
;F/3<H`5:DX49BT00b489BTQ2003:DX39BT3:DX00bDY8@PQ20029BT00b48:DX]J`02:DX29BT00bU:
;F/]J`02:DX00bDY:DXU:@029BT01B48:DXU:BDY:DX00RDY00<Q22DY9BT00bDY1b4811cW00<Q21cW
8@P011cW0RDY00<Q22DY7>L00QcW00@U:BU:9BTQ208Li`076<HDYAcW8@PU:B486<H01acW0b480acW
00@Q21cW8@PQ20<Li`059BTQ21cW7>LHaP047>L26<H37>L28@P00acW8@PLi`037>L28@P01AcW6<HH
aQS68@P00QcW0aS60QcW0b4800DLiaBU6<HHaRDY008HaP037>LU:B4800<HaP057>LHaQcW8@PU:@04
8@P01QcW8@PHaQcW6<HDY@8HaP8DY@8HaPDLi`056<HDYAS66<HLi`025:D011cW8@PLiaS61QcW11S6
1QcW00<HaQcW7>L011S600<LiaS67>L00acW0aS61AcW0aS600<DYAS67>L00QcW0QS600<LiaS67>L0
0QS60QcW11S611cW2AS60QBU00DHaQcW7>LHaQBU008HaPDDY@8HaP035:D@Q1BU00@DY@<@Q0036<HD
YABU008@Q0@DY@086<H@Q1246<HU:B486<H<H`HDY@DHaPDDY@046<HDYAS66<H75:D26<H01ABU6<HD
YA245:D00QS600DDYA245:D@Q1BU008@Q0@DY@P@Q08<H`0;48@DYAS648@<Ha246<HDYAS648@DY@05
48@00aBU48@@Q00348@01aBU6<H@Q1245:DHaQ24008<H`0348@DYA2400D@Q0045:D@Q0aS36<248@0
11S65:DDYABU0aS60QBU00<@Q1BU48@00a2400@<Ha2448@@Q08DY@0448@<Ha2448@25:D236<248@2
36<548@00aBU36<@Q00248@011BU48@DYABU0a240aBU00<@Q1BU5:D00A24000312400`0012448@04
12401`00248U:Dic=JdQ236<008e[@04<H`YBRDY8@P39BT28@P012DY:DXaS36<0Re[00HYBRe[;F/a
S2e[:DX29BT00bU:;F/]J`02:DX58@P29BT28@P00bDY8@PU:@058@P012DY:DXaS2e[0RU:00<]JbU:
9BT00R4800HU:BU::DXU:AcW8@P39BT01b487>LU:BU:<H`]Jb4800<Li`038@PU:BU:00@]J`039BTY
BRe[00<]J`04:DX]Jc6<;F/2<H`012e[:DXYBRDY12e[0c6<00<]Jc6<<H`00bDY00LYBRe[9BTYBRDY
:DXU:@03;F/00bU:9BTQ20029BT012489BTU:BU:0Re[00DYBRDY9BTU:B4800<U:@06:DX]Jc6<<H`]
Jc6<1BU:00D]JbDY8@PU:B48008U:@<YBP<U:@8YBP8U:@098@PU:B488@PU:BU:;F/Q22DY008]J`04
:DXU:BDY9BT2:DX29BT012489BTU:BU:1BDY0R480RDY0b4800<YBR488@P00QcW0R4800<Lib487>L0
0R480QcW00@Q22DY8@PQ20<Li`036<HQ22DY008YBP039BTLiaS6008HaP048@PU:B487>L26<H38@P0
0aS67>LQ20038@P00aS67>LQ20038@P27>L01B489BTQ22487>L00QS60QcW00@HaQBU6<HHaPDLi`<Q
20LLi`036<HLiacW00@Li`046<HDYAcW7>L28@P27>L00aS67>LLi`037>L00b487>LLi`027>L36<H0
0acW9BTU:@027>L00b487>LHaP027>L46<H011cW5:DDYABU0aS60QcW0QS600@DYAS66<HHaPTLi`03
6<HLib4800<Li`<HaP8Li`038@PLiaS6008HaP8Li`8HaP<Li`036<HLiacW00<Li`036<HLiacW008D
Y@046<HLiacW7>L25:D27>L00b487>LHaP026<H00acW6<HDY@026<H37>L36<H00acW6<HHaP026<H0
0acW6<HHaP025:D01QcW6<HLiaS65:DHaP<DY@8HaPLDY@0448@DYABU48@35:D0112436<<Ha2411BU
0QS60QBU0acW00<HaQ2448@00QBU00<HaQBU6<H02aBU0QS60QBU00<HaQBU6<H00QBU0a240QBU0QS6
1ABU00D@Q1BU48@@Q1BU008@Q0<DY@8@Q0045:D@Q12436<348@011BU6<H@Q0aS0Q2400@DYAS65:DD
Y@L@Q0045:D@Q0aS36<248@01ABU48@@Q1245:D02A240QBU0a2400<DYA245:D00Q242ABU0Q2400@<
Ha2448@@Q08DY@0748@DYA2448@<Ha245:D03A240PaS0Q2400<DYA2448@00QS60Q2411BU0AS60ABU
0A2400000`001240000212400`0012448@0412401BDYCW<icRDY:DX00c6<00<]Jb489BT01BDY00HY
BRe[:DXU:B48:DX2<H`00bU:9BTYBP02:DX0136<;F/]Jbe[0RU:1b480RDY0R4800DLibDY9BTU:BU:
008]J`03:DXU:BDY00<]J`8U:@8Li`8Q20059BTQ22488@PYBP039BT00b48:DXYBP02:DX012487>LQ
22480Re[00TaS2e[:DXU:BU:<H`]Jc6<:DX00be[00@YBRDY:DX]J`8YBP8U:@04;F/aS36<<H`2;F/0
136<;F/YBRU:0bDY0RU:0bDY0Re[00PYBRDY:DXYBR489BTQ22U:0RDY0RU:00<]JbU:;F/00RU:0bDY
00<]JbU::DX00RDY00LYBRe[;F/U:B48:DX]J`02:DX01bDY:DXU:BDY8@PU:B48008U:@098@PYBS6<
;F/U:B489BT]JbU:008U:@8YBP8U:@03;F/YBRU:00@]J`LU:@8Q20059BTQ22U::DXU:@038@P29BT2
8@P00acW8@PQ20038@P01acW8@PU:BU:9BTQ21cW00<Q20049BTQ22488@P29BT28@P29BT00b487>LL
i`027>L012487>LHaQcW0b4800@Lib488@PQ208U:@038@PLib4800<U:@037>LQ2248008U:@8Q208L
i`8Q208Li`8HaP8Li`8Q20037>LQ2248008Li`036<HLib4800<Q20TLi`8HaP048@PU:BDY7>L26<H0
0b487>LLi`038@P27>L02QBU7>LLib487>LQ21cW6<HLib480acW00HQ21S65:D@Q1BU6<H25:D01aS6
5:DDYABU7>LQ21cW008HaP8Li`8HaP8Li`8HaP047>LQ21cW7>L26<H57>L00b487>LHaP026<H00acW
8@PQ20027>L26<H00acW8@PLi`026<H01acW8@PLiacW6<HLiaS6008Li`036<HLiacW00HHaP057>LQ
21cW8@PLi`026<H25:D26<H00acW6<HLi`027>L36<H00acW6<HHaP096<H00aBU6<HDY@036<H00aBU
6<HHaP075:D00a245:D@Q0025:D0112436<@Q1240QS600@DYA2448@@Q0@DY@036<HDYABU00<@Q08D
Y@066<HDYAS66<HDYAS60Q240aBU00@HaQBU5:DHaP8DY@0448@DYAS66<H25:D011245:DDYAS611BU
0Q2400<DYA2448@00Q2400<<HaBU5:D01ABU00<@Q0aS48@00PaS00<DYA245:D00Q2400@<Ha2448@H
aP8DY@0448@DYA245:D848@01QBU48@@Q12436<@Q08DY@<<H`045:D@Q1BU5:D348@45:D248@00aBU
48@DY@025:D248@011BU6<HDYA240QBU00<@Q0aS36<00aBU00@@Q1S65:DDY@@@Q00436<@Q1BU48@3
36<348@00`aS48@@Q00448@25:D248@00aBU48@@Q0025:D00aS65:DDY@0148@000H48@030008@P@Q
00<48@0;8@Q>LcW>9BT]Jc6<>LhaS2U:9BTQ2002:DX29BT00b48:DX]J`02:DX00bDY:DX]J`02;F/2
:DX29BT012e[<H`aS2e[0bDY00<Q21cW7>L00RDY224800<U:BU:;F/00RU:00DU:BU::DX]JbU:008U
:@<Q20039BTQ2248008Q20<YBP8Q20059BTYBRU:9BTLi`028@P00bDY:DX]J`02;F/3:DX01be[<H`a
S36<:DX]JbU:008U:@@YBP059BTYBRe[;F/aS006;F/2:DX28@P01BDY:DX]JbDY:DX00be[12DY00<Y
BRDY9BT012DY00@YBS6<:DX]J`8U:@<YBP8]J`8Q20039BTYBRe[008U:@03:DX]JbU:00@U:@04:DXQ
21cW9BT2:DX29BT3:DX59BT2:DX02RDY8@PYBRe[<H`YBRDY;F/aS2U:0RDY00@YBRDY8@PQ208U:@<Q
20039BTYBRU:008U:@038@PU:AcW008Li`8Q20099BTQ22487>LHaQcW9BTYBRDY00<Li`8U:@078@PU
:B488@PU:B48:DX012DY00<Q21cW6<H00QcW00DHaQcW7>LLib48008Li`DQ20<Li`8U:@8Q208Li`03
8@PU:B4800<Li`038@PLiacW008HaP055:DLiacW8@PLi`048@P021S67>LLiacW8@PLib487>L26<H0
1B489BTQ21cW6<H011cW00<Q22DY9BT00QcW00<HaQcW8@P00R4800@LiaS66<HLi`<HaPHLi`<Q2004
7>LHaQBU6<H25:D011S65:DDYABU1QS60QcW00@DYAS66<HHaPDLi`036<HDYAS6008Li`036<HLiacW
00<Li`<HaP038@PLib4800<Li`046<HLiaS66<H57>L011S67>LHaQcW0aS600@DYAS67>LLi`<HaP8L
i`8Q20<Li`DHaPDLi`038@PLiaS600<HaP<Li`046<HDYAS67>L26<H35:D26<H01ABU6<HDYABU6<H0
0QBU0Q240aBU112400<<Ha2448@00QBU0a2411BU00<HaQBU5:D00QBU00@@Q1BU48@@Q08DY@8HaPHD
Y@0348@DYABU008DY@0648@DYABU6<HDYAS60QBU00@@Q1BU5:DHaP8DY@046<HDYA245:D548@25:D0
0a245:D@Q0035:D248@336<248@00aBU48@@Q00248@55:D00a245:DDY@0248@00aBU48@@Q00236<2
48@25:D448@01ABU48@@Q1245:D0112400<DYA245:D00Q2400<DYA245:D01A2400<DYA245:D011BU
112400DDYA245:D@Q1BU00D@Q0035:D@Q0aS008@Q0055:D@Q0aS36<DY@0248@00aBU48@<H`0248@0
0aBU6<HDY@0248@25:D011S65:DDYA240aBU0A2400001@00124000@Q00001`@Q00TQ24YB=JdYBSW>
?NlaS2U:9BT00bU:0R4800@YBRe[;F/YBP8U:@8YBP<aS004;F/YBRU::DX2<H`00be[:DXU:@049BT2
8@P49BT01R489BTQ22489BTQ208YBP03;F/aS2e[008YBP038@PU:B4800<Q208U:@<Q2003;F/aS2U:
008Q20039BTYBRU:00<Q20069BTYBRU::DXaS2e[0RU:00<U:Be[<H`00Re[0RU:00D]JbU::DXU:B48
00<U:@03;F/aS3F]008aS004=JdaS36<;F/2:DX29BT02bU:;F/YBRDY:DX]Jc6<=Jd]JbU:8@P00bDY
0R4800@U:B489BTYBP8]J`03:DX]JbU:008YBP<U:@038@PU:BU:008YBP04;F/U:BU:8@P29BT38@P3
9BT28@P2:DX2;F/49BT01Be[:DXU:BDY8@P00RDY0RU:00H]JbU:;F/]Jc6<;F/3:DX49BT01BU:9BTU
:BDY8@P01RDY00@Q22DY8@PQ20<U:@038@PLiacW00DLi`@Q20047>LQ22488@P29BT2:DX59BT68@P3
7>L28@P01RDY8@PU:BU:9BTQ208Li`079BTYBRDY8@PHaQcW9BT022480acW00TU:B487>LHaQcW8@PL
iaBU6<H00QcW00@HaQcW7>LQ20<HaP<Li`8Q20067>LHaR489BTYBR480QBU0QS60QcW00@Q22DY9BTL
i`8HaP067>LQ22DY7>LQ21S61QcW00DQ21cW6<HHaQBU008HaP8DY@LHaP047>LHaQcW7>L26<H47>L2
8@P27>L00aS67>LQ20057>L36<H00aBU7>LQ20067>L00b486<HHaP037>L01aS67>LHaQcW6<HLiaS6
00HLi`046<HLiacW7>L28@P00acW6<HHaP046<H021BU6<HLib487>LHaQBU7>L56<H011BU6<HHaQcW
0QBU00<HaQcW6<H01AS60QBU00<HaQBU5:D00QBU00D@Q1BU5:DHaQBU008@Q0056<HDY@aS48@DY@02
6<H55:D248@00aBU48@DY@025:D011245:D@Q1BU0a2411BU0Q2400<DYAS65:D00QBU0Q2400DDYA24
5:D@Q1BU00<@Q0035:DHaQS600LDY@<@Q00336<@Q12400@DY@8@Q0035:D@Q12400D@Q00536<@Q1BU
5:DHaP025:D011245:DDYA240QBU00/HaQBU48@<Ha245:D@Q1BU48@DYA24008DY@D@Q08DY@046<HD
YABU5:D248@00aBU48@@Q0025:D02A245:D@Q1245:D@Q1BU6<HDY@0348@011BU48@<Ha240aBU0a24
0QBU00<HaQBU36<00PaS00<@Q1BU5:D00Q240PaS0Q2411BU00<@Q1BU5:D00QBU0Q2400LDYAS65:DD
YA245:DHaP015:D000X48@090008@RDYCW<aS2U:?NlicS6<008Q20<YBP@U:@8]J`@YBP@]J`8U:@07
:DX]Jc6<<H`]JbDY8@P00RDY00@YBR488@PQ208U:@@Q20039BTQ22DY008YBPD]J`8U:@8Q208U:@<Q
20057>LYBRe[;F/YBP028@P01BDY:DXU:BU:9BT00R480RDY00<YBRe[;F/00RU:00@U:BU:;F/YBP8]
J`03<H`]JbU:00@U:@8Q2003:DX]JcF]00DaS08]J`03:DXU:BDY00HYBP8aS08]J`049BTQ22487>L4
9BT00b48:DX]J`02;F/012DY:DX]JbU:0RDY00DQ22DY:DXYBRDY008YBP04;F/YBRU:9BT48@P01BDY
8@PU:B489BT00bU:00<]JbU:9BT00R4800DYBRDY9BTU:BU:008U:@05:DX]Jbe[:DX]J`02<H`012e[
9BTU:BDY0b4812DY00<Q22DY8@P01BDY00@Q21cW7>LQ20<U:@038@PLiacW008Li`059BTLib488@PL
i`028@P29BT38@P3:DX29BT00b489BTU:@047>L00b487>LQ20027>L012489BTQ224812DY0QcW00@Q
22DY:DXU:@8Q208U:@038@PLib4800<Q208Li`038@PLiacW008Li`058@PLiacW7>LQ20046<H01AcW
8@PLiacW6<H00QcW00/Q21cW9BTQ21S65:DLibDY:DXQ21BU008HaP035:DHaQcW008U:@038@PLiacW
008DY@8Li`8U:@8Q20037>LHaQS6008Li`8Q20037>LHaQBU00@HaP065:DHaQS67>LHaQBU0QS60QcW
0QS61QcW11S60acW00<Q21cW7>L00QcW00HDYAS67>LQ21cW6<H27>L36<H00acW8@PHaP026<H27>L3
6<H00acW6<HLi`036<H57>L011S67>LLiacW0QS60QcW0QS600<DYAS67>L00acW1AS600<LiaS67>L0
2aS600@LiaBU6<H@Q0PDY@<@Q08DY@0348@<H`aS008@Q0035:DHaQBU00DDY@<@Q0055:DHaQBU5:D@
Q0025:D348@45:D011245:DDYA240QBU00@@Q1S65:DDY@8@Q0045:DHaQS65:D248@011BU6<HHaQBU
0Q2400<DYA2448@01a240aBU00<@Q1BU5:D0112400@<Ha2448@<H`8@Q0036<HDYABU008DY@8@Q08D
Y@8HaP@@Q08DY@<@Q08DY@0348@<H`aS008@Q00636<@Q1BU5:DHaQ240PaS00<@Q1BU48@00a240aBU
0Q2400@DYAS65:DDY@8@Q08DY@<@Q08DY@<@Q0036<HDYABU008@Q08<H`0448@<HaBU5:D248@00`aS
5:DDY@0348@35:D011245:DDYABU0QS61ABU0QS60A2400002000124000@Q00048@00248412401b48
CW<icRU:=JdaS2DY008Q208YBP<U:@07;F/e[C6<;F/U:BU:;F/00SF]00<]JbDY8@P00bU:0Re[00@Y
BRDY8@PU:@@Q2009:DXU:BDY9BTQ22DY8@PU:B4800<]J`8U:@03:DX]JbU:00DQ20<U:@8Q20059BTY
BRe[;F/YBP029BT2:DX00bDY8@PU:@029BT5:DX29BT2:DX4;F/01RDY:DXYBRe[:DXQ208U:@<YBP03
;F/aS36<008]J`05<H`]JbDY8@PU:@03;F/29BT0136<>Lhe[C6<0QcW0RDY00LYBRe[9BTLib487>LU
:@04:DX2;F/012U:;F/U:B480RDY0RU:0be[00<YBRDY8@P01B480RDY0bU:0RDY0bU:00HU:B489BTY
BRe[:DX39BT012U:<H`]Jbe[0bU:0Re[00DYBRDY8@PU:B4800<U:@04:DXQ22488@P49BT28@P02RDY
:DXYBRDY8@PU:BU:9BTQ22DY0R480acW00@Q22DY8@PHaP8Li`039BTQ22U:008YBP059BTQ22U::DXU
:@028@P39BT00acW8@PLi`029BT37>L01BDY:DXYBR487>L012DY00<Lib489BT00RDY0R4800@Lib48
7>LQ208Li`8HaP048@PU:BDY8@P27>L00b486<HLi`036<H27>L26<H47>L01B489BTLiacW6<H01acW
00LHaQBU7>LQ22DY8@PLi`026<H27>L29BT00b487>LLi`027>L26<H021cW8@PQ21cW5:DHaQBU6<H2
5:D26<H00aBU6<HDY@026<H37>L36<H47>L012487>LLiaS60QcW00DHaQcW7>LQ21cW00<HaP@Li`@H
aP@Li`8HaP035:DHaQS600@Li`036<HLiaS600@HaP8Li`046<HLiacW8@P27>L011S67>LHaQS60QBU
0aS600<LiaS67>L00QcW00@HaQBU5:DHaP8Li`<HaP057>LHaQS66<HLi`056<H35:D248@55:D01124
5:DDYABU0a2400@DYAS65:D@Q08HaP035:D@Q124008DY@0348@DYABU00LDY@8@Q00436<@Q1BU5:D3
48@01ABU6<HDYA245:D0112400<DYA2448@01ABU00<@Q1BU5:D01a2400<DYAS65:D00Q2400@DYAS6
6<HDY@@@Q0035:D@Q12400<<H`@DY@8@Q0075:D@Q1246<HQ21S65:D00PaS00<@Q1BU5:D00Q2400<<
Ha2436<01a240QBU00@HaQ2448@@Q0@DY@<@Q08DY@0448@DYA2436<248@55:D248@236<248@45:D4
48@01PaS48@@Q1BU48@DY@@@Q0<DY@@@Q0XDY@4HaP4DY@4DY@0030@Q00/U:Dic=JdYBSF]<H`YBR48
9BT]JbU:008U:@04:DX]Jbe[<H`2;F/01bU:<H`e[C6<;F/U:B48008YBP8]J`<YBP8U:@<Q20059BTY
BRDY9BTQ20059BT2:DX00be[:DXU:@02:DX29BT012487>LQ22480RDY0R4800<U:B48:DX00Re[00DY
BRDY:DX]JbDY008Li`038@PYBRU:008YBP8]J`8YBP069BTQ22U:;F/aS2e[12U:0bDY00@YBRDY:DX]
J`<aS08]J`8aS00=:DXU:BDY:DX]Jc6<:DXU:BU:<H`e[CW><H`012DY00DYBRDY8@PQ21cW008Q2005
:DXU:BU::DX]J`02:DX29BT00bU:;F/YBP07:DX68@P00acW8@PYBP02:DX29BT012U:;F/YBRU:0RDY
0bU:0RDY00PYBRe[<H`aS2e[:DX]Jc6<0Re[0bDY00DQ22DY8@PU:BU:008U:@8Q20047>LU:BDY9BT2
8@P00bDY;F/YBP059BT28@P37>L28@P01RDY8@PHaQcW6<HLi`8U:@8YBPHU:@<Q20<U:@047>LQ22DY
9BT27>L01b48:DXYBRDY8@PU:B4800<U:@<Q208U:@038@PLib48008Q208Li`8Q208Li`8Q20039BTL
ib48008Li`046<HDYAS66<H67>L012487>LQ21cW0R4800@HaQBU6<HLi`8Q20056<HDYABU6<HLi`02
8@P27>L011S67>LQ21cW0R480RDY0acW00DHaQcW7>LQ21cW008HaP047>LHaQBU5:D56<H00acW6<HL
i`037>L011BU6<HQ21cW0QS600@Lib488@PQ208Li`8HaP047>LQ22489BT26<H00aBU6<HLi`027>L4
6<H00acW8@PLi`036<H27>L36<H00acW8@PLi`026<H011BU6<HHaR481acW00DQ21cW6<HHaQcW008H
aP8DY@<HaP8Li`8HaP055:DHaQS66<HLi`025:D00aS67>LHaP086<H55:D00a245:DHaP035:D348@0
1aBU48@DYA246<HDYAS6008@Q0056<HLiaS648@<H`035:D248@00aBU48@DY@025:D448@00aBU48@D
Y@0348@35:D00a2436<@Q0025:D348@00aBU6<HHaP025:D26<H00a2436<@Q00548@25:D00a2436<@
Q0036<H548@25:D00a2436<<H`025:D248@01QBU6<H@Q12436<@Q0<Li`0648@<H`aS5:D@Q1BU0PaS
00D@Q1BU5:D@Q0aS00D@Q0035:DHaQBU00@DY@<@Q0045:D@Q12448@25:D248@25:D011245:DDYABU
0a2400DDY@aS36<<Ha2400DDY@0648@<H`aS36<DYAS60QBU00L<Ha245:D@Q1BU48@HaP025:D248@0
0aBU48@DY@0248@55:D00aS67>LHaP015:D0000500048@00124000041240200012448B48BU8icRU:
<H`3:DX39BT7:DX01c6<>LhaS36<:DXU:BU:008U:@<YBP039BTYBRDY00DU:@048@PYBRU::DX48@P0
0bU:;F/YBP03:DX012e[:DXYBR480RDY0RU:0RDY00LYBRDY9BTQ22U:;F/YBP029BT2:DX01Re[:DXU
:BDY:DX]J`8YBP8U:@058@PU:BDY:DX]J`03:DX29BT3:DX39BT00bU:9BTYBP02:DX2;F/2<H`00be[
<H`YBP039BT2;F/3<H`013g_>LhaS36<0R480RDY00DYBR488@PQ22DY00<Q20<YBP039BTYBRU:00<]
J`<YBP07;F/aS36<;F/U:B487>L00R480RDY00@Q22DY9BTYBP8U:@04:DX]Jbe[;F/39BT012U:;F/]
JbU:0bDY00HYBRe[;F/]JbDY:DX2;F/012U:8@PQ22DY0R4800@U:B488@PU:@<Q20039BTYBRe[008Y
BP<U:@04:DX]JbU:9BT38@P37>L38@P47>L28@P01RDY8@PYBRU:;F/YBP<U:@048@PLib488@P29BT0
1B489BTQ22489BT00b480RDY00<Q22DY8@P012480RDY00<YBRDY8@P00R480QcW0b4800HHaQcW8@PY
BRDY7>L28@P00acW6<HHaP027>L66<H01AcW6<HHaQcW8@P00RDY00HLiaS65:DHaQcW8@P26<H37>L0
2R487>LLiacW6<HDYAS67>LQ22DY0QcW0b481AcW0b4800HHaQBU6<HDYAS65:D56<H47>L26<H27>L0
0aS67>LLi`027>L01AS67>LLiacW6<H00QcW00DQ21cW7>LHaQcW008HaP<Li`8HaP8Li`8HaP047>LH
aQS66<H27>L26<H37>L01AS65:DHaQcW6<H00QcW00<Q21cW6<H00QcW0aS600<LiaS65:D00QS61acW
0QS60QBU0aS611cW00<HaQBU5:D00QS600DLiaS65:DDYAS6008DY@0348@DYAS600<DY@@@Q0<DY@8H
aPLDY@0448@DYA2448@35:D248@45:D00aS65:D@Q00248@011S65:D@Q1240aBU0Q240PaS1A242ABU
00H@Q1BU5:DDYAS65:D348@011BU6<HHaQS60QBU0Q241ABU00<@Q1BU5:D00QBU1A240QS600@LiaS6
48@@Q08<H`H@Q0035:D@Q0aS008@Q0035:D@Q1BU008DY@8@Q08DY@0448@DYABU5:D448@25:D448@0
1QBU48@@Q1246<HDY@@@Q08<H`0548@DYABU48@DY@0348@010aS48@@Q1BU0Q2411BU00<@Q1BU5:D0
0QBU0`aS00@DYAS66<HDY@8@Q0045:D@Q1BU6<H35:D000`48@048@Q:DSW>9BT3;F/01BU:9BTU:B48
9BT00RU:00@]JbU::DXYBP<e[@04<H`Q22DY9BT2:DX01Re[:DXYBRU:9BTYBPDU:@8YBP039BTYBRDY
00<U:@<YBP03;F/YBRe[008YBP8U:@06:DXU:BDY9BTYBRDY0b480be[00@YBRDY9BTU:@8YBP8U:@04
8@PU:Be[;F/2:DX59BT3:DX39BT00b489BTU:@039BT4:DX3;F/2<H`01be[:DXYBRU:9BTYBRe[008Y
BP8aS08icP06=Jd]JbDY9BTYBRDY0b4800@U:BU:9BTQ208U:@03:DXU:BDY008YBP04;F/YBRU::DX4
;F/01RU:;F/U:BDY8@PLi`DU:@8YBP039BTYBRU:00<]J`<U:@04:DX]JbU::DX2;F/00c6<;F/YBP03
:DX012e[:DX]JbU:0RDY0R4800<U:B489BT00b4800@U:BU:9BTU:@8]J`04:DXU:B488@P29BT012e[
9BTU:BDY0R480QS600@Lib488@PLi`8Q20069BTQ21cW7>LU:Be[12U:0RDY00@Q22DY8@PQ20<U:@04
7>LQ22DY9BT27>L012DY:DXYBRU:0R4800DU:B489BTLib48008YBP059BTLiacW8@PLi`028@P01RDY
8@PLiacW8@PU:@<Q200;7>LHaQS67>LQ21cW5:DHaQcW8@PLi`046<H00acW8@PQ20028@P36<H27>L2
6<H00acW8@PQ20047>L01b486<HDYAcW8@PU:B48008Li`038@PLib4800LLi`038@PLiaS6008DY@@H
aP047>LHaQS66<H37>L26<H37>L012487>LLib480QcW00<HaQcW8@P00b480QcW0QS600<LiaS66<H0
0QS61AcW0QS600<LiaS65:D00QS600@LiaS67>LHaP8Li`046<HLiaS67>L26<H00acW8@PLi`0=6<H2
7>L011S67>LHaQS60QBU0QS600@DYAS67>LLi`<DY@<HaP045:DHaQS65:D26<H00aBU48@@Q0026<H3
48@25:D00a245:DDY@026<H25:D011245:DHaQS60aBU00@@Q1BU48@@Q08DY@036<HDYABU00@DY@8@
Q08DY@0348@DYABU008DY@056<H@Q12448@<H`0448@01QBU48@DYA246<HDY@8@Q0<DY@8@Q0<DY@05
6<HDYABU48@DY@036<H248@01QBU48@DYABU6<HDY@8@Q0035:DHaQBU00@@Q0DDY@0348@<H`aS00d@
Q0085:D@Q1245:D@Q1S65:D@Q08DY@<@Q0<DY@<@Q00436<@Q1245:D248@01ABU6<HDYA2436<00Q24
00<<Ha2448@00aBU00D@Q1BU5:D@Q1BU008@Q00436<@Q12448@35:D348@25:D248@35:D248@65:D2
6<H148@0000800048@00124000@Q0008@P848@090008@RU:CW<e[B48:DX]JbU:00<U:@058@PU:BU:
<H`]J`03:DX00be[<H`]J`03:DX01Re[:DXYBRDY8@PU:@<YBP039BTYBRDY008YBP039BTYBRU:008U
:@8Q20039BT]JbU:00<YBPHU:@09:DXaS2U:8@PLibDY;F/YBRDY008YBP8]J`03:DXU:BDY008YBP03
8@PYBRe[008]J`<YBP068@PU:BU:;F/YBRDY0b4800<U:BU::DX00bDY00<YBRe[:DX00bU:0Re[00La
S2e[:DXYBRDY:DXaS002;F/012DY:DX]JcF]0SW>0RU:1R4800<U:BU::DX00b480bU:0RDY0RU:0be[
0S6<00H]JbU::DXYBR487>L28@P39BT2:DX49BT2;F/01c6<;F/YBRDY:DX]JbU:008U:@0>;F/e[C6<
:DXQ22DY:DX]JbU:9BTQ22DY;F/U:@LQ20039BTQ22U:008aS004:DXQ22DY:DX29BT01RU:;F/YBR48
7>LU:@<Q20047>LQ22489BT28@P37>L00bDY;F/YBP029BT01R489BTU:BDY8@PU:@8Q20049BTQ2248
9BT28@P01AcW8@PU:BU:9BT0124800@U:B489BTLi`HQ20047>LQ22487>L48@P27>L28@P00bDY7>LL
i`037>L26<H27>L56<H00acW8@PQ20037>L26<H25:D36<H27>L28@P37>L01AS67>LQ22489BT00R48
00DU:B487>LLibDY008Q20036<HLiacW00<Li`046<HDYABU5:D86<H27>L36<H27>L28@P37>L01AS6
7>LLiacW6<H00QcW00<Q21cW6<H011S60acW0QS60QcW00@HaQcW8@PLi`HHaP<Li`036<HLiacW008Q
20<HaP8Li`038@PLiacW008HaP8DY@036<HLiacW008Li`038@PLiacW008HaP055:DHaQS67>LHaP02
5:D011S67>LHaQS60QBU00@HaQcW6<HDY@8HaP035:DHaQ24008DY@8@Q0<DY@0448@DYAS66<H25:D0
11S67>LHaQS60QBU0aS60QBU0a2400HHaQBU5:D@Q1BU6<H25:D011245:DDYAS60a2400@DYA245:DH
aP8DY@8@Q0035:D@Q1BU00<@Q08DY@0348@DYABU008@Q0045:DHaQBU5:D248@011BU6<HDYA240aBU
0QS600<DYA245:D00QBU0Q2400HDYAcW9BTU:AcW5:D448@55:D011245:D@Q0aS0Q2400@DY@aS36<<
H`8@Q0035:D@Q124008DY@0448@<Ha2448@25:D01Q245:DDYA245:D@Q08DY@8@Q00436<@Q1245:D2
48@25:D011S65:DHaQBU0Q240PaS0Q240QBU0a2400<DYA2448@0112400<DYA2448@00QBU00<HaQBU
5:D00QBU00H@Q1BU48@@Q0aS48@26<H25:D248@25:D00aS65:DDY@0136<000P48@0:248000@Q248U
:Dic=JdLibU:;F/4:DX39BT012U:;F/aS2e[0RU:0be[0RDY0bU:0bDY0RU:0RDY0RU:0RDY12U:00@Q
22DY8@PU:@8YBP03;F/YBRU:00HU:@8YBP079BTQ22DY9BTYBRe[:DX00RDY00@YBRe[;F/YBP8U:@04
8@PU:BU::DX2;F/2:DX29BT4:DX00bDY8@PQ20028@P2:DX49BT4:DX2;F/01bU:;F/aS2e[:DXU:BU:
008]J`<YBP8aS004=JdaS2U:;F/29BT00b487>LQ20029BT38@P00bDY:DXU:@049BT2:DX7;F/2:DX0
12487>LLiacW0bDY12U:0RDY00DYBS6<<H`]JbDY008YBP8]J`03:DXU:Be[008e[@04;F/YBRU::DX2
9BT3:DX39BT00b489BTQ20058@P01be[<H`aS2U:8@PLibU:008U:@8]J`03:DXU:AcW00<Q208Li`@Q
20<Li`DU:@058@PU:BDY9BTQ20027>L29BT88@P49BT00b487>LU:@02:DX00b487>LQ20028@P00bDY
8@PU:@028@P00acW8@PLi`028@P29BT01B489BTU:B487>L00QS600<Q21S67>L00aS600DLiaS67>LL
iaS6008Q20079BTQ21S66<HLiaS65:D00QS600@LiaS66<HLi`<Q20046<HLiaS68@P37>L38@P47>L2
8@P47>L00aS67>LHaP036<H27>L46<H57>L00aS67>LHaP028@P00acW8@PLi`037>L011S67>LLiaS6
0QcW00@Q21cW7>LHaP8Li`@HaP047>LHaQcW6<H37>L36<H47>L011S65:DHaQS61AcW0QS600DLiaS6
7>LHaQcW00<HaPDLi`036<HLiaS6008Li`<HaP045:DHaQS67>L46<H011BU6<HLiaS60aBU0QS60aBU
0Q240QBU1AS60QBU00LHaQcW6<HDYA245:DHaP045:D348@45:D01AS65:D@Q1245:D00QS600LDY@aS
48@@Q1S65:D@Q0025:D011S65:D@Q1BU1A240QBU0a240aBU0Q2400<DYA2448@00aS60QBU00D@Q1S6
5:DLiaS6008DY@0348@DYABU008DY@046<HLibU:9BT26<H236<00a245:DDY@055:D548@00`aS48@<
H`0:48@75:D648@011BU48@@Q1BU0a2400@DYAS66<HDY@8@Q00336<@Q1BU008@Q00336<@Q124008D
Y@8@Q0045:D@Q1BU36<748@011BU48@@Q1240aBU0Q2411BU00@@Q1BU5:D@Q0<DY@4HaP4DY@4<H`00
00P000@Q124000@Q00048@Q20P@Q00H000Q2<HaJeSW>7>L2:DX38@P01RU:9BTYBRe[:DXaS08]J`03
:DXU:B48008Q2003:DX]Jbe[00<YBP03;F/YBRDY008U:@8YBP03;F/aS2U:00<U:@07:DXU:BDY9BTY
BS6<;F/00RU:124800<YBRDY:DX00bDY0R4800<U:Be[:DX00bU:00@U:BU::DXYBP8U:@8YBP8]J`8Y
BP039BTYBRU:008U:@<YBP058@PU:B489BTQ20039BT022489BTU:Be[:DX]JbU:;F/49BT3:DX2;F/0
1bU:;F/aS36<=JdaS2e[008YBP049BTYBRU:8@P26<H00acW9BTQ20027>L00b489BTU:@029BT3:DX0
0bDY:DX]J`02;F/29BT4:DX01RDY8@PU:BDY8@PU:@8]J`05:DXU:BDY;F/aS004:DX00be[:DXU:@02
:DX01be[<H`aS2U:9BTQ22DY00<YBP079BTQ22488@PU:BU:9BT00R4800DU:B488@PYBRe[008aS003
9BTYBRDY008Q20049BTYBRDY9BT27>L02b489BTYBRDY7>LQ22DY8@PU:AcW9BT00R480RU:00TU:AcW
8@PU:BU:9BTQ21cW9BT00QcW12DY0QS600@Lib48:DXU:@<Q20037>LQ21cW00DLi`@Q20037>LQ22DY
00<Q20047>LQ22DY8@P27>L29BT00b486<HLi`027>L36<H01AcW8@PLiacW6<H00QcW00DQ21cW8@PL
iaS6008DY@8Li`036<HLib48008Li`8HaP<Li`8HaP049BTYBRDY8@P26<H27>L00b487>LLi`047>L0
1QBU6<HHaR487>LHaP8DY@<HaP035:DHaQcW008Li`8HaP065:DQ22DY9BTLiaS60QcW00@HaQBU6<HL
i`<Q20057>LHaQS67>LQ20037>L36<H87>L46<H37>L012486<HHaQcW0R4800DLiaS66<HLiaS600<L
i`8HaP8DY@8HaP067>LHaQcW7>LQ21cW0QS600<LiaS65:D00QBU0QS600DLiaBU6<HHaQcW008HaP07
5:DHaQS66<HLiaS65:D00Q240QBU00<@Q1BU5:D00aBU00@HaQBU5:DDY@8HaP@DY@8HaP035:D@Q124
00<@Q0<DY@036<HDYABU00HDY@8@Q0HDY@056<H@Q1BU48@DY@0348@01aBU48@DYABU48@DYA2400<D
Y@066<HDYA2448@<Ha2411BU00<@Q1BU5:D00QBU00@@Q1BU5:DHaP@DY@047>LQ21S65:D248@01aBU
36<@Q1S67>LHaQBU00D@Q00436<@Q1BU5:D336<35:D031245:D@Q0aS48@DYAS65:D@Q1BU48@DY@<@
Q00536<@Q1246<HDY@0348@36<H248@010aS5:D@Q0aS0Q240aBU0Q240QBU0Q2400@<Ha245:DDY@L@
Q08DY@<@Q0<DY@<@Q08DY@8@Q0035:D@Q12400<DY@4<H`000P@Q00<000@Q12401P@Q00H8@S6<G_Lm
kaS69BT2:DX29BT00b48:DX]J`02;F/012U:;F/]JbU:0bDY00LQ22U:;F/aS2e[9BTYBP02;F/00bU:
9BTYBP02:DX3;F/01BDY8@PU:Be[:DX00R4800<YBS6<;F/00RU:00<Q22DY9BT00R4800DU:BU::DXY
BR4800<U:@04:DXaS2U::DX29BT012e[9BTU:BDY0RU:00DU:Be[;F/]JbU:008U:@<YBP049BTYBRDY
:DX38@P39BT00b487>LU:@02:DX00be[:DXYBP07:DX2;F/2:DX2;F/01CF]<H`aS2U:;F/012U:00@Q
21cW6<HLi`8U:@038@PLiacW00HU:@<YBP05;F/aS2U::DXU:@02:DX012DY8@PQ224812DY00PYBRe[
9BTU:BU:;F/aS2e[1BU:00PU:BU:;F/aS2e[<H`YBRe[12U:00<U:BU:9BT00R4800<U:BU:9BT00R48
0RDY00HLibU:;F/e[C6<9BT38@P01bDY:DXYBRU:9BTQ21cW008Q208U:@048@PLiacW8@P29BT00acW
8@PQ20029BT28@P012DY:DXU:BU:0acW00<Q22DY8@P00R480RDY0R4800@LibDY9BTQ20<Li`059BTQ
21cW7>LHaP027>L98@P27>L39BT27>L29BT011cW6<HHaR481acW0QS61QcW21S61acW00DHaQcW8@PU
:B4800<Li`8Q20037>LQ21cW00@Li`8HaP<Li`036<HDYABU008HaP8Li`8HaP067>LHaQcW6<HDYAcW
0R4800PLiaS67>LQ21S67>LHaR481QcW00@HaQcW7>LQ20@HaPPLi`<HaP037>LHaQS6008Li`048@PL
iacW7>L28@P00acW6<HHaP046<H27>L46<H01AcW6<HLibDY8@P00aS60acW00<HaQBU6<H02QS60QBU
00DHaQcW6<HDYA24008DY@036<HDYAS600@DY@046<HDYABU5:D36<H35:D01QS65:DDYA2436<@Q0<D
Y@8@Q08HaP<DY@036<HDYA2400@@Q08HaP055:DHaQ245:D@Q0065:D00aS65:DDY@035:D248@45:D2
48@00aBU48@DY@0248@00aS65:DHaP025:D00a245:DHaP025:D00a245:DHaP028@P011BU48@<H`aS
0Q2400<DYAS65:D00QBU00<@Q1BU5:D01Q2400<DYA2448@00a2400HDYAS648@@Q0aS48@55:D248@0
0aBU48@DY@0248@03PaS48@DYABU48@DYAS67>LHaQ2436<@Q0aS48@236<01A245:DDYABU48@00aBU
00<@Q1BU48@0112400@DYA2448@@Q08DY@0348@DYA24008@Q0<DY@8@Q08DY@<@Q08DY@0348@DYABU
004<H`0000D000@Q12448@0000L48@04:DYF]CW>7>L29BT00b489BTQ2002:DX00c6<;F/YBP03;F/0
12U:7>LQ22DY0S6<00DYBR489BTYBRe[008YBP04;F/YBRDY:DX3<H`02bU:9BTU:BU:;F/YBRDY:DXe
[C6<;F/00R4800DU:B48:DXU:BU:008]J`049BTQ22488@P4;F/29BT00bU:9BTU:@029BT3:DX022DY
:DXaS2e[9BTQ22DY:DX29BT28@P00bDY8@PQ20029BT28@P00acW8@PU:@039BT2:DX01Be[:DX]Jbe[
9BT00b4812e[0c6<0RU:0R4800@YBS6<9BTQ208HaP038@PLib4800<Q20099BTLiacW9BTYBRe[:DXU
:BU:00@]J`03:DXU:B48008Q20039BTQ22U:008YBP059BTQ22489BTYBP02;F/01C6<:DXYBRU:<H`0
0Re[00@U:B48;F/]J`8aS004:DX]JbU:;F/3:DX012DY8@PQ22DY0RU:00<U:B487>L00R480bDY00@Y
BR488@PLi`8Q20087>LQ22U:;F/YBR487>LQ20<YBP0:9BTQ22489BTQ22DY8@PU:B489BT28@P2:DX2
9BT00b487>LQ20038@P01BDY8@PQ22489BT00QcW00@Q22DY9BTU:@8Li`@Q20LLi`8Q20069BTQ21cW
6<HLib480RDY00DQ21cW8@PQ21cW00@Q20077>LQ21cW7>LHaQcW8@P00QcW00@HaQcW7>LLi`<HaP04
5:DHaQS65:D26<H00acW6<HHaP027>L021S65:DDYAcW9BTYBRDY7>L26<H37>L01AS67>LQ21cW6<H0
0QBU11S60QcW0QS60QcW0QS60acW0QS611cW00<Q21cW6<H00aS600<LiaS67>L011cW00HQ21cW7>LL
iaS68@P27>L00aS67>LHaP027>L28@P57>L00aS67>LLi`047>L26<H02B489BTQ21S65:DHaQcW6<HL
i`026<H00aBU6<HHaP026<H27>L00aS68@PLi`027>L46<H00aBU6<HDY@026<H00acW6<HHaP026<H3
5:D26<H00aBU6<HLi`026<H55:D248@45:D00aS65:DDY@035:D26<H35:D00a245:D@Q0075:D01A24
5:D@Q1BU48@00QBU00D@Q1BU5:DDYAS600dDY@036<H@Q124008@Q08DY@0648@DYA2448@DYA240QBU
00<@Q1BU5:D00a240QBU00P@Q1BU5:DHaQ245:D@Q1BU0aS60a2400<DYA2448@00QS600<DYA2448@0
0Q2400<<Ha2436<011240aBU0`aS00L@Q1BU48@@Q1BU48@DY@0248@35:D031245:D@Q12436<@Q0aS
48@DYAS65:DHaP<@Q00336<@Q124008@Q00536<DYABU6<HDY@0248@011BU48@<Ha240QBU0Q2400<D
YA2448@00Q240aBU00<@Q1BU48@00QBU1Q2400<DYA245:D01A240@aS00031240100012448@000PQ2
00L000@Q248YBU:D?NlQ20049BT02RU:9BTYBRe[<H`]Jc6<;F/YBRDY0R480bU:0RDY00DYBS6<;F/]
JbDY00<YBP05;F/aS36<<H`YBP029BT2:DX00be[9BT]J`02;F/02RU:9BTU:BDY8@PU:BU:;F/aS2U:
0RDY00<Q22DY<H`00S6<00<YBRDY:DX00RU:00@U:BU:;F/U:@8YBP03;F/aS2e[00DYBP069BTQ22DY
:DXQ21cW0R4800@YBRDY8@PQ208U:@05:DXU:BDY9BTYBP03;F/01BU:9BTQ22489BT00RU:00<]JbU:
;F/00S6<00<]JbU:9BT00RU:0RDY0b4800<Lib488@P01B4800<Lib489BT01BU:00@]JbU::DXYBP8U
:@@Q20@YBP049BTQ22DY9BT2;F/02C6<:DXU:BU:;F/aS2U:8@PYBP03;F/00bU:;F/YBP03;F/012U:
9BTU:B481BDY0b480RDY00@Q22DY9BTYBP<Q20<U:@03;F/YBRDY00<Q20039BTQ22DY00DU:@8Li`<Q
20079BTQ22489BTYBRDY8@P00QcW00DQ22DY9BTQ21cW008Q208U:@8Q208U:@8Q20037>LQ224800<Q
20036<HLiacW00@Li`@Q208Li`038@PU:BDY008Q20037>LQ224800<U:@8Q20036<HLiacW008Li`03
8@PHaQS6008HaP8Li`DHaP035:DHaQS600DLi`065:DHaQS66<HLib480RDY00<Q21S67>L011cW00<H
aQcW7>L00QS600@DYAS66<HHaP8Li`036<HLiaS6008HaP8Li`<HaP8Li`046<HLiacW8@P97>L00b48
7>LLi`028@P01BDY7>LHaQcW6<H02QcW0R480QcW00<HaQcW7>L011cW00<HaQcW7>L00QcW00LQ21S6
5:DDYAcW8@PLi`046<H02AcW6<HHaQBU6<HLibDY8@PLi`026<H01B485:DDYABU6<H00QcW0QS600DD
YAS66<HHaQBU00<HaP035:DHaQS600<HaP<DY@0448@DYABU48@36<H25:D36<H25:D26<H011BU48@@
Q1BU0Q240QBU00DHaQBU48@@Q1BU008HaP035:D@Q0aS008@Q0055:DHaQBU5:D@Q0035:D248@25:D2
48@25:D26<H01QBU48@@Q1245:D@Q0DDY@0348@DYA24008DY@8@Q0<DY@0348@DYABU00DDY@<HaP04
48@DYA245:D248@00aBU48@DY@025:D248@00`aS5:D@Q00348@25:D248@01ABU48@DYA2436<00Q24
0aBU0a2411BU112400@<Ha2448@DY@8HaP8DY@8@Q00336<@Q124008@Q08DY@066<H@Q1245:DHaQBU
0PaS00@@Q1BU5:D@Q0<DY@8@Q0055:DHaQBU48@DY@0248@00aBU48@@Q0035:D248@25:D248@00`aS
48@@Q00248@00003124000@Q00T48@079BU:DSF]7>LU:BU:9BT00RU:0Re[0RU:00DaS2e[<H`YBRDY
008YBP04;F/YBRDY9BT2:DX012e[:DXU:BU:0Re[00PYBRe[<H`aS2U:9BTYBS6<0RU:00lU:Be[;F/a
S2e[:DXQ22DY:DXQ22DY<H`e[Be[9BT00R480RU:0be[00HaS2U::DXU:B489BT28@P29BT3;F/01S6<
:DXU:BDY8@PU:@8]J`079BTLiacW8@PYBRDY7>L00b4800@U:BU:;F/YBP8U:@04:DX]Jbe[:DX79BT0
12U:<H`]Jbe[0RDY12U:0bDY0b4800<Lib488@P00RDY00DQ21cW8@PQ22DY00LYBP8U:@038@PU:BDY
008Q20059BTYBRU:9BTQ20027>L012DY;F/]Jbe[0RDY00DYBRe[:DXYBRDY008YBP8]J`HYBP@U:@05
8@PU:BU::DXU:@028@P00bDY8@PQ20048@P01AcW8@PQ22DY8@P00bDY00DYBR488@PQ22U:008U:@8Q
20@U:@<YBP8U:@8Q20<YBP049BTLiacW8@P29BT00b487>LLi`038@P39BT00b489BTQ20038@P011cW
8@PHaQcW0R4800DU:B486<HHaQcW00<Q208Li`DQ20057>LQ22487>LU:@02:DX012DY8@PQ22480aS6
0b4800HHaQcW7>LLiaS67>L46<H00aBU6<HHaP027>L36<H00aBU6<HLi`058@P27>L00aBU6<HLi`02
7>L36<H00acW6<HLi`027>L00aS65:DHaP036<H00acW6<HLi`026<H67>L01R487>LHaQS67>LHaP<L
i`8Q20037>LHaQS600DLi`038@PLiaS600<HaP<Li`<Q20<Li`038@PHaQcW00@Li`066<HLib488@PL
iaS60QcW00<Q21cW7>L00QS600DDYAS67>LHaQcW008HaP8Li`036<HLiaS600`HaPDDY@<HaP047>LQ
21cW6<H85:D01a245:DDYAS67>LHaQcW00@HaP035:DHaQBU00@DY@<@Q08DY@D@Q0055:D@Q12448@H
aP025:D00a245:DDY@0248@011BU6<HDYA240QBU00<HaQBU5:D00QBU0a240QS600<DYAS65:D00a24
21BU00@@Q1BU5:DDY@<@Q0045:DHaQS66<H45:D01A245:DDYABU6<H00QBU112400@<Ha2448@@Q08<
H`0348@DYA2400<@Q08DY@<@Q0045:DHaQBU36<548@236<548@011BU48@@Q1BU1a2400<HaQBU6<H0
0aBU00@@Q1BU5:DDY@D@Q0035:D@Q1BU008@Q0@DY@P@Q0<DY@8@Q0035:D@Q12400<@Q04<H`000P@Q
00@000@Q124000H48@049BU>LcW>7>L29BT00b48:DXYBP05;F/00c6<;F/YBP05:DX39BT3;F/012DY
:DX]Jbe[0RU:00<aS3F]:DX00RDY0bU:00L]JbU:=JdaS2e[:DXU:@02:DX29BT01Be[<H`aS2DY8@P0
12U:0Re[00<aS2e[:DX00R480bDY1BU:00<]JbU::DX00R4800@U:BU::DXU:@8Q20059BTYBRU:9BTL
i`028@P00be[:DXYBP03:DX012DY:DX]JbU:0R4800`U:BU:9BTU:B48;F/aS3F]<H`YBR489BT3:DX0
12DY7>LLibDY0b4800DLib488@PQ22DY008Q20047>LQ22DY8@P4:DX02bDY:DXYBRDY8@PLib489BTQ
22U:;F/00RU:00@Q21cW8@PYBP8]J`<U:@04:DX]JbU:9BT2:DX012e[:DXU:BU:0Re[00DU:B489BTU
:BU:00@U:@04:DXU:BDY8@P29BT00b489BTU:@028@P01AcW8@PU:B489BT00RU:0RDY0R4800DYBRDY
:DXU:B48008U:@8Q20049BTYBRDY:DX49BT3:DX012DY8@PLib480RDY0R4800PLibDY7>LHaR489BTY
BRDY0QcW1R480acW00@Q21cW8@PLi`<Q20057>LHaQcW8@PU:@038@P27>L38@P29BT012U:9BTQ22DY
11cW0R481QcW0aS60QBU00LHaQcW7>LLiaS67>LHaP025:D041cW9BTU:AcW8@PU:B487>LHaQBU7>LH
aQcW8@PHaQcW0aS60acW00@HaQBU5:DDY@8HaP047>LHaQS66<H37>L00aS67>LQ20026<H00aBU6<HH
aP037>L012487>LLiacW0QS60QcW0QS60R4800<LiaS66<H00aS600LLib488@PQ21cW8@PHaP047>L2
8@P00acW6<HHaP057>L28@P00bDY8@PHaP026<H00aBU7>LHaP037>L26<H47>L76<H00acW6<HHaP02
5:D26<H55:D26<H00b487>LHaP056<H00aBU6<HDY@025:D46<H011BU6<HDYAcW0QS600<@Q1BU5:D0
0QS60aBU0QS60aBU0Q2400<DYA2448@00QBU0QS61ABU00L@Q1BU5:DDYAS65:DHaP025:D011S65:DD
YAS60Q240QBU0QS600<@Q1BU48@00Q2400@DYAS65:DDY@8@Q0DDY@0348@DYABU008DY@046<HDYABU
48@25:D248@011BU6<HDYABU1a2400<DYA2448@00Q240aBU00<@Q0aS48@00QBU0a2411BU00D@Q1BU
5:DDYA24008<H`8@Q08DY@0448@DYABU5:D348@010aS48@@Q1240QBU0QS600<DYA2448@011BU0a24
0aBU00D@Q1BU5:DDYA2400@DY@8@Q0045:D@Q1BU48@35:D00aS648@@Q00248@00aBU48@<H`012480
000500048@@Q1240000512402@00248U:DHa;F/HaRDY;F/YBP02;F/5<H`01Be[:DXU:B48;F/00S6<
00<]Jb488@P00bU:0Re[00<YBRe[:DX00be[00<YBRe[:DX00RU:00<U:BU::DX00be[00/U:BU:8@PQ
22DY;F/aS2e[:DXU:BU:008Q2005;F/aS36<:DXU:@03:DX38@P012DY;F/]JbU:0be[0bU:0bDY0RU:
00@U:B488@PU:@8Q208Li`049BT]Jc6<;F/2:DX00c6<:DXYBP038@P39BT28@P012DY:DX]Jc6<0RU:
00<U:B489BT00RDY0R4800<U:B488@P00R4800DLib488@PQ22DY008Q20<U:@@YBP039BTYBRU:008Q
20047>LQ22DY9BT2:DX022DY:DXU:AcW8@PYBS6<9BT28@P3:DX29BT012487>LU:BU:0be[0RU:00<U
:B489BT00RDY0R4800@U:BU:;F/U:@8Q20047>LQ22U:9BT58@P011cW8@PLib480bDY00<Q21cW8@P0
0bU:00<]JbDY8@P00QcW0bU:00@]JbU:9BTYBP<U:@03:DXU:BDY00@U:@057>LQ22488@PLi`038@P4
9BT28@P011cW8@PQ21cW0R480RDY00TQ21cW6<HQ22DY7>LHaQBU7>L00b4800<LiaS67>L00R480QcW
0R480bDY00@Q21cW6<HHaP8Li`059BTQ22488@PHaP027>L26<H011BU6<HDYAS60QcW00hHaQBU5:DH
aQcW5:DHaQcW8@PLiaS67>LQ21cW11S611cW00@HaQcW8@PQ208Li`035:DHaQBU00@HaP037>LHaQS6
00<Li`8Q208HaP095:DHaQcW6<HLiaS67>LHaQcW008Q20@Li`<HaP037>LQ2248008HaP067>LHaQcW
6<HDYAcW0R480aS61QcW0QS600LLib487>LLiaS67>LQ20027>L011S65:DHaQS60QcW0aS600<LiaS6
6<H00aS600<LiaS66<H01QS611BU00@HaQBU5:DDY@<HaP@Li`@DY@8HaP@DY@THaP8DY@0448@DYABU
5:D248@011BU48@@Q1240aBU0Q2400@DYA2448@HaP<DY@8@Q08DY@036<HDYABU00LDY@8HaP035:DH
aQBU00<HaP8DY@<@Q0@DY@8@Q08DY@8@Q08DY@8@Q0045:DHaQS65:D248@35:D011S65:D@Q1240aBU
00<@Q0aS36<00a2400@<Ha2448@@Q08DY@0348@DY@aS00<@Q0035:DHaQBU00<DY@<@Q00436<@Q124
5:D348@010aS5:D@Q1BU11240PaS0Q240QBU00<HaQBU5:D011BU00<@Q1BU5:D00aBU0Q2400<DYA24
5:D00Q2400@<HaBU6<HDY@<@Q0045:D@Q12436<348@35:D348@25:D148@136<000<48@0300048@@Q
00H48@078@Q6<C6<7>LQ22U:;F/00S6<00<]Jc6<<H`00S6<00D]Jc6<:DXU:BU:008aS003:DXLibDY
00@YBP8]J`03:DX]Jbe[008]J`049BTYBRe[;F/2:DX00bDY:DX]J`02:DX49BT2:DX3;F/03RU:9BTQ
22DY;F/aS2e[:DXU:BU:;F/YBRDY7>L28@P00be[<H`YBP02;F/2:DX00bDY:DXYBP079BT02R489BTU
:B486<HU:BU:<H`]JbU:0Re[00DaS2e[9BTU:B4800<U:@048@PLibDY:DX2<H`00be[9BTU:@029BT3
:DX00bDY8@PU:@028@P01AcW6<HLiacW9BT0124800@U:BU::DX]J`DYBP8U:@8Li`039BTYBRU:008U
:@05:DXU:AcW7>LU:@02;F/00bDY8@PU:@089BT01be[<H`]Jbe[:DXU:B4800<U:@<Q2006:DX]JbU:
9BTLib480bDY11cW00<Q22DY8@P00b4800<YBRDY9BT00R4800PYBRDY;F/]JbDY8@PLiaS60RDY12U:
12DY00<Q22DY:DX00RU:00DQ21cW8@PQ22DY00<Li`038@PU:BDY008Q20039BTQ224800<Q20069BTQ
22489BTYBRDY0R4800<Lib487>L01acW00@Q21cW7>LHaP<Q20039BTQ22DY008Q208Li`096<HLiacW
8@PU:AcW8@PLiaS6008Li`<HaP8DY@<Li`036<HDYABU008HaP8Li`038@PLiacW00@Li`<HaP@Li`8H
aP037>LQ2248008HaP035:DHaQS600LHaP077>LQ21cW7>LHaQBU6<H00QcW00DHaQBU6<HLib4800<L
i`8HaP077>LQ22486<HDYAS68@P00QcW0QS600<DYAS66<H01QcW0QS60QcW00<HaQcW7>L00R4800<L
iaS66<H00QS600LQ21cW7>LLiaS65:DHaP037>L26<H01QcW8@PLiaBU6<HDY@HHaP8Li`8HaPXDY@05
6<HLiacW7>LHaP035:D00aS65:DHaP0248@00aBU6<HHaP036<H011cW6<HLiaS60aBU00@HaQBU5:D@
Q0@DY@<@Q08DY@@@Q0045:D@Q1BU5:D248@35:D00a245:DHaP035:D56<H35:D36<H00aBU6<HHaP04
48@00aBU48@DY@035:D248@00aBU48@@Q00248@00aBU6<HHaP0;5:D348@236<448@236<25:D011S6
48@<H`aS0QBU00H@Q1BU5:DHaQBU48@25:D011S65:D@Q0aS0Q240QBU2A2400<<Ha2448@00a2400@D
YAS66<HDY@<@Q0PDY@0648@<H`aS5:D@Q1BU0Q2400<DYA2448@0112400<DYA2448@00Q240QBU1124
0ABU0A240@aS00000`001240000312403@0024848@001248@R48AS4aS1cW:DX]Jc6<008e[@03<H`]
Jbe[008]J`07:DXU:BDY9BTYBRe[<H`00Re[00DYBRDY9BTYBRe[00DYBP03;F/YBRe[008YBP8]J`@Y
BP048@PLiacW8@P39BT01Re[<H`]JbDY8@PU:@8YBP04;F/YBRU:;F/2:DX01B489BTYBR489BT00RU:
00<aS3F];F/00RU:0Re[00<U:B48:DX00bU:00@Q22DY9BTU:@<Q20059BTYBRe[:DX]J`03:DX29BT3
8@P022DY8@PQ22DY8@PU:BU:;F/2:DX49BT2:DX48@P29BT00b487>LQ20028@P00bDY:DXYBP029BT2
:DX01bDY:DX]Jbe[:DXU:AcW008U:@8YBP8U:@03:DXU:BDY008Q200@9BT]Jc6<:DXQ21cW9BTYBRDY
8@PU:B487>LQ22DY;F/2<H`00be[:DXQ20028@P00bDY:DXU:@0;9BT28@P27>L012489BTU:BDY0R48
00<Lib488@P00R4800TYBRe[9BTQ21S67>LQ22DY:DX00RDY0bU:0RDY00@YBR488@PQ208YBP039BTQ
2248008Q20059BTQ21cW9BTYBP029BT01QcW8@PU:BU:9BTQ208Li`058@PYBRDY9BTLi`039BT01R48
5:DHaQcW6<HLi`<Q20057>LHaQcW7>LQ20037>L012489BTLib480acW0R480acW00<Q21cW7>L00QcW
0QBU00HHaR487>LDYAS67>L26<H01A246<HHaQBU6<H00acW00<HaQcW6<H00QcW00<Q21cW7>L011cW
12480QS600<DYAS65:D00aBU0QS600@LiaS66<HHaP@Li`8HaP047>LHaQS66<H27>L012486<HHaQS6
0acW00<Q21S67>L00aS60QcW0QS60QcW0QS60QcW00<Q21cW7>L01AcW00<HaQcW8@P00QcW00<HaQcW
8@P00QcW00@Q21S66<HDY@8HaP8Li`036<HLiaS600<Li`8HaP035:DHaQS6008Li`@HaP045:DHaQS6
5:D26<H01ABU6<HDYABU6<H00QBU0aS60QBU11S600<DYAS65:D00QS600LLiaBU5:DDYAS67>LDY@04
6<H25:D00aS648@@Q00248@55:D348@00aBU48@DY@025:D00a245:DDY@026<H00aBU48@DY@025:D0
0aS65:DHaP035:D36<H35:D26<H348@00aBU6<HDY@0248@00aBU6<HDY@0248@00aBU48@DY@035:D2
6<H55:D36<H021BU6<H@Q12436<@Q1BU48@336<548@01ABU48@<H`aS5:D011S600<LiaS65:D00Q24
00<HaQBU5:D00PaS00<@Q1BU48@00Q2400HDYA2448@<Ha245:D248@336<55:D348@55:D248@25:D0
0aS65:DDY@0248@35:D0112436<@Q1BU0Q2400H<Ha2448@@Q0aS48@236<00a245:D@Q0025:D248@1
36<000@48@0300048@@Q00D48@0<8@Q:DS6<8@PYBS6<;F/aS2e[<H`]JbU:0be[00<YBRDY:DX01bU:
0bDY00@YBRe[:DXYBP<]J`<YBP03;F/YBRe[00<YBP<U:@038@PU:BDY00DYBP8U:@03:DX]Jbe[00DY
BP049BTQ22489BT2:DX5;F/2:DX00bDY:DXYBP02:DX39BT00b489BTU:@037>L00b48;F/]J`03:DX3
;F/00bU:8@PLi`028@P01RDY8@PQ2248:DX]J`8YBP<Q20<U:@03:DXU:BDY00LU:@8Q20099BTYBRU:
:DXU:BU:9BTQ22U:008]J`049BTLiacW9BT2:DX39BT01bU:9BTU:B487>LU:BU:008]J`038@PU:BU:
008YBP048@PLib488@P29BT01Be[<H`]Jbe[:DX00b4800<U:BU:9BT01BDY0RU:12DY00@Q21cW6<HH
aP8Q208U:@058@PLib487>LQ20029BT01BU:9BTQ22487>L00R4800<U:BU:9BT00bDY00HYBRDY9BTY
BR487>L28@P01BU:9BTQ22489BT00b4800DLibDY9BTYBRDY00<Q208U:@<Li`8U:@04:DXQ22488@P2
:DX00b486<HHaP026<H27>L00b487>LLi`026<H38@P00acW6<HQ20029BT37>L28@P01acW6<HLib48
9BTQ21S600<Li`<HaP037>LHaQS600@HaP095:DHaQS66<HLib487>LHaQBU00@Li`058@PLiacW6<HL
i`038@P00bDY8@PLi`046<H35:D56<H47>L011S67>LLiacW0aS600LDYAcW7>LQ21S65:DHaP028@P3
6<H37>L36<H011cW6<HLiaS62AcW0QS61acW0aS60QcW00DHaQBU5:DLiaBU00<HaP038@PLiacW008H
aP085:DHaQS66<HLiaS67>LQ20<HaP035:DHaQS600<HaP8@Q0<HaP035:DHaQS600HHaPDDY@<HaP07
5:DHaQcW7>LHaQBU48@011BU0a2400H<Ha2448@@Q1BU6<H548@00aBU48@@Q0035:D011S65:DDYAS6
0Q240QBU00PHaQBU5:D@Q1BU6<HLiaS60QBU00<LiaS66<H00QBU00<@Q1BU5:D00QBU0a2400<DYAS6
5:D00Q2400LDYA2448@@Q1BU6<HDY@026<H00aBU6<HHaP045:D848@236<348@010aS48@@Q1BU0Q24
00H<HaBU6<HDYAcW6<H27>L00a245:D@Q00348@236<748@336<00a245:D@Q00248@00`aS5:DDY@04
5:D348@25:D248@45:D248@01QBU48@DYABU48@DY@<@Q08<H`0348@DYA24008@Q00736<@Q1BU5:D@
Q0aS5:D00QS60A240@Q200000`0012448@0212400`001248@P0412401RU:CW<icRDY;F/e[@<aS003
;F/YBRe[008YBP8U:@03:DX]Jbe[008U:@`YBP03;F/YBRU:008]J`8aS003:DXU:B48008U:@<Q2003
9BTYBRe[00@]J`@YBP03;F/YBRU:00<U:@8YBP8U:@06:DXU:BU:<H`icS6<0R4800<YBS6<:DX012U:
0bDY00DQ22DY7>LLibDY008]J`HYBP<Q20039BTQ21cW008Li`069BT]JbU:8@PLib480RDY00LYBRDY
9BTU:B48:DXU:@028@P00acW8@PYBP03:DX39BT00bU:9BTYBP039BT3:DX00bDY8@PQ20039BT022U:
9BTU:BU:9BTLib489BT2;F/00bU:8@PU:@028@P01RDY8@PQ22487>LQ208YBP<]J`8YBP8U:@@Q2006
9BTYBRU:9BTQ22DY0Re[00<YBRDY8@P00R4800DLib488@PQ22DY008YBP8Q20039BTYBRDY00@Q20<L
i`@U:@<YBP@U:@04:DXU:BDY:DX29BT58@P59BT38@P29BT58@P29BT012487>LQ22DY0R4800@HaQBU
6<HLi`8U:@8Li`036<HLiacW00<Li`056<HLib489BTQ20026<H00b487>LLi`027>L46<H01AcW6<HL
iaS67>L00QS60acW00<HaQBU5:D00QS600<LiaS67>L00QcW11S600DQ21cW7>LLiaS600<Li`8Q2004
7>LQ21cW7>L36<H25:D011245:DHaQS60QBU0QS611cW0aS600DLiaBU6<HHaQcW00<HaP8Q20<Li`<H
aP8Li`<HaP@Li`<HaP067>LQ22489BTLiaS60QcW0b4800<LiaS67>L00QcW00<Q21cW7>L00aS60QcW
00<HaQBU5:D00acW1QS600<LiaS68@P00acW00DHaQBU6<HLiaS600DDY@@HaP045:DHaQS66<H35:D2
6<H25:D36<H00acW6<HLi`025:D00aS65:DDY@025:D01QS65:DDYA2436<DY@@@Q0075:D@Q1BU5:D@
Q1BU48@00aBU00<@Q1BU6<H00QS600<DYAS66<H00aS600<DYAS66<H00QS600<LiaS66<H00aBU0QS6
00H@Q0aS48@@Q1BU6<H25:D00a245:DDY@025:D01a2436<@Q1BU6<HLiaS6008DY@0448@DYAS65:D3
6<H25:D01A245:D@Q1BU48@00`aS1A240QBU0a2400DHaQBU48@DYAS6008Li`045:D@Q1BU48@25:D7
48@00aBU48@<H`0348@236<448@00aBU48@@Q0085:D248@65:D01AS65:DDYA245:D0112400<DYA24
48@00Q2400<DYA2448@01A2400<DYA245:D00QBU0@aS000312400`0012448@0412401`00248YBU:D
>LhQ236<008e[@03<H`]Jbe[008YBP049BTYBRU:9BT4:DX01bDY:DXYBRU:9BTYBRe[008YBP049BTY
BRe[;F/4:DX01C6<=Jd]JbU:9BT00b4800<U:B488@P00RDY00@YBRe[;F/]J`8YBP8U:@8YBP8]J`<U
:@04:DXQ22DY9BT3:DX02CF]>LhaS2U:8@PYBRe[:DXU:@02:DX012DY8@PQ22DY0R480QcW00@Q22DY
;F/]J`HU:@8Q20069BTLib488@PLibDY0bU:00@LiaS68@PU:@8YBP059BTLib488@PYBP029BT00b48
9BTYBP02;F/49BT00bU:;F/U:@029BT00b48:DXYBP039BT00b489BTU:@03:DX29BT011cW8@PU:BU:
0Re[00@YBR488@PQ208U:@038@PLiacW008U:@03;F/YBRDY008]J`05:DXU:BDY:DXU:@028@P39BT0
1B48:DX]JbU:9BT00RU:00TU:B487>LLib487>LQ21cW9BT00bU:0RDY0RU:00<U:B488@P00QcW0b48
0RDY00@YBRDY9BTYBP8U:@<Q20057>LU:Be[<H`YBP027>L00b487>LQ20029BT012e[:DXQ22480RDY
00<YBRDY8@P01B480RDY0R4800HU:B487>LHaQBU7>L29BT012487>LDYAS611cW00@HaQcW7>LU:@8Q
20056<HLiacW6<HLi`026<H00acW6<HHaP027>L36<H00acW6<HLi`066<H01aBU7>LHaQS65:DHaQcW
00<HaP8Li`8Q20<Li`8Q20057>LQ22DY8@PLi`026<H011BU6<HDYABU11S60QBU0QS600@Q21S66<HH
aP8Li`DHaP8Li`036<HLiacW008HaP@Li`066<HLiacW7>LHaQBU0QcW00<Q21cW7>L00QS600HQ21cW
8@PQ21cW8@P97>L02R489BTQ21cW6<HDYAS67>LQ21cW0QBU00<HaQcW6<H00QS60QBU0aS600DLiaS6
7>LHaQcW00<HaP8DY@THaP@DY@LHaP035:DHaQS6008HaP045:DHaQS66<H65:D00a245:DDY@0448@2
5:D348@00aS65:D@Q0025:D01A245:DDYAS65:D00QS60QBU1AS600<LiaS66<H00QBU00LHaQBU6<HH
aQBU6<HDY@0348@01ABU48@DYA245:D00Q240aBU0Q2400@<HaBU6<HHaP8DY@0348@DYABU008DY@<H
aP8@Q00336<@Q12400<<H`0548@DYABU48@<H`0248@45:D248@56<H25:D011245:DDYABU0a240PaS
1A2400<DYA2436<00PaS1Q2400HHaQBU6<H@Q0aS48@35:D348@35:D00a245:DDY@035:D348@01QBU
36<@Q1245:D@Q08<H`8@Q08DY@0448@DYABU48@25:D248@136<00008124000@Q124000@Q0008@P@4
8@07:DYF]CW>9BTaS3W>=Jd00S6<0be[0RU:0Re[0S6<00DYBRDY:DXYBS6<008YBP04;F/aS2e[;F/3
9BT3:DX01Be[<H`aS36<;F/00RU:00DQ22DY8@PQ22DY00<YBPD]J`8aS008:DXU:BU:;F/aS2e[9BTY
BP@U:@04:DX]Jc6<<H`4:DX29BT3:DX00b489BTQ20037>L012489BTQ22U:0Re[00LU:B48:DXYBRDY
8@PLi`038@P00bDY8@PU:@039BT27>L012487>LQ22480bDY0R4800PU:BU:9BTLibDY;F/aS2e[0RDY
00<YBRDY9BT00bDY0R4812DY0R480RDY00HQ21cW9BTYBRe[:DX29BT01BU:9BTU:B487>L00b4800HU
:AcW7>LHaQcW9BT2:DX4;F/49BT01R486<HQ22DY;F/YBP8U:@<YBPDU:@058@PLib488@PU:@06:DX0
1BDY8@PU:B487>L01B480RU:1RDY0b4800PU:BU:9BTU:B489BTQ22DY0R4800@YBRe[:DXYBP@U:@06
:DXU:B488@PU:B480RDY0R480RDY00LQ21cW6<HHaQcW8@PU:@028@P26<H00acW8@PQ20036<H00acW
8@PLi`027>L00b486<HLi`027>L28@P00acW6<HLi`037>L01QS67>LLib487>LQ20<Li`076<HDYAS6
6<HQ21cW6<H00QcW0QBU00@Lib489BTQ20<Li`8HaP037>LU:AcW00@Li`HHaP037>LHaQS6008HaP<L
i`058@PLiaS67>LHaP037>L011S67>LHaQS60acW00<Q21cW6<H00QcW00<HaQcW7>L00QcW0QS611cW
0QS600PDYB488@PQ21cW6<HLib481QcW00DQ21cW8@PLiaS600<Li`046<HLiaS67>L26<H00acW6<HH
aP025:D00acW6<HHaP037>L26<H37>L36<H00acW6<HHaP025:D00aS67>LLi`026<H01QBU6<HDYABU
6<HDY@8HaP035:DHaQS600<HaP037>LHaQS6008HaP035:DHaQBU008DY@8HaP045:D@Q1BU5:D248@3
5:D011245:DHaQS61QBU0aS60QBU00<HaQcW7>L00aS60QBU00HHaQcW7>LHaQBU6<H25:D448@011BU
6<HHaQBU0Q240QBU0Q240QBU00<@Q1BU5:D00QS60aBU00H@Q1BU5:DDYAcW6<H25:D00a245:D@Q002
48@236<00a245:DHaP0548@25:D00a245:DDY@0248@26<H01AcW5:DDYA246<H00QBU1A2400@<Ha24
48@DY@8@Q0055:D@Q12436<@Q0065:D448@01aBU48@DYABU48@DYA2400@DY@0548@DYAS66<HDY@02
48@00aBU48@DY@0348@25:D248@45:D00a2436<@Q0045:D148@136<000848@0300048@@Q00<48@0=
248000@Q248YBUJe@Q0U:C6<=JdicS6<;F/00RU:0Re[00LYBRe[<H`aS2U:8@PU:@03:DX00be[:DX]
J`02;F/2:DX00bDY:DXYBP02:DX01Re[<H`e[C6<;F/YBP8U:@038@PU:BDY00@YBP03;F/YBRe[008a
S08]J`8Q2004:DXaS2e[;F/29BT3:DX01bDY:DX]Jc6<;F/YBRDY00DYBP039BTYBRDY008Q20087>LQ
21cW7>LQ22DY;F/YBPDU:@048@PLiacW7>L39BT28@P29BT28@P00acW8@PQ20039BT88@P012DY:DXa
S2e[0bDY0R480bDY0R480bDY0R4812DY00@Q22DY:DXYBP8U:@<YBP<Q20037>LQ21cW00<Li`049BTL
ibDY:DX2<H`00bU:;F/YBP029BT01b489BTQ21cW9BT]JbU:008Q20039BT]Jbe[008YBP<U:@048@PL
ib487>L29BT012U:;F/YBRU:0bDY0R4800<Lib488@P00acW12DY0R4800DYBRDY9BTQ21cW008U:@8Y
BP<Q208U:@8Q20039BT]Jbe[008U:@048@PU:BDY:DX29BT28@P29BT28@P49BT011cW6<HLiacW0RDY
00@Q21S66<HHaP8Li`DHaP037>LQ21cW00HLi`8Q20067>LHaQS66<HQ21cW0QS60QcW00DU:B487>LH
aQcW00@HaP<Li`036<HDYA24008HaP8Q208Li`058@PHaQcW7>LQ20027>L01AS67>LQ21S65:D00aS6
00<DYAS65:D00QcW0QS60QcW00<Q21cW7>L00QS600<LiaS66<H00QcW00<HaQcW6<H00QcW00<Q21cW
5:D011cW00<DYAS67>L00acW00<HaQcW7>L00QS600@DYAS67>LQ208Li`036<HLiacW00<Li`048@PL
iacW7>L26<H011cW8@PU:AcW0aS600DLiaS67>LLiaS6008DY@<HaP<Li`PHaP037>LHaQS6008DY@8H
aP037>LHaQS600<HaP8DY@0348@DYAcW008HaP035:DHaQcW00@HaP<DY@8HaP<DY@056<HDYABU6<HD
Y@0348@011BU48@DYA240aBU0aS60QBU00<@Q1S66<H00QS60QBU1QS60QBU00@HaQcW7>LHaP<DY@05
48@DYA245:D@Q0055:D448@26<H011BU48@@Q1BU0QS600<DYA245:D00Q240QS60QcW00@DYA2448@@
Q08DY@8<H`8@Q00336<@Q1BU008DY@0448@DYABU5:D248@25:D01AS65:DHaQBU6<H00a240aBU00<<
Ha245:D0112400<DY@aS48@00a2400<<Ha2448@01A240QBU00<<Ha2448@00QBU00D@Q1BU5:DHaQBU
00<@Q08DY@D@Q0<DY@0448@DYA2448@236<248@55:D648@136<0000500048@@Q1240000712403BU:
E[E242DY=JdaS2U:;F/aS3F]<H`]JbDY00D]J`06:DXU:BU::DX]JbU:0Re[00DaS2U:8@PQ22DY008Y
BP8aS005>Lhe[Be[<H`]J`02:DX29BT022U:9BTQ2248:DXU:C6<;F/4<H`00be[:DXYBP029BT012U:
9BTU:BDY0RU:0Re[00LYBS6<<H`]JbDY8@PU:@02<H`012U:9BTQ22480bDY00@Q21cW6<HQ20@U:@04
7>LQ22488@P27>L29BT022U:8@PQ22DY;F/YBR487>L28@P01AcW6<HQ22U:9BT00b481RDY00TYBRe[
:DXYBRDY8@PYBRDY8@P012DY0R4800@U:BU:9BTU:@8Q20059BTQ22488@PYBP039BT2:DX29BT48@P2
7>L011S67>LQ22U:0Re[00DYBRe[;F/YBRDY008Q20049BTQ22DY9BT28@P29BT4:DX01be[:DXU:B48
9BTQ22DY008Q208U:@8YBP8Q20@U:@<Q20DLi`049BTYBRDY7>L49BT012489BTU:BU:0RDY0R480RDY
00<Q22DY9BT00RDY00DQ21cW7>LQ22U:00<U:@<Q200@7>LU:B487>LQ22U:8@PLiaS68@PU:BU:9BTQ
22DY8@P27>L01B486<HHaQBU7>L00RDY00@LiaBU6<HLi`8U:@<Li`8Q208Li`0=6<HLiacW8@PLiaS6
7>LU:BU:;F/Q21S65:D00QcW00<Q21cW6<H00QS60QcW0QS60QcW00@Q21cW5:DDY@8Li`048@PLiacW
6<H37>L36<H27>L011BU6<HLiacW0QS60acW00HDYAS67>LQ21cW6<H27>L00aS67>LHaP028@P01acW
8@PLiaS67>LDYAS6008Li`048@PLiacW6<H37>L00aS67>LHaP027>L26<H57>L38@P27>L00aS67>LL
i`047>L01AS67>LLiacW6<H00QcW1AS600<DYAS67>L011cW0aS60QcW00HHaQcW6<HHaQBU6<H27>L0
1QS65:DLib487>LDY@@HaP035:DHaQS6008HaP045:DHaQS67>L46<H00aBU48@@Q0036<H01A245:DD
YABU6<H011BU00@HaQ245:DDY@8HaP035:DHaQBU008DY@<Li`036<HDYAS6008Li`038@PLiaBU008H
aP037>LHaQ24008DY@<HaP0548@DYA2448@DY@0248@25:D00aS65:DDY@035:D448@011BU6<HHaQS6
1ABU00@Lib486<HDY@8@Q0066<HDYABU48@DY@aS0Q240aBU0a2411BU00<@Q1BU6<H00aS600<DYA24
5:D00QBU00<HaQ2436<00PaS1Q2400<DYA2448@00Q240aBU00<HaQBU5:D00Q2400<<Ha2448@00Q24
0aBU00<HaQBU5:D00QBU00D@Q1BU5:D@Q1BU00T@Q0<DY@@@Q00436<@Q1245:D248@35:D148@136<0
00<48@0300048@@Q00@48@0600048BDYF]I242e[0S6<0Re[00@aS3F]=Jd]J`8YBP04;F/aS36<;F/4
:DX4;F/01RU:9BTQ22DY:DX]J`8YBP04<H`e[CW><H`2;F/02bU:;F/YBRU:8@PU:B489BTQ22DY:DX0
1C6<0Re[00@YBRDY9BTU:@8YBP069BTQ22U:;F/YBRe[0S6<00XYBRDY9BTYBS6<=Jd]JbU:7>LQ208U
:@038@PLiacW008Li`049BTYBRU:9BT27>L28@P012DY8@PLiacW0bDY0bU:00<U:AcW8@P00acW00@Q
22DY:DXQ208Li`8Q208U:@DYBP8U:@8Q20039BTYBRDY008Q20049BTYBR488@P39BT28@P01RDY8@PU
:BU:9BTYBP8U:@05;F/U:BDY8@PLi`028@P01bDY7>LLiaS67>LU:B4800@]J`<YBP048@PU:AcW8@P3
9BT01B489BT]Jbe[:DX00RDY00<YBRDY8@P00bDY0R480bDY0R481BDY00<Q22DY8@P00acW0R480RDY
00<Q22DY:DX00RDY0R4800DU:B489BTYBRDY008Q20@U:@088@PU:BDY:DXU:AcW8@PU:@8YBP038@PU
:BDY00<Q20037>LQ2248008Q20037>LHaR48008U:@048@PLib489BT37>L00b487>LHaP027>L01B48
7>LHaQS67>L0124811cW00@Q21cW7>LHaP8Li`098@PHaQS69BT]JbU:7>LDYAcW00<HaP068@PLiaS6
5:DHaQcW0aS60QcW00<HaQBU6<H011cW00<HaQcW8@P00QcW00<HaQBU5:D00QS60QBU11cW0QS61QcW
0R480QcW00DHaQcW7>LLib4800<Li`@HaP8Li`<HaP038@PLiacW008Li`@HaP<Li`8HaP@Li`038@PL
iacW008Li`8Q20047>LHaQcW8@P27>L00aS67>LHaP037>L46<H00acW6<HLi`047>L00aS67>LHaP02
7>L26<H011BU7>LLiacW0aS60acW00XDYAS65:DDYAS65:DHaQBU6<HLi`8HaP<DY@056<HDYABU5:DH
aP045:D00aS65:DDY@0448@45:D36<H00aBU48@DY@046<H01ABU6<HHaQBU6<H00QcW0QS60QcW0QBU
0Q240aS61ABU0Q240aBU00H@Q1BU48@DYAS65:D548@25:D26<H25:D00a246<HHaP027>L00aS648@D
Y@0348@25:D248@01@aS48@@Q1245:D00Q2400HDYA2448@@Q1BU6<H35:D36<H25:D348@01ABU48@<
Ha2436<03A2400<DYAS65:D00QBU0PaS0Q2400<DYA2448@00QBU00@@Q1BU48@DY@8@Q0<DY@@@Q004
5:D@Q1BU48@25:D348@00aBU48@@Q00248@011BU48@@Q1240QBU0A240@aS00000`00124000031240
0`0024848@0212401`Q2;F]Nmd8@8@P]Jc6<00<]J`03<H`]Jbe[008e[@03>Lh]Jbe[008aS003;F/Y
BRe[00<aS003;F/YBRDY00@YBP039BT]Jc6<008aS007:DXU:BU:;F/aS2e[:DX00R4800DU:BU:;F/Y
BRe[008e[@09<H`YBRDY:DX]Jc6<;F/YBR4800<U:@8YBP03;F/aS2e[008YBP089BTYBRU:9BT]Jc6<
;F/YBP8Q20<U:@8Li`049BTYBS6<:DX38@P00bDY:DXU:@038@P012DY:DXYBRU:0Re[00<YBRDY8@P0
11cW0b4800<U:B488@P00bDY0R4800@U:BU:9BTQ208U:@8Li`038@P]JbU:008Q20039BTYBRDY008Q
208U:@048@PU:BDY9BT38@P2:DX01RDY8@PQ22489BTQ20LLi`8U:@0;:DX]JbU::DXU:B489BTQ22DY
8@PLi`029BT012U:9BTQ22DY12U:00D]JbDY9BTQ22DY008Li`058@PU:BU:9BTQ20039BT00b487>LQ
20028@P47>L29BT28@P49BT48@P29BT38@P29BT28@P01RDY8@PU:BDY8@PLi`<Q20039BTYBRDY00<L
i`049BTQ22488@P39BT27>L012489BTYBRDY0QcW00<HaR488@P011cW0R480QS600<Lib489BT00b48
0RDY0R4811cW00HQ21cW6<HHaQcW8@P29BT28@P46<H37>L36<H01AcW6<HDYAS67>L01aS60QcW00<H
aQBU6<H00acW1aS600@DYAS66<HQ208Li`046<HLiacW6<H37>L36<H38@P27>L00aS67>LLi`027>L0
2AS67>LLiaS67>LHaQcW6<HLi`046<H011cW6<HDYAS60QcW00@Q21cW7>LQ20<HaP047>LQ21S66<H3
7>L00aS67>LLi`037>L26<H35:D37>L01B486<HLiacW6<H00QcW0aS60QcW0QS600<DYAS66<H01aS6
0QBU00H@Q1BU6<HDYAS65:D26<H55:D00aS65:DHaP036<H45:D01A245:DDYABU6<H01ABU0QS600HD
YA245:DHaQcW6<H45:D00aS67>LHaP026<H35:D011S65:DHaQS60QBU00<@Q1BU5:D00Q2400@DYAS6
6<HDY@8HaPDDY@036<HDYABU008@Q0075:D@Q1BU5:DHaQBU48@00QS600@Q21S65:DHaP8@Q0055:D@
Q1245:D@Q0025:D548@01aBU48@@Q1BU48@DYA24008DY@8HaP047>LDYA2448@25:D00a2436<<H`07
48@00`aS48@DY@0448@00aBU6<HHaP025:D00a2436<@Q00236<45:D248@25:D00a245:DDY@0248@0
10aS48@DYABU0a2400<<HaBU48@011BU00<@Q0aS36<01A2400<HaQBU5:D00Q240ABU0@aS00041240
1@0012448@@Q24800`@Q00D]JekgAS4U:C6<00<]J`03<H`e[Be[008aS003>Lhe[C6<008aS0<]J`<a
S003;F/YBRU:00@U:@8YBP08;F/aS36<;F/U:BU:;F/aS08]J`03:DXQ22DY008U:@09;F/YBS6<=Jdi
cS6<;F/U:BU:00<]J`039BTQ2248008U:@<]J`05<H`]JbU::DXU:@02:DX01BDY;F/aS36<:DX00R48
00<YBRDY8@P00QcW00@U:BU:;F/YBP@U:@8Q20039BTQ2248008U:@8YBP04;F/aS2U:9BT26<H01248
7>LLiacW0RDY0b4800<Lib489BT00RDY0b480RDY00TQ21cW7>LQ22DY;F/U:B489BT012481BDY0R48
0RDY0bU:00DU:B489BTU:B48008Li`058@PLiaS66<HLi`029BT5:DX38@P022DY8@PQ21cW9BTYBR48
9BT3:DX01B489BTYBRU:9BT00b4800DLib48:DXYBRDY008Q20039BTQ22DY008Q20<U:@048@PLiacW
8@P29BT28@P01BDY:DXQ22487>L00bDY0b4800<U:BU:9BT00bDY00<YBR488@P00R4800<Lib488@P0
0RDY0acW00@Q22DY8@PQ20<U:@0:8@PLiacW8@PU:BU:9BTQ21cW8@P67>L00bDY8@PLi`027>L28@P0
1RDY8@PQ22DY7>LQ208Li`<Q20DLi`078@PU:BDY9BTLiaS65:D00QS60acW0aS600@Q21S66<HHaP8L
i`<HaP037>LHaQS6008Li`@HaP037>LHaQS6008HaP067>LHaQBU6<HDYAS60QcW0QS611cW00LHaQcW
7>LHaQcW6<HLi`029BT00b486<HHaP037>L01aS67>LLiaS67>LHaQcW00@HaPHLi`@HaP037>LQ2248
00<HaP<Li`8HaP8Li`038@PLiacW00@Li`@DY@8Li`078@PLiacW7>LHaR487>L00aS60acW1aS60QcW
11S600@DYAS65:DDY@<HaP035:D@Q1BU00@HaP065:DHaQS65:DHaQBU0QS611BU00<@Q1S65:D00QBU
00<@Q1BU5:D00aS60aBU00@HaQBU5:DDY@@HaP037>LHaQcW008HaP8@Q0075:D@Q12448@DYAS65:D0
0a2400DHaQcW6<HDYA2400@DY@046<HDYA2448@25:D248@00aBU6<HDY@025:D26<H37>L26<H01Q24
5:D@Q1245:D@Q08DY@0348@DYA24008@Q0035:D@Q1BU00<DY@<@Q0055:DLiacW5:D@Q0025:D448@2
36<348@336<011BU48@@Q0aS0Q2400DHaQ245:DDYAS6008DY@0348@<Ha2400H@Q0<DY@0448@DYABU
5:D248@35:D00a2436<<H`0448@00aBU6<H@Q00348@011BU48@DYA240aBU00@@Q1BU48@@Q048@P00
00<000@Q12400P@Q00<000@Q24800P@Q00P000Q2:DYF]Cg_9BTaS3F]136<0Re[00<aS3F]=Jd01C6<
00@e[CW>=JdaS08]J`<YBP8U:@8YBP8aS005;F/YBRe[:DX]J`02<H`01RU:9BTQ2248:DXU:@<]J`09
=Jd]JbU:9BTYBS6<>LhaS2e[00<YBP039BTQ22DY00<]J`8U:@03:DX]JbU:00<YBP04;F/U:BDY8@P2
9BT011cW8@PQ22U:0be[0RU:0c6<00`U:AcW8@PYBS6<:DXU:BU:<H`]JbDY7>L28@P37>L29BT48@P2
9BT00b489BTYBP029BT01QcW8@PQ22489BTQ20HU:@8Q20037>LU:BU:008YBP039BTQ2248008Q2005
9BTYBRU::DXU:@03:DX01BDY8@PLiacW8@P00QcW0R4800<YBRe[:DX00R480bU:00<Q21cW8@P00R48
00<U:B489BT01BDY00PYBRDY9BTQ22DY8@PU:B4812DY0RU:00@U:B488@PU:@<Q20069BTLiacW7>LQ
22U:0bDY00@Q22DY9BTU:@8Q20049BTYBRU:9BT28@P29BT28@P012DY:DXU:BDY0QcW00DQ22U:;F/U
:B4800<U:@058@PHaQcW7>LQ20029BT00b487>LQ20039BT57>L28@P011cW6<HLiacW12480QcW00<Q
21cW9BT00bDY00<Q21cW7>L00QcW00@Q21cW6<HDY@8Li`<Q20047>LHaQS68@P37>L00b487>LLi`02
6<H37>L26<H011BU6<HHaQcW11S600<LiaS66<H00aS60acW0aS600<LiaS67>L00aS600<Lib486<H0
0QS600<Lib488@P00QS600@Lib489BTQ20@Li`046<HLib487>L26<H37>L26<H00acW6<HLi`047>L0
0aS67>LHaP036<H47>L011S65:DDYAcW0R4800<HaQBU6<H01AcW0QS600LDYAS66<HLiaS65:DHaP02
7>L01B487>LLib487>L00QS600<DYAS66<H00QcW0aS611cW0QS600@DYAS65:D@Q0@DY@@HaP035:DH
aQS600<HaP045:DHaQS66<H35:D00aS65:DDY@035:D00a246<HHaP026<H00aBU6<HDY@096<H011cW
6<HLiaS60aBU1AS600<DYA2448@00aBU00<HaQBU6<H00QBU00<HaQBU5:D00aBU00<HaQBU48@00a24
0aS600@DYAS66<HHaP8Li`<HaP<DY@0348@DYABU008DY@<@Q08HaP035:D@Q1BU008DY@8@Q08DY@03
6<HLiaBU008@Q08<H`@@Q0045:D@Q1BU36<248@25:D236<01a245:DDYABU48@HaR48008Li`035:D@
Q1BU008<H`8@Q0046<HDYABU5:D248@00aBU48@DY@025:D248@011BU48@HaQBU11240aBU1A2400<D
Y@aS48@00Q2411BU1124000312400`0012448@03124020001248@RU:E[Dmkb48;F/2<H`013F]<H`e
[Be[0S6<0SF]00/aS2e[<H`aS2U:<H`icT8@=JdYBR4800<YBP8U:@04:DX]Jc6<<H`3:DX012DY;F/]
Jc6<0RU:0R480RU:00<aS2e[<H`00S6<00HYBRDY;F/e[CW><H`2;F/4:DX00be[:DXYBP05:DX2;F/4
:DX49BT38@P01RU:;F/]JbU:9BTYBP8aS007;F/Q22489BTYBS6<:DX00RDY00<YBRe[:DX00R480acW
00@Q22DY9BTU:@<Q20@U:@03:DXU:B48008Q208U:@<Q20@U:@038@PU:B48008Q20049BTYBRU:9BT2
8@P27>L012489BT]JbU:0RDY0bU:00@Q21cW6<HQ208Li`048@PU:BU::DX28@P01RDY:DX]JbDY7>LH
aPDQ20`U:@@Q20089BTYBRU:9BTQ22DY8@PU:@8Li`<Q208Li`@Q20089BTYBRU:9BTQ22DY8@PU:@8Y
BP8U:@037>LQ22DY008U:@<YBP069BTLiacW8@PU:BU:0bDY0R4811cW00<Q22U::DX00R4800<Lib48
9BT00b480QcW00HQ21cW8@PLiaS67>L38@P011cW6<HLiacW1b480acW00<Q21cW7>L00QS60QcW0b48
1QcW00@HaQcW7>LLi`DHaP045:DHaQBU6<H27>L00aS65:DDY@037>L011S65:DHaQS60acW00<HaQcW
7>L011S600DDYAcW7>LQ21cW008HaP8Li`046<HDYAS67>L38@P00acW6<HLi`027>L26<H011cW6<HL
ib480QcW00<HaQcW7>L00QcW00<HaR487>L00aS600@LiaS66<HHaP8Li`DHaP037>LHaQcW008Li`03
8@PLiaS600<Li`THaP8Li`046<HLiacW7>L36<H011cW6<HHaQS60acW00@HaQcW7>LQ20<HaPLDY@@H
aP035:DHaQBU00<DY@<HaP8DY@0848@DYABU5:D@Q1BU48@HaPDDY@036<HDYABU008DY@8HaP057>LH
aQcW6<HDY@046<H45:D26<H45:D01acW5:D@Q1245:DLiaS600@DY@056<HDYABU5:D@Q0045:D00a24
5:D@Q0025:D00a245:DDY@027>L00aS67>LDY@035:D248@25:D448@00aBU48@DY@0548@011BU48@@
Q12411BU00H@Q1BU5:DDYA2436<248@00aBU48@@Q00236<548@010aS48@DYABU0QS600<LiaS65:D0
0QBU00<@Q0aS36<00aBU00<@Q1BU5:D00a240QBU00PHaQ2436<@Q1BU6<HDY@aS1A240QBU00P@Q1BU
48@@Q0aS48@<Ha2411BU00@@Q1BU5:DDY@4<H`0000P48@0012448@00124000Q210@Q00@U:E:D>LhU
:@<aS08YBP08;F/aS36<=JdaS2e[<H`e[@@aS007>Lhe[C6<9BTYBS6<;F/00bU:12e[00<YBRe[;F/0
0be[0RU:12DY00@YBRe[<H`]J`<YBP03;F/YBRe[008]J`@YBP8]J`0::DX]JbU:9BTYBRe[=Jd]JbDY
:DX2;F/012DY8@PU:BU:0RDY00<LibDY:DX00S6<0bU:0S6<00@]JbU:8@PU:@<YBP@]J`04:DXU:B48
9BT27>L011S67>LQ22480RDY0RU:12DY0b480bDY124800HU:B48:DXU:BU:9BT27>L012489BTYBRU:
0R480QcW00LQ22U:;F/YBR489BT]J`02<H`012DY8@PLiacW0b4800<U:B488@P01RDY00DQ22DY8@PQ
22DY008Q20039BTLiacW008U:@8YBP8U:@038@PU:BDY00<U:@038@PU:BDY008YBP039BTQ224800@U
:@047>LQ22487>L39BT00b489BTU:@03:DX00b489BTYBP02:DX00bDY8@PU:@049BT2:DX38@P49BT3
8@P00bDY8@PQ20027>L00b489BTU:@048@P2:DX29BT00acW6<HHaP037>L011S67>LQ22480QcW0QS6
11cW1B4800<U:B486<H00QS600<LiaS67>L00R4800DLiaS66<HQ21cW008HaPHLi`036<HLiacW008L
i`036<HDYABU008Li`036<HLiaBU00<HaP037>LHaQS600@Li`076<HLiaS65:DHaR487>L00QBU00<H
aQcW7>L00acW00<Q21cW7>L00QcW0QS600<Lib487>L00QS611cW00DHaQcW8@PQ21cW00@HaP047>LH
aQcW7>L36<H27>L00aS67>LLi`027>L28@P36<H57>L48@P00acW6<HHaP066<H021cW6<HHaQS67>LQ
21cW8@P46<H27>L36<H47>L26<H01QcW6<HDYABU6<H@Q0<DY@@HaP035:DHaQS6008HaP<DY@0=6<HD
YABU48@DYAS65:D@Q1BU6<HDYA245:D00QS600<DYA2448@01ABU0aS60QBU00<LiaS65:D00QS600DL
iaS65:DDYAS6008Li`056<HDYABU5:DHaP025:D00aS65:DHaP055:D348@25:D01a245:D@Q1BU48@D
YA2400<DY@<HaP035:D@Q1BU008DY@0548@DYA245:D@Q0025:D248@010aS5:DDYA240aBU00DLiaBU
5:D@Q1BU008HaP055:D@Q12436<DY@0348@25:D00a2436<@Q0035:D010aS48@@Q1240QBU00<@Q1BU
5:D00QS60aBU0Q240QBU00@@Q1BU5:DHaP8DY@0448@DYA245:D248@011BU48@DYAS60Q2400@<Ha24
5:DHaPL@Q08<H`03248<H`aS008@Q08DY@0448@DYABU5:D148@000848@0300048@@Q00<48@082484
8@00248U:Dic>LhU:@8aS08]J`03:DX]Jbe[008e[@03<H`]Jbe[008]J`@e[@03;F/YBRe[00<]J`<Y
BP8]J`<YBP059BT]Jc6<<H`YBP059BT2:DX3;F/00bU:9BTU:@02:DX3;F/2:DX012DY:DX]JbU:0be[
00@U:BU:;F/aS08]J`<YBP039BTQ22U:00@U:@8YBP03;F/aS36<008YBP049BT]Jbe[:DX29BT2:DX0
1Be[:DXYBRe[:DX00RDY0acW00@HaR488@PU:@8Q20039BTYBRU:008U:@8YBP039BTQ2248008Q20DU
:@088@PU:BDY9BTQ22DY8@PLi`8Q2008:DXQ22487>LU:AcW8@PU:@8YBP8U:@8aS003;F/U:B4800<Q
20<U:@8Q208U:@<Q208U:@048@PLib488@P29BT27>L022489BTYBRU:9BTQ22DY:DX28@P01bDY:DXY
BRDY8@PU:BU:00<U:@8Q208U:@DQ20<U:@8Q2004:DX]JbU::DX39BT2:DX39BT38@P02bDY;F/YBRDY
7>LQ21cW8@PU:B489BT00R4800<U:B488@P00QS600<Lib489BT00R4800<Lib489BT00bDY0QcW0QS6
11cW00<Q21cW8@P00QS60QcW00<Q21cW7>L00QcW12481AcW00DHaQcW7>LQ21cW008HaP037>LHaQS6
008HaP037>LHaQcW008Li`046<HDYAcW7>L26<H011BU6<HHaQBU1QS600HLiaBU6<HHaR487>L36<H0
0acW6<HHaP066<H37>L012487>LHaQS60QcW0QS60acW00<HaQBU6<H00QcW0aS600LLib488@PLiaS6
5:DHaP027>L26<H47>L00aS67>LHaP047>L00aS67>LHaP046<H57>L00bDY8@PQ20026<H021cW6<HD
YAS67>LHaQcW6<H57>L011S65:DHaQS611cW0aS600DLiaS67>LHaQcW00<HaP8DY@0348@DYAS6008H
aP8DY@8HaP8DY@036<HDYAS6008HaP<DY@036<HDYA2400PDY@046<HDYABU5:D26<H35:D00aS65:DD
Y@046<H00aBU6<HDY@025:D26<H00acW6<HDY@045:D011246<HHaQS60QBU00<@Q1BU5:D00QBU0Q24
00PDYA2448@@Q1BU48@DYA2411BU11S60QBU00<@Q1BU6<H00aBU00<HaQ2448@00a2400<<Ha245:D0
0aBU00<@Q1BU5:D00aBU0a240QBU112400<DYA2436<00a2400<DY@aS48@00`aS0Q2400<DYA245:D0
0QS600DDYA2448@@Q1BU008@Q08DY@036<H@Q1BU008DY@0448@DYABU36<348@26<H01a2436<@Q1BU
6<HDYA2400@DY@8@Q0@<H`8@Q08DY@8@Q0035:DHaQBU004<H`0000@000@Q124000P48@06:DYBU3W>
9BT]Jc6<0Re[0S6<12e[0c6<0Re[1C6<0Re[00<YBRDY:DX00RDY0Re[0S6<00DYBRe[:DXU:BU:008]
J`<U:@DYBP8U:@8Q2005:DX]Jc6<<H`]J`02:DX01Be[:DXYBRU:;F/00S6<00@]JbU:9BTYBP8]J`06
:DXQ22489BTYBRDY0R4800@U:BU:;F/YBP8U:@05:DXaS3F]=Jd]J`029BT2:DX00be[:DXYBP02;F/0
1BU:9BTU:BDY8@P00QS600<Lib488@P00b480bU:0bDY00LLiaS68@PU:Be[:DXQ20059BT28@P37>L2
8@P2:DX02BDY:DXU:B487>LQ22DY;F/YBP039BT022U:;F/]JbDY8@PU:B48:DX39BT01Re[:DXU:AcW
8@PU:@<Q20049BTYBRU:9BT27>L29BT28@P39BT00b489BTU:@059BT012U:8@PQ224812DY0RU:00<U
:B487>L01RDY0RU:00@U:B489BTQ20DU:@<Q20039BTQ22U:00<YBP@Q20039BTQ22DY00DQ208Li`04
8@PU:BDY9BT28@P012U:;F/]Jb480QcW00<Q21cW7>L011cW0b4811cW00<HaQcW9BT00RDY00@Lib48
8@PQ208Li`<Q20057>LQ21cW7>LHaP027>L66<H00b487>LLi`047>L011S67>LHaQcW1QS60acW00<Q
21cW6<H00QS600<LiaS66<H00QS600@Lib488@PQ20<HaP037>LQ21S6008HaP8Q20067>LHaQcW7>LQ
21cW0QS60acW00DDYAS66<HHaQBU008Li`8Q20036<HQ21cW00<HaP<Li`036<HLiacW00<HaP037>LQ
21cW00@Li`8HaP037>LQ21cW00DLi`<HaP055:DHaQcW8@PLi`036<H37>L012487>LHaQcW0QS60QcW
0aS600DDYAcW7>LLib4800@HaP8DY@HHaP035:DHaQS6008DY@8HaP@Li`035:DHaQS6008DY@0648@D
YA2448@HaQBU0QS61QBU00<LiaS65:D00aBU0QS60aBU0QS600@@Q1BU5:DHaP<Li`TDY@8HaP8DY@8@
Q0035:D<Ha24008DY@056<H@Q12448@DY@0348@35:D011S65:DDYABU0Q2400TDYA245:DDYAS648@D
YAS65:D00`aS0a2400@Lib488@PHaP8@Q08HaP045:D@Q12448@35:D00a245:D@Q00448@010aS48@@
Q1BU0Q240PaS0Q242ABU00@@Q1BU5:D@Q0<HaP8@Q0055:DHaQBU48@<H`0248@26<H25:D0112436<@
Q1BU11240QBU00<@Q0aS36<00PaS00H@Q1BU48@@Q1BU6<H45:D148@000@48@0?00048@0024848@00
1248@R48CW<icR48:DXaS2e[00<aS004;F/YBRU:;F/2<H`012e[:DXaS36<0SF]00<aS2e[;F/00be[
00LYBRDY9BT]Jc6<=JdaS00::DX00bDY:DXYBP03:DX29BT00b489BT]J`07;F/012U:;F/]Jc6<0Re[
0RU:00HU:Be[<H`YBRDY8@P29BT28@P00bDY:DXU:@03:DX29BT02Re[=JdicSF]9BTQ22DY:DXaS2e[
0RDY00<YBRe[:DX00R4800@HaQcW7>LLi`DQ20039BTYBRU:00<U:@<Q208YBP059BTQ21cW9BTQ2002
9BT28@P00bDY8@PQ20028@P29BT01BU:9BTU:AcW8@P00RDY0RU:0bDY00<YBRe[:DX00b4800XU:BU:
9BTQ22DY:DX]JbDY7>LQ208Li`8Q20049BTYBRU:9BT48@P011cW8@PU:BDY0b4800@YBRDY9BTU:@<Y
BP<U:@<Q20LU:@038@PU:BDY00@U:@8YBP<U:@04:DXU:B488@P39BT28@P02BU:<H`]JbU:8@PLib48
9BTQ20029BT38@P29BT00aS67>LQ2002:DX38@P49BT58@P47>L38@P36<H47>L78@P00bDY8@PLi`02
7>L012487>LLiaS60acW00HHaQBU6<HLib487>L26<H27>L26<H27>L35:D00aS67>LHaP036<H37>L2
6<H00aBU6<HHaP027>L26<H27>L00b487>LLi`036<H00acW6<HHaP037>L012486<HHaQS60acW0QS6
00LLiaS67>LDYAS65:DHaP027>L38@P00acW6<HHaP026<H27>L011S67>LLiacW0QS60QcW00<Q21cW
7>L011cW00@HaQcW7>LU:@<Q20<Li`036<HLiaS600<Li`046<HLiaS65:D27>L00b487>LHaP027>L0
0aS67>LHaP037>L36<H00b489BTLi`0:6<H25:D26<H00acW6<HDY@025:D01QS69BTLiaS65:D@Q08H
aP055:D@Q1246<HLi`045:D26<H00aBU48@@Q0046<H248@46<H00aBU6<HHaP045:D00aS67>LHaP02
6<H00aBU6<HDY@025:D011246<HHaQS60aBU00<HaQ2448@00a2400LDYA2436<@Q1BU6<HDY@0248@2
5:D00aS65:DHaP025:D011245:DDYABU0QS60QBU1a2400PDYA247>LQ21cW6<H@Q1S60aBU112400<D
YA2448@00Q2400DDYA2436<<Ha24008DY@0348@<H`aS00@@Q08DY@066<HDYA2448@DYA241QBU00DH
aQBU48@@Q1BU008HaP0748@<Ha245:D@Q1BU6<H00Q2400<<Ha245:D00QBU1Q240PaS11241aBU0A24
00000`001240000912401BU:BU8e[B48;F/01C6<0RU:00<]Jc6<<H`00be[00<aS3F]<H`00be[0c6<
0RU:00HaS3F]>LhaS2e[<H`4:DX00be[:DXYBP029BT01BU:9BTU:B489BT00RU:00LLib48:DXaS2U:
9BTYBP03<H`2;F/01c6<;F/]Jc6<;F/aS2e[00@YBP8U:@038@PU:B48008Li`038@PYBRU:008YBPD]
J`03:DXU:BDY008YBP059BTYBRU:<H`]J`049BT58@P27>L012DY:DX]JbDY0R4800<U:BU:8@P00R48
00@YBRDY:DXYBP8U:@038@PU:B48008Q20<Li`8Q20039BTYBRU:008YBP8U:@038@PU:BDY00<YBP05
9BTYBRe[:DXU:@028@P29BT01BU:9BTU:BDY:DX00RDY0b480QcW00@U:Be[;F/YBP8Q208Li`8Q2003
9BTQ22DY008U:@04:DXU:B488@P39BT00b489BTU:@029BT01B489BTU:BDY:DX00RDY00@Q22DY;F/]
J`8YBP8U:@LYBP079BTQ22489BTQ21cW9BT00bU:00DU:B488@PU:BU:008U:@8Q20049BTQ22488@P2
7>L00bDY:DXYBP028@P00acW:DXU:@028@P39BT012487>LQ21cW124800LU:B487>LLiaS67>LQ2002
9BT47>L012U:9BTU:B480RDY00DQ21cW7>LHaQcW00@HaP047>LHaQS66<H27>L01AS67>LQ22DY8@P0
0QS600<LiaS65:D00QS60QcW0QS60QBU0QcW0aS60acW0QS600HDYAcW9BTU:AcW5:D47>L01AS67>LL
iacW6<H00QcW00<Q21cW7>L02aS61AcW0aS600<Q21cW7>L01QcW00@DYAS67>LHaPDLi`036<HLiacW
00DLi`048@PLiacW7>L56<H01AcW6<HLiacW8@P00acW0QS60acW11S60QcW00@Q21cW7>LHaP8Li`03
8@PHaQS6008HaP047>LHaQBU6<H25:D66<H00acW6<HLi`046<H25:D011245:DDYABU0aS60QBU00@H
aQBU6<HHaP@DY@037>LDYABU00<HaP<DY@8HaP@DY@036<HLiaS600<@Q0035:DHaQBU008DY@8HaP@@
Q0065:D@Q0aS48@DYAS60aBU00P@Q0aS48@DYAS67>LDYAS611BU0Q2411BU00<HaQBU48@00Q2400DD
YA2448@DYAcW008Q20<HaP035:DHaQ2400<@Q0035:D@Q124008@Q00536<@Q12448@DY@0248@00`aS
48@@Q00648@011BU6<HDYABU0Q240QBU0aS600@DYA2448@@Q08DY@0348@DYA2400<@Q0065:D@Q1BU
48@HaQBU0a2400HDYA2436<@Q1BU48@536<00aBU48@DY@0348@25:D26<H15:D148@000H48@0=0008
@P@Q124000Q29BU:DSF]7>L]JcF]<H`01be[0c6<00<]Jc6<<H`00S6<0Re[00<aS2e[;F/00RU:00Da
S3F]=Jde[BU:008]J`<YBP8]J`<YBP039BTYBRDY008U:@08:DXU:BDY9BTYBRe[:DXU:@8YBP06<H`]
Jbe[<H`]JbU:0S6<00He[C6<;F/YBRe[:DX29BT012489BTYBRDY0QcW00<Q22U::DX00RDY12U:00@]
JbU:9BTU:@8YBP8U:@03:DX]JbU:008YBP049BTQ21cW7>L48@P00acW8@PYBP02:DX28@P00bDY8@PQ
20028@P012DY:DX]JbU:0RDY0R4800TU:B486<HLib489BTQ22DY8@P012U:0R480bDY0bU:00@U:BU:
:DXYBP<Q20DU:@8YBP089BTQ21S67>LQ21cW9BTYBP8]J`03:DXU:AcW008Li`049BTQ22489BT38@P4
9BT28@P49BT012489BTU:B481BDY00PQ22DY:DX]JbU:9BTQ22DY12U:0bDY1B4800DLibDY:DX]JbU:
00@U:@038@PU:BDY00<Q20039BTQ21cW008Q20<U:@@Q20<U:@05:DXQ22486<HLi`028@P012DY8@PU
:BDY0b4800<LiaS67>L012480QcW00@Q22DY9BTLi`<U:@047>LDYAcW8@P27>L26<H27>L011S65:DH
aQBU0acW00@Q21cW7>LLi`dHaP8Li`DHaP037>LHaQS600HLi`068@PLiaS66<HLiaS60QcW00<HaQcW
7>L00QcW1AS600@DYAS65:D@Q08HaP078@PLiacW8@PLiaS65:D00QcW00@Q21cW6<HHaP<Li`8HaP<L
i`076<HLiacW7>LHaQcW8@P00acW00<HaR487>L00QcW0QS61AcW00<HaQcW6<H01QcW0aS60acW0aS6
124800<LiaS66<H00QS600<LiaBU6<H00QBU00<LiaS66<H00QBU0QS60QBU0QS60QcW0QS60QBU00<H
aQBU6<H01ABU00<HaQBU6<H00QBU00<HaQBU5:D01ABU0aS61QBU11S600<DYA245:D00QBU0QS600<D
YAS65:D01ABU0`aS00<@Q1BU48@00a2400<DYA2448@00QBU0Q2400@DYAcW6<HDY@8@Q0035:D@Q1BU
00<DY@8@Q0035:D@Q12400@@Q08DY@@Q208HaP0648@DYABU48@DY@aS0Q240QBU11240`aS00<DYA24
48@00`aS00<@Q1BU5:D00aBU0a2400DDYAS65:DHaQBU00@@Q0036<HDYABU00P@Q0035:D@Q12400D@
Q08DY@0448@<H`aS36<248@010Q236<@Q1BU0a240QBU0Q240ABU0A24000010@Q00048@0020@Q00PU
:Dic=JdU:Be[>Lhe[C6<0Re[00@U:Be[;F/]J`8aS08YBP039BTYBS6<008]J`03<H`]JbU:008YBP8a
S005;F/aS36<<H`]J`06:DX2;F/012U:9BTU:BDY0RU:0bDY0RU:00D]JbDY:DXYBRe[008aS0<]J`@a
S0<YBP07<H`YBR487>LU:BU:9BT00QcW00LQ22DY;F/YBRDY8@PU:@03:DX00bDY8@PU:@029BT38@P0
0bU:;F/YBP028@P29BT00b489BTU:@039BT4:DX29BT48@P01BDY:DXYBRU:9BT00bU:00LU:B488@PL
ib487>LQ20039BT00bU:9BTU:@028@P00bDY8@PU:@028@P3:DX59BT38@P01bDY8@PU:BU:9BTQ21cW
008Q20047>LHaQcW8@P39BT48@P01bDY8@PQ21cW8@PYBRDY00@YBP8Q20057>LQ22DY9BTQ20027>L0
12DY:DXYBRDY0R4800<U:BU::DX00Re[0RU:00DU:B489BTYBRe[008YBP049BTQ21cW8@P27>L012DY
:DXYBRU:0b4800@U:BU::DXU:@@Q20039BTQ22DY008U:@03:DXU:BDY008Q20079BTQ22488@PU:BU:
9BT00b480QcW0R4800@U:B488@PQ20@Li`8Q20049BTQ22487>L38@P29BT28@P00acW9BTQ20036<H0
0acW8@PLi`036<H37>L00aBU6<HLi`047>L26<H00aBU6<HHaP056<H01AcW6<HLiaS67>L01QS621cW
1AS600DLiaS67>LQ21cW00@HaP055:DLib488@PLi`025:D36<H00aBU6<HHaP027>L36<H011cW6<HH
aQcW0R4800@LiaS67>LLi`8HaP8Li`036<HLiacW00HLi`038@PLiacW008HaP057>LHaQS66<HLi`03
8@P00aS67>LLi`027>L26<H27>L36<H01QcW6<HLiaS68@PLi`8Q20047>LHaQS66<H27>L011BU6<HD
YAcW0QS600@LiaS67>LHaP8DY@046<HLiacW7>L35:D26<H25:D36<H01ABU6<HHaQBU6<H00QBU00<H
aQBU5:D00aBU00DHaQBU6<HHaQBU008HaP<DY@8HaP065:DHaQS66<HDYA241ABU00<HaQBU48@00Q24
1QBU0Q2400<<Ha2448@00QS600@DYA2436<@Q08DY@@HaP035:D@Q1BU008@Q0@DY@0348@DYA2400<@
Q0035:D@Q124008DY@047>LHaQS66<H35:D00a245:DDY@0448@011BU48@@Q0aS112400@DYA2448@@
Q08<H`8@Q0<DY@0448@<H`aS48@25:D26<H011BU6<H@Q0aS3a2411BU0Q2400H<Ha2448@<Ha242482
36<648@25:D011S67>LHaQBU0A2400000`0012448@0212400`001248@P0212402@00248YBTic>LhQ
236<=JdaS003;F/3:DX012e[<H`]Jbe[0RU:1Re[0bU:00/]Jc6<<H`aS3F]<H`YBRDY;F/aS2U:008U
:@@YBP@U:@04:DXU:BU:9BT2:DX6;F/6<H`5;F/012U:9BTQ22DY0R480QcW00@Q22U::DX]J`HU:@04
8@PU:BDY:DX39BT3:DX29BT01b489BTQ22489BTYBRDY008Q20049BT]JbU::DX59BT00b489BTYBP02
:DX00bDY:DXU:@039BT012487>LLiacW0b480bDY00DYBRDY8@PLib4800<U:@038@PU:BU:008U:@03
:DXQ21cW008Li`059BTYBRDY9BTQ20049BT47>L59BT58@P00bDY8@PLi`029BT00be[<H`]J`029BT0
12489BTU:BDY0b4800<Lib488@P00bDY0R480RU:00<]JbDY9BT00bDY00H]JbU:;F/YBRDY8@P29BT3
8@P29BT00bU:9BTU:@079BT28@P29BT01bU:9BTQ2248:DXU:B48008Li`<Q20@U:@038@PU:AcW00<L
i`039BTQ22DY008Q20@Li`@Q208Li`<Q208YBP069BTQ21cW8@PLib480QS600LDYAcW8@PHaQcW6<HL
i`046<H021cW8@PLiacW5:DHaQcW6<H27>L26<H011BU6<HHaQS60acW1QS600<DYAcW8@P00R4800@H
aR487>LLi`8HaP047>LHaQS66<H27>L26<H27>L36<H27>L00b486<HHaP076<H37>L36<H57>L01b48
7>LHaQS67>LU:B4800<Li`8HaP<Q20@Li`058@PHaQS66<HDY@047>L011S67>LQ22480QcW00DQ21cW
7>LLiaS600<Li`8HaP8Li`038@PLiacW00<Li`036<HLiaS6008HaP055:DHaQS66<HLi`036<H00aBU
6<HHaP026<H011cW6<HHaQBU0QS600DLiaS66<HDYAS600<DY@8HaP075:DHaQS65:DHaQBU6<H00Q24
11BU11S60aBU00DHaQcW6<HHaQBU008HaP8DY@0448@DYABU5:D448@01AS65:DDYABU48@00QBU1124
00HDYAS65:DDYA2436<25:D00aS67>LHaP025:D248@35:D00aS65:DDY@0448@25:D248@01`aS48@D
YAcW6<HDYAS600@DY@8@Q0@DY@D@Q08DY@0348@<Ha2400<@Q00436<@Q1245:D248@25:D248@00`aS
5:DDY@026<H00aBU48@@Q00248@00aBU48@@Q00548@00aBU48@<H`045:D248@00aBU48@@Q00348@3
36<00a2436<@Q00548@35:D16<H15:D136<000848@0500048@@Q1240000512401RDYE[DmkbU:=Jda
S0<]J`03<H`]Jbe[00@aS0<YBP06;F/aS2e[:DX]JbU:0RDY00D]JcF]<H`]JbU:008]J`05:DX]Jbe[
<H`YBP039BT01RU:9BTU:BU:9BTLi`8U:@<aS003;F/YBRU:00@]J`09<H`]JbU:<H`e[C6<;F/U:BU:
00<]J`@U:@8YBPLU:@8Q20049BTYBRU:9BT38@P29BT98@P49BT01B489BTYBRDY:DX00RDY00<YBR48
8@P00R4800/U:B48:DX]Jc6<9BTQ22DY:DXU:B48008Li`8Q208U:@@Q20059BTQ22DY8@PU:@028@P3
9BT28@P00bDY:DXU:@039BT00bU:;F/YBP068@P00acW8@PQ20029BT00bU:9BTU:@029BT28@P012DY
8@PYBRDY0RU:00<U:BU:9BT00b480bDY11cW0RDY0R4800@U:AcW8@PYBP<]J`<U:@8YBP04;F/U:BDY
9BT48@P29BT01BU:;F/U:BU:8@P00RDY00<YBRe[:DX00bDY124800<U:BU::DX00b4800DU:B488@PQ
21cW008Q208YBP049BTQ21cW7>L38@P00bDY8@PU:@0:8@P011S67>LQ22U:12DY00HQ21S66<HHaQcW
6<H27>L28@P37>L012487>LLiacW1AS600<DYAS65:D01ABU00@HaQcW7>LLi`8HaP8Li`058@PHaQS6
6<HLi`036<H00acW8@PQ20036<H37>L36<H37>L36<H37>L01R487>LLiaS65:DHaP<Li`076<HLiacW
8@PLiaS65:D00QS60b4800@LiaS66<HHaP<Li`038@PLiaS6008HaP057>LQ21cW9BTQ20027>L26<H0
0acW5:DDY@037>L01B487>LQ22489BT00R480acW11S611cW0QS60acW00<Q21S67>L00aS600<DYAS6
6<H00acW0QBU0QS600<LiaS65:D01QS60aBU00<HaQBU6<H00QBU0QS600<LiaS66<H00QBU00@HaQBU
5:D@Q0<HaP<DY@036<HLiaS600@DY@@HaP035:DHaQBU00<DY@8HaP8DY@0348@DYA2400DDY@0348@D
YABU008DY@0448@HaQS65:D348@00aBU6<HHaP046<H01ABU48@@Q1BU6<H00aBU00<@Q0aS48@00aBU
0a2400DDYA245:DDYAS6008DY@0648@DYA246<HDYA240QBU0Q240PaS00@@Q0aS48@DY@8@Q00336<@
Q1BU00<@Q0<DY@0448@<H`aS48@25:D248@25:D548@436<548@01ABU48@@Q1245:D021240PaS0a24
00@<Ha2448@@Q08DY@046<HDYAS65:D26<H148@0000500048@@Q1240000212400`Q212448@021240
12U:E[DmkbU:0SF]00<aS2U:;F/01Re[00<aS2U:;F/00RU:00<]JbU:;F/00RU:00@U:BU:;F/aS08e
[@08;F/YBRU:9BTYBS6<;F/U:@8Q208YBP059BTQ22DY8@PU:@02:DX012e[<H`aS2e[0RU:00<aS2e[
;F/00Re[136<00P]JbDY:DXYBRe[<H`YBRDY0b4800<YBRDY9BT00b4800<U:B489BT00RDY0RU:00<U
:B488@P00bDY00<Q22DY8@P00QcW00@Q22DY8@PLi`8Q20<U:@098@PU:BU::DXU:B489BT]Jb48008L
i`059BT]JbDY9BT]J`02:DX29BT00bU:9BTU:@028@P03BDY8@PQ22DY8@PLib489BTYBRDY7>LQ22DY
00<Q208U:@8Q2006:DXU:BDY9BTQ22DY0RU:0RDY124800@Lib488@PQ208U:@068@PU:BU:9BTQ22DY
0RU:00<U:B488@P00bDY00DQ22DY9BTU:B48008U:@038@PLib48008Li`048@PU:BU:9BT28@P29BT0
12U:;F/aS2e[0bDY0bU:0RDY124800<U:B48:DX00RU:0RDY00@Q22U::DXYBP<U:@038@PU:BDY00HU
:@DQ208Li`8Q20039BTQ2248008U:@038@PLib4800<U:@8Q20<Li`056<HQ22488@PU:@037>L00b48
9BTU:@028@P01BDY7>LLiacW6<H011cW0R4800LLiaS66<HHaQcW8@PLi`036<H01aBU6<HHaQS65:D@
Q1BU00@HaP8Li`@HaP077>LHaQS65:DLib487>L00QS60R480QS600DLib486<HHaQBU00<HaP037>LQ
21S6008DY@046<HQ21cW7>L28@P27>L00aBU6<HHaP046<H00acW8@PLi`056<H28@P01acW5:DHaQcW
8@PLiaS600<Li`086<HLiacW7>LQ22DY8@PLi`8HaP8Li`<HaP@Li`038@PU:B4800HLi`046<HDYAS6
6<H57>L36<H27>L36<H011cW6<HHaQBU0QcW00@DYAS67>LLi`8DY@056<HLiaBU5:DHaP027>L26<H0
11BU6<HLiaS60aBU1AS600<DYAS65:D00aBU1aS60aBU0QS600<DYAS66<H00QBU00<HaQBU5:D00QBU
00@HaQBU6<HHaP8DY@0348@DYABU008DY@036<HDYA24008@Q0<DY@@HaP8@Q08DY@036<HDYAS600<H
aP8DY@0548@DYABU6<HDY@0448@00aBU48@@Q00248@65:D00a245:D@Q0045:D011245:D@Q1240`aS
00<@Q1BU48@00Q2400DDYA2448@@Q0aS008HaP045:D@Q0aS36<648@01ABU48@@Q1245:D00PaS0Q24
00HDYA2436<<Ha2436<248@35:D548@02@aS48@@Q12436<@Q0aS48@<H`0348@01QBU48@DYA246<HD
Y@8HaP4DY@4<H`0000<48@0012400P@Q00<000@Q12400P@Q00H000Q29BUF]D8@:DX5<H`00cF]<H`]
J`02;F/2=Jd012U:8@PU:Be[0SW>00@]JbDY9BT]J`8aS004:DX]Jbe[;F/29BT00bU:;F/YBP049BT2
:DX00bDY8@PQ20029BT3:DX02Re[:DX]Jbe[:DXU:Be[<H`e[Be[0RU:12e[00<YBRDY:DX00bU:12DY
00<Q22DY9BT00RDY0R4800<U:BU:9BT0124800<U:Be[9BT00acW00@U:B488@PHaP8Li`<Q20057>LQ
22DY:DX]J`039BT2:DX01B487>LQ22489BT012e[00HU:B488@PU:BU:9BT28@P89BT28@P00bDY:DXU
:@028@P29BT00bU:9BTU:@069BT2:DX01Re[9BTQ22489BTYBPLU:@03:DXU:BU:00HU:@8Li`058@PU
:BU::DXU:@038@P57>L28@P00bDY:DXU:@028@P012DY;F/YBRU:0be[00@YBRDY:DXYBPHU:@058@PU
:BDY:DX]J`0::DX29BT01B48:DXU:B489BT00RU:00DU:AcW7>LQ21cW008Q20049BTQ22488@P39BT0
0acW8@PQ20028@P01AcW8@PQ22489BT00R4800<U:B488@P00QcW124800@U:B487>LU:@8YBP058@PH
aQcW7>LQ20037>L00aS67>LLi`027>L00aS67>LLi`026<H45:D26<H55:D00aS67>LLi`036<H01B48
7>LHaQS67>L011S60QcW00@Q21S66<HLi`8HaP035:DHaQS600<Q20<HaP077>LHaQS68@PU:B487>L0
11S600<Q21cW7>L00QS600@Lib488@PLi`8HaP047>LQ21cW7>L26<H01R487>LQ22486<HLi`8HaP03
7>LHaR4800<Li`038@PLiacW00@HaP8Li`056<HLiacW8@PLi`026<H47>L01ABU7>LLiacW6<H00acW
0QS60acW00DHaQcW7>LLiaS600<Li`DHaP8Li`8HaP035:DLiacW00<HaP8Li`8HaP045:DHaQS67>L2
6<H27>L25:D01QS67>LHaQBU48@DY@8HaP8DY@066<HLiacW7>LHaQBU11S60QBU0QS60aBU00<HaQBU
6<H00QBU00D@Q1BU6<HDYAS600DDY@0348@DYABU00@DY@046<HDYA2448@25:D26<H00aBU6<HDY@02
6<H448@011BU6<H@Q1240aBU00<HaQBU48@00Q240QBU112400HDYA2448@DYA245:D248@01QBU48@@
Q1245:D@Q08DY@<@Q00436<@Q12448@35:D0112436<DYA240PaS0QBU00L@Q1BU48@@Q1BU48@DY@02
36<00a2436<@Q00448@25:D548@00aBU48@@Q00548@01ABU48@<H`aS48@00PaS00<@Q1BU6<H00QBU
0aS600<DYAS65:D00@aS000212401P0012448@@Q0008@P@48@059BUBU3g_9BT]J`04<H`013F]<H`a
S2e[0c6<00PU:B489BTaS3W>=JdYBRDY0RU:0S6<0Re[00@aS2U:9BTU:@<]J`04:DXQ22488@P3:DX3
8@P00bDY;F/YBP02:DX3;F/29BT012e[<H`e[Be[0RU:00<]JbU:;F/00bU:00P]JbU:;F/YBRDY8@PU
:B480RDY0RU:00<U:B488@P00R4800<U:B489BT00b480RDY0b4800<U:B487>L00acW1B4800/U:BU:
:DXYBRDY:DX]JbDY8@PLiaS6008Q2004:DX]Jbe[:DX49BT2:DX49BT00b489BTU:@02:DX28@P01RDY
8@PU:BDY:DXU:@8Q20HU:@<Q2004:DX]JbU:9BT38@P79BT5:DX00bDY8@PU:@028@P27>L01B489BTY
BRDY8@P00bDY00<Q21cW6<H00QS600DQ22DY:DXYBR48008Li`05:DXaS36<:DXU:@02;F/00bU:9BTY
BP02:DX59BT28@P29BT5:DX00bDY:DXU:@03:DX01RDY8@PU:B489BTYBP8U:@038@PLib4800LQ2005
7>LQ22e[9BTQ20027>L012DY:DXU:B480QcW00<U:B488@P00b4800<U:AcW8@P00QcW2B4800DLiaS6
7>LLib48008Li`066<HLiacW7>LQ21cW11S60aBU0QS60aBU00@LiaS65:DHaP<Li`036<HLiacW008L
i`046<HLiaS67>L26<H00acW8@PLi`026<H37>L01QS65:DLib489BTQ208HaP8Li`065:DHaR489BTQ
21cW1QS60acW00<HaQcW7>L00QcW0QS60QcW00@HaQcW7>LHaP8Li`8Q20PLi`068@PHaQS66<HLiaBU
0QS600DLiaS67>LLib4800DLi`078@PLiacW7>LHaQBU6<H00acW00<Q21cW7>L00acW00DHaQBU6<HH
aQcW00HHaP037>LQ21cW008DY@036<HLiaS600PHaP045:DHaQS66<H25:D46<H00acW6<HDY@035:D0
11S65:DDYABU1AcW21S600<DYA2448@00QBU00@HaQBU5:DHaPTDY@<@Q0056<HDYABU5:DHaP025:D0
1A2436<@Q1BU7>L00QS600@DYAS65:DHaP8DY@0348@DYAS600<DY@8@Q0095:D@Q12448@DYA245:D@
Q0aS008@Q0035:D@Q124008@Q0@DY@0448@DYA245:D348@00aBU48@@Q00236<248@35:D011S65:DD
YA240PaS0Q240QBU0Q240aBU0a2400@<Ha2448@@Q08<H`8@Q00436<@Q12448@45:D948@336<00a24
5:DDY@055:D36<H15:D136<0000400048@@Q000712403@Q2:DYF]Cg_8@P]Jc6<=JdicSF]<H`e[CW>
008e[@<]J`03:DXaS3F]008aS0<YBP04;F/aS2e[;F/3:DX3;F/2:DX39BT00b489BTQ20039BT00b48
9BTYBP02;F/00bU:9BTU:@02:DX012e[<H`e[C6<0be[0RU:00<U:BU::DX00RDY0be[00<YBRDY8@P0
0RU:00@]JbU:9BTQ20<U:@<YBP039BTLiacW008U:@04:DXU:AS66<H27>L48@P01BDY8@PQ21cW8@P0
12U:0RDY00@Q21cW7>LQ208U:@058@PYBRe[;F/YBP028@P00bU:9BTU:@02:DX29BT01R489BTU:BDY
8@PLi`<U:@8YBP<U:@048@PYBRU:9BT28@P012DY;F/YBRDY0bU:00@U:B488@PQ208U:@048@PYBRDY
:DX69BT28@P01bDY:DXU:B487>LQ22DY008Q208U:@058@PU:B488@PLi`038@P29BT012489BTU:B48
0RDY0Re[0RU:00<U:BU:8@P00bU:00<U:B487>L00bDY00<YBRDY:DX00RU:00<Q22DY9BT00RU:00@U
:BU::DXYBP<U:@LQ20039BTQ21cW008Li`039BTQ22DY008Q208U:@05:DXU:B488@PU:@058@P011cW
8@PLibDY0R480QcW00<HaQcW7>L00QcW00<Q22DY9BT00RDY00<Lib487>L011cW00@HaQBU5:DHaP8L
i`048@PU:BDY8@P36<H01AcW6<HHaQS65:D011S600PDYAS66<HLiaBU6<HLib480QcW0QS60QBU00@H
aQcW7>LLi`@HaP037>LHaQcW008HaP037>LQ21S6008HaP<Li`8HaP@Li`076<HLiacW7>LHaQcW6<H0
0QcW00<HaQcW6<H01AS600<LiaS67>L00QS60QcW00DQ21cW6<HHaR4800@Li`<HaP037>LDYAS6008H
aP037>LQ21cW00DLi`098@PLiacW7>LHaQcW6<HLiaBU008HaP048@PHaQS66<H37>L01AS67>LLiaS6
7>L00aS600<LiaS66<H00QS60QcW00<HaQBU6<H00QcW0QS600@DYAcW6<HHaP8Li`036<HLiaS600<H
aP057>LHaQS65:DHaP025:D011S65:DHaQBU0aS60acW0QS600HLiaS66<HHaQBU6<H25:D26<H55:D3
48@35:D448@00aBU6<HDY@025:D011S65:DDYA240QBU00<@Q1BU6<H00aS60acW00<HaQBU48@00a24
1QBU0QS60a240QBU0a2400@DYA2436<<H`8@Q0@DY@066<H@Q0aS36<@Q1BU1Q2411BU0Q2400@<Ha24
48@DY@@@Q0035:D@Q124008DY@L@Q0035:D@Q12400P@Q00336<@Q12400<DY@8@Q0045:D@Q1BU48@2
36<011245:DDYAS61aBU0A24000412401P0012448@@Q248000848@0;9BUF]D8@9BTYBSF]>LhmkcF]
<H`e[@02>Lh02c6<;F/aS2e[:DX]Jc6<=JdaS2U:9BT00Re[00@aS2e[:DXU:@PYBP@Q20049BTQ22DY
8@P29BT5:DX012DY:DX]Jbe[0SF]00LaS2U:9BTYBRe[:DXU:@02:DX00bDY:DXYBP03:DX01bDY8@PY
BRe[<H`]Jb48008U:@068@PU:BU:;F/YBRDY0R4800@U:BU::DXU:@<Li`046<HQ21cW7>L39BT38@P3
:DX29BT00b489BTQ20028@P01RDY:DXU:BDY;F/YBP8U:@8YBP059BTQ22DY:DXU:@028@P012U:;F/Y
BQcW0b480bU:0RDY00@Q22DY9BTU:@8Q20039BTYBRU:00<U:@<YBP8U:@088@PLib489BTYBRe[9BTQ
20@U:@038@PU:B48008YBP059BTQ21cW8@PYBP038@P2:DX01BDY8@PQ21cW6<H00R4800<YBR489BT0
12DY00<YBRDY:DX00Re[00<YBRDY:DX01RDY00@Q22DY9BTU:@<YBPDU:@<YBP@U:@<Q20039BTQ22DY
00<Q208Li`@Q20049BTQ22488@P29BT00acW8@PQ20058@P27>L012489BTQ21cW0QS600PLibDY8@PQ
21cW6<HLibDY0RU:00LU:B487>LLiaS67>LQ20027>L00aS65:DLi`027>L28@P021cW9BTHaQS65:DH
aQcW6<H25:D96<H47>L26<H01AcW6<HDYAS67>L011S60QcW00@HaQBU5:DHaP<Li`036<HDYAS600<L
i`055:DHaQcW7>LQ20027>L36<H37>L011S67>LLiacW0QS600DLiaS67>LLiaS6008Li`<HaP8Li`06
6<HDYAcW8@PLiaS60acW00@HaQBU5:DLi`<HaP8Li`8Q20<Li`038@PLiacW008Li`8HaP8Li`036<HD
YAS600<Li`8HaP@Li`045:DHaQS66<H37>L26<H25:D00aS67>LHaP036<H47>L00aS65:DDY@026<H0
0acW6<HHaP026<H27>L01aS65:DHaQcW6<HDYA24008HaP8DY@<HaP075:DHaQcW6<HDYAS67>L00QS6
00<@Q1BU5:D00QBU0QS61QBU0Q240aBU0Q240QBU0Q2400<DYAS66<H00QBU00<@Q1BU5:D00QBU00@H
aQcW7>LLi`8HaP@DY@0348@DYABU008DY@0348@DYAS6008DY@0348@DYABU008@Q00536<@Q12448@<
H`0248@00aBU48@DY@025:D01QS65:DDYABU48@<H`8@Q08DY@@@Q0035:DHaQS6008@Q08<H`8@Q005
5:D@Q1245:D@Q0025:D011245:DDYABU112400<DYA245:D00a2400<DYA2448@00aBU00<@Q0aS48@0
0a240QBU00<@Q0aS36<00a2400LDYAS66<HDYA245:DHaP045:D136<0000300048@0000848@030004
8@@Q00@48@099BU>LcF];F/icSg_=JdaS3W>00924003?NlicSW>00<aS08e[@03<H`]JbU:008]J`8a
S003:DXU:BU:008U:@8YBP03;F/aS2U:008U:@04:DX]Jbe[:DX39BT3:DX022DY8@PQ22U:;F/YBRDY
:DX2;F/012U:9BTYBRe[0bU:00@U:AcW9BT]J`8aS007;F/U:BDY:DX]Jc6<=Jd00RU:0RDY00<]JbU:
;F/00bDY0bU:0RDY00<Q21cW8@P00R480QcW00DQ22DY9BTU:AcW008Q20079BT]JbU:9BTQ21cW8@P0
1BDY0bU:22DY00@Q22DY9BTU:@8YBP<U:@058@PYBRU::DX]J`029BT00b489BTU:@028@P29BT01BU:
;F/U:BDY8@P00RDY00@YBRDY9BTU:@@Li`8Q208U:@03:DX]Jbe[008U:@038@PYBRDY00<Q20049BTQ
22488@P39BT2:DX01B487>LHaR487>L00R480RDY00@Q22DY:DX]J`DYBP039BTQ22DY00@U:@048@PU
:BDY8@P29BT3:DX022DY8@PLib489BTQ22DY8@P59BT38@P012DY8@PQ21cW0b480acW0R481BDY00@Y
BRDY9BTQ20DLi`<Q20DLi`036<HQ2248008Q208Li`049BTQ22487>L38@P01AcW6<HHaQS67>L00QS6
0QcW00<U:B488@P00QcW00<HaQcW6<H021S60acW0QS60QcW00@Q21cW6<HHaP8Li`<HaP037>LHaQS6
008Li`8HaP8Li`048@PLiaS66<H25:D00aS67>LQ20036<H01AcW6<HHaQS67>L00QS60QcW0R4800XL
iaS66<HDYAS67>LQ21cW6<HDY@8Li`036<HLiaS6008HaP<Li`036<HLiaS600DLi`<HaP<Li`<HaP03
7>LQ2248008Li`068@PLiaS65:DHaQcW0aS600<LiaS67>L00acW00<HaQcW6<H00acW00<DYAS66<H0
0QcW0aS611cW11S600<LiaS67>L00QcW00DHaQBU6<HHaQcW008HaP<Li`<HaP8DY@8HaP037>LHaQS6
00DHaP037>LHaQS600DHaP065:DHaQBU6<HDYAS611BU00<@Q1BU48@01A2400<<Ha245:D00QBU0QS6
1aBU0aS60QBU0QcW0aS60aBU0aS60Q2411BU00@@Q1BU5:DDY@@@Q0045:D@Q12436<35:D448@01QBU
48@@Q1245:D@Q08<H`<@Q08DY@8HaP8DY@@@Q0@DY@0348@DYA24008DY@8@Q0035:D@Q0aS008@Q08D
Y@@@Q0<DY@D@Q08DY@<@Q0045:D@Q12436<248@020aS5:DDYAS65:D@Q1S65:D348@15:D148@000H4
8@030008@P@Q00<48@079BU>Lcg_9BTe[CW>=Jd00SW>00Pmkd8@?NlmkcW><H`]Jc6<0cF]00<]JbU:
;F/00S6<00@]JbU:9BTU:@8YBP03;F/YBRU:008]J`03:DXU:BDY008YBP07;F/U:BDY9BTYBRe[:DX0
1BDY0bU:0Re[00<YBRe[;F/00RU:00<U:Be[:DX00RDY00<YBS6<<H`01BU:00TaS3F]<H`YBRDY:DX]
Jc6<:DX00bDY0RU:00<Q22DY:DX00R4800@Lib488@PQ208Li`8U:@<Q20<U:@05:DXU:BU:9BTQ2002
7>L01B48:DXYBRe[:DX00bDY0RU:1bDY0bU:00PQ22DY9BTQ22DY:DX]JbU:0RDY00<YBR488@P00R48
00@U:BU:;F/]J`@U:@03:DXU:BDY00<Q208Li`068@PU:BDY8@PU:BU:0Re[00<YBRDY9BT00RU:00LU
:B488@PQ22DY:DXU:@028@P2:DX00bDY8@PLi`028@P00bDY8@PLi`028@P00bDY:DX]J`02:DX29BT2
:DX01BDY8@PU:BDY:DX012480bDY12U:00DLib488@PU:BU:00<U:@03:DXU:BDY00@U:@<Q208U:@8L
i`036<HQ21cW008Q20@U:@<Q20<U:@038@PLib48008Q20067>LQ22488@PLiaS61AcW00@U:AcW7>LQ
208U:@068@PLiacW7>LQ21cW0aS60QcW00HHaQcW8@PYBRDY7>L26<H28@P00acW6<HHaP046<H01AcW
6<HLiaS67>L00aS600@Lib488@PQ208Li`8HaP<Li`075:DHaQS67>LHaQBU6<H00QcW00PQ21S65:DH
aQcW8@PLiaS60acW00@HaQcW7>LHaPHLi`8Q20047>LHaQBU6<H47>L36<H011cW6<HHaQS60acW00<H
aQcW6<H00QcW00@Q21S66<HLi`DHaP8Li`<HaP8Q20@Li`056<HLiaS65:DHaP037>L00aS67>LLi`06
7>L26<H01AcW8@PLiacW5:D00aS60QcW11S600HLiaBU6<HHaQcW8@P27>L26<H00aBU6<HLi`027>L0
11S67>LQ21S60QBU4aS60aBU0QS600<DYA2448@00QBU0Q2400<<Ha2448@00aBU00@@Q0aS48@DY@8H
aP0548@DYAS65:DHaP0248@25:D00aS65:DDY@027>L012487>LLiacW11BU00<HaQBU48@00a2400<H
aQBU5:D00QBU00D@Q1BU48@@Q1BU008@Q00336<@Q0aS00@DY@H@Q08DY@8@Q00436<@Q12448@25:D2
6<H25:D348@00aBU48@DY@0248@00aBU48@DY@035:D248@25:D348@00aBU48@@Q00248@35:D348@0
0aBU48@@Q00348@25:D248@236<248@25:D26<H65:D148@0000500048@0012400007124012DYAS4a
S2DY0c6<00<]Jc6<<H`01C6<0Re[0RU:0Re[00<e[Be[;F/00RU:00D]JbU:9BTU:Be[00<YBP03;F/a
S2e[00<]J`<YBP049BTYBRU:9BT28@P00bDY:DXU:@02:DX00c6<;F/YBP029BT4:DX28@P29BT00bU:
<H`aS002:DX02B48:DXaS2e[=JdaS2e[:DXU:@02;F/00bU:9BTYBP02:DX00bDY8@PQ20028@P012U:
9BTQ22480QcW00<Q22DY8@P0124800DYBRDY:DX]JbDY00<Q208YBP039BT]Jbe[008YBP8U:@03:DXU
:BDY008YBP048@PU:B48:DX3;F/00bU:9BTU:@028@P012DY:DX]JbDY0b480QcW00`HaR488@PU:B48
7>LQ21cW:DX]JbU:9BT28@P00bU:9BTQ20038@P00acW9BTU:@02;F/3:DX49BT38@P29BT28@P01BDY
8@PQ22DY8@P00RDY00DYBR488@PLiaS6008U:@8]J`<YBP039BTQ2248008U:@058@PU:BU:9BTQ2002
7>L29BT012U:;F/]JbU:0b4800<U:B488@P012DY124800@U:B488@PQ20<Li`8Q20079BTLiacW8@PL
ib489BT00bU:0RDY00<Q21cW7>L011cW0bDY00<Q21cW7>L00acW00HHaQcW8@PQ22DY8@P27>L00b48
7>LQ20027>L00aS67>LQ20027>L25:D47>L00aS67>LLi`028@P47>L01R486<HDYABU6<HLi`8HaP8L
i`056<HLiacW7>LQ20027>L01AS67>LLib487>L01QS60QBU00<HaQcW7>L00QcW00<HaQcW6<H011cW
00PHaQcW7>LQ21S65:DHaQcW0RDY0QcW00<DYAS67>L00QS600<DYAS67>L00acW11S60QBU00<HaQcW
7>L00QS60QcW00@HaQcW6<HLi`8HaP8DY@8HaPHLi`038@PHaQS600<HaP055:DHaQBU6<HLi`028@P7
7>L00aS67>LHaP046<H27>L36<H00aBU6<HHaP036<H27>L36<H011cW6<HHaQBU0QS60acW0QS600<D
YAS66<H00aS600LLiaS65:DHaQBU7>LHaP027>L011S65:DDYABU0QS600<DYAS66<H00QS6112400<D
YA2448@00Q240aBU00<@Q0aS36<00Q2400<DYAS66<H00QBU00H@Q1BU5:D@Q1BU48@36<H02aBU6<HH
aR487>LQ22DY8@PLiaBU48@00QS600<DYA245:D011240QBU1Q2400@DYA2448@@Q0<DY@0548@DYABU
48@<H`0248@011BU48@@Q1240`aS00H@Q1BU6<HHaQBU48@35:D348@00aBU48@@Q0045:D00a245:D@
Q00248@236<448@35:D00a245:D@Q00348@236<011245:D<Ha240QBU00@@Q0aS36<@Q08<H`8@Q0@H
aP8@Q0<DY@4@Q0002@@Q00P000@Q124Q24YB=JdQ22e[1C6<00<]Jc6<;F/01Re[00HYBRe[;F/aS2e[
:DX39BT2;F/012DY:DXYBRe[0RU:00DaS3F];F/YBRDY008YBPDU:@048@PU:B489BT5;F/29BT012U:
;F/]JbDY0R480RDY00D]Jc6<=Jd]JbU:008U:@04;F/e[CF]<H`2:DX3;F/6:DX012DY8@PYBRU:0RDY
0R4800XU:B487>LLibDY8@PLib489BTYBP8U:@8YBP039BTQ21cW008U:@<]J`04:DX]JbDY:DX69BT0
0b489BTU:@03:DX032DY8@PU:BDY7>LU:Be[<H`YBR486<HLi`<Q20086<HQ22DY9BTQ21cW8@PU:@8Y
BP@U:@038@PU:B4800<U:@048@PU:BU:;F/2:DX00bDY:DXYBP029BT58@P29BT00b489BTQ20028@P0
21cW:DXYBRDY8@PHaQcW9BT2:DX29BT00bU:;F/YBP028@P00bDY:DXU:@029BT58@P2:DX01Re[:DXU
:B489BTYBP8U:@8Q208U:@048@PU:B489BT58@P47>L28@P00bDY8@PLi`027>L012DY:DXYBRDY0R48
0RDY0b480acW0b4821cW00LU:BU:9BTQ21cW6<HLi`028@P47>L012486<HHaQS60QcW0QS60QcW00DH
aQcW7>LQ21cW00DHaP<Li`8HaP8Li`035:DHaQcW008Q20<Li`<Q20<HaP8Li`046<HLiaS66<H27>L0
1b486<HDYAS67>LQ21cW008HaP@Li`0:8@PHaQS66<HLibDY8@PLiaS65:D26<H37>L00aS67>LQ2002
7>L76<H011BU7>LLiacW11S600XLiaS67>LHaQBU6<HDYAS67>LHaP8Li`8Q20<Li`8HaP8DY@8HaP04
7>LQ21cW7>L26<H47>L00b486<HHaP026<H01AcW6<HLiacW6<H00QcW3aS60acW1AS600<DYAS66<H0
0QBU0QS60QcW00DDYAS65:DHaQcW00<HaP8DY@036<HLiacW00@HaP8@Q00336<@Q12400<@Q08DY@L@
Q0<DY@046<HDYABU5:D248@01ABU6<HHaQS648@00QBU00@HaQcW7>LQ208U:@057>LDYABU5:DHaP08
5:D448@00aBU48@DY@0548@45:D248@00aBU48@@Q00336<548@36<H25:D01A245:D@Q1BU48@00QBU
00@@Q1BU48@@Q0<DY@8@Q08DY@0436<@Q1BU5:D248@010aS48@@Q1BU0Q2400<<Ha2448@00Q2400@D
YA2448@<H`@@Q00436<@Q0aS36<248@011S65:DDYABU11240ABU0@aS00002000124000@Q00048@00
248312401`Q2:DYBU3W>9BT]JcW>00@e[@<icP03=Jd]JbU:008YBP03;F/YBRU:008YBP058@PU:BDY
:DXU:@028@P29BT01b48:DXU:Be[<H`]JbU:008U:@<YBP039BTYBRDY008U:@068@PU:BU::DX]JbU:
0bDY00<YBRe[:DX00bU:0R4800LU:Be[<H`]JbU:9BTYBP02<H`2;F/02C6<;F/YBRDY;F/aS2U:9BT]
J`02<H`2:DX00be[:DXU:@039BT00b487>LQ20029BT01RU:9BTU:BDY8@PYBP8]J`03=JdYBR48008Q
2007:DXU:BU::DX]JbU:9BT00b480bDY0R4800@U:B489BTU:@LQ20037>LQ2248008Q208U:@8Li`04
9BT]Jbe[:DX38@P00bDY:DXYBP029BT28@P29BT01b489BTU:BDY8@PU:BU:008]J`03:DXU:BDY008U
:@038@PU:AcW00DQ20059BTQ22487>LQ2003:DX00bDY8@PQ20028@P012DY:DXYBRDY0bU:00PQ22DY
8@PU:B489BTQ22DY0R4800<U:B48:DX00be[00<YBRDY9BT00bDY0R4800@Lib489BTYBP8U:@078@PU
:B489BTLiaS67>L00b480QcW0b480bU:00<Lib489BT00RDY0QcW00DQ21cW7>LLibDY00<Q20PLi`03
8@PLiacW00HLi`038@PLiacW008HaP8Li`@HaP8Li`036<HLiacW008Li`076<HLiacW6<HLiaS67>L0
0QS60QcW0R480aS600<LibDY7>L00QcW00<Q21cW7>L00QS600<LiaS67>L00acW00@Q21cW7>LHaPDL
i`056<HDYAS67>LQ20026<H00acW8@PQ20027>L56<H25:D00aS67>LQ20026<H27>L01b487>LHaQcW
6<HDYAS600<Li`046<HLiacW7>L26<H00aBU6<HHaP046<H01AcW6<HLiacW6<H011cW00@HaQBU6<HL
i`8HaP035:DHaQcW00<Q20HLi`035:DHaQS600PHaP047>LHaQS66<H27>L01aBU6<HHaQcW6<HDYAS6
008Li`<HaP057>LQ21S66<HDY@026<H011BU6<HLiacW0aBU0QS60QBU00<HaQcW6<H00QBU0aS60QcW
00@HaQBU5:DDY@8@Q00336<@Q1BU008@Q0045:D@Q1BU5:D248@010aS48@DYABU0aS61QBU0QS600LD
YA245:D@Q1S67>LQ20029BT012U:8@PLiacW0QBU00<@Q1BU5:D01ABU0Q2400<DYA245:D00QBU00<@
Q1BU48@00Q241QBU0Q2400@DYA2448@<H`88@P<@Q0LDY@0448@DYA245:D248@01ABU48@DYA2436<0
0Q240QBU00H@Q0aS5:DDYA245:D248@011BU48@DYABU0Q2400@<Ha2448@<H`8@Q08DY@0348@<Ha24
00<<H`8@Q00636<@Q1245:DLiaBU0Q2400@<HaBU6<HDY@4@Q00030@Q00LU:EJe?NlU:Be[=JdaS003
>Lh2<H`013F]>Lhe[C6<22U:00<U:B488@P00R4812DY00<Q22DY:DX00RU:0Re[12DY00<YBRDY8@P0
0b480bU:0Re[00<YBRDY9BT00bU:010U:BU:7>LLibDY:DXaS3F];F/U:B48:DXaS3F]<H`U:@8YBP04
;F/aS36<:DX29BT012U:;F/YBRU:0Re[00PYBRDY9BTYBRDY8@PLib480RDY00<Q22DY:DX00bDY00DY
BS6<<H`YBRDY008Q20039BTYBRDY00<YBP<U:@8Q20@U:@8Q20059BTQ22DY8@PU:@0:8@P012DY7>LQ
22U:0Re[00DU:AcW8@PYBRDY008YBP@U:@038@PU:BDY00<U:@068@PU:BU:;F/YBR480bDY00<YBRDY
7>L00R480RDY124800LU:B488@PU:BU:9BTQ20027>L00b489BTU:@029BT3:DX79BT012489BTQ21cW
0R4800DYBRe[<H`aS2e[00<U:@8Q20049BTQ22487>L39BT48@P00acW8@PQ20028@P01acW6<HLiacW
8@PU:B48008YBP059BTQ22488@PU:@048@P01QcW8@PQ21cW8@PLi`8HaP8Li`058@PLiaS68@PU:@02
8@P021cW8@PLiaS67>LQ22DY8@P27>L46<H28@P00acW6<HHaP036<H37>L00b487>LLi`036<H37>L2
6<H00acW8@PLi`036<H01R487>LHaQcW9BTLi`HHaP8Li`<Q20LLi`DHaP<Li`8HaP037>LQ21cW008L
i`<HaP045:DHaQcW7>L36<H01B487>LLiaS68@P00QS600<DYAS66<H00QcW0QS60QcW0QS60QBU0aS6
00<LiaS67>L00QcW00HQ21cW7>LLiaS67>L26<H01aBU6<HHaQS65:DHaQcW00@Q20057>LHaQS65:DL
i`066<H37>L011S65:DHaQBU0acW00DHaQBU7>LLiaS6008DY@056<HLiaS66<HDY@037>L00aS65:DD
Y@026<H011BU6<HHaQS60QBU00DLiaS65:DDYAcW008HaP@DY@@HaP085:DHaQS65:D<Ha2436<DY@<@
Q0065:D@Q1BU48@DYA240PaS00<DYAS66<H00aBU0Q2400@DYAS66<HHaP8DY@0648@DYAS66<HLib48
0bDY00DLiaS65:DHaQBU008@Q0@DY@<@Q0045:D@Q12448@25:D010aS48@@Q1S60QBU00P@Q1BU48@@
Q1BU48@<Ha240`aS0Q2400<<Ha2448@00QS60aBU00<@Q1BU5:D00aBU1A2400<DYA2448@00a2400<D
YA2448@00`aS0aBU0Q240PaS1Q2400<DYA2448@00a2400<<Ha245:D00Q2400H<Ha246<HHaQBU6<H5
48@136<0000500048@001240000512402P00248U:E[FBU8]Jc6<;F/aS3W>13F]00@icSF]<H`]J`8Y
BP@aS003:DXU:BDY008YBP03;F/YBRe[00<YBP07;F/YBRe[:DX]JbDY:DX00Re[00<YBR487>L01R48
00PU:BU::DXYBRDY:DXQ22DY0bU:00@Q22DY8@PYBP@]J`039BTYBRe[008aS003:DX]Jbe[00<]J`03
:DX]JbU:008]J`8aS003;F/YBRU:008YBP8Q20<U:@048@PU:BDY9BT48@P69BT48@P29BT68@P39BT3
8@P59BT01248:DX]JbU:0R4800@U:C6<;F/U:@<Q20037>LU:BU:008YBP8Q20049BTYBRU:9BT48@P5
9BT28@P022DY:DXU:B487>LQ22U:9BT28@P39BT01B489BTQ22489BT00R4800@U:BU::DXYBP<Q2009
7>LU:BU:;F/YBR489BTYBRDY00<Q20@U:@@Q20039BTYBRe[008YBP8U:@8YBP059BTQ21cW8@PU:@05
8@P29BT01BU:8@PQ21S67>L00R4811cW0bDY12480RDY00<Q21cW7>L00RDY00<LiaS66<H0124811cW
124800HU:AcW7>LLiaS67>L28@P27>L00aS67>LLi`027>L012487>LLiaS60QcW11S60R4800HLiaS6
6<HLib487>L26<H011cW8@PLiaS60QcW00LHaQcW7>LLib489BTLi`036<H37>L26<H00acW8@PLi`04
7>L46<H01QcW6<HHaQS65:DHaP@Li`8HaP<Li`056<HDYAS66<HLi`026<H01ABU6<HHaQS67>L00aS6
00<DYAS66<H00QS60QcW0aS600@DYAS66<HDY@HHaP@Li`036<HQ21cW00@HaP8Li`046<HDYAS66<H2
8@P02AcW8@PLiaS67>LHaQcW6<HDY@026<H27>L00aBU6<HHaP028@P26<H00aBU6<HLi`047>L26<H0
0aBU6<HHaP027>L02AS67>LQ21cW6<HDYAS67>LHaP025:D36<H35:D26<H35:D011S65:DDYABU0QS6
00<LiaBU5:D01QBU00<@Q1BU48@00QBU00<@Q1BU36<00a240QS600@DYA2448@DY@<HaP8DY@8HaP04
8@PLiaBU5:D248@27>L48@P27>L011S67>LHaQBU0a2400<DYA2448@00QBU0a2400DDYA2448@@Q1BU
00D@Q0035:D@Q1BU00<@Q0L<H`<@Q08DY@046<H@Q1BU48@25:D236<00a245:DDY@0548@25:D01A24
36<@Q1S65:D01A2400DDYA2448@@Q0aS008@Q0045:D@Q12448@35:D248@00`aS5:D@Q00336<011BU
6<HDYABU0PaS00D@Q1BU5:DDYA240048@P001P@Q00<000Q212400`@Q00LYBU[FAS4YBRe[<H`e[@02
>Lh2=Jd01CW>=Jde[C6<;F/00RU:00HaS3F]<H`aS2DY8@P29BT5:DX01S6<;F/YBRe[:DXaS08]J`8U
:@8YBP039BTQ2248008Li`<Q208U:@05:DXU:B488@PU:@02:DX01bDY8@PYBRDY8@PU:BU:008]J`04
9BTYBRU::DX3;F/2:DX00be[<H`]J`03:DX012e[<H`]Jbe[0RU:00H]JbU::DXQ22DY8@P49BT00b48
9BTQ20048@P012DY:DXYBRDY0QcW0R4800DU:B488@PQ21cW008U:@088@PU:B489BTQ22DY8@PU:@8Q
20039BTQ22DY00HU:@<YBP<Q200<7>LU:BU::DX]JbU:8@PLib489BTYBRDY0R4800<U:BU:8@P01BDY
0bU:00<U:AcW8@P00bDY0R480RDY124800<U:B488@P00RDY0bU:0RDY00<Q21cW9BT00be[00HU:B48
:DXU:BU:8@P29BT012U:9BTQ21cW0b4800HU:BU::DX]JbDY8@P29BT2:DX38@P012DY8@PQ22480RDY
124800<Lib488@P00b4800<HaQcW7>L00RU:00HU:B487>LLib489BT48@P012DY8@PQ22480QS600@L
ib488@PQ208Li`8Q20039BTQ2248008Li`036<HLiacW00HLi`056<HLiacW8@PLi`026<H00acW6<HL
i`077>L36<H37>L01AS67>LLiacW8@P01QcW12480QS600@Lib487>LLi`<HaP@Li`036<HLiacW008L
i`056<HLiacW7>LHaP027>L01b486<HHaQcW8@PLiaBU008HaP048@PHaQS67>L36<H00aBU6<HLi`02
7>L56<H011cW6<HHaQS60QcW00LHaQcW7>LDYAS65:DHaP037>L00aS65:DLi`038@P01AS67>LHaQS6
5:D00aS600@DYAS66<HHaP8Li`058@PLiacW7>LHaP037>L26<H27>L36<H47>L56<H01AcW8@PLiacW
5:D00QS600<LiaS67>L00QcW00HHaQcW7>LLiaS65:D46<H011BU6<HDYAS60QBU0aS61QBU00LLiaS6
6<HDYA245:DHaP035:D01Q2436<@Q1245:DHaP8DY@0348@<Ha24008DY@066<HDYA245:DLiaS60QBU
00<HaQBU6<H00QcW00HHaQBU48@DYAcW6<H28@P022DY8@PLiaS67>LHaQBU48@35:D248@011BU48@D
YA2411BU0a2400@DYA2448@@Q0<DY@8@Q00336<@Q124008@Q08<H`8@Q08DY@<@Q08DY@0336<DYABU
008@Q00336<@Q1BU008@Q0045:D@Q12436<248@011BU48@DYA240aBU0Q2400DDYA2448@@Q0aS00<@
Q08DY@0348@DYA24008@Q0035:D@Q124008<H`<@Q0055:DHaQS65:D<H`0448@15:D148@124800003
00048@0000P48@0;248]Jekg@Q0Q22e[=JdaS3F]>Lhe[@02<H`012U:;F/aS3F]0SW>00DaS3W><H`a
S2e[00@YBP059BTYBRU:9BT]J`02<H`012U:;F/aS36<0RU:00H]JcF]<H`YBQcW8@P29BT00bU:;F/]
J`02:DX00bDY:DX]J`03:DX39BT012489BTU:BDY0b4800<U:B489BT00bU:0bDY12U:00<U:BU::DX0
1BU:00<U:B489BT00b4800HLibDY8@PQ22U:9BT38@P02RU:;F/YBRDY:DXU:BU:9BTQ22DY0bU:0bDY
0RU:0bDY00@YBRDY:DXYBP8U:@037>LU:BU:008YBPPU:@047>LQ21cW9BT4:DX02RDY:DXU:AcW8@PL
ib487>LQ22DY0RU:00<U:B488@P0124800HLib488@PQ22DY8@P39BT38@P29BT48@P012DY:DXYBRU:
0RDY00@YBRe[;F/YBP@U:@<Q208YBP049BTLiaS67>L28@P012DY8@PU:BU:0be[00DYBRDY9BTYBR48
00<Li`8U:@058@PU:BDY8@PU:@028@P27>L28@P012DY8@PHaQS60QcW00<Q22DY9BT011cW0R4800<L
ib488@P00R481AcW00<Q21cW7>L00QcW0R4800@U:BU:8@PQ208HaP8Li`038@PLiacW00<Li`<HaP8L
i`038@PLiacW008HaP037>LQ21cW008HaP8Q20<Li`<Q20<Li`049BTQ22485:D26<H57>L00aS65:DH
aP026<H27>L01QS65:DDYAcW8@PLi`8HaP8Li`<HaP8DY@8HaP<Li`038@PLib4800DLi`8HaP8DY@8H
aP<DY@8HaP035:DHaQS600@HaP035:DLiacW008HaP037>LHaQcW008DY@056<HLib487>LHaP027>L0
0aS67>LLi`027>L46<H01ABU6<HHaR487>L00QS60acW00<Q21cW7>L00aS60acW00DQ21S66<HHaQBU
00@Li`8HaP037>LHaQS600HHaP037>LHaQS6008HaP037>LHaQBU008DY@066<HDYABU5:D@Q1BU0aS6
0QBU00<HaQBU5:D00aBU00D@Q1BU6<HLiaS6008DY@046<HDYABU48@25:D448@25:D00aS65:D@Q002
36<011245:DDYABU11S60aBU00<HaQcW7>L00QcW0QBU00<@Q1BU7>L00QcW00HQ21cW6<HHaQBU6<H2
48@25:D00aS65:DDY@0348@25:D248@25:D348@25:D02a2436<@Q1245:DHaQ245:D@Q0aS24800PaS
00<@Q0aS5:D00aBU0Q2400@DYA2448@@Q08DY@8@Q00336<DYABU008DY@0648@<Ha2436<@Q0aS0Q24
00@DYA2448@<H`8DY@D@Q00336<@Q124008HaP@@Q0035:D@Q12400<@Q00536<@Q1245:DHaP0248@0
1@aS48@DYABU48@00`aS000312400`001240000212402@Q200048@Q2;F]Nmd8@8@PYBP02<H`013W>
=Jde[CF]1C6<00HicSF]=JdaS2e[<H`2;F/012DY:DXYBRU:0RDY00@YBRe[;F/]J`8YBP8aS003;F/U
:Be[008aS006:DXQ22489BTYBRe[0RU:0Re[0bU:00<aS2e[9BT022DY0R4800<U:B489BT012U:00@Q
22DY:DXYBP<U:@07:DX]JbDY9BTYBRe[:DX00RDY00<Q22DY9BT00R480QcW00PU:BU::DXQ21cW8@PU
:Be[12U:00<U:B488@P00RDY0RU:0RDY00L]JbU:9BTQ22DY:DXU:@04:DX28@P29BT00bU:9BTYBP02
9BT2:DX29BT48@P00bDY:DXYBP03:DX00bDY8@PU:@047>L02248:DXYBRU:9BTQ21S68@P29BT01248
7>LQ22DY0b4800<U:B488@P00R4800<U:B488@P01RDY00@YBRe[9BTU:@8YBP8]J`03:DX]JbU:008U
:@037>LU:BDY008YBP8Q20037>LQ2248008U:@03:DX]Jc6<008]J`@U:@048@PLiacW8@P79BT28@P2
7>L012DY8@PQ22DY11cW0bDY00PLib487>LLib487>LQ22DY21cW00<U:B487>L00QcW00<U:B488@P0
0RDY1acW00<HaQcW8@P00QcW00<DYAS66<H011cW00DHaQcW7>LHaQcW00@HaP038@PLib48008Li`06
8@PHaQS67>LQ21cW0aS61AcW00DHaQcW5:DDYAS6008Li`058@PLiacW7>LHaP057>L00aS67>LHaP02
5:D02AS67>LLiaS65:DHaQcW9BTQ20037>L26<H25:D00aS67>LHaP025:D00aS67>LHaP026<H00acW
6<HHaP076<H01QcW6<HLiacW6<HDY@8HaP057>LQ21cW7>LHaP027>L00aS67>LLi`027>L86<H47>L3
8@P011cW6<HHaQS60R480QS60acW00<HaQcW7>L00QS60QcW00<Q21S65:D01aS600PLiaS66<HDYAS6
5:DHaQBU0QS60aBU0aS60QBU00DHaQBU6<HHaQ2400<DY@077>LHaQS66<HLiaBU48@00QBU0QS600D@
Q1BU48@@Q1BU008@Q08DY@@@Q08DY@046<HDYAS66<H45:D47>L00aS65:D@Q0025:D57>L011S67>LD
YABU0Q2411BU00<@Q1BU5:D00QBU1a2400@DYA2448@<H`8@Q08DY@0348@<H`aS00H<H`D@Q0045:D@
Q12448@35:D01Q2436<<H`aS5:D@Q0<DY@0448@<H`aS48@25:D011S648@@Q1240QBU0Q240`aS0Q24
00@DYA2448@@Q08DY@0348@HaQBU00<@Q0055:D@Q12448@<H`035:D348@00aBU48@<H`0248@136<0
000300048@@Q00T48@06;F]F]Cg_8@P]JcW>0cF]136<0SF]00<aS2e[<H`01C6<0RU:00<U:Be[;F/0
0Re[0RU:12e[0bU:00D]JbU:;F/]Jc6<00<YBP8U:@8YBPP]J`039BTQ22U:008]J`069BTQ22DY;F/Y
BRe[1C6<00D]Jc6<<H`]JbDY008YBP04<H`]JbDY:DX4;F/00bU:8@PU:@049BT3:DX00bDY:DXQ2003
9BT4:DX49BT5:DX3;F/02RU:9BTQ22U:;F/aS2U:9BTQ22DY12U:00<U:B489BT00RU:00P]JbDY8@PQ
21cW9BTYBRDY0RU:00<U:B488@P00RDY00<Q21cW7>L00R480bDY00@YBRDY8@PQ208Li`TQ208U:@03
8@PLiacW008U:@078@PLibDY:DX]JbDY8@P00bDY00D]Jc6<;F/]JbDY00<Q20@U:@8Q20039BTQ21cW
008Q20DYBP@]J`089BTQ21cW7>LU:B489BTQ20HU:@DQ20097>LQ22487>LQ22DY8@PU:B4800DLi`DQ
20057>LQ22DY8@PLi`028@P37>L012DY:DXU:B480RDY00DQ21S66<HHaQcW00DQ208Li`<HaP8Li`03
8@PLiacW008HaP8Li`056<HLiacW8@PLi`026<H011cW6<HLib480RDY00LLib488@PQ21S65:DHaP02
7>L36<H47>L26<H00acW6<HHaP047>L56<H011cW6<HHaQS60R4800DLiaS67>LQ21cW00PHaP035:DH
aQS600XHaP8Li`8HaP@Li`8DY@076<HLiacW7>LHaQBU7>L00R4800HLiaS67>LLib489BT26<H01ABU
6<HLiacW6<H00QcW00<HaQcW7>L00QcW00<Q21S67>L00QcW00<Q21cW7>L00QcW00DHaQcW6<HLiaS6
00@Li`038@PHaQcW00<HaP037>LHaQS600HHaP035:DHaQBU00@HaP8DY@036<HDYABU00@HaP@DY@8H
aP<DY@8HaP8DY@0548@DYAS66<HDY@0248@010aS5:DDYABU1A240aBU00@HaQcW7>LLi`8DY@<HaP06
8@PLiaS648@<Ha240acW00<Q21cW6<H00aS600<DYAS65:D00QBU00@HaQBU5:D@Q08DY@<@Q08DY@06
48@<Ha245:DHaQBU0a240QBU0a2400@<Ha2448@@Q08<H`8@Q0<DY@@@Q0035:D@Q1BU00H@Q0035:D@
Q1BU00<DY@8@Q08DY@0448@DYA245:D348@00`aS48@<H`0236<248@25:D348@25:D01AS65:DDYA24
5:D00a240QBU0a2400<<Ha2448@00Q240ABU0A240@aS000312400`001240000212402@Q2124000Q2
;F]JeSW>8@P]J`03>Lh01SF]<H`]Jbe[<H`icP8e[@DaS003=Jd]Jbe[00LYBP05<H`]Jbe[;F/YBP02
;F/01BU:;F/aS36<;F/00RU:00D]JbU::DXYBRDY008YBPH]J`04:DXU:BDY:DX2;F/00bU:9BTU:@02
:DX00be[:DX]J`03<H`00be[<H`e[@02;F/00bDY:DX]J`04:DX2<H`01Be[:DXU:BDY:DX00bDY00<Y
BRDY9BT00RU:0RDY00<Q22DY;F/00Re[00<YBRDY9BT012DY00<YBRDY:DX00Re[0RU:00<Q22DY9BT0
0RU:00P]JbU:9BTQ22U:;F/YBRDY0R4800DU:BU:;F/]JbDY008Q20039BTYBRDY00<U:@0;:DXU:BDY
9BTQ21cW8@PLib487>LQ2003:DX01BDY8@PU:B487>L00R4800<U:B488@P00acW00<U:B487>L00R48
0bDY00<Lib488@P00bU:12DY0Re[00<aS2U:8@P00RDY00<Q21cW8@P00bDY00@Q21cW7>LLi`8Q2004
9BTYBRU:9BT2:DX3;F/012DY8@PQ22DY0R4800@Lib488@PQ208U:@03:DXQ2248008Q20069BTYBR48
7>LHaR480RDY124800<LiaS67>L00R480RDY0b480acW00<Q21cW7>L00QcW00HQ21cW9BTYBRDY:DX3
7>L011S68@PQ21cW12480QcW0QS600<LiaS67>L00acW00<HaQcW7>L00acW00<Q21cW7>L00QS60QcW
00<Q22DY9BT00QcW00@HaR487>LLi`8HaP057>LHaQS65:DHaP057>L012487>LHaQS60acW0QS600@L
iaS65:DHaP8Li`075:DHaQS67>LQ21cW8@P00QcW00LQ21S66<HHaQBU6<HLi`026<H25:D00acW6<HH
aP026<H35:D01QcW8@PLiaS67>LHaP8Li`036<HLiaS6008HaP047>LHaQS66<H27>L00b487>LLi`06
7>L01AS65:DHaQS65:D01AcW00<HaQcW7>L00acW0QS600<Lib488@P00aS61AcW0QS600@LiaS67>LL
i`<HaP037>LHaQS6008DY@036<HDYAS6008HaP045:DHaQS66<H25:D36<H25:D011S67>LHaQS611BU
11S600@LiaBU5:DDY@8HaP@DY@@@Q0<DY@0548@<Ha245:D@Q0035:D01AcW6<HDYA245:D00QS600<D
YAS67>L00QS600@DYA245:DHaP8Li`8HaP037>LHaQS6008HaP0348@DYA24008DY@<@Q0<DY@<@Q08D
Y@0336<DYABU008DY@<@Q0035:D@Q12400@@Q00336<@Q0aS008@Q08DY@8@Q0055:D@Q12448@DY@04
48@01@aS48@DYA245:D00a2400<DYA245:D00QBU00H@Q0aS48@@Q1S65:D348@00`aS48@<H`0236<0
11245:D@Q1240aBU00<@Q1BU5:D00a240aBU00@@Q1BU48@@Q08<H`0548@<Ha2448@DY@0136<00003
00048@0000T48@069BUF]Cg_9BTaS3F]0SW>00He[C6<;F/e[C6<;F/2=Jd00c6<:DXYBP02<H`012e[
9BTU:Be[0RDY0RU:00@aS2e[:DX]J`<YBP8]J`<aS08]J`03:DXU:BDY008YBP04;F/YBRU::DX2;F/2
<H`013F];F/U:BDY0bU:0RDY0RU:00D]JbU:;F/e[C6<008icP05<H`]JbU::DX]J`02:DX02Be[9BTQ
22DY;F/e[C6<:DXQ20049BT01RU:;F/U:BDY:DX]J`<U:@03:DX]Jbe[008YBP8]J`06:DXQ22489BTY
BRDY0R4800<U:BU::DX00RU:00PU:B489BTYBRe[:DXQ21cW0b4800TU:B489BT]JbU:9BTLib48:DX0
0RDY00<YBRDY9BT00R4800<U:B488@P00R480QcW00@HaR489BTU:@8Q20<U:@@Q20037>LQ2248008L
i`046<HQ21cW7>L38@P00bDY7>LLi`028@P39BT2;F/012DY8@PU:Be[0S6<00<U:BU:9BT00R4800LL
ibDY;F/YBRDY8@PLi`028@P011cW8@PU:BU:0RDY00<YBRe[;F/00RU:0RDY0b4800DU:B489BTLib48
00<U:@068@PU:BU:9BTLib480RDY0b4800<YBRDY8@P00R4800@LiaS66<HLi`8Q20049BTYBR488@P2
7>L00b486<HHaP027>L29BT012U:9BTYBRU:0R4800@LiaS67>LLi`<Q20<Li`8HaP8Li`8HaP<Li`04
6<HLiacW7>L36<H00acW6<HLi`027>L011BU6<HLiacW0R480acW00<Q21cW6<H01QS60QcW0b4800<L
iaS66<H01QS60QcW00@DYAS65:DDY@<HaP<Li`8Q208Li`046<HDYAS66<H27>L011S65:DLiacW0QS6
00XLib486<HHaQBU6<HLib487>LHaP8DY@8Li`038@PLiaS600<Li`056<HLiacW6<HLi`028@P01BDY
7>LLiacW6<H00QcW0aS600DDYAcW7>LLiaS6008Li`039BTQ21cW00@Li`<Q20037>LDYAS6008Li`8H
aP037>LHaQcW008Li`035:DHaQS6008Li`<HaP037>LDYABU008HaP047>LDYABU5:D36<H01ABU6<HH
aQcW6<H00QBU00<HaQBU5:D01AS600<DYAS65:D00QS611BU0aS600DDYAS648@DYA2400<DY@0448@8
@Q2448@25:D00a245:DHaP027>L26<H01QBU48@DYABU7>LHaP8DY@0348@HaQBU008DY@@HaP8DY@<H
aP045:D@Q1BU48@55:D348@011BU48@@Q1240aBU00<@Q1BU48@00QBU0Q240`aS1a240aBU00@@Q0aS
48@DY@X@Q0055:D@Q1BU5:DHaP027>L25:D236<248@25:D00a2436<<H`0236<00a2436<@Q00348@4
5:D248@75:D548@00aBU48@@Q00248@15:D136<000H48@0=0008@P@Q00048@Q2:DY>LcF]8@PaS3g_
>Lh00cF]00<aS2e[<H`00cF]0be[00<e[C6<;F/00RDY00@YBRDY9BTYBP8]J`03:DX]Jbe[00<]J`06
9BT]Jc6<<H`e[C6<0RU:00DQ22DY:DXYBRe[00DYBP04;F/e[C6<;F/29BT00bU:;F/YBP03:DX00bDY
:DXaS002=Jd01CW><H`e[Be[<H`00be[0bU:00@]JbDY9BTYBP8aS003;F/U:B48008U:@03:DX]JbU:
008U:@<]J`<U:@8YBP06;F/YBRDY;F/YBRDY0R4800<U:B489BT00RDY12U:00DQ22DY:DXU:BU:008U
:@@Q208U:@03:DX]JbDY008U:@8YBP049BTQ22DY:DX39BT012489BTU:B480QcW00<HaR487>L00RDY
00<YBRDY8@P00R480RDY0acW00<Q22DY8@P00acW00@U:B489BTLi`HQ20089BTQ22DY:DX]JbU:8@PY
BP8aS003:DXQ22U:008U:@088@PU:BU::DX]JbDY8@PLi`8Q20037>LQ22DY00TYBP039BTQ2248008Q
20039BTQ2248008U:@05:DXU:BDY8@PU:@02:DX48@P29BT28@P01bDY8@PLiaS68@PLiaS6008Q2003
:DXU:B48008Q20<Li`048@PLiacW8@P3:DX39BT37>L01BDY7>LLiacW8@P011cW0R4800HLiaS66<HL
ib487>L26<H28@P26<H011cW8@PLiacW0QS611cW0b4811cW1QS60QcW00<Q21cW7>L00acW00@HaQBU
5:DDY@8Li`@HaP055:DHaQBU6<HDY@036<H27>L012487>LHaQBU0QS600@LiaS66<HDY@8HaPDLi`@H
aP037>LHaQcW00<HaP<Li`8HaP045:DLiaS67>L26<H011cW6<HQ22DY0R480QS60acW0aS600<DYAS6
7>L00acW0R4800<U:B486<H00QS600@Lib488@PQ20<Li`LHaP037>LHaQcW008Li`LHaP@DY@<HaP03
5:DHaQS6008HaP037>LHaQBU00<DY@HHaP0448@DYABU6<H27>L00aS648@DY@025:D00aS648@DY@02
5:D348@01aBU48@@Q12436<@Q1BU00<@Q0055:DLiacW6<HDY@0248@01aS67>LHaQS65:D@Q1BU008@
Q0055:DHaQS67>LHaP065:D00aS65:D@Q0065:D00a245:D@Q00448@35:D01Q2436<@Q1BU6<HDY@8<
H`8@Q08<H`8@Q0045:D@Q12448@25:D448@01QBU48@<H`Q248@DY@8HaP0748@<Ha2448@DYAS65:D0
0QS60QBU00@@Q1BU5:DDY@D@Q00436<@Q0aS36<248@010aS48@@Q1BU0QS611BU00D@Q1BU5:DHaQBU
00<@Q00436<@Q1BU48@236<348@0000400048@@Q000812401R48CW<icRU:=JdicP8aS003=JdaS2e[
008]J`05=JdicSF]<H`e[@02;F/2:DX02Be[:DX]JbU:;F/YBRDY:DX]J`02<H`2;F/2:DX012e[<H`a
S2e[0bU:00TaS2U:<H`e[Be[:DXU:BU:;F/00RU:0S6<00D]JbU:9BT]JbU:008U:@03;F/aS36<00<a
S00:;F/YBS6<=JdicS6<9BTQ22DY:DX2;F/2:DX2;F/01RU:;F/aS2e[:DXQ20<U:@04:DX]Jbe[:DX2
9BT01BU:9BTU:BU:<H`00Re[0R4800@U:BU::DXU:@8Q20049BTYBRU::DX39BT02bU:9BTYBRe[:DXU
:B487>LU:B489BT00R481BDY00<Q22DY:DX00RU:00DU:B488@PU:BU:008U:@HLi`068@PU:BDY8@PH
aR480RU:00@U:AcW8@PU:@@Q20<Li`038@PU:BDY008U:@068@PLib488@PYBRe[0RU:1RDY00DYBRDY
8@PU:B48008U:@8YBP8U:@058@PLib488@PLi`029BT2:DX01RDY:DX]JbU:9BTQ20<U:@@Q20039BTQ
2248008Q208YBP8U:@048@PU:BDY9BT28@P39BT27>L39BT00acW6<HLi`068@P47>L58@P00bDY8@PQ
20028@P01BDY8@PLiaS67>L00R481AcW00<HaQcW7>L00aS600<Lib487>L00acW00LHaQcW6<HLibDY
8@PLi`036<H01AcW8@PQ22487>L00QS60acW0QS600<LiaS66<H00QcW0R4800<LiaS66<H011S60QcW
00DHaQ245:DDYAcW008HaP037>LHaQcW008HaP057>LHaQcW7>LQ20036<H011cW6<HDYABU0QcW00PD
YAS66<HLib487>LHaQcW1QS600<LiaS66<H01AS60acW00<Q21cW8@P01acW00@Q21S66<HDY@8HaP06
7>LHaQS66<HLib480QcW00DQ21cW7>LLiaS600@Li`DHaP8DY@056<HLiacW7>LQ20057>L46<H35:D2
6<H35:D01aS65:DHaQS67>LHaQBU00@HaP035:DHaQS6008HaP035:DHaQBU008HaP055:DHaQBU5:D@
Q0065:D248@00`aS48@@Q00248@010aS48@@Q0aS0Q2411S61ABU00@HaQcW6<H@Q08DY@036<HDYA24
008DY@8HaP045:D@Q1245:D26<H011BU48@@Q1240QBU00@@Q1BU5:DDY@@@Q0035:DHaQBU00<DY@03
6<HDYABU008<H`0548@<H`aS36<@Q00436<248@00aBU48@DY@0348@01aBU36<<H`aS48@DYA24008D
Y@0348@DYA24008DY@@HaP035:D@Q12400<DY@<@Q00536<@Q1BU48@DY@0348@011BU48@@Q12411BU
00XHaQ2448@@Q1BU6<HDYA245:D<H`8@Q00336<@Q0aS008@Q04DY@4@Q00000<48@0012400P@Q00<0
00@Q124010@Q00@Q24ic>Lh]J`<e[@03;F/aS36<00HaS08icP8aS08YBP@]J`08<H`YBRDY:DX]Jc6<
;F/YBP@]J`04<H`e[C6<;F/29BT01Be[<H`aS36<:DX00Re[00@YBRe[:DXYBP8]J`8YBP069BTYBRU:
:DX]JbU:1C6<00<]Jc6<=Jd00SF]00XaS2DY9BTU:BU:<H`]JbU:;F/aS08]J`04<H`]JbU::DX29BT0
1bU:9BT]Jbe[<H`]JbU:00<Q2007:DXaS2e[;F/YBRDY8@P00RDY00DYBRDY9BTU:BU:008U:@8Q2003
9BTYBRU:008U:@8]J`04:DXQ22489BT38@P39BT012U:9BTQ22480RDY00<YBRDY9BT00b480bDY00@L
iaS66<HDY@8Q20<U:@037>LQ22DY008YBP039BTQ224800<U:@8Q20037>LU:B48008Q20<U:@8Q208U
:@<YBP039BTYBRDY00DYBP8U:@058@PU:BDY9BTYBP029BT58@P39BT00bU:9BT]J`02:DX89BT48@P7
9BT48@P29BT012489BTU:BDY0R4800<U:AcW8@P00QcW124800<U:B488@P00acW0b481RDY0R4800<L
iaS67>L00QcW00<Q21cW8@P00R4811cW00<HaQcW7>L00QcW0R4800HLiaS66<HLiaS68@P27>L26<H0
1acW8@PQ22486<HLiaS600<Li`<HaP085:DHaQS68@PLib487>LQ208Li`8HaP037>LHaQcW008Li`8H
aP035:DHaQ2400<HaP038@PLiacW00<HaP047>LQ21cW7>L36<H00acW6<HLi`026<H37>L26<H27>L2
6<H012486<HDYAS60acW00<HaQcW6<H00aS600<Lib487>L00acW00DQ22DY9BTQ21cW008HaP067>LH
aQcW6<HDYAS60QcW00@DYAcW7>LQ20<Li`038@PLiaS600@Li`036<HLiaS6008Li`046<HDYAS66<H8
7>L36<H35:D36<H00a245:DDY@035:D27>L26<H35:D01aS65:DHaQS67>LHaQBU00<HaP035:DHaQS6
00<DY@047>LHaQ245:D26<H01ABU48@DYABU48@00PaS11240QBU00<@Q1BU6<H00QcW11BU00<HaQcW
7>L00QS60Q2400<DYA245:D021BU0QS600PDYA2448@DYAS65:D@Q1BU11240QBU00D@Q1BU48@DYA24
00<DY@0536<@Q1245:D@Q00336<0112436<@Q1240QBU0Q240PaS00D@Q1BU5:D@Q1BU00<@Q0<DY@8@
Q0045:D@Q1BU5:D26<H45:D248@35:D0112436<@Q0aS112400@DYA2448@@Q08DY@066<HDYABU48@D
YA240QS600<DY@aS48@00QBU00@@Q0aS48@DY@8@Q08DY@4@Q0000P@Q00<000@Q12400`@Q00X8@P00
12448BDYDY@icRDY=JdicP8e[@07<H`e[Be[<H`e[CW>?Nl00SF]00@icS6<;F/YBP8]J`<YBP06<H`Y
BRU::DX]Jc6<0be[0c6<0RU:00PU:Be[:DXYBS6<=JdicSF]0RDY0RU:0Re[00@YBRDY:DXYBP8]J`07
:DXU:BDY:DX]Jc6<=Jd0136<0SF]00/aS2U:9BTYBRe[<H`YBRDY;F/aS2e[008YBP<]J`8YBP@U:@<Y
BP<U:@8]J`8YBP03;F/YBRDY00HU:@038@PU:BDY008Q20LU:@0::DXU:BDY8@PLib489BTQ22DY8@P2
9BT28@P29BT2:DX39BT00b489BTU:@038@P77>L39BT01b489BTU:B487>LQ22DY008YBP038@PU:B48
00@Q20069BTYBRDY8@PLib480RDY0bU:0R4800@U:BU:;F/YBP8U:@@Q208YBP<U:@8Q20037>LQ22U:
00<YBP039BTYBRU:008YBP8U:@<Q20039BTQ22DY008Li`8Q20DU:@<YBP049BTQ22488@P29BT00b48
7>LLi`029BT28@P47>L28@P27>L38@P27>L28@P39BT01acW8@PLiacW8@PLiaS600<Li`038@PLib48
00DLi`038@PLiacW00<Li`038@PLiacW008Li`<Q20047>LHaQS66<H27>L28@P00acW6<HHaP057>L0
0aS67>LHaP026<H01AcW8@PQ22487>L00aS600LLiaS66<HDYAcW8@PLi`036<H00acW6<HLi`047>L0
0aS67>LQ20027>L36<H37>L26<H27>L011S65:DHaQcW0QS60acW00HHaQBU5:DHaQcW8@P27>L011S6
7>LHaR4811cW00@Q21cW8@PLi`8Q20036<HLiaS6008HaP<Li`8HaP077>LHaQS66<HLib487>L01QS6
1AcW00HHaQBU5:DDYAcW6<H27>L012487>LQ21cW0aS600<LiaS66<H01aS60QBU11S60QcW0QS600HD
YAS65:DHaQcW6<H25:D26<H37>L00aS65:DDY@046<H01QBU48@@Q1BU48@DY@<@Q0045:D<H`aS48@2
5:D248@01ABU7>LHaQBU6<H00aBU00HHaR487>LHaQBU48@<5:D01AS65:DDYABU48@00aBU00@@Q1BU
48@DY@8@Q0DDY@056<HDYABU48@DY@0248@010aS48@@Q0aS0a2400@DYA245:DDY@<@Q08DY@8@Q005
36<@Q12436<@Q0025:D00a2436<<H`0248@011BU6<HDYABU0Q2400<DYA2448@00Q240QBU00<@Q1BU
48@00Q2400<<Ha245:D011BU00D@Q1BU5:DHaQcW00<DY@0348@DYABU008DY@0448@DYA245:D348@3
5:D16<H15:D136<0000800048@@Q124000@Q0008@P848@0600048B48CW<mkbe[0c6<00<e[C6<<H`0
0Re[00Le[CW>?Nle[Be[=Jd]J`02:DX01Be[<H`YBRDY:DX00S6<00@U:BU::DXaS0@]J`06<H`]JbU:
9BTYBRe[0RU:00H]JcF]>Lh]JbU:;F/6:DX01BDY:DX]Jbe[:DX00bDY00@YBS6<<H`aS08]J`09<H`e
[CW><H`YBRDY:DX]Jc6<00<YBP8]J`05:DX]Jc6<;F/YBP028@P2:DX00be[:DXU:@029BT28@P012DY
:DX]JbU:0Re[00HYBRDY8@PU:BU:9BT28@P49BT28@P79BT28@P012DY8@PQ22480bU:0RDY0b4800<Y
BRe[:DX01BDY124800<LiaS67>L00acW00<Q21cW8@P00bDY00TYBQcW7>LLibU:;F/U:B487>L01B48
0RDY00@Q21cW8@PQ208U:@058@PYBRU:9BTQ2003:DX00bDY8@PU:@028@P012DY8@PU:BU:0RDY00<Q
21cW7>L00QcW00HU:BU:;F/YBR489BT3:DX01bDY8@PQ22489BTQ22DY008Q20057>LQ22DY:DXU:@02
8@P39BT48@P29BT01B487>LLiacW9BT00R481QcW00<Q21cW8@P00QcW0R480QcW00<Q22DY9BT01B48
31cW00<HaQcW8@P00QcW00@DYAS67>LQ20DLi`8Q20@HaP037>LQ21cW00HLi`048@PLiaS67>L56<H3
8@P46<H011BU6<HHaR480QcW00LHaQBU5:DHaQBU6<HLi`028@P011cW6<HHaQS60acW0aS60acW00<H
aQBU6<H00QS60QcW11S60QcW0aS60b4800<LiaS66<H00aS60R4800<Lib487>L011cW00PHaQcW6<HL
iaS67>LHaQcW0QS60acW00TDYAS68@PQ21cW5:DHaQcW5:D00QS60QcW00<HaQcW6<H00QS60QBU0QS6
00<LiaS67>L011cW00<HaQBU5:D00QcW00<HaQBU6<H00aS600<DYAS65:D00aS600LLib486<HHaQBU
48@DY@026<H00aBU6<H@Q0025:D00a246<HLi`027>L25:D00aS65:DHaP035:D248@00aBU48@DY@02
48@236<00a2436<@Q0055:D36<H011BU48@DYAS60acW00<@Q1BU48@00QBU00<@Q1BU48@00aBU00D@
Q1BU5:DHaQBU008@Q08DY@8@Q0045:D@Q1BU48@25:D00a245:DDY@035:D26<H00aBU48@<H`0248@6
36<>48@00`aS48@@Q00248@00`aS5:D@Q00348@55:D448@00aBU48@@Q00248@00`aS48@@Q0025:D6
48@25:D26<H00aBU48@@Q0025:D448@01ABU48@@Q12436<00Q2400<DYA2448@00@aS00000`@Q0004
8@0812401`Q2:DYJeT8@9BT]JcF]008icP04=JdaS2e[<H`3>Lh00cF]<H`aS002:DX00be[<H`aS004
<H`2;F/29BT01248:DXYBRDY0RU:00/]JbU:9BTYBRe[=JdaS3F];F/YBRe[008YBP03;F/YBRU:008Y
BP049BTYBRU::DX49BT2<H`013F]<H`YBRU:1C6<00<]JbDY9BT012U:1Re[0RU:0R4800@U:BU:<H`a
S08]J`03:DXU:BU:008YBP8]J`8YBP@U:@04:DXQ22DY8@P29BT022489BTYBRU:9BTQ21cW9BT2:DX2
8@P012DY:DXU:AcW0RDY00<YBRDY9BT00RDY00XLibU:;F/aS2U:8@PLibDY:DXU:@8YBP068@PLiacW
7>LQ22DY0R4800<Lib488@P00bDY0b4800@YBRDY8@PU:@HQ20039BTQ224800<Q20059BTQ22489BTQ
2003:DX39BT2:DX28@P00bDY:DX]J`029BT28@P27>L28@P00bDY:DXYBP049BT00bU:;F/YBP029BT0
12489BTU:BDY0R4800<LibDY9BT00b4812DY0R4800<Lib488@P00b4800LLib488@PU:B487>LQ2002
9BT012487>LLiaS60QcW0R480acW0b480RU:00<Q21cW7>L00R480QS600<Lib488@P01AcW124800<L
iaS67>L00R480QcW00<HaQcW9BT00R4800<LiaS66<H00QS600<Q21cW8@P00QcW00LHaQcW7>LHaQcW
8@PLi`036<H27>L01R489BTU:AcW6<HDY@8Li`055:DHaQcW8@PLi`036<H01QBU6<HLib48:DXQ208L
i`<HaP8Li`048@PLiacW6<H35:D26<H011BU6<HLiacW0QS600@DYAS67>LLi`@HaP8Q208Li`8HaP04
8@PLiacW6<H97>L00aS67>LHaP026<H011cW6<HHaQS60acW00<Q21cW6<H00acW00DHaQcW6<HHaQcW
008HaP035:DHaQcW008Li`<HaP045:DHaQcW7>L28@P011cW6<HHaQcW0QS600<DYAS66<H00QcW00HH
aQBU5:DHaQBU48@25:D46<H25:D26<H00acW6<HDY@025:D011S67>LLiacW11BU00<@Q1BU5:D00QBU
00<@Q1BU5:D02A2400HDY@aS36<@Q1BU6<H55:D01AcW9BTYBR485:D00Q2400<DYA2448@00Q240QBU
0QS60QBU00@HaQBU5:DDY@D@Q0055:DHaQBU48@<H`0248@011BU6<HHaQBU0Q240aBU0`aS0Q2400@<
Ha2436<@Q0<DY@0448@<H`aS48@35:D0112436<<H`aS1ABU00@@Q0aS48@@Q0DDY@T@Q0055:D@Q124
36<@Q0045:D02AS65:D<Ha245:DHaQBU48@DY@026<H45:D26<H00aBU48@@Q00248@011BU48@DYABU
0Q24000312401@00124000@Q248010@Q00@U:EJe?NlU:@@e[@8aS003;F/aS3F]008icP<aS08]J`04
:DX]JcF]=Jd2<H`022e[:DX]JbU:9BTYBRe[9BT28@P5:DX5<H`2;F/00bU:;F/]J`06:DX00bDY:DXU
:@029BT01BU:<H`aS36<;F/00RU:0S6<00<e[C6<<H`00RU:00<U:BU::DX012e[00<YBRe[;F/00S6<
00L]JbDY9BTU:BU:=JdaS002;F/39BT00bU:;F/]J`03:DX29BT01bU:;F/YBRDY7>LQ22DY008Q2004
9BTYBRU:9BT28@P01BDY:DXYBRDY8@P00RDY0R4800HU:Be[;F/U:AcW8@P29BT012U:;F/]JbU:0R48
00TU:BU::DXYBRDY8@PLib489BT00R4800PHaQcW8@PLib489BTYBRDY0R480bDY00<Q22DY9BT00R48
00<Lib488@P00RDY1B4800<U:B489BT00RDY00<YBRe[:DX00R4800<U:BU:9BT00R480RDY00LYBRDY
9BTLib487>LQ2004:DX01RDY8@PYBRDY;F/YBP8U:@8Q208U:@8Q20037>LU:B4800DU:@8YBP089BTQ
21cW9BTQ21cW6<HQ208U:@037>LQ2248008Li`8U:@038@PLiacW008Li`038@PLiacW008Li`039BTQ
22DY008Q208U:@8Q20047>LQ22488@P37>L00aS67>LQ20029BT37>L28@P01AcW6<HLiacW8@P00QS6
00DLibDY9BTLiaS6008Li`036<HDYABU00DLi`8HaP047>LQ22487>L35:D00aS68@PU:@039BT37>L0
11S67>LHaQS611cW00DHaQcW5:DDYAcW00<U:@8Li`036<HLiacW008Li`046<HLiaS67>L=6<H01QcW
8@PHaQS65:DHaP8Li`038@PLiacW008Li`046<HLiaS68@P57>L00b487>LLi`036<H00acW8@PHaP03
6<H28@P27>L011S67>LLib480QcW00<DYAcW7>L011S600@LiaS66<HHaP8DY@046<HLib488@P37>L0
0aS67>LLi`046<H01aBU7>LLib486<HDYA2400<HaP035:DHaQS6008HaP045:DHaQBU5:D27>L01AS6
5:DDYAS67>L00QBU0aS600@DYA2448@DY@8HaP8@Q0<DY@0348@DYA2400<<H`@@Q08DY@<HaP055:DH
aQS65:DHaP029BT01AcW5:D@Q1BU6<H01A240QBU00@HaQBU5:DDY@8HaP<DY@<@Q0045:DHaQS65:D3
36<021BU6<HHaQBU48@DYA245:D248@00aBU48@@Q00336<248@35:D00a2436<@Q00948@45:D01124
36<<H`aS0QBU00H@Q1BU5:DDYAS65:D448@010aS48@DYAS60Q2400@<HaBU48@@Q0/DY@0348@DYABU
008DY@0448@DYABU5:D448@011BU48@@Q1240@aS00000`0012448@0312400`0012448@02124020Q2
;F]Nmd8@9BTaS3W>=Jd9<H`4;F/3<H`2=Jd00c6<;F/U:@039BT28@P2:DX012e[:DXYBRe[1C6<0Re[
00HU:BU::DXYBRe[<H`2;F/00bU:8@PU:@049BT2:DX2<H`022U:9BT]Jc6<>Lhmkc6<:DX39BT2:DX0
1Be[<H`aS2e[:DX00c6<00<]JbU::DX00RDY0Re[0S6<0bDY00DQ22e[:DXYBRe[008YBP059BTYBRe[
;F/YBP028@P27>L01RDY7>LQ22e[<H`]J`8Q20059BTYBRDY8@PU:@028@P01BDY8@PYBRe[<H`00RU:
0QcW00@Q22DY;F/YBP8Q20039BTYBRDY008U:@04;F/YBRDY8@P27>L01R487>LQ21cW8@PU:@<Q2003
7>LQ224800<U:@<Q20<Li`8U:@@Q20<U:@088@PU:BDY8@PU:BU:;F/YBP<Q20<U:@8Q20<U:@<Q2003
7>LQ22DY00<YBP<U:@<YBP049BTQ22488@P49BT00b487>LQ20029BT01bU:8@PU:BU:;F/YBRDY008L
i`<Q20<Li`8Q20077>LQ22488@PU:BU:9BT011cW0RDY00HQ21cW7>LLib489BT28@P01BDY8@PQ21cW
6<H00QcW0R481AcW00<Q22DY7>L00QcW00HHaQcW8@PQ21cW8@P27>L012487>LLiacW0aS600DDYAS6
6<HLib4800HLi`8HaP077>LHaQS67>LHaQcW8@P00RDY11cW0QS600<Lib488@P00acW0QS600DDYAS6
7>LLib4800@Li`036<HLiacW008Li`036<HLiacW008HaP8DY@046<HLiaS65:D36<H27>L01AS65:DH
aQS68@P00acW0aS600<Lib488@P011cW00@HaQcW7>LQ208Li`<HaP8Li`086<HLiacW6<HLiaS67>LQ
208Li`046<HLiaS67>L28@P37>L00aS67>LLi`026<H00aBU6<HHaP036<H38@P27>L00aS65:DHaP0;
6<H00aBU6<HDY@025:D46<H25:D46<H35:D00aS67>LLi`026<H25:D00aS65:D@Q00348@35:D248@0
0`aS48@@Q00548@25:D011cW6<HLiaS60aBU00@HaR488@PLi`8DY@8@Q0065:DHaQBU48@<Ha2411S6
00DDYA2448@@Q1BU008@Q00736<@Q1BU6<H@Q1BU36<00Q241QBU00T@Q1BU36<<Ha2436<@Q0aS48@0
0`aS00<@Q1BU5:D00a2400<<Ha2436<00aBU00D@Q0aS48@@Q1S6008DY@0448@DYA2448@25:D00aS6
5:D@Q00348@35:D348@336<248@35:D348@01QBU6<HDYAS65:D@Q08DY@036<HDYA24008DY@046<HD
YA245:D348@010aS48@@Q1240QBU0A2400001@@Q00048@@Q00000P@Q00X8@P@Q124000Q2;F]Nmd8@
9BT]J`<icP04<H`]Jbe[<H`2=Jd2<H`01BU:;F/aS36<=Jd00S6<0SW>00<]JbU:9BT00RU:00@U:B48
8@PU:@8YBP8U:@04:DXe[CF]<H`2;F/2:DX012e[9BTYBRU:0S6<00<]JbU:8@P00RDY0RU:00@U:B48
:DX]J`8aS004;F/U:Be[>Lh2?Nl0136<9BTU:BDY0Re[0RU:0S6<00HYBRe[;F/e[C6<;F/3:DX01RDY
;F/]Jc6<=JdYBP8Q20039BTYBRe[00LYBP05;F/YBRU:9BTQ20029BT28@P01Re[<H`aS2DY7>LQ208U
:@DQ20039BTYBRe[008]J`07:DXQ21cW8@PYBRe[:DX00RDY00DYBRDY9BTU:BU:00@U:@048@PLiacW
7>L38@P00bDY8@PU:@028@P01AcW8@PU:B489BT0224800DU:B488@PU:B4800@U:@8Q20069BTYBRU:
:DXU:B4812DY00@Q22DY9BTU:@8Q208Li`038@PLibU:008YBP039BTQ22DY008YBP<U:@<Q20<U:@05
8@PU:B488@PLi`028@P29BT3:DX28@P011cW8@PLiacW124800@Lib488@PQ208U:@8Q20047>LHaQcW
7>L48@P011S67>LQ22DY124800TLib487>LLib489BTLib487>L00R480QcW0R4800<LiaS67>L01QcW
0R481AcW11S61QcW00DHaQcW7>LLib4800<HaP8Li`<Q20DLi`8HaP8Li`048@PLiaS66<H27>L00aS6
7>LQ20028@P00acW6<HHaP027>L66<H011cW6<HDYA240QBU0QcW00DHaQBU6<HHaQcW00<HaP8Li`04
5:DHaQcW7>L26<H00acW8@PLi`087>L00b487>LLi`037>L26<H011BU6<HHaQS60R480QcW11S600@L
ib488@PQ208HaP037>LHaQcW008HaP045:DHaQS66<H67>L00aS67>LHaP046<H00acW6<HDY@046<H3
5:D00aS65:DDY@046<H01QBU6<HHaQBU6<HDY@8HaP035:DLiacW008HaP055:DHaQS66<HDY@0248@0
0aBU6<HHaP0548@01@aS5:D@Q12436<00Q2400@DYAS66<HDY@<HaP035:DHaQS600<Li`036<HDYABU
00<DY@@@Q0035:DHaQS600DDY@<@Q0075:D@Q12448@DYA245:D00a240QBU00H@Q1S65:DDYA2436<5
48@00`aS48@@Q00448@25:D0112436<@Q1BU112400<DYA245:D011BU00X<Ha245:D@Q1S648@DYA24
5:D@Q0@DY@0348@<H`aS008@Q0075:D@Q12448@DYA245:D00Q240QBU00<HaQBU48@00QBU0QS60QBU
0Q241QBU00<@Q1BU48@01A2400021240100012448@000P@Q00P8@P@Q1248@RU:G_LmkbU:0SW>00@e
[C6<<H`aS08]J`04:DX]Jbe[:DX9<H`01Be[:DXYBRe[9BT00b480RU:0RDY00D]Jc6<=JdicSF]008]
J`8YBP059BT]JbU::DX]J`03<H`3:DX49BT00be[<H`aS002:DX03be[=Jde[CF]<H`]JbU:;F/U:B48
:DXaS3F];F/YBP04;F/00c6<;F/YBP02:DX01Be[<H`aS2e[:DX00RDY0be[0RU:00D]Jc6<:DXYBRDY
00<YBP<Q20036<HQ22U:008]J`03:DXQ22DY008U:@038@PU:B4800<Q2006:DX]Jbe[9BTQ21cW0b48
00LU:BU:;F/U:AcW8@PU:@028@P00acW8@PU:@029BT00bU:9BTU:@068@P00bDY8@PU:@048@P00bDY
8@PQ20028@P01acW8@PU:Be[9BTQ21cW008Q208U:@05:DXQ22489BTYBP02;F/00bU:9BTU:@079BT2
:DX01B487>LLiacW9BT00RU:0bDY0R4800DU:BU::DXYBRDY00<Q20059BTYBRU:9BTQ20029BT00b48
7>LQ20029BT01RU:9BTQ22487>LQ208Li`8Q208YBP8Q200?7>LU:Be[9BTLib489BTQ21cW6<HQ22DY
:DXQ21S6008Li`039BTQ21cW008Q20039BTQ21cW00<Q20047>LQ21cW8@P27>L00b487>LLi`027>L2
6<H27>L012487>LHaQcW0R480QcW0aS60QcW0aS600LLib487>LLiaS67>LHaP037>L48@P011cW6<HL
iacW0b4811cW00HQ21S67>LHaR486<H27>L00b487>LLi`027>L00aS67>LLi`026<H00aBU6<HLi`02
7>L26<H27>L011S65:DDYABU11S60QcW0QBU00@HaQcW7>LLi`8HaP035:DHaQS600<Q20<Li`046<HL
iacW6<H47>L00aS67>LHaP026<H27>L012487>LLiacW11S600<LiaS67>L00QcW0aS60QcW0QS600<D
YAS66<H00aS600@Lib487>LLi`<HaP037>LHaQBU008DY@057>LQ21cW7>LHaP035:D36<H45:D01QS6
5:DDYAS67>LHaP<DY@<HaP037>LHaQBU008DY@036<HDYABU00D@Q00:5:D@Q12436<@Q1BU48@<Ha24
5:D248@00aBU7>LLi`025:D01AS67>LDYAS67>L00R480QBU00<@Q0aS48@011BU00<@Q1BU48@00aBU
00/@Q1BU5:D@Q1BU48@DYA245:D@Q1BU00@@Q08HaP<DY@0548@DYA2448@DY@0348@236<648@00aBU
48@@Q00548@236<01a245:DDYABU48@DYA24008DY@0348@DYAS6008DY@0736<@Q1BU5:D@Q1BU48@0
0PaS0a240PaS112411BU11241ABU00<@Q1BU48@00QBU00<@Q1BU5:D0112400<DYA245:D00QBU0A24
00000`0012448@0312402P0024848@@Q0008@RU:F]I6<BU:0cF]136<12e[00<YBRe[;F/0136<00Le
[C6<;F/]JbU:;F/YBP029BT28@P01RDY:DXYBRDY:DX]J`8icP03=Jd]JbU:008U:@8]J`09:DXU:BDY
;F/icS6<:DXU:BU:00@U:@09;F/e[C6<;F/U:Be[=JdicSF]008]J`05:DXaS2U:9BT]J`02<H`02Re[
:DX]Jc6<;F/YBRe[<H`]JbDY0RU:00@aS3F];F/YBP8U:@03:DX]Jbe[008YBP05;F/aS36<:DXU:@02
:DX012DY8@PQ22480QcW00<U:Be[;F/00RDY00DYBRDY7>LLib48008U:@038@PU:BU:00<YBP079BTQ
22487>LHaRDY;F/00RU:00<Lib48:DX00RDY00DQ21cW8@PU:BU:008U:@038@PU:BDY00@Q20<U:@8Q
20037>LQ2248008Q20059BTQ22488@PU:@02:DX00bDY6<HLi`049BT28@P012DY:DXYBRe[0bU:0RDY
0RU:0RDY00@Q22DY8@PQ208Li`8U:@038@PYBRU:00@U:@03:DXU:BU:008U:@@Q20DU:@<Q20039BTQ
22DY00<U:@038@PLiacW008Li`8U:@8Q20039BTLib4800<]J`059BTLibDY7>LHaP027>L29BT37>L2
8@P00acW8@PLi`028@P27>L28@P37>L01B487>LQ21cW6<H00acW0aS600@Lib487>LHaP8Li`<Q2004
6<HLiacW7>L36<H01aBU6<HHaQcW8@PLiaS6008Li`046<HLiaS68@P29BT00b487>LLi`037>L00b48
7>LLi`027>L012487>LLiaS61QcW00@Q21cW7>LHaP8Li`8HaP045:DHaQS66<H47>L011S65:DDYAS6
0aBU00DHaQBU6<HHaQcW00<HaP<Li`@HaP8Li`038@PLiacW008Li`8HaP@Li`056<HDYAS66<HLi`02
6<H01ABU7>LHaQcW8@P00QcW00<HaQBU6<H011cW00@Q21cW6<HHaP<Li`036<HLiaS6008Li`<HaP<L
i`8HaP0D7>LQ21cW6<H@Q1BU6<HLib487>LHaQBU7>LDYA245:DHaQcW5:D@Q08DY@0548@DYAS67>LH
aP055:D46<H75:D248@35:D00a2436<@Q00248@01ABU48@@Q1245:D00aS60QBU0QcW0QBU00HLib48
7>LHaQ245:D248@00aBU48@DY@0348@36<H01ABU48@<HaBU6<H00QBU00<<Ha2448@00QBU0Q2400DD
YA245:DDYAS600<DY@0348@DYA2400D@Q00436<@Q12448@25:D248@00`aS48@@Q00348@00aBU48@D
Y@0248@35:D00a2436<@Q00248@00aBU6<HHaP0248@010aS5:DDYAS61Q2400<<Ha2448@00`aS0a24
00<DYA2448@00Q240QBU00@HaQBU5:DHaP<DY@8@Q0035:D@Q12400<DY@0348@<H`aS00<DY@4@Q000
00D48@0012448@0000L48@06:DYJeT8@;F/e[CW>1CF]00PaS2e[;F/YBRe[<H`]Jc6<0SF]0S6<0be[
00<aS2U:9BT00R4800DU:BU::DXYBRe[00@aS08]J`8U:@058@PYBRU::DX]J`03<H`00bU:;F/]J`02
:DX29BT00bU:;F/aS003;F/4<H`2;F/3:DX022e[:DX]JcF]<H`YBRDY;F/2<H`01Be[:DXYBRU:;F/0
0bU:0Re[00DYBRDY:DX]JbU:00H]J`8YBPDU:@8Q208U:@03;F/YBRDY008U:@058@PLiacW8@PU:@03
8@P39BT01BU:;F/Q21S67>L00RDY00@Q21cW7>LU:@HQ20HU:@<Q20<Li`048@PLiacW8@P29BT27>L2
8@P27>L012489BTYBRDY0R480bDY0R4800HU:BU:9BTU:BU:;F/2:DX:9BT012U:8@PLib480RDY0RU:
1RDY0bU:124800<U:BU::DX00RU:12480RDY1B4800@U:AcW9BTYBP8U:@8Q208U:@06;F/YBRU::DXU
:B480QcW00DHaQcW8@PQ22DY008Q208Li`8U:@068@PU:B488@PLib480bDY0QcW00LHaQcW8@PLiaBU
6<HQ20027>L00aS67>LLi`036<H57>L00b487>LLi`027>L26<H011BU6<HLiacW11S600<LiaS68@P0
0RU:00@Q21cW8@PLi`8HaP037>LQ21cW008Li`048@PLiaS67>L28@P27>L011S68@PLiacW0R4800<L
iaS65:D00QS600<LiaS65:D00QS600@LiaS66<HDY@<HaP035:DHaQS6008DY@8Li`036<HDYAS600@H
aP065:DHaQBU6<HDYAcW0b480QS600<Lib486<H00QcW11S600@DYAS65:DDY@8HaP@Li`8HaP035:DH
aQS6008HaP8Li`8HaP047>LHaQBU6<H37>L46<H00acW6<HHaP047>L26<H47>L26<H35:D36<H25:D0
0aS65:DDY@035:D26<H35:D00aS65:DHaP046<H35:D36<H348@25:D348@01ABU48@<Ha2436<00aBU
0Q240QBU00@HaQBU6<HLi`DHaP8DY@8@Q08DY@8@Q00336<DYA2400<@Q00:6<HDYABU6<HDYA245:D<
Ha245:D26<H01ABU36<@Q1BU48@011BU0a2400D<Ha2448@DYA2400<<H`0348@DYA2400<@Q00436<@
Q0aS48@25:D01A2436<<H`aS48@01ABU00<@Q0aS5:D00aBU00H@Q1BU5:DDYA245:D348@01PaS48@@
Q0aS48@<H`<@Q0<<H`8@Q0035:D@Q0aS008@Q0LDY@0548@DYABU48@DY@0348@00aBU48@DY@055:D0
00848@0300048@@Q00L48@06:DYJeTHa:DXe[CW>13F]00DaS2e[;F/]JbU:008]J`08<H`e[CW>>Lhe
[Be[:DX]J`8aS004:DXU:B489BT5:DX01Re[<H`e[Be[<H`YBP8U:@8YBP05;F/YBRU:;F/aS002;F/3
:DX01Be[:DXU:BU:;F/00S6<00@]JbU:;F/aS08e[@0><H`YBRU:9BT]Jc6<:DX]JcF]<H`YBRDY:DXa
S08]J`8U:@03:DX]Jbe[008YBP8]J`03:DXU:BDY00@YBP8]J`04:DX]Jc6<:DX49BT48@P3:DX01RDY
8@PU:B487>LQ20<U:@8Q208U:@0;8@PU:BU:7>LHaQcW:DX]JbDY7>LQ20029BT38@P27>L012DY:DX]
JbDY0R4800HU:B487>LQ21cW8@P37>L00b489BTU:@037>L38@P39BT48@P49BT00b489BTU:@05:DX2
9BT00b489BTU:@059BT28@P39BT3:DX39BT38@P29BT2:DX01B489BTQ22489BT00RU:0RDY0b480bDY
00HLib487>LQ21cW8@P29BT2:DX28@P29BT00bU:;F/YBP02:DX28@P011S65:DLiacW0RDY00<Q21cW
7>L00R4800<U:B487>L00QcW00/Q22DY9BTU:B487>LHaQcW6<HLiaS600@Li`075:DHaR488@PLiaBU
6<H01QcW00DQ21cW8@PHaQcW00<HaP037>LQ21cW008Li`078@PHaQBU7>LU:BU:9BT00QcW00@Q21cW
7>LLi`8Q20@Li`8HaP047>LQ21cW6<H37>L012487>LQ21cW1AS600@DYAS67>LLi`HHaP055:DHaQS6
6<HDY@066<H01AcW6<HHaQS67>L00aS600DDYAS67>LLib4800<Li`035:DHaQS6008Li`8HaP047>LH
aQBU5:D37>L00aS67>LHaP037>L26<H011BU7>LLiacW1AS60QcW0aS600<LiaS66<H00aS600<LiaS6
7>L00aS60QcW0QS600HQ21cW7>LHaQBU6<H25:D36<H55:D56<H45:D56<H011BU6<HHaQS60QBU00@@
Q1BU48@<H`8@Q0085:D@Q1245:D@Q1BU48@<H`8@Q0035:DHaQBU008DY@8HaP047>LHaQS67>L26<H4
48@35:D01A2436<@Q1245:D00Q2400<DYAS648@00a2400<DYA245:D00QBU00H@Q1BU48@@Q1BU48@3
5:D248@25:D248@01@aS48@<Ha2436<00Q240QBU0a2400<<Ha2448@00a240PaS00HDYA2436<DYAS6
5:D248@25:D00aS65:D@Q00248@35:D00a245:D@Q00448@236<248@00aBU48@@Q00348@55:D00a24
5:DDY@026<H00aBU48@<H`0248@00aBU48@@Q00248@01ABU48@@Q0aS48@00QS60ABU0A2400001000
12448@000P@Q00X000@Q248000@Q248U:E[FAS4YBP8aS007>Lhmkcg_<H`YBRe[:DX00be[0c6<00@i
cRe[;F/U:@@YBP039BTQ22DY00<YBP8U:@05;F/aS3F]=JdaS002:DX012489BTYBRU:0Re[00PaS2e[
;F/]JbU:9BTYBRDY1BU:00@]Jc6<;F/aS0<]J`<YBP8]J`8YBP8aS004:DXU:BU:;F/2:DX2<H`01Be[
9BTU:BU:;F/00bU:00D]JbU:;F/aS2e[008YBP03;F/e[C6<00DYBP039BTYBRDY008Q2003:DX]JbU:
008U:@06:DXU:BDY7>LQ21cW0R480RDY0R4800HU:BU:8@PQ21S67>L28@P00bDY8@PQ20029BT28@P2
6<H01AcW8@PU:BU:9BT00R4800<U:BU:9BT00QcW00@Q21cW7>LU:@8YBP038@PHaR4800LQ20037>LU
:BDY008U:@048@PU:B489BT2:DX00be[:DXYBP02:DX012e[9BTQ22480RDY00<Q22DY:DX00RU:0R48
00<U:BU:;F/00RDY0R480bU:0R4800HU:BU:9BTQ21cW8@P29BT2:DX012DY:DXLiacW0R480RDY00LQ
21cW6<HLib489BTQ20039BT28@P29BT4:DX28@P37>L032DY8@PHaQS68@PYBR487>LQ22DY8@PLi`8H
aP059BTYBRU:8@PLi`028@P022DY7>LLiaS67>LHaQcW8@P27>L011S67>LLiacW0QS600<Lib488@P0
0QcW0QS600DU:B488@PLiaBU008HaP035:DHaQS600DLi`@U:@HLi`038@PLiacW008Li`056<HLiacW
7>LHaP067>L26<H47>L35:D26<H00aBU48@HaP027>L01aS65:DHaQS65:DHaQcW008Q20047>LHaQS6
6<H27>L00aBU6<HHaP026<H01ABU6<HLiacW8@P00QcW0aS60QcW1QS600<DYAS66<H00b4800<Lib48
6<H00aS60QcW00@HaQcW7>LQ208Li`076<HLiacW6<HDYAS67>L00R480QS600<LiaS67>L00aS60QcW
0aS60acW00<HaQBU5:D00QS600<DYAS66<H00QS60QBU0QS600<LiaBU5:D011BU00<HaQBU6<H00QBU
0QS61ABU0a240QBU00D@Q1BU48@@Q1BU00<@Q0@DY@046<HDYABU5:D26<H25:D021S67>LDYABU48@D
YA245:D648@35:D011245:DDYABU0QS60aBU00@HaQBU5:DDY@8@Q08HaP8DY@0348@DYABU00@@Q0@<
H`8@Q0036<HDYA24008<H`H@Q0045:D<H`aS48@236<00a245:DDY@035:D248@35:D00aS65:DDY@04
5:D00a245:D@Q00336<248@336<35:D248@00`aS48@DY@025:D01QS65:DDYABU6<HDY@8<H`0548@H
aQS648@<H`035:D00a245:DDY@045:D148@000@48@0400048@@Q248412402B48F]I242U:;F/e[Cg_
@Q0e[@02:DX2<H`3;F/02c6<=JdaS3F];F/YBRDY:DXaS2e[9BT00R4800<U:BU::DX00bU:00X]Jc6<
<H`e[C6<;F/YBR489BTYBP<]J`06:DX]Jc6<<H`]JbU:0RDY0bU:0be[00@YBRe[;F/]J`8aS0<YBP07
<H`]JbU:;F/aS2e[:DX00RDY0bU:00PaS2e[:DXYBR489BTYBRe[0RU:00<U:BU:;F/00Re[0RU:0c6<
00@]JbDY:DXYBP8U:@05:DXU:B488@PU:@02;F/29BT022U:9BTLiacW8@PU:AcW8@P39BT01b489BTY
BRDY7>LQ21cW00@Q20059BTQ21cW9BTQ20036<H00b48:DXU:@028@P02RDY:DXU:BDY8@PLib486<HL
ibDY0RU:00@Q21cW8@PU:@8Q208U:@8Q20047>LQ22488@P29BT28@P01BDY:DX]JbU:9BT012U:00LQ
22DY9BTU:BU:9BTQ20049BT00b489BTYBP02:DX39BT01BU:9BTU:BDY8@P00bDY00DQ22DY8@PU:B48
00<YBP039BTLib48008Q20049BTQ22486<H37>L28@P39BT38@P29BT2:DX00bDY7>LLi`026<H78@P0
11cW8@PU:B480acW00<HaQcW8@P00b4800<Lib487>L00acW00LHaR487>LLiaS65:DHaP037>L36<H0
0acW9BTQ20047>L01B487>LLiaS65:D00QS600@LiaS66<HLi`8Q208Li`<U:@8Li`038@PHaQcW00<L
i`058@PLiaS67>LHaP047>L26<H00b487>LHaP067>L35:D26<H47>L26<H011BU6<HHaQBU0QS600@L
ib487>LLi`8HaP037>LHaQS6008DY@056<HLiacW7>LHaP028@P011cW6<HHaQS60QcW00@HaQcW6<HL
i`<HaP045:DHaQS66<H47>L56<H011BU6<HQ22480aS600<Q21cW6<H00QS600@LiaS67>LLi`8HaP05
5:DHaQS67>LHaP027>L011S65:DLiaS60QcW00<DYAS65:D00aBU00<HaQcW6<H00aBU0QS60QBU11S6
00@DYAS65:DHaP8DY@@HaPDDY@0448@DYA2436<248@00aBU6<H@Q00348@26<H00aBU6<HHaP025:D0
1AS67>LHaQ245:D00QcW00DHaQ2448@@Q1BU00<@Q0035:D@Q124008DY@8@Q0<DY@036<HDYABU008D
Y@8@Q0046<HLiaS65:D248@011BU48@@Q12411BU0a2400<<Ha2448@01Q2400@<Ha2436<<H`8@Q003
5:D@Q124008<H`0448@DYA2448@35:D248@26<H348@011BU6<HHaQBU1A2400<DYA2448@00PaS1124
00H<Ha2448@@Q1BU48@35:D36<H00aBU48@DY@0648@00aBU48@DY@025:D248@011BU7>LLiaBU0A24
00000`001240000212400`0012448@0212402P00248]Je:D>LhYBSW>BU92436<0Re[00HaS3W>=Jda
S2e[:DX2<H`00cW><H`YBP029BT2:DX00be[:DXU:@029BT00bU:;F/]J`02;F/5<H`012U:9BTQ22DY
0RU:00Le[CW>=Jd]Jb48:DX]J`038@P01RU:<H`]Jc6<=Jd]J`8YBP03;F/e[C6<008YBP05;F/U:BDY
:DX]J`02<H`022e[:DXU:B48:DX]JcF];F/39BT5:DX01BDY;F/]Jbe[<H`012e[0S6<0Re[0RDY00<Y
BRDY9BT00bDY0R480bDY0R4800PU:B487>LU:BU:;F/YBRDY0R4800DLib486<HHaQcW008U:@HQ208L
i`036<HLib4800DQ20059BTQ22DY:DXU:@048@P39BT28@P00bDY8@PU:@038@P00bDY:DXU:@029BT0
0b489BTU:@029BT00bU:;F/]J`03:DX2;F/2:DX00bDY:DXYBP02:DX39BT012489BTQ22DY0be[00<U
:B489BT00RDY0R480RDY00@YBRDY9BTQ20<U:@@Q20039BTQ21cW00@Q20@Li`039BTQ22DY00<U:@8Q
20069BTYBRU::DXU:AcW0QS600LLib486<HLib489BTQ20027>L38@P011S65:DHaR480RDY00@Q22DY
8@PQ208Li`046<HLiacW8@P27>L01AS67>LLiacW8@P021cW00DHaQcW6<HLiaS600<Li`046<HDYABU
6<H37>L011S68@PQ22480QcW00<Q22DY8@P00acW00LHaQcW8@PQ21cW6<HDY@027>L36<H27>L00aS6
7>LQ20036<H37>L36<H00aBU6<HHaP027>L00aS65:DDY@036<H01ABU6<HQ22487>L00QS60acW1QS6
00<LiaS66<H00aS61AcW00@Q21cW7>LLi`@HaP<Li`<Q208HaP047>LHaQS66<H37>L01AS67>LLiacW
6<H00QcW00@HaQBU6<HLi`8Q20047>LHaQS66<H37>L26<H37>L00b486<HHaP025:D021S648@DYABU
7>LDYA245:D26<H25:D36<H00aBU48@DY@026<H00b486<HHaP025:D26<H00aBU48@@Q0045:D248@0
0aBU48@<H`0248@45:D00a245:DHaP026<H35:D26<H01ABU7>LLiaS65:D00Q2400PDYA2448@<Ha24
36<@Q1BU112400<<Ha245:D00QBU00@@Q1BU5:DHaP@DY@0348@DYAS6008HaP8@Q0095:DHaQS65:D@
Q0Q236<@Q0aS008@Q08DY@8@Q0045:D<H`aS36<248@011BU48@@Q1240QBU0`aS00<@Q1BU48@011BU
0a2400<DYAS66<H00aBU00<<Ha2448@00Q2400@<Ha2448@@Q0<<H`0348@DYABU00<@Q0075:DHaQBU
5:DHaQBU6<H00QBU00D@Q0aS48@<Ha2400@DY@8@Q0035:D@Q1BU00@DY@4@Q0001P@Q00<000Q21240
0`@Q00DYBUJe?NlYBSW>00924007>Lh]Jbe[<H`icSF];F/00RDY00@aS3W>=JdaS08U:@8YBP05;F/Y
BRU:9BTQ2002:DX5;F/2=Jd0136<:DXU:Be[0RU:00LU:BU:=JdicS6<;F/U:@03:DX00bDY8@PU:@02
;F/2>Lh0136<;F/YBRe[0S6<00@]JbU:9BTU:@8YBP8]J`<YBP8Q20049BTaS36<<H`29BT9:DX3;F/2
<H`01be[:DX]Jc6<;F/YBRDY008YBPDU:@048@PU:BDY9BT28@P01BDY8@PLibDY:DX00Re[00<U:B48
7>L00b480acW0b480bDY00@Q21cW7>LHaP8Li`038@PU:B4800@U:@068@PU:BDY9BTQ21cW0R480RDY
0R480RDY00<Lib487>L00RDY00<Q22DY9BT00RDY00<Q22DY9BT00RU:0Re[00<YBRDY9BT00bU:0RDY
0RU:00@]JbU:9BTU:@<Q200>9BTYBS6<<H`YBRDY7>LQ22DY:DXU:B487>LQ208YBP089BTQ22489BTY
BRDY8@PLi`<Q20037>LQ22DY008Q20@Li`078@PU:BU:9BTQ22DY:DX00RDY0RU:0R480QS60acW1248
00HLib488@PU:B487>L26<H27>L01BDY8@PQ22DY7>L00aS60acW00LQ21cW7>LLiaS67>LQ20027>L3
6<H37>L00aS67>LHaP057>L00aS67>LDY@026<H01AcW8@PQ22487>L01B4800@Lib488@PLi`8Q2004
7>LQ22DY7>L35:D011cW6<HHaQS60acW00@Q21cW7>LLi`8HaP8Li`8HaP035:DHaQS600<Li`046<HL
iacW6<H25:D011S67>LLiacW0QS600DQ22DY8@PHaQBU00<HaP8Li`056<HLiacW7>LHaP027>L00aS6
7>LQ20028@P37>L36<H01ABU7>LLib489BT00acW00@DYAS66<HHaP8Li`038@PHaQS600PHaP8Li`03
8@PLiacW00@Li`038@PLiacW00<HaP067>LQ21cW6<HDYAS62ABU0aS60QBU0QS600<DYA245:D00QS6
00DLiaS65:DHaQBU008HaP8DY@0348@DYABU00<DY@8@Q08DY@0348@DYABU00@DY@036<HLiaS6008H
aP8@Q0065:DHaQcW7>LHaQBU11240PaS00@8@Q245:DDY@8@Q0035:D@Q12400<@Q0@DY@036<HDYABU
00@DY@056<HDYA2448@DY@026<H35:D02A2436<<H`Q25:D@Q1BU48@DY@0248@236<848@00`aS48@@
Q0045:D26<H25:D248@25:D36<H01ABU48@<Ha245:D00Q2400<DY@aS36<00PaS112400<DYA2448@0
0Q240QS600DDYAS66<HHaQBU008@Q00536<@Q12436<@Q0035:D348@65:D148@0000500048@001240
000712403BDYDY@mkbe[>LhmkcF]<H`e[CW>=Jd]JbU:008]J`04<H`]Jbe[:DX29BT8:DX29BT2:DX0
2c6<=Jde[Be[:DX]Jc6<:DXU:B489BT00S6<0Re[0bU:12DY00<]Jc6<<H`00S6<0Re[00TYBRe[<H`a
S2U:9BT]Jc6<:DX00RDY00<YBRe[;F/00RU:0RDY0RU:00<]JbU::DX00RDY0RU:00@U:B489BTYBP8]
J`8YBP04;F/U:BU:;F/2<H`00bU:9BTYBP03:DX49BT02B489BTU:BU:9BTQ21cW8@PU:@02:DX00be[
:DXYBP02:DX012DY8@PLiacW1R480QcW0R4800<LiaS67>L00bDY0b4800XYBRDY8@PQ22DY;F/U:B48
9BTYBP8U:@038@PU:B4800<Q20037>LQ2248008U:@038@PU:B4800<U:@8YBP8]J`06:DXU:BDY:DX]
JbU:0RDY00<YBRe[:DX00RDY00DYBRDY:DXU:BU:008]J`8YBP058@PYBRU:9BTYBP039BT022489BTQ
22DY8@PU:BU:9BT88@P37>L29BT012487>LLiacW0bDY00<Q22DY9BT00RDY00HYBRDY8@PLiaBU6<H2
7>L29BT48@P012DY8@PQ21cW0QS600<Lib489BT00RDY00TLib487>LLiaS65:DHaQcW6<H011cW00DQ
21cW7>LHaQcW008Q20037>LHaQS6008HaP035:DLiacW008Q20<Li`036<HLiaBU008HaP048@PLiacW
7>L28@P01RDY7>LHaQS67>LQ20<Li`8Q20037>LHaQBU00HHaP8Li`038@PHaQcW00<Li`046<HDYAS6
7>L36<H37>L012487>LHaQcW0QS61acW0R4800DHaQBU6<HHaQcW008HaP037>LQ21S6008HaP8Li`04
8@PLiaS67>L28@P00acW6<HLi`025:D01aS67>LQ21cW8@PLib48008HaP037>LHaQcW008HaP058@PL
iacW6<HDY@027>L02AS65:DDYABU6<HQ22DY8@PLi`026<H37>L011S67>LLib480aS60acW00<HaQ24
5:D00aS60aBU11S600<DYAS65:D00QBU00<HaQcW7>L00aS600<LiaS66<H00aS600@DYA2448@@Q08D
Y@0548@DYA245:D@Q0045:D348@00aBU6<HHaP036<H01QBU36<DYAcW8@PHaP<DY@T@Q0035:D@Q124
008<H`065:D<Ha2448@DYAS60aBU0Q240aS61ABU0QS60QBU112400<DYA2448@01Q2400<<HaBU5:D0
0aBU0Q2400<DYAS648@00PaS00<@Q1S66<H00QS600@@Q1BU5:D@Q08DY@066<HDYABU36<@Q1BU0Q24
0`aS112400LDYA245:D@Q1BU48@DY@0248@00aBU6<HHaP025:D00aS65:D@Q00236<35:D26<H25:D0
10aS48@@Q1240aBU0AS60ABU0@aS000<12403bDYE[DmkbU:>LhmkcF];F/aS3F]<H`]JbU:;F/aS002
;F/01RU:9BTU:BDY:DX]J`8YBP049BTYBRDY:DX29BT2:DX02be[<H`]Jbe[:DXaS2e[:DXU:B48:DX0
0Re[00@aS2e[:DX]J`<YBP038@PU:BU:00<aS0D]J`03<H`]JbU:008YBP05;F/YBRU::DX]J`02:DX4
9BT01RU:;F/YBRU:9BTQ208U:@8YBP8U:@03:DX]JbU:008YBP8U:@05:DX]Jc6<<H`]J`02:DX29BT2
:DX012489BTLib480bDY0b480bDY00@YBRDY;F/]J`<YBP@Li`049BTLiacW9BT77>L28@P012DY8@PQ
21cW0bDY0b4800<U:B488@P00RDY00<YBRDY8@P00R4800<Lib488@P00RDY0R480RDY0R480RDY0RU:
00DU:Be[;F/]JbU:008U:@03;F/YBRDY00<YBP8U:@04:DXU:BDY9BT4:DX00be[9BTYBP069BT28@P2
:DX48@P29BT28@P011cW8@PQ22DY0R480QcW0R4800<U:B487>L00QcW00@U:B489BTYBP8U:@8Q2005
9BTLiacW6<HLi`026<H00b489BTU:@027>L00b489BTU:@037>L26<H28@P00bDY8@PQ20027>L36<H6
7>L012487>LLiaS621cW00DHaQBU6<HLib4800DLi`056<HLiaS67>LHaP027>L012487>LLib4811cW
00HQ21cW7>LLib487>L46<H00aBU6<HHaP087>L00aS67>LLi`035:D011S67>LLiaS60QcW0QS600TL
iaS65:DDYAS67>LQ21S67>L00R4800@LiaS65:DLi`8HaP035:DHaQS600<Li`036<HLiaS600<HaP06
7>LQ22DY7>LHaQ240aS600DDYAcW7>LQ21cW008Q20047>LHaQBU6<H27>L36<H37>L26<H00acW6<HD
Y@026<H28@P01AcW8@PLib487>L00QS60QcW00@HaQBU6<HHaP8Li`8HaP@DY@<HaP035:DHaQS6008H
aP8DY@@HaP<DY@036<HDYAS6008HaP047>LHaQS66<H35:D00a245:DDY@035:D00a245:D@Q0035:D0
0a245:DHaP055:D011S648@@Q1BU0R4800<LiaBU48@011BU0a2400<DYA2448@0112400HDYA2448@<
Ha245:D26<H25:D348@36<H55:D26<H248@236<0112436<@Q0aS0Q2400DDYA2448@<HaBU00<@Q004
5:D@Q0aS48@25:D348@01QBU6<HDYAS65:DHaPDDY@D@Q00436<@Q12448@336<348@010aS48@@Q124
0aBU00@@Q1BU5:DDY@8HaP<DY@<<H`8@Q0@DY@0448@<H`aS48@35:D00a245:D@Q00136<0000:0004
8@00124000@Q0008@P@Q000212402b48E[E:DS6<>LhaS3F]>LhaS2e[:DX01Be[0RU:0RDY1bU:0R48
00@U:BU:;F/YBP@aS004:DXU:BDY9BT3:DX2<H`00be[<H`U:@028@P01bDY;F/]Jbe[>LhmkcW>008Y
BP8aS004;F/YBRe[;F/39BT00bU:9BTYBP02:DX2;F/01RU:9BTYBRe[<H`]J`<U:@8Q2004:DX]JbU:
:DX29BT3:DX29BT00bU:;F/YBP05:DX01bDY8@PLib489BTQ22DY00<YBP049BTQ22DY9BT28@P01AcW
:DX]Jbe[:DX00R4800@U:B487>LLi`8Q20049BTQ22488@P29BT012487>LLib480acW00HQ22DY9BTQ
21cW9BT3:DX01B489BTU:BDY8@P00RDY0R4800@Lib488@PU:@8Q200>9BTQ22488@PU:BU:9BT]JbU:
;F/aS2e[<H`]J`TYBP8U:@@YBP05;F/aS2U:9BTQ2002:DX00be[:DXU:@028@P59BT01R489BTYBS6<
;F/U:@@Li`<Q20047>LU:BDY9BT37>L00b489BTQ20028@P39BT28@P00acW8@PQ20057>L00b489BTU
:@028@P01RDY:DXQ21cW6<HLi`8Q20039BTQ21cW00HLi`<HaP8Li`046<HLiacW8@P27>L01AS67>LQ
22487>L00QBU0QS60QcW00<HaQcW6<H01QcW00PQ21BU6<HHaR489BTQ21cW0aS600@LiaS67>LLi`8Q
20037>LHaQcW00<HaP<Li`<HaP<Li`038@PHaQcW008DY@8HaP8Li`8Q208Li`@HaP8Li`036<HLiacW
00<Li`8Q208Li`036<HLiaS600<HaPDLi`046<HLiaS66<H37>L02AS67>LLiaS65:DHaQBU7>LHaP02
7>L00b487>LQ20046<H27>L28@P27>L26<H27>L36<H01AcW8@PQ22487>L00R481acW00<HaQBU6<H0
0aS60aBU00<HaQBU6<H011S600<DYA246<H00QcW11S60QBU0QS600<LiaBU5:D00aS600@Lib487>LH
aP8DY@036<HDYABU00<DY@0348@DYABU008DY@046<HDYABU5:D36<H45:D26<H27>L011BU48@@Q124
0QS600@DYA2448@@Q0<DY@0348@<Ha24008DY@<@Q0035:DHaQ24008DY@066<H@Q1BU5:DHaQBU0Q24
00DHaQBU5:DDYA24008<H`0648@<HaBU5:D@Q1BU10aS0a240QBU0a240QBU112400<DYAS66<H00QBU
00<HaQBU5:D00Q240aBU00L@Q1BU48@<Ha2436<@Q00236<248@236<011245:DDYABU0a2400<DYAS6
5:D011S61Q2411BU00LHaQBU5:D@Q1BU6<HDY@0348@15:D148@136<000`48@058@QJeTYB=JdicP03
<H`02Re[<H`aS36<;F/YBRe[<H`]JbU:0R480bU:0RDY00<YBRe[:DX00R4800hU:Be[:DX]Jc6<=Jda
S2U:9BTYBR489BTYBRe[0S6<0Re[00XU:B489BTU:Be[:DX]JcF]?NlaS0<]J`8aS08YBP8U:@<YBP8U
:@03:DX]JbU:00<YBP@]J`04:DXU:B488@P39BT00bU:9BTU:@02:DX012DY:DXU:Be[0RU:00LU:BU:
:DXYBRe[:DXU:@038@P03RDY7>LQ22DY;F/U:B487>LQ22DY:DXU:B489BT2<H`012e[8@PQ22DY0b48
00HLib488@PU:B487>L28@P00acW8@PLi`028@P00acW8@PQ20029BT28@P29BT01RU:9BTQ22DY:DXU
:@@Q208Li`038@PU:BDY008U:@<Q208U:@8YBP039BTYBRU:00<]J`03:DXU:BU:00@YBP0<9BTYBRU:
9BTYBRDY:DXU:BU:<H`]JbU:0bDY00@YBRe[:DXYBP8Q20039BTQ22U:008YBP059BTQ22e[;F/YBP02
8@P00bDY8@PLi`027>L01bDY8@PQ22DY8@PLiaS6008Li`DQ208YBP058@PLiacW7>LQ20037>L00aS6
7>LLi`038@P29BT012487>LHaQS60QcW0b4811cW0QS600<LiaS66<H00QcW0aS600DLib488@PLiaS6
008Li`038@PLiaS6008HaP047>LHaQcW7>L36<H012487>LLiaS60acW00@HaQcW7>LQ208Li`8HaP09
7>LHaQBU6<HLib489BTQ21cW00<HaP047>LDYAS66<H27>L00b487>LLi`037>L56<H37>L01R487>LL
iaS65:DLi`@HaPDLi`056<HLib488@PLi`036<H00acW6<HHaP056<H27>L012487>LHaQS60acW11S6
0acW00@Q21cW7>LLi`@HaP<Li`036<HLiaS6008HaP047>LDYAS65:D27>L48@P27>L00aS67>LLi`03
7>L00aBU6<HHaP026<H01QcW6<HHaQBU6<HDY@8HaP045:DHaQBU6<H35:D26<H00acW6<HHaP046<H0
0acW6<HDY@025:D00aS67>LLi`036<H00aBU6<HDY@0248@75:D00aS65:DHaP056<H011BU6<H@Q124
0QS600<LiaS65:D00QBU00H@Q1BU48@DYA245:D348@011BU48@@Q0aS0a240QBU00<HaQBU5:D00QBU
00D@Q1BU5:DHaQBU008@Q08DY@036<HDYA24008@Q0<<H`0648@DYABU48@8@PaS0a2400D<Ha245:DD
YAS600@@Q00:5:D@Q12448@DYAS65:D@Q1BU6<H25:D011245:DDYABU11241@aS2Q2411BU00<@Q1BU
6<H00QBU0a2400<<Ha2448@00a2400@DYA245:D@Q0<DY@8@Q08DY@8@Q04<H`0000@000@Q124000@4
8@0924848@00248YBV<HBU8YBSF]00<aS008;F/YBRU::DX]Jc6<;F/aS0<U:@04:DX]JbU:9BT2:DX0
1Re[:DXU:B489BT]J`8aS005;F/aS2e[;F/YBP039BT4;F/0136<;F/YBR480bDY00dYBRe[=Je243g_
=Jd]JbDY:DXaS3F];F/YBP048@P39BT2;F/01BU:9BTQ22DY;F/00bU:0bDY00<Q22DY9BT012U:00LU
:Be[;F/YBRDY8@PU:@02:DX032DY:DXYBRDY8@PLibDY:DXU:B489BTYBPDU:@098@PLiacW9BTQ22e[
:DX]Jc6<008U:@8Li`038@PU:BDY008Q20037>LQ224800@Li`8Q208U:@8Q208Li`058@PU:B489BTQ
20039BT01B489BTYBRU:9BT00b4800<Lib488@P00R4800@U:B488@PQ208U:@03:DX]Jbe[008]J`@Y
BP039BTYBRU:008U:@8Q20<U:@03:DX]JbU:008]J`08:DXU:BDY9BT]Jc6<;F/YBP<U:@038@PU:BDY
00<YBP8U:@04;F/YBRU:9BT58@P012DY<H`aS2U:0QcW12480QcW00@Q22DY8@PHaP<Li`048@PLibDY
7>L88@P00bU:9BTLi`026<H01R487>LLib489BTQ208HaP037>LQ21S6008HaP8Li`8HaP@Li`8Q2003
7>LHaQS600<Li`<HaP038@PLiaS6008HaP<Q208HaP057>LQ21S66<HLi`028@P27>L01b487>LHaQBU
7>LQ22DY00<Li`8HaP@Li`036<HLiaS600<Li`046<HLiacW7>L46<H011cW8@PQ224811cW0aS611cW
00<HaQBU7>L00QcW0QS60acW00<HaQcW7>L00QcW0aS62AcW1AS600<Lib487>L00QS60acW00@HaQcW
6<HHaP<Li`038@PLiacW008HaP@Li`036<HLiacW008Q20037>LQ21S6008HaP047>LQ21cW5:D36<H0
11BU6<HDYAS60aBU0QS600LDYAS66<HDYA245:D@Q0026<H37>L26<H01ABU6<HHaQS65:D011S60aBU
0aS60aBU00<HaQBU5:D00Q240QBU0QS600@DYA245:DHaP8Li`065:D@Q1245:D@Q1BU0QS60QBU00<@
Q1BU5:D011BU00D@Q1BU5:DDYA2400<DY@<@Q0<DY@0448@DYA245:D26<H35:D011S65:DDYABU0Q24
0`aS1a240PaS00<@Q0aS48@00aBU00<@Q0aS48@00QBU00@@Q0aS36<<H`<DY@036<HDYABU00DDY@D@
Q0<<H`8@Q00636<@Q1245:D@Q0aS0Q240aBU00<@Q1BU5:D00QBU00@@Q1BU5:DDY@<@Q0<DY@0648@D
YABU6<HDYA240QBU0Q2400DDYAS66<HDYA24008<H`000P@Q00P000@Q12448@0024848@000P@Q00@Y
BV<HBU8YBP8]J`0:<H`e[C6<:DXU:Be[<H`]Jc6<:DX39BT012U:9BTU:BU:0Re[0RU:00@Q22DY:DXY
BP8]J`<aS003;F/YBRDY00<YBP8]J`8aS009;F/YBRDY9BTYBRDY:DX]JcF]00924005=Jd]JbDY:DXa
S003;F/28@P00bDY8@PQ20029BT00bU:;F/YBP029BT012e[:DXU:B480RU:0RDY00@Q22DY9BTU:@LY
BP039BTYBRU:00<YBP8]J`049BTQ22488@P29BT00b48:DXU:@089BT28@P01BU:;F/]Jbe[:DX00R48
00<Lib488@P00R480bDY0R480QcW0b480RU:00@U:B487>LLi`8Q20049BTQ22489BT2:DX00bDY8@PQ
20039BT022486<HLib487>LQ22DY8@P49BT2:DX012e[:DX]Jbe[1bU:0b480RU:0RDY00<Q22U:;F/0
0S6<00@]JbDY8@PU:@<]J`<U:@048@PYBRU::DX2;F/01RU:9BTU:B489BTYBP8U:@<Q20057>LYBSF]
<H`YBP027>L28@P011cW6<HHaRDY0b4811cW00<Q22DY8@P00b4800<Lib487>L00R4800<U:BU:8@P0
0QS600<Lib488@P00R4800<U:B488@P011cW00<HaQcW7>L00QcW00@HaQcW7>LLi`8Q20<HaP<Li`8H
aP@Li`8HaP057>LQ21cW7>LQ20036<H01ABU6<HLiacW8@P011cW00<DYAS67>L00QcW00<Q21cW6<H0
0QS600<Lib487>L02QcW00HHaQcW7>LHaQcW6<H27>L28@P67>L36<H00acW6<HLi`027>L26<H37>L2
6<H37>L36<H27>L01R487>LHaQS67>LQ208Li`8HaP037>LHaR4800DLi`056<HLiacW7>LHaP027>L0
0b487>LHaP036<H37>L26<H01QBU6<HLiacW8@PU:@8Q20DLi`046<HLiaS66<H35:D26<H25:D36<H2
5:D00aS65:DDY@025:D00acW6<HLi`056<H25:D26<H25:D00aS65:DDY@036<H01AcW6<HDYABU48@0
11BU00<@Q1BU48@011S600HDYAS67>LHaQBU48@35:D00aS65:DDY@025:D248@45:D00a245:DDY@02
5:D248@25:D348@25:D00a245:DDY@035:D00aS65:DDY@0248@36<H348@00aBU48@@Q00248@25:D0
0a2436<@Q00248@236<00a245:DDY@045:D00aS65:D@Q00236<00aBU6<HDY@035:D00a245:DHaP05
5:D248@00`aS48@@Q00248@336<248@00aBU48@@Q0025:D448@36<H348@25:D01A2436<@Q1246<H0
31BU0Q240PaS00001@0012448@@Q00000`@Q00`8@P@Q1248@SF]IcU24248<H`icS6<:DX2;F/00bU:
9BTYBP03;F/01BU:9BTU:BDY;F/00RU:00<]Jc6<:DX00bDY0RU:1Be[1BU:00D]Jc6<;F/aS2e[008Y
BP8U:@03:DX]JcF]008icP0??Nm243W><H`]Jc6<=JdicRe[:DXU:B489BTQ22DY00<YBPLU:@04:DXU
:BU::DX39BT8:DX39BT2:DX2;F/2:DX01B489BTU:B489BT00RU:00HU:B487>LU:B489BT28@P27>L0
22489BT]Jc6<:DXQ21cW6<H49BT00b489BTU:@029BT26<H00acW8@PYBP029BT27>L28@P29BT011cW
8@PLib480RDY00<Q22DY8@P00b480RDY1b4800@U:B488@PU:@8]J`@YBP8U:@8YBP0:9BTYBRDY:DXU
:B489BTYBRDY8@P29BT4;F/6:DX012DY7>LQ22DY0RU:0RDY00HYBRe[;F/U:B489BT38@P00bDY7>LH
aP028@P2<H`01Be[:DXU:B489BT00acW12480QcW00HQ22DY7>LLiaS68@P29BT012487>LLib480RDY
12480acW00@Q22DY9BTQ208HaP<Li`038@PLiaBU008HaPHLi`038@PLiaS6008HaP038@PLiacW008H
aP<Li`046<HLiacW7>L28@P27>L01AS67>LLiaS68@P00QcW0QS611cW0b480acW0QS600HQ21cW8@PQ
21cW6<H57>L01QS65:DHaQBU6<HLi`HQ20039BTQ21cW008Li`<HaP8Li`048@PHaQcW6<H27>L25:D2
6<H37>L00aS67>LLi`027>L012487>LLiacW0QS61AcW00<HaQcW7>L00b4800<HaQBU6<H00QS600<L
iaBU6<H01QcW00@HaQcW6<HLi`8Q208Li`035:DHaR4800<Li`@HaP055:DHaQS66<HDY@096<H35:D0
11S65:DDYABU0aS600<@Q1BU6<H01AS60QBU0aS600DDYAS65:DLiaS600<DY@8HaP<DY@036<HDYAS6
008DY@0548@DYABU6<HLi`065:D248@25:D01AS65:DDYABU48@00QBU1A240QBU00<@Q1BU5:D00Q24
11BU0Q2400HHaQBU6<HHaQBU48@35:D248@35:D01a2436<<HaBU6<HDYA24008<H`0548@<Ha2436<@
Q0036<H01Q2436<@Q1S65:D@Q08<H`0448@DYABU6<H25:D448@011BU6<HDYABU1A2400<<Ha2436<0
0Q240QBU0a2400@DY@aS36<<H`8@Q0055:DHaQBU48@DY@0248@25:D00a245:D@Q00548@35:D348@0
11BU48@DYABU0Q240@aS000312400`001240000212402`Q200048@Q2<HaS64Ha8@PaS3F];F/00RU:
00@]JbU::DX]J`8aS003;F/YBRU:00@YBP03;F/aS2e[008YBP098@PU:BU::DX]Jc6<:DX]JbU:008]
J`<YBPD]J`069BTYBR489BTYBRe[0S6<00DicT8@?NlicS6<008]J`<aS004;F/YBRU:9BT38@P2:DX0
12DY8@PU:BDY0RU:1BDY00<YBRDY:DX00bU:1bDY00@YBRDY:DXYBP<]J`049BTLib488@P69BT58@P2
7>L01R489BT]Jc6<:DXU:@8Li`078@PU:BDY:DXU:B489BT00R4800@LiaBU7>LLi`8U:@8Li`078@PU
:B489BTLib487>L0124800<U:B488@P00bDY00<Q22DY8@P00RDY0acW00<Q22DY8@P00RDY00<]JbU:
:DX022U:0bDY00<Q22DY8@P01BDY00HYBS6<<H`aS2U:8@P2:DX00c6<:DXU:@029BT2:DX39BT2;F/0
12U:8@PQ22480RDY00<YBRDY8@P00QcW00<Q22e[;F/00Re[0bDY00DLiaS67>LLibDY00@Q20059BTQ
21cW7>LQ20029BT37>L00b487>LQ20028@P02RDY8@PLiaS67>LQ22DY8@PLib480QS60QcW00<Q21cW
6<H00QcW0QBU0QcW00<Q21cW7>L00QcW11S60QcW0QS60QBU00@HaQcW8@PLi`<Q208Li`<HaP8Li`04
8@PHaQS66<H27>L26<H01AcW9BTQ21cW6<H011cW00@Q21cW7>LHaP8Li`076<HLiacW7>LHaQcW6<H0
0QcW00<HaQcW8@P00b4800@U:BU:8@PHaP<Li`<HaP8Li`046<HLiaS67>L56<H02AcW6<HLib487>LH
aQcW8@PU:@027>L00aS67>LLi`026<H01QcW8@PQ21cW6<HLi`8Q20037>LHaQBU008HaP077>LHaQS6
6<HLib487>L00QS60QcW11S600PLiaS65:DHaQcW8@PLiaS611cW1AS600TLiaS66<HHaQBU6<HLiaS6
7>L01aBU0aS600@DYAS66<HLi`8HaP<DY@047>LDYABU5:D26<H35:D26<H011BU48@@Q1BU0aS60aBU
00@HaQBU48@DY@@HaP<DY@046<HDYA245:D26<H95:D00a245:D@Q00248@45:D248@35:D011245:D@
Q1S61ABU00L@Q1BU48@@Q1BU6<H@Q00236<00a246<HDY@0248@030aS48@@Q0aS48@<Ha245:DLiaS6
48@<H`8@Q0035:D@Q1BU00<<H`8@Q0035:D<Ha24008DY@<@Q0035:D@Q12400@@Q08<H`0448@<Ha24
36<348@011BU48@@Q1240`aS00L@Q1BU6<HHaQ2436<@Q0035:D448@011BU48@@Q1240aBU0Q2400<D
YAS648@00Q240ABU0A2400000`@Q00048@09124012U:F]I242DY0bU:0Re[00<aS2e[;F/00bU:0be[
0RDY00H]Jc6<=Jd]JbU:9BT3:DX3<H`5;F/5:DX3;F/2:DX00bDY:DXYBP02<H`01CW>=JdaS3F]>Lh0
0S6<00<YBRe[<H`00c6<00HYBRDY:DXYBS6<;F/39BT28@P00bDY8@PU:@069BT032e[<H`aS2e[9BTQ
22DY;F/YBRDY8@PU:@<YBP03;F/YBRU:008Q20049BTQ22488@P37>L29BT38@P01QS67>LQ22489BTL
i`<Q208Li`8Q20<U:@058@PU:BDY9BTQ20026<H37>L012489BTU:BDY0QcW00HQ22DY9BTQ21cW8@P2
9BT48@P2:DX00bDY7>LLi`028@P01BDY8@PLib489BT00R4800<U:BU::DX00RDY00@Q22DY:DXYBP@U
:@8YBPDU:@<YBP03;F/YBRU:00DYBP039BTQ224800<U:@0>:DXU:B489BTYBS6<:DXU:B489BTQ22DY
8@PU:@8Q20@U:@<Q208U:@057>LHaQcW9BT]J`038@P00bDY8@PQ20028@P37>L012U:9BTU:AcW1B48
00@LiaS67>LLi`8Q20LLi`8Q20037>LHaQcW00<Li`038@PLiacW008Li`036<HLiacW00@Li`<HaP04
8@PLiacW7>L28@P00bDY7>LQ20037>L00aS67>LHaP027>L26<H00acW6<HHaP047>L00b487>LLi`02
7>L28@P97>L011S65:DHaQcW0R480acW00<Q22DY9BT00b480acW00<Q21cW8@P011cW00PQ21S66<HH
aQcW6<HLiaS60acW00<Q21cW8@P00b480QS60QcW00<Q21cW7>L00QcW0RDY0R4811S600LLiaS66<HL
ib487>LQ20076<H011cW8@PQ22480QcW11S600<LiaS68@P00QcW0aS600<Q21cW6<H00QBU00<HaQcW
6<H01AS611BU00HHaQcW6<HHaQBU6<H27>L00b486<HDY@055:D011S67>LHaQBU1aS600DDYAS65:DD
YAS600@DY@0648@DYABU7>LHaQBU0QS600<DYA2448@00a2400@DYA2448@@Q0<DY@8@Q0035:DHaQBU
008DY@<HaP0648@<Ha2448@DYAS60QBU00D<HaBU6<HQ21S600L@Q00436<@Q12448@25:D248@01@aS
48@@Q1245:D00Q2400@<Ha245:D@Q0<DY@0348@DYA24008@Q0035:D@Q0aS00H@Q0035:D@Q1BU008H
aP045:D@Q1245:D336<448@35:D548@236<248@25:D448@35:D248@010aS48@@Q1BU112400@DYAS6
6<HDY@8@Q08HaP4DY@4@Q0000P@Q00H000@Q12448@00248212402000248]JeJe>LhLibe[<H`2:DX0
3Be[<H`]Jbe[:DX]Jc6<;F/YBRe[:DXU:Be[008e[@03<H`YBRDY008]J`06:DX]Jbe[<H`]JbU:0be[
00<YBRe[;F/01BU:12DY00HYBRe[=JdicSF]<H`2=Jd01CW>=Jd]JbDY;F/00S6<00@]JbDY9BTU:@8]
J`03<H`YBR48008Q20@U:@<YBP079BTLibDY:DXe[C6<;F/00R480bU:0bDY12U:00<]JbDY8@P00bDY
00<Q21S67>L0124800<U:B488@P011cW0b4800<U:B488@P00QcW00@U:B488@PQ20<U:@038@PLiacW
00@Li`8Q20039BTYBR48008Q208U:@8Q20<U:@@Q20<U:@038@PLiacW008U:@038@PLib4800DU:@05
:DXU:BDY8@PU:@02:DX012DY8@PU:BDY0RU:0bDY0RU:00<U:BU::DX00Re[00<YBRDY:DX00RU:00<]
JbU:9BT00b4800DU:BU:9BTU:BU:008]J`04:DXU:AcW8@P39BT38@P2:DX29BT022487>LU:B489BTQ
21cW8@P39BT00acW8@PU:@038@P27>L011S68@PQ22DY1B481AcW124811cW00DQ22DY8@PQ21S6008L
i`056<HLiaS67>LQ20057>L00aS67>LLi`027>L26<H37>L01AS67>LQ22DY8@P01QcW00@HaQcW7>LH
aP8Li`8HaP<Li`038@PLiacW008Q20077>LHaQcW8@PU:AcW6<H00QcW0QS600<Lib486<H00QS600<L
ib487>L00QcW00<Q21cW8@P00RDY00<Q21cW6<H00R480acW0R480RDY00<LiaS66<H01QS600<Q21cW
7>L00R4800@U:AcW7>LHaPPLi`088@PLib488@PLiaS65:DHaPDLi`088@PLiaS67>LHaQcW6<HDY@8H
aPLLi`<HaP8Li`038@PLiacW008HaP8Li`DHaP8Li`<HaP035:DHaQ24008@Q0HHaP8Li`8HaP8DY@8@
Q0065:DHaQS66<HDYAS60QBU0QS600@DYAS66<HHaPDDY@0348@DYA2400<DY@@HaP<DY@8@Q08DY@<@
Q00336<@Q12400@DY@0348@DYABU00@HaPH@Q0035:D@Q1BU00<DY@046<HDYABU48@236<248@00aS6
5:DDY@0348@00aBU36<@Q00348@236<00a245:DDY@035:D00a245:DDY@0248@00`aS48@DY@0348@0
0aBU48@<H`0248@00aBU48@DY@035:D448@00`aS48@@Q00248@010aS48@@Q1240QBU0Q240PaS1124
00<DYA245:D00Q240aBU00<@Q0aS36<00QBU00P@Q1BU48@@Q0aS48@DYAcW1QBU0A2400001@001244
8@@Q00000`@Q00T8@P@Q1248@RDYF]I241cW9BT00RU:00<]Jc6<;F/00Re[0RU:00X]JcF];F/Q22DY
;F/icS6<:DX]J`8aS08]J`8YBPH]J`<YBP06;F/aS36<;F/YBR480bDY00<]JbU:<H`00Re[136<00D]
Jc6<<H`]JbU:008]J`03<H`]JbU:008]J`03<H`]Jbe[008YBP038@PLib48008YBP049BTQ22U:;F/4
:DX00be[:DXYBP029BT3:DX28@P01bDY:DXYBRU:8@PLibDY00<Q20037>LQ21cW008Q208Li`<Q2005
9BTQ22489BTYBP039BT27>L28@P39BT2:DX28@P011S67>LQ21cW0R4800@U:B489BTQ20<U:@038@PU
:BDY00<U:@8Q20049BTQ22488@P29BT37>L00b487>LQ20048@P00bDY:DXYBP029BT01RU:9BTQ22DY
:DXU:@8Q20049BTYBRe[9BT2:DX01RDY8@PU:BU:;F/aS08YBP8U:@06;F/YBRU::DX]JbDY0b4800<U
:B48:DX012U:00DU:B487>LQ22DY008Q20049BTLiacW8@P29BT01R487>LLib489BTQ208Li`048@PU
:BU:9BT28@P01AcW8@PQ21cW8@P00QcW0R4800@LiaS66<HLi`8Q20<Li`036<HLib48008Q20037>LH
aQS6008Q20049BTQ21cW6<H37>L00aS65:DLi`028@P27>L28@P00acW6<HHaP027>L00b487>LLi`03
7>L01AS68@PQ21cW8@P01acW00<DYAS67>L00QcW0aS60R480QcW0QS60R4800DLiaS67>LLibDY008Q
20046<HLiacW6<H25:D011cW5:DHaQS60QcW00@Q21cW8@PLi`8U:@038@PLib4800<Q208U:@0:8@PL
iacW8@PU:AcW5:DHaR487>L36<H27>L012DY8@PQ22DY0QcW00DHaQBU7>LQ21cW00<Q208Li`058@PH
aQcW6<HDY@026<H:7>L36<H011cW8@PQ22480QcW00DQ21S65:DHaQcW008Q20HLi`8HaPDLi`036<HD
YAS600<HaP<DY@037>LHaQS600<HaP038@PLiacW00<HaPDDY@046<HDYAS66<H25:D011245:DHaQcW
0QS60aBU00DHaQ245:DDYAS600<DY@DHaP<DY@@@Q00336<@Q12400@DY@8@Q0DDY@D@Q0035:DHaQS6
008DY@0548@DYAS66<HDY@0248@236<00a245:DDY@035:D248@00`aS48@DY@0248@01PaS48@DYA24
5:D@Q08DY@0348@DYAS6008@Q00936<@Q1BU48@<Ha245:D@Q0aS00@@Q0035:D@Q1BU00<HaP8DY@04
48@<H`aS36<548@00aBU6<HDY@025:D336<00aBU48@@Q00248@00aBU48@@Q0025:D348@00aBU48@@
Q0035:D00aS65:DDY@036<H00aBU48@@Q0026<H15:D148@000<48@0700048@@Q0008@P@Q00000P@Q
00L]Je:D>LhLibDY:DX]J`02<H`00bU:;F/]J`03:DX012e[:DXU:BDY0S6<00<]JbU:;F/00SF]00Da
S2U:;F/YBRe[00<YBP<]J`<YBP04;F/YBRe[:DX49BT01RU:<H`]JcF];F/aS0<]J`8aS0<]J`03:DX]
Jbe[008]J`05:DX]Jbe[;F/YBP059BT01B489BTU:BU:;F/00RU:0bDY0RU:1bDY00DQ22DY:DX]Jb48
008Li`038@PU:BDY008Li`046<HLib487>L38@P29BT27>L012489BTYBRDY0b4800TU:B487>LLib48
:DX]JbU:8@P00QcW00@Q22DY8@PQ208U:@8Q20<U:@047>LU:BDY:DX29BT38@P00bDY8@PQ20029BT2
8@P27>L01R487>LQ21cW9BTQ20@U:@04:DXU:B489BT3:DX69BT01BU:8@PU:B489BT00RU:00DaS2e[
:DXYBR48008U:@8YBP03;F/YBRDY008Q208U:@038@PU:BDY008YBP<U:@8Q20047>LQ22487>L:8@P0
0bDY8@PLi`028@P01BDY7>LQ22489BT01AcW00HQ21cW7>LQ21cW8@P37>L28@P27>L01B487>LQ21cW
8@P00aS600@Lib487>LHaP@Li`046<HLiacW6<H48@P00acW6<HHaP027>L00b487>LLi`027>L00aS6
7>LLi`028@P01RDY8@PLiaS67>LHaP8Li`036<HLiaS600<Li`<HaP037>LQ21cW008HaP047>LU:B48
8@P47>L00b487>LLi`027>L66<H67>L39BT27>L011S68@PU:BU:0RDY00LQ21cW7>LU:B487>LDY@03
7>L26<H27>L58@P27>L26<H27>L28@P00acW8@PLi`037>L46<H25:D011S67>LQ22480QS60acW0aS6
00<Q22DY8@P01AcW00<HaQBU6<H012481acW00<HaQcW6<H011S600<DYAS66<H011S600DLiaS65:DD
YAcW008Q20047>LHaQBU5:D26<H25:D011S65:D@Q1BU0QS600HDYA245:DDYAS67>L26<H35:D01AS6
5:D<Ha245:D00QS60QBU00<HaQBU6<H00QBU2A2400HDYAS66<HHaQBU48@25:D00aS65:D@Q00348@0
11BU48@DYABU0QS60Q2400@HaQBU6<H@Q0<<H`055:D@Q1BU5:D@Q0035:D348@011BU48@@Q0aS0a24
00<DYA245:D01ABU00@@Q1BU48@<H`D@Q00336<@Q124008@Q08HaP035:D@Q124008@Q0D<H`D@Q003
5:DHaQcW00H@Q08<H`8@Q0035:D@Q1BU00P@Q08DY@0548@DYA245:DHaP025:D248@35:D148@00003
00048@0000D48@0<24848@@Q248YBU:D=JdLibU:<H`]JbU:0Re[12U:0Re[0RU:0RDY0c6<00<e[C6<
<H`00be[12U:0Re[12U:12e[0bU:00H]JbU:;F/]Jc6<:DX2;F/00c6<;F/]J`02:DX3;F/01RU:9BTY
BRe[:DX]J`8aS004:DXU:BDY;F/2:DX38@P00bDY:DXU:@02:DX00be[:DXU:@028@P2:DX29BT27>L2
9BT00bU:9BTQ20058@P37>L28@P00bDY8@PQ20028@P00bDY:DXYBP029BT2:DX00bDY7>LQ20028@P0
22DY:DXYBR487>LQ22U:8@P26<H00acW8@PLi`027>L012DY:DXU:BDY0R480bDY00<Q22DY8@P00RDY
0b480bDY00<Lib487>L00QcW0R4800XU:B488@PU:B489BTYBRe[<H`]J`8U:@038@PU:BDY008U:@03
8@PU:BU:008YBP8U:@05:DX]Jbe[;F/YBP028@P29BT00bU:;F/YBP02:DX49BT00b489BTYBP02;F/0
0bU:8@PLi`028@P00bDY8@PLi`029BT012487>LHaQcW1B4800@Lib488@PU:@<Q20<U:@057>LQ21S6
6<HLi`038@P011cW6<HLib480acW00@HaQcW8@PU:@<Li`8HaP8Li`8Q20057>LQ21cW7>LQ20087>L0
12487>LLib4811cW00<Q21cW7>L02AcW0QS60R4800@LiaS66<HQ208Li`8HaP8Li`<HaP037>LQ2248
008Li`036<HLiaS600<Q20047>LDYAS66<H35:D01QS67>LHaQcW6<HQ20@Li`DQ208U:@8Q20<Li`<Q
20047>LHaQcW8@P37>L28@P27>L38@P37>L00aS67>LLi`038@P01QcW8@PQ22487>LHaP8DY@067>LH
aQcW8@PU:B480acW11S61QcW0b4800THaQcW7>LLib487>LQ21cW8@P00QcW00DHaQcW6<HDYAS6008L
i`<HaP035:DLiaS6008HaP045:DLiaS67>L26<H011cW6<HLiacW0QS60QBU00DHaQBU5:D@Q1BU00@H
aP<DY@8HaP8DY@8HaP8DY@0348@DYABU008@Q08HaP<DY@8HaP055:DHaQBU6<HDY@0348@010aS48@D
YAS60aBU0a240QS60QBU1A240aBU0Q240QBU00<@Q1S66<H00QBU0PaS0a2400L<Ha245:DHaQBU48@<
H`0248@00`aS48@DY@026<H248@00aBU48@@Q0025:D248@236<35:D248@01`aS48@<H`aS48@DYAS6
00<DY@<@Q00336<@Q1BU00D@Q0035:D@Q1BU008HaP<@Q08DY@0448@DYABU5:D348@011BU48@@Q124
0QBU0a240aBU0Q240aBU0Q2400<DYA245:D00QBU0A24000512400`001248@P0212402@00248]Je:D
=JdHaRU:<H`]J`02:DX00be[:DXYBP03;F/00bU:9BTQ20029BT2<H`2=Jd00c6<;F/aS003;F/9:DX3
;F/012U:;F/YBRU:22e[0S6<00D]JbU::DX]Jc6<008YBP039BTYBRe[008]J`03<H`]JbU:00<YBP04
;F/U:BDY9BT3:DX29BT00bU:;F/U:@028@P01bDY;F/U:BDY8@PU:AcW008U:@038@PU:B48008Li`8Q
20067>LHaQcW8@PU:B480QcW00<U:B488@P00RDY00@YBRDY9BTYBP@Q208U:@038@PU:BDY00@U:@8Q
20047>LQ22487>L38@P59BT00b489BTU:@049BT00b487>LQ20029BT28@P011cW8@PQ21cW0R4800<U
:B489BT01BDY0be[00<U:B489BT00RDY0R4800<U:BU:;F/00bU:0RDY00@YBRe[:DXYBP<U:@8YBP04
;F/YBRU::DX29BT28@P01RDY8@PYBS6<;F/YBP8Q20049BTLib486<H27>L38@P37>L28@P29BT03248
7>LQ22489BTQ22DY:DXU:B487>LHaP@Li`068@PLiacW7>LU:B480QcW00HHaR489BTU:AcW6<H37>L3
6<H00b487>LQ20047>L00aS67>LLi`027>L01AS68@PQ22DY8@P00acW00<HaR489BT00R4800DLiaS6
8@PLiaS600@Li`066<HDYAS68@PU:B480QS60QcW0QBU00@HaR488@PQ20HLi`046<HLiacW7>L38@P3
6<H01AcW6<HHaQS67>L00aS600<Lib488@P00b4800<Lib489BT00RDY00<Q22DY9BT00R480acW0R48
0acW00@Q21cW6<HHaP<Q20059BTQ22488@PLi`036<H27>L00b489BTU:@028@P00acW8@PLi`026<H0
0acW6<HDY@026<H38@P26<H37>L26<H47>L38@P00acW6<HHaP027>L28@P37>L28@P021cW5:DDYAS6
7>LDYAS67>L46<H011cW5:DDYAS60QcW0QS600@LiaS66<HHaP8Li`036<HDYABU00<HaP<DY@056<HL
iaS65:D@Q0025:D01AcW6<HDYABU6<H021BU1aS60QBU0Q240aBU0a241ABU00D@Q1BU5:DHaQBU008@
Q08DY@8@Q0045:DHaQBU5:D248@25:D26<H248@01PaS48@@Q1BU48@<H`<@Q0036<HDYA24008@Q003
36<@Q1BU008HaP055:D@Q1245:DHaP025:D548@25:D01Q245:D@Q12436<@Q0@DY@0348@DYABU00/@
Q08DY@036<HDYABU008@Q0055:D@Q12448@DY@0:48@01QBU48@@Q1245:D@Q0<DY@8HaP8DY@0348@<
HaBU008DY@4@Q00000L000@Q12448@001240000412401PQ2:DY:DS6<7>LYBP8aS003;F/YBRDY008Y
BP8]J`04:DXU:BDY:DX2;F/2:DX01Be[=Jde[C6<;F/00bU:00PU:BU::DXYBRDY8@PU:BU:12e[0cF]
00D]JbU:<H`e[C6<008]J`03:DX]Jbe[008YBP049BTYBRU:9BT2:DX7;F/6:DX012DY8@PU:B480RDY
00/Q22DY9BTQ22DY:DX]JbU:9BTYBRe[008U:@046<HQ22487>L28@P01BDY8@PQ22489BT00b4800@U
:B488@PLi`<Q20047>LU:BDY:DX39BT28@P00bDY8@PYBP02:DX38@P012DY8@PLiaS60QcW0R4800<U
:B488@P01R480RDY2R480QcW0R480RDY0QcW00DQ22DY:DXYBRe[008YBP03<H`]JbU:008Q20039BT]
JbU:00@U:@<YBP8]J`06<H`]JbDY9BTQ22DY0bU:00<U:BU::DX00bU:0R4800@U:Be[<H`]J`8U:@03
:DXU:BDY008U:@@Q20049BTQ21cW6<H27>L00bDY8@PLi`039BT38@P01BDY:DXU:B486<H00acW0R48
0QcW0R4800<Lib488@P00QcW124800@LiaS66<HHaP<Q20<Li`076<HLiacW8@PLib486<H00acW00@Q
22DY8@PQ20@Li`068@PU:BDY7>LHaQcW0R4800@LiaS66<HHaP8Li`<HaP048@PLiaS66<H87>L26<H2
7>L28@P36<H29BT00b486<HLi`027>L00aS65:DHaP026<H01ABU6<HLiacW8@P011cW00DHaR488@PY
BRDY008Q20039BTLiacW008Li`8Q208Li`8Q208Li`038@PLiacW00@Q208Li`036<HLiacW00@Li`<U
:@DLi`8HaP<Li`038@PLiaS6008HaP8Li`078@PLiacW7>LQ22DY8@P00QcW00<Q21cW6<H00QcW00HQ
21cW6<HHaQcW8@P27>L011S65:DHaQBU11S600LDYAS67>LQ21S65:DHaP027>L26<H01ABU6<HHaQcW
6<H00QcW0QS621BU00@HaQBU5:DDY@8HaP<DY@046<HDYABU6<H25:D01Q245:DDYAcW6<HDY@<HaP06
5:DHaQcW7>LHaQBU0Q240QBU0Q2400@DYAS65:DDY@<@Q08DY@0348@DYA24008@Q0<DY@8@Q00736<@
Q1BU5:DHaQBU48@00QBU112400<<Ha2448@00QBU00<HaQ245:D00Q2400@<Ha2436<<H`8@Q0046<HD
YA2448@25:D336<248@25:D248@00`aS48@@Q00448@45:D248@00`aS48@@Q00448@00aBU48@DY@04
5:D00a245:DDY@025:D011245:DDYABU0Q2400@DYA2436<<H`<DY@0548@DYAS65:D@Q0035:D248@3
5:D00aS65:D@Q0025:D136<000848@0300048@@Q00848@0:24848@001248@RU:BU8aS1S69BT2<H`2
;F/00bU:9BTYBP02;F/01RU:9BTU:BU:;F/U:@8YBP03<H`e[C6<008aS003:DX]JbU:008YBP03;F/U
:B48008Q2004;F/aS2e[:DX2;F/00cW>=JdaS002;F/00c6<=Jd]J`02:DX2;F/00bU:9BTU:@02:DX3
9BT3;F/00bU:;F/YBP03;F/3:DX012e[:DXU:B480RDY0R4800@U:BU:9BTU:@<YBP079BTYBRU::DXU
:B487>L00R4800@LibDY9BTQ208Li`8U:@048@PLib488@P27>L00b489BTQ20028@P39BT48@P29BT0
1R489BTYBRDY8@PLi`<Q20<Li`038@PU:BDY008U:@8Q20059BTQ22DY9BTQ20029BT28@P00acW8@PU
:@028@P011cW8@PQ22480RDY0R4800HU:B488@PU:BU:;F/3:DX2;F/2:DX00b489BTU:@02:DX29BT0
0bU:;F/YBP02:DX012e[<H`]JbU:1BDY0RU:1BDY0R4800@U:BU:<H`]J`<U:@8Q208U:@8Li`058@PU
:BDY8@PLi`026<H00acW9BTQ20028@P39BT27>L02b489BTU:BDY7>LHaQcW8@PU:B487>L00QS61248
0QcW00<Q21cW8@P00R480QS600<Lib488@P00QcW00LQ21cW8@PLiaS67>LQ20027>L26<H00acW8@PQ
20038@P01AcW8@PU:BDY8@P00acW00<Q21cW7>L00QcW00<HaQcW7>L00QcW00LHaQcW8@PLiaS67>LQ
20037>L00b487>LLi`057>L012487>LHaQS60QcW00<Q21cW7>L00acW0aS600DDYAS65:DHaQcW00<Q
20047>LQ22487>L28@P39BT012U:9BTQ224821cW00<Q21cW6<H00QcW00LU:B488@PQ21cW8@PLi`03
6<H27>L48@P57>L01aS65:DHaQcW9BTQ21cW008HaP@Li`<HaP<Q20<Li`8HaP8Li`058@PHaQS67>LQ
20027>L00aS65:DDY@055:D00aS65:DHaP066<H27>L56<H00acW6<HHaP046<H25:D01AS65:DDYAS6
5:D00QS600<DYAS65:D00aBU00DHaQ245:DDYAS6008DY@8@Q0045:DHaQcW7>L25:D01QS65:DHaQS6
7>LHaP@DY@8<H`0648@HaQBU48@DYA240QBU0Q240PaS00D@Q1BU5:DDYA24008DY@<@Q0035:DHaQBU
008DY@<@Q00336<@Q0aS008@Q0035:DHaQ24008DY@@@Q0095:D@Q1245:D@Q1BU48@DYAS6008@Q003
36<@Q124008<H`0348@DYA24008<H`035:D@Q0aS00<@Q0035:D@Q1BU00@@Q0055:D@Q12448@DY@03
48@35:D01A245:DDYA245:D00Q2400<DYAS65:D0112400<<Ha2448@011BU00@HaQ245:D@Q0@DY@04
48@DYABU48@25:D148@15:D136<00005124000@Q12400007124022DYBU8e[B48;F/aS3F]<H`3:DX0
136<:DXU:BU:0be[0RDY00<YBS6<=Jd0136<00@]JbU::DX]J`8YBP049BTQ22DY8@P2:DX2<H`00be[
<H`aS003<H`6;F/2:DX012DY:DXU:BU:0RDY00D]JcF]<H`]Jb4800PYBP8U:@08:DXU:BDY9BTLib48
9BTQ20<U:@8YBP06;F/YBRe[;F/U:B480QcW00<U:B488@P00R4800DHaR488@PQ22DY008Q208U:@@Q
208U:@8Q20057>LQ22488@PU:@038@P00bDY8@PQ20029BT012486<HLiacW0R480QcW00<Q22DY:DX0
0b4800PU:B488@PQ22DY8@PLibDY0RU:00<U:AcW7>L00R480bDY0R480RDY124800@U:BU:;F/]J`8Y
BP03;F/U:BDY00<YBP<U:@8YBP08;F/YBRe[<H`e[C6<:DXQ20@U:@04:DXU:BDY9BT3:DX012DY8@PU
:BU:0Re[0bDY00@YBRDY9BTQ208U:@8Q20039BTQ224800<Li`LQ20037>LU:BDY008YBP8Li`036<HL
ib48008Q20069BTQ21cW7>LHaQcW0b4800<U:B489BT00QcW0QS60QcW00@Q22DY9BTQ208Li`8Q2005
6<HLib489BTQ20027>L58@P27>L00b487>LQ20028@P67>L012487>LHaQS60QcW00DQ21cW6<HQ22DY
00@Li`078@PU:AcW7>LHaQcW8@P00QcW0aS60QcW00<HaQcW6<H00R4800<LiaS66<H00QS60aBU00DH
aQcW6<HHaR48008Li`8HaP047>LQ22U::DX28@P00bDY7>LLi`048@P46<H01QcW6<HLiacW9BTQ208L
i`068@PLiaS66<HLib480QS600@Q22DY:DXU:@8Li`8HaP058@PLiacW7>LQ20027>L36<H97>L011S6
7>LQ21cW0aS61AcW00@HaQcW6<HHaPDDY@8HaP<DY@<HaP035:DHaQS600<HaP035:DHaQBU00<HaP8L
i`036<HLiaS6008DY@0348@DYAS6008HaP057>LHaQS65:DHaP045:D36<H01ABU48@@Q1BU6<H00QBU
0aS600@DYA245:DLi`8Q20046<H@Q12448@25:D00a245:DDY@025:D248@011BU48@DYABU11240QBU
0a2400<DYA2448@00Q2400@DYAS65:DDY@H@Q0HDY@0448@<H`aS36<548@25:D00aS65:D@Q00248@2
36<248@25:D348@00aBU48@@Q00236<25:D548@010aS48@DYABU0Q241ABU0Q2411BU0Q240QBU00D@
Q1BU6<HDYA24008<H`8@Q08DY@0548@DYABU5:D@Q0045:D01A245:DDYA245:D00Q240ABU0A240@aS
000312400`0012448@0412401@00248Q24ic>Lh00R4800@]Jc6<>LhaS08YBP07<H`YBRU::DX]Jc6<
:DX00RDY00H]JcF]=JdaS2U:;F/2<H`01Be[:DX]JbU:9BT0124800<YBRe[<H`00c6<0SF]00DaS2e[
<H`aS2U:00@]J`04:DXU:BDY9BT2:DX01B48;F/aS3F];F/00RU:00@]JbU::DXU:@<]J`8U:@8Q2003
9BTQ22DY008Q208U:@8YBP03;F/YBRU:008YBP06<H`YBR486<HLib480RDY11cW0RDY0R4800<Lib48
8@P00b4812DY0R4800@Lib489BTU:@8Q20<U:@8Q20039BTQ2248008HaP0:7>LQ22DY7>LQ22DY:DXQ
21cW8@P2:DX28@P29BT01B489BTYBRU:9BT00QcW00@Q22DY:DXU:@8Q208U:@058@PLiaS67>LQ2003
:DX3;F/00bU:9BTU:@06:DX02Be[:DX]JbU:;F/aS3F]<H`]J`039BT3:DX29BT00bU:9BTYBP029BT0
0bU:8@P]J`02;F/00bU:8@PU:@029BT28@P00bDY8@PU:@029BT28@P00acW8@PLi`048@P29BT38@P0
0bDY:DXU:@047>L00b489BTU:@047>L38@P01AcW8@PQ21cW8@P00acW0QS600HQ22DY:DXU:AcW8@P2
7>L01AS67>LQ22489BT011cW124800@Lib487>LU:@<Q20047>LQ21cW7>L28@P27>L26<H011cW8@PQ
21cW0QS600<Lib487>L00QcW0RDY00DQ21cW5:DHaQcW008Q208Li`036<HLiacW00<Q20037>LHaQcW
00<Li`DHaP<Li`DHaP047>LU:BU::DX39BT012486<HLiacW0b4800<LiaBU6<H00acW0b480QcW00<Q
21cW6<H00QcW00@Q21S67>LQ208U:@038@PLiacW008Li`8HaP@Li`DHaP<Li`8HaP037>LQ21S600<L
i`8Q20077>LDYAcW8@PU:B486<H00acW0QS611BU00DHaQBU5:DHaQcW00<DY@036<HLiaS600LHaP03
7>LQ21cW00DHaPDDY@<HaP035:DHaQS6008DY@0448@HaQS66<H65:D00aS67>LHaP026<H01aBU48@D
YAcW8@PU:AS6008@Q0<DY@8@Q08DY@0348@DYA24008@Q0<DY@0548@<Ha2448@DY@0348@03aBU48@<
Ha246<HLiaBU48@DYA245:D@Q0aS48@<H`0248@25:D248@00aBU48@<H`0448@00`aS48@DY@045:D2
48@00`aS48@@Q00448@01ABU48@<Ha2436<00Q2400LDYA2436<<Ha245:D@Q00236<011BU48@DYA24
1QBU00D@Q1BU5:DHaQBU008@Q08DY@D@Q08<H`085:D@Q1BU48@DYAS65:DHaP8DY@036<HDYABU00<@
Q08DY@0448@DYABU48@136<0000300048@@Q00848@0300048@@Q00<48@08248U:DYB<H`U:C6<=Jda
S08]J`0<:DX]Jbe[:DXU:Be[<H`]JbU:9BTYBS6<1CF]00LaS2e[:DX]Jc6<;F/YBP027>L01BDY;F/a
S36<;F/00S6<00L]JbU:<H`e[CW><H`YBP04;F/29BT012U:;F/]JbU:0RDY00D]Jc6<<H`]JbU:00<]
J`8YBP<U:@@YBP<U:@8YBP038@PU:BDY00<]J`<YBP049BTQ22488@P49BT68@P29BT2:DX01BDY8@PQ
22489BT00R480acW00<U:B488@P00QcW00HQ22DY:DXYBRDY8@P27>L011S68@PU:BDY0b4800LU:BU:
9BTQ21cW8@PU:@028@P00bDY:DXYBP028@P00bDY:DXU:@039BT48@P29BT012487>LLib480RU:00D]
JbU:9BTYBRe[008YBP039BTYBRe[00HYBP8]J`06=JdaS3F]<H`]JbU:0RDY0bU:0RDY00<YBRe[:DX0
0RDY00DYBRe[;F/YBRe[008U:@038@PU:BU:008U:@058@PU:BDY8@PU:@028@P021cW9BTYBRU:7>LH
aQcW:DX29BT38@P39BT01B487>LQ22489BT00R480RDY0R4800<LiaS67>L00RDY00HQ21cW7>LQ21S6
7>L26<H01acW8@PU:AcW8@PU:B48008Li`038@PU:BDY00<Li`<Q208Li`078@PLiacW8@PU:BU:9BT0
0QcW0R4800<U:AcW5:D00QS60R481AcW0R480QcW0R480RDY0acW00DHaQcW8@PU:B48008HaP8Li`05
6<HLib487>LQ20037>L46<H47>L01QS65:DHaQcW8@PLi`8Q20039BTYBRDY008Q208Li`046<HLiacW
7>L26<H00acW6<HLi`038@P00acW6<HHaP047>L01QS65:DLiacW8@PU:@8Q20077>LQ22488@PLiaS6
7>L00b4800@LiaBU5:DLi`@HaP038@PLiacW00@Li`066<HLiacW7>LHaQcW0QS60QcW00@Q21cW6<HH
aP8DY@046<HDYABU5:D26<H25:D56<H011BU6<HHaQcW0QS600DDYAcW8@PQ21cW008HaP035:DHaQS6
008HaP0348@DYABU008HaP8DY@076<HDYAS66<HDYAS65:D00QS60aBU0Q2400DHaQcW7>LHaQ2400@D
Y@066<HLiaS66<H@Q1BU0a2400<DYAS66<H00QBU00@@Q1BU5:DDY@@@Q0035:D@Q1BU00@DY@<@Q003
5:DHaQBU008@Q0056<HDY@aS36<@Q0025:D00a245:DDY@025:D00a2436<@Q00348@010aS48@DYA24
11BU00D@Q0aS36<@Q0aS008@Q00:6<HDYABU5:DHaQBU48@<Ha245:D848@;5:D011S65:DDYA240aBU
00H@Q1BU6<HDYA24248236<248@25:D01AS65:D@Q1BU48@00QS600<DYA245:D00aBU0Q2411BU0@aS
000010@Q00048@000P@Q00<000Q212400`@Q00`YBTYB<H`Q22e[>Lhe[Be[<H`e[C6<;F/2:DX02Re[
<H`aS2U:9BT]JcF]>LhaS3F]0S6<00Xe[BU::DXYBS6<;F/U:AcW8@P]J`8YBP07;F/aS36<<H`]JbU:
<H`00SF]00DaS2e[<H`]Jc6<00@YBP8]J`04:DXU:BDY:DX2;F/01BU:9BT]Jc6<;F/00RU:00<]JbU:
:DX00bU:0RDY00<YBRDY:DX00bDY00@YBRe[;F/YBP8]J`03:DXU:B48008U:@<Q20089BTLiacW7>LU
:BU:9BTQ20HU:@<Q20089BTQ21cW7>LQ22DY8@PLi`<Q20<U:@8Q20056<HQ22488@PU:@048@P012DY
8@PU:BDY12480bU:0R4800@U:BU:9BTQ20@U:@8Q20039BTYBR4800<Li`039BTYBRU:008U:@04:DX]
JbU::DX29BT3;F/012U:9BTYBS6<0Re[00@aS3F]>LhaS08YBP8U:@03:DXU:BU:00<YBP03;F/YBRU:
008U:@<]J`08:DXU:BU::DXQ22DY8@PYBP@U:@038@PU:B48008Q2007:DXQ21cW7>LU:BU:9BT00QcW
00<Q22DY9BT00RDY00DQ21cW7>LQ22DY00HQ208HaP8Q20039BTQ21cW00<Li`086<HDYAcW8@PU:B48
7>LHaP8Q208Li`058@PU:B487>LHaP027>L28@P37>L00b487>LQ20049BT27>L02B489BTLiacW6<HL
ib486<HLi`028@P37>L01BDY7>LLiacW8@P00RDY00@Lib487>LLi`@Q20PLi`8HaP038@PLiaS6008D
Y@8Li`<HaP8Li`036<HLiacW008Q20049BTYBRDY:DX28@P57>L26<H011cW6<HHaQS60QcW0R4800<L
iaS66<H00QcW0aS60acW00DQ22DY7>LLib48008U:@077>LHaQS67>LU:AcW6<H00QBU0QcW00<DYAS6
7>L011S60acW0R480aS60acW00PU:B488@PLiaS65:DHaQBU0QS60aBU00<HaQBU6<H011BU1aS600<D
YAS67>L00R481QS611BU0QS600<DYAS66<H00QS60QBU0aS600<DYAS65:D00QBU00D@Q1S66<HLiaS6
00<DY@0548@DYAS66<HLi`035:D02A2436<@Q1BU6<HDYA2436<@Q0025:D011S65:D@Q1240PaS11BU
0Q2400DDYA245:DDYAS6008DY@0748@DYA245:D@Q0aS48@00aBU0Q2400LDYA2436<@Q1BU6<HDY@02
48@00aBU48@@Q0025:D248@01@aS48@@Q0aS48@00QBU00H@Q1BU6<HHaQBU48@236<248@01QS65:DD
YA2436<@Q0PDY@036<HDYA24008DY@046<HDYA245:D248@00aBU48@DY@0348@00`aS48@@Q0035:D0
11245:D@Q1240aS60Q240QBU1Q240QBU0@aS000412400`0012448@0512401RU:E[De[B48=JdicP8a
S08e[@0>:DXU:BU:<H`e[Be[9BTYBS6<=JdicSF]<H`]J`DaS003;F/YBRU:008YBP049BTYBRU:;F/2
<H`2;F/01BU:;F/aS3F]<H`00RU:00<]Jc6<;F/00RDY0RU:00XaS2U:8@PYBSF]<H`]JbDY:DXaS0T]
J`8YBP03;F/YBRU:008U:@8YBP<]J`8aS003;F/YBR4800<Q20069BTYBRDY8@PLib480bDY00<Q22DY
9BT00R4800<YBRDY8@P00QcW00DU:B488@PQ21cW008U:@06:DXQ22488@PU:BU:0R480QcW124800<L
ib489BT00R4800<Lib489BT00bDY0R480RDY0bU:0RDY0R4800DU:B489BTQ22DY008Q208YBP049BTQ
21cW8@P5:DX012DY:DXU:B480RDY0RU:00<U:BU::DX00RU:00D]Jc6<>Lhe[C6<00D]J`8YBP8U:@@Y
BP059BTYBRe[<H`]J`02:DX00bDY8@PQ20028@P2:DX012e[:DXYBRU:0RDY00<Q22DY8@P00R4800<L
ib489BT00bDY0R4800@U:B488@PQ208Li`038@PU:BDY008U:@8Q20087>LQ21cW7>LU:BU:9BTLi`@H
aP037>LHaQcW00<Q20057>LHaQS68@PLi`028@P00bDY8@PU:@029BT27>L00aS67>LLi`027>L00b48
9BTU:@038@P00acW8@PLi`047>L011S67>LQ22480QcW00<U:BU:9BT00acW0b4800@U:B486<HQ20<U
:@@Li`<Q20036<HLiacW008Li`048@PLiaBU6<H27>L00b486<HHaP036<H58@P29BT00bU:8@PQ2002
7>L00aS67>LHaP027>L26<H47>L022487>LHaQS67>LHaQBU6<H27>L00b487>LQ20028@P47>L01248
7>LQ21cW0R4811cW0QS600<DYAcW7>L01AcW00<HaR487>L00QcW0QBU00DHaQcW8@PLiaS600<Li`04
6<HDYABU48@25:D00aS67>LHaP026<H35:D26<H00acW6<HDY@036<H00aBU6<HLi`037>L56<H00a24
5:D@Q0065:D01QS65:DHaQS65:DHaP8Li`036<HDYABU008HaP8DY@8HaP047>LHaQBU48@25:D348@0
1ABU48@@Q0aS48@00QBU00D@Q1BU5:D@Q1BU008HaP035:D@Q124008DY@8@Q0085:DHaQS65:D@Q1BU
48@DY@<@Q08DY@D@Q0065:DHaQS66<HDY@aS11240QBU0Q2400<<Ha246<H00QBU0Q2400<DYA2448@0
0Q240aBU00<HaQBU5:D01Q2400<DYA2448@00PaS0Q2400LDYAS66<HDYAS65:DHaP025:D248@021BU
6<HDYABU48@DYAS65:D348@00aBU48@@Q00248@00`aS48@DY@025:D248@011BU6<HHaQBU112400<D
YA245:D00aBU0A240ABU0@Q2000212400`0012448@0312402@Q2124000Q2:DYBU3g_9BTaS002=Jd0
0c6<>Lhe[@03:DX2<H`01be[:DXYBS6<=JdicSF]00LaS08YBP8U:@08:DXU:BDY9BT]Jc6<=JdaS08]
J`<aS08YBP07;F/aS2e[;F/YBRDY:DX00Re[0RDY00TYBS6<<H`YBRDY:DXaS2e[:DX01Re[0bU:00T]
JbU:;F/U:BU:;F/YBRe[:DX012e[00<YBRDY:DX00RDY00HLib489BTU:B489BT2:DX01BDY8@PQ22DY
8@P00RDY0b4800@U:BU:9BTQ208Li`<U:@8Q208U:@<Q20049BTLiacW7>L38@P00bDY:DXQ20037>L0
1BDY8@PU:BDY8@P012DY00<Q22DY9BT01bDY0b4800<U:Be[8@P00QcW00DU:Be[9BTQ22DY00@YBP8U
:@HYBP039BT]Jbe[008e[@03<H`]Jbe[00<]J`<YBP@U:@8YBPD]J`8YBP<U:@038@PU:BDY008]J`8Y
BP8U:@<Q208U:@@Q2003:DXU:B4800@U:@8Q208Li`8Q2003:DXU:BDY00@Li`048@PLibDY:DX29BT0
11S67>LLiaS60acW0R4800<LiaS67>L0124800DLib488@PQ22DY008Q20067>LQ21cW7>LHaR480RDY
00@Q21cW8@PQ208Li`036<HQ22DY008Q20046<HLib488@P27>L00bDY:DXLi`026<H29BT00acW8@PQ
20027>L012489BTU:AcW0QS600@Q22DY7>LLi`8Q20<HaP079BTQ21cW6<HDYAS68@P00QcW00<DYAS6
7>L00QcW0b4800LU:B488@PU:BU:9BTQ20026<H37>L36<H00acW6<HQ20027>L00aS67>LLi`026<H0
0acW6<HDY@026<H38@P29BT01AcW6<HHaQcW9BT01acW11S60QBU00@HaQcW7>LHaP8Li`046<HLiacW
7>L26<H37>L01aS67>LLiaS67>LDYAS600DDY@/HaP8Li`<HaP035:DHaQS6008Li`<HaPLDY@046<HD
YABU5:D26<H00a245:DHaP027>L011S648@@Q1BU0QS60QBU0QS600<LiaBU5:D00QBU00<HaQBU5:D0
0Q2400<DYA2448@00a2400`DYA2448@@Q1BU6<HLiaBU48@<Ha245:D248@25:D248@00aBU6<HHaP02
5:D748@01QBU48@DYABU6<HDY@@@Q00336<@Q12400H@Q0046<H@Q0aS48@25:D248@25:D011245:DD
YAS611BU11240QBU00@@Q0aS36<@Q08HaP035:DHaQS6008DY@@@Q08DY@036<HDYABU00DDY@8@Q08D
Y@0348@<Ha24008@Q0045:D@Q1BU48@45:D248@25:D236<448@15:D148@12480000600048@@Q0004
8@001P@Q00<U:E[FAS400Re[0S6<00@e[BU::DX]J`8icP07<H`U:BDY;F/icTHa?Nl00be[00LaS3F]
>Lhe[C6<;F/YBP03;F/00bDY:DX]J`02<H`01Be[:DXU:Be[<H`00SF]0c6<0Re[00DYBRDY:DXYBRe[
00<YBP8]J`8U:@05:DXU:BDY9BTYBP03;F/00bU:;F/aS002=Jd012e[9BTYBRU:0bDY12e[00/YBRe[
;F/]JbDY8@PU:Be[:DX]JbU:00<U:@048@PU:BDY9BT2:DX29BT38@P012DY8@PU:BDY0b4800<U:BU:
9BT00RDY0b4800<Lib488@P00R4800<Lib488@P00RDY1B4800HLibDY9BTU:B489BT2:DX00be[9BTQ
20029BT00b489BTU:@029BT012489BTU:BDY1B4800<YBRe[;F/00RDY00<YBRe[:DX00R4800<U:BU:
:DX00RU:00<U:BU:;F/00RU:00<e[CW>=Jd013F]00<aS2U:;F/00RDY00<YBRDY:DX00bU:12e[00LY
BRDY:DXU:B487>LU:@02:DX01Be[:DX]JbDY:DX012DY00@Q21cW8@PQ208U:@DQ20<U:@<Q208U:@03
8@PU:B48008Q208Li`@U:@8HaP057>LHaQcW6<HLi`029BT00acW6<HHaP028@P26<H37>L01b48:DX]
JbU:9BTLib4800@Li`LQ20067>LHaQS66<HLib480QcW00<HaQcW8@P00R480bDY0R480RDY00DQ21cW
9BTU:B48008Li`038@PLiacW00@Li`<Q208Li`8U:@048@PHaQcW8@P26<H011BU6<HHaQS60QcW00<Q
21cW8@P00RDY0R4800HU:BU:8@PDYAS68@P27>L02QBU6<HHaQS67>LQ21cW8@PLib480acW00<HaQcW
6<H00QS600TLib489BTQ21cW8@PLibDY8@P00acW00@Q22DY8@PQ20HLi`8HaPLLi`076<HDYABU5:DH
aQcW8@P00QcW00@HaR488@PHaP8DY@037>LHaQBU00<DY@036<HDYABU00@HaP8DY@8HaP8Li`HHaP8D
Y@086<HDYABU5:D@Q1BU48@DY@8@Q0<HaP8DY@DHaP8DY@036<H@Q1BU008HaP048@PLiaS65:D248@2
5:D26<H00aBU6<HHaP0248@010aS48@@Q1BU0Q240QBU00<HaQBU5:D00Q2400<DYA245:D00QS60aBU
0QS60QBU00DHaQ2448@@Q0aS008@Q0076<HDYABU5:D@Q1BU6<H00Q240PaS0Q240QBU0Q2400H<Ha24
5:DDYA245:D548@35:D00a245:D@Q00548@01QBU48@DYABU48@<H`8@Q0LDY@8HaP8DY@0548@HaQBU
5:D@Q0025:D031245:DDYABU48@DYA245:D@Q0aS48@<H`<DY@0348@DYABU00<DY@0348@<Ha2400D@
Q0035:D@Q12400<@Q00000<48@0012401@@Q00P8@P0012448BDYF]I:DRU:0S6<00Pe[C6<:DXYBS6<
>Lhe[BU:0RDY00@e[CW>?Nlmk`8]J`8aS08icP8aS0@]J`03:DX]Jbe[00D]J`8YBP8aS00:=Jd]Jc6<
>Lhe[Be[8@PU:Be[:DX2;F/01RU:;F/]JbU:9BTQ208YBP8U:@03;F/aS2e[008YBP03;F/aS36<008]
J`<YBP049BTYBRU::DX2;F/01BU:;F/]Jc6<:DX00RDY00DYBRe[=Jd]JbU:00<Q20HU:@048@PU:BDY
8@P29BT012U:9BTQ21cW0R4812DY0R4800<Lib488@P00b4800@Lib488@PQ208U:@048@PU:AcW7>L3
8@P59BT2:DX39BT01bU:9BTQ22489BTLib4800@U:@8Li`8Q2005:DX]JbU::DXU:@02:DX49BT3:DX0
1bDY:DXYBRe[:DX]Jc6<008e[@8aS08e[@03;F/YBRU:00HYBP039BTYBRe[008]J`<YBP8U:@8YBP08
8@PU:BU:;F/aS2U:9BTQ208YBP03;F/YBQcW00<Li`079BTYBRDY7>LQ21S67>L00bDY00@Q21cW8@PU
:@8Q20049BTYBRU:9BT28@P29BT012U:9BTLiacW0QS60acW00<Q22DY7>L01AcW0b480QcW00<U:Be[
:DX00R480bDY0QcW124800<Lib488@P00acW00<HaQcW8@P00R4811cW00<U:B489BT00QcW224800<L
ib487>L00QS600<Lib487>L00QcW00DQ21cW6<HHaR48008U:@038@PLiacW008HaP<Li`045:DHaQS6
8@P27>L39BT012489BTYBQcW0QS600<Lib487>L00aS60acW0R481acW0QS60QcW1B480QcW0b480QcW
00DQ22DY8@PLiaS600<Li`8HaP<Li`038@PLib48008Li`@HaP037>LHaQS6008Li`048@PLiaS66<H2
7>L36<H011BU6<HDYABU11S611BU0acW00<HaQcW6<H00acW0aBU00<@Q1S66<H01ABU00<HaQBU5:D0
0QS60QBU1aS60QBU1AS600<DYAS648@00Q2400@DYAS65:D@Q08HaP075:D<H`aS48@DYA245:D00Q24
0aBU00PHaQBU48@<Ha245:DHaQcW0QS600DDYAS66<HHaQBU00P@Q0@DY@H@Q00736<@Q12448@DYA24
5:D00Q2400@DYAcW5:D@Q0@DY@D@Q08DY@<@Q0055:D@Q1BU48@DY@0348@011BU6<HDYABU0aS62ABU
00<@Q1BU5:D00QBU0Q2400LDYA245:DDYA245:D<H`0448@011BU48@DYA240QBU3A240@aS00021240
1P0012448@@Q0008@P848@080008@Re[HaQ6<BDY;F/aS0<]J`<aS0@]J`8icP8e[@8]J`<aS005=Jdi
cS6<;F/U:@02:DX02BDY;F/aS3F]<H`]JbU:;F/aS003=Jd2<H`2;F/5:DX2;F/29BT012U:;F/]JbU:
0RDY00/YBRDY:DXYBRe[:DX]Jc6<>LhaS2e[008U:@03;F/aS2U:008Q2003:DXaS2e[00@YBP8U:@<Y
BP03;F/YBRU:008U:@038@PU:BDY008Q20039BTQ224800HQ20089BTQ22487>LQ22DY:DXU:@<Q2003
9BTQ2248008Q208Li`8Q20@U:@<Q20037>LQ224800DU:@038@PLibDY008YBP039BTLib4800XQ200:
7>LYBRU::DXU:B48:DX]JbU:9BT28@P01BDY;F/YBRDY:DX00Re[0bU:0S6<00@e[Be[:DXaS08e[@0:
<H`YBRe[:DXU:B489BTYBRDY:DX2;F/2:DX01BDY:DXYBRU:9BT00R4800DYBRe[:DXYBRDY008YBP06
9BT]Jbe[9BTQ21cW0b4800DLib488@PU:B48008U:@8Li`8U:@03:DXU:B48008U:@<Q208U:@038@PU
:BDY008Q20046<HDYAS66<H68@P01AcW6<HLiacW6<H01AcW00<Q22DY9BT00RDY0R4800<LibDY8@P0
0R4800@Lib488@PQ208Li`046<HLiacW8@P67>L48@P39BT68@P011cW8@PLib481AcW0b480bDY00<Q
21cW8@P00QcW00@HaQcW7>LQ208Li`038@PLiacW008Q2004:DXU:BDY9BT28@P27>L26<H00bDY8@PL
i`025:D27>L28@P01AcW8@PU:AcW8@P00aS60QcW00LHaQcW9BTU:B487>LHaP027>L01R487>LHaQcW
8@PU:@8Q20067>LQ22487>LHaQcW0QS600<Q22DY9BT00QS600DLib486<HHaQBU00<HaP8Li`8Q208L
i`PHaP035:DHaQS600<DY@056<HDYA245:D@Q0027>L00b487>LHaP025:D26<H65:D00aS65:DHaP02
5:D00a245:DDY@055:D26<H25:D01a245:DHaQBU48@DYAcW008HaP0648@DYABU48@DYAS60QcW00@H
aQBU5:DDY@<@Q0045:D<Ha245:D26<H25:D248@00aBU36<@Q0025:D27>L25:D011245:DDYABU0a24
0PaS0Q240aBU0Q240QBU0Q240PQ200<<Ha246<H011240QBU0Q240QBU0a240QBU00<@Q0aS36<00Q24
0QBU00H@Q1BU5:DDYA245:D248@010aS48@@Q1S60aBU00<HaQBU5:D011BU112400DDYA245:DDYA24
00<DY@056<HDYABU48@<H`0248@01ABU36<@Q1BU6<H00QBU00<<Ha2436<00a240aBU00DHaQBU6<H@
Q1BU008@Q00000D000@Q12448@0000<48@0;24848@@Q248]JfLiAS4Q22e[<H`YBP02;F/3<H`3;F/0
1S6<=JdicSW>=Jd]J`8YBP06;F/e[CW>=JdaS2e[0RDY0RU:00@aS3F]<H`aS08YBP8aS0<e[@8aS007
;F/aS2U::DXU:BU:;F/00RU:0RDY00DYBS6<;F/YBR48008U:@8YBP079BTYBRU:;F/e[CW><H`00bU:
0S6<00@YBRDY9BTYBP8]J`04:DXU:BDY9BT3:DX01Be[:DX]Jbe[:DX00RDY00LQ22DY9BTU:B487>LQ
20029BT01B487>LQ22489BT01B4812DY00@Lib488@PU:@8Q20047>LHaR488@P49BT012489BTQ22DY
0R4800@Lib488@PU:@8YBP039BTYBRDY008Q20@U:@088@PLib489BTLib487>LU:@8Q200=9BT]Jbe[
9BTQ22U:;F/YBR487>LU:Be[:DX00RDY00XYBRe[<H`YBRDY:DXaS3F]<H`]J`8aS004=JdaS2e[9BT3
:DX49BT01Be[:DX]JbU:;F/01BU:0RDY00<YBRe[:DX00bU:00HU:BU::DXYBR487>L28@P01BU:8@PL
iacW9BT00b4800DLib488@PU:B4800<U:@@Q20039BTYBRDY008U:@048@PLib486<H27>L00aS67>LQ
20029BT38@P00acW6<HHaP057>L022487>LQ22DY:DXU:B487>L28@P00bDY7>LLi`047>L00b487>LL
i`067>L00b487>LQ20028@P00acW8@PLi`029BT38@P01acW6<HHaR489BTQ21S600@Li`DQ20<U:@8Q
20@Li`038@PHaQS6008Li`<Q208U:@03:DXU:BDY00<Q208HaP8Q20049BTLiaS66<H37>L00b489BTQ
20028@P37>L36<H00acW8@PQ20028@P27>L38@P27>L012489BTYBRDY11cW00<Q21cW6<H00QS600<Q
22DY7>L00acW00<Q21cW5:D00aBU00THaQcW7>LQ21cW8@PU:AcW6<H00QBU00<LiaS66<H00aS60QBU
0QS61ABU00DHaQcW7>LQ21cW008HaP035:DHaQBU00HDY@8HaP075:D@Q12448@DYAS65:D00Q2400@D
YAcW6<HHaP8DY@0348@DYAS600<DY@046<HDYA245:D248@01aS65:DLiacW6<HDYAS600P@Q08DY@03
6<HDYAS6008<H`8@Q0<DY@0;6<HLiaS65:D@Q1BU48@DYA245:D@Q00336<25:D348@25:D0112436<<
H`aS0a2400HHaQ2436<<Ha245:D348@25:D00a245:DDY@025:D00a2436<<H`0448@25:D448@010aS
48@<Ha240QBU0QS61aBU00<@Q1BU5:D00a2400THaQ2448@@Q1S65:D@Q1BU6<H00Q2400D<Ha245:DD
YA2400@DY@@@Q08<H`0348@DYAS6008HaP@DY@4@Q00000<48@0012400P@Q00<000@Q12400`@Q00D8
@Re[HaQ6<B48008aS08YBP0:;F/aS36<:DXU:BU:<H`e[Cg_>Lh2<H`2;F/01C6<;F/]JcF]<H`00Re[
0RDY00`YBRe[;F/YBS6<>Lhe[C6<:DX]Jc6<>Lh2=Jd00c6<:DXYBP02:DX00be[:DXYBP029BT012U:
;F/]JbU:0Re[0bU:00<U:BU:;F/012e[00@aS2U:9BTYBP8]J`05<H`YBRe[9BTYBP049BT38@P39BT2
:DX01RDY8@PU:BDY:DXU:@8Q20037>LQ22DY008U:@048@PLib489BT28@P011cW8@PU:BU:12480RU:
00LU:B487>LHaQcW8@PU:@028@P01RDY:DX]JbDY8@PU:@DQ20039BTYBRDY00@U:@03:DXU:B4800@Q
208Li`058@PU:B488@PLi`029BT012U:9BTU:BU:0bDY0bU:00<U:B48:DX00bDY0RU:0be[0c6<00@e
[C6<<H`]J`8YBP0:;F/YBRU::DXU:B489BTYBRe[:DX39BT012U:9BTU:BU:0RDY0bU:00H]JbU:8@PU
:B489BT2:DX02B487>LLibDY8@PLiaS67>LQ20029BT38@P39BT012489BTYBRU:1BDY0RU:0RDY00<Q
21cW6<H00QS60QcW0R4800<Lib486<H01QcW00<HaQcW8@P00RDY00DLib489BTQ21cW00HQ20TLi`@Q
20036<HLiacW00<Q20099BT]JbU::DXQ21S67>LQ21cW008Q20DLi`<Q20039BTQ2248008U:@03:DXU
:AcW00@Q208Li`8HaP038@PU:BDY008Li`039BT]JbU:008U:@038@PLiacW008Li`049BTYBRDY7>L2
6<H00bDY8@PQ20047>L28@P27>L26<H00acW6<HLi`028@P37>L01b487>LLiaS67>LQ22DY008Q208H
aP<Q20<HaPDQ20047>LHaQS66<H27>L01QS65:DHaQS67>LQ208HaP8Li`@HaP047>LHaQcW6<H35:D2
7>L01QS648@DYABU6<HLi`DHaP045:DHaQS66<H35:D00aS65:DDY@045:D248@25:D26<H00aBU48@D
Y@026<H00aBU48@@Q0025:D01aS67>LLiaBU6<H@Q0aS008HaP8Q20036<HDYABU008DY@0:48@<Ha24
48@HaQ245:D@Q1BU48@25:D348@00`aS48@DY@026<H25:D00aS65:DDY@0348@011BU48@@Q1240PaS
00D@Q1S66<HDYA24008DY@0448@<H`aS36<248@01QBU48@DYABU48@DY@<@Q0035:D@Q1BU008DY@03
48@DYABU00<DY@8@Q00336<@Q1BU008DY@0548@<Ha245:D@Q0025:D00a245:DDY@026<H25:D00a24
5:D@Q00548@45:D01A245:DDYAS65:D0112400<DYA245:D00Q240QS600<DYA2436<01@aS0Q2400<L
ib488@P00QcW0AS60ABU0A24000312400`0012448@0212402PQ200048@@Q;F]S648@9BTe[C6<0RDY
00<]JcF]<H`00RU:00<]JcW>>Lh00SW>00@aS2e[;F/]J`8aS004=JdaS36<;F/39BT00be[:DXaS005
<H`02Be[<H`aS3W>=JdicSF];F/YBP029BT2:DX01RDY8@PQ22e[<H`]J`8YBP8]J`03:DXQ22U:00@Y
BP08<H`e[C6<;F/YBRDY;F/aS0HYBP059BTYBRDY9BTQ20029BT01R489BTU:BU:;F/YBP<U:@04:DXL
ib488@P39BT00b487>LQ20039BT27>L48@P29BT3:DX28@P00acW6<HLi`028@P29BT2:DX00bDY8@PQ
20039BT28@P012DY8@PU:BDY12U:0bDY00<Q22DY9BT01B4800DU:B488@PU:BU:00LU:@038@PU:BDY
008YBP038@PU:BU:008]J`8YBP@]J`<aS007=JdaS2e[:DXU:BU:;F/00bDY2BU:00<U:B489BT00bDY
0bU:00@U:B489BTQ208YBP089BTQ21cW7>LQ21cW8@PLi`8Q20039BTQ224800<Q208U:@048@PU:BU:
:DX29BT01R489BTYBRDY:DXU:@<Li`045:DLiacW8@P29BT00b486<HHaP027>L00aS67>LLi`037>L2
8@P49BT28@P011cW8@PU:BDY0R4800@LiaS67>LLi`8Q20<Li`038@PU:B4800<Li`098@PLib487>LQ
22DY:DXU:B48008Li`8Q20039BTQ2248008Li`046<HLiacW8@P39BT28@P39BT00b487>LLi`038@P3
7>L01B489BTQ21cW8@P00RU:00PU:AcW7>LU:AcW8@PLib480RU:00HU:AcW7>LQ22DY8@P97>L26<H8
7>L26<H27>L01aS68@PQ22DY7>LHaQcW00<Q208HaP047>LQ22U:8@P47>L00aS67>LHaP036<H03AcW
8@PLiacW6<HLib487>LHaQBU6<HQ21cW008HaP047>LDYABU6<H27>L00aS648@@Q0025:D26<H00acW
6<HLi`025:D011S67>LLiaS60aBU00<HaQBU5:D011BU00<@Q1BU5:D01ABU00@HaQBU5:DDY@8@Q003
5:DHaQcW008HaP055:D@Q1245:DLi`028@P35:D00aS65:D@Q00248@00aS65:DDY@0248@00aBU6<HD
Y@0448@00aBU36<DY@025:D011S65:DDYAS60aBU0Q2400<DYA2448@00PaS00<DYAS65:D00a2400DD
Y@aS36<<Ha24008DY@@@Q0055:D@Q12448@DY@0248@011BU6<HDYABU0Q240QBU00<@Q1BU48@00PaS
00HDYAS66<HDYA2436<248@55:D36<H00a245:D@Q0025:D248@236<35:D348@00aS65:DDY@0248@2
5:D448@26<H011BU48@DY@aS0Q2400DDYA2436<@Q1BU008Li`056<HLiacW6<HDY@0148@000050004
8@@Q1240000312402@Q212448@Q2;F]Nmd8@9BT]J`03=Jd01S6<;F/U:BU:;F/aS08mk`06=Jd]JbU:
;F/e[CW>0S6<00LYBS6<<H`YBRDY8@PU:@02:DX3<H`00be[:DXaS003=Jd01C6<=JdaS3F];F/00RU:
0be[0RDY12U:0RDY00P]Jc6<=JdaS2U:9BTYBRe[0bU:00@]JbU::DXYBP<]J`04:DXaS2e[:DX49BT0
12489BTQ22480RDY00<Q22U:9BT00RU:00LQ21cW7>LQ22DY:DXU:@048@P00bDY:DXQ20026<H00acW
9BTU:@038@P2:DX012DY8@PLiacW124812DY00<YBR489BT00bDY0R4800<U:BU:;F/01bU:00DU:B48
9BTQ22DY008Q20037>LQ21cW00<Q208YBP03;F/YBRDY00<U:@038@PU:BDY00@U:@8YBP<]J`07<H`]
JbU:9BTYBRe[<H`012e[00<YBRe[;F/00RDY00DQ22DY9BTYBRDY008YBP@U:@03;F/YBRU:00<U:@8Y
BP059BTQ22487>LU:@028@P39BT01R487>LHaQS67>LQ20<U:@8Q208U:@038@PU:BDY00<YBPLU:@03
8@PLiaS6008HaP037>LQ22DY008Q20TLi`048@PLiacW8@P49BT27>L00b487>LU:@029BT01B486<HH
aQcW6<H00QcW00<U:B488@P0124800<Lib488@P00QcW00HQ22DY8@PQ21cW9BT27>L01B489BTU:B48
7>L01b4800<Lib488@P00bDY00HYBRDY7>LLiaS68@P27>L48@P29BT012U:;F/YBRDY0QcW00<Q21cW
7>L00QcW0bDY00HQ21cW8@PU:BU:9BT28@P27>L36<H00acW6<HLi`027>L28@P27>L00aS65:DLi`02
7>L032487>LQ22DY8@PLiaS67>LQ21cW6<HLi`@Q20057>LQ22DY8@PLi`026<H00acW6<HHaP027>L3
6<H27>L011S65:DDYAS61AcW00<HaQBU5:D00QBU11S600<DYAS66<H00QS60QBU00DHaQcW8@PLiaS6
00DDY@8HaP<DY@0348@DYABU00@DY@<HaP8DY@8@Q08DY@056<HDYAS65:DHaP0248@021BU7>LU:AcW
6<H@Q1BU48@26<H25:D00`aS48@DY@026<H55:D0112436<@Q1240aBU00D@Q1BU6<HHaQBU008@Q005
5:D@Q12448@<H`0248@00aBU6<HDY@0248@01QBU48@@Q12436<DY@8HaP8DY@0448@DYAS65:D236<2
48@55:D248@00aBU6<HHaP0248@00`aS5:D@Q0025:D348@35:D011245:DDYAS611BU00@@Q1BU48@D
Y@8@Q08<H`0648@DYABU5:D@Q1BU0Q240PaS00D@Q1BU48@DYA2400@DY@<@Q0035:D@Q124008@Q003
36<@Q1BU00DDY@4HaP4DY@4@Q00000@48@00124000848@0=0008@P@Q124000Q2;F]NmdHa:DXaS3W>
=Jd00S6<010]JbDY:DXYBS6<?NlicS6<;F/YBS6<>Lhe[C6<;F/aS08]J`8U:@038@PU:Be[008]J`8a
S003:DX]Jbe[008e[@03<H`e[C6<008aS003;F/YBRe[008aS007:DXQ2248:DX]Jc6<;F/00bU:0S6<
00@]JbU::DXYBPD]J`03:DXU:Be[008aS008:DXU:Be[;F/YBRDY8@PU:@8Q20039BTYBRDY008Q208U
:@04:DXU:BU:9BT38@P49BT28@P01acW9BTQ22DY7>LQ21cW00DQ20039BTYBRDY008Q20047>LU:B48
9BT38@P2:DX29BT28@P01BU:9BTLiacW8@P00Re[12U:00<]JbU::DX00RDY0R4800@Lib488@PQ208L
i`<Q2005:DX]Jbe[9BTQ20029BT28@P01BDY:DXQ22489BT00bU:00D]JbU:<H`]JbU:00<]J`06<H`]
Jc6<;F/YBRe[0bU:12DY00@]JbU:9BTYBP8U:@03:DXU:BU:00HU:@04:DXU:BDY8@P49BT28@P39BT4
7>L00b489BTU:@038@P39BT00b489BTYBP02:DX00bDY8@PU:@02:DX01BDY8@PQ21cW8@P00QS60QcW
00<Q22DY7>L00QcW00@HaQcW8@PHaP8Li`038@PLiacW008Q20059BTQ22DY8@PLi`038@P01BU:9BTQ
22487>L00QS60QcW00@U:B488@PLi`<Q208Li`8Q208Li`048@PU:BDY9BT48@P29BT28@P27>L01b48
7>LLib489BTYBRDY00<Q20<U:@@Q20@Li`038@PU:B48008U:@8YBP038@PLiacW008Li`<Q20087>LU
:BDY:DXU:B487>LQ20<U:@@Li`<HaP<Li`058@PLiacW6<HLi`036<H27>L28@P27>L011S67>LLib48
0QcW0QS600<Lib488@P00b4800<U:AcW7>L00QS600HLiaS65:DDYAcW8@P27>L86<H27>L00aS65:DD
Y@066<H01aBU6<HHaQS65:DHaQBU008HaP037>LQ21cW008HaP<DY@8HaP8DY@0348@HaQBU008@Q003
5:DHaQBU00<HaP035:DHaQ24008DY@8HaP035:DHaQcW008DY@8@Q0047>LQ22488@P45:D248@25:D0
0aS65:D@Q0025:D00aS65:D@Q00648@35:D248@26<H25:D248@011BU48@<H`aS0Q240QS600L@Q1BU
48@@Q1BU48@<H`0248@25:D011S65:D@Q1BU0a2400<<Ha2448@00aBU0a240QS600<DYA2448@00a24
11BU00<@Q1BU48@00Q240QBU00@HaQBU6<HDY@8@Q0045:D@Q1BU5:D248@236<348@25:D248@00`aS
48@@Q00448@25:D26<H01QBU48@@Q1BU48@<H`T@Q0046<HLiaS648@136<000`48@05:DYJeT8@;F/m
k`02@Q000cF]<H`]J`02:DX0136<=Jde[C6<0RU:136<0be[0RU:1RDY0c6<00@e[Be[;F/YBP@]J`04
:DX]Jbe[;F/2<H`02Be[:DX]Jbe[<H`]JbU:9BTYBP03;F/2:DX3;F/00bU:;F/YBP03:DX00be[<H`e
[@02=Jd00be[:DXU:@02:DX00bDY7>LLi`038@P02bDY8@PQ21cW9BTYBRe[:DXQ22DY:DX00RDY0RU:
0RDY0R4800LLibDY8@PQ21cW9BTYBP028@P01bDY:DXYBRDY7>LQ21cW008Q2004:DXU:BU:9BT4:DX0
0bDY:DXYBP02:DX29BT2;F/00bU:9BTU:@03:DX01be[:DXYBRU:9BTYBR48008Li`036<HLiacW01<U
:@058@P]Jc6<;F/YBP029BT2:DX012e[<H`aS2e[0RU:00<aS2e[:DX00R4800HU:BU::DXYBRDY8@P3
9BT01bU:9BTYBRe[:DXU:B48008YBP039BTQ22DY008U:@8Q20039BTYBRU:008U:@038@PLib4800<Q
208Li`098@PYBRe[:DXQ22DY<H`e[C6<008Q208U:@03;F/YBRDY00<Li`8Q208Li`038@PU:B48008L
i`058@PLiacW6<HLi`048@P27>L01R487>LU:B489BTQ20<Li`8U:@8Q208HaP8Li`038@PLiacW008L
i`<Q20039BTQ21cW008Q20<U:@@Li`@U:@047>LHaQcW7>L49BT01BU:8@PQ22489BT012480RDY00<Q
22DY9BT00QcW00@Q22DY9BTU:@8YBP039BTQ21cW00<Q208Li`<Q208Li`038@PLib48008U:@03:DXU
:B48008Li`038@PHaQS6008HaP038@PU:B48008HaP8Q20047>LHaQS67>L48@P47>L00b487>LLi`02
6<H00acW9BTQ20027>L01B489BTQ22487>L00aS60acW0QS600<Lib487>L00aS600<LiaS66<H00QS6
00LQ21cW6<HDYAS65:DHaP035:D36<H011BU6<HHaQS60acW11BU00<LiaS66<H00QS60QBU00<@Q1BU
5:D00QS600<DYAS66<H00aBU00@HaQBU6<HDY@<HaP057>LHaQBU5:D@Q0025:D00aS67>LHaP025:D2
48@01QBU6<HHaQBU48@<H`8@Q0035:DHaQS6008HaP0448@<Ha245:D26<H348@26<H00aBU48@@Q003
48@010aS48@@Q0aS0Q2400<DYAS65:D00QBU1A240QBU00<@Q1BU5:D00aBU0Q2400<<Ha246<H00QS6
00<DYA2448@011S611240QBU00@@Q1BU5:DDY@8@Q0035:DHaQS600DDY@8HaP<DY@<@Q08<H`8@Q005
6<HDYABU48@DY@0348@00aBU48@@Q00248@26<H01ABU48@@Q1245:D00Q240PaS00<@Q1BU48@00QBU
00H@Q1S65:DDYAS65:D148@0000300048@0000848@0500048@@Q2480000212402RU:F]I2436<?Nm2
43W><H`]Jc6<0Re[0S6<00<e[C6<;F/00be[0S6<0Re[0bU:00<U:B489BT00RU:00DU:BU:<H`e[C6<
008]J`03<H`YBRU:00<]J`05:DX]Jc6<<H`]J`02:DX00be[<H`aS002;F/49BT2;F/00c6<:DXYBP08
:DX02S6<=JdicSW>;F/YBRDY;F/YBR480QcW0RDY0b4800<U:B48:DX00bU:1RDY00DQ22DY8@PQ21cW
00@Q20047>LQ22487>L28@P00bDY:DXYBP038@P01QcW9BTQ22U:9BTYBP8U:@<YBP049BTYBRe[:DX2
8@P012DY<H`]JbDY0bU:00D]JbU::DXU:BU:008U:@8Q20<Li`8Q2009:DXU:BDY9BTQ22DY:DXU:B48
00@U:@058@PU:B489BTYBP03;F/2:DX012DY8@PYBRe[0c6<00<YBRe[:DX00RU:00@U:B488@PU:@<Y
BP038@PU:BDY008U:@03:DXU:BU:00HYBP079BTQ22489BTLib489BT00RU:00PU:B488@PQ21cW6<HL
ibDY0R480QcW00PU:Be[:DXQ22DY;F/e[Be[0bDY0bU:00TU:AcW7>LHaQcW8@PLib489BT00b480acW
00PHaQcW6<HLib489BTQ21cW0RDY00<Q21S68@P00b480acW00LQ22DY9BTLiaBU6<HLi`028@P26<H2
8@P011cW8@PQ22480acW00@U:BU:9BTU:@<Li`8Q208U:@DQ208Li`@U:@058@PLib488@PU:@038@P0
12DY8@PQ21cW0R4800@U:BU:9BTU:@8YBP049BTQ22488@P57>L28@P37>L012DY8@PU:BDY124800<L
iaBU5:D00QS60R481QcW0QS600@Lib488@PU:@8Q208Li`0:8@PLib487>LDYAS67>LQ22DY8@P27>L0
22489BTLiacW5:DHaQcW6<H47>L01aS65:DHaQS65:DHaQBU008HaPDLi`TDY@8HaP<DY@036<HLiaS6
008HaP055:DHaQS65:DHaP025:D00a245:DDY@025:D011S65:DDYABU0aS60QBU00HHaQBU6<HDYAS6
7>L36<H01ABU6<HDYABU6<H00QcW00@HaQBU36<@Q0@DY@0348@DYA24008@Q0045:DHaQBU5:D348@0
1aBU6<HHaQBU48@DYA24008DY@D@Q0035:D@Q124008@Q08DY@036<HDYABU008@Q0035:D@Q1BU00<D
Y@0348@DYAS6008HaP0448@<Ha2448@55:D248@011BU6<HHaQ240PaS00DDYA2448@@Q1BU008@Q0@D
Y@8@Q0@DY@036<HDYAS6008DY@0348@<H`aS00d@Q0065:D@Q12448@DYAS60QBU00@@Q1BU5:DDY@D@
Q00336<@Q1BU008DY@0536<@Q1BU6<HDY@0148@000@48@0300048@@Q00@48@08248YBU[F?NlaS48@
AS5240<aS003:DX]Jbe[008]J`<aS08]J`08:DXU:BDY:DXaS2e[:DXQ20@U:@058@P]Jc6<=JdicP03
;F/03RU:;F/YBS6<:DXU:Be[<H`e[C6<;F/aS3W><H`3;F/3:DX2<H`00bU:9BTYBP02:DX012e[:DXY
BRDY0be[0SF]00@icSF]<H`e[@8]J`048@PLib488@P2:DX00bDY8@PQ20029BT01RU:;F/YBRDY8@PU
:@8YBP03;F/YBRU:00<Q20<U:@8Q208U:@03:DXQ2248008U:@05:DXU:B487>LQ20029BT00bU:9BTU
:@039BT01BU:;F/]JbU:9BT00RU:00<U:B489BT00RDY00HYBRDY:DXU:B489BT2:DX29BT01B489BTQ
22487>L00R4800<U:BU::DX00RDY0b481bDY00<Q22DY9BT00RU:00<]JbU:9BT00bDY0Re[00<aS2e[
:DX01BU:0bDY00@YBRDY9BTQ208U:@05:DXU:BDY9BTYBP039BT2:DX012DY8@PQ22DY0RU:00LU:B48
9BT]JbU:8@PLi`028@P012DY8@PQ22480QcW0RDY12U:00<]JbU:9BT00bDY0Re[00<YBRDY8@P00b48
0QcW00DQ22DY9BTYBRDY00<Q20047>LQ21cW7>L38@P01RDY8@PLiacW8@PYBP<Q20049BTQ21cW7>L3
8@P36<H00acW8@PQ20037>L01B489BTU:B486<H00QcW0R480RDY0R4811cW00HU:BU:9BTLiaS67>L2
8@P01QcW6<HLib489BTYBP<U:@<Q208YBP058@PLib48;F/YBP028@P3:DX29BT01B487>LLiacW9BT0
1B4800@U:B489BTU:@<Q208U:@038@PHaQS6008HaPHQ20037>LQ224800DLi`048@PYBRDY8@P27>L0
0b489BTQ20038@P00acW6<HLi`028@P00acW6<HLi`027>L00aS65:DHaP038@P00acW6<HHaP046<H0
0acW6<HQ20028@P37>L00b487>LHaP025:D36<H25:D26<H00aBU6<HLi`027>L00aS65:DDY@046<H0
1ABU6<HHaQBU6<H00acW0QBU0QS600DDYAS68@PLiaS6008DY@056<HLiacW7>LHaP045:D27>L02R48
7>LDYABU48@<Ha245:DHaQBU1Q240QBU00<HaQBU48@00Q2400@DYAS65:DDY@8@Q0DDY@0348@<H`aS
008<H`8@Q0045:DHaQS66<H85:D00aS65:DDY@025:D00aS648@DY@025:D26<H01QBU48@@Q1245:D@
Q08DY@0348@DYA2400<@Q0035:D@Q12400HDY@DHaP8DY@<HaP035:D@Q12400<<H`8@Q0@DY@0648@<
Ha245:D@Q1BU0Q2400@DYAS65:DHaP<DY@L@Q0036<HDYABU008@Q0<DY@8@Q04<H`0000@000@Q1240
00@48@0;24848@00248]Jekg?NlYBSW>@Q0mk`02<H`01Be[9BTYBRU:;F/0136<00<]Jc6<:DX00RDY
00<YBS6<:DX00RDY0RU:0RDY00PQ22e[<H`icSF];F/YBRe[0RU:0be[00HYBRe[=Jde[C6<;F/3<H`2
;F/00c6<;F/YBP03;F/01S6<:DXU:BDY:DX]J`<YBP04;F/YBRU:<H`2>Lh01cF];F/e[C6<;F/Q21cW
008Q20<U:@057>LQ22DY9BT]J`02:DX29BT00b489BTYBP02:DX00bDY8@PQ20039BT00b487>LLi`02
8@P00bDY:DXU:@028@P00bDY:DXU:@028@P01BDY:DXU:BDY8@P00RDY0bU:00@]JbU::DXYBP8U:@07
8@PU:BDY9BTQ22DY:DX00bDY0bU:00@Q22DY8@PU:@<Q20037>LU:BU:00<YBP058@PU:BDY9BTYBP04
9BT022489BTQ2248:DX]JbU:;F/49BT01bU:;F/aS36<;F/YBRDY008YBP8U:@058@PU:BU::DXU:@02
8@P29BT00bU:9BTU:@02:DX01248:DX]Jbe[12DY0RU:0RDY0bU:00DU:B488@PQ21cW00HQ208YBP03
8@PYBRe[008aS08U:@058@PYBRe[;F/U:@028@P27>L38@P021S68@PYBRe[:DXLib489BT28@P01AcW
8@PQ21cW9BT00R4800DLiaS68@PU:B4800<Li`038@PLiacW008Li`048@PLiaS67>L28@P47>L29BT2
8@P27>L00bDY8@PQ20028@P27>L58@P01RDY7>LLiacW8@PU:@8Li`056<HLibDY9BTYBP029BT012U:
9BTQ22480RDY00<Q21cW9BT00RU:0b4800DYBRDY8@PQ21cW00<Q208Li`038@PLiacW008Li`8U:@<Q
20<U:@058@PLiacW5:DHaP027>L29BT47>L01b487>LLiacW9BTQ22DY00@Q20039BTQ21cW008Li`06
8@PU:B488@PHaR480QcW00@HaR487>LHaP8DY@047>LQ22DY8@P27>L56<H01AcW8@PQ22DY8@P011cW
0QS60aBU11S611BU0QcW00DHaQBU5:DHaQcW00DHaP035:DHaQBU00@HaP8DY@0348@DYAcW00<Li`8D
Y@8HaP087>LHaQBU5:D@Q1BU48@HaP8Q20037>LDYAS6008DY@0448@DYABU6<H348@00aBU48@DY@02
5:D01AS65:D<H`aS48@00QS600<DYA245:D00QBU00<@Q1S66<H00Q2400<<Ha2436<00a240QBU0aS6
0QBU00@@Q1S65:DDY@<HaP0348@DYAS6008HaP8@Q0035:D@Q1BU008DY@046<HDYABU48@25:D548@3
36<25:D01QS65:D@Q1245:DHaP8DY@8HaP8@Q0085:DHaQS65:D@Q1BU48@<H`8@Q0035:D@Q124008@
Q00636<@Q12448@DYA240PaS0Q2400HHaQBU48@@Q1BU48@25:D348@45:D248@55:D136<000848@05
00048@@Q12400005124012U:G_M>Lc6<0cW>00de[C6<;F/U:BU:;F/aS3W>=Jd]Jc6<;F/YBP029BT0
12U:9BTU:BU:0Re[0bU:00@]Jc6<<H`e[@8]J`05:DX]Jbe[;F/YBP029BT3;F/00bU:9BTU:@03<H`0
0cF]<H`e[@03<H`00be[:DXYBP08:DX2;F/2<H`013W>?NlmkcW>0SF]00<aS2U:9BT00b4800HU:BU:
9BTU:B48:DX3;F/29BT01BU:9BTYBRU:;F/00RDY00<Q22DY:DX00RDY0RU:00@U:B489BTU:@8Q208U
:@03:DXU:B48008Q208YBP038@PLibDY008]J`03:DXU:BDY00@YBP8Q208U:@@YBP089BTQ22488@PU
:BU:9BTYBP@U:@098@PU:BDY:DX]JbU:;F/YBRDY008Q20049BTYBRe[:DX29BT01AcW8@PQ22DY:DX0
0Re[00@YBRDY9BTYBP8]J`05<H`]Jbe[:DXU:@03:DX29BT012U:;F/]JbU:0RDY0RU:0bDY0bU:00<]
JbU::DX00bDY0RU:00@U:BU::DXYBP8]J`8U:@8Q20<YBP<Q20079BT]JbU:9BTQ22U:;F/00S6<0RU:
00H]JbU::DXU:BU:9BT28@P022DY7>LHaQcW9BTYBRDY8@P2:DX01R487>LQ22489BTQ20<Li`@U:@8Q
208U:@068@PLiaS67>LU:B480QcW00<HaR488@P00acW00HQ22DY8@PQ22DY8@P67>L00b48:DXU:@02
8@P01bU:9BTQ21cW8@PU:B4800HLi`8Q208U:@HQ20@U:@8Q208U:@8YBP099BTQ21cW7>LU:B489BTQ
21S6008Q20039BTLiacW008Q20099BTLiacW7>LQ22DY8@PLiaS6008Li`046<HU:BDY9BT37>L00bDY
:DXU:@038@P00bDY:DXQ20078@P49BT28@P00acW6<HLi`027>L26<H011BU6<HHaR480RDY00<LiaS6
6<H00R4800<LiaS67>L00QcW00DQ21cW8@PLib48008Li`8HaP@DY@8Li`066<HDYAS66<HQ21cW0QS6
00<LiaS66<H00aS600<DYAS66<H011S60QBU00<HaQBU5:D00aS600<LiaBU5:D00QS60QcW0aS600DD
YAS65:DDYAS6008Li`8HaP065:DHaQBU5:DHaQBU0Q2400TDYAcW6<HDYA245:DHaQBU48@00PaS00@H
aQcW7>LDY@<@Q08DY@0448@DYABU5:D336<00a245:DDY@095:D00aS67>LHaP025:D26<H00acW5:DD
Y@0248@25:D248@01ABU48@DYABU6<H00QBU00<@Q0aS48@00QBU0a2400<DYAS66<H011BU0QS600@D
YAS67>LHaPDDY@036<HDYABU00/@Q08DY@<@Q0@DY@0348@DYA24008DY@0348@DYABU00<DY@0448@D
YABU5:D348@15:D16<H148@00005124000@Q1240000212400`Q212448@02124022DYHaQ>LcF]>Lhe
[C6<=Jd2<H`01RDY8@PYBS6<>Lhe[@8aS003:DX]JbU:008]J`04:DX]JbU:9BT2:DX012e[:DX]Jbe[
0SF]00@aS2e[:DXYBP8]J`04<H`YBRDY9BT3;F/01BDY;F/]JbU:;F/01S6<00DYBRDY:DX]JbU:008U
:@03:DX]JbU:008YBP8]J`07<H`icSW>@Q0mkcF]>Lh00Re[00<U:B489BT01bDY0bU:0RDY0bU:0Re[
00HYBR488@PU:BU:9BT2:DX00bDY8@PQ2002:DX00bDY7>LQ2002:DX38@P00bDY:DXYBP039BT3:DX2
9BT012U:;F/YBRe[0b4800<U:BU:9BT00RDY00PYBRDY9BTU:B489BTQ22DY0bU:00@U:B489BTU:@DY
BP039BTQ224800@YBP8U:@037>LQ22DY00DYBP8U:@06;F/YBRe[;F/aS2U:0RDY00@]JbU::DXU:@<Y
BP039BTYBRDY00<U:@<YBP03;F/YBRU:008YBP<U:@8YBP<U:@8YBP03;F/YBRDY008Q20<U:@038@PU
:B48008Q20<YBP048@PYBRe[;F/4:DX01Re[:DXYBRDY8@PU:@8Q20037>LQ2248008Q208U:@8YBP04
9BTQ21cW7>L28@P01AcW6<HQ22489BT00QcW00<Q22DY8@P01B4800<HaQcW7>L00R4811cW00@Q22DY
8@PLi`8Q20069BTQ21cW8@PLiaS60QcW00PU:B488@PU:Be[:DXQ21cW0R480QcW0R480acW0b480RDY
00<Q21cW9BT00RDY0QcW00PQ22DY9BTU:B489BTYBRe[0RDY0acW124800<Lib487>L00R4800@LibDY
9BTQ208Li`098@PU:B487>LHaQcW6<HLib4800<U:@047>LQ22489BT28@P00acW9BTU:@039BT01b48
9BTU:BDY8@PLib48008U:@<Q208Li`046<HLiacW7>L25:D01aS67>LQ22DY8@PLiaS600<Li`046<HL
iaS68@P27>L00b487>LLi`047>L00aS65:DDY@026<H27>L26<H00aBU6<HLi`037>L46<H01QcW6<HH
aQBU6<HLi`8HaP035:DHaQBU00<DY@8HaP8Li`036<HLiaS600@HaP067>LHaQS65:DHaQBU0QS60QcW
00LDYA245:D@Q1BU48@HaP0348@00aS67>LDY@0248@00aBU48@@Q00248@02AS67>LHaQ2436<@Q1S6
5:D@Q0035:D00a2436<@Q00248@45:D011245:D@Q1BU0QS60QBU00D@Q1BU5:DDYA2400<HaP<@Q08D
Y@046<HDYABU36<348@00aBU48@DY@025:D248@00`aS48@@Q0035:D01aS648@DYA246<HLiaS600<D
Y@<HaP@DY@0448@DYA2436<248@25:D236<01A245:D@Q12436<01ABU00<@Q1BU48@00aBU0a2400TD
YAS65:DDYA2436<@Q1BU48@00QBU0Q2400000`0012448@0212401@0012448@@Q00000`@Q00D000@Q
12448@0000<48@0500048@@Q1240000312401@0012448@@Q00000`@Q00D000@Q12448@0000<48@05
00048@@Q1240000312401@0012448@@Q00000`@Q00D000@Q12448@0000<48@0500048@@Q12400003
12401@0012448@@Q00000`@Q00D000@Q12448@0000<48@0500048@@Q1240000312401@0012448@@Q
00000`@Q00D000@Q12448@0000<48@0500048@@Q1240000312401@0012448@@Q00000`@Q00D000@Q
12448@0000<48@0500048@@Q1240000312401@0012448@@Q00000`@Q00D000@Q12448@0000<48@05
00048@@Q1240000312401@0012448@@Q00000`@Q00D000@Q12448@0000<48@0500048@@Q12400003
12401@0012448@@Q00000`@Q00D000@Q12448@0000<48@0500048@@Q1240000312401@0012448@@Q
00000`@Q00D000@Q12448@0000<48@0500048@@Q1240000312401@0012448@@Q00000`@Q00D000@Q
12448@0000<48@0500048@@Q1240000312401@0012448@@Q00000`@Q00D000@Q12448@0000<48@05
00048@@Q1240000312401@0012448@@Q00000`@Q00D000@Q12448@0000<48@0500048@@Q12400003
12401@0012448@@Q00000`@Q00D000@Q12448@0000<48@0500048@@Q1240000312401@0012448@@Q
00000`@Q00D000@Q12448@0000<48@0500048@@Q1240000312401@0012448@@Q00000`@Q00D000@Q
12448@0000<48@0500048@@Q1240000312401@0012448@@Q00000`@Q00D000@Q12448@0000<48@05
00048@@Q1240000312401@0012448@@Q00000`@Q00D000@Q12448@0000<48@0500048@@Q12400003
12401@0012448@@Q00000`@Q00D000@Q12448@0000<48@0500048@@Q1240000312401@0012448@@Q
00000`@Q00D000@Q12448@0000<48@0500048@@Q1240000312401@0012448@@Q00000`@Q00D000@Q
12448@0000<48@0500048@@Q1240000312401@0012448@@Q00000`@Q00D000@Q12448@0000<48@05
00048@@Q1240000312401@0012448@@Q00000`@Q00D000@Q12448@0000<48@0500048@@Q12400003
12401@0012448@@Q00000`@Q00D000@Q12448@0000<48@0500048@@Q1240000312401@0012448@@Q
00000`@Q00D000@Q12448@0000<48@0500048@@Q1240000312401@0012448@@Q00000`@Q00D000@Q
12448@0000<48@0500048@@Q1240000312401@0012448@@Q00000`@Q0@000@@Q0@@Q000312401@00
12448@@Q00000`@Q00D000@Q12448@0000<48@0500048@@Q1240000312401@0012448@@Q00000`@Q
00D000@Q12448@0000<48@0500048@@Q1240000312401@0012448@@Q00000`@Q00D000@Q12448@00
00<48@0500048@@Q1240000312401@0012448@@Q00000`@Q00D000@Q12448@0000<48@0500048@@Q
1240000312401@0012448@@Q00000`@Q00D000@Q12448@0000<48@0500048@@Q1240000312401@00
12448@@Q00000`@Q00D000@Q12448@0000<48@0500048@@Q1240000312401@0012448@@Q00000`@Q
00D000@Q12448@0000<48@0500048@@Q1240000312401@0012448@@Q00000`@Q00D000@Q12448@00
00<48@0500048@@Q1240000312401@0012448@@Q00000`@Q00D000@Q12448@0000<48@0500048@@Q
1240000312401@0012448@@Q00000`@Q00D000@Q12448@0000<48@0500048@@Q1240000312401@00
12448@@Q00000`@Q00D000@Q12448@0000<48@0500048@@Q1240000312401@0012448@@Q00000`@Q
00D000@Q12448@0000<48@0500048@@Q1240000312401@0012448@@Q00000`@Q00D000@Q12448@00
00<48@0500048@@Q1240000312401@0012448@@Q00000`@Q00D000@Q12448@0000<48@0500048@@Q
1240000312401@0012448@@Q00000`@Q00D000@Q12448@0000<48@0500048@@Q1240000312401@00
12448@@Q00000`@Q00D000@Q12448@0000<48@0500048@@Q1240000312401@0012448@@Q00000`@Q
00D000@Q12448@0000<48@0500048@@Q1240000312401@0012448@@Q00000`@Q00D000@Q12448@00
00<48@0500048@@Q1240000312401@0012448@@Q00000`@Q00D000@Q12448@0000<48@0500048@@Q
1240000312401@0012448@@Q00000`@Q00D000@Q12448@0000<48@0500048@@Q1240000312401@00
12448@@Q00000`@Q00D000@Q12448@0000<48@0500048@@Q1240000312401@0012448@@Q00000`@Q
00D000@Q12448@0000<48@0500048@@Q1240000312401@0012448@@Q00000`@Q00D000@Q12448@00
00<48@0500048@@Q1240000312401@0012448@@Q00000`@Q00D000@Q12448@0000<48@0500048@@Q
1240000312401@0012448@@Q00000`@Q00D000@Q12448@0000<48@0500048@@Q1240000312401@00
12448@@Q00000`@Q00D000@Q12448@0000<48@0500048@@Q1240000312401@0012448@@Q00000`@Q
00@000@Q12448@4000000?h000@Q00048@00124000@Q00048@00124000@Q00048@00124000@Q0004
8@00124000@Q00048@00124000@Q00048@00124000@Q00048@00124000@Q00048@00124000@Q0004
8@00124000@Q00048@00124000@Q00048@00124000@Q00048@00124000@Q00048@00124000@Q0004
8@00124000@Q00048@00124000@Q00048@00124000@Q00048@00124000@Q00048@00124000@Q0004
8@00124000@Q00048@00124000@Q00048@00124000@Q00048@00124000@Q00048@00124000@Q0004
8@00124000@Q00048@00124000@Q00048@00124000@Q00048@00124000@Q00048@00124000@Q0004
8@00124000@Q00048@00124000@Q00048@00124000@Q00048@00124000@Q00048@00124000@Q0004
8@00124000@Q00048@00124000@Q00048@00124000@Q00048@00124000@Q00048@00124000@Q0004
8@00124000@Q00048@00124000@Q00048@00124000@Q00048@00124000@Q0P000?d48@00124000@Q
00048@00124000@Q00048@00124000@Q00048@00124000@Q00048@00124000@Q00048@00124000@Q
00048@00124000@Q00048@00124000@Q00048@00124000@Q00048@00124000@Q00048@00124000@Q
00048@00124000@Q00048@00124000@Q00048@00124000@Q00048@00124000@Q00048@00124000@Q
00048@00124000@Q00048@00124000@Q00048@00124000@Q00048@00124000@Q00048@00124000@Q
00048@00124000@Q00048@00124000@Q00048@00124000@Q00048@00124000@Q00048@00124000@Q
00048@00124000@Q00048@00124000@Q00048@00124000@Q00048@00124000@Q00048@00124000@Q
00048@00124000@Q00048@00124000@Q00048@00124000@Q00048@00124000@Q00048@00124000@Q
00048@00124000@Q00048@00124000@Q00048@00124000@Q00048@00124000@Q00048@00124000@Q
00048@00124000@Q00048@020000P0@Q00048@00124000@Q00048@00124000@Q00048@00124000@Q
00048@00124000@Q00048@00124000@Q00048@00124000@Q00048@00124000@Q00048@00124000@Q
00048@00124000@Q00048@00124000@Q00048@00124000@Q00048@00124000@Q00048@00124000@Q
00048@00124000@Q00048@00124000@Q00048@00124000@Q00048@00124000@Q00048@00124000@Q
00048@00124000@Q00048@00124000@Q00048@00124000@Q000112400001\
\>"], "Graphics",
  Evaluatable->False,
  ImageSize->{640, 480},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005H0001=Q000`40O003h00O00@@Q1BU7>LQ208L
i`038@PHaQBU008@Q0056<H@Q1BU5:D@Q0035:D26<H25:D011245:D@Q1240QBU0Q2400<<Ha2448@0
0a2400THaQcW6<H<H`Q236<HaR487>L00aBU00<@Q1BU48@00aBU0Q240PaS0Q2400<HaQBU48@00`aS
00<DY@aS24800PaS00@@Q0aS36<@Q08DY@<@Q00336<@Q124008HaP0348@<H`Q2008<H`0348@8@Q24
008DY@0436<8@PaS48@336<00a2436<8@P0436<00`Q236<<H`0336<248@01ABU36<<H`Q236<00QBU
0Q240`aS0QBU00P@Q0Q236<@Q0Q2120<HaBV0RU:00DQ1acX9BPQ236<00924008:DXHaPaS48DHaA24
5:DHaP8Q20037>LQ2B48008DY@07128<HQ256<DDYQ24248010aS00L@Q1BU36<@P`aT5:@Ha`026<H0
0aBU36<8@P0236<00a2436<8@P0236<02PaR248<Ha256<DDY@aR248@QABU0QcW01<HaPaS36<<Ha24
7>LHaQcW8@PLiaS67>PU:36<=Jd]JbDY7>LHaP027>L03aS648@<H`aS48@@QA2436<8@Q2436<@Q123
24<@P`0248@01PaR36@DYAS65:D<H`8@Q00636@DYA2448@DYAS60QBU0PaS00@@PaBU48@@Q08<H`05
48<@QABT5:D@Q00236<011BT5:DHaQS60QcW00DYBRe[;F/]JbDZ008Q20076<HDY@aS36<@Pa245:D0
0a2400LDYA2448@HaAS7=J`e[@02>Lh02BDZ9BTLiaBU6<H<Ha2448DHa@027>L012489BTQ22480aBU
00h@Q1BU5:D@Q12348@DY1245:DLiQ255:@8@PaS0aBU0Q2400001A246<HLib487>L011S60QBU0Q24
00@<Ha2448@@Q08DY@<@Q0<DY@8@Q08DY@0348@8@PQ200<<H`0448@DYAS66<H55:D27>L01QS648@D
YAS67>LDY@8@Q0035:DHaQBU00<@Q08DY@0348@<Ha24008<H`848@8<H`0348@<Ha2400@DY@0336<@
Q0Q200<<H`8@Q0035:D@Q1240088@P0336<DYA2400<<H`035:D@Q0aS00<<H`0548@DYA2436<48@02
36<01Q2436<48@@Q248<H`8DY@0448@DYABU48@236<00a246<HDY@0236<03A245:DDYA2436<8@Q24
36@8@QBU8@LYBbDY008Li`0=9BTU:Re[?NhicR496<H<HaS57>PHaAS67>L00b4800@LiaS65:DDY08<
H`0748@<I1BT5:D@Q12536<00`Q200/<H`Q3248@Q1S68@PHa@aS48@<I0aS008@Q0045:D<H`aS2482
36<020Q236<<H`aT48@DYA246<D26<H04ABU48@@Q1S57>LQ21BU36<@Q1cW9BTLib48:DXe[C6<:DX0
0R4800DDYQS65:DDYA2300H<H`0636@@Q1BU48@<Ha230PaT0PaS00@DY1BU6<HDY@8<H`0<6<DDYABU
5:D@QABT5:D@Q0aS5:@@QAS60QBU00D@Q0aS248<H`aT008DY@8@Q08DY@0;48@DYABU7>LU:Be[=Jha
S2U98@PHaP025:D01a245:@DYQBU48@<Ha24008DY@0<48D<Ha248@PYBSF]<H`YBc6;:DXU:AcW0QBU
00P@Q1BU5:DDYAcW8@P]JRU:0QcW00<DYA2424800PaS00<@P`aT36@00`aS00@DYABV6<D@Q@8<H`03
5:@@QABU008DY@0000@<HaBU7>LLi`8DY@077>LQ21cW48@<HaBU48@00QcW0QS600DDYA2436<@Q1BU
008Li`<HaP@DY@0536<8@PaS5:DHaP0248@00aS68@PHaP035:D011S65:DDYABU0Q2410aS0Q2400<D
YA245:D00aS62Q240PaS0PQ20Q2400@HaQBU48@@Q0<DY@0448@DYA2448@25:D00aS65:DDY@025:D0
0aS648@@Q00336<324800a245:D@Q00336<01`Q236<<H`aS248<Ha24008DY@88@P031248@PaS00D<
H`8@Q08<H`88@P0:48@DY1BU36@<HQ245:DHaQBV5:@25:D00aS67>HDY@0348@011255:DHaA250PaS
00HDYAS548@8@`Q124<248@00aS65:DDY@0248@25:D020aR248<HaBU48@<HPaS48@26<H02`aS2488
@@Q248@@QA2424848@0012400Q2400HHaABU36<<H`Q236<45:D011BV6<HLiacW11BU00@@Q1BU6<HQ
208YBP03:D/YBRDX008Li`8HaP035:H<Ha2300<8@P03368DYA24008<H`0336@<H`aR008<H`0448@@
Q@aS36<248@03AS79BPU:BDX6<H<I1BT24<48@aS7>LQ21S6008<H`045:DHaQBU48<324800a2436@<
H`0348@03ABU48@DYABU8@LQ2B48:DX]JacX6<H<Ha24008DY@056<HDYABU5:DDY00336<25:D04aBV
6<DDYQcW8@LQ2BU:8@PHaQBU6<HLiaBV36<@Q1258@LLiaS600<DY@066<HDYQBU368<I12411BU00D@
Q1BU48<<I0aR00<<H`000PaS00LDYAcW6<HQ22U:7>LDY@02248011246<HHaQS60QBU00<Q21cW6<H0
0Q2400<HaQcW6<H00Q2400@DYAcW6<H<H`88@P8DY@8Li`066<HDYABU6<HLiaS611BU00@<Ha245:D@
Q088@P0536<DYABU5:D@Q0025:D011S65:DDYA240QBU00@@Q0aS48@<H`88@P0836<DY@Q2124DYB48
9BTLi`88@P0448@HaQS66<H236<248@25:D00aS65:DHaP0236<248@01AS648@<H`Q236<00a2400L<
H`Q2248<Ha245:D@Q00336<248@436<248@336<011246<HDYA240PaS00@8@Q2436<8@`8<H`8HaP0:
5:DHaQBT24<<HaS67>PLiaS636<348@00aBU48D@P`0336<00aBU48@@Q00224803A2348@DYABU48<<
Ha2436<@Q0aS248<HPaT008<H`0;5:DDYQcW7>L@Q0aR128<HaBU5:@<H`0324800`aS2488@P0348@3
36<25:D01QS56<HDYAS67>LHaP<DY@0>6<HDYABV5:DU:BU:<H`]JbDY7>LQ21S548D@Q08DY@<<H`0;
48DDYABU48@<Ha245:D<H`Q236<@Q0025:D04A2436<DYAS68@PU:R486<HDYA2448DDY0aS48DDY1BV
5:@00Q240QS600HHaa2436<8@PaS5:@248@01QBU48@@Q1BU48@HaP8Li`07:DX]Jbe[:DXQ1acW48@0
0QBU00`@Q12536<@Q1BT5:D<H`Q236<@Q1cW7>H26<H04R489BTYBR487>LHaQcW48@<Ha2348@HaacV
6<LLiaS67>LHaP8DY@8@Q0066<HDYA24248<Ha240QBU00D@Q1BU5:DDYA24008<H`000PaS00DHaQcW
5:D@Q1BU008HaP047>LHaQS648@35:D01R487>LHaQBU36<@Q08DY@046<HDYABU6<H25:D01Q245:D@
Q124248DY@8Q20037>L@Q0Q2008@Q0085:D<H`Q248@HaQcW5:D<H`8@Q08<H`04248DYABU5:D28@P0
1QS648@DYAS68@PLi`8DY@8HaP057>LDY@aS36<@Q00336<01PQ25:DDYAS648@<H`8@Q00624848@@Q
36<DY@aS0QBU0Q2400D8@PaS36<<Ha24008HaP035:D@Q1BU008HaP035:D<H`aS0088@P8@Q08DY@@@
Q00336<@Q1BU00@<H`045:DHaQS65:D536<00a2348@DY@035:D236<01A2436<@Q12336<00aBU00<<
H`Q236<00PaS00@8@P@Q248<H`8@Q00736<<I1245:D<Ha245:H00QBU0`aS00<<I12336<00PQ20Q24
00<<H`Q224800PaS00H8@`Q2124000Q248@25:D030Q21248@PQ236<8@P@Q248<Ha2436@<HP88@P09
48DHaR488@PLiaS66<DDYAS600@Li`098@PU:Be[:DXU:1cX6<DHaQBU008<H`05248<HPQ336<<HP02
36<01PaT36<<H`Q248<@Q@<@Q0045:D@Pa245:D26<H02ABU36<@Q1BT36@DY1BV48@<H`0224800aBT
5:D@Q00248@236<01@Q21248@PaS48@00`aS11BU00DHaQcW6<HU:BDZ008U:@0;6<HHaABU5:DDYQ23
24<<Ha245:D@Q@035:D021S66<D@QA2436<DYAS67>L28@P04AcW5:DDYABU6<H@Q1S69BT]JbU97>L<
I1BT5:HHaABV5:@00Q2400HDYAS66<HDYA2436<148@000065:D@Q0aS48@HaQBU0PaS00HDYB486<HD
Y@aS48@26<H27>L25:D00a245:DHaP045:D26<H01Q2436<@Q1S65:D<H`8@Q08Li`8DY@0548@<Ha24
48@<H`045:D448@35:D011245:D@Q1BU0acW00@HaQBU6<HHaP8DY@056<HLiaBU36<8@P0336<248@3
5:D01QS648@<H`aS248<H`88@P0336<HaQS6008<H`8DY@88@P0436<HaQS66<H248@236<02QBU36<<
Ha2436<8@PaS48@HaQ240PaS00<@Q1BU36<00Q2400D<H`Q236<<HaS6008DY@0336<@Q0aS00<<H`05
48@<HaBU5:D@Q00336<011245:DDYABU0PaS0Q240PaS00`<HPaS36<<H`Q224<@PaS65:D<H`aR48@2
36<011246<HHaQ250PQ200<<Ha2336@00`aS00T8@PaS36<8@PaS2488@@Q212400`Q200<@Q0aS36<0
0PQ200T<H`Q22488@P@Q248<Ha2436<00PQ200D@Q1BT48@HaacW008Q20047>LHaQBU5:D27>L02248
9BTYBRU;:DXHaQS536@248@010aR2488@PaS0PQ200<48PQ136<00PaS00@8@PaS36<Ha@8DY@8HaP03
48@<HaBU008Li`046<H@Q12436<348@00a2324<<H`0224801Q245:DHaQBT24<<H`88@P<<H`08248<
H`aS5:DHaQS55:HHaP8Q2005:DX]JRDY8@PHa`026<H04Q2436<<I1235:D@Q1BU5:@@QA2348DHaABV
5:@@Q1BU6<HLi`@HaP0?7>LDYA2448@DYBDY:DTU:AS76<DHaQcW5:D@Q0aS008DY@8<H`0348@DY@aT
00<<H`0000<Q21S648@00Q2400<Q21cW8@P00QcW0b4800DHaQ245:D@Q0aS008HaP057>LHaQBU5:DH
aP027>L35:D011S65:D@Q1240QBU00<HaQ2436<00PaS00<DYA2436<00PaS0Q2400L8@P@Q36<@Q1BU
36<8@P0336<01@Q236<@Q1BU6<H00QcW00<HaQBU6<H00QS600<DY@aS36<00Q241@aS00P8@PaS2488
@PaS5:D@Q0aS0PQ200`<Ha24248<Ha24248<H`Q236<@Q0aS48@25:D011S65:DHaQcW0QS600<DY@aS
36<00QBU00@@Q0aS248@Q08DY@8Li`<DY@0348@HaQS6008HaP0348@DYAcW00@Li`046<HDYABU5:D2
48@00`aS5:DDY@0224800`@Q248@Q00336<324801@@R36<<Ha2336@00`aS01<@Q1BU5:HDYA2448<H
abDX9BTQ2124248<H`Q236<@Q1BT5:D<I00236<01@Q212448@Q236@00P@Q00P8@Q245:D<H`aT48@D
Y@aS0PQ200@48PQ136<8@P<<H`0724<<H`aR248DYAS67>L00QS600`Lib488@PQ21cW8@PU:B48:DXU
:AcW6<H348@01`Q336<<Ha245:@<I0aR00<8@P@<H`<@Q00636<@Q0aT48@<H`aR0`aS00D@Q0aS2488
@PaS008DY@0348D<H`aS008@Q0057>LQ21BU48D8@@0336<05PQ236<@Q0aS248DYAS67>LDYABT7>LU
:RDY9BPU:B489BTQ21cW7>HDYAS60QBU00<@Q1BU48@00`aS00L@Q1BU5:D@Q0aS48@HaP02:DX28@P3
5:D0112448DHaAcW0R4800`U:B488@PQ212424<8@PaS6<HLiQBU36<1248000<DY@036<HLiacW00<H
aP088@PYBR486<HDYA245:DHaP@@Q08DY@@HaP085:DHaQBU48@DYAcW6<HDY@8@Q0036<HDYA24008<
H`05248<H`aS48@DY@026<H011BU48@DYA240PaS00@8@PaS48@HaP8DY@076<HQ22DY8@P@Q0aS5:D0
0R4800<HaPaS12400PaS0Q2400<<H`Q224800a240`aS00<@Q0Q236<01@Q200D48@aS36<DYA24008D
Y@056<HDYABU5:DHaP027>L26<H02PaS248@Q1BU6<HDY@aS248@Q1S60QcW0aS60QBU00X<Ha246<HD
YAS648@DYAS67>LQ20<HaP8Li`055:D@Q12324<<H`0212402PQ236@HaQS548@8@`Q236<@Q0aR0PQ2
00@<H`Q2248<H`8DY@0936<@Q1BU7>LHaQcW8@TQ1aBV008@Q00?48D<HP@R248<HaBU6<D<H`Q20004
8PaR24<<HPQ3008<H`0848@DYA2448<@Q0aS36@8@P<48@0836<@QA2424848@Q248@DY@8<H`0748@L
ib487>LHaQBU7>L00RU:0R4800HYBAcX6<HDYABT36@236<02`Q236<DY12436<8@P@Q248<H`Q236@0
0aBU00T<Ha2448D@Q0aS368<Ha2436<0112400<<Ha2448@00PaS00<@Pa2436<00PaS00H<I1S55:DD
YA2424<324800`aS48@@Q00236<224825:D00b498@PYBP03:DX022DY8@PLiaS55:H@Q0aS5:D26<H0
21BU36<<Ha2336@@Q1BU6<H248@011cW8@P]JbU:0QcW0aBU00XDYQS648DHaB49:DXU:AcW5:DHaP8D
Y@0348@DYABU008@Q08<H`0000<HaR487>L011cW00@HaQBU5:DDY@<HaP8@Q08<H`0948@<Ha2448@D
YAS65:D@Q0aS008@Q08<H`06248@Q12436<@Q1BU0QS600LDYA2436<<Ha2436<8@P0236<0112436<8
@PQ20Q2400@HaQ2436<8@P<<H`045:D@Q12448@436<01a2436<<HaBU6<HDYA24008<H`0448@DYA24
36<224801@aS48@HaQBU48@00QBU0Q240PaS11240QBU00HHaR488@PQ21cW6<H25:D00a2436<@Q003
48@236<0112436<@Q0aS0a240QBU0a2400L<H`@Q248@Q1BU7>LQ20026<H021cW9BTLiaBU48@HaR49
7>H25:D02aS67>HDYA2436<<I1BT6<HDY@aS48@00PaS00<8@`Q124800PaS00P8@P@Q248DYAS65:D<
Ha2411BU00<HaQ2436800`Q200H8@`aR36<<HaBU48@224801@aR36<<H`Q1128010Q200L<HPaS36<<
Ha2436<<HP02248010aS24848@Q20Q2402H8@PaS48@DYQ2336<DYB477>LHaQcW7>PQ1acW6<HDYBDY
<H`]JacW36<8@aBU48@<H`aT48@8@P00244<Ha2536848PaS6<DDYA250`aS00L8@`aS36848PQ22448
@P0436<0112448<<I0aS0PaR00D48PQ2124<H`Q2008@Q08DY@@HaP0G5:D<HPQ3368<HaS56<HQ21cX
8@P]Jc6=;F/Q21cW8@PU:BDZ7>LHaA245:DHa`025:D061255:@@Q12448DHaQS548DHaQcV9BX]JQcX
6<D<H`aR5:D<Ha235:HLibDX7>LDY@8@Q00336<DYABU00<DY@0000<DYAS65:D00QBU0QS600<LiaS6
5:D01aBU0PaS00<@Q1S66<H01ABU00@@Q0aS36<<H`8DY@046<HDYA245:D448@010aS2488@PaS0Q24
00<8@Q245:D00QBU00<8@PaS24800`Q200L<H`Q2248DYAS67>LHaP0236<2248248@00aS648@<H`02
5:D02A2424848@aS48@<Ha245:D@Q00236<011BU7>LDYA240PaS00@@Q0aS36<8@P8<H`066<HLiacW
9BTYBQcW0QBU00<HaQcW6<H00QBU10aS00@@Q0aS48@<H`<@Q0035:DHaQ2400<<H`0848@<H`aS5:DL
iaS65:DLi`8YBP049BTHaQS66<L26<H021BV5:@<I1BT5:HHaQBU48@25:D248@224800`aS124<H`04
36<040@Q248<HaBU6<HDYA2436<@P`aS5:DDYQS536<8@`Q20Q2400@<HPQ336<@Q0@<H`88@P051248
@PQ12488@`0536<01A2336@@Q0aT48<00PQ200<<HPaT36<00PQ200H<Ha2436<@Pa255:D36<H27>L0
42487>LHaQS67>LQ22DY7>LLiQBU36<@P`Q336<DYA240PaS00/00@@P36<@Q1S648@<Ha245:DHaQBU
008<H`05248<H`aS2488@`0336<010Q224<@Q0aS0`Q200P<I1BT36<8@PaR5:DLiaBU0Q2400<DYAS6
48D00`aS00D@Q12536<DYAcW00<U:@05;FXaS2U;9BTQ1`038@P03AS65:DDYABU48@<H`aR248<I1BU
5:@DYA24008DY@087>LQ22489BTLiaBV48@<I08DY@0648@HaAS67>PLiaBU0`aS0aBU0PaS000236<2
5:D00`aS48@DY@026<H01ABU6<HLiaBU6<H00QBU0QcW00@HaPaS248<H`<DY@8@Q00536<@Q1BU6<HD
Y@0236<25:D02@aS248DYAS648@<H`Q236<@Q0025:D01AS65:DDYAS67>L00R480QBU0a241PaS1A24
00<<Ha2436<00Q24018DYA2436<<Ha2436<@Q0aS248DYAS67>LHaQ245:DHaQcW5:D248@336<01124
6<H@Q1BU0Q240aBU00D@Q1S66<HDYA2400<<H`0;248<HaBU5:D<H`Q236<DYAS648@<H`0248@01@aS
48@<Ha2436<011BU00L<HaBU6<HHaQ2436<<HP0336<01Q2448D<H`aR248<H`<@Q08<H`@@Q00936@D
YAS67>LHaPaS48<@QABU008<H`0748@DY@aT48<DYAS65:D00`aS00<@Q1BU24800P@Q00<8@QBU48@0
2@aS0PQ200<<Ha2448D00Q2400LDY1S648D@Pa255:D@Q003248010aS36@8@PQ20PaS01@DYA2448@@
Pa247>LQ2B486<HDYAS6:DX]JcF]AS8mkc6<8@PDY1BU0`aS00@@Pa245:D@Q08<H`06248@Q1245:@D
YA240PaS00L@Q1BU48@@Q0aS368<I00248@236<01A2448DHaABU48D00Q24010DYAS65:DHaR48:DXL
ia24368@Q1BV5:D@Pa2436@<H`8@Q00=6<DHab489BPQ22e/<H/e[SF]:DX]JacW5:D00Q2400H@QA23
36<<Ha245:D448@00`aS48@DY@026<H00aS55:DDY@0236<00a2448DHa@0248@011S67>LHaQ240QBU
0A240@aS00000`aS48@@Q0026<H25:D01A245:DHaQBU6<H00QcW0QS60aBU00<HaQ2436<00PaS00<H
aQBU48@00PaS00<@Q1BU5:D00PaS11240QBU00/@Q0aS36<@Q1BU6<HLiaS65:D@Q1S6008Q20087>L@
Q0Q248@8@Q2436<8@P8<H`<@Q0065:D@Q0aS248<Ha240QBU00<@Q0aS48@00QBU00D@Q0Q2124<HaBU
008Li`036<HDYABU008DY@8HaP0448@<H`Q236<348@011S65:DDYABU0PaS00@HaQcW7>LHaP<<H`8D
Y@0548@8@PaS5:D@Q00336<00a2436<<H`0248@01ABU36<8@PQ236<021BU00@@Q0aS5:D@Q0<8@P8D
Y@0348@<H`aS008<H`8@Q0065:D@Q0aS36<@P`aS1ABU00<@Q0aS48<00Q2400<<Ha245:D00aS600@@
Q0aS12448@88@P0348@8@PaS00<@Q00336<8@`aS00<<H`04248<H`aS36<224801@aS5:DDY12548@0
0QBU00D@Q0aS48<8@PaS00848@0736<@PaBU5:D<Ha2448D00PaS00<@QABU8@L00QS60QcW00PHaRU:
>Li6<DH`;F`Q1acW0QBU00D@Q0aS36<48PaS00<DY@0736<<HPaS48@@QA2436<00PQ20`aS00H@Q0aS
24<<HPQ236<25:D26<H0312436<<HPaT5:D@Q1BU7>LU:B486<HDY@<@Q08DY@0448@<H`aR36<25:D0
2aBV9BPYBbU:9BT]JRe/=J`]Jb499BT00QBU00D@P`aS48@<I124008<H`0448@DYABU5:D248@25:D0
11cW8@PLiaBU0PaS00`DYAS65:@<I0aS6<HLib487>LDYA245:D248@000075:D@Q0aS5:D@Q2487>L0
0R480bDY00LQ21cW6<HDYAS67>LHaP025:D03AS67>LLiaBU48@DYAcW:DXLia2436<@Q1BU00<<H`03
48@<H`Q200<<H`0448@DYAS67>L35:D01aS65:DHaQS65:DHaPaS00<8@P8DY@D@Q08<H`0348@<H`aS
008<H`045:DHaQBU36<224800aBU6<HDY@02248010aS5:DDYABU10aS0Q2400<DYA2448@00Q240`aS
00`@Q0Q236<8@PaS5:DLiaS648@48@aS48@2248010aS5:DHaQS60aBU0QS600HDY@aS48@DYA245:D4
48@01ABU48@<H`aS248010aS00D8@PaS36<<Ha2400P<H`0748@DY@aS36<DYAS65:D00Q2400lDYAS6
5:D@Q1255:@8@a235:HQ1aBV36<8@PaS5:D00a2400D8@PaS48@@Q1BU00<HaP8DY@0648@<I0aS36<@
Q1230`aS112400L<Ha2448@<H`@Q36<<I0025:D224800`Q3248@Q0025:D01ABT36@DY1S67>P00QcW
00<U:B488@P00QS600LQ2B48:DXmkd8@>LlaS0025:D26<H02QcW6<HDY@aS36@@Q1BV5:D<H`Q210aS
00@8@PaS36<@Q0<8@P0336@@P`aS008<H`8@Q08<H`03248<Ha24008DY@8HaP8Li`8Q20039BTQ21S6
008HaP8Li`045:DHaAS68@P27>L011S67>LYBRU:0S6<00DaRc6=:DXQ21cW008HaP<@Q0045:DHaQBU
48@236<00a245:@@Q00236<35:D00a255:DDY@025:D01QBT48@@Q1BU48@HaP8DY@000a2400HHaR48
8@PQ21cW9BT2:DX28@P27>L00aS65:DDY@025:D26<H27>L01aBU48@DYAS67>LDYA24008<H`8@Q08D
Y@0636<8@PQ236<@Q0Q20PaS00<DYAcW7>L00QBU0PaS00XDYAS66<H@Q0aS124<Ha245:D@Q08<H`06
48@DYABU48@DYA240`aS014DYAS66<HDYA2436<8@Q245:D@Q1BU36<8@Q245:DHaQBU0088@P0348@D
YA24008<H`<@Q0035:D<Ha24008<H`03248<H`aS008DY@0348@DY@Q200<8@P0636<DYABU48@<Ha24
0QBU0a240QBU112400<DYA2436<00PaS0aBU00@@Q0aS2488@P8<H`8@Q08<H`8DY@0<48@8@P00000@
Q1BU6<HDY@Q3248@Q1BU0QS600DDYA2448@@Q0aS008@Q00:5:DLiaS65:@8@`aR36@DY0aS24<336<0
1A245:DDYQS548@010aS00/@Q0aS48@@QA2436<8@PQ348<<I123008<H`0448@DYA2548<336<03a24
48<<I12324<@Pa256<H<I0aR48DQ1bDY7>LHaP058@P02beZ:DXYBSg_AS4e[B485:DHaQcW6<H011BU
00<DY12448@00PaS00@8@PaS48@@Q088@P07368<H`aS36<<HPaS48@00`aS00L8@PaS36<<I0aR36<@
Q0036<H011cW8@PLiacW0b4800XLiaBU5:DHaQcW6<HDYA255:DLi`8DY@087>LYBS6<;F/aS3F]<H`Y
BP8Li`046<H@Q1BU48@25:D248@02@aS36@<HaBU6<HDY@aS248<H`026<H011BU6<HLiaS60PaS00<@
QAS66<H00PaS0A240@aS0A2400001@aS48@DYAcW5:D00Q240QS600DLiaS66<HDYAS6008Li`046<HD
YAS67>L2:DX02R487>LLiacW8@PLiaS648@DY@aS0Q240`aS0`Q200@<HaBU48@<H`8DY@0748@8@PaS
5:DHaQBU36<00Q240PQ200DDYAS648@<HaBU008Li`0B5:D@Q1BU6<HDYA2436<8@PaS48@DY@aS48@D
YAS65:D@Q0aS0QBU00@HaQBU48@<H`8@Q0035:D@Q0aS0088@P045:DHaQS65:D248@011cW48@<H`@Q
0PaS00D8@PaS48@@Q1BU00<<H`04248@Q0aS48@25:D011S65:DDYAS60a2400D<Ha2436<@Q1BU008H
aP065:D@Q0Q248@DYAcW0QBU00<HaQBU48@00PaS00H@Q0aS48@@Q1S648@224800`aS48@@Q00336<0
1PQ2124<Ha245:D@Q0<8@P0348@DYA24008<H`0948@@QABT24<8@P@Q248<H`aR00@<H`0348<@QABU
00<HaP057>LQ1acX8@PLi`036<H011BU48@@Q1240PQ200T@Q1BV5:@8@`Q25:@DY@aR24<00QBU00T<
H`Q236<DYA23248<HaBU6<H00`aS00HHaQcW6<HHaQBU48@25:D27>L02AS68@PU:B487>L<HaBT36@8
@P0236<00a2436<8@P0224800`aS2488@P0224800`Q348@<H`0248@02ABT36@<H`aS5:D@Q0aS1248
@P0236<00`Q248@@Q00336<04QS67>LLib489BTLiaS636<DYABV48@@P`aS48@DYA245:D@Q08HaP8L
i`07;F/e[Cg_?Nle[Be[:DX00QcW0QS60aBU00<LiQBU5:D00PaS00@DY@aS48@<H`<@Q0075:DLiaS6
5:D@Q1BU7>L00QBU0AS60AcW00025:D01a245:DHaQBU48@<Ha24008Li`<HaP045:DHaQS65:D28@P2
9BT031cW6<HHaQcW8@PLiaBU6<HDYA24248<H`8DY@0436<8@PaS5:D348@25:D02AS648@@Q0aS48@D
YAS65:D@Q00236<248@011BU48@@Q1S60acW0QBU0Q2400@<H`Q236<@Q08DY@0348@<H`aS008@Q08H
aP8DY@8@Q0@DY@0348@8@PQ2008<H`065:DLiaBU48@8@PaS0Q2400<<H`Q224800PQ200H@Q0aS48@@
Q1BU48@436<25:D26<H25:D26<H01QBU36<@Q12436<DY@8Li`055:D<H`aS6<HDY@0248@011BU6<HH
aQ240PaS00<8@PaS5:D00QBU0PaS00<@Q0aS24800PQ20PaS00<@P`aS48@00Q240QBU00H<H`@Q36<@
PaS76<H736<224800`Q336<<H`0224803PaS5:DDYAS65:@DYAS67>PQ22475:HHaAS67>H25:D01Q24
36<@Q0aS5:DHa@8DY@0:48@<H`aT36@<Ha2348@DYA2436<224801@aS48@DYA2436<00a2400<HaQBU
6<H00QBU018HaQBU6<HDYAcW6<HQ22DY7>LDY@aS24<@Pa2436@<HPQ2124236<3248236<00a245:DD
Y@0248@01@Q336<DY1255:@00PaS00H8@PQ1128<Ha245:D324800a245:HDY0027>L00b489BTHaP04
5:D0112436@@Q1BU0PaS00d@Q1S66<HHaR489BTe[C6<=Je243W><H`Q20026<H021BU48@DYABU6<D@
Q@aT36<45:D00a2436<@Q00248@02QcW8@PLiQBU36<@Q1S648@@QABT0ABU00000aBU8@PHaP026<H6
7>L01R486<HHaQcW8@PLi`8HaP087>LU:BDY7>LHaQ245:DHaP8DY@0448@DYA2436<248@011BU36<8
@PQ20PaS00PDYAS66<HDYA245:DHaQcW0aBU00HHaQBU5:D<HaBU7>L28@P45:D236<25:D01Q242488
@Q2436<@Q08HaP045:D@Q1BU6<H28@P01QcW5:D<H`aS48@8@P8<H`8@Q00736<@Q1BU5:D<H`Q21240
0PQ20`aS0PQ200P<HaBU36<48@Q248@DY@aS0PQ200<DY@aS36<00PQ200@<Ha245:D@Q08<H`0648@D
YABU5:D<H`Q20QBU00<HaQBU5:D00Q2400<<Ha245:D00`aS0Q2410aS0`Q200L@Q1BU48@8@`Q1248<
I00236<02PQ236<<Ha2436<8@`Q236@DY0aS0PQ210aS0`Q20Q2410aS0QBU00THaAcX9BTU:B479BTY
BbeZ9BX00QcW00<Lj2489BT00R4800@U:BU:9BXQ20<DY@096<HDY0aS36<<I1S56<HDYA24008<H`8@
Q00336<DYAS6008DY@0436<@Q12536<248@02AS67>LHaQS65:D8@P@Q48@DY@028@P011S65:D@P`aS
0Q2410aS00@48@Q236<<H`<8@P8<H`0;5:D@QABT6<HLia2436<8@PaS5:D@Q00436<01Q2436<@Q124
36<DY@8HaP085:D@Q1BU6<HDYABT36@DY08DY@0?6<HDYA2436<DYAS68@PU:BU::DTYBRDY;FXYBbU:
008aS00:8@PLia255:DHaAS648@DYA2436<248@01`aS48@@Q12436<@QAS6008Li`8DY@8HaP4Li`00
1AS60R4800DLiaS65:DHaR48008HaP038@PYBQcW008DY@076<HU:BDY7>LDY@aS48@00QS600@DYAS6
6<H@Q08<H`035:D@Q1BU008<H`0348@<HaBU00@DY@0<6<HLiaBU36<@Q1BU6<HDYA246<HQ22DY0QcW
00HQ21BU48@<Ha246<H25:D00a2436<@Q00248@011BU48@@Q1S60QcW0QS600DLiaS65:D@Q0aS00D@
Q08<H`045:D@Q0aS36<224801@aS2488@PQ248@00PaS00@@Q0aS5:D@Q08<H`05248<Ha2424848@02
36<011BU48@@Q1240`aS1A240QBU00<@Q1BU6<H00QS600D@Q1BU5:DDYA2400<<H`@@Q0L<H`D@Q0<<
H`05248<HPaS36<<HP0236<01@aT36<<HPaS48@00PaS00L8@PaS48<<H`Q236<8@P0336<02ABU48@H
aQcW:DX]JbU;<H/aS002;F/042DY8@PQ22DY;F/U:AcW7>PQ1b487>LDYQ2448<@Q1BU0a2400<DYAS6
6<H00Q2400@<Ha245:D@Q0<DY@056<H@Q12348@DY@026<H45:D00aBT36@@Q0025:D03248:DXQ21BU
36<8@aBU48@8@P@Q248<H`8@Q00536@<H`aR24<<HP0348@031BU48@DYQcW5:D<H`Q236@@Q0aS248<
H`8@Q00=36<<HPQ336<<I1BU5:HHaA255:@HaQcW6<H00QBU00<DYQBU48@011240QBU00@U:S6;<Hda
S08YBP05;F/aRc6<;F/YBP027>L25:D01Q2436<DYABU6<H<H`88@P8DY@8<H`0336@LiQS6008Li`03
6<HLiacW008HaP0000<@Q1BU5:D00QS600LDYAS66<HDYAS67>LQ20027>L012DY;F/e[Be[0R4800<L
ibDY7>L00aBU00@LiaS66<HHaP8DY@@@Q0<<H`8DY@8HaP085:DHaQS66<HDYA245:D@Q0@DY@@@Q0@<
H`0348@<Ha24008DY@0348@<H`Q2008@Q0DDY@046<HDYABU5:D248@436<0112436<8@PaS1Q2400<<
Ha2448@00Q2400D8@P00000000Q200<<H`0548@<H`aS248<H`045:D01aS648@8@Q246<HLiaS6008D
Y@DHaP055:D@Q12448@DY@0236<00a2436<8@P0236<55:D01Q2436<@Q1BU48@8@P848@8<H`8DY@0A
6<HDYABU36<48@@R248DYA2436<@P`aS24<<HPQ35:@<H`02248236<3248031245:D@Q1BU6<HLibDX
;F`]JbDY6<HLi`8Q20036<H@Q1BU008HaP037>LHaQcW008Q20037>LHaA25008DY@066<HDYA2324<8
@QBU0QS600/LiaS66<HLiaBU36<DYAS68@PLj1S5008@Q00536<@QAS66<H@Q003248348@236<00a24
7>LLi`027>L00aS536<<H`0236<03Q2436<<HPQ33688@PQ3368@Q0Q2124@Pa2548@224803PaS5:@<
I1235:DLiaS65:D<I1BT36<<HPaS5:@248@336<020Q236<DYAS55:D@Q0aS5:D236<04ABU7>LU:B48
7>HLiaS65:HHaQcW8@PQ2AcW8@LQ22e[:DX00QcW00<DYA245:D00aBU00P@Q1BU6<HDY0aS248<HaBU
0a240AS60AcW0AcW000010Q26<HQ21cW0Q2400@DYB487>LHaP8Li`036<HLibe[008aS003:DXQ2248
008Li`DHaP8Li`0:5:D<H`aS6<HDYA24248<Ha245:D26<H011BU36<<H`aS0QBU00@@Q1BU6<HHaP8@
Q0045:DHaQ2436<248@00`aS248<H`0248@236<25:D0112436<@Q1240QBU0QS60aBU0aS600h<H`Q2
36<@Q1BU48@<H`Q248@<H`Q248@<Ha240PaS00@8@PaS5:DDY@88@P041248@PaS248236<01Q2436<@
Q1BU48@<H`88@P035:DHaQBU008HaP@DY@086<HDYABU6<HLiaBU48@<H`8DY@D@Q08<H`03248<Ha24
008@Q08<H`0948@DYABU48@8@PaS48@<Ha2400<HaP0348@<Ha2400<8@P8<H`0=248<Ha2448@<H`@R
2448@`aS2488@`Q236800PQ300/<Ha245:@DY@aS5:DLj2e[=JdaRb48008HaP068@PLiaS55:DLib48
0QBU00LYBCF];F/Lia245:DHa@0248@00a2548@@Q00248@45:D01a245:DHaQcW6<HDYAcW008Q2004
6<H@Q0aS36<248@0112336<48Q230QBU00D@Q0Q2248HaQcW008Q20087>LDYQS648@<H`@Q248<H`8@
Q00436848PQ2248436<01PQ236<<H`Q236<@Q0<DY@8HaP065:D<H`aR24<<H`Q20Q2400DDYA2436<@
Q1BU0088@P0<5:DQ21S636<8@Q245:D<HacW9BTYBR490QBU0QS60acW00LQ1b489BXU:B489BTLi`02
5:D011245:DDYABU0Q240PQ200<8@`aS36<00PaS00<@Q1BU6<H00aS6000011BU48@DYA240QBU00<H
aQBU36<00Q2400/U:B489BT]Jc6<=Jd]JacW6<HDYAS6008Li`085:D@Q12436<DYAS67>LHaP<@Q004
5:D@Q1BU5:D26<H011BU48@DYABU0QcW00L@Q1BU7>LHaQ2436<@Q0025:D248@00aBU48@<H`0336<0
212436<8@PQ236<@Q0aS48@25:D26<H00a2436<<H`0236<00a2436<<H`0236<01A2436<8@PaS2480
0Q2400D<H`Q212448@Q2008@Q006248000Q236<DY@aS0`Q20`aS0Q2400HHaQBU48@<H`Q236<26<H0
0aBU36<<H`0236<011245:DHaQ240PaS112400H<H`Q2248<Ha245:D236<00`Q236<@Q0025:D336<2
48@236<01@Q2124<H`aS48@00`aS00@@Q1BU48@DY08DY@035:HDY0aT008<H`8@Q00436<48@@Q48<2
6<H03PaS248@PaBU48@@QABU7>LQ21cW9BPQ2AcW6<H25:D00aS65:D@Q00248@236<010Q236<<H`aS
0Q2400D@QA245:DHaQBU00<<H`0G6<HDYAcW7>LU:C6<=JdmkcW>@Q16<Cg_=JdQ2B487>LDYABT36<<
I0aS248@Q0025:D00a2436<<H`0436<011245:@@QABU0Q240PaS00<@Q0aS24800P@Q0Q2400<<H`Q2
24800P@Q0`aS00`8@@Q248@DY@aT368<I1S548D<H`aR24<224801@aT48<@QABU48@00PaS00D8@PaS
48@DY0aT008<H`<@Q0055:DHaABU5:D@Q00336<01A246<HHaQS65:D00QcW00@YBRDY8@PU:@<Q2006
6<H<H`aS36<@Q0aR0Q2400HDYA245:@@Q1BV5:D16<H0000=5:DHaQBU6<HLiaBU48@<HaBU8@PLib48
:DX00Re[00/U:Be[<H`U:AcW5:DHaR487>LDYA24008DY@036<HDYABU008DY@036<HDYA24008@Q08D
Y@8HaP077>LHaQ2436<@Q1S67>L01ABU00@@Q0aS5:DDY@8@Q08<H`8@Q088@P8<H`0>248@Q1BU7>L<
H`Q248@LiaS636<48@aS5:D@Q08<H`0348@<H`aS008<H`04248<H`aS36<324803`aS48@8@PQ236<D
Y@aS248<Ha2436<8@P@Q248@Q0035:D248@02QBU36<@Q1BU7>LDY@aS248<HacW0QS600@DY@aS48@@
Q08<H`8@Q08HaP065:D@Q0aS48@DYA240`aS0QBU00<<H`Q224800PaS0PQ200H<Ha242488@QBU6<H2
5:D010Q236<@Q1BU0QcW00`DY12424<<HQ255:@DYA2436<8@Q2424<224800`aS5:@DY@0348@031cV
8@TQ1acW7>PU:1cW48@DYAS68@PLi`8@Q00536<8@PaS36<<I00248@01`aS48@@Q12436@DY124008<
H`0?48<DYQcV7>PQ22DY=JdmkdHa=JdmkdYBAS4icQcW008HaP055:D@Q12436<@P`0248@03A2548@@
Q0aS48@<H`Q236<@Q1BV5:D@PaBU008HaP0448@<H`aS248212401@Q25:D@Q0Q324800`aS0`Q200T<
Ha2436<@Pa245:D@Q0aT48<00Q2400T<Ha245:D@P`Q3368@Q1BU48D00PaS00@@Q12548@@P`8<H`04
48@DY@aS48@26<H011BV5:@@Q1S61ABU00DHaAcX8@PU:RDX00<Q20057>LDYABU5:D@Q00236<01ABU
48@<H`Q348@00QS60AS50A240A2400025:D011S65:D<HaBU0QcW00@DY@Q25:DLi`8HaP<DY@046<HD
YAS648@336<00a245:DDY@025:D0112436<DYAS60QBU00H<Ha245:DDYAS65:D348@02`aS48@@Q124
5:DHaQBU6<H<H`Q248@00QBU0PaS00@8@PaS5:D@Q08<H`03248<H`aS008<H`@@Q08DY@0448@<H`Q2
36<248@01aBU48@8@PQ236<8@PaS008@Q00636<8@PaS248<Ha2410aS00<DYA245:D00QBU00DHaQ24
36<@Q0Q2008<H`0548@DYAS65:D@Q00336<00a2436<DY@0248@011BU48@DY@aS0PQ200h<HaBU36<4
8@aS5:D@Q0Q236<@Q1BU36<8@PaS0aBU00DHaQ246<HLiaBU008<H`8@Q0<8@P8@Q08<H`095:D@Q0aS
6<HLj2485:D<Ha2400<DY@@<H`0524848@Q22488@`02248010aS5:D<H`aS0QBU00H@Q0aS36<DYABV
5:D236<00`Q336<<H`0236<010Q22448@PaR0PaS00<<HPQ336<010aS00D48PaS36<DYAS5008DY@03
6<HLiacW00@Li`<Q208Li`056<HLiaS65:HHaP027>L01AS648@@P`aS24800PaS00<DY12448@010aS
00D@Q1BU48@<I12300H@Q0045:@DYQBT36<2248010aS48@DY@aT0PaS00@DY0aS248<H`8@Q0083688
@PaT36<8@PQ1124<H`8@Q00548<<I12448@DY@036<H011BU6<HHaaBT0`aS11240QBU00LHaQS56<DH
ab489BTYBP02<H`02BU:8@PDYAS548D@Q0aT48@DY00348@25:D16<H000035:DLiaS6008DY@8<H`06
5:D@Q1S65:DHaQBU0Q240QS60aBU00@@Q1BU36<8@P8<H`0348@DYABU008@Q0035:DHaQS6008<H`8D
Y@0448@<H`aS5:D648@00aS65:DDY@0248@336<348@45:D01a245:D<H`aS24848@aS008@Q08<H`03
48@DY@aS00848@0336<DYAS6008@Q00336<8@Q24008@Q00336<8@PaS00<<H`03248<Ha24008@Q0<D
Y@0648@DYABU5:DHaQ240PaS00LDYA2436<8@PaS6<HDY@0436<01Q245:DHaQBU48@<H`8DY@88@P03
36<DYA240088@P0336<DYA24008<H`03248@Q0aS00<<H`085:D@Q12448@DYAS648@8@P8<H`03248<
H`aS00@<H`0348@DYA2400@HaP0348@<Ha2400<DY@0336<8@PQ2008<H`0348<<H`Q200<<H`<DY@03
48D@Q124008DY@0348@DY1BU008@Q003248<H`Q200848@03248@Q0Q30088@P0>36<DY@aS36<@Q0aS
24848@aR48@<I12324<@Q08Li`058@PLiaS67>LQ1`038@P01acW36<<I0aS6<HQ21S600<Li`077>H@
Q@aS368<I1BU36<00PQ202P<Ha2436<@Q0aS5:DDYQBU48<8@a245:D8@PQ1248<HaS65:D<I0aS1240
00Q336<DYAS548@<I0aS24<<H`Q236<@Q12548@<HP@R248@Q08<H`075:DLiaBU36<8@Q246<H00QBU
01<Lib477>LDYA2448D@Q1BU36<8@Q245:DHaaS66<DDYQcW8@LU:@02:DX2;F/02BDY7>LHaQS75:@<
H`aR36<DYP025:D00a245:DLi`017>L000096<HU:BDY7>LDYA246<HLiaS600<DY@8@Q08HaP037>LH
aQS6008@Q0055:DHaQBU5:D@Q0025:D00aS68@PDY@0336<01ABU48@@Q0aS48@00PaS00<@Q1BU6<H0
0Q2400X8@PaS5:DLiaS648@8@PaS5:D@Q0<DY@8@Q08<H`<@Q0D<H`0348@<H`aS00@<H`03248<Ha24
008@Q00336<8@PaS00H<H`04248<Ha2448@436<25:D336<00aBU6<H@Q00436<0112436<<Ha240`aS
00@@Q1BU6<H@Q0D<H`88@P<@Q00436<48@Q236<248@236<03ABU7>LDYAS636<HaS6<@Q16<BU:6<HQ
21cW00<HaP0648@<H`Q2124@Q0aS0Q2400D<H`Q2248<Ha24008DY@0436<8@PQ236<25:D01`aS24<<
HPaS48@8@`@Q0088@P0748@<H`Q236<@Q1BT6<H00aBU00X@Q1BU48@<H`Q22448@a2348@<I0<8@P03
36@DYA24008@Q00848<@Q0Q31248@@Q35:D@Q0<<H`085:DHaQcW6<H<H`Q35:DLi`8YBP038@PLiacV
008DY@046<HDYAS66<D35:D01a255:DHaQS65:D@Q1BU00<HaP0>5:DHaQS66<DDYQBU7>LU:2DY8@TL
iaBU36<@Q08DY@88@P0336<DY0aT008<H`0<36@<HPQ248<@Q1BU3688@a2336<8@PQ110Q200<<HPaT
36<010aS00/DYAS66<HLiaS69BT]JbU:7>L@Q0aS00<@Q08<H`8@Q0036<HHaacW008Li`068@PU:BU:
:DX]JbeZ0RU:00<Lj1cW6<D00QS60Q240ABU0AcW00000aS68@PLi`026<H35:D03`aS48@DYAS65:D@
Q0aS48@DYAS65:DHaQBU6<HDY@0236<01a246<HDYAS65:DHaQBU00@@Q00836<DYAS67>LDYA2436<@
Q0<<H`8@Q0055:D@Q0aS48@<H`0648@010aS48@@Q0aS0PQ200<<HaBU36<010aS0PQ210aS00<8@Q24
5:D00Q2400<8@PaS36<00QBU00D<H`Q2248DYA2400848@06248<H`aS36<8@PaS0Q240`aS0a240`Q2
0PaS0PQ200<<HaBU48@01PaS0Q2400@<H`Q2248@Q0D<H`8@Q00436<DYAcW6<H248@01AcW=Je243W>
<H`00b4800HHaPaS36<DYAS648@3248248@01PaS248<H`aS5:D@Q08<H`0448<DYQS548@2248236<0
10Q348<@Q0Q20P@Q00D<HaBU48@<H`Q2008@Q0046<HLiaS648@236<248@010aS3688@`aS0P@Q00<8
@PaS5:@00a2400D<H`Q224848@Q2008<H`<8@P8@Q00?5:DHaQS55:DDYQ2336<DYAcW:DXYBAcX7>LH
aQBU00<HaP055:D@QA2448@DY@036<H02A245:DHaQ2436<DYAS68@PLi`025:D05AS65:DHaQcW8@PH
aQS548DDYQBT36<@Q1BU48@8@`Q2368<H`Q2124<H`025:D01A231288@PaR24<010aS01D8@`Q22488
@PaS36@@PaS67>L@Q0Q236<DYBU;:DXLibDX7>LDYA242480112400DDYA245:D@QABT008Li`8U:@03
:DXU:B49008YBP059BTU:1cW6<HDYP025:D00`aS48@DY@016<H000057>LQ22488@PLi`0248@25:D2
6<H00aBU48@DY@0236<01A2436<DYA246<H00QcW00@HaQBU6<HHaP<Li`036<H@Q0aS00@@Q00?36<8
@Q246<HLiaBU36<@Q1BU6<HDY@aS248<HaBU008@Q08<H`8@Q08DY@066<HDYABU5:D@Q1BU112400L<
Ha245:DHaQBU36<8@P0236<00a2436<<H`0236<248@00aBU36<<H`0236<01Q2436<8@PQ21248@P<<
H`0348@DYA24008@Q00436<@Q1BU6<H35:D00a2436<8@P0236<00a2436<<H`0236<01A246<HDYABU
36<00PQ200<<H`Q212400P@Q0PQ20Q2400<DYA245:D00acW00@DY@aS5:D@Q08Li`098@PicTYB?Nl]
JacW:DX]Jb4800<DY@0=48@DY@Q2248<Ha2436<8@P@Q248HaQBU6<H01aBU010@P`aS48@<Ha2436<8
@QBU:DXe[C6<8@PLibDY8@PHaP8@Q00324<<HPQ300<8@P033688@PaS008<H`0D248<H`Q2124DYAcW
6<H@P`@R48<HaQBU36<@Q1S68@PLj1cW6<H@Q08DY@0=6<HHaaS66<HQ22DY7>LHaQBU6<HLiacV48@0
0PQ200<<Ha2436<00`aS00@@Q1BT5:HHaP8DY@057>LQ22DY:DXU:@02:DX01RU99BXYBRU98@TQ1`8L
i`046<HHaA2448@336<010Q224<8@PQ30PaS0PQ210aS00H8@P@Q248<Ha2448<324804A2436<DYAS6
6<D@Q1BU7>LU:AcW5:D@Q1BU48@<Ha245:D00QcW00DDY0aT36<<HaBU008@Q0055:DLibDX8@P]J`02
<H`01Re[9BTU:BDY8@PU:@8HaP0000DLib48:DXQ21BU008@Q08HaP065:D<H`aS36<DY@aS0PQ200@D
YAcW6<HHaP8Li`<HaP057>LHaQBU36<@Q0035:D01A2436<<H`aS12400Q240QcW00<DY@aS36<00a24
0`aS00/DYA2448@@Q1BU48@DYAS67>LHaQBU008<H`@DY@88@P0836<48@Q236<@Q1S648@<H`88@P@<
H`0348@<H`aS008<H`<@Q00336<8@PaS008<H`08248<HaBU7>LHaQ24248<H`8HaP035:D<H`Q2008D
Y@0436<8@PQ25:D336<00a245:D<H`0248@236<3248236<00`Q236<<H`0236<00`Q248@HaP029BT2
5:D01@aS48@LiacW8@P00RDY00DmkdHa?NlYBQBU008Q20047>L@Q0Q248@236<01a2436<<H`Q236<@
Q1BU008<H`035:DHaQBU008<H`0@6<DDYQS524<48PaS48@DY@Q336<DYBDY:DX]JbU:8@P37>L02AS6
5:DHa@Q2004000Q148@<H`0224802PaS48@@Q12436@<HPQ236<DYA240`Q200H@QABU6<HDYAS55:D2
6<H25:D01aS67>LDYAS68@PU:AcW008HaP087>LHaQS536@<Ha2436<@Q0<<H`0648@<H`aS36<@QAS5
0QS601@DYAcW8@P]Jc6;:D/]JbU98@TU:2DZ:DXQ21BV5:@DYQBU6<H<H`@Q0PQ200<@Q0aT36800PQ2
0`aS0PQ20`aS00<8@PaS36<00PaS00h8@PaS36<<HaS67>LHaQ2436<DYAcW7>PLiaS50aBU0aS600@D
YA255:DDY@8@Q0075:HHaQ2448@HaRU:;F/00bU:0Re[0RU:00@U:B487>LLi`4HaP0000DLibU:;F/]
JbU:008Li`8DY@0448@<Ha2448@26<H25:D01aS68@PLibDY:DXQ21cW008HaP037>LHaQBU008DY@8H
aP075:D@Q1BU6<HLiaS648@00QS600HDY@aS48@HaQ2436<2248011245:DDYABU0Q2400LDYB48:DXU
:AcW6<HLi`02:DX27>L348@25:D00`aS2488@P0348@236<011245:DDYAS60QBU0a2400HDYA246<H@
Q1BU48@224800`@Q248<H`0336<00a246<HLi`025:D248@011BU6<HDYA240PaS0Q2400@DYB488@PL
i`8DY@036<HLia24008@Q0075:D<H`aS48@HaQBU48@01`aS0Q240PQ200@48@aS48@DY@@Li`8Q2008
>Lhe[DYBIcUF]Cg_8@P48@<8@P8<H`88@P8<H`065:D<H`aT6<DHaaS50Q2400LDY12448@DYAS57>LH
aP027>L021S65:DDYQBT5:D@Q1BU36<2248336<2248236<02Q2436<<H`aS48<8@`Q236<@QABU0PaS
00XDYAS65:D@P`aS48DHaQBU6<HDY@@Q20056<HDYABU5:DHaP0248@02QBU6<HYBRU:7>LDY@aS6<DH
aPaS0PQ200l@Q0aS2488@Q2436<8@PaS48@LiaS79BPYBRDZ8@P00RDY00d]JcW>=JdicSF]<H`]JbDY
:DXLiaBU48@<H`0248@00aBT48D<H`025:D00aS648@<H`0248@324801Q2436<8@P@Q248<H`8@Q005
36<8@a235:HHa@036<H02Q255:DDYABU7>LQ22DY8@PDYA230Q2400@HaQS55:HHaP8Li`065:HLib49
;F/YBRe[0S6<00<]JbU:9BT00B4800001acW9BTYBS6<:DXLib4800@@Q08DY@8@Q00;6<HDYABU6<HL
ibDY;F/LiaS648@Li`029BT01acW6<HDYAS67>LHaQ24008DY@057>L@Q1245:DHaP025:D436<01124
5:DDYA240PaS00HDYAS68@PU:B487>L36<H01R489BTLiaS6248<H`<DY@0348@<Ha24008@Q08<H`8@
Q08DY@036<HDYA24008DY@076<H@Q0aS36<DYA2436<00PQ20PaS00@@Q0aS36<<H`8@Q08DY@036<HD
YA2400@DY@8<H`0448@HaQcW7>L26<H25:D00a245:DDY@025:D548@25:D248@01PaS48@@Q12436<8
@P<<H`0648@DYABU6<HLibDY0R4800d]Jc6<?NlicTHaIcUJeRe[36<001245:D<H`0224800`aS48@@
Q00236<00a245:D@Q00248@00aBV5:D@Q0025:D00acW5:DHaP028@P01BDY6<H@Q1245:D00QS60PaS
018@Q0aS2488@P@Q36<@Q12524848@@R48<@Q@aS48<@Q12336<224803a245:DLiaS55:D@QAS56<HL
iaS65:DLibDY8@PHaP0236<00aBU48DDY00236<021cW9BXU:1BU48@HaABV48@324800`@Q248<H`02
48@224801PaS5:DHaR489BTQ208U:@8Li`03:DXe[3g_008icP05?NlaS2e[7>LHaP035:D224801PaS
5:DDYA2436<@Q@8DY@0348@<H`aS008<H`05248<H`aS36<8@`0224800`aS48@DY@045:D04aS65:HH
aQ2336<DYB48:DXQ21BU6<HDYA255:D@Q1BU6<HLiaS6008DY@076<DYBRe[<H`]JbDY;F/00S6<0BDY
0AcW0AcW00000aS67>LLi`026<H022DY:DXaS2e[8@PU:B486<H25:D01acW6<H<Ha247>LQ21cW008@
Q0036<HDYAcW00<Li`038@PLiaS6008DY@066<HLiacW5:D@Q1cW0R4800PHaPaS36<<Ha245:D@Q0Q2
0`aS00<@Q1BU6<H00aBU0aS600@DYA245:D@Q08HaP045:DHaQBU48@25:D27>L01AS636<<Ha2436<0
0Q2400DDYA2436<<Ha2400<<H`04248<H`aS248236<324802PaS1248@PQ236<HaQ246<HDY@aS0`Q2
00@@Q0aS48@<H`<DY@0:48@<H`aS5:D@Q0aS48@DYAcW6<H248@01AS648@<H`aS24800PaS00<@Q0Q2
24800PQ200<48@Q224800PaS00H8@Q245:DHaQ245:D27>L011S65:DDYBDY0SF]00<YBQS636<00Q24
0PaS00@@Q1BU6<HDY@8HaP8<H`0536@DYAcV6<H@Q@0236<00a245:DDY@025:D011S67>LLiaBU0PaS
00D@Q12536<<Ha24008<H`032488@a23008@Q00748<<I12348@<H`Q224<00QBU00D@Q0aS36<@Q1BU
008HaP055:DLiacW8@PU:@038@P02be[9BPDYQ245:@HaQ2436<<I1BT6<H00QBU00<DYQBU48@00PaS
0Q2400DDYA2324<<HPaS00<8@P0536<@Q12448@DY@0248@00aBT48@<I0025:D02QS65:DDYAS68@PL
ibDY;F/aS2e[0bU:00HQ21S67>LQ1b487>L35:D448@236<02A245:@@Q0Q25:DHaR487>LDY@037>L0
1AS548D@Q0aS48@00QBU00TQ22DY<H/aS2DY7>LHaQBU6<H00QBU00@HaQcW7>LHaP8DY@8Q2004:DXU
:BU:;F/1:DX000036<HLiacW008Li`079BTYBRe[;F/YBRDY7>L00Q2400<DYAS66<H00aBU0acW00<H
aQBU6<H00QS600LQ21cW7>LHaQ245:DHaP027>L00aBU6<HHaP036<H45:D336<03aBU48@<H`aS48@D
YAS65:D@Q1S68@PLia24248<H`035:D011245:DDYAS60aBU00D@Q1BU48@DYA24008<H`0548@DYABU
6<HDY@0248@4248248@010aS24848@Q20`aS00<8@PaS36<00QBU00D@Q0aS48@<H`Q2008<H`0948@D
YABU36<8@PaS5:DHaQ24008DY@037>LHaQBU008HaP0736<@Q1BU6<HLiaBU12400PQ200<48@Q236<0
0PaS00H8@PaS36<8@PaS124236<031246<HDYAS67>LHaPQ25:DU:CW>=JdU:@8@Q004248@Q1BU48@2
36<248@25:D0112436<<HaS50QS600<@Q0aR36<00aBU00L<HaBT7>LYBQcW5:D<H`0248@030aS48@@
Q1BU48@<HPQ3368<Ha255:@@Q08<H`0524<<H`aS248@Q0025:D00a24248<H`025:D01aBV7>HLj248
8@TQ1acW008Q2007:DXU:B488@PLiaBU5:H011BU00<@QABU5:D00aBU00<@Q0aS36<00QBU00<@Q0Q2
24800PaS0PQ200@<HaBU6<HDY@<<H`0348DDYA23008<H`8DY@8Li`058@PU:BU::DX]J`02:DX012DY
:DXQ22480QcW0QS600HDYAS65:HDY12436<248@04@aS48<@Q@aS248<HaS69BTLiaBU7>LQ21S65:@D
YAS65:D00a2400XQ22U:;F/]JacW6<D@QA235:DHaP8Li`096<H@Q1BU7>LQ22DY8@PU:BU:008]J`4U
:@0000@LiaS66<HHaP8DY@<HaP047>LQ22e[<H`2=Jd01c6<:DXU:AS65:DLib48008YBP048@PLiacW
6<H37>L01QBU6<HDYA247>LQ208YBP0;8@PLibU:<H`mkcF];F/Q22U:8@PHaP035:D336<348@03ABU
6<HHaQBU6<HLiaS636<@Q1S69BTQ21S600<DY@077>LHaQBU48@HaQBU48@00QBU0aS60QBU0PaS00D@
Q1BU5:D@Q0@Q0088@P8<H`88@P<<H`88@P0748@LiacW6<HDY@Q236<00Q2400<DYA2436<010aS00L@
Q1BU5:D@Q1BU6<H@Q00236<01ABU7>LHaQ2436<00`Q210aS00X8@P@Q248<HaBU6<H@Q0aS5:D@Q0<<
H`8@Q00;7>LU:Be[>LhaS2U:8@PDYA2436<8@P0236<248@011S67>LLiaBU0PaS00@DYAcW5:H@Q08<
H`8@Q00336<8@`aS008@Q00348D@Q124008@Q0035:@DYA24008@Q00348D@Q0aR0088@P0536<8@`aR
36<8@P0336<248@236<00aBU5:H@P`0336<00aS67>HQ20037>L02RU:;F/U:R475:DHaR486<D@Q0aS
0QBU0PaS00L@Q1S55:D@Q0aS36@@Q0027>L03QBU36<8@a2348@DYA2436<8@PaS48@DYABT48@436<2
48@436<248@02AS65:DHaR48;F/YBR488@T]J`02AS401DicDYA:DDHa>Lh00Re[00@Q21cX5:DDY@8<
H`8@P`046<LLib487>L26<H051BV36<<H`aS5:DLiaBU48@<HaBV7>LU:2498@LQ2BU::DTQ21cW5:H2
5:D248@25:D011cW9BTYBRU:0B48000012486<HHaPaS0QBU00H@Q1S66<HU:BU:;F/2=Jd00c6<;F/L
i`037>L00b487>LHaP047>L25:D27>L01aS648@@Q1BU8@PU:B48008Li`05:DXe[CW>=JdYBP028@P0
12DY7>LDY@aS1a2411BU00LHaQcW7>LHaQBU6<HLi`028@P01aS648@@Q1BU6<HLiaBU00D<H`0748@D
YAS66<HDYA2424800`aS00<DYA2436<00PQ200H<H`Q224848@Q248@236<0212436<HaR486<H@Q0Q2
36<448@01QBU36<<Ha245:DHaP8DY@096<H@Q0aS48@DYAcW6<H@Q0@Q0088@P0548@DY@aS36<@Q002
36<2248236<248@25:D236<55:D28@P01BU:<H`YBRDY7>L00a2400DDY@aS248<HaBU008Li`DHaP@@
Q00336<8@`Q2008<H`09248<H`aS36<@Q0aS5:DHaQ25008<H`8@Q0043688@PQ336<2248236<248@0
6`Q21248@PaS48@<Ha245:DHaQ2536<DYAcW6<H@Q1BU7>LYBbU:8@PYBRDX5:HDYAS67>LHaP0436<0
10Q2368<I1BU0QS600/@Q1BT5:DHaQBU48@<HaBU36@<H`Q200@<H`0448@<I0aS48@236<00a246<H@
Q00224800a246<HDY@025:D01acW9BPU:R487>LQ22U9008icP=6<@09BU924Cg_=JdYBR485:D@Q1BU
008HaP0@36<@Q1BV8@LHaQBU7>PQ1aBU48@48@aS6<HLiaS65:D236<011S68@PYBRDY0R4800HYBR49
7>HDYAS648@236<01aBU8@PQ22DX:DX]JbU:004U:@0000@Q22U::DXQ208HaP037>LQ2248008Li`0;
8@PYBSW>@Q0mkd8@?Nl]JbDY7>LQ20029BT48@P012DY6<HDYABU0QS60QBU0QS60aBU00@LibDY8@PU
:@8Q20037>LHaQBU00<DY@<@Q0057>LQ22488@PLi`048@P00acW8@PHaP035:D06aS648@<HaBU7>LD
Y@aS48@Lib485:D<Ha245:D<Ha245:DHaQ24248<HaBU48@48@Q236<@Q00224800a245:D<H`022480
2@aS5:DDYABU6<H@Q1BU48@<H`035:D02A2436<<H`aS48@<Ha245:D<H`0224801P0036<HaR486<H<
H`88@P0836<8@PQ236<8@PaS24848@88@P0448@DYA245:D248@336<0212436<@Q1247>LU:BU:9BT2
8@P00bDY8@PLi`025:D348@336<00a2436<<H`0236<00aBU6<HLi`037>L00aS55:D@Q00236<010Q2
48@DYAS60R4800@LiaS636<8@P8<H`0336@@P`aS008<H`0448<@Q@aS124224802ABU6<H@Q0Q21248
@QS67>HHaP035:D01AS67>LLiacW8@L00R4800/HaaBT5:DDYAcW5:D<I0aS48@DY0aT008<H`<8@P03
36<@Q124008@Q00536<DYABU48@<H`0224802Q256<DHaQBV48<<Ha245:DHaQ240PQ200@@Q1BU48@<
H`8@Q00936<@Q0aS5:DDY1BU7>LQ22U:008Q200A:DX]Jbe[=J`e[D8@BU9BU5JeCW<mkcF]9BTYBR49
8@LHa`027>L021S65:D@Q1245:D@Q1S65:D248@040aS48<@QABT48D@Q1BU6<DLibDX9BXQ22477>LQ
21cW0aBU00@HaQBV6<HLi`4Q200000@Lib488@PQ208Li`<Q20089BTLibU:<H`mkdicAS4aS08Q2003
:DX]JbDY008Li`0>8@PHaQcW6<HLiaS65:DLib486<HDYA246<HLi`8@Q0066<HU:BU:8@PU:B480QcW
0aBU00DHaQ24248<HaBU008Q20057>LQ22487>LHaP037>L26<H27>L011S65:DDYABU0Q2400H<H`Q2
6<HQ21cW48@224800aS65:DDY@0248@636<02`Q248@<H`Q236<DYAS648@8@P0024800Q2400LHaQcW
6<H@Q0aS48@HaP0248@00`aS48@<H`025:D248@01AS648@8@P@Q36<00QS60Q2400HDY@Q22488@Q24
36<2248011245:D<H`Q210aS0a240`aS00L8@P@Q48@HaR489BTQ2002:DX012DY6<H@Q1240aBU00<@
Q0aS48@00QBU00L<H`Q2248<Ha246<HDY@026<H03AcW8@PHaQ2436<@PaBV36<<HQBU7>LU:AcW008@
Q088@P0936<@Q12436<8@P@Q248<Ha23008<H`04248@Q1BU48@336<011245:DDYQS50QBU00THaR48
7>L@Q1S6:DX]JbDY5:D00QS600HHaABU48@@Q12336@336<00`Q12488@P0336<25:D348@0112548<8
@PQ20PaS00P8@PQ348<DYQBT48@<Ha240`aS018@Q1BU6<H@Q0aS248480Q35:DLiaBU36<DY1cX;F/Y
BR498@P2:DX02SW?@Q1:DTYBAS5>LTYC>LhaS1cW124800@LiaS66<HLi`8@Q0045:DHaQS65:D236<0
3a2436<DYAS67>LLiQBV6<HLibe[:DXQ21S636<@Q0026<H27>L011BU36<<HacW0BU700001R489BTQ
22DY8@PLi`8HaP077>LQ21cW7>LU:Be[=Jd00Re[00TaS2DY:DXLiaS68@PYBS6<;F/00RU:00@aS2U:
7>LHaP8Li`<DY@@HaP075:DHaQcW6<HDY@aS48@00QBU0QS600DLiaS65:DHaQcW008DY@056<HLibDY
8@PHaP025:D011S68@PQ21BU0Q2400<<HaBU5:D00aBU0QcW0RU:00DQ21cW5:DHaQcW00<DY@8HaP05
5:D@Q12448@<H`045:D011245:DLiaS60QBU00<HaQcW7>L00aS600<LiaBU5:D00QBU00<HaQcW7>L0
0QcW0aS600/Q21S648@<Ha245:D@Q0aS248<Ha24008<H`0>5:D@Q0aS6<HLibDY7>LDY@aS5:DLiaS6
5:D@Q088@P0736<@Q1BU36<DYAS68@P00RU:00@HaQBU48@DY@8HaP035:D<H`aS008HaP0I36<8@PQ2
5:D@Q0Q248@DYA24124DYBU:;F/Li`Q224<HaA255:@@QABU7>LQ1aS76<H010Q20Q2400H@Q@aS36<8
@PaS48@236<224802`aS5:D@Q1245:@DYQBT48@<Ha2348D00Q240QBU00@@Q1BU6<HHaP8DY@0;48@D
YQS55:DDYQS548@<H`Q248@<I00212400`Q25:DDY@0436<03PaR24<<Ha245:D@Q0aS368@QAS648@8
@P@Q128224800`aS48@<H`0336<00a2436@@P`025:D031BV5:D@Q0aS5:DLibe[<H/YBRDY7>LHaP8Q
200@:DXQ2BDX:DX]Jc6<<H/]K36<>LdmkcW>>Ld]JbU:9BT28@P06aS65:D@Q1BU48@DYA245:@@Q0Q3
36<DYAcW5:D<HaBU6<LQ21BU6<DLj2477>LDYAS67>LDY@0148@000047>LYBRU:8@P25:D00acW9BTL
i`027>L2:DX012e[<H`e[C6<0bU:0b4800<U:Be[<H`00Re[00<YBR487>L01ABU0QS60aBU00<LiaS6
5:D00Q240`aS00T@Q1cW8@PQ21cW5:DHaR486<H00QBU0QcW0aBU0R4800DLiaBU36<@Q1S60088@P03
36<DYAS6008DY@036<HLiacW008Q20037>LHaQBU008<H`03248<HaBU008DY@0348@8@PaS008<H`0<
48@<HaBU5:DHaQBU48@HaQcW8@PLiaS60aBU00DHaPaS5:D@Q1S6008Li`058@PLiacW7>LHaP025:D4
48@324802`aS48@<Ha246<HDY@Q236<LibU:6<H00PQ20QBU00<@Q1BU48@00Q2400/<H`Q236<@Q1cW
8@PU:BU:8@PLiaS6008@Q08DY@046<HDYA245:D348@236<2248236<248@02QcW;F/Q20Q2000<Hb48
7>L@QAS50R4800@DYABT5:D<HP<48@0:5:D@P`aS36@<H`Q21248@PaS48@336<00a246<H@Q0022480
2PaS5:HLiaS65:@<H`aT48@LiaS611BU0QS600@@Q0aS36<@Q0H<H`05248<HaBT5:H@Q00236<01A24
36<8@PaR36<00Q2400D<H`Q248@@Pa24008<H`0>24<<HPaS248@Q1BU36<8@P@R248DYABT5:HDY@8<
H`0448<@QABU:DX2;F/03BU:7>LQ1acW6<HQ1b49:DXYBBDZ<H/aS3F]00<aS005<Hde[CF]=Jd]J`02
8@P37>L00aS648@@Q@0236<01A24248<I1BT5:D00Q2400@<Ha245:DDY@8Li`087>PLiacW5:HDYAS6
5:DHaP4DY@0000DQ22U:=JdmkcW>008aS08YBP049BTQ22DY8@P39BT022U:;F/YBR487>LQ22DY8@P3
:DX29BT02CW>@Q0e[BU:7>LQ22DY7>LHaP025:D27>L01ABU36<HaR487>L00PaS00@@Q1S65:DDY@8L
i`0348@8@QBU008Q20036<HDYABU00<DY@8HaP035:D@Q0aS00<<H`046<HLiaBU5:D236<011cW9BTa
S3F]0Re[00PU:AcW6<HLib486<HDYA240QS600<@Q0Q236<00PaS00<@Q0Q236<00PaS0Q2400@<Ha24
48@@Q0<DY@0:6<HDYA2436<DYAS69BTQ21cW8@P448@00aBU48@<H`0424800`aS248@Q00236<32482
36<248@236<011245:DDYABU0PaS0aBU00<<Ha245:D00a2400DDYAS66<HDYAS6008@Q08DY@036<HD
YABU00<@Q0085:D@Q0aS36<8@Q235:D@Q0<<H`075:D@Q12348DHaAS76<H00QBU00d@QA2436<@Q0aS
24<<HPQ236<@Q0aS5:D@Q@025:D020aS48@<H`Q236<@Q12548<2248020Q348@@Q1BT5:D@QAS56<H2
5:D248@01PaS48@DYQS55:H@Q0<<H`0@248@Q1BU6<HLiaBU48<<I12348D@Q0aS2488@a2336<248@2
5:D01ABV5:D@Q12336@00`aS00D@Q0aS248<HPaT008@Q0@<H`0336@@Q123008@Q0035:D@QAS600<L
i`035:HHaAS6008HaP035:HDYAcW008Q200>7>LHaQcW;F/e[CF^>LdaSCF/=JhaS2e[7>LHaP@@Q003
48<<I0aS008@Q00<36<8@a235:DHaQBT5:DHaQcX8@PHaQBT0QBU0AcW00001BDY<H`e[CW>=Jd00Re[
0bU:0RDY00DQ22U::DXYBRe[008YBP0@9BTLiaS68@PYBRe[8@PLibU:>Li243F]<H`]JbDY8@P27>L3
6<H03ABU6<HDYAS67>LHaQ24248@Q1S67>LDYA24008HaP0348@<Ha24008HaP055:DHaQS67>LHaP03
5:D00aS65:DDY@0236<35:D224801Q246<HYBR48:DXaS08]J`079BTHaQcW7>LQ21cW5:D00PaS0PQ2
00L<Ha245:D@Q0Q236<@Q00224801a246<HHaQ2436<DYAS600<DY@046<H@Q1247>L29BT01AS65:DD
YABU48@00PaS00<@Q0aS24800PaS0`@Q00H<HaBU5:D<H`@Q24825:D00`aS1248@P035:D00a245:DD
Y@0248@00`aS48@@Q0035:D0112436<<Ha240QcW00DHaQBU36<@Q1S6008DY@@@Q00:5:D@Q0aS48@8
@P@R48@DYAS65:D2248248@01ABU48@<I1BT5:D00QcW00T<H`Q2248DYAcW48@48PQ148@011BU00<@
Q0aS24801@aS00`@Q0Q348<@Q1S636<48@Q26<DQ21S65:D26<H248@01aBU6<HDY@aT48<@QA24008<
H`0348@DYAS6008HaP0<5:HHaQS66<HHa@aS24848PQ236<@Q1S60QcW00HHaPaS36<@Q0aT48<248@0
0`aS1248@P0236<01@aR2488@a2448<00Q2400TDYA2436@<Ha247>HLib487>L00QBU00<HaQBU6<H0
11S600@Q1acX9BPQ208YBP03;F`aS3F]008e[@05<H`]JbDY8@PDY@0348@00aBU48@<H`0224803@aS
5:@@Q0aS36@@Q1S55:HHaQS55:DHaAS6008Li`8HaP0000/aS2U:9BTicSg_BU9>LcF]<H`YBRDY008]
J`0K<H`e[CW>:DXLibDY>Li6<C6<:DXaS3F];F/U:B48:DXQ21cW8@PU:AcW5:DHaRDY;F/YBQcW008Q
200:6<H@Q0aS48@DYAcW5:D<H`Q236<25:D248@26<H25:D0212436<<Hb48:DX]Jb485:D26<H00aBU
48@<H`0348@00aBU48@DY@035:D01acW8@PYBRe[:DXU:B48008YBP059BTLi`aS48@DY@026<H01aBU
36<8@PaS48@DYA2400<8@P<<H`8@Q0065:D@Q0aS36<8@Q2410aS00<DYAS66<H00PaS00<@Q1BU5:D0
0PaS0`Q20Q240QS600H<H`Q22488@Q2436<224801Q245:DHaQBU248<H`8@Q00336<8@PQ2008@Q0@D
Y@@@Q0095:D<H`Q2248DYAS65:D<H`Q200<@Q0065:D<H`aS36<<HPQ20PaS00@@Q0aS248<H`8@Q006
48<<I12448D<Ha231a2400DDYA2448@@Q1BT008DY@0548@<H`Q236<@Q00236<010aR24<@Q1240aBU
00<@Q@aS36@00a240PaS01<@Q1S66<HHaA255:@HaABU7>LYBRDY8@P@Q0aS48@<HaBU7>LHa`028@P0
1A2436848@Q25:D00`aS00DDYAS66<HLiQS6008Li`035:D@Q0aS008@Q00324848PaR008DY@0648@<
H`aS48<@Q1BU0PaS112400D8@Q247>LYBRDY008HaP037>LHaQBV008@Q08HaP048@LHaQS68@P29BT0
1QcW8@PU:B486<HHa@8Li`036<H<I0aR008<H`075:D@Q0aS48@DYAcW6<H00a2400<DYAS65:H00acW
00001RDY>LhicT8@?Nle[@8icP8aS004;F/aS3F]<H`2:DX28@P02CF]?Nm243F]9BT]Jc6<;F/U:@04
8@P36<H01acW:DXU:BDY:DXQ21cW008DY@046<H@Q1245:D348@010aS248@Q1240QBU0Q2400HDYA24
5:DDYA248@P29BT01acW48@DYAS65:D@Q0aS008@Q0096<HDYABU5:DLib487>LQ22U:008]J`<YBP8L
i`8HaP085:D@Q12436<DYAS648@<H`88@P8<H`88@P0536<8@PaS36<@Q0025:D01Q2436<<H`Q236<@
Q08DY@8@Q0055:D@Q12436<@Q0025:D00a24248<H`0236<02Q2436<<Ha2424848@Q25:DHaPaS0PQ2
00@<HaBU48@DY@8@Q08<H`03248<Ha24008HaP0748@<HaBU5:DHaQBU48@00PaS00@@Q0aS48@<H`8@
Q0045:D<Ha245:D248@324800`aS24<<H`0248@00`aT36<8@P0336<00aBT5:D<H`02248011BU7>LL
ia240PaS00L@Q1S67>LDYQBT48D@Q00636<3248021245:DHaQS648@<Ha2348@236<01PQ248@DYABU
6<HDY@8<H`0<48@@QAcW7>LQ22DY7>LDY@aS48@DYAS50QBU00THaABV5:@@Q1BU36<8@P@Q24800PaS
00@@Q1S67>LLj08HaP0S5:D@Q12448<@Q0aS1248@Q245:H<H`Q236<HaQBV36<@PaS648D8@P@R248D
Y1245:DU:Re[9BTHaQBU6<HHaaBT36<<I0025:D012487>PQ22DY0RU:00<U:AcW7>L00aS600LLiaBU
48@<HPQ348@<I00348@36<H02ABU36<@Q1BU36<HaRDX:DXLi`0148@0000@?NlYBS6<;F/YBSW>AS5B
U5Je@Q0icSF]<H`e[C6<:DX3;F/00bU:9BTU:@038@P27>L26<H00aBU48@HaP025:D348@01AS65:DH
aQS67>L00QS60QcW00DHaQBU36<<Ha2400<<H`055:D@Q1BU48@DY@0248@011BU6<HHaQBU0Q2400@D
YAS65:DDY@8@Q0035:DHaQS6008@Q08<H`8@Q0046<HLib487>L26<H02QcW5:DDY@Q2124@Q1S67>LH
aQBU0QcW00P@Q0aS5:DQ21S648@<Ha240QBU00H<H`Q236<DYAS648@336<01Q2436<<H`aS48@DY@8H
aP8<H`03248@Q1BU008<H`05248<Ha245:D<H`0224800`aS48@8@P02248010aS5:DDYABU0`aS00<@
Q1BU36<00PaS00@8@Q24248<H`8DY@0348@<Ha24008@Q00636<8@PaS5:DHaQBU0PaS00D@Q1BU48@<
H`Q200D<H`8@Q00836<<HPaS36<DYA2436<@Q08DY@0A48@DYAS67>LHaQBU36<@Q0aS36@@Q12348D@
Q12336<8@P0236<00`aR36<<H`0248@25:D248@01aBU48@@Q0aT368<I12400<DY@0448@DYA245:@2
6<H021BU48@DYAcW8@PLiaBU48@36<H01a2436<@Q1BU5:H@Q0aS008@Q0@DY@0448@DYABT48@27>L2
:DX021BV48@<HPQ348@DYABT36<2248010aS5:DDYABU0Q2400@DYABT5:D<H`8@Q00836<@PaBV7>LU
:B487>LQ208Li`8HaP0448D@Pa2448<35:D00aS65:DHaP036<H00aS78@PLi`025:D02Q235:HLiQcW
8@PLib48:DTLj1S60PaS00@DYABV7>L<I04<H`000S6<0SF]00TYBSg_CW=F]Dic=Jd]JcF]<H`00SW>
00<aS2DY9BT00bDY0R480acW00DHaQBU48@DYAS6008DY@0336<DYABU008DY@046<HDYABU5:D26<H2
8@P00aBU48@<H`0248@236<248@00aBU48@@Q00248@65:D011S65:DDYABU0Q2400<<Ha2436<00PaS
00<8@QBU5:D00QBU00<HaQcW7>L00QS60aBU00`@Q0aS48@@Q0aS6<HQ21cW5:D<H`Q25:D46<H00aBU
36<@Q00248@224800`aS48@@Q00236<021242488@PaS48@HaQBU48@25:D248@236<2248236<01A24
36<@Q12436<00PQ200<@Q1BU36<00PQ200@<H`Q236<<H`8@Q00336<8@PaS00<<H`0348@DYABU00D@
Q0075:DHaQBU48@8@PaS48@00`aS112400D<Ha2336@<Ha240088@P0536<48PaR36<@Q00436<26<H2
7>L051S65:DDY@aT48<<Ha2336<8@PaR24<<Ha2436848@aS36@DYA2548<2248031246<HHaQ2436<D
YABT36@<HPaS5:D<H`<DY@056<HDYQS67>HDYP025:D011cW8@PQ21BU0a240QBU0a2400<DY1BU5:H0
0QBU0Q240QBU00D@Q0aS48DHaRDY00<Q208DY@0536<<HPaS248@Q@025:D248@01a2336<@Q1256<DD
YA25008DY@8<H`04248<HaS57>L2:DX011cW6<HDYABT0QBU00@DY1255:@<I0@DY@046<HDYABU6<H2
7>L01AS65:DDYABU6<H00QcW00dHaR48:D/U:AS6368@Q1BU36@DY1S57>LDY@0148@00003<H`e[CW>
008mk`0G<H`]JbDY:DXU:B486<HQ22e[<H`]Jb486<HLib487>LDY@aS5:DQ21cW5:D@Q0035:D36<H0
1QBU36<@Q1BU6<HDY@<<H`<HaP8YBP05=Jd]JbDY9BTHaP0348@26<H25:D011S65:D8@Q240QBU0PaS
00XDYAS65:D@Q0aS48@8@PaS48@DY@8HaP075:DHaPaS248@Q1BU7>L00QS600@DYAS66<HDY@<<H`08
6<HDY@aS124<HaS65:DHaP8DY@036<HLiaS6008@Q08HaP0448@8@PQ248@45:D01AS67>LHaQBU36<0
0QBU00<HaQBU5:D00PaS00X@Q1BU5:DDYA2436<@Q0aS248<H`8DY@0948@<Ha246<H@Q0aS1248@Q24
00<DY@06248<H`aS48@DYA240QBU0QS600DDYA245:DDYA24008DY@8HaP0348@<H`aS008<H`8DY@06
36@<H`aS5:@DYQBU0Q2400HDY1BU5:D@QA245:D26<H00aBU48DHaP026<H01ABU5:@@Q12448D00QBU
00<<I0aS48@00QBU00L@Q@aS48@DYA2324<<H`0748@01PaS24<8@PQ236<@Q08DY@0=48@<H`aS48@D
YAS65:DHaAcV5:H@Q12348D00QS600<DYA2548@00`aS00<8@PaS48<00Q2400H<H`Q236<8@Q246<D2
5:D02`Q248@HaQS636@8@PaS6<HDYA2448<00`aS00H8@PaS36@@P`Q3248236<03A2436<8@`aR36@@
Q1BT5:HHaQBU48@HaAcX008YBP077>LDYA2448@DYAS548D00QBU00DDY12436<DYAcV008HaPDLi`08
8@PHaQ245:@DYQS65:D@Q08DY@0336@<H`aS004DY00000H]Jcg_@Q0mkc6<:DX2;F/012487>LHaRU:
0be[00DYBR489BTLiaS6008@Q0045:D@Q1S65:D26<H45:D01aS65:DDYA2436<@Q1BU008@Q08<H`03
6<HLib48008YBP8]J`038@PLiaBU008DY@046<HDYA2448@25:D00aS648@<H`025:D336<348@01PaS
5:DDYA245:D@Q08DY@<@Q00636<DYA246<HLiaS60QBU00<<H`Q25:D00QS60PaS00<@Q1S65:D00Q24
0aBU00@HaQBU7>LLi`8@Q00836<DYAcW48@<Ha247>LHaP8DY@037>LHaQBU008@Q0036<HDYABU008D
Y@8<H`045:DHaQcW6<H236<00`Q236<DY@036<H03Q241248@PaS48@DY@Q248@HaQBU48@8@P@Q48@2
7>L01ABU2488@QBU6<H011BU00@@Q1S66<HHaP8@Q00A36<@Q1245:D@Q0aS48@DYAS65:DDY1245:D@
Q1BV5:DHa@0348@36<H00aS56<HDY@0348@01QBU3688@PQ35:@HaP8DY@0536<DYABU5:D@Q0022482
48@00aBU48@<H`0236<348@01ABT48@@Q0aS36800PaS0Q2400H<Ha2448@DYA2448D25:D00aS65:DD
Y0025:D01AS55:DDY12436@00Q2400LDY0aT36<<H`Q236<<I00248@031BV6<DDY@aS48@HaQS548@4
8PQ236<@Q0<<H`04248<H`aS248248@01A2336<<H`aS48@00`aS00PDY1S77>LHaA24368<I2480RU:
00@Q21BU5:DHaP<@Q0036<DDYQ24008<H`035:D@QAcW008Q20066<HDYABU7>LLj1cW0QS600H@QABT
5:D@Q1BU48@236<148@136<148D000067>LU:BU::DXU:AcW0RDY00<Q21cW6<H011cW00XHaQcW7>LH
aQcW48@<Ha245:DHaP8DY@0548@DYAS66<HLi`026<H00acW5:D@Q00236<00aBU48@DY@0348@01QBU
6<HHaR489BTQ208Li`0:8@PYBRU:8@PU:B486<H@Q0Q236<25:D26<H011BU6<HHaQ240QBU00THaQcW
8@PLiaS65:DHaQcW6<H00QBU00<@Q1S67>L00aS600HDYAS67>LDYA245:D27>L00aBU48@DY@037>L2
5:D248@01PaS48@DY@aS48@DY@8HaP035:DHaQS6008DY@<HaP0;5:D<H`aS48@DYAS65:DHaQBU6<HD
Y@0348@03aBU36<<H`aS5:D<HaBU6<HLiaS648@DYAS67>LHaP035:D46<H01QBU6<HLib487>LDY@8H
aP067>LHaQBU5:DHaQcW0R4800<HaPaS48@00PaS00/DYAS65:D<HPQ248@DYA2436<@Q1BU008@Q08<
H`065:D@Q1BU5:D@Q0aT1@aS00D8@a246<DHaQBU008@Q08DY@045:@DYABU5:D224800`aS5:D<H`02
12400`aS48@<H`0224801`aS48@DYABV48@<I0aS0088@P0336<@Q0aS008<H`8@Q0033688@a24008H
aP035:H@Q0aT008DY@036<HDY@Q300<<H`075:D@Q1245:DHaQ2424800P@Q00@@Q1BT36@8@P8<H`<D
Y@035:HDYA24008<H`0348@HaQS6008DY@<@Q00336<DYABU00DDY@0448DDYABU5:@26<H032DY<H`a
S2U:6<H@Q1BU48@DYA2448D@P`8<H`<DY@036<HDYAS6008HaP045:D<H`aS48@35:D00aS66<D@Q002
36<148@000048@PYBRe[9BT38@P29BT27>L02R487>LQ21cW5:DHaQBU7>LHaQBU0Q240QS60aBU00@L
iaBU5:DHaP8Li`056<H@Q1BU48@<H`0248@25:D248@011BU6<HLib480RDY00TLibDY:DX]JbU:8@PL
iaBU36<00a240QBU0Q2400<DYAS65:D00PaS00<@Q1cW7>L00QBU00<HaQcW8@P00QBU00@8@PaS5:DD
Y@8HaP0>5:DHaQcW6<HDYA2436<Lib489BTHaPaS48@Li`8HaP@DY@0448@8@PaS36<56<H00aBU6<HH
aP036<H236<011246<HLiaS60QBU00<@Q0aS36<00PaS0QBU00@<H`Q236<@Q0@DY@<HaP@DY@036<HD
YABU008Li`<HaP<Li`<DY@8Li`045:D@Q1247>L28@P01AcW48@8@PQ25:D00QcW00D@Q0Q236@@Q125
008@Q08<H`DDY@8<H`0448@DYABT48@224800`aS48@DY@0236<021246<HDY@aS248<HaBU48D336<3
48@01A232488@PQ124800PaS00H@Q0aS36<@QABT48@236<348@236<03A2436<@Q12448D@Q1BT5:HD
Y@aS3688@Q2400<DY@076<HDY0aS36<@Q1BU48<00`aS0Q240`aS0Q2400<<H`Q224800QBU00hHaQS5
48@<Ha2436<8@PaS48@DYA2436<DYA240PaS00<@Q1cW6<H00QBU00`HaAS65:D@QABU7>HLj2U:;F`Y
BR486<L448@03aBU48<<I1235:DHaQBU36<8@Q246<HDYA2436<@Q0035:D01@aS5:DLiaS648@00PQ2
0ABU00002be[:DXU:Be[<H`U:AcW6<HQ22U:8@P00QBU00<HaQBU5:D00Q2400HDYAS65:D<Ha245:D2
7>L00aS67>LQ20027>L26<H01AcW6<HDYAS65:D00PaS00@@Q1S65:DDY@8HaP8DY@047>LQ21cW6<H2
5:D01AcW8@PLiaS67>L011BU0QS600DLib487>LLiaS6008DY@046<HQ22DY7>L35:D011S67>LLiaS6
0QBU0aS600DDYA2436<<Ha2400<<H`045:DHaQBU36<25:D030aS24848@Q236<8@QcW9BTLiaBU248<
H`<DY@8<H`03248<HaBU008@Q0D<H`8@Q0036<H@Q124008DY@036<HDY@aS00<<H`8@Q00;36<@Q124
36<DYA245:DU:C6<@Q0mk`02=Jd2;F/3:DX28@P041cW8@PLiaS67>LU:AcW48@DYAcW:DXQ21S67>LU
:AcW0QS600LLiaS636<<Ha246<DDY@0236<01124368<I1BU0QcW00LDYAcW9BTQ2AcW36<8@`0248@2
6<H00aBU48@@Q0025:D00aBV5:DDY0025:D00aS548D<H`0236<348@224800`Q348<<I00224800a23
5:HDY00236<0112336<8@PaS0a2400<8@PaS48<00`aS00<@Q12348D00aBU0QS600DLiaBU48@@Q125
00<HaP0348D@Q0aS00@<H`<8@P063688@a246<DHaQBU0PaS00<@Q1S67>L00QS600<@Q1BU48@00PaS
00D8@PaS48@@Q1BU008@Q00=36<@Q1245:@@Q1BU5:HLiQBU6<HLib48:DT00b48014DY@aS248<Ha25
36<@Pa256<HDYABT5:HHaQcW6<D<H`Q30088@P0648@DYABV48<8@`Q20@aR00003BU:;F/aS36<:DXQ
21S68@PU:B486<HDYA24008DY@0548@DYA245:DHaP035:D00acW8@PLi`037>L01AS65:DHaQBU6<H0
0QBU00<HaQ2436<00PaS0aBU00<@Q1BU6<H00QBU00LHaQBU5:DHaQcW8@PHaP035:D26<H27>L45:D0
0acW8@PQ20026<H00aBU7>LHaP026<H03A246<HHaQBU36<@Q1BU7>LHaQBU6<HDY@aS0088@P8@Q08<
H`0548@DYAS65:D<H`0224800a2436<<H`02248011cW8@PLiaBU0PQ200<@Q0aS36<00`aS00@8@PaS
5:DDY@<<H`0448@DYABU48@336<248@26<H236<2248348@236<02Q246<HDYAS6:DXicSg_<H`YBRe[
0SF]00<aS2U:8@P00R4800@LiaS66<HHaP8Q20057>LHaQcW8@PU:@028@P29BT012487>LDYABU0Q24
00P<H`aR24<<Ha2424<<HaBU0QcW00DLiQcX8@PU:B48008Li`055:DDY1BU5:DHaP025:D248@26<H0
0acW5:DDYP026<H02QBU36<<HPaS248<I0aR1288@PaS0Q2400<<HPQ336<00Q240`aS00D@Q12548<8
@P@Q0088@P8DY@0<48@<H`aS24<DY1BV6<D@Q0aS5:DLiaS60Q2400LDYAS65:DDYAcW7>HDY@0236<0
212548<<H`@R1248@PaS48@2248030aS5:D<H`Q248@HaR487>LDYA2424<<HP<@Q00836<8@`Q236<8
@Q2436@<H`8DY@8HaP0;48@DY1BV5:@Lib489BTYBRDY7>LDY@0348@00`Q336<@Q0025:D02A245:DD
YAcW7>HDY@aT36<@P`025:D00a2436<<H`025:D148@136<000036<HLiacW008U:@8Q20<Li`038@PL
iaBU008DY@036<HDYABU008DY@036<HDYAS6008HaP8DY@0448@DYA245:D26<H00b487>LHaP035:D0
0aS65:DHaP025:D01AS68@PQ21S67>L00R4800@LiaBU7>LLi`8DY@0448@HaQBU48@25:D03bDY7>LU
:BDY7>LHaQBU6<HQ22DY8@PLiaS65:DHaP025:D348@25:D26<H25:D01AS65:DLiacW5:D00PaS00<@
Q1cW6<H00QBU00@HaQBU48@@Q08DY@0336<@Q1S6008Li`0848@DYA24248<Ha245:D@Q0<8@P8<H`03
48@DYA2400<<H`<@Q08HaP045:D@Q0aS36<248@45:D01Q246<HQ21BU6<IF]@Eoo`08IcUNmcW>9BTQ
21S68@PLi`8HaP075:DLiacW6<HDY@aS48@00aBU00XHaQcW6<H<Ha245:DLiaS65:D@Q@8<H`0748@<
Ha2448@DY12436@00PaS01LDYABT48@<H`aR24<@Q1BU6<HDYA2436<DYA2436<@Q1BU8@PQ1aS66<LH
aA25008@Q0045:@@QABU48@236<01A2436@<HPQ324800a2400d8@`Q2248<Ha2436<@Q1BU36<8@PQ3
48<HaP035:D76<H348@00a236<HLi`028@P04AcW5:D@Q0aS48DDY1BU48<8@Q245:DDYQS648@8@`Q2
36<00QBU00X<HaBU8@PYBR495:DHaQBU48@@P`@@Q088@P0336<DYA24008<H`8DY@0348D@Q0aS008@
Q00@5:DHaQS69BTYBQcW6<D<HaBU6<HDYAS55:DHaQBT48D236<011S57>LHaQ240PaS0Q240ABU0A24
0A24000011246<HU:BU:124800HU:B486<HDYA245:D37>L35:D36<H25:D01a245:DDYABU48@<HaS6
008Q20047>L@Q1245:D26<H00a245:DHaP027>L011S67>LQ21cW0aS60QcW00HDYA2448@@Q1S67>L2
8@P01aS67>LU:B487>LDYAcW008Q20047>LYBRU:7>L25:D01QS65:D<H`aS5:DHaP<DY@<HaP<DY@08
6<H@Q0aS48@HaQcW5:D<H`<DY@8@Q0035:D@Q0aS008DY@036<H@Q12400<@Q0@<H`0348@8@PQ2008<
H`8DY@0636<8@PQ2248@Q1BU0QS60QBU00<HaPaS36<00PQ200<@Q1BU5:D00QBU00DHaRU:7>LYBV]J
00=oo`06MkeooeJeAS4YBQS60QcW0R4800<HaQBU5:D011S600<DYAS65:D00QS600DDYAS67>LU:AcW
008@Q08DY@0636<<HPaS48@DY1BU0Q240PaS00H<I0aS6<HLiaS65:D236<248@25:D26<H25:D56<H0
0aBU6<H@Q00236<00`aT5:DDY00336<01A2436<@Pa2548<00`aS00@@Q0Q22488@P8@Q00<36@@Q1BT
36@8@PaS48DLiaS65:@@QAS60b4800DHaQ245:D<I0aS008DY@8Li`067>PDYABU48<@Q1BU0Q2400H<
H`aT48@<Ha2448<25:D248@020aS5:D@Q0aS6<HQ22eZ8@P348@01@Q248@@Q1BU36<00`@Q0PaS0QBU
00<<I0aS5:@00aBU00@@Q0aS36<Li`8Q20085:H@Q1BU6<HDYABT48DDY@<HaP075:@DYABU5:HDYA24
5:D00Q2410aS0A2400001ABU48@@Q1S67>L00RU:00DU:B486<HLib48008Li`036<HLiaS6008@Q0<H
aP8DY@0948@<Ha2448@DYA2436<@Q1BU008Li`085:D@Q1BU7>LU:BU:8@PDY@<HaP8U:@0?6<H@Q0Q2
5:DHaQ2436<DYAS648@<Ha246<HLib4800<DY@057>LU:AcW8@PYBP02<H`38@P011BU48@@Q1240aBU
00D@Q1BU5:DDYA2400<<H`8@Q0<DY@0336<DYAS6008Li`0648@<H`aS48@DYA240PaS00@@Q1S66<H@
Q0<<H`035:D@Q0aS00<<H`05248<H`Q248@<H`02248010aS48@DYAS60a2400<<H`Q248@00QBU00`@
Q1BU5:DU:Be[<H`e[Be[8@PYBTYBG_L7Ool02GNmBU9245:D=JdQ20aS6<H@Q00236<011246<HHaQBU
11S600<DYA2436<00`aS00PDYABT48DDYABT48D@Q0Q30PaS00/@Q1BT48<<I12436848PaS5:DQ21cW
008DY@055:HHaA2448@<H`0248@02PaS248<H`aS6<H@Q1BU6<HLiaS60QBU00PDYQcW7>HDYQBT36@<
Ha240PQ200<<Ha2448@00PQ200<<Ha2336@00a2400L<HaBT6<HHaQ2424848@0536<01A245:DHaABU
5:H00QS600<DY1245:D00QcW00LDY@aT48@<H`aR36<8@P025:D27>L00aS536@@Q00236<00a245:DD
Y@045:D01124248<HaS60QBU0Q2410aS00<@Q1BT48D00`aS0a24010<Ha2436<8@QS57>PU:1cW5:DH
aQcW5:DDYQBU6<H@Q@<<H`@@Q0<<H`4@Q04<H`0000DHaQBU48@Q22DY008YBP8HaP8Li`058@PLiaS6
36<@Q0025:D27>L00aS65:D@Q0026<H224800a246<HDY@0336<01ABU6<HHaQBU6<H00R4800<LiaS6
6<H00QcW1QS60QBU0QS61ABU00<HaQcW6<H00QS600<Lib488@P00b4800<YBRe[:DX00QcW11BU00DH
aQBU5:DHaQ240088@P0:36<DYA24248<Ha245:D@Q1BU48@25:D00aS65:D@Q00336<02a2436<8@PaS
5:DHaQBU48@DYAS648@00`aS0Q240`aS00DDYA245:D8@P@Q0088@P045:D<H`aS36<548@25:D27>L0
0bU:<H`icP02<H`00aS68@QNm`08Ool02FLiAS4aS36<9BTLiaBU36<DY@026<H0112436<<HaS60QcW
00<DYA2436<01A240PaS00L@Pa2548@<HPQ3368<H`025:D04A2536<8@PaS36@<HQBU6<HQ21S65:D@
Q1BU36@<Ha2348@00QBU00T8@PQ33688@PaS48@HaR478@P00aBU0QS600DDY@aS5:D<Ha240088@P03
3688@a23008@Q00;5:D@Q0aS248<HPQ25:@@QAS65:D@Q00336<348@01PaS248@Q1245:HDY@8@Q004
5:D@QABU6<H25:D01A2336<8@PQ212800PaS00HDYABV6<DDYQBU5:@248@02@aS5:DDYQS65:D@Q1BU
48@<I00448@03PaS48@@Q1BU36<@P`aT48@DYA2436<8@PaS48@236<02PQ236<DYAS57>PQ21cW6<HD
YQBU0aS611BU00<@Q0aS36<00QBU0`aS0A240@aS0@aS00000a245:DDY@027>L01QS65:DDYABU7>LH
aP8DY@037>LQ224800<Q20089BTLiacW7>LHaQcW6<HDY@<HaP035:D@Q1BU00<DY@0548@HaQBU6<HL
i`036<H011BU6<HHaQS60aBU00D@Q1S65:DDYA24008<H`0648@DYABU5:DHaQ240PaS00H@Q1S65:D@
Q1S69BT28@P2;F/01C6<:DXLiacW5:D00a2400@HaQcW7>L@Q088@P8@Q00836<@Q1BU6<HDYA246<H@
Q0<<H`8DY@0:36<@Q1BU48@<Ha245:DLiaS65:D27>L00aBU48@DY@027>L01ABU48@DYABU48@00PQ2
00@<Ha2448@@Q08DY@@HaP095:DYBS6<@Q0icRU:<H`YBR48008Li`04<H`Q21S6G_L3Ool01GNmOomo
ofmkLi`00goo00ABU1BU8@PHaP8<H`<@Q0<<H`8@Q00324848@aS008@Q0<8@P045:HQ22486<H22482
48@236<248@01A23248<H`aS5:D00QS600<DYA245:@00QBU00LHaQBV5:D@Q0aS48<<I00236<01@Q2
36<<I1BU6<H00QBU0Q2400HDYA2436<<Ha246<H25:D348@35:D01aBV5:DDYABU48D@Q0aS008DY@8@
Q0071248@PaS48@DY@aS24800Q2400P@P`aS36<@Q1235:D@Q1BU0Q2400TDYAcW6<H@Q0aS48@HaQS5
5:D00Q2401H<Ha246<HLiaBU3688@Q246<H@Q12336<@Q1BU6<HQ21S65:D@Q0aS48@@Q@8DY@8@Q00;
36<@Pa2448@@QA2436848PQ224<DY0045:D021S67>LQ1acW6<HDYA2448<248@01@aS248<Ha245:D0
0Q240@aS0A2400025:D26<H00a245:DHaP028@P36<H011cW8@PQ22DY0Re[00TQ21cW5:D@Q1BU6<HL
ib486<H00`aS00<DYAS65:D00QBU00DHaQcW6<HDYAS6008Li`036<HDYA2400@HaP0448@DYAS65:D2
36<00`Q248@DY@055:D01Q2436<DYABU6<H@Q08DY@077>LQ22U:<H`]JbU:7>L00QS600<DYA245:D0
0QBU0Q2400<DYAS648@00PaS0Q240PaS00D@Q1S65:DDYA24008<H`0:48@<H`Q248@DYAS65:D@Q1BU
6<H25:D27>L00aBU36<DY@027>L00`aS248DY@0248@236<248@01ABU48@<Ha245:D00QS60QcW00HY
BRe[<H`e[BU:9BT28@P01BU:6<HLicF]CW<01Goo00=[FVLiLi`00goo00=S63F]36<00QS600@DY@aS
36<@Q08<H`88@P@<H`041288@PQ224825:D00acV6<H@Q00236<01@Q248@8@PQ236<00Q2400h8@`Q2
36<DYAS548DDY12548<@QAS55:HDYA240PaS00PDY12548@@P`Q3244<Ha240aBU0Q2400<DYA2448@0
0PaS0Q2400T<Ha2448@DY@aT368DYAcW6<D00PaS00DDYAS65:D<H`aT008@Q0035:@<H`Q300H<H`06
5:D@Q12436<@Q1250QBU00<@Q1BU48@00QS600T@Q0aS36<DYAS65:H@Q0aS48@00QS600<DYA242480
0PaS0Q2400D<I0aS48@HaQcV008HaP0=5:D@Q12448@<HaS56<HDY@aS248@Q1BU24<00PQ200<@Q1BU
48<00PaS00/8@`aS48@@Q1BU6<HQ21cW6<HDYA24008<H`0348@<HaBU008<H`<@Q04<I04@P`4<I000
0aS600HDYA245:DDYAcW6<H25:D011S65:DHaQS60QcW00HQ22U::DXYBR489BT2;F/28@P01aS68@PU
:BDY8@PHaQ24008DY@DHaP<Li`8Q20039BTLiacW008Q200:9BTHaQBU48@DYB486<HDY@aS48@25:D0
3aS65:DDYAS65:D@Q0aS48@Lib487>LHaQBU6<HLi`02<H`022e[:DXDYA245:DLib485:D248@00aS6
8@PQ20026<H011245:DDYA240QBU00@HaQBU36<<H`8@Q004248<HaBU5:D236<00a247>LDY@0248@2
5:D00aS648@@Q00236<35:D236<02@Q25:DHaR48:DXQ22U:9BTLi`026<H37>L336<03P@Q36<<HaBU
7>LHaRDY<H`e[Cg_<H`LicW>E[D5Ool014icBU8Q21cW10aS00D@Q0aS36<8@PaS0088@P032448@PaS
00<@Q00336<@Q1BU00<DY@8@Q00336<@Q1BU008DY@0748@DY12436<@Q0aT5:@00Q2400h<I0aS5:DH
aQcV6<H@Q0aT48<@QABT36@<Ha230QBU00@@Q1BU5:D@Q08<H`8DY@0348@DY1BV008Li`036<HDYAS6
008HaP0>5:D@Q1BU5:DLiaS76<DDYAS55:DDYQ2436<<HPD<H`0:48@@QAS66<HDYA2348@@QAS56<H2
5:D01AS65:DDYA2336<00QBU00@LiaBU48@<H`8@Q0<<H`085:D@Q1245:@<I0aR24<<H`<DY@0348@<
H`aS008DY@036<HDYABU00<DY@0:36<8@PaS6<D@Q0Q224<@Q1S648@436<01aBU5:HHaB489BTU:R48
008DY@0348@DYA2400<<H`4DY04@Q04@Q0000QcW00THaQ2436<@Q1S68@PLiaBU36<00QBU00PLiaS6
6<HQ22DY<H`]JbDY0RU:00H]JbU:8@PHaQBU7>L28@P01BDY8@PDYABU48@00QS60PaS00<DYAcW8@P0
0acW0bDY00HQ21S66<HHaQBU6<H25:D011245:DHaQS60QBU0Q2400@DYAS66<HDY@8HaP077>LHaQcW
6<HLibDY:DX00SF]00<U:AcW5:D00QS600@@Q1BU36<HaP8Q20049BTQ21S66<H548@25:D648@01`aS
248<Ha245:DHaQBU00<@Q0036<HDYA2400<<H`8@Q00<5:D<H`Q236<@Q2487>LHaR48;F/YBR4811cW
00@DYAS65:D<H`88@P0336<@Q1S6008Q2008<H`]Jcg_BU8icQcW?Nm_N`Aoo`06HaPQ22487>LHaQ24
0PaS00@@Q1BU5:D<H`88@P042448@`Q2124224826<H01acW6<HDYA255:D<Ha24008<H`035:D@Q1BU
008@Q0085:D<H`Q3368<HaBV5:DDY0@HaP8@Q00536@@Pa2448@<H`0224800`aS48DDY@0336<02124
5:@@QA2348@@QAS67>H26<H031cW6<HHaQBU6<HDY@aS5:DHaRDX8@LDYP@DY@0648@@P`Q336<@P`aS
0Q240QBU00<@P`aS48@00QBU00DHaABU36@<Ha24008DY@8@Q08DY@096<HDYABU5:D@Q1BU36<8@Q24
008HaP055:D8@`Q248@<H`035:D00`aS48@@Q@026<H021BT5:HHaQS65:D<Ha245:D25:@03`aS24<<
HPQ35:@DYABT48@<Ha2348DDY1S65:DLi`028@P00bDX8@PDY@0348@011BU36@<H`aS0Q240ABT0000
0acW6<HHaP025:D02AS65:DHaQS65:D@Q0aS48@HaP035:D26<H27>L00aS67>LQ2002:DX01b487>LL
ib48:DXU:B48008Li`048@PLiaBU6<H248@00aBU48@DY@036<H00a245:DHaP025:D00`aS48@@Q002
5:D01aS65:D<H`aS48@DYAS6008DY@0348@DYAS6008HaP<DY@0436<@Q1cW8@P29BT01aS65:DLib48
:DX]Jb48008Li`8DY@046<HDYA2436<224800a245:DHaP065:D00`Q2000DY@02:DX01AS6248DYAcW
5:D00`aS00<@Q0aS36<00`Q20aBU00T@Q1BU6<HYBS6<;F/YBRDY6<H00aBU00D<H`Q2000000@Q0080
00051248@P@Q00048@0436<248@02PaS5:DHaRe[AS5BU4YB>Li:DUJe0Vmk00Hmkc6<5:DHaR485:D2
48@011BU36@8@@Q20`aS0PQ200H@Q0aS36<@Q1BT48@336<248@03`aR248<Ha2448D@P`Q3248<HPQ2
36<@Q1BU6<HDY@0248@01Q2348@<H`Q21288@P<<H`035:@DYQS5008DY@0448DDYABU5:D248@01A25
6<HQ21cW5:D00PaS00@@Q1BU48@DY@8HaP056<LDYABU48D<HP0236<010aT5:D@Q1250QBU00@@Q1BU
5:DLi`DHaP065:HDY0aS48DHaQBU0PQ200<8@aBU36<00PaS0QBU00H@Q0aS48@@P`aT48@25:D01PaS
1248@Q2348@<H`88@P06368<H`Q224<<HPaS0aBU0Q2400P<H`aT36<<H`aT5:@@Q0aS0PQ20PaS0a24
0QBU00hLiaS76<H@Q1BU6<LQ21cW5:DDY1BU36<@Q0aT0A24000011246<HHaQ240PaS00<DYAS65:D0
0aBU0Q2400<HaQcW7>L00QBU00@LiaS65:DLi`<YBP037>LHaQcW00<Q20@HaP097>LHaPaS48@DYAcW
5:D@Q0aS00<DY@8@Q0055:D@Q12448@DY@026<H011BU48@<Ha240aBU00D@Q1S66<HHaQBU008HaP06
7>L@Q1BU48@DYB480acW00@HaQcW7>LLi`<U:@038@PLiaS6008@Q0035:D<H`Q2008<H`047>LQ21S6
5:D236<248@336<01AcW9BTQ21S648@00QBU00@@Q0aS36<@Q08<H`0?1248@PQ236<DYAS65:D<HaBU
8@PaS3F];F/Q21cW008DY@0548@<H`Q224848@0300000`@Q00048@02124224803QBU48@DYABU48@<
HacW:DY245:DE[E6<Cg_DY@2IcT01E:D9BTQ21S65:D00QS600X@Q0Q22488@Q2436<8@P@P004<H`8D
Y@0748@<Ha245:H@P`aS48@00QBU00@8@P@R36<@Q08<H`075:DDY0Q324<<Ha245:D00Q2400DDYA24
36<<H`aT008@Q0<<H`07248<Ha256<DDYQ246<D00QS600<DYQ2348@00aBU0aS60QBU00<@QA2448@0
1ABU00L@Q0aS24<<Ha245:DDY00248@03aBU6<HHaQBU48@<HaBV7>H@Q@aS48@HaQBU36<<HP0248@0
0`aS248<HP0236<0112448DDYA240PaS00<DYA2548<00`aS00<DY12424<00PQ200D<HaBU48@<H`Q2
008<H`8DY@0448@DYA2436@248@01ABU48@<Ha2448D00Q2400@<I12448@<H`8@Q08DY@<HaP8Li`8Q
20036<H@Q0aS008DY@0348D@P`aS004@Q00000@Q21cW6<HHaP8Li`036<H@Q1BU008DY@037>LDYABU
008@Q00:5:D@Q1S67>LHaQ245:DLib486<H248@061S648@@Q1BU6<HLiaS65:DHaQ2436<@Q1S69BTL
ia245:DLiaS648@8@Q245:D<H`8@Q0035:D@Q0aS00@<H`055:DHaQcW6<HQ20029BT02ABU36<@Q1S6
5:D<Ha245:D@Q00236<01A245:D@Q1246<H00b480RDY00HYBRDY9BTU:AS65:D248@01ABU6<HHaQS6
48@00`Q210aS1A2400<<Ha2448@00PaS00<8@PaS5:D00QBU0`aS00D@Q0aS36<<Ha24008U:@058@P<
H`Q236<48@0400000`@Q0000000200000`@Q0000000200000`@Q0000000212400`001248@P0236<0
1`Q25:DYBQcW36=247>L009oo`06>Lhe[BU:7>LU:AS60QBU00HHaPaS24848PaR5:D236<35:D01Q23
48DHaPaS248@Q08HaP0548@8@PaS5:@@Q00236<236801A2436<<H`aS36@01@aS0PQ20`aS00<8@PaS
48@00QBU00@@QABT36<8@P8@Q0076<HQ21cW5:D@Q0@Q36<00Q2400DHaABV5:@8@PaS008DY@0348<8
@PQ2008<H`063688@`Q224848@Q20PaS00<@Pa255:@00QS600@Lib488@PLi`8DY@066<HDYA2436<@
Q1S60QBU00XDY1BU36<@Q1BU48DLiQcW5:D@Q088@P8<H`0548@<I12336<8@`0324800`aR48@@Q002
6<H27>L011S536@<Ha240QBU00l<H`Q236<<HPQ236<@Q1253688@a246<HLiaBU36<00Q2400THaABU
48@HaAcX8@PLiPaT36800@aT00000b487>LQ20036<H00aBU6<HDY@025:D011245:DHaQ240QBU11S6
0QBU11S600DDYAS65:DDYAS6008Li`056<HDYAS66<H@Q0025:D37>L248@01QBU7>LHaPaS124<H`8D
Y@<@Q0<<H`055:DHaQBU7>LU:@028@P00a245:DDY@026<H00a2436<<H`0248@00`aS48@DY@045:D0
0b489BTYBP028@P02BDY;F/YBQcW48@DY@aS248DY@026<H01A242488@QBU48@00`aS0Q2400@DYA24
36<<H`<@Q0<<H`8@Q08<H`0348@<H`aS008<H`8DY@057>LQ21S65:D@Q002124300000`@Q0000000;
000020@Q2488@P@Q00048A2436<25:D012U:9BTQ26Li0Woo00AcW2U::DXQ208Li`046<HDYA2336@3
48@04PaS248<HPaT48@DYA2436@<HPaS48DHaABU36<@Pa255:@<I088@P0424<8@PaS24<336<030aR
2488@PQ224<@P`aS368<HaBT5:D@Q08<H`035:DHaQBU00L@Q0055:DHaQS548D<H`0224800`aS48@@
Q0025:D03A2448DDY0aT24848@Q124<<Ha2324848@Q2008<H`0:48DDYABU5:DDYQBU6<DHaQS76<D2
5:D011BV5:DDY0aT0QBU00/@Q0aS248<HaBT5:DHaaS55:HHaPaS00<8@P<<H`06368<I12348<<I123
0PQ200@8@`aS8@PU:@8Q200B48@<HPaS5:DHaPaS1248@Q245:H@P`@R368@Q0aS48@DYAS60QBU00`<
HaBU36<8@aS68@PU:AcW48@DYAS636<1368000038@PLiaS6008HaP055:D<Ha245:DLi`026<H25:D0
11S67>LLiaS60aBU00@HaR488@PHaP8@Q00736<@Q1BU5:DHaQBU6<H00QcW00@Q21cW7>LLi`8Q2003
7>LHaQcW008Q208DY@036<HDYABU008@Q0045:D<H`aS48@25:D236<01A246<HDYAS65:D00aS60Q24
00@<Ha2436<8@P<<H`8@Q00336<@Q1BU00DHaP055:DHaQBU5:DU:@02;F/02bDY6<HQ22485:D@Q0aS
48@DYAS648@00PaS0QBU0Q2400<8@Q245:D00QS600<DY@aS36<00PaS0Q240PQ200L48@0036<Q236<
:DX<H`0400000`@Q0000000F000312401PaS5:DHaPaSCW=g_@=oo`0:F]HYBPQ25:D8@`Q236<DY1BU
36<25:D031cW5:DDYAcW9BPLj1BU5:@DYQBU36<<I08DY@<<H`065:D@P`Q336<DY0aT0PQ200d<Ha24
36<8@@@Q2488@aBU48D@Q0Q3368@Q0025:D236<00a247>LHaP025:D021245:DHaA2548<<HaBU48@3
36<0112436@@Q1BT0Q2400@@P`aS36<<H`88@P8<H`0548@<Ha245:@@Q@036<H01aS56<HHaQcW6<HD
YAS6008Li`8HaP047>LQ22DY8@P27>L05QBV6<HQ1aS67>LQ212424848@Q25:HDY@aS48@DYA2436@<
H`Q336<8@PaS0Q2400D8@PaS36<DYA2400@<H`P8@P8<H`0448@@Pa2436<348@00a235:DHaP026<H2
5:D36<H000037>LQ2248008Li`8HaP@DY@046<HLiacW6<H35:D46<H031BU7>LLiaBU36<DYAcW6<H@
Q1BU6<HQ208Li`038@PHaQBU008HaP038@PLiaS6008DY@047>LQ21S648@236<25:D248@01aBU48@@
Q0aS48@DYA2400<DY@<HaP<DY@0548@DY@aS1248@P0236<224800`aS6<HHaP026<H37>L26<H27>L0
1RDY8@PYBRU:7>LHaP8<H`0748@<H`aS48@HaQBU24800PaS00DDYA2436<DYA24008<H`0A5:DHaQBU
48@DYAS65:D@Q0@Q00048@aS7>LU:AS636<48@020002124>0002124:000010Q248@DYAS60R4800Qc
W7ooOomooekg=JdHaP@Q0Q2400@<HaBU5:D<I08<H`0648DHaQS55:DHaQcW0QBU00<@QAS548@00PaS
0QBU00`DY0aS48@DYA2448<@Q0aT3688@P@Q248336<01@Q336<@Pa2448<01@aS00d@P`aT6<DDYABV
6<HDYABT36@<HaBU36<@Q0025:D02aS65:D@Q12448DDY1BU5:HDYA2436@00PQ200X48@aS36<8@PaS
36@DY0aT48@DY0DHaP057>LQ1aBV48@HaP02:DX01QcW5:DDYAcW7>HLj0@HaP8Q20046<HDY@aS36<7
48@00`aT48<<H`0236<00aBT48D<H`0224802@aS5:DDY@aS128<HQ245:D<H`0624801@aS248@Q0aS
48D0112400P@QABU5:D@Q0aS48@HaQBU0QS60AcW00037>L011BU48@@Q12411BU0QS600<Q22DY8@P0
0b480acW0aS60aBU00`HaR489BTQ21S67>LU:B487>LDYAS67>L28@P00acW8@PLi`057>L03aBU48@@
Q1245:D<H`Q26<HU:AS636<8@QBU6<HDY@026<H27>L26<H01QBU7>LLiaBU36<8@PD<H`0348@DYABU
00<<H`<HaP035:DHaQcW008Q20037>LQ22U:008YBP039BTLiaS600<DY@8@Q0045:DHaQS66<H25:D0
0a245:DDY@025:D00`aS48@@Q0025:D020@Q00048@Q248@HaQ24248300000`Q236<48@0=00000`Q2
0000000;00001P@Q24848@007>LU:@Aoo`07JeX]JaS6000<HPaS24800PaS0Q2400TDYAS65:HDYA24
5:@DYAS548D00a2400<<Ha2436@00PaS00D8@`aR36@<Ha230088@P8<H`0548@<H`@R1208@P0236<0
3`aT36<48@@Q36<DYAcX6<D@QABU5:@@QA2448DDY00248@25:D0112436<<H`aS0Q240aBU00@DY0aS
36<<HP848@88@P<<H`0548@<Ha2348@DY@027>L38@P04QS648D<Ha2436<48@aS5:DHaQ2436<8@Q24
36<@Q1S56<HDYP<DY@@HaP035:D@PaBU008DY@0:48<8@PaS368@Q0aT5:@HaQ2436<224800a2436<<
H`02248236<011BU6<HDY@aS0PQ200l@QABU48@<H`Q236<DY12548@<HPQ35:@DYAcW8@P00QBU0A24
0@aS0A2400027>L01B485:D@Q0aS48@011BU0acW0R480QcW0QS600LLib487>LHaQBU48@DY@026<H3
8@P37>L26<H25:D01AcW8@PQ22487>L00b4800@LiaBU36<@Q08HaP035:D@Q124008HaP095:D<Ha24
36<@Q1S65:DHaQBU00@HaP065:D@Q1BU5:D@Q0aS0PQ200<<Ha2448@00QBU0QS60a2400@DYAS66<HH
aP8Q208U:@07:DX]Jbe[9BTHaQ245:D011240QBU00XHaQBU5:DQ21cW48@8@Q247>LHaP<DY@0848@D
Y@@Q00048AS6:DXDYA@000031240000000`00006124<H`00000aS5Je17oo014mk`aS48@<H`aT36<4
8@aS48@LiQ2436<DYABT48DDY125008DY@0348<<H`aS008<H`0748<@Q0aS36<@Q0aS48@00`aS00@8
@`aS48@8@P848@0?36<DYABU36<<HPQ2124<Ha255:@@QA2436<8@PaT008Ha@0448@8@`Q248@25:D2
36<02Q2348@@P`Q348<@QABU48D<HPQ30PQ200H<H`Q2248<Ha245:D236<01A257>HDYQBU6<H00QcW
00PDYPaS36<<Ha235:D<Ha240aBU00<@Q1256<D00Q240QBU0QS60QBU0PaS00DDYAS67>LHaa2400<8
@P0A36@@Q0aS5:DLiaBV48<8@PaS48D<HPQ236<@Q0aS24<@P`025:D00a24248<H`0248@0112336<8
@PaS0a2400L<H`Q248@DYAcX7>LHaP035:D16<H136@136800003?NlaS2e[008YBP038@PHaQ2400<D
Y@DHaP045:D@Q1BU5:D27>L00aS67>LHaP026<H00`aS5:DHaP038@P02QBU6<HDYAS67>LHaQcW8@PU
:AcW0QS600<Lib487>L01ABU00<HaQ2448@00aBU0QS600<Lib486<H00aS600dQ22DY8@PHaQBU6<HL
ia2436<8@Q246<HDY@0236<01PQ236<@Q0Q236<@Q08Li`0448@DYABU6<H25:D011245:D@Q1BU0aS6
0QcW00DU:Be[;F/YBRDY008Li`@HaP055:D@Q12448@DY@028@P01a24124000@Q36<8@P@Q00L00003
1240000000h000031240000000`000848@0;000Q23g_IcUg_Dic>LhYBQ256<D<H`03248010aS48@H
aQcW0R4800THaPaS36<DYB497>L@Q0Q236<00QS60QcW010DYABV5:@8@`aS1248@@aS36@DYA2436<@
Q0aS48@<H`88@P0C24<<H`aS36<@Pa2436<<HPaS48@DYQBU5:@<I1BU6<HLiaBU48@00PQ20PaS0Q24
00H<H`aR24<8@@Q236<248@236<020Q248@DY1BV6<D@QABT5:D26<H01ABU48@8@PQ248@00QBU0PaS
0QBU00L<H`Q2248@P`aT48@<H`0448@236<041245:@<I1246<HLiaS65:D@QABT6<HDYQS65:DDY1BU
0acW00XQ21S636<<HaBU6<DDY@aS24<<H`LDY@H<H`8@Q00448<<H`aS48@25:D148@148<136@00008
=Jd]JbU:9BTQ21cW6<HDY@8HaP085:DHaQS67>LHaQ246<HLi`8Q208Li`8DY@056<HDYAS648@DY@02
7>L02RDY8@PDY@aS5:DHaR486<HDYAS60RDY0R4800DLiaBU6<HDYA2400<DY@8@Q00736<@Q1246<HU
:B487>L00QBU00DLib489BTLiaS6008DY@037>LHaQS600<<H`05248@Q1BU5:D<H`0224801124248<
HaS60QcW00@HaQ2448@DY@8HaP0448@<HaBU7>L25:D011S67>LU:B480bU:00PU:AcW7>LHaQBU6<H@
Q1BU0PaS00`HaQcW8@PDY@Q236<48@001248@PaS248300000`@Q24848@0>000212400`Q21240000:
000312401@Q21240036<G_L00Woo00DmkbU:8@P@Pa2500<<H`08248DYAS67>PLiQ245:DLi`8DY@04
48@DYABU6<H25:D011S67>LLiacW0QBU00@<I0Q11288@P8@Q00@368<Ha2348D<Ha245:@DY@aT2484
8@Q2244<H`aT36<448@25:D36<H00aBU36<<H`0248@020aS36@DYABU36<8@PaT5:D248@224801`aS
5:DDYABV48<<I12400HDY@<<H`0348@<I0aS008<H`<DY@<<H`0348DDY1BU00DDY@0648@<Ha2448@@
PaBU0QcW00LDYA24368DYAcX9BPLi`025:D00aS68@TQ20025:D02A24248<H`aS5:D@QA2436<@Q004
5:D011255:D@Q12420aS00L<I1245:@@Q0aT48<<I0015:@00004>Lh]JbU:8@P27>L00b487>LHaP02
6<H00acW8@PQ20028@P26<H27>L012DY:DXQ22481ABU00@HaQcW6<HDY@<HaP0A7>LDYA2436<@Q1BU
6<HDYA2436<HaQcW6<H<H`Q25:D@Q00336<03ABU48@<Ha246<HDY@aS248DYAcW6<H@Q0aS008@Q006
6<HLiacW6<H@Q0aS0QBU00<@Q0Q236<010Q200<<HaBU7>L00acW00<HaR487>L00QBU00H<H`Q236<8
@Q2436<248@00aBU7>LLi`02:DX2;F/01BU:9BTDYABU6<H00a2400@<HaBU48@<H`<48@0324848@00
00T000848@8000848AT000061248@PaS000<HacW0RU:00<Ha@aT36<00PaS00T<HPQ224<<HaBT48@@
QABU36<00PQ200H<HaBU5:D8@PaS48@27>L01ABU36<8@PQ248@00PaS00T<HPQ348<<I12424<8@PaS
48@010aS00`8@P@Q36<<I1233688@`aS48@<H`Q236<2248010aS48@DYA240PaS00D@Q1BU48@@Q1BU
00<@Q08DY@0:36@@Q0aS36<DYAS55:H@Q0aS5:D56<H011BU48@<H`aR0PaS00<@Q1BT48@00`aS00P@
Q1BT5:DHaQBU48@<I1230a240`aS00<8@PaS48@00QBU00@@Q1S66<LHa@8@Q0065:DQ2BDY8@PQ1aS6
0aBU0QcW0aBU00/HaABU36<<Ha2336<HaR489BTLiaBU008@Q08DY@0:48@<H`@Q1208@P@Q36<@Q1S6
36<124800008<H`YBRDY7>LQ21cW8@PLi`8HaP037>LQ21cW008HaP8Li`076<HU:BU::DXU:AS65:D0
1AS60QBU00@HaQBU5:D@Q0HDY@046<H@Q12448@26<H00aBU36<<H`0248@25:D01PaS2488@PaS5:DH
aP8DY@0448@DYABU5:D236<00a246<HHaP035:D236<03Q2436<@Q12436<@Q0Q236<@Q0aS5:DLib48
7>L25:D37>L011BU36<<H`Q210aS00<@Q1BU6<H00QcW00@YBRe[;F/]J`8Li`036<H@Q1240088@P04
48@HaQBU248200000`Q236<48@0300001@@Q00048@0012401P000P@Q6@0000/48@000008@PaS7>LY
BRDY7>LDY@Q200@<H`0O248@Pa255:D@Q0aR48@@Q@aS24848@Q136<<I1BU6<H@Q12336<@Q1BU48@<
H`@Q248<Ha245:D@P`aS36800PQ200<8@`aS24800PQ200T<HaBT36<<H`01124<HPQ25:D00Q240PaS
00D8@@aS36<@Q0aS0088@P0336<DYABU00@DY@045:@<H`Q236<248@01`aS368<I1BT48@DYA2400@H
aP035:D@Q1240088@P0536<@Pa2548@8@P0336<01a255:DHaQBU48@<Ha24008<H`<DY@0>36<8@PaS
24<8@P@R368@QABU6<DDYQBU6<HLi`8Q208HaP035:D<HaBU00HDY@0:24<8@PaS5:DLiaBU6<HQ1b48
6<H236<01ABU48@<HPQ236@00PaS0PQ200@<Ha2448@DY@4@Q@000b480RDY0RU:014LiaBU6<HHaRU:
<H`e[Be[9BTHaQBU:DX]JcW>;F/Q22U:008Q20035:D@Q124008@Q0<DY@8HaP8DY@0348@<Ha2400@D
Y@0648@DYA246<HLia240PQ200<<HaS648@00Q2400@HaQBU48@<H`8@Q00<36<DYAS68@PU:AS65:D@
Q1BU7>LHaQBU0Q2411BU00@@Q0aS2488@P8<H`0548@<Ha2448@DY@026<H236<2248236<00a2436<<
H`0224800a245:DDY@035:D00b487>LYBP02?Nl01Be[6<HDYAcW48@00P@Q00<<H`Q200007@0000<4
8@0000004@000`Q20PaS0a2400X<H`aT48<DYAS66<L@Q12348@DY@8<H`0848@DYB487>LQ22DZ7>LH
aP<DY@<<H`0:48@DYABU36<8@PQ348<HaQ2436<248@01@Q21248@Q245:D00PaS00@@Q1BU5:D@Q08<
H`0:24<@Q1BU5:D<H`Q336<@Q0aT368236<25:D01AS636<<H`aS48@00aBU00DHaQ2448@@Q1BU00<H
aP038@PHaPaS008<H`045:D@QA2448@35:D00a2548@@Q0025:D02`aS48@@Q1245:HHaA2536<8@PaS
48@00PaS00<@Q1S548@00a2400XDYA2436<<Ha246<DLiaBV5:DHaP8Li`8HaP057>LHaQBU48@@P`03
48@25:D00aBV5:D<H`0248@35:D248@236<2248010aS48@HaQBU0A2400000aS67>LQ20029BT28@P0
2acW6<HLibDY<H`icSF]9BTLiaS67>L00S6<0SF]00HQ21S65:D@Q1BU48@45:D00aS65:DDY@0248@0
0aBU48@@Q0055:D02AS65:DHaQ2436<@Q1BU6<HDY@0236<01aBU6<HLiaBU36<8@PaS008DY@067>LH
aQS67>LHaQBU0Q2411BU0aS600D@Q0aS248<Ha240088@P0336<DYAS6008DY@8@Q00336<@Q124008<
H`88@P8<H`0548@8@PQ2248@Q0026<H02AcW6<HQ22U:<H`e[Be[9BTDY@0236<010Q2124000@Q5000
00<48@0000006`0000X8@Q2448@<Ha245:D@Q0Q2124<H`8@Q08HaP065:DHaQ2548@@QABT0QBU00PH
aR488@PQ21cW5:DHaAS60QBU0Q2400<@QA2448@00a240PaS00P8@Q2448@<H`Q2368@QABU0PaS00<8
@Q245:D00PaS00P8@PaS48@<HPQ35:@HaQ240PQ200<@Q1S55:D010aS00/@Q1BU5:DHaQcW5:D@Q0Q3
36<DYA2400<DY@<Li`8DY@0348@<H`aS008@Q0056<HHaABU5:DDY0045:D248@011BU6<DLiaBU0Q24
00L<Ha2436<8@`aR248@Q0025:D336<00a247>LHaP036<H03acV6<HDYABU7>LQ22U:8@PHaQBU36<@
Q1BU6<DDYP0236<011BU6<HHaQBU0PaS00@<I1245:D@Q08<H`06248<H`aS36<@Pa250AS5000023W>
=JdYBQS67>LHaQcW6<H25:D01A246<HLibDY:DX00Re[00XYBRe[?Nle[C6<8@PYBRe[9BTQ208Li`8H
aP8DY@8Li`8Q20066<HDYABU6<HLiaS60QBU0QS60PaS0Q2400<<Ha2448@00QBU00@@Q1BU5:DDY@DH
aP<DY@076<HLiaS65:DLibDY8@P00QBU00PHaQcW7>LDYAS636<@Q1BU0a2400LDY@aS48@DYAS65:D<
H`0248@01QS67>LLiaS65:D@Q0<<H`<@Q08<H`065:DHaQS67>LHaR480Re[00LLia24000000Q236<4
8@0<00000`@Q0000000H00000`@Q0000000600001@@Q0000000024800PaS0QBU00D@Q0aS36<DYAS6
00@DY@0=48@@PaBU5:HHa@aT5:@HaQBV48<8@`aS5:D00a2400DDYA243688@PQ300P<H`0748@<I123
24<<H`aR24800Q240QcW00LDY0aS2488@QBU48DDY@0236<01ABU5:@DYQ2436<01Q240PaS0Q241ABU
00@DYQS55:HDY@8@Q00436<@Q0aS48<336<01@Q35:DHaQBV5:@00Q2400<@QABU6<H00QBU10aS00<@
P`aT36800`Q200<<I0aS48<010aS00@@Q1BU6<HDY@8<H`035:D@Q1S600<DY@036<HDYABU008HaP0;
7>PQ21S66<D@QABT5:D8@`Q2124<H`025:D29BT021cW5:D8@PQ348<8@`aT5:@15:D00003;F/Q2248
008Li`056<HDYAS66<HLi`026<H01248:DX]JbU:0RDY0SF]00<icS6<8@P00bDY00<Q21cW7>L00QcW
00HDYA245:DQ22DY8@P248@011BU48@LiacW0QS600DDYA245:DDYA24008<H`0348@DYABU00<@Q009
5:DHaQS67>LQ21BU36<@Q1BU008Q20096<HDYAcW8@PU:AS65:D<Ha24008HaP8Li`065:D@Q0aS248<
Ha240QS600<DY@aS36<00Q2400TDYA245:DHaQcW5:D@Q0aS5:D00PaS00<8@PaS6<H00QS60Q2400<H
aR48:DX00RU:00<Q20aS24800`@Q400000<48@00000020000`@Q5@0000D48@Q236<8@PaS00<DY@09
36<8@Q245:DLiaS636<@Q1BU00@@Q00=5:HHaA2536<@Pa256<DDYA2436<@Q1BT5:H00Q2400<8@PaR
36<00Q2400/<I0aR248<HaBT5:D@Q0Q3368<I12400<<H`0348DDY@aT0088@P0:36<DYAS55:D@Q0Q2
36<DYAS548D236<02Q2436<@Q0aS48@<Ha2436<@Q1BT1QBU0Q24014HaQBU36<<H`Q248@HaQBU48@@
P`aT48@HaQBV5:DDY1BU00<@Q00336<@QABU008<H`88@P<<H`07248<Ha256<H<H`Q236<00QS600l@
Q0aS5:DHaQBU36@@Q1BU6<HLiaBU48@HaQS79BP00QcW010Q21S66<H<H`Q236<@PaBU48@<HaBU7>LY
BRDY5:D@Q08<H`045:D@P`aS36@15:D0000>9BTQ2248:DXaS2DY6<HDYAS69BTLiaS65:DHaP8Q2005
9BTQ22489BTQ20037>L012489BTYBR480QcW00DYBRe[9BTU:B4800<HaP0848@U:Cg_BU8icR4848@H
aP8Q20057>LDYA245:D@Q00236<01a246<H@Q0aS48@DYB4800<Li`<Q200:6<HLiacW7>LYBRe[:DXQ
21S67>L48@P01aS65:D@Q1245:D@Q1BU008Li`035:D<Ha24008DY@0548@DYABU5:D@Q00236<00aBU
48@<H`045:D01`aS248HaQcW9BTYBQcW008@Q006248<HaBU48@<H`Q2;00000<48@0000000P0000D4
8@00000000@Q0088@P0748@DYB489BTLiaS636<00PQ200L<HaBU48@@Q0aS5:D@Q00236<25:D020aS
2488@PaS24<<HPQ3368236<01A2436<@Q12448<01@aS00<@Q1BU48@00PQ200/<HaBU48@<H`Q124<@
Q12336@@P`aS00<8@P0948@DY@aS248<Ha256<HDY@aT0088@P0;36<8@PaS36<@Q1BU5:@<I0aS5:@H
aP027>L011S65:DDYABU0Q240PaS0Q2400<<I0aS48@00aBU0a2400<DYA2436<00`aS00@8@PaR36<<
H`848@0336<HaABU008<H`8DY@0548@<Ha256<HDY@0348@00`aR36@<H`045:D26<H55:D031S56<HD
Y@Q336<8@PaT5:@<Ha2436<@Q@8DY@056<D@Q0aT36<8@P0136<000059BTYBRU:8@PLi`046<H27>L0
12487>LLiaS60R4800DHaR489BTU:AcW008DY@0E9BTYBRU:7>LHaR48:DX]JbDY8@PU:AcW5:DLib48
=JdmkcF];F/Q21S600<Li`046<HLiaBU5:D248@01QBU6<HLiaS648@<H`<HaP8DY@046<HLiacW7>L2
6<H38@P29BT48@P27>L00aBU6<HDY@0248@011BU6<HHaQS60aBU00H@Q0aS36<@Q1BU7>L25:D236<2
48@26<H011242488@Q240QcW00@HaR487>LDY@88@P0336<@Q0aS00<000031240000000L000031240
000001X0000312400000008000031240000000D000848@05248HaR48;F/U:@0248@2124236<01aBU
36<8@QBU7>LHaPaS0088@P8@Q00;36<8@PQ21208@a2348DDY@aS24848P0236<01A2436<<H`aT48@0
0PQ200`48@aS48@@Q0aS128<Ha246<H@P`Q224<436<0112436<<H`aS0Q2400D@P`aS36<<Ha2300@<
H`0448@@QAS548D236<021247>PLiaS67>HDYQBT48@25:D236<01@@R248@Q0aS5:@00Q2400@@Pa24
48@DY@D@Q00436<@Q0aS24<336<03a245:D@QABU48@<H`Q236<@Q1BT36<<HPaS36@DY0025:D01a24
36<<H`aS48@HaQS5008DY@0348<DYQBU008@Q00<5:DHaQ2436<8@aBT48D@Pa245:DDY1240`aS00<8
@PaR36<00ABU000011S67>LU:BU:0RDY0R4800PU:AcW5:D@Q1S69BT]JbDY1B4800<YBR487>L00acW
0QS600@Lib489BTQ20<U:@03:DXLiaBU008DY@<U:@038@PLiaS600<DY@046<HLiaS65:D236<348@0
11S65:DHaQS60aBU00@@Q1BU5:DHaP8Li`8DY@0>6<HQ22486<HLib486<H@Q0aS5:DHaQ2436<@Q08D
Y@8<H`0348@<Ha2400H<H`045:D@Q1245:D26<H25:D00aS65:D@Q0025:D37>L01`aS248000Q236<8
@P@Q008000031240000000H000071248@P@Q36<DY@aS12400P0000<48@0000006@0000<48@Q21240
1P0000`8@PaS6<HHaQ2436<8@P@Q36<8@PaS248236<248@03PaS48<@Q0aS1288@Q2336@8@P00248@
QABT36<2248236<00`aT48@8@P02248010aS48@@Q0aS0PQ200<<Ha2336<00PQ200l<I1BT36<8@PaS
5:D@QA2348DDY1BU248<H`aT48@00`aS018@Q0aS36<@Q1BU5:@DYA2448D<HP@Q5:DQ22U:8@P@Q0aS
48D35:D336<01a2336@8@P@Q368@QAS600<<H`8DY@0548@8@PQ21288@@0236<01A2436@@P`aS48<0
0`aS018@Q0aS36<<H`Q236@DYAS65:D<H`Q348<@Q1BU5:@@Q1BU5:H25:D011255:DDYABU0`aS00@D
Y1BU5:D@Q08DY@0448@<H`@Q0002248448@15:D000077>LQ22e[;F/U:AS68@P00QcW00@HaQ246<HL
i`8YBP8U:@03:DXU:BDY008Li`8HaP047>LU:B487>L26<H00acW9BTU:@029BT01QS67>LHaQBU6<HL
i`8YBP0;8@PHaQS66<HU:AS648@8@PaS6<H@Q00236<248@25:D021S67>LLiaBU48@<HaBU7>L36<H0
0acW5:DLi`038@P00acW6<HDY@026<H25:D248@01QBU36<<Ha245:D@Q0@<H`06248<H`aS36<@Q0aS
0a2400DDYAcW7>LLiaS6008DY@8@Q0095:DHaQS6248000@Q36<8@P@Q00/00088@P0436<@Q12436<2
248G000010@Q000000000P@Q0`000P@Q1@0000@DYB48<H`Q2088@P051248@Q2448@<H`0224800a24
5:DDY@0224801aBU48@<HPQ224<@P`Q30088@P0748<<I0aR248<H`aR24800PaS0QBU00X@Q0Q21248
@aBT24848@@P24<@Q088@P0436<@QAS55:D336<0212548@<I1235:D@Q0aS48<25:D00a2436<<H`05
36<248@01aBV5:@Lib477>PLiaBU008@Q00>5:DHaQBU48@8@P@Q36<HaABV36<8@Q235:HDY@8<H`04
48@<H`aS36<224801PQ336<@P`aS48@8@`8<H`0448@DYABT5:D336<01a245:D<Ha246<HDY@aS0084
8@055:DDYQBU5:DDY0027>L01AS65:D<Ha245:D00`aS00<@Q1S65:D00Q2400X<H`aT48<@Q0Q3248<
HPaS5:HDY@4<H`0000DHaQcW6<HLib48008U:@056<HDYABU5:DLi`028@P011cW6<HDYABU0QS60R48
00PU:B487>LU:B486<HDYA240QBU00D@Q1S66<HU:B48008Li`8HaP8Li`8U:@038@PHaQBU00@DY@8<
H`0448@<Ha2436<248@35:D47>L35:D00a245:DHaP036<H27>L26<H35:D46<H348@25:D348@01QBU
6<HDY@aS5:DHaP8YBP039BTLiaS6008@Q0036<HLia24008<H`0448@HaQS65:D236<212400`Q21240
000=000412400`Q21240000J0002124600001@@Q0000000012400Q2400H<Ha2436<8@PaS248248@2
5:D36<H236<07@Q336<<Ha2348@<Ha2348@DY@aS24848@Q236<48@aS5:D@Q0Q2124<HacW48@48@Q2
5:DDYQ2324800`aS00<DY12548@00QBU00X@P`aS248<HQ2548@DY12436@@Q0<<H`0348@DYA24008@
Q0085:HLiacW5:D@Q0aS48DQ1`8Li`076<HDYA2448@<H`Q236<00a2400@<HPQ236<@Q08DY@0648@<
H`aS48@HaQBU0`aS00D@P`aS36<8@Q24008DY@@<H`086<HLiaBU48@<HaBU7>HDY@D@Q08<H`0:48@H
aQBU5:D@Q0aS5:DHaQcW6<H25:D021S648@<HaBU6<HLiaS536<248@00`aR24<8@@0236<15:D00005
5:DLiacW9BTQ20027>L25:D26<H28@P011cW6<HDYAcW0b4800THaQcW8@PU:B485:D@Q1BU7>L00QS6
00<DYAS67>L00QcW0R4800<HaQcW7>L00RU:00<U:AcW5:D01aBU00D@Q0aS36<<H`Q2008<H`056<HQ
22487>LDY@0248@011S65:DDYAS60QBU00<HaQcW7>L00QcW00@HaQBU6<HHaP8Li`<DY@046<HDY@aS
36<2248011BU6<HHaQBU0PQ20QS600DU:Be[8@PHaQBU00<@Q08DY@8@Q0055:DHaQBU48@8@P021240
0`aS1240000?0004124G00021242000010@Q000000000`@Q0`000P@Q0PQ200@DYAS66<HDY@848@88
@P0536<DYAS66<H@Q0035:D010aS2448@a240QBU00L8@P@R248<HaBU48@<H`02124010aS48@@P`aS
0a2400@<Ha245:D<H`88@P0424<@P`aS36<248@336<051BT48D@P`Q3248<Ha255:D@Q0aR24<@Pa25
5:@<I1245:DHaAS65:D56<H27>L03R487>LHaQBU36<DY12548@@P`aS48@@QA2448D248@021BU5:@D
YA2448<<I12348@236<0112436<8@PaS0QBU0PaS00D8@QBU5:DHaQBU00<@Q00;5:DHaQ255:D@Q0aS
5:D<Ha245:DHaP025:D02PaT48<DYABU6<HDYAS65:DDYQ240QBU0QS600LDYABV6<HDYQ242488@`03
36<15:D148@000<YBP068@PLibU:=JdYBQcW0PaS00<HaQBU6<H00QS60QcW00HU:BU:9BTLiaS68@P2
:DX38@P021S648@@Q1BU6<HDYAS67>L26<H021BU6<HHaQS648@DYAS65:D348@00aBU36<<H`0236<0
0`Q236<@Q0025:D020aS48@@Q1BU36<@Q1BU6<H25:D01PaS48@DYAS65:D@Q08DY@066<H@Q0aS48@D
YA240QBU00<@Q0aS5:D00a240QBU0a2400<HaQcW7>L011cW010HaQBU36<8@QS67>LHaQ2424848@aS
6<HLia24124000848B0000031240000000d00006124000001248@P@Q1@000`@Q00H8@Q2436<@Q1BU
48@336<01aBU36<<Ha246<HDYA2400<<H`0636@<H`aS3688@Q240PaS00H@Q12548@<H`@Q128236<0
1Q2436<@Q1BU6<D@Q08<H`0B5:D@Q0aS48@DYAS76<DHaQcW7>PHaQBU248<HaBT5:D@Q0aS0PQ200@D
YA245:DDY@8@Q0045:D<H`Q248@26<H248@011BU7>LLiacV0acW00@DYQS55:D<H`<8@P0348@@P`aS
00@<H`0548@@QABT48D@Q00436<00a2448D@Q00336<041245:DDY@aS48DHa@Q31208@Q247>LDY@Q2
36<@Q0aT0Q240`aS00H@Pa245:DHaQBU48@25:D01AcW8@PQ21cW6<D011BU0`aS00D@Pa2448@<H`Q2
004<H`0000TYBRe[;F/YBRDY:DX]JacW5:D00PQ200@DYB488@PLi`8HaP037>LYBRU:008U:@077>LQ
22DY:DXQ21S65:D00PaS00PDYAcW8@PHaQBU6<HLiaS60aBU0a240QS600<<H`Q248@00QBU00L@Q1BU
48@@Q0aS48@DY@0336<25:D236<01AcW6<H@Q0Q236<00aS60QBU0`aS00<DYAS65:D0212400X<HaBU
6<HHaQBU36<DYAS65:DHaP<Q20037>LHaQS600<@Q0065:D<Ha24248<Ha240QBU00D8@P00000000@Q
02X000031240000000D000031240000000800004124000@Q0002124236<548@010aS48@<H`aS0Q24
00DDYA2436<8@PaS008@Q00448<8@`aS48@236<224801PaR36<@Q0aS248<HP8<H`0448@<H`aS36@2
5:D010aS48@HaABU0PaS00H8@QS66<LLib486<H248@01@aS48@HaQS524<00PQ200@<HaBU6<HDY@8@
Q00>36<DYA2436<@Q1BU5:@@QABT48@Hab489BXQ208DY@046<D<I0Q2248236<010Q236<<I1240PaS
00H8@Q2448@DYA24248236<00aBU48@@Q00336<00aBT48@@Q00236<01QBU6<H@P`@R2488@`8DY@@<
H`8@Q00;48<<Ha2448@<HaBV7>LDY@aS248<H`026<H01AcV8@PQ21cW5:H00PaS00L@Q1BU6<DDYA25
5:D@Q00336<148@000095:DQ22U::DXHaQBU6<HQ21cW00<DY@0336<HaQBU008HaP8DY@DHaP8Li`05
6<H@Q1BU48@HaP027>L01aBU36<<HaBU7>LHaQBU008HaP045:D@Q1245:D436<01Q245:DDY@aS248<
H`8@Q00736<@Q1245:D<HaBU7>L00RDY00@DYA2436<@Q08HaP035:D@Q124008@Q0095:D@Q1BU7>LH
aQBU36<@Q1BU008<H`06248@Q1S66<HLiaS60Q240PaS00@@Q0aS5:D@Q08DY@046<HDY@aS36<248@3
36<011BU6<HDY@Q20P000P@Q<00000H48@Q26<HLia2436<7000212400`aS48@HaP037>L00a24248@
Q00248@25:D01AcW9BTLiaBU36<00Q2400@<H`Q2248<H`88@P8<H`055:HLiQBU36<8@`025:D04A24
36<@Q1S636<8@PaS5:HLiaS648@DYA255:@@Q1BU6<D00QS600TDYA2436@8@QBU6<DHaQS748@00PaS
00@@Q1BT48@8@`8<H`0348<8@PaS00<@Q00F36<@Q1S65:DHaR487>LHaQBU36<@Q12336@<Ha2448<<
Ha245:DDYQS548D336<348@324802A2448D<H`aS5:DDYQ2324<<H`025:D01A2336<<HaBT48@00`aS
00H@PaBU5:D@Q@aS248236<0112436@<H`aS0Q241ABU00LDY12448@<H`aT5:DDY00336<15:D148@1
36<000049BTQ21cW7>L38@P011S65:D@Q1241ABU00@HaQBU5:D@Q08Li`048@PYBQcW5:D248@021S6
5:D8@Q246<HLiaBU6<H27>L01a2436<DYAcW48@<H`Q2008@Q00536<@Q1245:D@Q00836<35:D02QS6
7>LLiacW48@DYAS65:DHaQ241ABU00@@Q0aS5:DHaP8DY@8<H`0848@DYA2448@<HaBU6<HDY@8@Q003
5:D@Q0aS0088@P8@Q0055:D@Q0aS48@DY@0248@01@aS248@Q1BU48@010Q200<48@0000001`000P@Q
9`0000D8@QBU7>LDY@@Q00<0000324800000008000041240012448@28@P00aS65:DDY@0236<01124
5:DHaQBU0QS60QBU0Q2400D@P`Q2124000@R008<H`8HaP086<D@Q@aS248@Q1BU6<H@Q08<H`035:D@
Q0aS008<H`8@Q00448<<Ha245:D26<H021BU48@DY1255:DHaAS65:H25:D01AS55:D@Q@aR12800PQ2
00`@P`aS36<48PQ236<<I12436<@Q1S67>L25:D021cV8@TLiQ2436<8@`aS368236<01@aT36<@Q1BT
5:D00Q2400H<Ha2448@<H`Q236<224802`aS48@HaAS65:D<Ha2436<@Q1BU48@00PaS0a2400X@Pa24
36<@QABU6<HDYA2436<8@P8<H`0448@@P`aS36<248@011BU48@DYABU0Q2400LDY0aT36<@P`aS48D@
Q00236<148@136@148<000<HaP085:D@Q1cW8@PU:B486<HDY@8HaP8Q208Li`059BTLiaBU48@HaP02
:DX02248:DXQ21S65:D@Q1BU6<H35:D00a245:DDY@035:D01AS65:DDYABU48@010aS00@HaQBU6<HH
aP8DY@046<HDYA2436<248@02QBU48@<HaS67>LU:AcW6<HDYA240`aS0Q2400@<Ha245:DHaPHDY@04
36<DYABU6<H27>L00aS648@<H`025:D030Q21248@QBU48@<Ha245:D@Q0aS48@<H`8@Q0<<H`0448@<
H`Q2124O0002124B000236<26<H248@00`aS12400003124300004@@Q248HaR487>LHaQ24124<H`Q2
5:D@Q0aS5:DHaQcW6<H00Q2400<<I0aS36@00PaS10Q200@@Q1BU5:DHaP8@Q08<H`0=48@<H`aS36<@
Q0aS248@Q1BU5:HHaABU5:H011BU00H@Q@aS36<@Q1255:@236<011245:D@P`aS0Q240PaS0PQ200H<
H`Q236<@Pa2436<248@01ABT48@@Q1256<D00QBV00<DYAS55:D00Q240QBU0PaS00L@QAS548D@Q123
48D@P`0236<248@236<00`aR36@<H`0336<011BU7>HDY@aS0PQ20PaS010@QABU5:HHaABU6<HDYAS6
7>LDY@aS368<Ha2436<8@`88@P0936<@Q1BV5:D@Q0aS2488@a23008<H`0336@@Q12300<<H`4<HP4<
H`000acW00HDY@aS6<HHaR486<H25:D00acW8@PQ20028@P25:D00b487>LYBP028@P01BDY8@PU:AcW
5:D00Q2400XHaR487>LHaQ2436<DYAS65:DHaP8DY@0>7>LHaQ2436<8@PaS48@<HaBU7>LHaQBU36<8
@P8@Q08DY@056<HDY@aS5:DHaP028@P26<H0112436<<H`aS1A240aBU0QS600@DYA2436<DY@8@Q08D
Y@8Li`0<5:D@Q0aS48@<H`@Q248@Q1S65:D<H`Q2112400@DY@aS2488@P<<Hb<000848A40000448@H
aR487>L324821243000212400`00248@Q0028@P011BU48@<H`Q20`aS00HDYA246<HLib487>L236<0
3`aR48@@Q0Q224448Q2348@<Ha2548@HaAS65:D@Q0022480112436<<H`aS0Q2400L<HaBU6<HDYA24
36<DY0026<H01ABU48@@P`Q236<00Q240aBU00LDYQ2436<8@`aS48@8@`02248236<06@Q248@@Q124
36<8@Q2436@8@PaS6<HLib476<H@Q0aT48<@QABT36@@Pa245:DHaA24008<H`0548@DYA2436<<I002
36<01A2324<8@`aR24800`aS00@DYABV6<HDY@<<H`06248@P`aT5:DHaQcW0R4800DLiaS648@<H`Q2
00H<H`04368<I1BT5:D336<02A2336@<H`aS5:@@Q0Q3248<H`025:D148@0008Li`8DY@046<HDYA24
36<448@02PaS48@@Q1BU9BTYBR487>LDYAS60R480RDY00LYBQcW7>LLib489BTYBP028@P00aS65:DD
Y@035:D011S65:DDYABU0QS600HDY@aS36<<Ha246<H248@25:D336<348@27>L012487>L@Q1240QBU
0aS600<DYAS66<H00QS60QBU0Q2400@<Ha245:DDY@8@Q08<H`076<HLiacW5:D<Ha2436<00PQ200T<
Ha2436<<Ha246<H@Q0Q248@00QcW00D@Q0Q2248<H`@Q03400003124000000080000336<8@Q2400<D
Y@0336<8@PQ200P0000848@HaQcW7>L@Q0Q236<48@88@P03124@Q124008@Q00724848@@R36<DY124
24<00`Q20`aS00T@Q1BU48@<H`aR36<@Q@aS36800PQ20PaS0QBU0`aS00@<I1S55:DDYP8DY@036<HL
iaBU008<H`0:48@LiacW6<HDYA24248<Ha2348D336<848@00a2348@<H`0348@00aBU6<HDYP035:D0
2AS67>LDYA2548@<Ha2436<8@P0236<248@01A2336@<Ha2336<00PQ20148@`aS48@<Ha2348@8@`aR
1288@@aT5:DLiaS65:D<Ha2400<HaP0348D8@PQ2008<H`0648<<H`aS128<HPaS0QBU00@<H`Q336<@
Q08<H`0424<<H`aS5:@25:D26<H0008Li`046<HDYAS65:D46<H248@00`aS5:DLi`038@P00acW8@PL
i`037>L00bDY;F/YBP037>L00bDY:DXQ20027>L35:D26<H01Q2436<<HaBU6<H@Q0<<H`0448@DYA24
48@25:D00a2436<<H`0248@011BU6<H@Q1S60QcW0Q240QBU0PaS00TDYAcW6<HDYAS65:DHaQcW48@0
0PaS00TDYAS648@8@PaS6<HDYA245:D00QS600@@Q0Q236<<H`88@P0348@HaQ24008<H`8@Q00636<@
Q1S65:D<H`@Q0Q2400<48@0000002`0000<48@000000100000<48@Q200001`0000<8@P@Q12400`00
00<8@P@Q00003`0000P8@QBU7>L<H`@Q248@Q0Q2100000h48@00000000@Q7>LQ21cW6<H<H`Q236<8
@PaS0`Q200<@Q1BU36<00PaS0Q2400D<H`Q2124480@R008<H`8@Q0035:D@Q124008<H`0324<@P`aS
008<H`<@Q00436<8@PaS48@26<H00aBV6<DDY@035:D03aS65:HDY1BV7>LHaQBT48@DYAS536@<HQ24
6<D@Q00336<01ABU36<DYABU48@00`aS00L@Q0aS36<DYAS68@PLiP026<H00aBU6<HDY@0248@00`aS
48@<H`0236<348@536<3248348@04`aS48@<I0aS368<I0aR128<HQBU7>LHaQ246<HLiaS65:DDY124
00@<H`0624<<H`aR36<8@`aS0QBU00<DY12448@00Q2400L<Ha2448@<Ha255:@DYP025:D000058@PL
iaS66<HDY@026<H35:D0312436<DYAS67>LHaQcW8@PU:BU:8@PLi`8DY@8HaP047>LQ22489BT28@P2
:DX012487>LHaQcW0R4800DLiaS648@DYAS6008Li`096<H<H`Q25:DLibDY7>L<H`Q2008@Q0045:D<
H`Q224825:D248@26<H00aBU48@<H`045:D02@aS48@DYAS65:D@Q0Q248@HaP027>L01Q2436<<H`aS
48@DY@8<H`0348@DYA24008@Q0045:D@Q12448@25:D01Q246<HLiacW8@PDY@D@Q0032480000001@0
0004124@Q124124900001@@Q36<<H`Q21240200000<48@0000001@0000<8@PaS248010000P@Q0P00
00X8@P@Q000000Q27>LQ21S65:D@Q0848@05248<Ha2436<48@02248236<2248020@Q36<<Ha2348@8
@PaR36@248@020aS48D@Q0aR248<I1BU48@224800`aS5:D@Q00248@021BU48@@Q0aT5:DDY12548@3
36<021245:@DYQS65:D<H`Q3368248@00`aT36<<H`0224803@aS48@DYABU36<8@PaR48DDYA24248<
Ha24008HaP@Li`036<HDYQBT008DY@<<H`0448@DYA2436<224801Q245:D@Q0Q236<@Q08<H`0:48@<
H`aS3688@a2336@8@PaS48@27>L01QS65:D@Q1BU6<D@Q@D@Q00436<<HQ2448D26<H0212436<<I1BT
5:D@QABT48@236<01@Q248@HaQcW5:D00@aS000011cW6<HLiaS60aBU00`HaQBU5:D@Q1BU36<DYAcW
:DXU:AcW6<H27>L25:D021S69BTQ21cW6<HQ21cW8@P2;F/02BDY7>LHaR48:DXQ21S65:DHaP025:D0
11S67>LHaQBU0Q2400@HaQcW6<H@Q08<H`055:D<H`Q2248<H`0248@02aBU6<HDY@aS48@DYAS648@<
Ha246<H00Q2400@<Ha245:DDY@<<H`0348@LiaBU008@Q0<DY@<@Q0035:D<H`aS008<H`085:DHaQBU
36<8@PaS5:DHaPDDY@8<H`88@P031240000001<000041248@PaS36<21247000224800a242480000>
00000`@Q00048@0224840003124500001A246<HLiacW48@010Q200X@Q0aS12448@Q248@@P`Q20004
8@<8@P0424<@Q0aS248236<011BU48<<H`aS0PQ20PaS00@@Q0aS2488@P8@Q003248<HaBU008DY@07
48@DYABU48@@P`Q236<00QBU00DHaQBU48<8@a23008HaP0536<8@PQ248@<H`03248236<0112436<<
H`aS0Q2400LDY@aS36<8@PaS6<HHa`028@P26<H0112448<8@`Q10PaS00<@QAS548@00PaS0188@PaS
36<8@PaS48@DY@aS248<Ha2436<8@`aR36<@Q0aS368236<011245:DHaQS60aBU00DHaaS536<8@`aS
008@Q0042488@`aS48<35:D01aBT48D@Q0aS5:D@QA24008<H`0548@DYABT5:D@Q0015:D0008Li`03
48@<H`aS008DY@0948@DYABU6<HLib487>LHaQBU008Q2003:DXU:AS600@Li`046<HLib489BT2:DX0
1Be[<H`e[C6<:DX00RDY00@Q22DY9BTU:@8HaP065:DLiaBU48@<Ha240QBU00<@Q1BU48@00PaS00@@
Q1BU5:D@Q08<H`0448@HaQS65:D236<011BU6<HQ21S60QBU00<HaQcW6<H00aBU0Q2400HDYAS66<HD
Y@aS48@35:D00aS648@<H`0236<45:D27>L00aS65:DDY@0248@2248236<00aBU6<H<H`0J00000`Q2
0000000700001P@Q248HaQcW36<48@@000031240000000P000848@X0000624848@0000048A240aS6
00PDY@Q22488@PaS48@<H`Q20P@Q00<00@Q224800PaS00D8@PaS248<HPQ300<8@P0336<@QA2400L<
H`<8@P0D48@8@P@Q248<HaS55:H@Q0Q2128<HaBU48@<H`Q236<@Q0aS2488@`@<H`0948<<H`aS36<8
@PQ3248<Ha24008<H`04248<Ha2448<236<00a2436<<HP0248@01A2336<8@PaS48@00PaS00@8@a23
48@@Q08<H`88@P0436<@Q12436<324801`aS48@<H`aR36<@Q0aS0088@P0336<HaQBU008HaP<DY@07
48@<Ha2448@DY0aS24800PaS00/<HQ245:HHaQBT36<8@a245:DHaPaS00848@0736<DYABU48@<I1BT
48D00ABU00000aS65:DDY@0248@35:D00a246<HDY@027>L48@P47>L26<H01AcW8@PQ22DY8@P00bU:
0Sg_00/icS6<8@PQ22U:;F/YBQcW5:D@Q1BU008Li`046<H8@PaS48@26<H02A2436<<H`Q248@HaQcW
6<H@Q00224802ABU6<HHaQBU36<@Q1BU7>LHaP025:D248@36<H35:D01AS65:DDYABU6<H00QBU00D<
Ha245:DDYA240088@P0>48@LiaBU5:DLibDY7>LHaQ2436<@Q1BU36<8@P8<H`8HaP0336<8@P0001D0
00848@0324848@0000P00004248DYAS648@60002124=000212450002124200001P@Q248LibU:8@P@
Q0848@0336<HaPaS0088@P0<1248@P@Q1248@Q245:D<H`Q2124<H`Q20P@Q00`8@A2448DDY0aS368@
Q1S636<8@P@Q36<248@02PaS248<H`aS48@DY12448<@Q0Q20PaS00HDY1BU36<<HaBU36<224801Q23
5:D@Q0Q336<@Q08<H`03248<H`aS00D<H`<@Q088@P0324<<Ha24008<H`<@Q00424848@Q2248348@0
11BU36@<H`aS0PQ20PaS0Q241@aS00<8@PaS24<01@aS00<@Q1BU5:D011BU0PaS00hDYAS65:H@Q0Q2
36<DY0aT48@@Pa2436@<Ha230a2410aS00H@P`aS36<HaQS75:@136<000D@Q08DY@066<HDYAS65:DL
iaBU11S60QBU00THaQcW7>LLiaS67>LQ236<=Jd00S6<00Te[Be[;F/]JcF];F/U:B48:DX00S6<00<Y
BR486<H00a2400XDY@aS124DYBDY;F/Q20aS48@Li`8HaP085:D@Q1BU5:DQ21cW8@PLi`8@Q0075:DH
aQcW6<HDYAS68@P011BU0QcW00<HaQBU48@00aBU0PaS11BU00D@Q0aS36<<H`Q2008@Q00:7>LHaQBU
6<HQ21S648@8@P@Q5:D27>L00a240000000P000010@Q000000@Q0PQ200<48@00000020000P@Q4000
10@Q0P0000D8@Q248@PYBQcW008DY@88@P<DY@0348@8@PQ200<<H`0348@DYABU008<H`08368<H`Q2
128<HPaS5:D@Q@8<H`0748@HaQS636@<HPQ236<00QBU0PaS00@@QAcW7>LLi`8DY@0348@DYAS6008D
Y@036<HDYA24008<H`0336@@Pa2400@<H`035:D@Q0aS008<H`8@Q00;24<<HPaT5:D<H`Q3368@Q1S6
5:D<H`02248010aS5:DDY@aT0PaS00@@Q1BU48@@Q08<H`8@Q00348<<H`Q20088@P0<36<@Q0aS36@@
P`aT48<<H`Q236<@Q1250QBU00<@Q1BU7>L00QS60QBU00<@Q1BU48@010aS00P@Q1BU36<<H`Q236<D
YA240`aS00D@Q1BU5:D@Q0aS008@Q08HaP4@Q00000<<Ha2448@00QS600<DYA2448@00QS60aBU1aS6
00HLib486<HDYAcW:DX2>Lh00c6<:DX]J`03<H`00bU:9BTYBP02;F/2:DX00b486<HDY@0248@22480
1PaS48@Q22DY7>LHaP8<H`0448@DYABU48@25:D00aS67>LQ20026<H45:D011S65:DHaQS60QBU00@@
Q1BU6<HDY@8HaP055:DHaQcW6<H@Q00236<348@010Q248@<H`Q20PaS00<@Q1BU5:D00QcW0QS600T<
Ha2436<<HaBU6<HDYA2412407`000`@Q0`0000<48@Q212403@0000<48@Q212402`0000<8@P@Q0000
0P000P@Q00DDYAS67>LQ21BU008<H`0348@<HaBU008DY@0548@8@P@P1248@P0348@236<3248040Q3
48<8@PaS48@DY1255:@DYA2536<@P`Q3248<Ha240aBU00@HaQcW6<H@Q08<H`035:DHaQ25008<H`07
5:DLiaS636<8@`aR24<011240PaS00X@Q0aS248<HaBU48D@P`Q348<DY@8<H`0748@DYABU36<@Q0aS
24800`aS00<@P`aS48@00QBU00L@Q0aS36<<Ha2336<<I00436<05@Q236<<H`aR48DDYA24248<Ha24
6<H@Q1BU6<HQ21S648@HaQcW6<HDY00336<01aBU48@<H`Q236<@Q0aS0088@P8<H`8@Q08<H`04368<
I12348D248@00aBU6<HDY@016<H000076<HQ21S65:DHaQBU48@00PaS0Q2400LDYAS67>LQ21cW6<H@
Q0025:D57>L26<H01248:DXe[CF]0S6<00<]JbU:=Jd00SW>00T]JacW8@PU:AS648@<Ha2436<00PQ2
00<<HaBU48@00QBU00@@Q1BU5:D@Q08DY@046<HQ21cW5:D248@25:D021245:DLib486<H@Q1S67>L2
9BT01QcW5:DLiacW8@PLi`8DY@036<HDYABU008DY@036<HDYAS6008@Q0035:D<H`Q2008<H`0648@D
YA246<HDYA240PaS00<DYAS65:D00PQ20P@Q00<8@P0000005`0000<48@0000001@000P@Q2@0000<4
8@0000001P0000@8@P@Q00048@L000848@0348@<H`0000<0000536<48@Q248@DY@026<H011245:DD
YAS60QBU01@8@P@R36<@Q1BV48<8@P@Q248@QABU5:HDY0Q336<@Q0aS48@<H`aT0PaS01<@Pa2548@<
H`Q236<<HPQ26<HLibDY8@PHaQBV5:@8@P@R244<H`025:D248@02PQ2368<I1BT6<HDYA2436<@Q1BT
0PaS00<@Q0aS36<00PaS00<DY@aS36<00Q2400@<I0Q2248<H`L@Q00336@@P`aS00<<H`0348@<H`aT
008<H`<@Q0<<H`0348<@Q@aS008<H`0748DDY1BU5:DLiaBU48@00PaS0QBU1a241PaS00<<I0aR36<0
1PaS00<@Q12548@00PaS00<@Q1S66<H00ABU00026<H01QBU6<HDYA245:D@Q08<H`0;48@HaQBU5:DH
aQcW6<HDYA245:DLi`028@P01QcW6<HLibDY8@PYBP8e[@08;F/YBRe[=JdicSg_9BTLi`8HaP097>LH
aQBU48@DY@aS248<H`Q2008DY@<@Q003248DYAS6008Q20066<HDYAS65:D@Q1S60acW00/DYA2448@@
Q1S67>LQ21cW6<HLib48008Li`035:D@Q1BU00HHaP0348@8@PaS008@Q0035:D<H`aS008<H`<HaP0:
5:D@Q0aS248@Q0aS5:D@Q0aS248g00001@@Q0000000012401`000PQ20PaS10000PQ200D@Q1S67>LH
aQ24008<H`0?5:DLiaBU48<48PaR48<<I0aS24<<HPaT48@DY1BU00@<H`8@Q08<H`0548@DY12548<8
@P02124040Q236@<H`@Q5:@U:C6<7>P<HPaS5:HDY0aS24<<Ha230`aS00<@Q0aT48@00`aS0Q2400hD
Y@aS36<<H`Q35:D@Q12336<8@Q2436<@Q0aS0PQ200<48@aS36<00PaS00<<I12436<00a240`aS00<@
Q0aS36<00PaS112400T<H`Q224<<HaBU5:@<I12336<00QBU00PHaQ2448@DY1BU48D@Pa240QBU00<@
QA2436<00QBU00X<H`Q2124<Ha2436<<HPaT5:D<H`<8@P0648@<HaBT6<HDYA240PaS0aBU000248@2
6<H25:D03AS648@<Ha246<HQ21S65:D@Q1S65:D@Q1BU008HaP055:D@Q1S67>LHaP035:D00aS67>LL
i`026<H00aBU6<HLi`027>L55:D0112436<<H`aS0Q240aBU00<@Q0aS48@00QS600DLibDY:DXQ21S6
00<<H`0348@HaQ24008DY@046<HLiacW8@P37>L04A24248DYB489BTQ21BU6<HLiaS67>LYBRe[9BTH
aQ245:D00QS60PaS00P8@PaS5:D@Q0aS5:DLiaS6112400<DY@Q200000P0000D48@00000000@Q01H0
00031248@P0000<000031240000000X000848@T000848@<0000312400000008000848@H000051248
@PaS48@<H`035:D04Q2436<<Ha2436<<I1S548@<H`@R1208@PaS248DYAS65:D@Q08<H`0?5:DHaQBV
36<8@PaS6<H@Q0Q2124<HaBU48@<I1BU00<HaP0748@<H`aS48@LiQcW36@00PQ200<<HaS66<H00PaS
0PQ200<<Ha2448@00QBU0PaS00D<HPaS36@<Ha24008<H`04248<H`Q236<248@236<00`Q236<@Q002
5:D01Q2436<<H`aS24<<HP8<H`0348@@P`aS00<8@P0448@DYABT48@236<0412336<8@PQ336<DYAS6
48@<H`Q3368@QABT5:D@QABT0QBU00d@Q0aR24<@Q0aS1288@PaR36@@Q12336<8@P0236<25:D021BV
7>L@Q0aS248<HaS65:D148@0000348@HaQBU008HaPPDY@036<H@Q124008DY@DHaP035:DHaQBU008H
aP047>LDYAS66<H27>L01QS65:DLiacW6<H@Q0<DY@<<H`0348@DY@aS0088@P0336<HaQBU008<H`06
5:DQ22U::DXQ21240PaS00L@Q1S65:D@Q1BU6<HDY@026<H01acW9BTU:AcW5:D@Q1BU008Li`038@PU
:AS6008@Q00<5:DU:BDY8@PLib487>LHaQBU48@<H`Q20PaS00HDYA245:DHaQcW5:D236<248@010Q2
000000@Q7P000P@Q3@0000<48@0000001P000P@Q1@000P@Q100000<48@Q21240100000D8@P@Q2488
@QBU008HaP8@Q00436<DYAS65:D236<248@010aS24448@Q20`aS00h@Q1S66<HDYABT5:HHaQS55:D<
Ha2436<DYA240PaS00L<HPaT36<DY1S67>LDY@0236<01QBU36@<Ha2448<@Q0T<H`0448@DYABU48@2
36<01`Q248@DYA2424848@Q2008DY@8<H`D8@P8<H`065:DHaQBU48@<H`Q21PaS00<@Q0aS36<00PaS
00<@Q1BU48D00`aS0Q2400<8@`aS48<00QBU00<@QABU36<00PaS00/@QAcW6<HDY@aT5:@DYA2548<<
H`Q200<<H`0748@<H`aS36<@P`aS48@00aBU0a241ABU000021BU6<HHaQ2436<@Q1S65:D248@01aS6
8@PHaQBU6<HLib4800<Li`<DY@056<HQ22487>LHaP035:D46<H00b487>LHaP035:D00aS648@@Q002
48@236<35:D01A2436<@Q1S65:D00aS60R4800PHaPaS36<HaQcW5:D<H`Q20QBU0QcW00<DYA2448@0
0aBU00<<Ha2448@00aBU0Q2400hDYAS68@PLiaS65:D@Q0aS6<HQ21cW5:D8@Q240aS60QcW0R4800@H
aQBU2488@P@000848B80000324848@00008000031240000000<000848@`000031248@P0000<00084
8@T00006124<HaS66<HDYA240PaS00D@Q0aS36<<Ha24008<H`0324848@aS008@Q00936<8@PQ248@D
YAS67>LDY@aS0088@P8@Q00736<@Q1BV5:@<H`aT48@00QBU00<<Ha2448@00PaS00H@Q1255:@@QA23
36@336<00`Q236<<H`0536<248@01@aS48@<HPQ236<00QBU00<@Q0aS24800PaS00H8@Q2448@@Q0aS
1242248236<01@Q236<8@PaS48@00PaS00<8@PaS36<010aS00L@Q0aR36<8@`aS48@DY00248@02ABU
6<HHaA2436<@Q1BU6<H@Q00236<348@236<01a2436<<H`aS36@@Pa25008DY@095:H@Q12548@@Pa25
6<HHaA25008<H`4DY@4HaP4HaP0000XDYAS65:DDYAS648@8@PaS48@Li`8HaP055:DHaR488@PLi`03
5:D02AcW6<HHaQcW8@PLiaS65:DHaP035:D02AS67>LDYABU7>LHaQ2436<DY@026<H00a24248<H`02
36<00a2436<DY@045:D01Q246<HLib487>LDY@<HaP0436<@Q1BU6<H25:D00aS67>L@Q00248@041cW
48@8@PaS6<HLiaS648@<Ha2436<DYAS68@PLiaS61ABU0QcW0aBU00<LiaS65:D00QBU0QcW0QBU00@4
8@00000000<48@@000031240000001/000031248@P@Q00T000031248@P@Q01400004124000001244
0003124236<25:D248@01@aS248<I12336@00`aS00D@Q0Q32488@PaS008DY@0448<<I12448@35:D2
48@236<0212436<DY12436<8@a2348@35:D00`aS24<@P`025:D01Q2424<<HPaT5:@@Q0<<H`0948@@
QABU36<<HQ256<HDYA240088@P0336<8@PaS008<H`0=368<H`aS36<@Q1253688@P@R244@Q0aS48@0
10aS00P@Q0aS48@DY@aT36<<HPQ30PaS0`Q200T48PQ2368<Ha2548@DYABV48@00PaS00TDYAS636<@
Pa246<HDY@Q236<00QBU00@<H`Q236<@Q08<H`0>368<I1BT5:DHaQBU48@@Pa245:DHaA2548@Ha@8D
Y@4@Q048@P4<H`0000<DYA245:D00QBU0aS60Q240QBU00@@Q0aS36<@Q0@HaP045:DHaQS66<H37>L0
2QS67>LQ22U:<H`YBR486<HDYAS60QBU00T@Q0aS48@<Ha246<HDYAS67>L00QBU00@<H`Q25:DDY@8H
aP8DY@067>LQ22487>LHaQBU0aS600@DYA245:DDY@8HaP035:DHaQS6008HaP8@Q0045:DHaQcW6<H5
5:D011S67>LHaQS60aBU00X@Q1BU6<HHaPaS48@DYAcW8@PHaP8Li`035:D<H`0000<00003124000@Q
00848@<00004124<H`aS248<00000`@Q00048@020003124424800`@Q000000020002124500021240
11245:DDY@Q26`0000<48@aS36<00QS60QBU00L8@PaS5:DDYA245:D@Q00336<01a245:D@Q0Q32488
@@@R008@Q0045:DLiacW6<H35:D011BV5:D@Q1BT0PaS00D@Q0aS48@@Q123008<H`0836@@Pa2436<D
YAS68@PLi`8DY@096<DHaQS66<HDYPaS248<Ha24008DY@8@Q0<DY@0324<8@PQ2008<H`043688@PQ2
124236<01A2436<<Ha2424800`aS00PDYQBU5:DDY@Q236<8@PaS0`Q200l<HPaT48@<Ha2436<@Q1BU
5:@<H`Q348@DYA2424<01@aS0a240PaS00@@Q1BU5:D@Q08<H`<@Q0045:D@QAS55:H248@01QS56<HH
aaS648@8@P4<H`001QBU00@HaQBU6<HDY@8<H`0448@HaQcW7>L45:D05AS68@PQ21cW6<HLibU:8@PH
aQcW8@PYBRDY7>LHaQBU7>LHaPaS248<H`036<H25:D348@00aBU48@DY@0448@25:D46<H00aBU7>LL
i`027>L01ABU48@DYABU6<H00acW1AS611BU00LHaQBU5:DHaQcW8@PLi`0236<021246<HLiaS6248<
Ha245:D36<H25:D012489BT<H`@Q0P0000D48@00000000@Q00@0000424848@Q236<2124?00001@@Q
248<H`Q212400P000PQ2100000<8@P@Q00001@0000D48ABU48@<H`Q200D000031240000000X00003
1240000000@00008124000@Q48@DYAS65:D<H`8@Q08<H`05248<Ha246<DDY@0236<248@010Q236<@
Q1BU0PaS00DDYAcW5:DDYA24008HaP075:DDY1245:D@Q1BU36@00`aS0Q240QBU0PaS00d@Q1S68@PL
iaS65:DHaQcX8@PLiaS548<@Q00236<248@011BU5:H@Q1240`aS00@@P`aS2488@P<<H`<8@P0448@D
YA2436<324801@aS36@@P`aS48@00QBU00T<I0aR248<H`Q236<<I1BT5:D00Q2400h@QABT5:D<Ha24
3688@PaS48@HaA2436<48@Q20PaS0a240PaS00/8@Q2448DDY0Q3248<HaS57>LHaQ25008@Q00636@D
Y1BV6<DDYA240PaS00001AcW8@PU:BDY7>L00QBU0aS600<DYAS66<H00QS600@@Q1BU6<HHaP8DY@03
6<HLiaS6008HaP037>LHaQcW00@Li`LHaP<DY@036<HDYABU008DY@8Q208HaP035:DHaRDY008Q208H
aP045:DLib487>L26<H01R48;F/]Jb486<HLi`8Q20087>LDYABU48@<HaBU7>LHaP8<H`056<HQ21S6
5:DHaP029BT01AcW8@PQ21S65:D00PaS00<DY@aS48@00Q2400@<Ha2436<<H`8Li`035:D8@P0000L0
00<48@0400048@Q2124236<224801P@Q0000000024848@@00088@P0300048A24008Q20<HaP0648@<
Ha2448@8@P@Q2@0000DDYBU::DX@Q0@Q0088@P<000031240000000@0000424848@@Q124300021245
00003P@Q248001S6:DXicS6<6<HLiQcW5:DHaPaS36@236<02a2436<8@PaS24448@Q2368DYA245:D0
0a2400X<HaBU6<HDYA2548@HaQBU48@8@P8<H`8@Q00<48DDY0aS24<@Pa256<DDYQBT5:DHaQS50aBU
00D<I0aS48<<HaBU00H@Q00536<@Q0aS24<<HP0524800`aS248<H`0336<0312436<<H`aS48<<H`Q2
36<@PaBV6<D8@`<8@P045:D@Q0aS36<248@336<01a2436<@Q1255:@@Q0aT00@@Q0<<H`07248<Ha25
5:@<H`Q124800QBU00<HaQS76<H00aBU00DDY1255:@@QABT00@@Q04<H`000RU:0b4800DHaQ2448@D
YAS600<DY@036<HDYAS6008HaP047>LQ21cW6<H25:D26<H37>L28@P01AcW5:DDYB487>L00Q240QBU
00<<H`Q25:D00QcW00D@Q1BU7>LHaQ24008DY@048@PHaQS67>L28@P031S67>LQ21S65:DHaQcW<H`]
JbU:8@PHaP8Li`046<HDYABU6<H35:D02AS65:D<H`aS6<HU:AcW6<HQ2002:DX01b485:DDY@aS248<
Ha24008HaP0636<8@PaS36<DYAS60QBU00<<H`Q224801`0000@48@00000000848@0336<8@PQ200<8
@PP00003124000@Q008000065:DLib488@P@Q0aS0Q2400@DY@Q2124000848@0324848@0000@00006
124Q22e[9BT<H`000P@Q00@000@Q24848@<000031240000000800006124000Q2124000@Q1@0000H8
@PaS24848ABU8@P2=Jd021S75:D<H`aS48@DYA2336<524800`Q3248<H`0248@020aT36<DYAcW5:D@
Q0Q236<45:D336<07@Q236<<HPQ3368<I12348@<I0aR36@DY1BV5:D@Q1BU6<HDYQ2436<DY@aS248<
HaBU6<H@QA235:D00Q240PaS0Q2400<8@`Q224800P@Q0PQ200<<Ha2448@00Q240PaS00TDY1255:D@
Q12348D@Pa2436<00PQ20PaS0Q2400@<H`Q3248<HP8<H`035:D@Q124008DY@8@Q00336<<I12300D<
H`0548@@P`aT36<@Q0025:D02A255:@DYABU6<HLiQBV5:D@P`0248@336<148@136<148@000<U:@03
8@PLiaS6008HaP8DY@<HaP055:DHaQcW6<H@Q0026<H012DY8@PQ22480QcW00<HaQBU6<H00QS60QcW
00@DYA2448@HaP8Q200:7>LDYABU6<HQ236<=JdYBRDY5:D26<H011BU7>LU:AcW0QBU00<@Q1S67>L0
0acW00<HaQBU5:D00aS601/DY@aS48@LibU:;F/Lia2436<HaR48:DXLia245:DHaQ245:D@Q1S648@<
H`Q236<@Q0Q236<011240PaS00@HaR487>L@Q0800004124<H`aS248600000`@Q00000002000010Q2
12448@Q20P@Q10000P@Q0`0000L8@PaS248001BU6<INm`02Ool027>L<H`HaRe[=JdU:AS648@22484
12401`Q2000000@Q48@LiaBU0088@P@000032480000000@00004124000@Q124400000`@Q00000005
000010@Q48@<HaS60R4800@HaQBU48@DY@8@Q08<H`0448@<Ha2436<212402001124@Q1245:@@Q0aS
248336<00a2448<<H`0236<00`aR36<<H`0248@010aS2488@PQ20`aS0QBU00DHaQcW7>LHaaS5008@
Q00A5:@DYA2536<DYAS65:D@P`Q236@DY@aS248<Ha2424<8@@0224801@aS2488@PaS5:D010aS00L@
QABT48@@Q1255:@@Q@0236<00`aT48@<HP0236<248@040aS2488@PaR36<@QABU36<8@`aR36<@Q123
48@<Ha240PQ200<<Ha2436<00PQ200T<Ha2436<<I0aS5:DHaAS65:D00Q2400/@QABT36<<HaBU48@<
H`Q224<@Q1BU004<H`0000TLib48;F/Q21cW48@DYAS648@00QS60acW00HHaQBU5:DDYAS67>L29BT9
7>L36<H02ABU6<HLiacW6<HDYA246<HYBP02<H`012487>LLiacW0QS60R480aS60R4800<LiaS66<H0
0QcW00HHaQBU6<HLib487>L25:D01AcW9BTYBRDY8@P00QBU00@HaR487>LHaP8@Q08DY@0348@DYA24
008@Q08<H`04248<Ha2436<25:D46<H25:D0112436<<H`@Q1`0000<48@0000000P000P@Q0`000P@Q
200000P8@PaS1248@P@Q000YBV<H0Woo00MJeSg_>LhQ22DY7>LHaP025:D2248700001A245:DHaQ24
1240100000<48@0000000`000`@Q00@8@P@Q000000<48@L000848@045:DLib488@P25:D00aBT36@D
Y0025:D01A2436<8@P@Q24800PaS00X<HP@Q1248@Q245:DDYQ2324<8@P8@Q00536@8@PQ236@@Q003
36<00a2436<<H`0348@236<01A246<DDYQcW8@L00QcW00HDYA245:D8@`aS5:D26<H0112424<<Ha23
0PaS00<8@PaS24800PaS00@8@P@Q2488@P<<H`88@P8<H`035:D<H`aT008<H`0348@@QA23008<H`8@
Q0045:D<H`Q2248436<224801A245:DDYAS536@00`aS00@DY@aS2488@P@<H`065:D@P`Q3248<HaBT
0PaS00<DYAS66<H00QBU00XHaPaS24848Q235:H@Q0aS368<H`88@P0000<DYA2436<00Q2400@DYA24
248<H`8@Q08DY@8@Q08DY@046<HDYABU5:D36<H25:D26<H01AcW5:D@Q1245:D00R4800DLiaS65:DD
YAcW008Q20057>LHaQBU6<HLi`028@P00acW5:D@Q0025:D36<H35:D00aS67>LHaP026<H02QBU6<HH
aQ245:DHaR485:D<Ha240QS60QBU00T@Q1cW:DXU:AcW36<8@PaS48@00QBU00<@Q0aS24800PaS00<@
Q0aS48@00aS600<DY@aS24800P@Q0P0000<8@PaS12400`0000<48@000000100000<8@P@Q00000`00
0`@Q1P0000D48@Q26<HQ212400<<H`03@Q1S67oo00Eoo`03Kg/mkc6<008DY@05248000@Q0008@P03
12401@Q236<<H`Q21240100000<48@0000005@000PQ20QcW00DQ22U:6<HDYA2400<<H`0936@<HPQ3
248@Q0aR12848@Q2008@Q08<H`0<36@8@PQ1248<Ha2336<8@PaR36<8@`aR0PaS0Q240`aS00T8@PaS
36<@Q@aS6<DLib486<H00Q2400DDYAS66<HDYABT008<H`8DY@036<H@Q124008DY@0548@<H`Q236<@
Q00336<01Q246<HDYA23248<H`D@Q00548<<H`aS36<@Q0025:D336<01Q2436<8@PaS48@<H`88@P09
36<@Q0aT248@Q12536<8@P@Q008<H`0348@8@PQ2008<H`0648D@Q0aS248@Q1BU0QcW00@DYA2448@@
Q0<DY@085:@DY@aS36<8@PaS48@8@P448@0000dDYA245:D@Q0Q236<DYAS648@<HaBU6<HDY@0248@0
0aS65:D@Q00248@25:D03QS67>LHaQBU48@DYAcW5:D@Q1BU7>LU:AcW6<H27>L00aBU6<HDY@037>L0
22U:;F/Q21BU48@HaQcW6<H25:D26<H35:D00aS68@PLi`035:D02B487>LHaQS648@DYAS65:DHaP03
5:D348@022DY:DXQ21S636<8@Q2436<248@00`aS248<H`0224802ABU7>LLia24248<HaS65:D<H`02
24800`@Q00000002124:00001P@Q00048@@Q248<H`@00003124000000080000936<DYAS65:D<H`Q2
8@PaS6Li00Ioo`09JeYF]BU:8@P<H`Q21248@P@Q008000041248@PaS124236<00`@Q0000000J0000
10Q236<<HaS60RDY00PQ21BU5:DDYA2548<8@`Q10P@Q00H<H`Q236<8@PaS48<336<010Q23688@PQ3
10Q200L<Ha2436<8@P@R124<H`0348@03`aS248<H`aS248DYAS78@PLiaBU36<@Q1BU7>LDY@0236<0
11BV6<HDY0aS0a2400<@Pa245:D010aS00<@Q0aS36@00a2400<<H`Q336<00PaS00<<HPaS48@00QBU
00<@Q0aS36<010aS00<8@PaS36<00PaS0a2400D<Ha2336<<Ha23008@Q00848<@Q12436<8@`Q236<@
Q08<H`08368<H`aS36<8@PaS48@HaP8Li`045:DHa@Q324825:D011BV5:D8@P@Q0PQ20A240@aS0@Q2
000336<26<H25:D248@00aS65:DDY@0448@25:D011245:DDYAS611cW0QS60QBU00<HaR487>L011cW
00<HaQBU48@00QBU0PaS00<@Q1BU8@P00R4800lHaQBU5:DDYA245:DLibDY8@PHaPaS48@DYAS68@P0
0QS600hQ21S648@@Q1BU6<H@Q0aS5:DLiaS648@<Ha240QBU0QS600<LiaS65:D011S60QBU0QS600@D
Y@aS48@DY@8Li`055:D<H`Q2248<H`0800000`@Q000000020002124?000010Q236<@Q1240PQ200@H
aQBUCW=cW0Uoo`06:DXQ20Q200048@000P@Q0`000`@Q3P0000<48@0000003P0000@<H`Q26<HQ208Y
BP8Li`058@PHaQBU36@<H`03248236<01PQ32488@PQ23688@`88@P<48@0:248<Ha2336@<HPQ236<@
Q12548<236<00a245:D<H`0236<00aBT5:HDY00248@01ABU5:HHaABU5:@00QBU00<HaAS636<00PQ2
00<<Ha2548@00PQ20PaS00@@Q0aS248<HP@@Q0066<D@QA2324<8@PaS0Q2400D@QABT48D@Q0aR00@<
H`05248<HPQ236@@P`0236<00`Q3248<H`0336<01@aT36<<H`aS24800PaS00@DY0Q2248<H`8DY@0>
48@<H`aS48@DYABV6<HLiaS648@@QABT6<HDYP8DY@<<H`8@Q088@P0000<DYAS65:D00aBU0Q240QS6
00@@Q0Q2248DY@8@Q0045:DHaQcW6<H45:D011S68@PQ21S60QBU00<HaQcW7>L00QS600@Lib487>LH
aP8@Q0075:D@Q1BU6<HLib487>L00QS600H@Q1BU48@<HaBU7>L29BT00aS6248<H`025:D00acW6<HH
aP037>L548@36<H00a2436<@Q00348@01aBU8@PLib487>LHaQBU00@@Q00:248@Q1S67>LDY@aS5:DH
aPaS124200000`@Q00000002000212400`Q20000000500000`@Q0000000400031245000010Q236<<
Ha240PaS00<U:Be[Kg/027oo00EcW5[F6<H<H`Q200D000051240000000048@0=0002124=00021242
00001@Q25:DYBRU:8@P00acW00<Q21S648@00PaS0Q2400T8@P@Q248<Ha2436<8@PaS5:D00PaS0P@Q
00L<H`aT36<8@P@Q248<H`0224801@aS48@<H`Q348@00QBU0`aS00/@Q0aT48@@Q1BU48@@QABU5:HD
YA24008<H`0348@@P`aS00<<H`0?48@8@PQ2248<HaBU48@<H`Q248@DYAS75:D<H`Q200D<H`<@Q003
36<8@PQ2008<H`0<36@<H`aS48<<H`aT48<<H`aR248<Ha240PaS00@@Pa255:D@P`<8@P0336@DYA24
00@<H`8DY@DHaP8DY@0548@DYAS67>LDY00336<011BU36<8@PaS0A2400002A247>LQ22DY8@PHaQcW
8@PLi`035:D02Q245:D<Ha246<HLib487>LDYAS60QcW0b480QS600P@Q1BU6<HLiaS65:D<HaBU0QS6
00DDYA2448@@Q1BU008HaP<DY@8Li`076<HDYA245:DLib486<H00Q2400PDYB488@PU:B487>LQ21cW
0aS600@Lia2448@DY@8HaP035:D@Q0aS008DY@8HaP037>LQ22DY008Q20<HaP<Li`036<HLiaBU008<
H`0548@DYA2412400002124700000`@Q000000050002124400000`Q212400007000020@Q36<<H`Q2
6<HDYDicNmh:Ool00e[F1240000B00000`@Q0000000E000010@Q48@DYB480S6<00<U:ABU48@00aS6
00hHaABU6<HLiaS66<DDYABV6<HDYA2448<<I1240`aS0QBU10aS00<DY@aS36<00PaS00@@Q0aS48<<
I0@<H`@@Q08<H`0348<DYQBU008@Q00424848PaS36<25:D348@010aS24<8@PaS0QBU0QS600D@Q0aS
248<Ha2400<<H`<@Q08<H`0B24<<H`aS36<@P`aS48@@QA2348@<I12436@@Q0aS48@DYA240`aS0Q24
0PaS00<@Q0aR24<00`aS00T8@`aR36<@Q1BU6<DHaQBV6<D00a240PaS0Q2400@@QA2436<<H`<@Q000
01@8@QcW9BTU:ABU6<HU:BU:7>L@Q1BU7>L@Q0aS5:DLibDY7>LHaQBU0QcW00DQ21S66<HHaQcW008H
aP<Li`0;6<H@Q0aS48@HaQcW5:D@Q1BU7>LHaP025:D01AS65:DDYABU48@00QS60QcW01DHaQcW7>LH
aQBU48@Lib487>LYBRe[8@PDY@aS5:DLiaBU36<@Q1cW6<H00QBU0QS600DDY@aS5:DLiaS600<Li`8Q
20066<HDYABU5:DQ21cW0QS600<DYA245:D00Q240PQ2100000@48@00000000848@L0000312400000
00/00004248<H`Q2248248@010aS8@PYBW>L2Woo00EF]BDY000000Q202L0000:1248@P@Q48@Libe/
<H`Q21cV7>L36<H00aBU6<HHaP026<H03ABU36@@Q1246<HLiaS636<8@PaR48DHaQBT0088@P0336<8
@Q24008DY@0448@<H`aS48<25:D01@aS3688@a2348@00`aS0QBU00hHaABU36<<HaBU36<48@Q348<D
Y@Q32448@Q240aBU00@DY0Q2248<I08HaP0848@<Ha235:D@Q0aS248<H`@@Q0L<H`0536@<Ha245:DD
Y00348@436<348@020aS48@@Q1BT48@<H`aT48<248@336<00`Q348@DY@026<H03aBU48DDYA2336<@
Q1BU48@@P`aS5:@@QA2436<8@P0136<000<Li`8Q20037>LHaQS6008HaP@DY@@HaP<DY@<HaP@Li`03
6<HDYA2400<DY@8<H`@@Q0065:DHaQS65:DHaQcW0QS600PDYAS66<H@Q1BU7>LQ21S60Q240QS600@@
Q1BU5:DHaP<DY@<HaP045:D<Ha245:D27>L01aS65:DDYAS67>LHaQBU008HaP045:D@Q12448@25:D4
48@35:D236<25:D010Q212448@@Q100000D48@00000000@Q01<00003124000Q20088@P<48@045:D@
Q3F]E[D9Ool00d8@<H`<H`02124224800`@Q0000000;00000`Q21240000G0002248041cV;F/e[CW?
;F/HaQBU248<H`aT48@DYAS65:DDY1240aBU0Q2400<DY12548@00PaS00<@Q0aT48@00QBU0PaS0Q24
00/DYA2448@<H`Q336<<HPQ336<8@PaS00<@Q00336@<H`aS008<H`88@P08368<H`aT368<Ha2448D@
Q0<<H`0448@<Ha245:@248@01PaS248<Ha245:@<H`88@P0336@HaABU008@Q08<H`8@Q0045:DDY1BU
48@236<348@236<648@021BU48D@Q0aS248@Q1S648@2248011BT7>LHaQ240QBU00D@Q0aS5:@DYABV
00@<H`0524<8@@@R36<<HP0336<000036<HLib48008Q208Li`@HaP0;5:D<HaBU6<HLib489BTDY@aS
48@HaP028@P45:D011S67>LLiaBU0PaS00<DYAS66<H00aBU00@HaQcW6<HHaPDDY@0548@DYAS67>LH
aP025:D37>L01QS65:DDYAS67>LDY@<HaP045:D@Q1247>L25:D00aS67>LHaP025:D01QcW8@PLiaBU
6<HDY@<@Q0045:D@Q0aS48@25:D00a245:DDY@026<H00a2436<8@P02124300000`@Q000000030002
124D00000`@Q2488@P0424826<H00e:DLiaoo`07Ool016]J:DXLi`aS0P@Q3P0000@48@0000048@/0
00848@X0000<124@Q0Q26<HaS3g_=JdHaPaS48@<HPQ20Q2400HHaQBU5:D@QABT36<248@011S648@@
Q1240QBU00H@Q0aR36<@Q1BU48@236<01@Q236<@Q0aT48<01@aS00H@Q0aS36<8@PaS48<436<00`Q2
24<<H`0236<01@Q236<<H`aT48<00`aS00d@Q0aT48@<H`Q236<DY1BU36@8@P@R36<8@P0236<248@5
36<248@01a256<HDYA2536@<Ha23008@Q08<H`0448@DYAS65:D248@02PaS48<<I12336@@P`aS48@D
YQBT0PaT01<DY1S66<HHaABU6<H@QABU6<DDY@aS24848@Q136<8@PQ336<@Q002248000048@PYBRe[
:DX27>L29BT01AcW5:DHaQcW6<H00a240QcW00HHaQ2436<DYAcW6<H35:D00a246<HDY@025:D01AS6
5:DDY@aS48@01AS600hDYAS65:DDYAS65:DHaQBU6<HLiaBU36<8@Q240R4800<HaQBU8@P00R4800<L
iaS66<H00acW0QBU00@<Ha246<HDY@8@Q0036<HQ2248008Q208HaP0448@<Ha2448@26<H011BU6<HL
iaS60QBU00HHaQcW5:D@Q1BU36<400000`@Q000000040002248D00000`@Q2488@P0324802ABU48@8
@QcW<HaNmfmkIcUkgP02Mkd00fmkAS4icP026<H00a242480000=0003124500000`@Q0000000D0002
48@01b48?Nm:DU:D>LhQ21cW00<@Q08DY@0648@DYAS67>LHaQ240QBU0QS60QBU00H@QABU6<H@Q1BU
48@25:D01Q2448<<Ha245:D@Q08<H`0748@@P`aT3688@`aR24<00PaS00X8@`Q2248<Ha2348@<H`Q2
24<<HP8<H`88@P0336<@Q124008<H`0348@<H`aS0088@P0536<@P`aT36<<HP02248248@25:D02A24
5:D<H`aS48@<HaBU6<DDY00324800`aS5:DDY@0436<36<H25:D236<2248236<25:D01ABT48@<I123
48D00QBU00@@Q12324<<H`8@Q08<H`031288@PaR008<H`88@P0000@]JbU:7>LLi`8U:@0<8@PHaQS6
7>LHaQBU48@DYA245:DHaQBU0QcW00P@Q0Q236<@Q1cW8@PHaPaS0Q240QS60a2400<HaQBU6<H00QS6
00<DYAS66<H00QS600<DYA245:D00QBU0QS600@DYA2448@@Q08HaP057>LHaQS67>LHaP027>L011S6
5:DDYABU0acW00HDYA2448@HaR486<H27>L28@P25:D01a2436<@Q1S67>LU:AcW00<DY@8HaP0648@D
YAS65:D<H`@Q10000P@Q100000<48@000000500000<48@Q224800`Q200P48ABU48@aS4icKg]oofmk
0Woo00AcW6<H<H`YBP8DY@0348@8@P0000`000041248@PQ2124900000`@Q0000000@00027>L0536<
AS56<D8@;F/HaQcW36<8@@Q336<DYA2348@DYQcW6<HDY@aS48@25:D00acW6<HDY00248@35:D01123
36@@Q0Q30`aS00X@Q1BU36@8@PaS5:DLiaBU36<8@P@<H`04248<Ha2436<224800a235:H@Q0022480
1a2436<<H`aS368@Q0aT008<H`06248<H`aS2488@@@R0PaS00@@Q0aS48@@Q0@<H`0A248<HaBU6<H@
Q@aS248<H`aT36<DYAS65:D<H`Q248@HaP025:D031255:DDYAS636<48@aS5:DHaQBT24<<H`<DY@08
48@<Ha2448@DY@aS24<8@P8<H`0648<8@`Q2368<H`Q20@aS00000c6<;F/U:@048@P01QcW8@PLiaS6
7>LHaP<Li`05:DX]JbDY7>LHaP038@P011cW8@PLiaS60QBU00<HaQcW7>L00QcW0aS600HDYAS67>LQ
22DY8@P25:D01QcW:DX]JbDY7>LQ208Li`8Q208YBP<U:@038@PLiacW008Q200=7>LHaQS67>LQ22DY
8@PLiaBU6<HLib489BT00b4800<LibDY7>L00QBU00l@Q1S67>LLiaBU6<H@Q0aS5:DQ22DY8@P<H`Q2
12400P0000@48@aS48@48@D000848A@00088@P05000DYBDY9BTLi`0200003a24:DY6<DYB>Lh]JbU:
;F/e[AS6000HaT8@BU8Q200200000`Q20000000900000`@Q0000000300000`@Q2480000300000`@Q
0000000@00001@@Q48@Q22U:9BT00QS600/Q22U:@Plml36<;F/HaQBU48@<Ha2400@<H`8DY@056<HH
aABV6<HDY@0236<02Q246<H@Q0aS5:DHaAS648D<H`Q20PaS00lDYAS55:D@Q0aS248<H`Q2368<Ha24
5:D@QA245:D00Q2400<@P`aS48@00a240PaS00<8@PaS48@00PaS00@8@P@Q2488@P<<H`<@Q08<H`06
48@<H`Q236<DYA240`aS00LDYA2536<@Pa2436@<HP0236<021BU36<@Q1BU6<HLiQS65:D236<448@3
36<248@011BU6<HHaQ240`aS00D@P`aT36<<H`aT008<H`0324<<H`aS004<H`0000Te[Be[8@PHaQcW
9BTQ21cW6<H00QcW00@Q21cW7>LQ208U:@038@PLiacW00<Li`096<HLibU:9BTLiaS648@DYAcW008H
aP055:DHaQcW7>LHaP025:D26<H03B487>LHaRU:;F/aS2485:DLib486<HLibDY008YBP048@PLib48
9BT28@P27>L011S67>LU:B480QcW00@HaR489BTQ20DLi`078@PLiacW6<HDYA246<H00QcW00DHaQBU
48@DYAS6008Q20056<H@Q0Q2248<H`04124236<01`@Q000000001248@P@Q00`000848@L000061240
01cW:DXU:ABU0P0000LLid8@HaQBU2U:8@P]J`02<H`01Q24000DYCg_@Q0Li`8000031240000000<0
00061240000000048@Q20`000`@Q1P0000<48@0000002`0000<48@0000000P0001PDYAS68@PU:BU:
7>LHaRU:=Je:DTHa:DXQ212448DDY@aS48<DYAS65:D@Q1BT48D27>L02AS55:D<I1BT6<H@Q12548@D
Y@026<H021BU48<48@Q236<@Q1BU48D436<01a2424448A245:HLiQBU00<<H`0436@@Q12448@22480
1@aS5:DDYA2436<00PQ200@<H`Q22488@P8@Q00;36<8@PaS5:D@Q0aS248@Q1BU6<H@Q00236<01@Q2
48@DYABU5:@00`aS00<DY0aT48@00Q240aS600LDYAcW6<L@Q0aR1248@P036<H011BU248<Ha240QBU
0PaS00/@Q1BU48@<H`Q2368<H`Q2368<Ha2400@<H`000be[1BU:00<U:B487>L01b480QcW00DQ21cW
9BTQ22DY008Q20046<HDYAS66<H28@P3:DX29BT48@P00aS67>LLi`028@P29BT01BU:9BTQ21cW8@P0
0bDY0acW00@Q22DY7>LHaP<Li`8Q2007;F/YBRU:8@PLiaS68@P00QcW00DU:BU:>Lhe[C6<008YBP8]
J`068@PLiaS67>LHaQBU0aS600<Lia2436<00PQ200<<H`Q2248010Q200<48@Q212400`Q200<48@00
00003P0000L48@00000000@Q24848@0224802BDY<H`]JacW248<HaS65:D@Q0026<H25:D436<00`Q2
0000000=00000`@Q0000000=00000`@Q0000000<0003248031S67>LLiaBV5:DHaR487>LQ22DY<H`m
kP8icP03:DXU:AcW008DY@055:HLiQcW6<H@Q@035:D00a2548@<H`0236<25:D00aS65:DDY@025:D0
1QS65:DDY1255:DHaP8DY@0736<<I1245:@HaacW5:D00PaS00D@Q1BU36<8@PaS008DY@0336<8@PQ2
008<H`8@Q0@8@P8<H`88@P0336<8@PaS00@@Q0<8@P0436<DYABT36@236<02a255:@<I0aS48@DYAS6
48@<H`aT5:@00Q2400X<Ha2448D<Ha2448D@Q1BU36<8@P8<H`046<HDYABU5:H25:D00aBT36@@Q002
48@01Q2548<@Q1BU48@<H`48@P000S6<00@]JbDY:DXU:@@YBP0<9BTQ21cW9BTLiaS68@PYBRDY7>LH
aR480RU:0R4800lLiaS67>LLib487>LHaR48:DX]JbDY6<HDYAS67>L00b480QcW00@Q22DY;F/YBP8U
:@@Q20<U:@068@PLiaBU6<HLib480bDY00<YBRDY9BT00QcW00/Q22DY:DXU:B48:DX]JcF]?NlaS2e[
008Q20039BTQ224800DLi`055:DLib486<H<H`0200021249248010aS24848@@Q2@0000<48@000000
1P0000@48@Q22488@P8DY@04:DX]JacW5:D236<36<H01ABU36<@Q1BU36<00P@Q0PaS00@48@000004
8@d000031240000001X000031248@QS6008Q208Li`8HaP0@8@PU:C6<;F/e[CW>=JdaS2DZ8@LQ21BU
5:HHaABV8@L37>L05A2436@@Pa246<HDY12436<DYA2436<@QABU6<HHaaBT36@@Pa245:D@Q00236<0
2A246<HDYAS55:D@Q1BU36<DY@0236<2248236<01`aR48DDYA2436<48@Q200<<H`8@Q0<8@P0436@D
YA2448<248@01PQ336<@Q1BU5:@<I0D@Q00?36<@Q1246<HDYA2436<@Q1BU6<L<H`Q236<DYAcV008@
Q08DY@0636<8@PQ236<@Pa2411BU00D@Q0aT48<<HaBU00<@Q00436@@Pa2436<136@000<]J`03<H`Y
BRe[008]J`04<H`YBRU::DX2;F/29BT48@P49BT01B487>LHaQ246<H00QBU00dQ22U:;F/]Jb487>LU
:Be[<H`]Jb485:DHaP027>L012487>LDYAcW0QS600<Lib488@P00b4800@YBRe[<H`YBP8Q20039BTY
BRU:008Li`8Q2005:DXQ21cW5:DHaP025:D01AcW8@PYBRDY7>L012480QS60QcW00LHaQBU6<HLib48
7>L@Q006248200001@@Q36<@Q0aS24800`aS0`Q200<48@0000000P0000<48@0000000P0000@8@P@Q
12448@H000091248@PQ26<HQ236<;F/U:B48008U:@07:DXaS2e[;F/YBQBU24800P0000<48@Q21240
3P000`@Q2P0000<48@0000004@0000`48ABU7>LDYBDY:DXQ21S6248<HaS67>L2:DX01c6<?Nlmkcg_
<H`U:B48008DY@043688@PaS48<25:D02A2436@<H`Q236<@QABT48@@P`0248@00aBU48@@Q00248@0
0aBU6<HDY@0236<00a2436@8@P0224800aBU48@@Q00248@336<0112436<<Ha240QBU00<@Q0aS36<0
0PQ200H<H`@Q36<<HaBT5:D2248010Q348@DY1240PaS00D8@a245:DHaABU008<H`075:DDY0aS36<D
YAcW6<H00QBU00D@P`aS36<<HaBU00<@Q0<DY@8<H`035:D@Q125008@Q00348<<Ha24008@Q0095:D8
@PQ22488@a2348@<I124004<H`0000<YBRe[;F/01be[00@YBRDY9BTU:@8YBP059BTQ22488@PU:@02
7>L28@P00acW6<H@Q0025:D01AS69BTaS3F];F/00QcW00DU:BU:;F/YBR4800DLi`036<HLiacW00<Q
20037>LQ22DY008]J`8YBP049BTQ21cW9BT2:DX01RDY7>LQ22DY:DXU:@8Li`096<HLiaBU48@Lib48
:DXQ21cW008Q20<DY@@Li`096<HLiacW6<HDY@aS24848@0000848@H<H`88@P<<H`0324848@@Q00P0
00@48@L0000=1248@PaS36<Q236<=JdYBQcW9BT]JbDY8@P00RU:00DLi`aS1248@P@Q008000031248
@P@Q00l0000312400000008000031240000001@000848@8<H`0548@Q22488@PHaP0348@01`aS6<HH
aRU:;F/icSg_008icP03;F/LiaS6008<H`0736@<HaBU48DDYA245:@00Q2400D<H`aT5:@@QABU008@
Q0036<HDYABU008<H`<@Q00848DDY0Q21248@PaS5:D<H`88@P0348@DYABU008@Q08<H`8@Q00936<8
@PQ248<@Q@aR1248@PQ30088@P0336<@Q0aS008<H`@@Q00336<@Q1S5008DY@8<H`085:DDY0aT36<@
Q0aT36<@P`8DY@0648@<I0aS5:@@Q0aT0aBU00<@Q0aS36<00aBU0`aS00HDYA2436<<HaBU36<22480
10aS5:DDY0aT0Q230@Q20@aS00028@P012U:<H`]Jbe[0RU:0Re[00<Q22DY:DX00SW>00<]JbDY:DX0
0R4800<Lib488@P012480acW0R480QBU00<HaRDY:DX00RDY00PLibDY;F/LiaBU48@HaR480acW1AS6
00TDYAcW5:DHaQcW9BTQ21cW6<H00QcW0aBU00HLib488@PLiaS65:D26<H01ABU6<HHaR487>L00QS6
0aBU00<@Q1BU48@00`aS0QS600D@Q0aS1248@Q24008<H`0648@HaQ2436<@Q1S60R4800@DYA241240
00<8@P848@D000031248@P@Q00/000091248@PaS248@Q1BU9BT]JcF]008aS006@Q16<DYB?Nl@Q0Q2
0P0000<8@P@Q0000400000D48@00000000@Q01X0000A124@Q124368]K4YA?NlU:@@Q48@Lj1BU6<HD
YB477>LQ20029BT01SF]>LhmkcW>:DXU:@8Li`045:D<H`aS36<25:D0112336@@Q1BT0Q240PaS00<@
Q1BU36<00PQ20Q240PaS00@<I12336<<H`@@Q08<H`03248<Ha24008HaP8DY@0848@<Ha2448@DYA25
36<<HP8<H`0948@<H`aS48@<H`Q2368<Ha25008@Q00336<@Q0aS00<<H`0436@@P`aS36<25:D01QS6
48D<H`aS48<<H`8@Q0DDY@035:@DY@aS00<<H`0448@DYABU48@236<01@Q25:DDYABU48@00PQ200@@
Q1BU5:H<H`48@P0000LHaRDY<H`aS2U:8@PaS002=Jd01be[9BTYBRU:;F/aS2e[008YBP0<6<H@Q1S6
8@PYBQcW5:DHaR489BTQ21S60QBU00DLib486<HQ22DY00<YBP049BTLiaS66<H25:D03AcW6<HU:BDY
6<HDYA245:DLiaBU6<HLib48008Li`058@PHaR488@PHaP035:D37>L01ABU48@DYB489BT00QcW0R48
00<LiaBU48@01ABU0Q240QBU00hHaQcW36<000@Q36<HaQBU248<Ha2436<8@QS60QcW00<HaPQ22480
0PQ20`@Q1`0000<48@Q21240200000T48@0000048@aS5:D<HaS68@P00SF]00PaS3F]>Li6<DYB>LhY
BPQ20`0000D48@00000000@Q01l000031248@P0000X0000<248<HaS648@<Hc6<BU<mkQcW1248@R47
0QcW00@HaQBV7>LYBP8]J`8aS08e[@03:DTQ2ABT00<<H`045:D@Q0aS248236<01Q246<HDYQ245:D<
H`@8@P<@Q00536<<HPaS36@@P`0348@236<011245:DDYA240aBU00L<Ha245:DLiaS75:@@Q00636<0
0a245:D@Q00336<02`Q3368<H`aS48@DYA2436<@Q1BU48@00PaS00TDYABT36<<HaBT5:D<I0aS48@0
0QBU00H<HaBU5:DDYA2436<248@336<348@436<01A245:D@Q0aS48@00QBU00<<H`Q224800@aS0000
1ABU7>LQ22DY8@P00bDY0R4800DU:C6<;F/]JcF]008icP03<H`U:BU:008YBP8U:@058@PLib487>LQ
20037>L01b485:D@Q1245:DQ22DY008Q20059BTYBRe[:DXU:@057>L00b486<HHaP026<H00acW6<HH
aP026<H35:D00aS67>LHaP035:D26<H00acW8@PQ20048@P27>L66<H021242488@PaS6<HDYA2436<2
124224800aBU48@@Q0025:D236<00a245:DLi`037>L01A2424848@0012400PQ200D48@00000000@Q
00L000031240000000@000848@0400048@000002248010aS48@@Q1S60Q2400<<H`@Q12401P000`@Q
10000`@Q30000P@Q1P0000<48@0000000P0000<48@0000002@0000d48@Q25:DLiaS5;F`mkbU:6<H4
8@Q25:HDY@0248@25:D248@021BU7>LHaR49:DX]JbU:9BT28@P26<H236<00a245:DDY@035:D01aBT
48@<H`Q248@<HaBT008@Q00636<8@PaS36<DYA25112400T<Ha245:D<H`Q236<DYAS648@00PaS00LD
YABT48@@Q0aT48@DY@0336<248@00`aS2488@@0236<01Q2436<<Ha245:D@Q0<<H`8@Q00436<@Q0aS
24<236<011BU48@DYABU0QS600<DYA2436<00Q240QBU00X@Q0aS5:DHaQcW6<H@Q0Q23688@`8<H`07
48<<H`Q3368<I1BU36<00@Q200026<H00acW9BTQ20027>L00b48:DX]J`02:DX01CF]?NlicRe[:DX0
0Re[0bU:00DU:AcW6<HLib48008HaP8Li`068@PHaQBU7>LHaQBU0R4800PaS3F];F/YBRDY7>LQ21cW
0QS600LQ21cW5:D@Q1BU7>LDY@086<H25:D00a245:DHaP026<H011cW8@PU:B481QcW00<Q21BU5:D0
0PaS0Q2400@DYA24248<H`8@Q00936<48@@Q248@Q1BU6<HDY@aS008@Q0056<HLiaS68@PLi`025:D4
12400`Q2124000060004124500000`@Q00000004000010@Q36<<H`Q20`aS00D@Q1BU48@@Q0aS01T0
00031240000001L0000A12400000124<HaS66<LYBBDZ:DX]JaBU36<8@PaS6<D@Q00336<03Q246<HL
iaS67>LHaR489BT]Jc6<9BTLiaBU48@25:D348@25:D01QBT36@<Ha245:DHaP8@Q00336@<H`aS00@<
H`0548DDY1BU6<H@Q00336<00aS65:DDY@0336<01QBU48@@Q0aS36@@Q0D<H`0536@<H`aS48<<I002
36<224802PaS48@@Q0aS248<Ha255:D<Ha240QBU00X<H`Q236<@Q0aS48@DYAS65:D@Q08<H`0448<<
I0aS48@236<02Q256<DHaQS65:D@Q0aS24<8@PaR0PaS00L8@a2336<@QABT36<8@P0136<000048@PU
:BDY9BT2:DX01B486<HLibDY7>L00R4800LYBS6<<H`aS2e[:DX]J`03:DX02be[<H`]Jbe[:DX]JacW
6<HLibDY:DX00RDY00HYBRe[<H`]JbU:8@P27>L02BU:<H`U:ABU6<HQ22DY8@PDY@0348@011cW8@PU
:B480acW00@YBS6<:DXQ208HaP039BTQ224800<Li`069BTQ21cW6<HQ21cW0QBU0QS600<DY@aS36<0
0Q2400L<Ha246<H@Q0Q200048@04248020aS248<Ha245:D@Q0aS48@27>L01124248<H`Q20`@Q00<8
@P0000000P0000<48@0000003@0000<48@Q200002@0000<48@Q212401P0000<48@Q212400P0000<4
8@0000001@0000<48@Q200003P000P@Q400000T8@P@Q124DYAcW<H/YBQS65:D00Q2400<DYA245:D0
0aBU0Q2400<@QABU5:@00QBU0aS600HHaacW8@PU:B487>L28@P01RDY8@PLiaBV48@<H`8@Q0035:D@
Q12400@<H`88@P0448<DYQcW6<D248@26<H00aBU36<<H`0236<00aS65:DDY@0236<02a2348D@P`aS
48@HaQBU36<@Q1BT5:H00Q2400@DYQS67>LDY@8@Q00536<@Q12448<<H`0348@01a2548@DYA245:@@
Q1BU00<HaP<DY@0H48DDYABU36<@Q1BU6<H@Q0aS48@HaQcV48DDY1S65:D@Q@aS368<I1BU6<HDYAS5
0QS600028@P04AcW9BTYBR487>LHaR489BTQ21cW8@P]Jc6<=JdaS2e[:DX00be[00HYBS6<;F/U:B48
9BT2:DX00b487>LLi`028@P022e[<H`]Jbe[9BTYBRe[8@P27>L28@P041S68@PU:B486<H<Ha246<H@
Q1S68@PYBR486<HLibDY0Re[0QS600<DYAS68@P00QcW00<U:BU:8@P00aS600DLiaBU6<HLiaBU00<@
Q0035:D@Q0aS0088@P045:DHaQ242482000010@Q248@Q1BU0PaS0a2400HHaQBU6<HHaQBU6<H236<0
0`@Q00000003124200000`@Q0000000@00000`@Q00000002000224800`@Q00048@0;00000`@Q0000
000I00000`@Q0000000300000`@Q0000000700000`@Q00048@0224801248:DXYBR480Q2400P@QABU
5:D@Q0aS248@Q1BU0QcW0aBU00<Lib477>L00QcW00DLiR489BTU:B48008Li`<Q200<48@DY0Q2128@
PaBU6<HDY@aS2488@`aR0`aS00@@Q0aS48@DY@8HaP035:D@Q124008<H`0348@<HaBU00<DY@88@P03
36<8@Q24008DY@0;36<<HQ256<HLiQ2548<HaAS65:D<H`0224801@aS6<D@Q@aS48@00QBU00/@Q0aR
48@@Q0Q336<DYAcW5:D@Q1BU008HaP045:@@Q1S648@236<00a245:DDY@025:D011255:DDYA240`aS
00<@Q1BU5:D00a240ABV0AS60ABU00000be[:DXYBP068@P01acW6<HHaQBU6<HLib48008U:@8Q2008
9BT]JbU:8@PYBSF]AS4e[@8YBP06=JdicSF]9BTLic6<0TYB00PaS1cW6<H]Jc6<=Jd]Jb480QS60aBU
00HHaQBU5:DDYAS69BT2;F/042U:8@PQ22U:8@PLiaS65:DHaQcW8@PLiaS67>LU:AcW0QBU00THaR48
9BTHaQ2436<DYAcW6<H00Q2400<DYA2436<00PaS00<48@0000001@000PQ20P@Q00@8@PaS36<<H`<8
@P075:D@Q0Q224848@0024800P@Q3`0000<48@0000003`000P@Q1@0000<48@0000000P0000H8@P@Q
2488@P@Q2482124400000`@Q0000000=000224801@@Q0000000012401@000P@Q00T8@P@Q1248@PaS
48@<Ha245:D00R4800@LiaBU5:DHaP8Q200>7>LDY1BU5:DHaaBU36<<I1BU7>LHaacW7>HLi`8Q2007
9BTLiaBU5:DHaQ245:D00Q240QBU0Q2400`<Ha2336<8@Q245:D@QA24368@QABU48@236<25:D01`aT
48<<I1BT48D<H`@R0088@P<DY@0448@<H`aS36<348@336<00`aT5:D@Q00336<011255:DDYABU0PaS
0Q2400D<H`aT36<DY1S6008DY@8@Q0045:@DYABU48@336<348@01`aS36@@Q1S55:HDY125008DY@<<
H`<DY@0348@DY124004DY@000bU:0b480RU:00TLiaS67>LQ21S65:DHaR48:DX00R4800PU:B487>LY
BRe[>Li243g_0S6<12e[0RU:00/icTYB?NlYBQS67>LaS3F]<H`U:AcW008DY@8HaP085:DHaQBU36<H
aR48:DX]J`8Q20059BTQ22487>LHaP025:D28@P00bDY8@PQ20028@P01AcW6<H@Q1BU6<H00QcW00<Q
21BU48@00Q2400HDYA2448@DYA242483124400000`@Q2488@P0324800`@Q36<<H`0436<524800`@Q
00000007000212450003124<000010@Q000000@Q100000H48@00000000Q2124200001`Q2124000@Q
248@Q0aS00P000848@T000031240000000@00003124<H`@Q00<000031240000000@0000336<HaQS6
0088@P035:DYBRU:008Li`0;5:D@Q1BU7>LQ21cW48@@PaBU6<LHa@025:D01AS67>LQ2B487>L01248
00<HaQ2448@00aBU0Q24014DY@aS48<@QABU6<HDYA2436<DYAS66<LDY0Q348<HaA25008@Q0095:@D
YA2448@@P`aS368<I1BT008@Q00336<8@PaS00<DY@07248<Ha2448@<H`aR36<00a240PaS00DDY1BU
48@<H`Q2008<H`04248@PaBU5:H45:D248@00a2548@@Q00336<00a245:DDY@0336<01a246<HDYABT
36<8@PaS008@Q00436<@P`aS24<336<0000D8@P]Jc6<9BTDYA246<HYBRe[:DXU:AcW8@PU:AcW6<HL
ibDY:DXU:@@Li`079BTQ2248:DXaS3W>?Nl00THa00Q243g_>LhicRe[:DXU:Be[0SF]00/]JbU::DXQ
22DY5:D<HaBU6<HU:B48008Li`059BTQ22489BTQ20029BT28@P29BT28@P01QcW6<HHaR48:DXQ208H
aP8Q20037>LHaQcW008Li`<HaP8DY@8HaP0548@48@001248@P0300000`@Q00048@04000212400`Q2
12448@0224800`aS2480000200000`@Q24848@040002124:00000`@Q24848@0400000`@Q00000005
00000`@Q0000000;000212422482124400000`@Q0000000:0002124600001`@Q000000Q236<8@P@Q
00T00003124<Ha24008@Q0035:DHaQBU00HDY@076<HDYQ245:@DYQcW6<H00Q2400<DY1BU6<H00QS6
00@Q22DY8@PQ208DY@0348@DYA2400<<H`0348D@Q124008@Q00436<@Q0aS36<25:D27>L00aBV5:DH
a@0348@03Q255:D@QAS56<LHaQBU5:HHaQcW6<DDY@aS48@336<25:D01Q2548@@QAS636<@Q08DY@0?
48D<H`aS48@DYQS55:D@Q1255:DHaQBU48@<Ha2400DDY@8HaP<@Q08DY@0A48@<Ha2348@DYA2548@<
Ha2436@@Q1BT36@@QAS56<HDYP0148<0000D8@PU:BDY7>LHaQcW8@P]Jc6<;F/U:B485:DHaQcW8@PY
BRDY8@PU:@@Li`078@PHaRDY<H`mkdYBAS400cg_00=243W><H`00RU:00T]Jc6<<H`]JbU:8@PLib48
7>L00QS60QBU00DLib489BTYBR48008HaP047>LQ22U:8@P47>L03RDY:DXYBR486<HLibDY8@PHaQcW
8@PU:AcW5:D26<H011BU6<HHaQcW0QS60QBU0PaS300000H48@Q212448@00248248@010aS12448@@Q
10000`@Q1P000`@Q0`0000<48@0012403@0000<48@0000001P0000<48@0000000P0000<8@PaS1240
0`000P@Q5P000P@Q00D8@P@Q000000@Q00D0000412400000248236<00`Q236<@Q0027>L36<H04QBU
6<HDYABU7>LQ21S648@<HaBU6<HDY12536<DYAS67>LLj08Li`0>6<HQ22DY6<H<I0Q136<HaQBU48@<
I1BT48DDY@@@Q00C5:@<Ha246<HLia2436<@Q1S67>LDYA245:@@QA235:DHaR477>P00aS600DDYA25
5:DDY@aS0088@P0O36<DYA2436<@P`aS248<HaBU7>LDY@aS248@Q12324<@Q1S67>HHaQBU6<DDYQBT
48D<H`aR5:DHaR486<H00`aS00P@Q1BU36<<Ha245:HDYA240PaS00L@Q12348@@Q1255:@@Q00236<1
48<148D0008icP03=Jd]JbU:008YBP8U:@038@PU:B48008Q200<7>LQ21cW6<HU:BU:<H`]JbU:=Jda
S2480QcW00DYBRe[9BTQ22DY008YBP03<H`e[Cg_00<icP07?Nle[CF]>Li243W><H`00bU:00DQ21S6
7>LHaQBU008Li`0:8@PLiacW8@PU:B487>LDYAcW8@P27>L00bDY:DXQ20027>L29BT27>L01B489BTQ
21cW8@P01AS600DDY@aS124000@Q00D000848@0324800000008000032480000000P000848@<00084
8@L000031248@PaS00@8@P848@8000031240000000d000031240000000X000848A/000031248@P@Q
00L0000;12400000000<HaBU248HaS6<?NlYBP0248@28@P03AS67>LLiacV5:D@Q0aS5:@DYQS55:D@
Q1S6008Li`046<HDYAS55:D26<H01QBU8@PU:BDY7>LDY@8@Q0036<DHaQcW00<Li`@HaP037>LHaQS6
008Li`0<5:D<H`aS5:DHaQBU48DDY1BV6<DDYAS60aBU00<@Q1BT5:D01ABU00@HaA2548@DY@8HaP0C
5:@@Q1BT48D@Q1256<DDY@aS5:DHaQcW5:H@P`Q348<<H`aT5:H00QcW00<HaQBU5:D00QBU00<DYQBT
48@00aBU00H<H`aR48@DY0aT48@25:D248@00`aS5:DDYP016<H00004?Nle[BU::DX2<H`012U:8@PQ
22U:0QcW00@HaR488@PQ208Li`0;9BTYBS6<=Jd]JbDY8@PLib489BTYBP028@P012DY;F/e[C6<0SF]
00<icSg_=Jd00Re[00PaS3g_AS4icRe[:DXQ22DY0R4800@LiaBU5:DHaP8Li`036<HLibDY008Q208L
i`0?8@PHaR489BT]JbU:9BTHaQcW:DX]JbU:7>LDYAS600DLi`055:DHaQcW7>L@Q002124224830002
1245000212440004124400000`@Q0000000500000`@Q24848@0300000`@Q2488@P0212400`Q21240
000300000`Q212448@0:00000`@Q0000000200000`@Q000000050002124M00000`Q236<8@P0<0000
2AcW:DXicSW>9BTHaQBU48@Li`028@P011S65:H@Q1BU0a2400`DY1BV48@DYAS68@LLiaS65:DDYQS5
5:D26<H03QcW8@PQ21S65:HDY1BV6<LQ1acW6<HDYAS67>P27>L46<H021BV5:D@Q1BU48@<HaBT5:D2
6<H35:D00a245:DDY@025:D0112548@<Ha240aBU00@@Q1BT5:DDYP8@Q00448D@Q12448<336<021BV
6<DHaQcW5:D8@P@Q36<25:D00`aS5:@HaP027>L01Q2436<@Q1BU6<HDYP8@Q0045:D@Q12448D25:D0
212436<8@PQ236<@Q1S648@236<00006?NlicRU::DXaS3F]0Re[00/icSF]9BTHaQcW:DX]JbU:;F/a
S3W>00<e[@@aS0<]J`0<:DXQ21cW6<HLibDY:DX]JbDY8@PYBRe[0Sg_00E244YBCW=>LdHa00A24004
:DXLiaBU48@27>L02R487>LLib489BTYBRDY8@PYBRDY0b4800HYBRDY:DXU:BU:9BT38@P29BT02B48
9BTLiaS65:D@Q1S65:D@Q008000010@Q000000@Q1@000`@Q0`0000<48@0000003P000`@Q00@@Q1BU
7>LDY@8<H`03248<H`@Q00D0000412400000000224800`@Q0000000A00001@Q21240000012405@00
00<48@0000002`0000X48ABU36<Q23F]?Nle[AcW5:DHaP<DY@<@Q00:36<8@PaS48DDYA2336@DYAS7
6<H248@01aBU6<LHaQS65:DHaQcW008U:@097>LHaQS68@LU:B485:H@Q1BU008HaP056<D@Q1245:@D
Y@0348@25:D248@02a256<D@QABT48DDYABT48@8@PaS5:D00QcW0Q2401HLib485:D@Q1S67>PHaQS5
5:HHaABV6<D<H`Q336<<I1S56<HDYQS55:D@Q@<HaP0348@<HaBU008HaP0736<8@QBU6<HDYA2448<0
0QBU00<HaA2536<00PaS00@DYAS65:D@Q08<H`<@Q08<H`0000@aS3F]<H`]J`@aS004;F/YBR489BT5
:DX022DY<H`icSW><H`U:BU:;F/2:DX01RDY:DXQ22487>LQ208]J`8YBP049BTQ236<=Jd3@Q0014ic
DYA>LdHa0Sg_00<e[Be[7>L00acW00<Q21cW7>L00QS600<Q22U::DX00R4800HYBRDY8@PLib48;F/2
9BT02R489BTYBRU:9BTQ22DY;F/Q21cW0QS600<LiaBU36<00PaS0P@Q10000`@Q0`0000<48@000000
0P0000<48@0000000P0000@48@0012448@T000031240000000800005248<HaBU48@<H`035:D01124
124000000`@Q1@000P@Q00<8@P@Q00001@0000<48@0000001P0000<48@000000100000<48@Q21240
5@0000<48@Q200002P0000X48AS67>LaS3W>;F/YBR486<HDY@8@Q08DY@0548@<H`aS5:DHaP025:D0
2Q245:@HaQcW5:D@Q1BT6<HLiaS60QBU00/HaR487>LHaABU7>LYBRDZ7>LHaAS600<DY@0=6<HDYQBU
48@DYABV6<DDYA2436<@Q1BT5:H00Q2400THaQBU48@<H`aT5:D@Q0aS5:@00QS600PDYAS68@PLiaS6
5:DHaQcW0aBU00LHaQ2448@@Q1BT48@<H`025:D01AS65:D@Q1BT5:D00a2400/@Pa255:DDYA2436@@
Q1BT48@DYA25008DY@0348@@P`aS0088@P0936<DY1BU48D<Ha235:D@QABU008@Q00000<e[Be[:DX0
0Re[00HaS2e[:DX]JcF]>Lh5=Jd2<H`5;F/2<H`2:DX00be[<H`aS003:DX022DY8@PQ2248:DXU:BU:
9BT2:DX01c6<;F/e[Cg_@Q1>LdYB0092408e[@03;F/YBRDY008Li`048@PU:Be[;F/28@P01QcW:DXU
:B486<HLi`8Q20069BTLib488@PYBRDY0R4800LU:BU:8@PLib487>LDY@0236<00a24248000080000
0`@Q2488@P0N00001P@Q248@Q1BU6<HDY@8<H`P000848@0300048@@Q00848C`0000348@<HcW>009o
o`0FG_LLi`0036<DYAS67>LHaQ2436<@Q1BU6<D@QABU6<LQ1aS648DDYAS67>L36<H00aBU6<HHaP02
5:D00aS68@PU:@028@P03R478@PQ21S65:D@Q1BU6<HDYQBT5:DDYQS56<H27>L011S65:DHaQS60QcW
0QBU00`@P`aS48@@Q12548@<HPaS36@DY1245:D26<H00aBU48@@Q0025:D01a2436<@Q0aS2488@`aS
00<DY@0448@DYA255:D236<01A245:DDYA2448<00Q240QBU00HHaQcW5:DDYA245:@248@25:D26<H0
1QS55:H<H`aR48@<H`4@Q00000HicS6<;F/]JcF]<H`3:DX4=Jd00c6<;F/]J`02<H`013W>=Jd]Jbe[
1BU:00DaS3F]:DXLib48008]J`048@PHaR48:DX39BT03BU:;F/e[Cg_>Li:DTicBU9243W>AS4e[BU:
008Q2006:DXQ21cW8@PYBRe[0RDY00lQ22DY8@PQ21S67>LYBRe[9BTLib489BTYBQcW8@P00RU:00HQ
21S67>LLiaS648@26<H00`aS2480000Y00000`@Q2488@P025:D26<H01@aS1240000012400`0000L4
8@00000000Q248@8@P0G00000`Q20000000?00000`@Q0000000A000030@Q:DXU:D8@Nmi_NcW>36<0
01BU8@PDY@D@Q00<36<@QAS57>PU:1cW48D@Pa255:DQ1acW1QBU00<HaR488@P00b4800<Q2B488@P0
0QS60QBU0QS600LLiaBU5:DHaQcX8@PHaP027>L26<H01A245:DDYABU5:H00Q2400<<I12336<00a24
00<DYAS65:D00PaS00P@Q1S65:DDYA245:D@Q0Q20Q2400DHaABU48@@Q1BU008@Q0035:@DY@aS008<
H`09368HaQcW6<H<H`Q236<HaQBU00<@Q00;5:HDYA2436<@Q1BU6<HDYA2436<@Q00236<148@148<0
000=<H`]Jbe[9BTQ22e[=JdicS6<:DX]JcF];F/012U:0RDY00XYBRe[;F/e[CW><H`]JbU:9BT]J`8Y
BP04;F/YBRU:9BT38@P27>L011S68@PQ22480RU:136<00XU:B487>LQ22DY8@PYBS6<=Jdmk`<icP8Y
BP077>LQ22488@PLib489BT00RU:0QcW00XYBS6<@Q0icS6<;F/aS3W>=JdU:@8HaP037>L<H`0000H0
00051240000000048@02248400000`Q212448@0700000`@Q0000000<00001@Q236<8@P@Q00000PQ2
0Q240P@Q100000@48@0000048@88@P031240000003`00003248<Hb48008YBP0>9BTQ212448@DYAS6
7>LHaQBU6<HLiaS66<DHaP8Li`047>PDY1245:D27>L011S648@@Q1240QBU00H<H`Q348<HaaS65:D2
36<27>L2:DX01AS65:D@Q1246<H00PaS00L@Q1S55:HDYA245:DHaP045:D02aS65:D@P`aS48<@QABU
36<8@PaS48D00aBU00P@Q12348DDYA245:D@Q1BU0Q2400TDYAS67>LDYA2536<DYAS648@00PaS00@<
I1BU48@8@`<<H`035:D@Q1BU008DY@<@Q0<DY@0436@8@PaS48@26<H011BT48@@Q0aS0@aT00000bU:
9BTU:@02:DX2;F/2=Jd0136<;F/YBRDY0bU:00DU:B489BTYBS6<008]J`04<H`]Jbe[;F/3:DX01BDY
;F/aS2U:9BT00QcW00<U:B488@P00QcW00<U:BU::DX00RU:0Re[00LYBR48:DXYBR489BTYBP02>Lh0
1SF]>LhicSg_>LhYBP8Q20067>LQ21cW8@PU:BU:0QcW00DHaQcW;F/aS3W>00<e[@8icP06<H`LiaBU
48@DY@Q22@000`@Q1P0000<48@Q20000400000<48@0012400P0000<48@Q212400`0000@8@PaS248<
H`<48@@000D48@L000031240000000d000031240000002D0000448@Libe[=Jd29BT01QcW5:DDYABU
6<HLi`8HaP8DY@036<HLiacW00<HaP065:D@Q1BU5:DHaQS70Q240PQ200L@Q1BU6<HDYA24368<H`02
6<H01RDX8@TU:2486<HDY@8@Q00@5:DHaQS66<HDYAS55:HDY12436<@Q1BU5:HHaA2548@236<00aBU
6<DDY@0336<35:D01aBV48@8@PaR48@HaQBU008<H`8HaP055:D@Q1BU6<HDY00248@03Q255:DDYA24
36<8@PaS5:DDY1BU5:HDYA245:D248@011BT5:DDYABU212400<<I0aS36<00PaS0002:DX032e[:DXQ
22U:<H`]JbDY7>LHaR48:DX]J`8YBP8DY@08;F/e[DicDY@e[Be[:DX]J`8aS007:DXU:BDY;F/aS2e[
8@P00QS6124800<U:AcW8@P00RU:00@]JbDY9BTU:@<Q208YBP0<7>LQ22U:>Li6<D8@?NlicTHaDY@e
[BDY0QBU00LU:B489BTQ21cW6<HLi`028@P2:DX28@P01AcW:DXU:B4848@00PaS00<48@0000000P@Q
200000H48A2448@8@P0012440002124A000212401@aS;F/aS1BU12400P0000<<H`@Q00001P000P@Q
00<<H`@Q00000`@Q0P000P@Q00H8@P0000048@aS24880002124Y00002PQ25:D8@PaS:DXicSF]7>LD
YAS60R480QS600PLibU:;F/U:AcW5:DQ1acX0RDY00<Q1acW7>L00R4800@LibDY8@PQ208Li`038@PL
iaS6008HaP096<LLib489BX]Jc6;;F/]JR49008HaP077>LQ22DY8@PLj2487>L00QBU00TLib487>HD
YQBU7>LDYA255:D00QS60QBU00<LiQcW7>H00QS60acW00DDY@aS5:DLiaS6008<H`095:DLiaS648@<
Ha245:@HaQcW00<DY@0636<8@a245:DLiaS60QBU00@HaQ2548@DY@8HaP0648@<HPaT5:D@Q1BU0QS6
00<DY@aS5:@00AS600028@P02bDY=Jde[Be[:DXLib48:DXU:BU:;F/00bU:00/HaQBU<Ha:DUJe@Q0U
:C6<?Nle[C6<008U:@06:DX]Jbe[;F/Q22DY0QS60QcW0b480QcW0RDY00DYBRDY7>LLib48008U:@0<
7>LHaQcW;F]244YB@Q0icSg_AS5243F]0R480QcW0b4800DHaQcW7>LLib48008U:@8Q20067>LQ22DY
8@PLia240PQ20`0000<48@0000000P0000D48@00000000Q2008DY@0348@48@0000d0000312400000
00800004124000001243000012e[DY@mk`aS0P0000@48@0000048@D000848@03248<H`Q20088@P<4
8@06248000001248@P@Q2`000P@Q00<8@P@Q00002@0000<48@0000001`000P@Q100000<48@000000
2P0001448@Q25:D@Q1cW;F/icRe[6<H@Q2489BTHaQcW8@PU:BDZ008Q20048@LDYQBU8@L2:DX00acW
6<HQ20029BT00b487>LLi`047>L26<H27>L28@P01bU:;F/aS2e/9BTQ2247008DY@0:7>LU:B485:DL
ibU:9BTHaQ245:D28@P00aS65:DDY@027>L00aS648@DY@028@P02acW48DDYAS548DDYAS67>LDYA24
5:D00QcW00DDYA245:HLiaS6008@Q00A5:@DYQS65:DDY0aS24<DY1BU8@PLiaS56<HDYA245:@DY@02
6<H00aBU36<<H`0248@01QBU36<@Q1BU7>H@Q@8<H`4DY00000<YBSW>?Nl00SW>00<YBRe[:DX00bU:
00@U:AcW8@PLi`8Q20056<HU:Be[>Lhe[@02<H`2:DX29BT00c6<=Jde[@02>Lh02S6<;F/Q21cW8@PY
BRe[9BTLiaS60R480bDY00DQ21cW7>LU:B48008Li`046<HQ22489BT28@P01RU:<Ha:DTHa@Q16<@@i
cP03;F/YBR4800HLi`078@PHaRU:>Lhmkbe[48@050000P@Q300000<48@0000002P0000<48@001240
2@000`@Q0P0000<48@aS12400`0000<8@P@Q12400`@Q00@8@P@Q00048@L0000448@Q21S624830002
124800001@@Q000000001240100000D48@00000000@Q00X0000>124000001248@P@Q36<]JdHaDY@i
cRU:;F/U:@8YBP079BT]JcF/;F`U:AS65:D00QcW00<HaQcW7>L00QcW0aS600<DYAS65:D00aS60QBU
00L@Q0aS48@DY1cW8@LHaP035:D02acW9BTYBS6<;F/U:AcW8@LQ22U:8@P00aS60aBU00<HaQBU5:D0
0QBU11S600@DY12448DHaP8Li`036<HDYAS600<DY@096<HLiQBU5:DHaQcW6<HDYQBT00<HaP<DY@8@
Q0@DY@0<36<@QA245:HHaQBU48@8@PaS5:DHaQS50QBU00@DYQ2448@8@`4<H`0000LYBSF]?NlicRe[
9BTQ2004;F/00b487>LQ20027>L28@P012e[<H`icSW>0S6<00@]Jb48:DX]J`8e[@05;F/e[CF]=JdY
BP039BT48@P011cW8@PU:B480RU:00@Q21cW7>LQ208U:@0;7>LQ22487>LQ21cW9BTicSg_AS5:DP02
>Lh01CF]?Nlmkc6<9BT00R4800DLiaS65:DDYB48008YBP057>LQ23g_=JdLi`0200000`@Q0000000;
00000`Q248@<H`0B000312400`Q2000000020002124200000`@Q00000008000212430003124010Q2
00048@000P@Q00H000@Q248<H`Q2124300001`Q2000000@Q;F]242DY01T000848A00000;124001BU
F]IoofLi:DX<HacW=Jd]J`02:DX02RDY:DXYBRDY7>LDYAS65:DLib490acW00<Q21cW5:D00Q2400@D
YAS66<HHaP8DY@045:HHaAS65:H26<H37>L00acX:DX]J`02<H`012e[8@PLj1cW0b4800<LiaS65:D0
0QS600hDY12536<@Q1BU5:HHaABU48@DYQBU48@DY1BU0aS60QBU0Q240QBU00@HaaS66<HHaP<Li`06
6<LHaQBU6<HDYAS60aBU00`HaQBU5:H<H`Q1368DYAcW5:D<H`@Q36<36<H01ABV48@DYA245:@00a24
000013W>?NlicSF]0cg_00<icSg_AS400THa00Y243W>:DXQ21cW9BT]JbU:>Li24096<@09?Nle[CW>
?Nm>Lf<HJeY_NfLi00=S6007IcUF]D8@=JdaS3W><H`00Re[00<aS3W><H`01C6<00<e[C6<;F/00bU:
00XU:BU:<H`e[Cg_@Q0icS6<=JdicP96<@0B?Nle[CF]=JdmkcW><H`YBRe[:DXQ22U:>Lh]JacW1240
00@Q400000D8@P@Q000000@Q00T000848@@000061240000000048@000P@Q3@000P@Q0`000`@Q0`00
00@<H`Q224848@<8@P848@P000031240000000H000848@P0000524848@0000048@0400000`@Q0000
000700000`@Q0000000600001`aS7>LU:Be[:DXLibDY008Li`059BTYBRe[;F/]JP02:DX01RDY8@PL
j2487>LHaP@Li`066<DDYABU36<@Q1BU0aS600<DYAS65:D00aBU00<HaABU5:H00QBT00H@QAcV7>PQ
1b499BP29BT022488@LHaQBU48@<Ha2348D25:D011BT5:DHaA250a2411S600<Lj1S65:D00QS60QBU
0Q2400<DYA245:D00QS600H@Q0aS36<HaABU48@25:D03aBT36@@Q1245:DDY1245:D@Q@Q23688@Q24
5:D@Q0046<H01ABU6<DHaQBV6<D00QBU00001C6<>LhicSg_>Lh00SF]0Sg_00E244Ha?Nle[C6<008Y
BP048@PYBS6<>Lh2AS42?Nl2=Jd01D8@CW=S67>LJeX00f<H00mJeUkgHaQ:DSg_;F/e[D8@=Jd]JbU:
<H`e[CW><H`00be[0SF]00@U:AcW8@PLi`8]J`0B:DXe[CW>@Q0mkcW><H`icTHa@Q0mkcF]<H`icSg_
=JdaS2e[0RU:00HaS2e[;F/aS1S624820002124@00000`@Q0000000<000010@Q000000000P@Q0`00
00<48@0000000P0000<48@00000030000`@Q0PQ200<48@0000000`@Q00@000Q236<48A4000031240
0000008000031240000000D000031240000001D000041248@QS6:DX2;F/01BU:7>LQ22487>L00RU:
00<aS2e[9BX00RU:0R481QcW00@DYAS65:DDY@DHaP8DY@8<H`0<48DDY1S66<HDYQS65:D8@a246<DQ
2BDX0R4800HU:B488@PDYQS65:D248@01QBU5:HHaABU48@@Q@8@Q0046<HDYAS66<H25:D00aBV6<HH
a@0248@030aS5:@LiaS75:D@Q1BT7>LU:AS536@@Q08DY@0348D<Ha23008@Q00348D@Pa25008DY@8@
Q08DY@0436<8@`Q236<25:D27>L021S55:DDYQcW6<H@Q0aT48<15:D00003;F/icSF]008YBP8U:@0<
<H`]JcF]>Lhmkd8@=JdLiaBU6<HQ236<0RDY0RU:00<U:BU:;F/00SW>00<mkdYBBU800eJe00EBU4YB
BU9243g_008e[@03<H`YBRe[00@aS08]J`048@PLiacW7>L2:DX28@P37>L28@P2:DX02QcW6<HLibDY
<H`YBR487>LU:CW>0T8@00Te[BDY8@PYBRDY<H`icRDY6<H02P0000<48@000000200000<48@000000
1@0000<48@0000000P000P@Q0P0000<48@Q21240100000@48@0000048@D000051240000000048@02
24801@@Q0000000012400P0000<48@Q200000P000`Q20P@Q0`000P@Q200000<48@Q212400`0000<4
8@0000002P000`aS00<8@P0000000P000P@Q400000/48AS67>LLicF]@Q0e[BU:5:DHaRU:008]J`09
9BTHaR48:DTLiaS56<HQ22U;008U:@0?:DXQ2B486<HDYAcW9BT]JbU:7>L@Q1BU6<DDYQS600<DY@04
5:@@Q0aS36<35:D05Q256<HQ21cW9BPQ2AcW9BTLiaBU6<DDYQS648@<Ha246<HDYA2436<@Q1BT0a24
0QBU00<@QA2436<00PaS00DDY12448@<I124008DY@8@Q004248<HPaS48D25:D010aS48@<H`aS1124
00<<Ha245:D00Q240`aS00L<I0aS36<@P`aS48@DY@0348@0000:;F/aS3F]<H`YBRDY:DX]JbDY<H`2
BU801CW>8@P@Q1S68@P00RU:00`U:BU:;F/aS2U:;F/aS3g_@Q16<DicBU82E[D015:DCW=244Ha0T8@
00<icRe[;F/00Re[0S6<00HYBRDY7>LU:B487>L48@P01acW6<HHaQS68@PU:B4800<YBP059BTLib48
8@PLi`028@P03RU:?Nm6<D8@=JdHaPaS;F]>LdYB<H`48@0012450002124>0002124400000`@Q0000
0002000212400`Q200048@03124200000`@Q0000000600000`Q236<48@030002248600000`@Q2484
8@02124010Q2000000@Q0PQ200<48@0000002@0000<48@Q212400`000P@Q2`0000D48@Q236<8@P@Q
018000848@8000031248@QS6008icP05@Q0e[BU:9BTQ20039BT38@P01AcW7>PHaQS69BT00RU:00LU
:1cW8@PLiaBU6<HLi`028@P00acW6<HHaP028@P02QS648@<Ha256<HHaABU48@HaQBU0aS60QcW00<Q
21cW8@P00R4800@LiaBV6<HHaP8DY@8@Q00=5:DHaQBU48@<Ha2448D@Q1BT5:DHaQS55:D00`aS00@@
Q1BU5:D@Q08<H`0936@HaABU5:D@Q0aS36@DY12400<<H`055:@@Q1245:@<H`0324800a245:DDY@02
48@020aS48<<I0aS36@@Pa2436<25:D16<H000047>LU:BDY8@P37>L022U:=Jde[Be[:DXU:BU:8@P2
6<H00aBU8@PQ2002:DX01R486<HLibDY<H`e[@@]J`8aS007:DXe[DHa@Q0icR487>L00RDY0Re[00<Y
BR487>L00QcW0b4800PYBR487>LHaPaS48@HaR480RU:00@LiaBU6<HLi`8YBP067>LHaQS66<HU:Be[
0bU:0QcW0QS600LDYAcW5:D8@P@Q248<H`04000212400`001240000400000`@Q0000000900000`@Q
0000000312401@Q236<<H`aS48@00PQ200<48@Q224800P@Q0P0000<48@0012401P000P@Q0P0000<4
8@Q212400`0000H48@aS12448@0012422482124700000`@Q0000000300000`aS248<H`0212422482
124:00001@@Q7>LYBQS624804@0000<48@0000000`000PQ200T<HbDY:DXYBQcW5:DHaQcW6<H00QBU
0aS600TDY1255:DHaAcW6<LHaABV6<D00QS60QBU00<@Q1BU6<H00acW00<DYA245:D00QcW00<HaQ25
5:D00QS60QBU00<@Q1BU5:D00aBU00@DY1BV5:DLiP8Li`8HaP0:7>LQ22486<HHaABV6<HDYAcV6<H2
7>L00aS65:D@Q0035:D01@aS248<HaBU5:@00QBU00/@Q0aT5:@<Ha2448<@Q1255:@@Q12500@<H`03
48D@Q12400<@Q08<H`0;248@Q1BU5:D@Q0aR24<@Q1BU6<D@Q00124<000<U:@8Li`068@PLibe[<H`e
[C6<0bDY00<LiaS67>L00RDY00<Q22DY:DX00bDY00<YBRe[<H`00c6<0RU:00de[Cg_AS52436<;F/Y
BRDY:DX]Jc6<;F/YBP027>L26<H01BDY:DXQ21cW6<H00QBU00h@Q1BU7>LU:Be[:DXLiaS67>LU:B48
6<HDYAcW0RDY0R4800@YBRe[:DXLi`8DY@057>LU:AcW36<48@0700000`@Q0000000700000`@Q0000
0002000010@Q000000@Q10000P@Q10Q200<<H`Q212400PQ200D@Q0aS1248@P@Q00<000848@<00084
8@<000848@88@P@0000524848@@Q24848@02000224830002124600001PQ236<<H`Q236<8@P848@04
00048@Q2248400031243000020aS9BTQ20aS124000@Q248D000031247>LHaRU:<H`U:ABU36<HaR48
7>LHaP<DY@086<HDYABU6<HQ21cW5:DHaP8Li`0448@<HPaT7>L26<H05AcW9BTQ22485:D@Q0aS5:@H
aQ245:DHaQcW6<HDYQBT5:HDY0aS5:DDYP026<H00aS55:DLi`02:DX00b486<D@Q@026<H01aBT5:HL
iQcW6<HDYABV00<HaP0348DDY@aS00<<H`055:D@Q1245:D@Q00236<041245:HHaQBU36@<Ha2448DD
Y@aS5:DHaQBU48D<H`aR0Q240`aS00<8@PaS48@00QBU00H<H`Q236<@Q12548@236<0008U:@087>LQ
22U:;F/YBR48:DXU:@8Q208YBP039BTLiaBU008HaP035:DQ22DY008YBP0<8@PLib488@PU:C6<>Lh]
JbDY7>LQ22e[0bU:00@]JbU::DXU:@<YBP8U:@038@PHaR48008YBP088@P@Q1BU7>LHaQBU6<HLi`8Q
20<DY@8Li`055:DHaQcW9BTQ20025:D00aS65:D<H`0236<011S65:DHaR480QcW00<@Q0@Q24800P00
00@48@Q224848@H000031240000000X000<8@P0A00048A247>M6<Dic>LhQ20aS48@LiaS648@<H`Q2
1248@P041244000212440002124500000`@Q00048@0224800`@Q0000000200000`@Q000000040000
2@@Q000@Q2U:?Nm:DS6<8@PHaP0448@2248600001`@Q000001S6:DXaS1cW01P00005248@Q0aS248L
i`02<H`00b4836<@Q0055:D236<01A245:DHaQS65:D00QcW00dDYQS66<HQ1b487>LDYA246<HLib48
7>LDY@026<H06ABV8@LQ22U:9BTLiaS65:DHaQcX6<HDY1245:HHaQ2436@HaQcW6<D@QAS58@P]JRDZ
008Q200:5:D@Q1255:@HaQBV6<DHaQBU36@236<03PaT36<<H`aS5:D@Q@aS48@HaQcW5:D<Ha246<D3
5:D011S55:DDYQ240PaS00<@Q12524800PaS00@DY1BU36<<H`8@Q00436<@Q1245:@236<1248136<0
00<Li`06:DXU:Be[<H`Q21cW0QS600HQ22e[;F/Q21S65:D37>L00b48:DXU:@027>L00b48:DXU:@03
:DX012DY8@PU:BDY0RU:0Re[00@YBRe[;F/YBP8U:@04:DXQ21cW6<H27>L00aS65:DDY@036<H25:D0
0aS68@PLi`036<H00acW6<HDY@025:D011S67>LDYAS60QBU0QS600/DYA2436<<HacW9BTLiaBU2484
8@Q200848@88@P031240000000<48@L000031240000000@000<48@09248000Q2:DY6<Dic<H`HaQcW
008HaP0548@<H`Q21240000224800`@Q000000030003124300000`@Q000000040002124400022480
10@Q000000000P@Q1@0000/48@007>M244icAS4Q21245:DHaQBU008<H`<000<48@<00008124@Q2DY
8@PHaQ2400048@l000032480000000<00003124<Ha24008Q200:9BTYBQcW6<H<H`Q236<@Q1S65:D2
36<00aBU6<HDY@025:D56<H011cW7>PHaQS60aBU00hHaQBU5:DLiQS66<LHaABV8@PYBRDY7>LDYAS6
0aBU00/@Q1BU5:DHaABU5:@<HaBV6<HQ22DY00@Q20037>LDYABU00<@Q0045:DDYQS55:D436<01123
36<<I123112400<DYAS66<H00aBU00PDY1S65:HHaQS548@DY@aS0PQ200X@Q1BU48@8@PQ348@HaQBU
48@DY@D@Q08<H`0012U:00DU:Be[<H`YBQcW008DY@039BTYBRU:008YBP047>LHaR48:DX2<H`2:DX0
12e[<H`aS2U:0R480RU:00<U:B488@P00R481AcW0RDY00@Q22DY:DXYBP8e[@0=;F/YBQcW6<HLib48
9BTLiaBU48@DYAcW6<H00R4800@LiaS65:DHaP8Li`048@PLiacW6<H27>L031S65:DDY@@Q000@Q1S6
@Q1F]D8@:DXDY@<00008248<H`@Q248@Q1BU48@48@<000031240000000<00003124000000080008<
H`0548@48@aS36<Q2003Ool02Vmk>LiBU5:D?NlQ21BU6<H<Ha240PQ2100000@<HaBU5:D<H`800003
2480000000P00088@P848@T0008<H`055:D8@QS69BUF]@03Ool01EJe@Q1BU4Ha=Jd00QBU0PaS0PQ2
00<48@0012400P0000D8@PaS7>LQ20Q200<000031240000000h000081240000000048@aS248HaP<L
i`0448@DY@aS248236<25:D248@00aBU6<HHaP027>L02aS65:@<I1246<D@QABT48DDYAS65:D00aS6
00PHaaBU48@DYAcW8@PLiaBU0Q240QBU00T@Q0aS5:DHaR487>PLiacX8@L00QcW00P@QABU8@PU:C6;
:D/U:BU:0R4800HHaQ2448@DYAS65:D248@04ABT5:HDYA2324<@Q1BU7>LHaQBU6<HLiaS65:HHaAS7
7>L00QS600<LiaS65:@00Q2400<DYA2448@00Q240PaS00X<I1245:D@Q1BU48@@QABT5:DHaP4Li`00
00@U:CF]<H`]J`8U:@05;F/YBQcW5:DLi`02:DX01BDY6<HHaQS68@P00Re[00PYBR488@P]JcF]<H`Y
BR4812U:0bDY11cW00dQ21cW8@PU:Be[:DXQ22DY;F/e[CW>9BTQ20026<H00b487>LHaP027>L011S6
48@DYAS60QcW0aS600<DYAS65:D011S60aBU00H<HaBU248001S6>Lh2HaP00bDY24800002000336<0
1@@Q248HaQBU36<0100000<48@0000001P0000<48@Q236<00PQ200@000Q2@Q1_N`9oo`9F]@924005
=Jd]JaS65:D<H`0312401@Q2124000@Q24800PaS100000<48@0000001@0000H48@0012448@Q21248
000020Q236<8@PaS248002DYIcT2Ool00fLiAS5:DP02CW<01CF]:DX8@PQ212400`0000D48@001240
00@Q008<H`036<H@Q0@Q00/0000312400000008000848@L0000648@DYB488@PLiaS60Q2400DDY@aS
36<<HaBU008<H`0648@DYB487>LQ21cW0QBU00L@Q0aS48@<Ha245:@DY@027>L011S65:DDYAcV0QcW
0aBU010HaR476<H@Q0aS48@DY@aS6<HQ22DX7>LDYAcW8@TQ1`8HaP0@7>LQ2248:DXU:BU::DTHaaS6
5:@<I1BU48@DYAS65:D248@01@aS5:D@Q1245:D00aS600<HaABU6<H00Q2400@DYQS67>LHaP8DY@03
48DDYABU008DY@035:@@Q0Q20088@P0348@HaA24008<H`0448@HaQS636@236<16<H0000?;F/U:Be[
;F/U:AcW8@PU:B489BTQ22DY7>LQ22DY008Q20037>LQ22U:00H]J`0=:DXQ22DY6<HDYAS68@PYBR48
9BTYBRDY7>L00QS600<U:B48:DX00R4800/U:B48;F/aS2DY8@PLibU:<H`]Jb48008Li`045:DHaRU:
;F/2:DX26<H01AcW8@PU:BU:8@P00QBU00DLibDY7>L8@P@Q008<H`800004248DYABU48@236<010@Q
36<48@000P@Q00D8@P@Q12448@Q200D000031240000000D00004124DYAcW5:D2248010aS:DYS66]J
1goo00ANmc6<5:D@Q0<48@0700048@@Q5:DHaQ2412400P0000<8@P@Q0000100000D8@P00000000@Q
0088@P<0000324848@0000@000085:DU:BU:6<HDYAS6BU9_N`Moo`06HaQ6<AS636<@Q0@Q0`0000<4
8@Q212400P000PaS00<48@0000005P000P@Q0Q2400<DYA2448@00QS60QcW0QBU0aS61QBU0aS60QBU
0Q2400T@QABU5:@DYQS65:HDYA2336<00QBU00DHaQcW6<HDYQBU008<H`0;7>LU:BDY8@PDYQBU6<D@
QAS57>LQ20027>L25:D02AS78@LQ21cX9BTYBRe[:DXQ1`026<H01ABU6<DHaQBU6<H00QBU00<HaABU
48@00QBU0QcW00LQ21BU5:DHaR478@PHaP025:D26<H011BU5:@@Q0aT0QS600<DYA2436<00`aS0Q24
0QBU00<<Ha235:D00AS60002:DX48@P01BU:8@PQ21cW8@P00RDY00@Lib48;F/]J`8YBP03;F/aS2e[
00<YBP079BTYBR487>LDYAS69BT00RU:00TLiaS69BTQ21S65:DLibDY8@P00QcW00<Q22DY8@P00bU:
00LLibU:>LhicS6<7>LHaP028@P012U:;F/YBRDY0R4800DLib489BTU:AcW008HaP057>LU:B486<HD
Y@02248010@Q0008@Q240QS600<@Q0Q212400`Q200L48@000008@PaS24848@0=00002@@Q36<DYABU
36<8@QBU9BU24008Ool00eJe>LhQ200236<22482000011BU:DX]JaS620000P@Q0`0000@48@002484
8@H0000<24800000248HaRDY7>L8@PaS:DXe[Ekg27oo00LmkcF]48@8@P@Q00048@0300001P@Q2484
8@aS48@48@<000031240000000T000031240000000L000071248@Q2448@DYAcW6<H011BU0QS60QBU
0QS60QcW0QBU0Q2411BU00THaPaS368@QAS68@LHaQ2436@00Q2400<HaQcW7>L00QBU00@@Q1BT5:DH
aP8Q208Li`@DY@076<HLib487>LHaQBU6<H00QcW0RDY00T]Jc6<:D/U:1cX7>HLiaS65:H00aBU00DH
aQBU48D@Q0aS008DY@0?6<LLiacW6<H@Q1S66<LLiaS55:DHaQcW6<HDYA24008DY@0348DDY124008@
Q0035:DDYQBU00<@Q0045:@@Q1255:D16<H00003<H`]Jbe[008]J`<Q20037>LYBRU:008]J`03<H`Y
BRDY008U:@03<H`e[Be[008YBP04<H`mkcg_<H`2=Jd032U:8@PLib486<HDYAS67>LYBR486<HLi`8Q
2007:DXQ2248;F/e[CW><H`00RDY12e[00HU:AS66<HLib48:DX28@P01BDY7>LDYAS67>L00RU:00XU
:AcW7>LQ22DY7>LDY@Q236<48@8000041248@PQ2124200000`@Q2480000200000`@Q24848@020000
0`@Q0000000<000010@Q248<H`Q20QBU00<YBWNmOol02Goo00<mkaBU00000`0000<48@0000001@00
00<48@0000000P000`@Q0P000P@Q1P000`@Q0`0000L<H`Q236<<Hb489BUJeP0:Ool00dic8@P48@0V
0002124021BU7>LHaQ24248<HaBU48@236<02AS65:D@Q1246<HDY@aS248<H`047>L01QS65:DDYABT
48@DY@8@Q00436<@Q1S66<H248@01Q235:D<H`aS24<<H`8@Q08HaP037>LQ21cW008DY@0348@HaQcW
008Li`8DY@036<DDYQS5008DY@037>LHaQcW008Q20047>LHaABV6<H25:D248@01QBU6<HHaQS66<D@
Q08DY@8HaP036<D@Q124008@Q0086<HLiacW6<LDYA245:@<I0<<H`0548@<HaBT6<H@Q00236<00`Q2
48@<H`0148@00009:DX]Jbe[;F/YBQcW6<HLibDY008e[@<YBP0A9BTYBRe[<H`icSF]:DXU:BU:;F/e
[CW>=JdaS2e[9BTQ20037>L011BU6<HQ22DY0acW00HU:B488@PQ22U:<H`3=Jd02bDY7>LYBRU:=Jd]
JbDY5:DHaQcW9BT00R480QBU0QcW0RDY0RU:00DQ22DY9BTLiaS6008DY@8<H`04124000@Q12422483
12420003124@0003124200001P@Q36<<HacW;F]6<@Yoo`03@Q048@@Q00D000031240000000D00084
8@@000031240000000@000848@H000081248@PQ236<@Q0Q2<Ha6<@]oo`0348@48@0000T000848A/0
000748@DYAS65:D<Ha245:D00Q2400<DYAS66<H00a240QBU00@@Q0aS36<DY@8Li`086<HDYA2448@<
I1BU6<HDY@<@Q08HaP0448@<H`Q336<25:D2248010aS5:D<HaS60R4800DHaQ245:HQ21cW008DY@05
7>HDYABU48@<H`025:D00aS67>LLi`028@P02BU:8@THaQBU36<@Q1S648@DY@0348@021BU48@@Q1BU
6<HDY@aS48@26<H01a2536<<HaS67>LQ21cV008DY@076<HDY0aT368<I12324<00a2400D<H`Q236<@
Q0aR004<H`0000M>Lf<HJeYNmeJe;F/YBP02<H`033g_=JdicT8@BU8mkc6<=JdicSg_=JdU:@<Q2005
9BTQ21cW8@PU:@028@P011cW8@PQ21S6124800<HaQcW9BT00RDY01H]JbU:9BTQ21cW8@PLiaS67>LU
:Be[=Jd]JbU:9BTLibDY8@PLib48:DX]J`LYBP8U:@046<H@Q1242486000412420003124500000`@Q
24848@0500000`@Q00048@0300001@@Q24848@@Q00000Q2400<Lie[FLi`02Goo00EJeRDY00048@Q2
00848A000003124000@Q00P0000412400000124200001PQ25:DaS2e[AS5cW0Uoo`03MkdicPQ200@0
00848B80008@Q0045:D@Q0aS36<448@01ABU6<HHaQBU48@00PaS00DDY@aS36<@Q1S6008DY@0448@H
aQBU48@2248011245:DHaQBU0Q2400<DY1255:D00Q2400H@PaBU36<8@Q245:D28@P03QS65:DHaABV
7>LYBR49:DXU:AS65:D@Q1S68@P26<H01R48:DXHaQBT6<HQ208e[@049BTQ21BU5:D26<H021BU248<
HaBU8@PYBR486<H37>L00aS65:HDY00348@02ABU48DDY1BV5:@@Q0aS24<<HP0236<248@010aT36<<
H`aT0ABU00002E:DIcUS64YB=JdQ22U:>Lhmk`02@Q000cW>=Jdmk`02>Lh2?Nl00c6<:DXU:@03:DX0
1BDY8@PU:AcW8@P00bDY0QcW0R4800LYBQS636<DYBU:=Jd]J`028@P2:DX02B487>LQ22DY7>LYBS6<
>LhaS0038@P27>L01b489BTYBRDY:DXaS2U:008U:@068@PYBS6<;F/LiaBU0PaS0P@Q1`0000<48@Q2
12402P000P@Q2@0000<48@Q224800P@Q00D<H`Q25:DU:Cg_00Yoo`03IcTU:ABU00<000848@h00004
24848@00124:00002P@Q24848@@Q248DYA24<Ha247_N2Woo00@]JaBU000000848B@00003248DYAS6
008@Q00936<8@PaS36<@Q1BU48@DYA24008DY@<@Q00536<DYABU5:DDY0025:D02aS65:D<Ha246<HD
YA2324<@Q1BU48@00PaS00H@P`aS36<@QABU5:@236<02QBU8@PLiacW6<HHabDX;F/YBR480QBU0QS6
00<Lj1S67>L00b480QS6014Lj2489BTaS36;8@THaQ235:DHaQBU48@<H`aT5:DLib4800<Li`038@LQ
21BU008<H`0=5:DLiaBU36<@Pa2548@@Q@aS248<Ha245:D00Q2400D<H`aR36<DYA23004<I00000AW
>G>LLiaNm`9BU00:E[ENmf<HCW<icRU:8@P]JcF];F/2?Nl023W><H`YBRU:<H`e[C6<8@P27>L00bDY
:DXQ20028@P02QcW48@HaQcW8@PDYAS67>LYBR480acW0RDY00<LiaS66<H00R4800PLiaBU6<HQ21cW
6<HDYA240QBU0aS600@DYAS66<HLi`8YBP068@PDYA245:D8@P@Q1P000`@Q0P0000<48@0000005P00
00@48@0012448@8<H`036<HicTHa00Moo`05Lia:DR487>L<H`0224800`@Q0000000500000`@Q0000
00060002124=00001@Q212448@@Q24800QBU00<U:DHaJeX01Woo00=g_E[F8@P00QS60PaS0PQ29000
0P@Q00@Libe[:DXQ208@Q0036<HDYA24008<H`0:48@DY@aS36<8@PaS5:D@Q0aS36@248@236<02A23
36@<HQ245:HHaA2424<<H`0448@00`aT48<<I0035:D248@01aBU7>LQ22476<HDYAS6008Q208DY@06
6<HHa@aT5:@Lib480QBU00DLibU::DXLiaBU008HaP096<DQ2Be[:DXLiaBU6<DQ21cW008HaP087>HL
iacW5:HDYA2436<DY@8HaP0B48D<HPQ35:@@Q0aR48@HaQBU48D<HPaS36@@Pa2424<<HaBU0AcW0002
Mkd03FmkCW=6<DicG_MW>EJe=Jd]JbU:8@P]JcF]00<icP03;F/YBRe[008icP03<H`LiacW008Q208U
:@038@PLiacW008Li`065:DHaQBU48@DYAcW0RU:0RDY0b480QcW0QS60QcW0RDY00@Q21S65:D@Q0TH
aP077>LQ22487>LDY@aS24800P@Q00<000@Q00000`0000@8@P00000000<48AH0000324848@000080
000548@DYBDYE[E_N`07Ool01U[F;F/DYA2424848@88@P071240000000048@Q212403`000P@Q0`00
0P@Q0P0000<48@Q212400PQ20QS600<mkfLiOol01Woo00EF]D8@6<H@Q0Q200<00088@R4000091240
00aS48@Q22DY8@PU:AS6008DY@8<H`8@Q08DY@0724848@Q236<LiaS65:D00Q240PaS00@@Q1255:@<
I0<<H`0648@@Pa245:D@Pa2411BU0a2400<DYAS66<H00QBU010DYQ235:DQ22U:8@PHaPQ236<Lib47
9BXQ21S67>LQ208Li`0E6<HLiacV7>PLiaS68@PYBRDY6<H@Q1BU8@PLj1cV5:HHaR489BPQ21S6008<
H`8@Q00648D@P`aT5:@DYQ240`aS00<DYA2448@00Q2400DHaQBU36<<HacW004YBP000Tic0dYB00mc
W7ooKg]S64HaBU9S65[FG_MS65kgHaQNmd8@?Nl00Re[00<aS2DY8@P00QcW00LDYAS66<HLiaS65:DH
aP028@P011cW6<HQ22DY0QcW00<HaQcW7>L00acW00LHaQBU5:DLibDY8@PHaP037>L01aS65:D@Q124
6<HQ21cW00<Q20037>LDYABU00<DY@0336<8@P0000D00004124000000002124300000`@Q0000000D
00003@@Q48@DY@Q2124000@Q<Ha6<F<HE[E:DUJe009BU009>LhLiaS69BTicRU:36<000@Q00D00003
248<H`Q200L000848@d00003124000Q200<DY@09248001BU?NmW>G>LDYA244YB0096<@068@PDYABU
:DX]JaS6:@0000P8@PaS6<HQ21cW6<HDYA240QBU00D@Q0aS48@DYA2400<<H`8DY@066<HDYA2448@<
H`Q2112400<<Ha2448@00`aS00T@QABU6<HHaQS56<HLib487>L00QS600DLibU:<H/YBb4800@Li`03
6<LHaA25008DY@056<HHaA2536<@Q0026<H011BU36@<HQ250QcW00/HaQBU6<HQ2Be[:DXQ21cW6<HQ
21BU008<H`075:DLiaS648@DYABT48@00`aS00PDY12548@<H`aR48<@QA240QBU00@HaQBU5:D<H`4@
Q000019JeU:D@Q1BU6LiMke_NeJeDYA>LdYBDYAJeUkgJeYW>EJeBU82<H`01be[<H`YBQcW5:DLib48
00<DY@056<HU:BDY7>LHaP025:D01R489BTQ21cW6<HDY@8Li`066<HLiacW7>LQ21cW0QS611cW0R48
00DDY@aS5:DHaRU:008U:@048@PHaQBU6<H27>L011BU248000@Q1@0000<48@0000001P000`@Q1P00
0`@Q300001L8@PaS48@<Ha24248@Q3g_F]Ig_EkgAS5BU4Ha?NlYBQBU6<HYBS6<7>L8@P0000848@<0
00<48@<000031240000000h00005248000000008@P025:D224803124248YBU[FKg]cW4YBAS5F]DHa
=JdLi`8HaP037>LDY@Q200H00003124000000200000548@LibDY9BTDY@0548@236<01A2436<<H`aS
48@00acW0QS60PQ200h<HaBU6<HDY0aS48@<I0aS48@<Ha2436<@Q1S60QcW00@HaQcW8@PHaP8DY@08
7>L]Jc6<:D/YBB485:DHaP8DY@8HaP8DY@0548@@QABU48<<H`0248@01ABT48@DYABV6<D00QBU00<@
Q1cW9BT00Re[00HQ21S55:DDYAS65:D236<00aBU6<HDY@025:D01QBV48@<Ha2448D@Q0<<H`0436@<
Ha2336<45:D148@15:D16<H0000?AS4mkcg_AS5245JeF]I>Lcg_@Q1>LfmkLiaW>F<H00=JeP07HaQN
mdicBU8e[C6<;F/012U:0QcW0R4800<U:B487>L0124800@U:AcW6<HHaP8Li`048@PLib488@P37>L0
0aS67>LLi`038@P348@02AS67>LHaQBU48@HaR489BTDY@0236<00a242480000L00000`@Q00000008
00002PaS7>LLia241248@Q245:DU:AcW0R4800THaQcW5:D<Ha248@PYBQS62480100000<48@001240
0PQ200<48@0000005P0000H<HaS68@PQ212436<248@01AS67>LLiaS65:D00QS600H@Q0Q236<DYAS6
36<40002124600000`@Q0000000L000020Q27>Le[D8@;F/HaQBU36<348@01aBU6<HDYA2436<@Q1S6
008DY@8<H`055:DHaR487>L@Q@025:D00aS55:D@Q00236<35:D03Q2436@DYABU7>LHaQBV6<DDYQS6
8@LQ2BDY7>P25:D00aS57>LLi`027>L35:D01AcW8@PLiaS636@00Q2400<DY1245:D00a2400dDYAS5
48DHaB488@TU:AcW5:DHaaBU36<@Q0026<H010aT368<HaS60QBU00@DY12448@<H`88@P0324<<Ha24
008@Q00348<@QA24004@Q00000A244Ha@Q1:DP9BU008F]I:DSW>AS5F]G>LMkeW>@9F]@06F]INmf<H
HaQ6<Cg_0RU:00l]JbDY9BTU:BU:8@PLib489BT]JbU:7>LHaQcW8@P00bDY0acW00<Q22DY9BT00QcW
0QS600PQ22DY9BTQ21S67>LQ21S60Q2400@DYB486<HDY@8Li`8DY@8HaP0336<48@0000848@<00003
1240000000P000<48@<000051240000000048@0300000`@Q0000000600001`Q25:DLiaBU36<000Q2
008HaP8U:@048@P]JacW5:D236<01ABU7>LHaPaS12401P000PQ20P@Q0P0000<48@0000002P0000<4
8@0000000P0000`48@00124001BU8@PYBQcW248001246<H28@P25:D01AcW48@8@PaS5:D00QS600<8
@P000000:P0000TDYCF]@Q0mkacW36<HaQ2436<00QBU0QS60Q240aBU00<@Q0aS36<011BU00@HaQS5
6<LDY08<H`0948@HaQBU48<<I1BT5:DDY1BV00<DY@0<7>LHaR489BTYBRU97>LDYAS65:DDYQcV0QcW
00@HaQBU5:DLi`<HaP0B5:DDY12448@@QABU48@DYA245:D@Q1cW8@PU:BU;9BPLiaS60QBU0Q2400LD
YAS65:DDY0aT36<@P`035:D02A2436<@Q0aR128<HPaS5:HDY@0248@15:@148@148D000038@PU:BU:
00@e[@03<H`icTHa009:DP04CW=BU5JeE[D4F]H015JeF]IBU5:D0THa00DicRe[9BTLib48008U:@08
:DXU:AcW6<HLibU:;F/U:@8DY@8Li`036<HLiaS6008HaP8DY@@HaP<Li`035:D@Q1BU00<DY@<HaP8D
Y@046<HDY@Q212440002124800000`@Q0000000500000`@Q24848@0900000`@Q0000000500001@Q2
5:DHaR486<H00QBU00L@Q0aS48@@Q1BU36<8@P0200000`Q236<8@P0400000`@Q0000000200021240
0`0012448@0800001@@Q000000001240200000@48@006<HU:@8YBP055:D<H`aS36<8@P0236<248@0
1P@Q000000@Q24848@L000031240000001h0000:1240000000048B48;F/YBR487>L35:D01aS67>LL
ia2436<8@QBU00<Li`035:DHaRDX008U:@058@P@QA2436<@Q0045:D011BV5:D@Q0Q30`aS00T@Q1BT
36<<Ha245:DHaQ255:@00aBU00HDY0aS36<<Ha246<H25:D348@35:D01aBV6<D@QA2436<DY1S6008D
Y@0436<@Q1BT6<H248@02AcW:DX]JbDX5:DDYQBT48D@Q00236<00a245:HDY@055:D536<00a2448D@
Q00148<0008YBP0>9BT]JcF]=JdaS3W>@Q1>LdYBAS5BU5[FG_MF]@9BU0=JeP0:E[E>Le:D@Q0aS2U:
8@PYBRDY7>L28@P2:DX042DY8@PLib489BTQ21cW5:DHaQcW8@PLiaS648@HaQcW1AS60QcW00DHaQ24
36<<HaBU00@Li`035:D<Ha24008HaP0448@000000002124400000`@Q0000000500000`@Q00000002
0002124400000`@Q24848@0700000`@Q00000002000030aS7>LLib485:D<H`Q248@DYAS648@<H`8@
Q0848@030008@P@Q00<00004124000@Q124300000`@Q2480000C00002`@Q000000aS6<H]JbU:6<HL
iaS624800P@Q00H<HaBU36<8@PaS124:0002124K00000`@Q0000000600001`aS48@Q236<:DXLiaS6
008@Q08HaP8DY@8@Q08DY@0>6<HDYABU8@PU:BU;:DXLiacV48@<Ha2448D@Q088@P0336<HaA240088
@P0748@DYA2548<<I12436<00QBU0QS600PDY@aS36<DYQS65:H@Q0aS0QBU00<@Q0aS5:D00QS60aBU
00THaAS648@<H`aT48@HaQcW5:D00Q2400D@QB487>LHaR48008YBP098@TDY1BU5:D@Q1BU36<@Q1BU
008HaP0348@<HPaT00@<H`0648<<H`aS48@HaA250@aS00000bDY8@PQ20029BT012U:9BTQ22480RDY
00<YBS6<?Nl00Sg_00PicSg_@Q0mke:DHaQg_G>L0VLi00MS65:DBU9>LdYBAS4icP02;F/02C6<=Jda
S2U:8@PYBSW>=JdYBP038@P27>L00aS65:DHaP025:D01acW9BT]Jb485:D<HaBU008HaP045:D@Q124
6<H25:D424800`@Q00000002000011BU36<<Ha240P@Q1P000`@Q0P0000@8@QBU5:D8@P8000031240
000000D000848@L00009248<Ha248@PYBR4836<e[E[F009oo`03>LhQ20Q200@000031240000000T0
00051240000000048@0400000`@Q0000000<00000`@Q36<Q20029BT2:DX02aBU48A:DVmkNmiF]@aS
24848@0012408`001@@Q1P0000@48A247>LQ208HaP047>LHaQS636<224800`aS5:D@Q00248@01aS6
8@PU:CF]<H`]JbU:008<H`88@P<DY@8<H`0636@DY124248<HaBT0QBU0Q2400DDY12448@@Q125008@
Q00436<@Q1BT5:D248@011BU48@@P`aT1Q2400T<HaBU6<HHa@aS248@Q1BU36<00PQ200<@Q1S65:D0
0QBU0QcW00TYBRU98@TQ21cW6<HDY@aS5:@00PaS00/DYQcV7>LHaQ2436<DYQS67>LQ21BV008<H`00
0R480QcW00<Q22U:9BT00RDY00@YBRDY;F/icP92408icP=6<@0=HaQW>GNmNmiW>EJeCW=:DU:DBU96
<C6<=Jd00S6<0Re[0RDY00HYBRe[<H`YBQcW6<H27>L01aS67>LQ21S636<DYAS6008YBP8Li`076<HD
YABU6<HDYAS67>L00QBU00D<Ha2436<8@P@Q00D000061248@PQ2248<H`Q21`0000<48@0000000PQ2
0Q2400<8@P@Q00003P0000D48@001248@QBU008Li`0=6<HQ22487>MBU6]JKg]NmacW36<8@P001240
3`000P@Q1@000P@Q1@0000<48@0000000`0001048@00000<HaBU9BT]JbDY5:DHaRDY>LicW6mkBU8e
[@d000848AX000<48@L0000436<Q22DY7>L25:D27>L01aS636<@Q12436<@Q0aS008DY@077>LYBRe[
=JdaS1cW5:H00PaS1ABU0Q2400<DY12548@00PaS00P@Q1BV6<HDYA2436<@Q1S60Q240PaS00P@P`aT
48@<Ha2336@@P`Q30PaS00<HaABU48@00PaS00LDYAS66<H@Q0Q336<DY@0248@336<01aBT6<HLiacW
6<HLibDY008YBP038@LLiaS600@DY@056<HDY@aS36<@Q0045:D01AS67>LDYA2336<00ABU00001B48
:DXU:BU:9BT00RU:0RDY00TQ21cW8@PYBRe[<H`]JbDY:DX00S6<00<mkd8@AS400Tic00=:DUJeLi`0
0goo00acW6<HCW=>Le:DBU9243g_=Jd]JbU:7>L39BT02AcW6<HDYABU6<HLib487>LDY@066<H02ABU
36<@Q1246<HLiaBU48@8@P0212460002124020aS48@HaQcW5:D<H`@Q00022483124200001`Q236<<
H`Q2124000@Q00@000@48@P00004124<Ha245:D336<01acW8@PQ22DY6<H<H`Q200848@@000031240
000000L000031240000000`000031240000000D0000312400000008000051248@Q246<HDY@028@P0
0acW5:D48@0:00000`@Q0000000200000`@Q0000000<00000`@Q48@8@P05000212401@aS124000Q2
12400`0000H48@0000048ABU8@P27>L01AS65:DHaQ2436<00PQ20Q240QBU0acW00hYBRe[;F/YBQBT
36@<HQ235:HDYA2436<@Q1250QBU00@<Ha245:DDY@<<H`0348DDYABT00@@Q08DY@0548@<H`Q336<@
Q00336<02Q246<HLiaS648DDY1BV6<HDYA230Q240QBU0PaS00D@Q1BU5:HDYABT008DY@086<HDYA25
5:DLibDY9BXQ208Li`035:D@QA2400<<H`0848@@PaBU5:DHaQBU5:HHa@4HaP0000HQ22DY:DXU:AcW
8@P2:DX01B487>LYBS6<:DX00RDY00D]Jc6<;F/e[Cg_0096<@92409BU006IcUoogooOomkgUJe0U:D
00AF]DicBU8e[@8aS003:DX]JbDY008Q20047>LQ22486<H25:D00aS67>LHaP025:D00acW5:D@Q002
48@26<H01a24248@Q1S67>LDY@@Q00<0000312400000008000848@@HaP0624848@0000048@Q20`@Q
00<8@P@Q24800PQ210@Q1@000P@Q20000PQ20P@Q00<<HaBU8@P00acW00@HaQcW48@8@P@000031248
@P@Q00h000031248@P000180000<1248@PQ2124<HaS67>LHaQcW8@PDY@aS300000<48@Q200004000
00<48@aS24801@0000@48@Q22488@P<000848@<00088@P0836<Q22DY8@P@Q0aS48@DY@<8@P035:DH
aQS6008Li`0=9BTYBRe[9BTQ22U:5:H@P`Q336<HaABU48D00Q2300L@Q1BU5:@<I12436@DY0025:D0
0a2436<<I0025:D03a2436<<H`aS248DYAS67>LHaPaS248<Ha235:HDY@0348@00aBU48@DY@025:D0
112548@@Q1240PaS00D8@Q245:DDYABV00<DY@8HaP087>LHaQcW9BPU:B486<L@P`8<H`0636@@Q0aS
48@@QAS511BU0A250ABU000011cW8@PQ21cW0QS600<LibDY8@P00QcW00LU:B48<HaF]F<HJeYJeP02
?Nl023W>@Q1243W>=JdaS48@BU82E[D03U:DJeYg_F<HBU9245:DIcUBU4icF]IW>F<HCW<2?Nl00bU:
9BTQ20029BT012489BT]Jbe[0RU:00DQ21cW8@PU:AS6008<H`0348@HaQS60088@P/000041248@PQ2
248212400`Q2000000020002124200001@@Q2488@PQ212401P000P@Q100000<48@0000000P000P@Q
0PQ20P@Q00D000@Q12448@Q200848@P000@8@PX000031240000001H000848@0424848@Q236<22484
0002124400000`Q21240000C000010@Q36<8@P@Q1@0010@Q00<000@Q00000`0000/48@00124<HaBU
<H`e[BU:7>L48@Q2008<H`055:D@Q1BU48@DY@026<H35:D02QcW7>HDY@aS48@DYQBT5:D@Q1250QS6
00h@Q@aS48@HaABV5:@<Ha246<HDYA245:@DYABT0Q2400<DYAS66<D00Q240PaS00<@QABU5:D00QS6
0Q240PaS00@DYA245:DHa@8@Q00536<@Q1BU5:DHaP055:D01@aS48@HaQcW6<H00QBU0QS600DLib48
9BPLj1S600<DY@055:@DYA256<DDYP035:D000048@PDYAS66<H47>L02R487>LDYB48?NmF]FLiE[E:
DTic0THa00=243g_>Lh00Sg_00`icT8@BU9JeVmkJeYNme:DBU9BU5[FE[D2DY@025[FIcUS65JeAS4]
JbU:8@P2:DX01BDY8@PU:BU:9BT00RU:0b4800HDYA245:DHaQBU48@336<00`Q21240000800021240
1@0012448@Q212400P0000<48@0000000P0000H48@aS36<<H`00248?000020@Q00048@Q236<8@P00
12422482124236<00`Q20000000200001`@Q0000000036<DY@aS01<000051240000000048@0>0000
10@Q2488@PQ20P@Q2P000`@Q4`0000<48ABU48@01`0000@48@002488@P848@L000048@Pe[Cg_:DX4
24800a2436<<H`0248@45:D27>L031S648@<H`aS6<HLiaS65:D<H`Q236<@Q08DY@8@Q0055:DDY0aT
36<@Q0025:D00a2548@DY@035:D021BV6<HHaQBU48@@P`aT5:@25:D26<H03ABU36<@Q1BU48@8@PQ3
5:DHaQBT48@DYB48008DY@8<H`055:@@QAS67>LHaP025:D03Q245:DDYABU7>LQ22DY7>LHaQS55:DH
aABV6<H25:D011256<DHaQS50ABU00004248:DX]JbDY6<HLibe[<H`U:AS67>LYBRe[=JdaS2U:0c6<
00LYBRDY:DXaS3F]<H`]J`02<H`06D8@BU96<EJeF]IBU4YB>Li245:DBU9JeVmkLiaW>E[FE[ENmgNm
LiaW>Ekg>LhaS2DY008YBPHU:@067>LDYA245:D@Q0aS0PQ200<48@000000300000D48@00000000@Q
00H0000324848@@Q008000848@h000848@@000031248@PQ200@000848@D00004124000Q236<21240
0`001240000300000`@Q0000000P00000`@Q24848@0500000`Q212448@0336<01@Q212448@Q21240
40000P@Q500000/48AcW8@PQ21S636<DYAS65:DHaQ24008DY@046<HLiacW6<H35:D27>L01aS648@D
YABU6<HDYABT008DY@8@Q00648<<I12448@DYA240QBU00<HaA255:D00aBU00H@Q0Q224<<Ha2348D2
5:D01A245:D<Ha2336@00aBU01T<H`aR48@@Q1S66<LDYA2436<DYAcW5:D@Q0aS5:DHa@aS48@HaAS6
48@<Ha256<HDY@0248@36<H02RU::D/aRbe/7>LHaQBT48@HaQBV0ABU00001RDY:DXU:AcW6<HU:@8Y
BP079BTLiacW:DXaS3W>=Jd01Be[00@U:BU:9BTYBP8aS005>LhmkdHaCW=:DP02DY@2BU80848@?NmB
U5kgKg]cW6LiF]IF]FLiKg]g_F]JDYAF]Be[8@PU:BU:;F/U:AcW8@PYBRDY6<H@Q0aS48@HaQ24248=
0002124600000`Q200000002000010Q2000000@Q2@000`@Q100000<48@0000000P0000<48@000000
0P000`@Q2P0000@8@PaS48@<H`848@X000848@L000051240000000048@0>0002124200000`aS2480
000200001PQ2000000@Q248<H`88@P0312400000008000031240000000h000848A4000041248@PQ2
6<H28@P01QBU36<@Q1S65:D@Q08DY@066<HLiaS65:DHaQcW0QBU00<<Ha245:D00QS61ABU00D@Q0aR
2488@`aR00<@Q08<H`0:5:DLiaS536<@Q1BU7>LDYA245:@336<01PQ236<DYABU6<HDY@8<H`<@Q009
248<HaBU7>LDY@aS48DHaQBT00<DY@035:HDY12500DDY@045:@@Q1BU36<25:D27>L02AS69BTYBRe[
;FXLiacX5:H@P`025:D16<H0008HaP0A7>LQ22487>LDYBDY;F/e[Be[9BTHaRDY>Li6<EJeCW<mk`02
>Lh06cg_AS5243W><H`e[C6<=JdicSF]>Li243F]:DX]JcW>BU8mkcF]>Li:DTicG_MW>FmkMkecW002
Ool01G>LJeY:DTHa?Nl00S6<0RU:0R480QcW0QS600<@Q0aS1240400000<48@0000000P000P@Q0`00
00D48@aS124000@Q00X0000312400000008000848@D000031240000000<48@`00088@P8000<48B<0
00<48@H000051248@PaS48@8@P04124E00000`@Q248000020002248400021245000212401`aS2488
@QcW;F/e[BU:00<DY@0348@HaQBU00<Li`086<HDYA2448@DYAS65:D@Q08DY@DHaP0348D@Q0aS008<
H`0348@<H`aS008@Q00?6<HDYABU48DDYAS55:D@Q0aS248<I12436<<HPaS008DY@035:HHaABU008D
Y@8@Q08<H`0448@DYAS65:@448@010aT5:@DYABU0Q2400<<I1245:D00QS60aBU00P<H`Q248@HaR48
6<HQ22U;0S6<00<U:1cW5:D00Q2400047>L48@P2:DX29BT01Be[?Nlmkcg_@Q000THa00<mkcW>>Lh0
0SW>0SF]00LaS2e[<H`aS3W>?NlicP02<H`00cF]>Li24003@Q001TicDYAJeVmkLiakgP9cW003NmiS
65Je00<icP04;F/U:B488@P26<H25:D26<H00a245:D0000300000`@Q0000000C000010@Q248<H`Q2
800000<48@0000001P000P@Q0`0000<48@0000002@0000<48@0000007`0000@8@Q245:D<H`<48@88
@Q<000848@0300048@0000T000031240000000<00003124@Q1BU00<<H`068@P]Jbe[8@P<Ha240acW
00@HaQBU6<HLi`<DY@097>LHaQ2436<@Q1BU48@<Ha24008HaP0>5:DDY1255:@DYA2548@DY12448D@
Q1BT5:HHaP8DY@0736@@Q12436@<H`Q236<00QBU0PaS00@@Q1S55:HDY@H@Q00836<@Q1BT48DHaA25
5:D<H`<@Q0055:D@Q0aS36<@Q0035:D01A245:DDYABU6<H00Q2400@DYAS6<H/aS08]J`046<HDYABU
5:D17>L0000B5:DHaQcW7>LHaQBU48@HaQcW9BTQ21cW6<HQ236<>Li6<Cg_0SF]00<YBRe[:DX012U:
00<U:BU::DX0136<0Re[00<aS2e[;F/00RU:00XaS2e[<H`aS3g_DYAF]F<HG_MBU09JeP03G_M>LdHa
00924096<@07>LhaS2e[9BTQ212424806P0000<48@00000040000P@Q3`0000<48@0000002P0000<4
8@000000100000<48@0000001P0000<48@Q200002P0000<48@000000400000<48@Q212400P0000D4
8@Q2000000@Q01l000031248@P0000D00004124@Q12436<25:D013F]CW<icRe[0PaS00<DYA2448@0
0QS600<LiaS67>L00acW00<DYAS65:D00`aS00<@Q1S66<H00QcW00<DYQBU36<00Q240QBU00<<Ha24
48@00QBU00<@Q0aS36<00PaS00<@Pa245:D011BU00H@Q1255:DDYAcW6<H25:D020Q2124<HaBU7>LD
Y@Q336<25:D236<01a2436<@Q0aS248@Q1BT008DY@0748@<I1BT5:D@Q1BU48@011BU0QS600@Lib49
9BPYBP4U:@0000<HaQBU6<H00aBU00@HaQcW8@PQ208U:@067>LQ236<@Q1:DT8@0Re[1BDY00DQ22U:
:DX]JcF]008aS08]J`03<H`]JbU:008aS08icP08=Jd]Jc6<?Nm:DUkgHaQJeP9F]@05G_MJeU:DAS52
4003AS401SW>=Jd]JbU:7>LHaP848A/000848@<000031240000000/000<48@d000031240000000X0
00031240000000848AL000031240000000T000031240000000D000041248@PQ21243000212440000
0`@Q0000000=000010@Q000000@Q200000<48@0000000P0000D48@Q2248<Ha24008DY@067>LU:CW>
?NlYBR480QBU00dLiaBU36<DYAcW8@PLiaBU48@HaR487>LDY@0236<35:D011S67>LHaaS50aBU0`aS
00H@Q12348@@QABT48@336<0612336<@Q1BU5:@<I1245:DHaQBU48@DY1S67>LHaPaS248<Ha245:D@
QA2448DHa@8HaP8DY@8<H`03248<Ha24008@Q00348DDYABU008DY@8@Q0@DY@096<HDYA246<HQ22U:
8@PLj1cW004Q200000TLiaS67>LHaQ246<HQ22U:7>L00QS600HLiaBU6<HQ22U:<H`2;F/00cF];F/Y
BP028@P2;F/3=Jd0336<=Jdmkd8@DYA>LdYBCW<icS6<8@PHaP8Q200;9BTQ22489BTaS3W>=JdicSg_
AS524002AS402EJeF]IF]E[FBU9F]E[F:DXDY@0R00000`@Q0000000500000`@Q0000000Q00021240
100012448@Q2200000<48@0000003`000P@Q1P0000<48@0000003`0000<48@000000400000<8@PaS
24801`0000<8@P0000000P@Q100000<48A245:D00Q2400<<HbDY:DX00SF]00HLi`aS36<@Q2486<H2
48@00aS67>LHaP046<H031BU48@HaQcW8@TQ1aBV9BPaS2e[8@P<H`<DY@0548@<Ha2448@DY@026<H0
11BU48@<Ha240QBU00hDYQcW6<HDYQS55:DHaR487>LDYA24248<HaBU0Q2400D<HaBU6<DHaQ24008<
H`036<HDYA24008<H`0D5:D<H`aT5:@DYAcW6<H@P`aT5:DQ21cW5:D@Q1256<DDYQBU6<HDYP8DY@4D
Y04HaP0000@Lia245:DHaP8Li`8HaP037>LQ21S6008HaP038@PYBRe[008icP8YBP8Q20<YBP04;F/a
S36<=Jd2>Lh2AS42BU8024HaBU8]JbDY8@PHaR489BT28@P012U:;F/aS48@0THa0Sg_00I6<EJeF]IF
]E:DBU82F]H014Ha;F/<H`aS1P0000<48@0000009`0000<48@0000003`0000<48@0000002P0000<4
8@0000006`0000<48@0000001P0000<48@0000001@0000<48@0000001`0000<48@Q212403`0000@4
8A245:D48@800004124000000002124200021243000010@Q36<8@Q240QBU00`@Q2U:@Q0icRU:248<
HaBU48@<Ha245:D36<H01A245:DLiacW6<H00Q240QS600<Lib488@P00RDY00@Q21cW5:DDY@<@Q007
36<@Q1BU7>LDYQ2336<00aBU0Q2400`HaAS66<D@Q0aT48@DYAS65:D@Q@aS48@35:D236<00a2448DH
a@026<H03Q24248<Ha245:D<H`Q25:@HaQBV6<HDYAS65:D56<H02QBU5:@<Ha245:D@Q1BT48@HaQcX
0B4800000b487>LLi`027>L00b48:DXQ20027>L02QS69BTU:BU:8@PLib48:DX]JbU:0QcW0RDY00@]
JbU::DXaS0<icP03@Q16<CW>008YBP03>Li2436<008Li`039BTLib48008Li`096<HDYAcW8@PU:AcW
8@PYBSg_0096<@06?NlicTYBDY@icRDY0P@Q800000<48@0000000P0000<48@000000:0001@@Q7000
00<48@0000002P0000<48@Q200006@000PQ200<48@000000200000<48@0000000`0001@<H`@Q0004
8@Q248@<Ha245:DLibDY8@PHaQBU6<HLiaS65:D<HaBU0a240QBU00<HaQS548D00Q240aS600@U:BU:
8@PLi`<DY@0348@DYABU00<HaP065:@@QAcV7>PQ21cW0aBU00@HaQS76<HHa@8DY@0448@DYA245:@2
48@00aBU48@DY@025:D248@00`aS48@<H`0336<01PaT5:@DYABU36<@P`8@Q0055:DHaQS67>HLi`02
6<H021BU6<HDYQBU48<@Q1BU48D25:D16<H000057>LHaQcW7>LHaP028@P012DY8@PLiacW0b480RDY
0RU:1B4800<U:BU:<H`013W>00=243W>=Jd00S6<00LmkdHa=JdYBQBU6<HQ20036<H011cW8@PLiacW
0b4800@e[D8@BU9:DP8mk`05@Q1>LdHa;F/Li`1600000`@Q0000000900000`@Q36<48@0800000`@Q
0000000O00000`Q236<48@0600000`@Q0000000200000`@Q0000000800000`@Q0000000312490000
10@Q24848@@Q10000P@Q00@000aS5:DDY@8<H`035:DQ21cW00@HaP047>L@Q12436<65:D01a255:DH
aAS648DDY1cW008YBP057>LLiR486<HDY@0248@03ABU48@@Q1BU7>LHaaS67>PU:1cW5:H@Q1BU008L
i`0;6<H@QA245:DHaQcW6<HDY@aT36<<HP045:D548@436<248@04ABU5:HDYA245:DHaQcX8@PLiaBV
5:@DYAcW6<HDY@aS48@00QS600@DYA245:DDY04HaP0000LYBR487>LLib489BTQ20027>L28@P01BDY
<H`icSW>=Jd00Re[00@e[Cg_=JdaS08U:@03<H`]Jc6<008]J`<icP03=JdaS36<00<YBP089BTQ22DY
8@PHaQBU6<HQ20@YBP8Q200;9BTQ22487>LU:CW>?Nm6<CW>9BTHaP0P00000`@Q0000000<00000`@Q
0000000I00000`@Q24848@0200001`Q236<48@001248@P@Q00L000848@P000031240000000P00003
1240000000P000031240000000/000031248@P0001`000031240000000@00003248<Ha24008<H`04
48@HaQS66<H27>L011BU48@@Q1240QS60QBU00L@Q0aS48@DYAS55:HDY@0248@236<011S78@P]K2e[
0QcW11BU0QcW00PHaQBU5:DLiQcW9BTQ1b480RDY00HQ21cW6<HHaQS56<H25:D03Q245:@@Q0aT5:DL
iaS65:D8@PaS48@DYAS65:D248@01Q2336<8@`aS368@Q@8HaP0348@@Pa25008Li`065:DHaQS66<HD
YA2411BU00<@Q1BU48@00A2400001RDY8@PQ22487>LQ208U:@8Q2004:DXe[CF]=Jd2<H`2>Lh00cg_
>Lh]J`03:DX0336<:DXYBRe[?Nm243g_>Lhe[Be[<H`]J`8YBP8Q20069BTYBQcW6<HDYAcW12U:00<Q
21cW8@P00RU:00TLibDYAS5JeTYB8@P48@aS2480700000@48@00000000<48@`000031240000000@0
00848A80008<H`0624800000124<H`Q23`0000<48@0000002@0000<48@0000003P0000<48@000000
5`0000<48@0000000P0000<48@0000004@0000<48@aS6<H00a2400DLib488@PLiaS6008DY@0448@D
YABU5:D26<H02A2436<<H`aS6<HDYAS55:DHaP0248@011S68@LYBR490R4800@HaQBT48DDY@<Li`03
8@LLiacW008Li`8Q208Li`0=7>PQ22476<H@QABT36@DY12548@@P`aS5:D00QS600<DYA2436<00Q24
0QBU00<@Q1BU5:D00a240aBU00L@Q1BU5:DHaAS66<DDYP046<H348@25:D00a245:DDY@015:H00004
7>LQ22488@P37>L38@P01BDY8@PQ22489BT00Re[00DYBRe[<H`]JbU:008HaP8Li`059BTYBRU::DXU
:@028@P02RDY:DXU:AcW9BT]JcF]<H`U:AcW0aS60R4800XLiaS65:DLiaS648@DYAS68@PLi`<DY@03
36<8@P0001@00004124000000002124B0002124J00000`@Q00000002000010@Q000000000PQ200D4
8@001248@P@Q00D000031248@P@Q00@000<48@h000848AL000031240000000X000031240000001@0
00051248@PQ236<@Q00236<01QBU7>LU:BDY8@PHaP8DY@0G6<HLiacW5:DHaQBU48@DYAS65:HDYA24
5:DHaQcW7>PLiaS68@PYBS6<;F/Li`035:D01aS636@<Ha245:DQ2B48008Li`8HaP048@PU:BDY9BT3
7>L01AS648DDYAcW6<H00QBU00<HaR486<H00QBU0aS60Q2400H8@PaS48@@QAS55:D248@25:D01AS6
5:HDYABU6<L00QS600<DYAS55:H01QBU00000acW8@PU:@038@P02RU:7>LLiacW8@PU:B487>LQ22DY
0SF]01X]JbDY7>LLib487>LQ22DY;F/YBRDY8@PYBQcW6<HQ22U:;F/U:B48:DX]JbU:8@PLib480QBU
00DHaR488@PLiaBU008HaP8DY@0748@DYB487>LDY@aS12406@000P@Q4P0000<48@Q200006`0000<4
8@0000000P0000@48@aS36<48@T00004248@Q0aS12450003124e0002124C000010@Q248DYA240PaS
0QBU0acW00<Q21cW6<H00QS60QcW0QS60QBU0Q2400<DYB476<H00QBU00XHaQcV6<HLiacV9BT]JbDY
8@TDY@8@Q0045:DHaQS65:D248@00aS68@PQ20026<H02R48:DXQ22DY8@PYBQcW5:H@Q1BT0QS60QcW
0aBU00@HaR487>LHaP8DY@<@Q004368<Ha2448D236<01QBU6<HHaQS65:DHa@@HaP035:HDYA2400<@
Q04DY@4@P`4@Q0000R480acW0b480acW00/U:AcW8@PU:BU:8@PLib489BTYBRDY008HaP077>LU:BU:
:DXQ21S67>L00R4800@U:B487>LLi`DQ20077>LYBSF]@Q0icRU:8@P00RU:00@U:AcW7>LHaP<DY@03
6<HDY@aS00/000031240000000<000031240000000L000848@/000848@D000045:De[CW>8@P=0000
0`@Q0000000?000212401@Q20000000012400PaS00H8@P0000048@00124300001`@Q000002e[F]Hm
k`@Q008000032480000001d00005248Libe[8@P48@0S000412402@Q2124000Q248@Q22DY8@PHaP03
5:D01QS67>LDYA2436<@Q08HaP8DY@<@Q00@6<HLiaS648DDYA249BT]JbU:8@PHaQcW8@PHaPaS2482
48@010Q236<DYAcW0QBU00<Lib487>L00QBU00@HaAcW8@PHaP<DY@8Q20079BT]Jb486<H@Q0aS48@0
1ABU112400@<Ha245:DHaP<DY@0;6<DDYABU36<@Q1BU5:@DYQS55:D<I00136<000<Q208Li`8Q200<
9BTQ21cW6<HLibU:;F/U:AcW6<HLibDY0R4800<Lib488@P00RU:00<Q21cW7>L00R4800DLiaS67>LU
:B48008HaP069BT]JbU:9BTQ22U:0SF]00HmkcF]9BTU:AcW6<H27>L00aS636<<H`025:D010Q20000
00@Q900000<48@0000000`0000@48@00000HaP8icP036<H0000001`000<48@<00004124@Q1BU36<3
0002248400001`@Q000<HbDY:DXLi`Q200T000031240000001<0000712400000248aS48@7>L06`00
0P@Q1`0000`48@Q212448@Q236<8@Q246<HU:B486<H35:D00aS65:D<H`0248@031BU48@@Q1S65:D<
Ha2436<DYAcW8@PLi`8HaP067>LU:BU:9BPQ21cW0QS600@@P`aS248@Q0<DY@0548@HaAS67>LQ2002
7>L021S65:DDYAS65:HLiaS68@L38@P011S67>LHaQ240aBU0aS600TDYQBU48@DY1S65:D<H`Q236<0
0QS60QBU00DHaQS536@@Pa24008DY@0448<@QABU368136<00004<H`]Jbe[9BT3:DX28@P021cW5:DH
aQcW8@PaS3F];F/2:DX032e[=Jd]Jb487>LQ22U:<H`]JbDY7>LU:@8Li`05;F/e[CF]<H`Q20027>L0
0b489BTHaP026<H02BU:;F/Q22DY8@PYBRe[8@PLi`025:D011S648@8@P@Q:@0000<8@P@Q00001000
0`@Q0`0000<48@0000001@0000<48@0000000P000P@Q3P000`@Q0`0000@<HacW7>L8@PH000031240
000000<000031240000000H000031240000001X00003248DYA2402/00004248@Q1S67>L28@P02QcW
5:DDYA245:DLib489BTQ21cW0R4800DLiaBU48@DYAS6008Li`096<HHaABV6<D@Q1BV8@LU:AcW008D
Y@0:7>PHa@Q248@HaQcW5:D8@aBU7>L46<H35:D01aS65:DHaQ2548@DYAS600<Q20057>LHaQBU6<LH
aP045:D021S648D@Q1BT5:DDYQBT48D25:D00acW6<LDY@0248@01AS68@PLiaS65:D00Q240ABU0000
136<;F/]JbU:0R4800XU:B487>LDYA247>LU:C6<=JdaS08YBP03<H`e[BDY008HaP049BTicSW>:DX3
7>L02B489BTLibe[>Lhe[Be[5:DHaP038@P27>L01248:DX]Jc6<0RU:00DQ22DY8@PLiaS6008DY@03
48@<H`0002D000031240000000X000031248@P@Q00D000031240000000D000031240000001400006
124000006<HaS2480`0000<8@P@Q00000`0000@48@00000000848@8000031240000000<000031240
000001P00004248@Q12436<N00021249000212401@aS48@HaR487>L00QS600DDYAS66<HDYAcW008Q
20047>LHaQcW7>L36<H011cW8@PLiaS60QBU00/HaQBV5:DDYAS68@PU:B487>HDY@aT00<@Q0065:@D
YAS55:DDYQS60QcW00<DYQBU5:D00Q240QBU00LHaABU5:HLiR488@TLi`036<H01acV6<HDYAS68@LH
aQ240088@P0848DHaQcV5:HDY1BV7>HHaP<DY@<HaP<DY@4HaP4@Q04@Q00000D]Jc6<=Jd]JbU:008Q
20@Li`068@PU:BU:8@PHaQcW0b4800DHaQBU5:DLibDY00<Q20<U:@8YBP05;F/aS2U::DXQ20026<H0
2R489BTLiaS67>LYBRe[:DXQ22DY0R480RU:00@U:B4848@8@Q`000031240000000P000848AP00003
1240000001X000<48@8000051240000000048@0700000`@Q00000008000212440003124200000`@Q
0000000400000`@Q00000006000224800`@Q0000000:00000`@Q5:D<H`0300000`@Q0000000B0000
20@Q00048@@Q48@Q22DY7>L236<00aBU8@PLi`035:D26<H01AcW6<H@Q0aS48@00QS600H@P`Q348@H
aQcV5:D248@030aS5:HU:Be[:DXLiaS67>LHaQBU36@@Q08DY@0A6<HHaABV5:D@Q1S67>LHaQBT48DH
aR475:H@Q1BU6<HDY00248@00aBU6<HDY@026<H25:D01Q245:@DYA2336@@Q08HaP035:HHaAS6008D
Y@0836<<HQBU7>LQ21S65:D<H`4@Q0000c6<00TYBR487>LYBRDY7>LHaQcW9BT00R4800DLib488@PQ
21cW008HaP037>LQ224800<Q20047>LU:BDY9BT2:DX0136<;F/YBRU:0acW00@HaR488@PQ208U:@8Q
200;;F/aS36<8@PLibDY8@PLi`aS24848@0R00000`@Q0000000600000`@Q00000008000212430000
0`@Q0000000900000`@Q0000000B0002248010@Q000000000P@Q1@000P@Q100000<48@0000008000
0P@Q2`0000L48@00000000aS5:D<H`020003124C00002`Q21248@QS68@PLiaBU48@HaQcW6<H00QBU
0Q2400<DYAS66<H00QBU00<HaQcW5:H00PQ200D@Q1BU48@<Ha24008HaP8Li`0@8@PYBRDZ8@LHaQBU
6<HDYQBU48<@Q1S65:DHaQBU6<D248@35:D01@aS5:DLiacW6<H00QBU00@HaQBV5:D@Q08DY@8HaP<L
i`<HaP045:DDY1245:D26<H01QBV5:D<H`Q348<@Q@DHaP4DY@4@Q00000TU:BU::DXU:B489BTYBRe[
:DX00Re[00@aS2e[;F/YBP8U:@0:7>LU:BU::DXQ21S67>LU:AcW8@P49BT01B489BTU:B489BT00RU:
0bDY00@YBR488@PHaP8Li`0:6<HU:BU::DXU:B48:DXU:AS6248S00001@@Q0000000012400PQ21`@Q
0P0000<48@001240100000<48@Q212406P0000<48@00000010000PQ200<48@0000000`@Q0`000`@Q
200000<48@0000003`000P@Q1P0000<48@Q200000P0000D48@Q22488@P@Q0088@Pd0000448@DYAS6
48@G00001`Q21248@QS68@PYBQcW00<<H`8@Q0<DY@8HaP095:DHaQS65:D@Q1BT5:HHa@aS008DY@8L
i`0=6<H<I12336<Lib487>P]Jc6<>Lde[B497>L00QBU00XHaA2448DHaAS65:D@Q0aS5:DHaP8DY@8H
aP8DY@035:@HaQS6008HaP035:DHaQS6008HaP8DY@035:HDYAS6008HaP075:D@QABT5:HHaA245:D0
0acW00@DYQBT48D@Q04DY@000Re[0R480RDY0b4800DYBRe[=JdaS2e[00DU:@038@PLiaS6008Li`07
9BTYBRDY:DX]JbDY8@P00QS600TU:Be[;F/U:B489BTaS2e[:DX00R4800lLib488@PLib489BT]JbU:
8@PYBQS636<48@0012404@0000D48@00000000@Q00D0000312400000008000031240000000@00005
1248@PQ224848@03000010@Q000000@Q0`0000<48@Q236<07P0000<48@0000000P0000H<H`Q22484
8@00124400000`@Q00000002124300000`@Q36<48@0@0002124900000aBU48@48@0200000`aS1244
8@0312400`001240000900001P@Q48@Q21cW48@48AL0000436<@Q1BU7>L26<H02ABU36<<HaBU48@D
YA245:DHaP027>L01QS65:DDYA245:@@Q@8<H`0:48@HaR487>LHaQBU48@HaQBU7>H28@P2;F/012e/
<H/Q22480QS600XDYQ2448@@Q1S65:D<Ha255:@DYP<DY@0:6<DDYABU5:HHaQcW6<HDYQBT5:H37>L0
1aBV6<HLiQS55:HHaQcW008DY@0348@HaAS700@HaP057>HHaQ2548<<H`0148@000047>LQ22489BT2
:DX00bDY7>LQ20048@P00bU:<H`e[@02=Jd02bU:8@PQ22U:8@PLiaS67>LQ22DY8@P00QcW00DHaQcW
7>LLib48008U:@8Li`8Q20067>LHaQS67>LQ21cW0QS60b4800@HaPQ22488@Ql000848@<000848@03
248<Ha24008<H`05248<H`Q224848@03000312430004124N00001@@Q2488@PaS24800Q2400DDY@aS
248<H`Q200@000848@@000031240000001T0000412400000000224800`aS48@@Q0025:D01@aS2488
@PaS24802P0000@<HaS6<H`YBP8<HaH00005124@Q1BU36<DY@027>L01QBU248<HaBU48@HaP8DY@8H
aP8DY@8@Q0086<HQ22485:@DYR48;F/Q208DY@097>LHaQBV5:D@Q1BU6<HYBBU;008]J`039BPLiacW
008HaP035:HDYABU00<HaP0H6<DDYQS55:D@QA245:DHaAS65:DHaQBU48DHaABV6<H@Q1BU6<HLiaBV
48@DY1S60aBU00LDYR488@PU:BU:7>PHaP0248@35:D000058@PU:B488@PU:@028@P01QcW8@PYBQcW
9BTYBP8e[@@]J`03:DXU:B48008Q208Li`038@PLib48008U:@038@PLiaS6008Li`<Q200=7>LHaR48
8@PU:AS648@DYAS6:DXU:B487>L00PaS00<8@P000000900000<48@Q2248010aS0Q2400@8@P@Q0000
0088@P031240000000D000031240000001/000848@0300048@Q2008<H`8@Q088@P04124000@Q0003
12440002124E00000`@Q000000060003124010aS48@@Q1240PQ20`aS00<48@000000200000H48AS6
8@PQ21S6124F00001@@Q248@Q1BU48@00QS600@DY@aS36<<H`<DY@<HaP035:D<H`aS008<H`036<HL
iacW008HaP078@LLiaBU5:@@QAS65:D00Q2400LHaRDY7>LYBS6;;F/U:P057>L01ABT5:D@Q0aT6<D0
0aS600DDYABV7>HDYQS6008DY@8HaP045:@<H`aS5:@37>L00aS65:DDY@036<H02A2336<DYAcW;FXY
BQcW6<HDY@026<H25:D136<148@00005:DXQ22488@PLi`039BT28@P00bDY;F/]J`03:DX022e[<H`]
JbU:8@P]JbU:8@P26<H00b487>LQ20027>L00bDY8@PQ20027>L00b487>LHaP025:D58@P011cW6<HQ
22DY0RU:00@Q21S636<48B8000848@0>24848@009BTmkdic?NlDYAS67>LHaQBU48@<H`8@Q0042484
8@000002124400000`@Q000000030002124E000040@Q5:D48@00AS5kgWooCW<8@QBU8@PDYA245:D@
Q0@Q0P0000<8@P@Q00000P0000@48@0000048AX000848@035:D8@SW>00=oo`09=JdDYB487>LHaQ24
36<48@Q200L00088@P04:DXaS1S6124200000`@Q0000000D00001PQ25:DDYAS65:D@Q08HaP8DY@05
6<HLiaBU36<@Q0035:D248@031S67>LQ22486<HDYA255:DLiQS65:D@Q0@HaP0@7>LLj1cW8@PLibU:
<H/YBQcW48D@Q1S56<HDYAS67>L28@P011cW6<HHaABV0QcW00/Q21BU48<DYQcW9BTLiaBU6<HLiaS6
008DY@056<H@Q12448@DY@057>L36<H17>L15:D148@000038@PU:BDY008U:@8Q20<U:@04:DXU:BU:
<H`2:DX3;F/012U:9BTU:BDY0R480acW1B481AcW00DHaQcW6<HLib48008Li`8HaP037>LU:B48008Q
208@Q003124000000200000<124<H`@Q00048@00>LiJeU:D>Lh8@PaS0R4800@LiaBU36<48@<8@PL0
00848@h000031240000000X0000@124000Q25:DLie[FLiaJeSW>48@Lib4848@<H`Q236<22483124H
00000`@Q00048@05000224803`@Q7>LYBV<HOomkgUJe;F/@Q2487>L@Q0Q236<48@0800001ABU7>LY
BQcW24806@0000<48@aS6<H00aS60Q240QBU00@HaQBU48@<H`8@Q00?5:DHaQBU5:D@QAcW8@PU:B48
6<H@Q1BT5:HLiaBU008@Q0045:DQ21cW8@P27>L28@P02RDY8@PU:B486<HDY1245:DHaQBV0QS600dL
iQcW5:DDYAS65:@DYAS67>LLj1S66<DHa`047>L26<H021BU5:HHaQBU48@DYAcV7>P47>L01AS66<DD
YQS65:D00AS600002cW>AS56<CW><H`]Jc6<=JdaS2U:8@P00RU:0Re[00PYBSF]>Li243g_<H`]JbDY
0RU:00DQ21cW9BTYBRDY00<Li`038@PU:BU:00<YBP099BTQ22U::DX]Jb487>LHaQcW008Q20047>LU
:ABU36<T00000`@Q248<H`0200003Re[DYAoogooMkeW>E:DBU9BU3W>9BTHaR4836<200000`@Q36<0
0002000011245:D<H`@Q6@0000@8@QcW7>LHaP88@P05DYAoogooOomF]@02IcT045Je?NlicRU:6<H@
Q0@Q0008@QS6124000@Q;F]242485@0000/48@000008@RDY<H`Q20@Q000aS6Li00=oo`9cW004Kg][
FSg_;F/212401@Q212448@Q212400P0000H48A24:DXQ20aS124J000248@36<H011cW5:DHaQBU0QS6
0QBU00L@Q1BU5:DDYAS65:DHaP028@P04QcW5:D<Ha256<DHaaS65:@@Q1BU6<HDY1256<DDYAS648@D
Y@8HaP097>LQ22486<H<Ha246<DLj1cW00<DY@8@Q0035:DHaQcW00<Li`<DY@0<6<DHaacV6<HLiQS7
5:@<Ha245:DLiaS70QcW00PHaQcW7>HLiaBV5:DDY1240AS6000013W>?Nlmkc6<0Re[0SF]00<]JbDY
9BT00Re[0S6<00D]JcF]>LhicS6<00<YBP8U:@05:DX]JbU::DXU:@048@P022DY8@PQ22U:;F/aS2U:
8@P29BT01QcW6<HDYAcW9BTQ208HaP0336<48@0002800004248<H`@Q1242000035JeOomoogooAS5:
DU[FE[E6<C6<:DX@Q0<<H`88@P800004124DYAcW48@=00000`@Q0000000:000020@Q6<H]Jb485:D8
@QBUKg/3Ool03DicG_MF]Dic=Jd]Jb4848@<H`@Q24848@Q2008000045:DaS3F]48@H00001aBU=Jde
[AcW248DYE:D00=oo`05NmicW7NmG_M6<@02:DX01A24000000002480100000@DYAcW9BTDYAX00009
1248@QS67>LHaQBU48@DYAS600<DY@0548@DYAS65:D<H`0248@01AcW8@LLj2487>L00aS600HLiaBU
5:@@Q12548@236<04A257>HHaaS65:D@Q0aS5:DLib498@PHaQ255:DHaQcW6<H00Q240aBU00<DYQBU
6<H011cW0aS600/DYAS66<HLiaBV5:D@QAcV6<HHaAS6008Li`<HaP066<LDYABT48@HaQBV0AS60000
1CF]<H`]Jbe[<H`00Sg_0SF]0be[0RDY0R4800PaS3W>=JdYBR48:DX]JbU:124800<U:B488@P00QcW
0RU:0RDY0QcW0R4800@U:AS66<HDY@8Li`055:DLiacW7>LHaP02124V00001@aS248002U:BU802Goo
00A:DSW>5:DDY@<8@P060008@Q246<HDY@Q26@0000T48AS69BTLi`aS124DYD8@F]H027oo00AcW3W>
8@P48@<8@P800004248DYAcW48@H000020aS8@PYBQBU124<HdYBHaP9Ool00c6<9BT8@P0U00001`@Q
48@8@R489BTYBR48008DY@0A6<HDYABU36<DYA245:D@Q1BU6<HLiaS548@<Ha245:HDY00248@02a25
5:D@Q1BU6<HDYA2436<DY1BU48@00PaS00H@Q0aS36<HaRDX8@P26<H02B489BPLi`aT36<DYA245:@@
Q@025:D00aS55:DDYP026<H25:D01@aS5:DDYQBU5:@00aBU00D@QA2448@Q1b48008U:@<DY@0348DH
aQBU004@Q00000P]JbU:<H`e[CW>=Jd]Jc6<0SF]00HaS2487>LQ22DY;F/2=Jd2;F/2:DX012e[9BTQ
21cW0R4800@YBRDY8@PLi`8Q208U:@DQ20037>LHaQcW008Li`068@PLib489BTDYA247P0000<48@00
00001@000P@Q00D8@PaS36=>Lf]J00Qoo`04IcTaS2U:36<224801`aS248000009BTicR4800<00003
1240000001@00009248YBSW>9BTDY@aS;F][FW>L00Moo`08Mke:DQS648@8@PaS24848@800004248@
Q0aS248H00001a248@PLi`aS5:DLif<H00Qoo`05NmiF]ABU36<8@P0300000`@Q0000000O00000`@Q
36<@Q0027>L28@P011BU48@<H`aS11BU00L@Q1S65:DLj1cW6<HDY@0236<02Q245:DDYA2436<@Q1BU
6<HDYA240QBU0Q2400TDYABT48@@QA245:DHaR489BT00acW1QBU00@@Q0Q236<DY@8Li`0348<8@PaS
00<HaP085:D@Q12448D@P`aS36@DY@<Li`046<HDYABU6<D35:D16<H15:@15:D000039BTYBRDY00<U
:@HYBP8U:@048@PU:BU:9BT2<H`2:DX00acW8@PU:@027>L2:DX01R487>LQ22U:<H`]J`8U:@<Q208L
i`0:6<HLibDY8@PU:AcW8@PU:ABU248V00001`@Q24848@aS48@e[Cg_00]oo`056<H<H`0000048@0Q
00001`@Q248@Q0aS5:E246<H00Yoo`03F]H<H`00028000061248@QS648@icVLi2Woo00=kgPaS0000
9`0000@U:Cg_DY@mk`8<H`0348@<H`aS008<H`095:DHaQBU36<DYAS67>LHaQBU008HaP<<H`<DY@04
24848@aS36<26<H01aBU36<8@`aS5:DDYQS5008DY@8Li`058@PLj248:DTU:@028@P26<H25:D011S6
8@PHaQBU0PaS00<DYAS65:D00aBU11S600<HaABV6<H00aS600<LiaS76<H00QS60AcW0AS70ABU0002
8@P01RU:9BTQ2248:DX]J`8YBP8U:@037>LQ236<008e[@06:DXQ22DY<H`]JbDY0QcW00/Q22U:9BTU
:B487>LU:BU:;F/U:B48008YBP<Li`0;8@PLiacW8@P]Jb485:DHaR486<H@Q00V000212401@Q248@D
YE:DHaP02Woo00=F]@0000000P0000<48@0000007P0000L48@aS124DYAS6;F]_N`0:Ool00f<H8@P0
000R00001P@Q000001S68@Q[FP]oo`03?Nl0000002@0000:12400000;F]>LdYB<H`48@aS5:D22480
6@aS5:DDY@aS5:DHaQcW5:D@Q0aS5:DHaQBU36<8@PaS6<HDYA24248<Ha245:DHaQBU008<H`06368<
Ha2448@@QAS60QcW00<HaQcW7>L00RDY00<Q21cW6<H00QBU00DHaQcV6<LDYA24008<H`045:DHaQS6
6<H35:D26<H35:D011S67>LQ22DY0R4800<LiQS67>L00QcW0AS50ABU000012U:;F/Q22DY0RU:00<U
:AcW7>L00b4800XLibDY:DXaS3F]<H`icTYB=JdYBP8HaP@YBP049BTLiaS67>L28@P27>L00aS68@PU
:@038@P37>L00b48:DXQ2002<H`00acW5:D0000U00001`@Q00048@Q236<aS3W>00]oo`05BU8YBP00
00048@0R00001P@Q36<8@QBU<Ha>L`Yoo`03DY@<H`Q202<00005124DY@Q2:DY>L`09Ool017>LF]H@
Q0@Q9@0000H48@aS7>LLibDY8@P26<H0112436<@Q0aS0QS600HDYB488@PLiaS636<248@011BU5:@@
QA240PaS00H8@PaS48@DYAcW8@P25:D01`aS48@DYQ245:@@Q1BT008@Q0045:DHaQBU6<H35:D02AS6
9BTYBRDY7>LDYQBU6<HDY@0336<55:D011S67>LLiaS60QBU00<HaAS67>L00QS60aBU00@HaR479BTL
j04DY@0000<YBRe[9BT00QcW00dQ22DY:DXYBRDY7>LQ21S68@PaS3W>@Q0icP02<H`01Be[:DXQ21cW
8@P00RU:0RDY00LHaQBU7>LQ22U:8@PHaP048@P011S67>LLibDY0R4800HYBRe[:DXQ20Q2124W0000
1PQ26<HDY@Q2<Ha>L`Yoo`03Li`DYABU02@000848@8@Q0036<I>Lfmk00Uoo`05G_L]J`Q224848@0Q
00001P@Q000<HaBUCW=cW0Uoo`03?NlYBP0002D00007124<H`aS6<HLib487>L00QBU0Q2400XDYAS6
7>LQ22DY7>LHaQBU6<H@Q08<H`0<248@Q1BT5:H@Q123248<HaBU6<HLiaS60aBU00@DY1245:DDYPDD
Y@0<36<DYAS67>LDYQS57>LQ21cW6<HDYAS50QS600T@Q0aS36<DYAS65:D<H`aT6<D00QS60QBU00@D
YQS66<HDY@8HaP<DY@056<HLj1cW6<HDY0015:D000068@PYBRU:;F/YBRDY0R480RDY01D]JbU:7>LH
aR48;F/YBRDY8@P]Jcg_>Li6<E:DAS4mkc6<;F/aS2e[:DX00RDY0R4800<LiaS67>L00RDY00HQ21cW
7>LU:B489BT2;F/0136<:DX<H`Q2:0000`Q200@DYAS6CW=S60Moo`05Kg]BU1S648@48@0H00021249
0002124224801@aS5:DU:EJeIcT01Woo00IS63F]7>L48@aS124O0004124224801AcW9BU245kgNmh0
17oo00Ug_F<H9BTHaPQ200048@0012408P0000H8@QBU9BTQ21cW8@P26<H25:D021S648@DYAcW8@PL
iaBU48@26<H248@04QBU6<LHaQ245:DHaQBU48@DYAS67>LHaPaS368<Ha256<LHa@8@Q0@DY@8HaP8@
Q0035:@DYQBU00<HaP067>LU:BU:9BTLiaBU0Q2400DDYA245:DHaABV008DY@0748@DYAS56<HDYQ23
48D00QS600D@Q1BU7>LU:1cW00<DY@0000DHaRU::DXaS2e[00@Q20059BTQ22488@PU:@02:DX01Be[
:DXe[CF]?Nl00T8@00E:DT8@>Lh]JbDY00<YBP059BTQ21cW7>LU:@02:DX012487>LQ22U:12480SF]
00<Q21BU0000600000<48@000000300000<48@Q224800PQ200<Q22U:IcT027oo00I6<Be[248<H`Q2
124S00001`@Q2488@QBU:DXaS7>L00Ioo`06Nmi:DQS648@000@Q0PQ280000P@Q00H<H`Q28@PaS5Je
Nmh5Ool01ekgBU8@Q0aS124000@Q02<00006124DYABU7>LQ21S60Q2400LDYAcW5:D@Q1S67>LHaP03
5:D01Q245:D<H`aS48@DY08HaP037>LHaQBV00<DY@046<HDYABT48D35:D00a2324<@Q0055:D01124
5:DDYABU0a2400@HaQcW8@TU:0<Q20035:D@Q0aS008DY@8<H`035:DLiacW008DY@0<48@DYAcW6<HD
YA245:DHaQBU6<HDYQcW0b480AcW00001bDY:DX]JcF];F/aS3W>008e[@0=<H`]Jbe[8@PU:C6<?Nle
[Be[7>LQ236<=Jd00T8@00@icT8@@Q0icP8e[@03>Lh]Jbe[008YBP0:;F/YBRU:7>LQ22e[=JdicSF]
<H`3:DX011cW6<H48@@Q9`0001<48@001248@PaS48@Q22U:@Q16<DicHaQJeU:D?NlQ21S636<48@03
248P000020Q248@@Q0aS124<Ha245:D29BT01cW>?Nm6<E:D>LhYBQS6008DY@031240000000T00003
1240000001<0000448@HaQBU248200001QBU6<HU:Be[<H`e[@<aS0058@PLi`aS36<48@0V000032DY
BU9JeSW>5:DU:B487>LDY@aS5:DHaP8Q20<DY@8HaP085:D<H`aS48DDYA2436<DY08HaP035:DHaABU
00<DY@0848D@Q1BT36@<HPaS248<H`8DY@8HaP8<H`0:48@DYAcW6<HDYA246<DLib498@P57>L01AS6
5:DHaQBU6<H00QcW00<DYAS66<H011S600PDYAS67>LLib485:DHaQBU0Q2400000bDY;F/]J`03=Jd3
<H`02be[9BTU:BDY;F/icSg_<H`YBR48:DX00cW>0cg_00dicSF]=Jd]JbDY;F/aS2e[:DXQ22DY:DX]
J`03<H`00bU:;F/]J`02<H`00bU:5:D<H`0X000212400`0012448@025:D00be[<Ha6<@02F]H026<H
DY@mkc6<7>LHaPaS2482124Q00002a247>L@Q0@Q0008@QS68@PaS2e[?Nl00dHa00<aS2DY6<H00PaS
00<48@0000007`0000P<HaBU36<8@P@Q248Q22U:0S6<00/]Jc6<=JdicRe[7>LDY@Q21248@P@Q02<0
000<248Q23g_<H`YBRe[9BTQ21S65:D@Q1BU0aS60Q240QBU00HHaQBU36<<I12336<25:D26<H011S5
36@@Q1250QS600<@Q0aS36<00aBU00P<I0Q248@LiaS65:D<Ha240aS600DDYA2448@DYAS6008Li`03
8@PHaQBU008Li`048@PHaQBU6<H45:D011cW8@PQ21cW0aS600@Lib477>LHa`8DY@046<H@Q1BU5:D1
6<H00006:DXaS2e[<H`icSg_0cW>1DHa00Lmkd8@?Nlmkd8@?Nm6<@02CW<01d8@=JdmkdHa=JdYBR48
008YBP069BTYBRe[;F/Q22U:0Re[0RDY00@Q22U:8@PLi`<YBP038@P48@0002P0000548@<H`@Q0008
@P025:D02aS67>LU:B487>LDYAS636<8@P@Q2480700000<48@0000001@0000d48AS6:DXLi`@Q0008
@Q2436<HaQcW8@PHaP0236<01124248000000P@Q800000L8@QBU6<H48@00124<H`026<H236<01a24
5:DDY@aS124000@Q02L0000:7>L]JcF]7>LYBT8@?NlYBPaS48@36<H00aBU6<H@Q00236<00a245:DD
Y0055:D00aBV5:DDY@0348@26<H00aBV5:DDY0026<H00aBT5:DDY@036<H25:D01`aS5:D@Q1BU6<HL
iaS6008<H`055:DQ22DY7>LDY@036<H012DY:DXYBR490QS600@Q21cW7>LDY@8HaP097>LQ22496<HD
YAS57>LQ21cW008DY@4HaP0000PU:CF]?NlicSF];F/e[D8@0THa01A:DT8@>Lhe[Cg_@Q0mkcW>?Nm6
<DicBU9244YB@Q0icSF]<H`e[BU:0R4800<U:Be[:DX00R4800HU:Be[<H`YBQcW8@P29BT01AcW8@PU
:ABU36<0:@000`aS00<8@P0012400PaS00TLibU:9BTLiaS648@DY@aS24809@0000`<HacW8@P@Q0@Q
24848@Q248@DYBDY8@P26<H00a2436<8@P03124Q000010aS5:DLia240P@Q00P@Q1BU6<HDY@aS248<
Ha240`aS9`0000D8@QcW;F/Libe[008mk`03<H`DYABU008DY@037>LHaQ24008<H`0548@<HaS65:DH
aP065:D01QS67>LDY@aS48<DY@8HaP8@Q00336@@Q1BU008DY@8HaP8DY@0548@<HaBU5:DLi`026<H2
5:D021246<HLj2DX6<HDYA245:D4:DX01B478@PU:2487>L00QBU00<HaR488@P00QS60QcW00<HaQ24
6<H00QcW0AS60ABU0A25000012DY;F/e[C6<0bDY00P]JbDY8@PYBSF]<H`mkdic0UJe00M:DTHaAS5B
U5JeBU96<@02=Jd01CW>;F/YBRU:;F/00SF]00D]JbU::DX]Jcg_00=2400:=JdicSF]9BTLibDY:DXa
S2U:124Z000010Q236<<H`@Q0P0000D8@P@Q36<<H`Q200<48@0300048@@Q00<000848@<000031240
000000X000031240000000`000081248@PaS36<8@P@Q00048@<8@P0300048@@Q00848BH0000436<D
YA2436<200001`@Q00048@@Q00048@Q202/0000=1248@RU:;F]6<EJe=JdQ21247>L]JbDY6<H00Q24
0`aS00d@Q0aS36<@Q1S67>LHaQ2448<@QABT5:DDYP055:D00a245:DDY@025:D00a245:DDY@035:D3
7>L011S65:DLib481AS600<DYAS66<H00QBU00/HaQcW:DXYBRDZ:DXU:1cW6<HDYAS600LLi`<HaP4L
i`4DY@4@P`0000<YBS6<;F/00RU:00dQ22DY9BTU:Be[:DXaS4HaDYA>LdYB@Q16<@03DY@024YB?Nm2
43W><H`]JbDY;F/2<H`02SW>=JdYBRDY:DX]JdHaBU9243g_0S6<00Le[BDY7>LU:Be[9BTHaP0Y0000
10@Q0008@PQ20P@Q00<000@Q24800PQ20PaS00<48@0000000P@Q9@0000D48@Q236<<H`Q200D48@04
248<H`Q2124X000011245:D<H`Q20P0000<48@0000000`@Q;00000P8@QBUAS5:DTHa?NlHaQcW0R48
00@LiaS65:D<H`<@Q08<H`0448@DYAcW6<H25:D00a2548@DY@045:D248@01aS66<DHaQBU48DDYAS6
008DY@0348@DYAcW008Li`0:6<HLib489BTQ21S77>HHaQBU5:H26<H248@25:D02RU99BXYBRU:8@PL
j1cW6<LQ1acW0R4800<Lib488@L00QcW00@HaQBU6<HHaP<DY@0000<LibDY:DX00cF]00@]JbU:;F/Y
BP8Q200>9BTe[CF];F/aS3W><H`U:BU:@Q0mkc6<6<HLi`<]J`0;<H`]JcW>?Nle[Be[7>LQ22e[<H`e
[@03:DX00cF]@Q0icP02BU800be[9BT0000/000312400`001240000c000212400`Q21248@P0_0002
2482124`00002@Q248@e[CF]>LhmkcF];F/YBP027>L01ABU48@DYAS648@00PaS00<@Q1S66<H00QS6
00XQ21S65:D@Q12348DHaR475:D@Q0<DY@0448DDY1BU5:D26<H25:D011BT6<LU:AcW0QS600DQ22DY
7>LDYA24008HaP035:DHaAS6008HaP8DY@0848DHaABU5:DLib48:DXYB@8Q20037>PU:BDY008Li`03
5:HLiaS6008DY@036<HLiaBU004DY@0000dLibe[?Nm243W>;F/icS6<:DXU:B48:DX]J`03<H`2;F/2
<H`01SW>?Nl]Jb487>LYBP8e[@07<H`]Jc6<=JdicRe[:DX00RDY0S6<00Le[C6<=Jde[Cg_AS524002
BU800acW36<0000/000010Q236<<H`aS100000<48@0000004P0000<48@0000004P0000P48@000000
00@Q248<H`Q20`@Q;P0000@48@Q236<8@P<48@<000031240000002T000076<HU:DYBBU8e[C6<7>L0
0R4800<LiaBU48@00aBU00<HaQBU6<H00QS600<DYAS65:D01ABU00LHaQBU36@@Q1BU6<DDYP025:D0
11245:DHaAS60QBU00D@Q1BV8@LLib4800@Li`0@8@PLiaS648D@PaBU5:HDYAcW6<HDYA2348@DYQcW
7>H26<H011cW8@PU:B470QcW00HQ22DY7>LHaQcW5:D248@00aBU8@PLi`016<H00005<H`e[CW>>Lhe
[@03<H`5=Jd0136<=JdicSF]0c6<0Sg_00XicSF];F/aS3F]>Lhe[C6<;F/aS08icP03=JdU:BDY008Y
BP04;F/YBRU::DX2;F/01RDY>LhicS6<9BT48C8000031240000003<000<48F@00008:DXe[DYB@Q0Y
BRe[9BTQ20<Li`036<HDYAS600@HaP8Li`038@PLiacW008HaP087>LDYA245:DHaQS55:D@Q0<DY@03
48@@QAS6008DY@0348DDY1BV00<DY@8@Q00=5:DHaQcW5:HDY12448D@Q12336@@Pa2436@01ABU00DL
ibDY8@TLib48008YBP079BXQ22DX7>LQ21S66<D00QBU0ABV0AS60AS600001Be[<H`icT8@=Jd00RU:
00daS3W>?Nle[C6<;F/e[CW>?NlicS6<;F/aS002=Jd2<H`4=Jd01cg_=Jd]JcF]?NlicS6<008Q2003
9BTYBS6<00<]J`07=Jd]JbDY=Je6<Be[6<H0<P000P@Q<`0000<8@P@Q0000I00000/48A24>LhicT8@
AS4]JbU:7>LHaQcW00<HaP8Li`045:DLib487>L36<H27>L00b486<HHaP035:D03A245:HHaQS648@@
Pa256<DDYA255:DHaQS5008DY@0348@DYABU008HaP8DY@0648@@Pa2448DHaABU0Q2400@@QA2448<@
Q08HaP055:DHaQcW:DXU:@028@P00bDY:DXQ20028@P01acW6<HDYA255:DLiQcW008DY@0000<icS6<
<H`00S6<01H]Jb48:DXe[Cg_>Lh]Jb48:DXe[Cg_AS4icSg_AS4e[C6<;F/aS3F]<H`icP8e[@8Q2007
:DXe[DYB@Q0icSF]<H`01Re[0R4800He[CW>AS4mka2436?<00003PQ28@PicRDY6<HYBRe[8@PHaQBU
6<HDYAS65:D36<H25:D56<H00a245:DHaP028@P01aS636<<HaBU6<HLiQBV008<H`065:D@Q1BU48<<
Ha250QBU00PDY1245:DDY@aS48@DYAS60PaS00@@Q1S67>LLi`8HaP065:D@Q12436<HaQcW0RDY00PQ
22U:;FXHaQBU36<DY3F]0Sg_00<e[AS76<D00QS60AcW0AS60A2500001bDY:DXicSF];F/Q22U:00<i
cP0;<H`YBRe[=JdmkcW>@Q0mkcW>=JdaS002;F/0136<>LhicRe[0RU:0R4800@icTHaE[E:DP8e[@03
<H`]Jc6<008]J`088@PYBQcW7>M245:D>LhLic<000051240000000048@2F000011BU9BTicS6<0acW
0R4800DHaQ245:DLiaS6008DY@036<HQ21S600DDY@036<HLiacW008HaP075:D@Q0Q248@HaQBV5:@0
0PaS00@@Q1BU5:DHaP8DY@0=6<HDY@Q336@DY1S76<HDY1255:@@QABU6<D00QS600@DYAS68@LDY@8@
Q0046<HU:AcW8@P2:DX042497>LDYAS67>LQ236<=JdaS2e[6<HDYAS65:DLiaS60AS5000022DY8@PY
BRe[:DXQ21cW8@P2:DX032DY8@PU:Be[:DXU:Be[=JdicSF]:DX]J`8aS003=Jd]Jbe[008]J`0::DXQ
22e[<H`icS6<=Jdmkd8@?Nl3<H`02RU:;F/]Jbe[?NlicS6<;F/@Q0Q2HP0000<48@000000I`0000<D
YAS69BT00QcW00<Q21cW7>L011BU11S60QBU0aS600<@Q1BU6<H00QBU00<HaQcW48@00PaS0QBU00<<
H`aR36@00aBU00HHaQS548@<Ha246<H27>L01QBT48@<HPQ348@@P`<DY@076<HLib498@LHaacW6<H0
0aBU00<Lib48:DX00RDY00HQ22DY8@PHaa2436<25:D01S6<?NlmkcF]7>LDY@8HaP4Li`0000LHaRDY
:DX]JbDY7>LQ2002:DX01BDY7>LQ2248;F/00RU:00@]JcF]=JdaS0<]J`03<H`YBRU:008YBP05;F/Y
BRU:;F/e[@02<H`023F]>LhmkcW><H`]Jc6<;F/3=Jd2?Nl00bDY7>L0003;00001@@Q5:DLiaS65:D0
0QS600<DYAS66<H00QcW00@DYA245:DHaP8Li`045:DHaQcW5:D248@00aBU6<HHaP036<H25:D00a24
5:D<H`0336<25:D0112436<<I1240QBU00X@Q1BU5:DDYQS636<8@@Q35:DLi`8DY@0=6<HU:BDX6<LQ
1b496<HDYA246<LYBR489BP00RU:00`Q21BU5:DLiaBU36<DYB48>Lhe[Be[:DX27>L16<L15:D15:D0
008DY@0C7>L]Jbe[:DXU:AcW8@PYBRe[:DXHaQBU6<HQ22DY6<HLibDY;F/00RU:00hQ22U:9BTYBRe[
:DXU:B48:DXaS2e[9BTQ22DY0bU:00<aS3F]=Jd00S6<0Re[00<U:AcW6<H00PaSbP0000@8@QBU8@PH
aP<Li`056<HLib489BTHaP0248@011BU36<<HaBU0QcW00HDY@aS48@DYA245:D27>L01AS65:D@Q1BU
48@00QBU00X<HaBU6<HLiaBU48@DYAcV6<LHaP<@Q0085:DHaA2448@DYAcW8@PLj08DY@086<HYBR48
6<HDYAS65:D@Q08DY@8Q200:7>LHaaS66<HLia2436<@Q1BU7>L36<H01R48:DX]Jc6<<H/YBP4U:@00
00LDYBDY=Jde[BU:6<HLi`058@P29BT38@P00bDY:DXU:@02:DX39BT00bU:;F/YBP02:DX01BDY:DXU
:BU:9BT00R480RU:00@e[CW>?NlicP8e[@03<H`YBR48008DY@0336<8@P0002l000031240000009L0
000536<HaRe[9BTHaP037>L00b487>LDY@025:D010aS48@DYABU0QcW0QBU0PaS0QBU0aS600TDYA24
48@@Q1BU48@DYAS65:D00a2400LHaA255:DDYAS67>LHa@025:D04a255:D@Q0aS5:@LibDY7>LHaQcW
8@TQ21cV5:HHaABU48DDYAS5008HaP<Li`0>6<HHaAS67>HDYA245:DHaR487>LYBSF]>LdaS@<Q2000
0R480RDY0QcW00@Q22U:8@PU:@8]J`0::DXQ22DY:DXQ21S65:DLibU:9BT4:DX39BT4:DX032DY8@PQ
22U:8@PLib48;F/mkcF]:DX]J`8e[@059BTQ21cW5:D<H`3900002`Q2;F/mkcg_7>LDYB489BTLiaBU
6<H00acW0QS600<DYA245:D00QS600<DYA2436<00QBU00/HaQcW8@PHaQBU48@DYAS65:D@Q1BU00<@
Q0075:DHaQBV6<DLibDY8@P00QcW00@HaQcV6<HDYP<DY@8HaP<Li`0A8@LDYQS55:H@Q12348DHaQcW
6<H@Q1BU6<HDYA255:DDYP026<H25:D01aS67>LLiaS65:HHaRDY008YBP000QcW00hU:B488@PHaQcW
8@PLib48;F/e[Be[9BTQ22DY1b480RDY00TQ22DY9BT]Jc6<=Jd]Jb487>L00b4800DLib48:DX]JcF]
008aS004=JdaS2e[9BT27>L00`aS2480000Q00000`@Q0000002S00001`aS;F]2436<8@PU:AcW00@H
aP047>LQ22487>L26<H00aBU6<HDY@025:D02Q245:DDYAS67>LHaQBU48@DYAcW0QBU00D8@PaS6<HH
aQBU00<@Q0096<HLib49:DTU:B487>PHaQBV008HaP036<DDYA2400<DY@076<HDYAS65:DHaQBU6<H0
11240QS600HLiaS66<H@Q1BT6<H27>L02AS65:D@Q1S65:HHaQBU7>LQ2002:DX18@P00003;F/YBR48
008YBP8]J`<U:@067>LQ2248:DXaS2e[0S6<00<]Jc6<:DX00be[00He[C6<=Jd]JbU:;F/2<H`01Re[
9BTU:BDY:DXU:@<Q2003:DX]Jbe[008YBP08;F/aS2DY5:DHaRU:7>L<HlH00008248Lib487>LaS48@
AS4icP<Li`036<HLiacW008Li`036<HDYABU008Li`8Q208Li`@HaP035:D@Q0aS00<DY@8<H`0348@H
aQS6008@Q0045:D@Q1BU5:D26<H011cW6<HHaABU0QS600DDYQBU5:DHaAS600<DY@@@Q00<5:D@Q124
36<DYAS67>LHaQ245:@DYQS511BU00@HaQBU5:@DY@8HaP036<DDYABU004Li`0000TU:Be[<H`]Jb48
7>LQ22U:9BT00R480RDY00PYBSF]=JdaS2e[:DXU:C6<0SF]00H]JbU:<H`e[Be[:DX3<H`02BU:9BTY
BRDY8@PU:B489BTYBP05;F/022U:9BTQ22U:8@PLi`Q2127600002@aS7>L]Jbe[=JdicRe[8@PLi`02
8@P37>L01BDY7>LLiaS67>L00RDY00<Q21cW5:D00QS60QBU00@HaQcW6<HHaP8DY@0348@<HaBU008H
aP035:D@Q1BU00<DY@8HaP<DY@035:HHaQS5008HaP065:DDYQ2436<@Q0aS112400P<Ha246<HDYQBT
48@DYAS611BU0Q2400DDYAS67>LLiaS600<DY@046<HDYQBU5:D16<H00005>Lhe[Cg_AS4mk`02=Jd0
1Be[:DXYBRU:9BT012480RU:00<aS3F]=Jd00S6<0SF]00<aS2U:9BT00Re[00/YBRe[:DX]Jc6<;F/U
:B48:DX]JbU:008U:@8YBP09;F/Q22488@PLic6<>Lh]Jb4804L000031240000007/00088@P0336<D
YABU008Q208U:@8YBP@]J`8YBP048@PLiacW7>L26<H00aBU6<HHaP029BT01BU:8@PHaQS67>L00QS6
00DDYAS65:DDYA2400@DY@8HaP<@Q0055:DHaQS548@<I00248@011cW6<HHaQS60aBU0a2400L<HaBU
6<HDY0aT36<DY@026<H01QBU48@DYA2536<@Q08DY@8<H`0748DDYABU36<DYAS65:D00AS600001CW>
?Nm2448@?Nl00S6<00DYBRDY9BTQ22DY00<YBP048@PYBRe[=Jd2;F/2<H`01cW>=JdYBRU:9BTaS2e[
008YBP06;F/aS2e[:DX]JbDY0b480RU:00@U:BU::DXYBP8Q20069BTaS36<7>LHaP@Qa00000`<Ha24
48@DYAcW8@PLib489BTYBRDY;F/2=Jd0136<8@PQ22480QcW0QS60QBU0QcW00TQ22U:8@PQ21cW6<HL
iaS65:D00aS600/DYA2448@DYAS65:D@Q0aT48@HaAS6008DY@066<H@Q12448@DYAS60QcW00<HaQS5
5:D00aBU0Q240aBU00@HaABU5:DDY@<@Q08DY@076<HHaaS65:DHaQBU6<D00aBU00<@Q1S65:D00ABU
00002E:DHaQW>F]JG_MF]E[FBU8mk`02:DX012e[:DXYBR480RDY0RU:0bDY0c6<0Re[0R4800HU:BU:
<H`]JbDY8@P27>L00bDY8@PU:@02:DX2;F/2:DX02b487>LLib48<H`]Jd8@E[Dmkb481240_`0000<4
8@Q212400P@Q00@@Q1cW6<HHaP8DY@056<HDYABU6<HQ2004=Jd01C6<;F/YBR487>L00QS600<DYA24
6<H00QcW00@HaQBU5:DDY@<HaP055:D<H`aS36<DY@046<H01AcV6<HHaQ2436@00Q2400HDYABT5:HL
iQS65:D248@00aS65:HDY@045:D348@03@aS5:DLib486<HDYABV7>LHaPaS48<HaQcW00<DY@058@PL
iacW8@PLi`0248@00009AS5W>GNmKg]JeSg_BU8mkc6<008YBP08;F/YBRU:7>LHaR48:DXaS08U:@06
<H`e[C6<9BTYBRe[0RU:0Re[00@YBRDY8@PU:@8Q208U:@8YBP03;F/YBRU:00<Li`038@PYBRDY008a
S004>Li:DRU:24820002125L00000`@Q0000001L0003248020@Q248HaQcW6<HDY@aS48@25:D021S6
48@Q22e[@Q0icRe[:DX3;F/01AcW5:DDYAS67>L00QBU00@HaQcW7>LHaPDDY@036<HDYABU008DY@8@
Q08DY@<HaP036<DDYA24008@Q00336@DY1BV008HaP8DY@0548@<Ha2448@DY@026<H04Q2436<<HaS6
7>LHaQBU48@DYAS56<HLiaS65:D<HaBU6<DLj08Li`038@PLiaS600<DY@0000DaS2U:;F]6<E:D009o
o`9cW007E[E>LdYB>Lhe[C6<;F/00R4800@Lib48:DXU:@8]J`04>Li243g_=Jd2:DX2;F/2:DX01b48
:DX]Jbe[9BTQ22e[008aS08U:@03:DXQ21cW008Li`099BTYBS6<;F/Q22U:8@PDY@Q20;`000085:DU
:CF];F/DYA247>LHaP<DY@8HaP055:D@Q1245:DLi`029BT012489BTYBRU:0S6<00@U:B485:DDY@DL
i`@Q20035:D<Ha24008HaP095:D@Q1S68@PHaQBU48@DYAS7008Li`0A5:D<HaBT48D<HaBU6<HQ21S6
5:HDYAcV6<H@Q1S69BTLi`0248@011BU7>LHaQBU0QS60QBU0Q2400T@QA246<HHaQcW7>PLiQcW5:D0
0a240ABU00001BU:<H`icUJeF]H00Woo00Eg_F]JCW=243g_008aS08Li`8Q20@YBP8e[@05?Nm243W>
=JdaS003:DX29BT00b48:DX]J`03:DX2<H`01cF]<H`HaQS65:DQ22U:00<Q20069BTYBRU::DXLi`Q2
5P0000<48@000000?`0000<48@0000002P0000<48@000000D`000P@Q00HQ236<;F/YBQcW5:D56<H3
48@01ABU6<HDYAS67>L01BU:00H]Jc6<8@PHaQBU7>L28@P00acW6<HQ20037>L00aBU6<HLi`026<H2
36<011BU6<HLiaS60QBU0QS600HDYAS66<HHaQBU5:@248@04aBT5:DDYABU6<HHaaS66<DDYQBU6<HD
YAS68@TLiaS536@<Ha2400<DY@045:@DYAS66<H25:D01ABT6<HHaQS648@00PaS0ABV00000bDY<H`e
[@03>Lh01Cg_AS56<DYBF]H00V<H00IF]E[FE[E2436<7>L38@P02be[?Nm6<Cg_;F/Q22U:=JdmkcW>
=Jd00Re[00@aS3W>=Jd]J`8U:@0:<H`]Jbe[8@PLib489BTYBRDY7>L29BT022487>LHaR489BTQ2124
124W00000`@Q0000002:00004@@Q5:DQ21S60008@P@Q000Lif<HOomg_BU:248HaQcW6<H00QBU0Q24
0QBU11cW0b4800DU:B488@PQ22DY00<YBP047>L@Q1BU48@36<H248@25:D01aS67>LDYABU48@<HaBU
00<@Q00:5:DLiacW7>LHaQBU5:HHaABV5:D348@01QBU5:@@QAS68@LLi`8DY@0<7>HLiaBV48@DYAS6
5:DHaPaS24<@Q1S60R4800@Lib487>PLi`8HaP8DY@4DY0000RU:00/]JcW>>Li6<D8@BU9>LeJeDYAF
]E[F009F]@05CW<aS2e[7>LQ2002;F/00cW>?Nle[@02=Jd01S6<=JdicSg_>LhaS08YBP06>LhmkcW>
:DXQ22U:0S6<00<YBRDY8@P00QcW00DQ22U::DXU:AcW00<U:@048@PHaQ24248R00000`@Q0000000]
00000`@Q0000001P000011248@PQ21BU0P0000XDYAcWBU9_NekgBU8YBQ246<HLi`<DY@0548@<Ha24
5:DQ20029BT37>L01R489BTU:BDY7>LQ208U:@048@PHaQBU5:D46<H35:D26<H:5:D47>L01AS65:DH
aQcW6<H00Q2400dDYAcW6<H@Q1S67>PQ1aBV48@DYQS55:D@Q0025:D01Q2436<<HaBU6<HDY@8Li`8Q
20068@LQ2AcW5:@<I0aS0ABU00000be[@Q16<@02BU801T8@BU8mkcF];F/aS0@icP06@Q1BU5JeCW<m
kcW>0T8@00/e[C6<=JdicS6<;F/e[CW>?NlicS6<008]J`0E<H`icSF]=JdicSF];F/YBRe[>LhaS248
:DXaS3F];F/U:BU:<H`]JbU:008Q20049BTYBQcW48@P0002125000000`@Q0000001:00001`@Q0000
00@Q248HaQBU008YBP04;F/YBRDY8@P2:DX3;F/02R487>LHaQS65:DHaQBU48@HaRU:0Re[00<Q21cW
8@P00QcW0QS60QcW0b4800LU:AcW48@HaQBU6<HDY@0248@25:D00aS648@@Q00436<011246<HLib48
0QS600<LiaS648@00QBU0QcW0QS600TQ21cW7>LDYA2436<@Q1S548@01ABU00<DY1BU5:D00QBU00<H
aQcW7>L00QcW00DQ2BDX7>LLiaS6008DY@0000@icT8@>Li6<@9:DP04?NlaS36<>Lh3=Jd01Sg_BU9>
LeJeDY@mk`8icP8mk`0;>Lh]JbU:<H`e[Cg_>Lh]Jc6<>LhaS0029BT0136<?Nlmkc6<0SF]1Be[00DY
BRe[<H`e[Be[00<YBP8]J`069BTLibU::DXHaPaSA@0000<48@0000001@0000<48@0000002@0000<4
8@000000B@0000<48@0000000`0000@48@00000000848@<8@P066<HU:Be[:DXQ22U:0Re[00hYBRe[
;F/YBRDY7>LHaQBU6<H@Q0aS5:DHaR480RU:0b4800<LiaS65:D00QcW0b4800XYBRDY6<H@Q1S67>LH
aQ2436<@Q08HaP035:D<H`aS008DY@88@P0336<HaRDY008Li`046<HDYAS65:D236<011BU8@PLiaS6
0QcW00<HaQBU48@00QBU0Q2400H@QABT48DDY1255:D26<H02QBU6<DDYABU6<HLibDY8@PLiacX0acW
0QBU0002<H`01Re[:DXYBRe[<H`YBP8Q20049BTaS36<:DX3;F/04RU:<H`e[CW>?Nm244Ha@Q0icSF]
>Li6<EJeDYA:DT8@;F/aS0<YBP059BTYBRe[;F/Q20027>L00bDY;F/YBP038@P01RU:<H`aS36<;F/Y
BP8Q208Li`8U:@04:DX]J`aS248200000`Q20000000<00000`@Q0000000<00000`@Q00048@020000
10@Q00048@@Q6@0000@48@00000000848@`000031240000000H000@48@0300048@00008000032484
8@0000<00003124000@Q00/000031240000000H000041248@PQ2124200031244000224800`@Q0000
000224850002124300000`Q236<8@P0212402`aS6<H@Q1246<HQ21cW48@DYAS69BT012480bDY00<Q
21S67>L00be[00@Q21BU5:DDY@<HaP047>LHaQS66<H45:D348@011BU6<H@Q1240QBU1BDY0R480QcW
0QS610aS00DDYA2448@DYAcW008Q20096<HDYA2436<DYAS68@PLiaS6008DY@8@Q0<<H`07248HaQcW
7>LDY@aS24800Q240QS600d@QAcW9BTU:AS65:DQ1bDY7>LHaQcW8@PDY@0136<0000:<H`e[BU::DXa
S2e[:DXQ22DY:DX2<H`00be[:DXYBP02=Jd0136<>Li243g_0SF]01=244Ha=Jde[DHaF]IBU3g_=Jdm
kcW>;F/YBRe[<H`YBR48:DX]J`038@P02BU:;F/YBRU:8@PU:BU:=JdaS0029BT02B487>LQ22489BTa
S2e[7>LDY@030002124Q00000`aS24848@0^0002124300001P@Q00048@Q236<48@8000<48@L000<4
8@P000848@<000848@D000041248@PQ2124400001P@Q000000001248@P848@042480000000021243
00000`@Q00000002000030@Q36<<H`Q236<@Q1BU48@<HaS68@PLi`8DY@038@PU:AcW008Li`0<:DXa
S2e[6<HDYAS69BTaS2e[8@PLi`aS0Q2400<<HaBU5:D00acW0QS60QBU00P@Q0aS48@DYA245:DHaQBU
0QcW00@U:BU:9BTQ20<Li`036<HDYA24008@Q0035:D@Q0aS008@Q0035:DLiacW008Li`0448@<H`aS
36<57>L25:D03PaS48@<H`aS6<HDYAcW8@PDYA2324<<Ha246<H35:D031S68@PLiaBU5:HQ22DY7>L@
Q1BU7>LHaP4DY@00010e[Be[9BTQ22U:;F/Q21S67>LYBQcW8@PaS3g_@Q0aS08YBP09<H`e[C6<<H`U
:B48>Li245[F009W>@=oo`04HaPicSF];F/2:DX01B489BTYBRU:9BT00R4800H]JbU:8@PU:BU:@Q02
AS400dYB=JdYBP028@P39BT37>L021S6;F/e[C6<9BT@Q0aS248800000`@Q24800003000212440002
124200001`@Q2488@PaS5:DHaRDY008Q20036<H8@PQ200@48@@000848@0400048@Q2124300021240
100012448@@Q0`000`Q20`001@Q200X48@Q21248@P@Q000<HaS65:D<H`848@8HaP057>LHaQBU6<HL
i`028@P39BT021cW5:DHaQ2436<8@PaS48@536<01`@Q24848@aS48@<Ha2400@8@P0936<48@@Q36<@
Q1S648@LibU:008aS0068@PLiacW6<HLiaBU0Q2400<HaQcW6<H00Q2400<<Ha2448@00Q240QBU00/@
Q0aS36<@Q1S65:DHaQcW8@PYBR4800<HaP8Q20<Li`09:DXe[Be[9BTQ22U:<H`]JbU:008Q20<HaPHD
Y@@HaP047>LQ21cW5:D236<448@236<011245:DDYABU0aS600<U:BU::DX00R4800XYBRDY8@P@Q0Q2
36<DYAS68@PDY@8HaP0G5:D<Ha246<HQ21cW5:DHaQBU36<8@PaS5:DHaQBU48@DYAS66<DDYQBU48@<
HP0248@26<H01AS55:HHaAcW6<H00R480QcW00@HaQ245:DDY04DYP0000T]JbU:8@PYBS6<9BTLiaS6
7>L00bU:00De[Cg_=JdaS2U:008aS00:=Jd]JbU::DX]Jd8@AS5JeW>LNmh2Ool01ekgDY@U:B487>LQ
22e[008U:@048@PYBQcW7>L28@P02bU:;F/e[CF]AS5:DTHa?NlYBRDY8@P00QcW00HQ22DY7>LLib48
9BT2?Nl01BU:6<H8@P@Q36<01`0000@48@Q224848@8000848@D000848@0324848@Q2008<H`075:D@
Q1S69BTYBR485:D00P000P@Q00<8@P@Q00000P@Q00@000@Q1248@P@0000324848@@Q008000031248
@P00008000848@<00009248<H`Q2248000@Q24848@Q200848@0800048@aS6<HDY@Q2124<H`8Li`05
6<HDYAS65:DLi`02:DX01bDY8@PLib485:D@Q0aS008@Q0<8@P0436<@Q0aS36<248@010aS48@@Q124
0PQ200P48@Q22488@P@Q0008@Q240R4800@YBRe[9BTU:@DQ20047>LHaQ2448@25:D0212436<<HaBU
6<HDYA24248248@25:D26<H00aBU6<HLi`029BT00b487>LLi`047>L01248:DXYBR480RDY00P]Jc6<
;F/YBR487>LQ21S60QBU00/HaQBU36<@Q1BU7>LDYAS68@PU:B4800@DY@L<H`0848@DYAcW8@PLib48
:DXU:@<Li`04:DX]JacW6<H248@01aBU36<@Q1245:DLiaS6008<H`0548@HaRDY9BTHaP025:D03PaS
5:D@Q1246<HDYAS65:D<H`aT48<@QAS55:H25:D011S56<LLiacW0QS60QcW00LLiQS66<HDYA255:@@
Q@016<D00003:DX]Jbe[008YBP039BTQ21cW00<Li`069BTaS3F]=Jd]JbDY0RU:00@]Jc6<<H`]J`8Y
BP06;F/aS2e[>Li>LeJe0W_N00=_NfLiAS400Sg_00M:DTHa?Nl]JbU:<H`U:@03:DX00c6<;F/aS002
;F/03CW>=JdU:AcW8@PaS3F]:DX]JcF]<H`YBR48008YBP8Q20069BTYBR487>LDYA240`Q20PaS00<8
@P0000000PQ200D<H`@Q248<HaBU008Li`0F8@PLibDY;F/e[Be[=JeBU5kgF]Hmkb487>L<Ha245:D@
Q1cW8@PLiaS636<248@010aS2488@PQ21ABU00<@Q1S67>L00QS600<DY@aS48@00PQ200X<Ha246<HL
iaS648@DYAS69BTYBP8Q20037>LHaQBU008HaP0:7>LHaRDY:DXicSg_;F/YBQcW5:D37>L29BT01248
6<H@Q0aS0Q2400@DYA2448@@Q0<DY@0?6<HDYAS67>LHaQ245:DHaQcW48@8@PaS48@DYA24008DY@06
9BT]JcW>=JdmkdYB0Tic00dmkbe[;F/]JcF]<H`YBQBU6<HDYA247>LHaP037>L35:D011S69BTQ21S6
0aBU00@HaQ245:DHaP8Li`086<H@Q1BU48@<HaBU6<HLi`8Q2004:DXQ21cW6<H45:D01AcW6<H@Q0aS
48@00QS600DDYA245:DHaQBU00H@Q0035:D@Q12400<@Q0035:DHaQBU008DY@8HaP0E7>LHaQBU:DXe
[Cg_>LhLia245:DHaQcW6<HDY@aS248HaQcW:DXQ21S6008DY@H@Q0035:DHaQBU00<<H`045:DDY0aT
248236<00a256<DDY@025:D02QS67>LHaQBU36<@Q1S66<DDYQ230A2400003R48;F/aS2e[:DXHaR48
7>LHaR48:DXaS3F]<H`3:DX4;F/01C6<;F/aS2e[:DX00SF]01Y6<F]JLiaoog>LBU96<CW>@Q1BU4ic
@Q0e[Be[:DX]JbU:8@P]JcW><H`U:B48:DXmkcF]0be[00PYBRe[<H`aS3W>=JdYBR480QcW0bU:00@]
JbDY7>LDY@88@P<48@88@P061248@PQ2248<Ha240`aS00@DYAcW6<HU:@<YBP0F;F/YBSg_F]IS65Je
<H`DYAS65:D@Q1S68@PHaQBU36<DYAS648@<H`Q236<248@00aS648@@Q0026<H25:D011S67>LDYA24
0PaS00<@Q1S65:D00Q2411BU00PHaR488@PQ21S65:DHaRDY0R4800LHaQBU;F/icT8@?NlU:@027>L0
1QS67>LLiacW8@PLi`8DY@0536<@Q12448@<H`02248010aS5:DDYABU0R4800/LiaBU36<@Q1S68@PH
aQBU36<@Q1S6008<H`035:DU:Cg_00<icP06?Nm:DTHa@Q0icRe[0S6<00D]JbU:8@PDYAS600<DY@06
6<HLiaS65:D@Q1S60QcW0R4800<LiaS65:D01ABU0QS600PLiaS65:D@Q1BU6<HDYB480RU:00HU:AS6
6<HHaQ245:D26<H01ABU36<@Q1246<H00aBU0aS600@DYA2436<@Q08DY@0348@<H`aS00<@Q08DY@8L
i`056<HDYABU5:DHaP02:DX2=Jd01BU:9BTHaQS67>L00aBU00THaQBU48@DYB489BTQ21245:D00Q24
00@DY@Q236<<H`8DY@0448@<Ha2436<648@02aBU6<HDYQBT5:HHaR487>LDYQS65:D00PaS00<<I1BU
48D00A2400002B48<H`e[CF]:DXHaQcW8@PLi`029BT01Be[:DXYBRDY8@P00Re[00<e[CW>;F/00bU:
00D]Jb489BT]JcW>00<mk`<icP0<@Q16<DHa>Li6<EJeG_M>LcF]:DXe[C6<0RU:00<aS3F]=Jd00Re[
00@aS2e[<H`]J`8aS08]J`04:DX]Jbe[;F/2:DX042e[<H`]JbU:7>LQ22U:=JdicSF]?Nm6<C6<:DXD
YAcW0RU:00HQ21BU6<HU:Be[=Jd2:DX00c6<;F/YBP028@P022DY8@PU:BDY:DXQ21S67>L29BT00acW
5:DDY@036<H37>L26<H01AcW8@PQ22DY8@P022DY00LQ21cW5:DLibDY:DXU:@048@P27>L36<H348@2
7>L02ABU8@PQ236<=JdU:B486<H@Q0026<H27>L01b486<H@Q1246<HLiaBU008@Q08HaP0=7>LU:BU:
9BTQ21BU36<LibDY:DXQ21BU48@00QS600<Lib488@P00R480QS600@]Jc6<?Nle[@8aS00;=JdicSg_
BU96<D8@=JdaS3F]:DXQ20025:D28@P021cW8@PQ22DY7>LHaQ2436<248@00`aS48@@Q0046<H011BU
48@HaQS60QBU00@@Q1BU6<HHaP8DY@0348@HaQBU00PDY@036<H@Q124008<H`@@Q00436<@Q1BU5:D2
36<01Q246<H@Q1245:DLi`8Q20065:D@Q0aS248DYAS60R480QcW00<Q21cW9BT00RU:00<U:AcW5:D0
0QBU00<@Q1BU5:D00QBU0PaS00P@Q1BU5:D@Q0Q236<DYA240PQ210aS00D@Q1BU48<<I1BT008HaP8D
Y@8HaP077>H@Q1BU48@<HaS56<H00AcW00001acW:DXaS36<:DXHaQcW008Q200;:DX]JbU::DXU:B48
9BT]Jc6<=JdaS0029BT00b489BT]J`02:DX00be[=Jdmk`02?Nl00d8@?Nlmk`02AS401dicBU9:DTic
BU8mkcF]00@]J`07:DX]Jc6<<H`icSF]<H`00Re[00@aS3F]<H`aS0<U:@8YBP<Q20039BTYBRU:008Q
2004;F/icTYB>Lh4;F/01bU:9BTLiaBU6<HLibDY00<]J`<YBP8U:@@YBPDQ20037>LHaQcW008Li`03
6<HDYAS6008Li`<Q20@Li`048@PU:B488@P27>L03b48:DXYBRDY8@P@Q1BU8@PYBRe[8@PLibDY8@PL
i`036<H25:D248@00aS67>LQ20028@P3:DX02RDY6<HHaQBU7>LU:B487>LDYA240QS60QBU0Q2400<D
YAcW8@P01B4800<HaQBU7>L00RU:00@U:ABU5:DHaP8Li`8U:@067>LHaQcW7>Le[Cg_0T8@00Pe[C6<
=JdicT8@AS5243F]0Re[00<e[BU:7>L00QS600TQ22DY:DXQ21cW5:DHaQBU6<H00a2400<<HaBU5:D0
1AS60aBU00<@Q1BU48@011S60aBU00<@Q1BU5:D00QS600@@Q1BU6<HHaP8DY@0A6<HDYABU48@<Ha24
36<8@Q245:DHaQBU36<@Q1BU48@HaP037>L00aS65:DDY@0248@27>L28@P37>L28@P01BU:9BTLiaBU
36<00a240QBU0a240`aS00<DY@Q224800PaS0QBU00X@Q1BU36<8@PaS5:DHaQcW6<HDY@8HaP037>LH
aQBU008DY@066<HDYA255:@DYQBT0A2400002be[<H`e[Cg_=JdaS3g_>LhaS2U:8@P00bU:00HQ21cW
8@PYBRe[:DX28@P00acW8@PQ20027>L01248:DX]JbU:0Re[0RU:00<Q21cW8@P00bU:0RDY00D]JcF]
?Nm243W>008aS08]J`03<H`]JcF]00924004=Jd]Jb48:DX2<H`01BU:9BTLibDY;F/00RDY0RU:00@Q
21cW7>LQ20@YBP087>LDYAS68@P]Jb486<HLi`8YBP057>LHaQS6;F/aS002>Lh2;F/6:DX3;F/01BU:
;F/Q22487>L00QS600XDYAcW8@PU:AcW5:DHaR48;F/U:@8Q20<Li`8Q20097>LHaQS66<HLiaS67>LQ
21cW00<DY@037>LHaQBU00<HaP0@48@HaQcW7>LHaQBU48@HaR48:DX]Jb486<HDY@aS5:D36<H01aBU
48@@Q248;F/e[Be[00<Q200:7>LQ21BU48@LibDY?NlicRU:8@P25:D03aS65:DHaQ245:DHaQcW8@PU
:AS648@HaRU:<H`U:@027>L022e[=Jde[C6<;F/e[CW>AS42@Q001DYB>Lh]Jb485:D011cW0QBU00DH
aQBU48@@Q1BU00DHaP8DY@0:36<@Q1cW8@PHaQ24248DYAS648@224801ABU48@<Ha245:D00a240QS6
00<@Q1BU5:D00QcW00DHaPaS36<<Ha24008HaP0648@<H`Q236<@Q0aS0QBU00HHaQBU5:D@Q0aS48@2
5:D020aS5:DQ22U:6<H@Q1BU8@P2:DX29BT28@P011S65:DDYAS60QcW00<DYAS648@00`aS00<@Q1BU
36<011BU0Q240QBU0QS600LDYA2448@<I0aS5:@DYP047>L15:D148@136<0000@;F/icT8@=Jd]Jc6<
>Lhmkc6<9BTYBRe[:DXU:AcW8@P29BT012U:9BTU:BDY0R4800/Lib487>LLibDY;F/aS3W><H`YBRDY
008Li`8U:@06;F/YBRe[8@PU:CW>0THa00DicRU:;F/]JbU:008]J`8icP8aS0@]J`04:DXQ22489BT2
8@P00bDY8@PLi`088@P02BDY7>LHaQS68@PU:AcW6<HQ20029BT02R487>LQ236<=JdmkcW>;F/YBRDY
0Re[0RDY00DLibDY:DXYBRDY00<Q208Li`8HaP8Li`038@PLiaS6008Q2006:DXQ21cW9BTQ21S60QcW
00DQ21cW6<HDYAS600<Li`076<HLib487>LHaQ245:D00aS600DDYAS66<HQ21S6008@Q0066<HYBR48
7>LQ21cW11BU0QS60Q2400<DYAS6:DX00RDY0RU:00XQ21cW8@PQ21BU248Libe[@Q0icP8Li`8DY@05
6<HDYABU5:DHaP027>L00b487>LQ20027>L28@P01AS68@PYBS6<>Lh00S6<00De[CW>>Li244Ha008m
k`03;F/YBR4800DHaP<DY@<<H`045:DQ21cW6<H25:D01A245:DDYA245:D00aS60PaS1Q240QBU00<@
Q1BU48@01ABU00@HaQcW5:DDY@8<H`@DY@8<H`06248<H`aS48@DYAS60acW0Q2400<DYAS65:D00Q24
00<Lib486<H00QS60RU:00DQ22DY:DXQ21cW00@HaP<DY@0336<DYA24008DY@8@Q08DY@<@Q08DY@03
48@DYAS6008@Q00436<@Q12436<25:D00b477>LHaP026<H15:D15:H000077>LYBRe[<H`]Jb489BT0
0RU:00LaS2U::DXYBRe[8@PLi`036<H47>L26<H00acW9BTQ20028@P01BDY:DX]Jbe[:DX00QcW12DY
0R4800DU:C6<>LhmkcW>008mk`0;E[ENmf<HG_MF]F<HIcUJeTHa;F/YBP049BT47>L00bDY:DXQ2002
7>L01QBU6<HLiacW8@PLi`8HaP0648@DYABU6<HLib480RU:00<U:B488@P00RDY0R480QcW0RU:0Re[
00<YBRe[<H`01S6<0bU:00<Q22U:;F/00Re[0R4800@YBRDY9BTQ20<Li`@HaP@Li`8Q20047>LU:Be[
:DX27>L00b48:DXQ20037>L28@P46<H27>L01B489BTU:BDY8@P00acW00HHaQcW6<HHaQBU8@P2:DX0
1B487>LHaQcW8@P00QcW0QS600PLibe[<H`U:AcW5:D@Q1S60QcW0QBU00@@Q1S68@PU:@8Q200:7>LY
BR487>LDYA246<HLib48:DX2;F/0336<?Nm245JeHaQBU4Ha>LhmkdHa@Q0aS08Q20047>LQ21S65:D7
6<H45:D01AcW8@PU:AcW6<H00QcW00XDYA245:DHaQBU36<@Q1BU6<HDY@@<H`0448@<Ha245:D36<H2
5:D01acW9BTQ21S636<@Q1BU008<H`0448@DYA2448@236<01acW8@PQ21S6248<HaBU00<@Q0035:DH
aQcW008YBP8aS007=JdaS2e[:DXQ21cW6<H011BU00H<H`Q236<@Q2489BT28@P00aS648@@Q00236<0
1QBU6<HDYA2324<<H`8DY@035:HHaABV008DY@8<H`0000hLibe[?Nle[B487>LU:C6<:DXU:Be[<H`Y
BR480QcW0QS601<Q22U:8@PDYA247>LYBR487>LDYAcW8@PYBSF]<H`U:B487>LQ2002:DX032DY8@PQ
2248;F/e[Cg_>Lhe[D8@E[EW>@9Nm`06HaQW>FLiE[E6<CW>0bU:00<]JbDY7>L00QS600LYBRe[:DXQ
21S65:DQ20027>L48@P011cW6<HHaQ240QS600@Q22U::DXU:@8Li`078@PYBRDY8@PLib489BT012e[
00<aS2e[;F/00SF]00LicSF]:DXU:B48:DX]J`029BT01248:DXU:BDY0Re[00@YBR487>LU:@8Li`8H
aP057>LDYABU5:DLi`049BT01248:DXU:B480QcW00DQ21cW8@PLib4800PLi`058@PU:BU:9BTQ2005
7>L01QS68@PU:BU:8@PLi`8Q200;7>LHaQcW:DXLia246<HYBSF];F/DY@036<H38@P01aBU48@HaR48
:DXQ21cW008Q20<Li`<Q200E:DX]Jbe[;F/aS2U:BU9JeVLiG_Lmkbe[<H`e[Cg_=Jd]Jb487>LHaQBU
008HaP8Li`036<H@Q12400<DY@0<48@LibDY8@PDYA246<HQ21cW6<HDYAS60QBU00H@Q0aS36<@Q1BU
48@35:D348@35:D36<H02a248@PYBR486<H@Q1BU6<H@Q0aS48@01ABU0QcW00<HaQBU36<00PaS00d8
@Q246<HQ21S67>L]JcW>@Q0e[BU:;F/Q20036<H011cW6<H@Q1240QBU00LHaQBU5:DQ22DY7>LDY@02
36<011BU6<HHaQBU0Q2400D@QABT36<<Ha24008HaP045:@@Q1245:D16<H000<Q200;7>LHaQcW7>LQ
21cW8@PLib489BTYBP027>L02QS67>L]Jbe[<H`icRU:7>LDYAcW0RU:00@Q22DY:DX]J`@YBP047>LQ
22U:;F/4:DX27>L00bU:<Ha6<@02AS401dYBCW=F]EkgF]IW>G_N009oo`09JeY:DTHa?Nm243W>;F/Q
22DY008]J`8aS00=;F/Q22488@PU:BU:8@PYBSF];F/YBQS65:D00QcW0b4800@Lib486<HLi`8Q2004
;F/icSF]:DX28@P4:DX012e[8@PLib480Re[018U:AS67>LaS3W>?NlaS2U:>Li:DSg_:DXLibU:=JdY
BQcW5:D27>L01RDY8@PLiacW8@PU:@8Q20039BTQ2248008Q20049BTYBRU:9BT38@P2:DX28@P01AcW
8@PU:BDY:DX00RDY00<Q21cW7>L00R4800dLib48:DXU:AcW6<HLibDY8@PDYAcW8@PLi`026<H011cW
:DXU:B480QcW0RDY00HLiaBU6<HLib487>L26<H27>L01R487>LQ22U:;F/U:@@Q20059BTLiaS6;F/i
cP02BU8043g_BU9>Ld8@>Lhe[CW>@Q16<D8@?NlYBRDY8@PLib480QS600DDYAcW5:D@Q1BU00@HaP8Q
20077>LDYAS66<HDYA245:D00QcW00HDYA245:DDYAS65:D248@01ABU6<HDYA245:D00acW0QS600<Q
22DY8@P00aS600PQ21cW8@PHaQBU48@DYAS611BU11240QBU00<HaQBU5:D00QBU00PLibe[;F/icTHa
?NlicRe[0R48112400XHaQBU7>LQ22U:<H`Q21BU36<48@8@Q00=5:D@Q12336@@Q1BU6<HDYA2448DD
YAcW6<H00ABU00027>L26<H47>L01R489BTYBRU:9BTQ20@Li`08;F/aS36<:DXHaQcW9BTQ208YBP05
;F/YBRU::DX]J`02:DX01QcW8@PQ22U:;F/YBP8Q20059BTQ2248=JdicP02DY@01DYB@Q16<E:DJeX0
0VLi0Woo00=[FTic>Lh00Sg_00@e[Be[<H`U:@8YBP8]J`8YBP047>LQ22488@P3;F/00c6<:DXU:@03
7>L28@P01QcW6<HLib48:DXQ208U:@<]J`03:DXU:BDY008YBP049BTYBRDY9BT38@P2:DX4;F/0336<
;F/e[D8@BU8icRe[7>LQ22U:9BTLi`<HaP8Li`046<HLib488@P29BT01248:DXYBRU:0b4800LYBR48
8@PU:Be[<H`YBP026<H00acW6<HU:@029BT012U:8@PQ21cW0QS600DLib489BTQ21S600<Li`0A8@PD
YAS65:DHaQcW6<HLibDY8@PLiaBU6<HQ22DY:DXLi`026<H00acW8@PQ20028@P01AcW6<HQ2248:DX0
0bDY00<YBRDY:DX00R480RDY00Hmkd8@DYABU4Ha?Nl2>Lh0248@?Nlmkd8@AS5243g_9BT27>L02R48
9BTHaQBU6<HLiaS65:D<HaBU0QS600<LiaS66<H00QcW00LHaQBU5:DHaQ2436<HaP028@P00aBU36<<
H`0236<01A245:DHaQBU6<H00QcW0QBU0QcW00LYBR487>LQ21cW8@PLi`025:D01QcW9BTLia2436<D
Y@8HaP@@Q08DY@086<HDYAS648@HaR487>LaS0<mk`06:DXU:BDY7>LHaQ240PaS00D@Q1cW7>LYBRDY
008Li`0;5:DHaQBU36<8@PaS48@DYA245:DDY00348@00aBU6<HHaP025:D16<H0000;@Q0aS2488@PY
BSF]<H`Q21cW8@PU:@02:DX29BT012487>LHaR480RU:00@U:AcW8@PU:@<Q200;:DXU:BU:>Li243g_
=Jd]Jc6<=Jd]J`02:DX01Be[:DXaS2U:9BT00RU:00`mkd8@>Lhe[BU:;F/aS2U:=Je245:DHaP2F]H0
2e:DIcUg_FmkHaPicRe[<H`]JcF]:DX00b480RU:00@Q21cW7>LHaP<U:@078@PLia245:DHaQcW8@P0
1QcW12480QcW0QS600LLib488@PQ21cW8@PLi`028@P27>L38@P00aS65:DDY@027>L2:DX012487>LH
aQBU0R480RU:00@U:BU::DXe[@8]J`03<H`YBRDY008Q2006:DXLiacW7>LU:B480QcW00XQ21cW7>LD
YAS67>LHaRDY7>LQ20<]J`099BTHaQS66<HQ22DY:DXLiaS6008@Q0035:DHaQcW00<HaP038@PYBRe[
008]J`8YBP038@PU:B4800<Li`@Q208U:@068@PLibDY:DXQ21cW0aS60QBU00<HaQcW8@P00RDY00<a
S3F]?Nl00SW>00=244icDY@01DHa00<e[C6<8@P00R4800<LiaS65:D011BU00@<HaS67>LLi`8DY@05
48@HaQcW7>L@Q00236<00aBU7>LHaP025:D020aS248@Q1BU6<H@Q0aS48@35:D236<011cW:DXaS2U:
0QS600<LiaS65:D00aBU0QS600HLiaBU48@@Q1BU6<H35:D011246<HHaQBU0Q2400DLib486<HDYA24
008Q2006:DXmkcW><H`YBQBU0a240aS600@@Q1BU5:DDY@8<H`0448@DYB486<H25:D011BT5:HDYA24
0PaS0QBU0A24000013F];F/U:B480S6<00@YBR489BTYBP8Q20039BT]Jb48008Li`039BT]JbU:00@U
:@8YBP059BTQ22DY:DX]J`02>Lh2?Nl00cF]<H`]J`02;F/2:DX07RDY:DXYBRU:;F/e[D8@AS4e[BU:
8@PYBSF]:DXe[E:DIcUJeTYBCW=S67_NLiaF]DYB<H`e[CW>;F/YBP@U:@0E7>LHaQcW8@PYBRDY7>LQ
22DY7>LHaQBU6<HLib487>LHaQcW8@PU:B48008Li`8Q20<Li`068@PU:AcW6<HLib480RDY124800@U
:BU::DXLi`8HaPDLi`8Q208Li`038@PYBRU:008U:@07<H`icSg_>LhYBRe[:DX00RDY00XQ21cW7>LQ
22DY:DXU:B487>LHaP<Li`8HaP067>LU:BU:;F/aS2e[0QcW00@DYAS68@PQ208Li`8DY@8HaP087>LH
aQS65:DHaRDY8@P]J`8YBP07;F/YBRU:9BTQ22DY8@P00QcW0QS600dDYAcW8@PYBRDY8@PHaQcW8@PY
BQcW5:D<H`026<H00aBU8@P]J`02<H`01Be[<H`icSg_@Q000Tic00I6<CW>@Q1>LdYB@Q029BT00b48
7>LLi`026<H25:D26<H27>L36<H01R487>LHaQ2436<DY@8@Q0056<HDYABU48@<H`025:D00a2436<D
Y@025:D01A2436<@Q0aS48@00QS600@U:BU::DXU:@@HaP047>LHaQS648@25:D36<H35:D26<H00aBU
6<H@Q0035:D02aS65:DHaR487>LDYAcW:DXicSF]9BT00R4800DHaQBU48@DYAS6008DY@<HaP075:D<
H`Q25:DLib486<H00a2400L@PaBU48DDY1245:D@Q00148h00003?Nle[BDY008HaP<U:@038@PLiacW
00<Q20039BTQ2248008Li`069BTLiaBU5:DQ22e[0R4800@]Jcg_?NlaS08U:@058@PLibDY8@PYBP04
9BT04R487>LHaR489BTLibDY:DXQ21cW8@PYBRe[9BTLib48;F/e[@8aS00;;F/aS36<BU9BU5JeBU8e
[C6<:DXQ20049BT01B487>LHaR489BT00S6<00X]Jc6<=JdYBRDY8@PYBRDY8@PLi`8Q20059BTQ21cW
7>LHaP098@P012DY8@PU:BU:0RDY00<Q22DY:DX00R480QcW00TQ21cW8@PYBR487>LQ22DY:DX00RDY
00LLiaS68@PYBRe[:DXU:@03:DX012DY7>LLiaBU0acW0b4800DU:B489BTU:AcW008Q2007:DX]JbU:
:DXQ22DY8@P00RU:00<U:AcW7>L00R480QcW11S60aBU00<HaR487>L00b4800HLiaS65:DHaQBU6<H2
36<0112436<DYAS60QBU00<<Ha245:D00QcW00@HaQBU5:DHaP@DY@038@PLibDY008YBP8]J`06:DX]
Jcg_?Nm:DU:D0Sg_00L]Jb48<H`icT8@?Nl]J`028@P00aS65:DHaP027>L011S65:DLiacW0QBU00HH
aQcW6<HHaQBU6<H27>L25:D02A245:DHaQ2436<8@PaS48@DY@0248@26<H27>L26<H25:D36<H75:D0
1QcW8@PQ21S648@HaP8DY@0348@8@PaS00<DY@0348@DYABU008Li`8@Q0046<HYBS6<;F/3>Lh01CF]
6<HDY@aS48@00QBU0PaS0QBU0QS600/DYQS55:HDYA2536<@Pa255:@DYQBU004DY00000D]JbDY8@PQ
22DY00@Q20<U:@8Q200:7>LQ22DY:DXQ21BU6<HLibU:8@P29BT02Re[=Jde[Be[9BTLib489BTLib48
0bDY0b480QcW0b4800PLib48:DX]JbU:8@PYBRDY0QcW00@U:Be[=JdicP8aS08icP08E[ENmdic@Q0U
:AcW9BTQ208YBP039BTLiaS6008Li`0:;F/aS2e[8@PU:CF]?NlaS2DY6<H38@P022U:9BTYBRU:8@PL
iaBU6<H88@P011cW9BTU:BU:0R4800<U:Be[:DX00b48010LiaBU6<HQ22DY6<HLib48;F/U:B489BTY
BRDY8@PU:@<YBP8]J`8YBP038@PLib48008Q20039BTLib48008Q20047>LQ22U:9BT27>L012DY<H`a
S2e[0RU:0R4800<YBRe[9BT00QS600<Q22U:8@P01ABU0QS60acW00<Q22DY9BT00RDY00HLiaBU5:D@
Q1BU6<H248@021S67>LHaQBU48@DYAS67>L56<H248@00aBU6<HDY@028@P012DY:DX]JbU:0Re[014a
S3W>?Nm:DU:D>LhYBR489BTicSg_>Lhe[Be[8@PU:AS6008DY@068@PLiaBU48@DYAcW0Q2400DHaR48
7>LDYAS6008Li`035:D@Q1BU00<HaP8DY@0448@DY@aS36<25:D57>L01B487>LHaQS65:D00QS60QBU
00<@Q1S66<H00QcW1ABU00<HaQBU5:D0112400@<Ha2448@HaP8@Q00;5:DYBRU::DXaS2e[?Nm243F]
:DX@Q0045:D011245:D@Q1BU0QS60QBU00<<I1235:D00aS600@DYA2448@DY@4DZ`0000<]JbU:8@P0
0QcW0RU:00DQ21cW6<HLibU:00DQ20DLi`@DY@037>LU:BDY008Q208DY@047>LQ22DY8@P27>L48@P0
22DY8@PU:B48:DXU:B48:DX2;F/02bU:7>LLib487>L]JcF]>Li6<Cg_<H`00Re[0c6<00XQ21cW:DXa
S4HaHaQNmeJeAS4aS08]J`0:<H`YBR487>L]JcF]<H`U:B48:DX4;F/38@P00acW8@PQ2002:DX01Re[
9BTQ22U:;F/icP8e[@03?NlicSF]00<YBP8]J`03:DXLiaS6008HaP035:DHaQcW008Q20037>LU:B48
008Li`078@PU:AcW5:DHaR48;F/00R4800<]JbU:9BT00QS600<Lib488@P00bU:00<Q22DY9BT00c6<
00@e[CW>@Q12408]J`04<H`mkdYB@Q02=Jd01C6<=JdicSW>=Jd00RU:00<U:Be[:DX00R4800@U:C6<
<H`YBP8U:@038@PU:AS6008DY@066<HDYABU48@<HaBU0QcW00@DYA246<HU:@8Li`8DY@8<H`8@Q0<L
i`8Q20037>LHaQcW00<Q200<:DXaS36<9BT]Jcg_>LhU:B48=Je>LdYB0Sg_00I6<E[FE[E:DSg_9BT5
8@P02acW5:DHaQcW9BTYBR486<HDYAS65:D00QS60QBU00@<H`@Q248DY@8Q208DY@066<HQ21cW6<HL
ia240PQ200d@Q1cW9BTQ21cW6<H@Q0aS6<HQ22U:8@PLi`038@P01QS648@<H`aS48@DY@<HaP075:DL
iacW5:D<Ha247>L00QS600@YBS6<@Q0icP8e[@069BTLiaS65:DHaQ240`aS00@DYAS56<HDY@8@Q0<D
Y@8<H`4@Q04DY@0012U:00<U:B489BT00R4800<LiaS68@P00RDY00DYBRDY8@PQ21S600<DY@8HaP05
8@PYBRU:8@PLi`038@P26<H01B489BTYBR486<H00QcW00<YBR489BT00R4800DYBRDY:DXYBR48008U
:@0;:DXU:AcW8@PYBS6<?NlicSg_=JdicP03=Jd01be[8@PYBRU:>Li6<DYB009JeP0FBU8icRDY:DX]
JcF]<H`Q22U:>Li243F]8@PHaR48<H`]JbU:9BTQ22U:9BT37>L3:DX01bDY8@P]JcW>@Q0e[C6<008i
cP03<H`YBRDY00<YBP037>LHaQBU00<HaP047>LQ22489BT27>L00b487>LQ20028@P37>L00b48:DX]
J`029BT47>L38@P27>L03BDY:DX]Jbe[:DXaS3W>=JdaS3g_@Q16<CW>008e[@08?Nm6<D8@>Lhe[D8@
>LhYBP8Li`8YBP038@PU:BDY008YBP05;F/YBRDY9BTQ20037>L012486<HDYABU0aS600@DYAS67>LD
Y@8HaP8Q20066<HDYA245:DHaQBU0Q2400<DYBDY8@P00R4800DLiaS68@PQ22DY00<aS004;F/YBSF]
<H`2:DX023W>BU9243F]@Q1>Le[FDY@2>Lh48@P01BDY6<HDYAS67>L00RU:00@LiaS65:DHaP8Li`03
5:DHaQBU008DY@08248<HaBU7>LYBR486<HLi`8HaP0;5:DHaQS636<@Q1BU8@PU:AS65:DHaP025:D2
7>L28@P47>L01AS648@DYABU6<H00QBU0Q2400@HaQcW6<HDY@8<H`036<HLib48008e[@06@Q16<CF]
;F/HaQBU0aS60QBU0a2400<<I12448@011BU0`aS0@Q20ABT00000aS68@PQ20038@P37>L021BU48@H
aQS69BTYBRDY7>L25:D27>L248@011BU8@PQ22480QcW00<HaQcW9BT00RU:0R4800<YBRDY9BT00QS6
00<Lib489BT00b4800HU:B486<HHaQcW9BT38@P02bDY8@P]Jcg_AS5:DT8@=JdicS6<;F/00RU:00<a
S3F]=Jd00cW>00<mkdHaCW<00ekg00EJeTHa>Lhe[CW>0092400=?NlaS2U:8@PU:C6<=JdaS2e[7>LH
aQBU6<H01B481BDY00DYBRDY7>LHaR48008]J`03:DXQ2248008Q20059BTLiacW7>LQ20039BT00acW
6<HLi`027>L39BT00b487>LHaP028@P3:DX29BT3:DX01BDY8@PU:BU:9BT00b4800HU:BU:9BTQ22U:
=Jd2>Lh03Sg_@Q1>LeJeDYA6<CF]>Lhmkc6<;F/YBS6<=Jd2;F/2:DX00be[<H`]J`03:DX01bDY:DXY
BRDY8@PHaR48008U:@057>LHaQBU7>LQ20037>L35:D26<H01ABU48@DYAS67>L01B4800@LiaS66<HL
i`8Q208Li`058@PLibDY<Ha6<@02BU82E[D015[FE[EBU4ic0UJe0U[F00Y6<Cg_<H`Q22U:9BTQ22DY
:DXLi`8DY@067>LU:AcW48@<Ha240QBU1QcW0QS60a2400XHaQcW5:DDYAS69BTQ21S65:DHaP<YBP04
9BTLiacW8@P27>L00aS65:DHaP027>L01QS648@<Ha245:DHaP<DY@046<HDYABU6<H28@P01AcW:DX]
Jc6<:DX00acW00<DYAS65:D011S600<HaA255:@00Q2400@DYA2448@8@P48@`0000<HaQcW8@P00QcW
00HHaR488@PLiaS67>L28@P011cW8@PLiaS60a240aBU00<HaR488@P00b480RDY0QcW00XQ21cW:DXY
BRDY8@PLiaBU8@PU:@8YBP046<HQ22U:8@P26<H02BDY;F/YBQcW48@LibU:=Je6<@02@Q0013g_>Lhe
[Be[0RU:00PQ22e[=Je244Ha?Nm244Ha0TYB00]F]EkgE[EBU3W>=JdicSg_@Q0mkcF]008Q2007:DXa
S36<:DXLibDY8@P00QS600@Lib48:DXU:@8Li`048@PU:Be[:DX29BT00acW8@PQ20029BT00bU:9BTQ
20038@P011cW8@PLiaS60R4800DU:B487>LLib4800<Li`058@PU:B487>LU:@02:DX29BT38@P012DY
:DXU:AcW0R480RU:00DQ21cW7>LLibDY00<Q200;;F/aS2e[AS5>Le[FCW=244Ha@Q0icP03=Jd01BDY
8@PQ22e[=Jd00S6<00Le[C6<:DXQ21cW:DXU:@048@P01AcW8@PQ22486<H00QBU00PLib489BTQ21S6
48@<Ha240aBU00P@Q0aS6<HU:BU:8@PLiaS60QcW00@HaR488@PLi`8HaP0<8@PYBQcW9BTe[DicE[E>
Le:DE[ENme[F0e:D00UF]E:DDYA243F];F/U:BU:9BT00b4800DLiaS66<HHaQcW008HaP8DY@0348@D
YAS600<HaP035:DHaQS600<@Q0076<H@Q1246<HQ22U:8@P00QS600HLib48:DX]JbDY8@P26<H011cW
5:DHaQS60acW00<DY@aS48@00aS600D@Q1BU5:DDYAS6008DY@086<HLibDY8@PYBRe[9BTQ20<Li`<H
aP087>LDYA2448@@QAS55:H@Q08<H`035:DHaQBU004@Q0000QcW00DQ21cW7>LLiaS6008Li`0=8@PL
ib488@PYBS6<;F/Q21BU6<HQ22U:8@P00QcW0RDY0RU:00<]JbU::DX00Re[00<aS3F];F/00bU:0S6<
00@YBQcW8@PHaP<Q20047>LDYABU5:D4:DX28@P2:DX00bDY:DXYBP029BT28@P00bDY:DXYBP03;F/0
236<8@PU:B48;F/e[Be[@Q02DY@034YB@Q1>LeJeDYA6<Cg_>LhaS2e[:DXU:@<YBP8U:@0>8@PU:B48
8@PU:Be[:DXU:BU:;F/aS2U:9BTQ208U:@8YBP0>9BTLiacW7>LQ22U:9BTLiaS67>LQ22e[:DXU:@@L
i`0?9BTYBR485:DHaQcW:DXU:B487>LQ21cW8@PYBRe[008YBP067>LHaQcW8@P]JbU:0RDY0Re[00Da
S2e[:DXU:BU:008]J`09=JdicTHaAS4mkc6<:DXQ22e[008aS007:DXQ21S67>LYBRDY<H`00SF]00La
S2U::DX]JbU:;F/aS002;F/0136<9BTU:B480Re[0R4800PU:Be[7>LDYAS69BT]Jb480QcW0RDY0bU:
0RDY00<Lib487>L00b4800TLiaS66<HLib485:DHaRU:=Jd00THa00@aS2e[?Nm:DP9g_@9cW007HaQN
meJeE[E>Lc6<:DX00QBU0b4800@HaQBU6<HQ208Li`0;6<HLiacW8@PHaQBU7>LQ22DY:DXHaP025:D0
0aS67>LHaP025:D00b48;F/]J`03>Lh2<H`01CW>=Jd]Jb486<H00acW00<Q21BU5:D00QS600PDY@aS
48@HaQBU7>LHaQcW0R4800@LiaS66<HLi`8U:@088@PLiaS67>LYBR487>LDY@8HaP055:DLiacW6<HL
i`0248@25:D16<H15:D136<0000548@HaQcW:DXU:@048@P062DY7>LLibU:<H`]JbDY7>LU:B489BTL
iaBU6<HLibe[:DXU:BU:;F/YBRDY:DXe[@8icPDYBP8U:@077>LQ21S65:DLib487>L00aS600LU:BU:
:DXYBRDY8@PU:@028@P00bU:;F/YBP027>L01248;F/]Jc6<0SF]00@]JbDY7>LQ208]J`8icP96<@9:
DP0@CW=BU5:DBU9243W>=JdYBRDY:DXaS2U:9BTLib489BT2:DX00be[<H`YBP02:DX01BDY;F/aS2e[
9BT00R4800@]JbU::DXU:@HQ20047>LU:BU::DX38@P27>L00b487>LLi`027>L58@P27>L01R489BTY
BRU:;F/U:@8Q208Li`048@PYBRe[;F/2:DX2;F/00bU:8@PQ20028@P00be[<H`mk`02@Q001THa>Lh]
JbU:8@PU:@<]J`8Q20067>L]JcF]>Lhe[BU:0Re[0RDY00@YBRe[=Jde[@8]J`039BTQ22e[008e[@0<
9BTHaQcW:DXQ21cW6<HU:B486<HLibU:0Re[00<Q22DY9BT00acW00@HaR487>LQ20<HaP0C7>LHaQS6
48@Q23F]AS5:DT8@<H`e[E[FJeYoogNmHaQ_Nf]JF]H00dYB00@aS24848@DY@8Li`DHaP055:DHaQcW
9BTQ20026<H01ABU7>LU:B487>L00QS600TLiaBU6<HDYB489BTYBSF];F/00SF]0c6<00De[Be[:DXQ
21S6008Li`068@PLiaS636<@Q1BU0QS60Q24010DYAcW6<HDYAcW8@PHaQ245:DQ22U:8@PHaQcW9BTL
i`8HaP047>LQ21cW6<H25:D01acW6<H<H`aS48@HaQ24008<H`4DY@000acW00D]Jc6<=Jd]JbDY008]
J`04:DXU:B488@P29BT00bU:8@PLi`027>L01248:DXYBRU:0c6<00<]JbU:9BT00S6<00Te[C6<;F/]
JbU:;F/YBRDY8@P011cW00LU:BU:;F/U:AcW8@PU:@03:DX012e[<H`aS2U:0RDY00<YBRDY9BT00QcW
0R480RU:0RDY00<Q22DY:DX00acW00@Q22e[<H`aS0<YBPDmk`8e[@DYBP8Q20057>LYBSF]>LhaS002
9BT2;F/01BU:9BTYBRU:9BT00R4800T]Jc6<<H`U:B489BTYBRe[:DX00b480RDY00LLib48:DX]JbU:
7>LDY@026<H02QcW8@PYBRU:9BTQ21S67>LU:Be[0S6<00LU:B48:DX]JcF]<H`YBP058@P04QcW8@PU
:AcW6<HQ22e[<H`]JbDY:DX]Jc6<;F/YBRDY7>LU:@8Q208Li`038@PLib48008YBP8HaP0:8@PaS2U:
7>LQ22U:;F/Q21cW9BT3:DX04acW9BTYBSF]>LhaS2U:8@PYBRe[=JdaS2e[:DXaS2e[=JdicSF]008]
J`04:DXaS2e[:DX27>L01QS65:DDYAS68@PU:@<Q2004:DX]JcW>>Lh2@Q002dYBCW=F]EkgIcUg_FLi
BU8e[BDY8@P00QcW01<HaQ2448@DYAS65:DLib489BT]JbU:6<H@Q1cW;F/aS2DY48@DY@026<H01aBU
36<@Q1BU6<HQ22DY008YBP06;F/aS2e[:DXLiaBU0QS600DLiaBU48@@Q1BU00<Li`0=6<HDYA2448@<
HaBU7>LU:AcW5:DHaQcW6<H00Q2400PDYAS67>LDYA245:@<I1S50bDY00TQ21S66<HHaQcV5:D<Ha24
6<H00RU:0AcW000011cW:DX]JbU:0R4800@YBS6<<H`YBP<Q208YBP039BTQ22DY00@Q20079BT]Jbe[
<H`]JbU:;F/00RU:0Re[00<aS2e[;F/00Re[0b4800<YBQcW7>L00QcW0RDY00/Q21cW8@PU:Be[:DX]
Jc6<>Lhe[BU:008U:@04:DXQ22488@P27>L022DY;F/]JbDY8@PU:Be[9BT28@P29BT011cW9BTaS36<
0RU:00XaS3g_AS56<D8@>LhaS2e[9BTQ208U:@09:DXLibDY;F/icSF];F/Q22DY008YBP07;F/YBRDY
:DXU:B48:DX00Re[00HU:B489BTYBRe[:DX28@P27>L28@P00bU:9BTU:@029BT28@P05QS65:DLib48
;F/YBQcW9BTYBRDY8@PYBRe[9BTLibDY:DXicS6<:DX]Jb480acW00<U:B488@P011cW00@YBRe[=Jda
S0@U:@03:DXQ21cW008Q200<9BTLiaS67>LU:BU:9BTLiaS68@PU:B480RDY00<YBS6<<H`00Re[00@L
ib488@PQ208YBP07;F/aS36<;F/YBR48:DX0136<00@YBRDY;F/e[@8icP08=JdaS36<=Jd]JbDY7>LD
Y@8HaP055:DHaQS67>LHaP027>L012DY;F/aS3g_0dHa01E>Le:DG_MW>F<HKg]Nmd8@<H`DYAS68@PY
BQcW5:D8@Q248@PHaQBU8@P00RU:00LU:A2448@Q22e[<H`Q200248@25:D02AS65:DDYABU6<HYBRe[
=Jd]J`02:DX28@P00acW5:DDY@027>L02QS648@DYAcW8@PLiaBU6<H@Q0aS0Q240acW00DQ21cW6<HH
aQ24008DY@086<HDYA245:D<I1BU6<HLi`8U:@8Q20036<DHaQBV00<DY@047>LQ22486<H148@00007
;F/e[Be[:DXaS2e[9BT00RU:0be[00<YBRe[<H`00SF]00d]JcF]>Lhe[Be[9BTQ22U:;F/aS2e[:DX]
J`03<H`4:DX29BT012489BTU:B480QcW00<Q22DY8@P00RDY0QcW00<Q22DY:DX00RU:00/U:BU:8@PU
:BU:;F/U:AcW6<HU:BU:00<Q2003:DXU:BU:00<YBP078@PLib488@PLib489BT00bU:0R4800HU:BU:
:DXU:Be[<H`2>Lh012e[:DXYBRe[0S6<00DYBR488@PLib48008YBP8]J`07:DXU:BDY8@PYBRe[<H`0
0Re[00<YBRDY<H`00SW>018]JbU:<H`]JbDY6<HDYB489BTQ21cW8@PHaQBU7>LQ22e[:DX28@P01RU:
9BTQ22487>LQ208U:@037>LQ22DY008U:@8HaP@Li`058@PLiaBU7>LU:@02:DX032489BTU:B489BTY
BR487>LHaQBU6<HQ208Li`066<HLib48:DXU:B480QcW00@Q22DY9BTLi`8DY@<Li`8HaP047>LU:BU:
9BT4:DX2<H`2>Lh0148@AS5:DU:D0U[F00EBU48@?NlaS3F]008aS003;F/YBQcW008Li`055:DHaQS6
8@P]J`02<H`02Be[<H`e[DHaCW=BU4HaBU9BU002F]H01E:DBU96<CW><H`00R4800PLiaBU5:DDYAS6
5:DHaR480RU:00LLiaBU5:DLibDY<H`e[@02:DX01acW5:DDY@@Q36<@Q1S6008]J`09<H`YBRe[?Nli
cRe[7>LHaRDY008Li`036<HLiacW00@HaP077>LDYABU5:D<HaBU6<H00QcW0QBU00<@Q1BU5:D00QcW
0aS600`@Q1BU7>LQ21S648@<Ha249BTYBRU98@T27>L012489BTQ21cW0AS600001BU:<H`aS3F];F/0
12U:00@]JbU:;F/]J`8aS08e[@03<H`e[CF]008aS006:DX]Jc6<;F/YBRDY12e[00<YBRe[;F/00RU:
0acW00<Q22DY8@P00QcW1B4800<U:B489BT00RU:00dQ22DY:DXaS2U:9BTYBRe[:DXQ21S67>LU:@02
8@P3:DX012DY:DX]JbU:0QcW00<U:BU::DX00R4800hU:BU::DXYBR48:DXaS2U:7>LYBSW>?Nle[B48
0RDY00L]Jc6<9BTQ22DY;F/aS002:DX2;F/02c6<:DXYBRU:9BTYBS6<=Jd]JbDY;F/00Sg_00<aS2U:
;F/00S6<00DU:AcW7>LHaQcW00<HaP<Li`038@PLib48008Q20039BTQ2248008Q208U:@038@PU:BDY
008Q20047>LHaQS66<H27>L28@P00acW6<HHaP027>L3:DX27>L01BDY:DXU:B486<H00aBU0QS600<L
ib488@P00QcW00PU:C6<8@PHaQcW9BTYBQcW0aBU01LLiaS648@DYAcW<H`YBRDY:DXaS2U:9BTYBSW>
AS4mkcW>@Q1>LeJeF]IBU4Ha00924005?Nle[BU:9BTLi`038@P01QcW5:DDYAcW;F/e[@8aS0<icP0=
AS5244YBBU9BU5[FG_MJeU:DAS4mkbU:8@P011BU0Q240QBU00LQ22e[;F/Q21S648@DY@02:DX01S6<
;F/LiaS65:D<H`8@Q00?6<HLiacW;F/e[CW><H`]JcW>;F/Q21S67>LU:AcW008HaP8Li`075:DHaQcW
6<HDYA2436<00QBU0QS60QBU0Q2411BU0QS601<DYA246<DHaQBV5:D@Pa245:DHaRDY:DXU:AcW6<HQ
22U:8@PQ1`027>L0008YBP048@PU:BU:<H`3;F/2<H`012e[<H`aS2e[1RU:00DaS2U:9BTQ21cW00<Q
20077>LQ22DY9BTYBR489BT00RU:00<U:AcW7>L00RDY00/YBSF]<H`]JbU:5:D@Q1BU8@PYBRDY008L
i`8Q20<U:@048@PLibU:;F/2=Jd012U:8@PQ22480RU:00TU:B488@PQ22DY8@PHaR48:DX00S6<00<Y
BRe[;F/00RDY0QS600HQ22e[<H`YBRDY;F/2?Nl01DYBE[EF]E:DBU800T8@0SW>00He[C6<<H`e[C6<
;F/29BT01BU:8@PYBRU:;F/00cF]00<aS3F]?Nl00SW>0S6<00h]JbDY7>LHaQcW<H`icSg_<H`U:C6<
=Jd]JbDY0R48010Lib487>LLib489BTLiaS67>LQ22e[9BTQ22U:<H`U:@8Q2004:DXU:AcW6<H27>L0
21BU7>LYBS6<9BTQ21cW:DX28@P37>L01QS6:DX]Jbe[9BTLi`8Q20<Li`8Q20099BTHaQBU6<HLib48
9BTQ21S6008DY@8Li`0@6<HU:BDY:DXU:AcW8@PYBRDY;F/e[CW><H`]JbDY;F/2<H`0348@DY@icRU:
7>LU:CW>=Jd]JbDY:DX]J`8e[@03:DXU:Be[00<aS006>LhmkcW>>LhmkdHa0TYB00I6<D8@@Q1:DSW>
:DX27>L01b486<HHaQS68@PU:B48008Li`0C8@PU:Be[<H`Q21S648@DYBDY7>LHaPaS5:DQ22DY=Jda
S2U:;F/00bDY0acW00dQ21S65:DHaRDY8@PLiaS67>LHaQ2436<@Q0027>L00aS65:DDY@026<H00acW
5:D@Q0045:D021BV6<HDYAS65:HDYAcW7>P27>L021255:DLiacW9BT]JbU;:DX18@P000067>LQ22U:
;F/YBRe[0SF]00@aS2e[;F/e[@8aS08]J`8YBP<]J`03:DXQ22DY00<Q20037>LQ22U:008YBP039BTL
iacW00<YBP8Li`038@PaS36<008]J`05:DXQ21cW6<HLi`028@P01BDY8@PQ21cW9BT00RU:00HU:B48
7>LQ22U:;F/2=Jd29BT00acW8@PU:@028@P00bU:;F/U:@026<H03R48:DXU:BU:;F/aS2e[:DXU:BU:
9BTQ22U:;F/2<H`2;F/01THaBU9JeUkgE[E>L`=6<@03?NlicRe[008YBP03;F/aS2e[008YBP04;F/U
:B48;F/2>Lh2;F/00cW>?NlicP03=Jd01S6<:DXLiacW8@PYBP8e[@05<H`]JbU::DX]J`02:DX00b48
7>LLi`028@P02AcW8@PQ22486<HQ22U:<H`YBP028@P29BT00bU:9BTQ20028@P01AcW6<HHaQcW:DX0
0Re[00@aS2U:8@PQ208Li`038@PLib4800<U:@@Q20039BTHaQS600<Li`8HaP055:DQ22U::DXQ2002
5:D27>L00b48:DXYBP028@P01acW8@PU:BU:<H`]Jc6<008e[@04;F/YBRU:<H`2?Nl2@Q0032U:7>LL
ibU:?Nle[BU:9BTYBS6<=JdaS08YBP05<H`e[Be[=Jdmk`02@Q003Cg_AS5:DTYB?Nm6<DYB@Q0e[B48
9BTLiaS6008Li`<Q200:7>LQ21cW8@PU:Be[:DXQ21S65:D27>L032486<HDYABU6<HYBRe[<H`]JbU:
8@PYBP8U:@038@PLiaS6008Li`086<HQ22487>L@Q0aS6<HDY@8<H`0348@LiacW00<Li`8HaP8<H`03
5:DHaQS6008DY@055:@HaQS55:DHaP037>L01QS66<DHaQBU:DTYBP8]J`4YBP4Q204Q200000PQ22DY
8@PQ21cW8@PYBS6<0Re[00<YBS6<<H`00cF]00<aS2e[=Jd00SW>00@aS2DY:DXYBP8Q20049BT]Jc6<
;F/2:DX38@P00bU:<H`]J`04:DX012e[<H`aS2U:0R480RU:00@U:B489BTU:@@Q20<Li`038@PU:BDY
008Q20099BTYBRU::DXU:AcW8@PU:BU:008U:@048@PU:BU:9BT2:DX01BDY8@PLib489BT01RU:0S6<
00@e[C6<>Lhmk`9>L`03DYAJeV<H009_N`09E[E6<CF]=JdmkcF]<H`]Jc6<00@e[@8YBP04<H`icSg_
?Nl2<H`01BU:9BTU:BDY<H`00Re[00He[Cg_>Lh]JbDY:DX2<H`01be[:DXYBR489BTQ22DY008YBP03
9BTQ22DY00<YBP04;F/e[Cg_<H`2:DX0136<;F/Q21BU11S600HQ22DY8@PLib489BT2:DX01BDY:DXU
:AcW8@P00RU:00@Q21cW8@PU:@8Q20@Li`8DY@8Li`8U:@048@PU:BDY7>L29BT032U:;F/]Jbe[:DX]
Jc6<:DXQ21S65:DLi`<HaP065:DQ22DY:DXQ21S60R480RDY0R4800@Lib487>LQ208]J`8icP03?Nli
cSF]008icP04<H`e[CF]@Q02BU82CW<2AS403cg_@Q0mkcW>=JdaS2U:9BTQ22DY:DXLiaBU6<HLi`02
<H`2;F/01BU:;F/aS2e[:DX00acW00DQ21cW6<HDYAcW008Q20036<HLib48008HaP8Q20069BTLiaS6
7>LHaQ240PaS00D@Q1S66<HLiaS600@DY@8HaP045:D8@PaS48@36<H040aT48@@Q1247>HLiaBU36@<
HaBU7>PHaQcW:DX]JbU:0B4800000acW8@PQ20029BT022U:;F/]Jc6<:DXQ22DY<H`2>Lh01bU:8@PY
BS6<=JdicSF]008U:@8Q2008:DXaS36<>Lhe[BU:8@PU:@8YBP049BTYBS6<<H`29BT02248;F/e[CF]
:DXQ21cW9BT2:DX00b489BTU:@038@P01BDY7>LLiacW8@P00Re[0RU:00<LibDY8@P00R480QcW00TU
:BU::DXQ22DY:DX]JbDY8@P00RU:00DU:B489BTaS2U:008Q20049BTaS2e[:DX3;F/00cW>BU9F]@02
CW<01ekgJeYcW6LiAS5243F]008mk`04=JdaS36<>Lh2<H`03bU:;F/U:BU:=Jdmkd8@?Nl]Jc6<;F/U
:BU:9BT]J`04=Jd2;F/3<H`023F];F/YBRDY8@PYBR487>L28@P02Be[:DXU:B48:DX]Jc6<=JdaS002
9BT012U:;F/]JbU:0aBU00<@Q2DY:DX00RU:00HQ22U:;F/U:B487>L28@P011cW8@PU:BDY0b4800<U
:B487>L00QcW00LHaQBU7>LLibU:;F/YBP028@P00bU:;F/YBP028@P01BDY=Jde[CF];F/00R480acW
0R480aBU00@LibU:9BTQ208Li`068@P]Jbe[:DXU:B480QcW00DU:Be[<H`aS3W>008mk`8e[@8mk`04
<H`]Jc6<@Q02DY@00eJeCW=6<@02?Nl3>Lh01S6<;F/YBR489BTQ208Li`0;8@PLiaS69BTaS3W><H`Y
BRe[=JdYBP027>L28@P27>L00b487>LLi`026<H032486<HHaQBU6<HQ22DY8@PLiaBU36<@Q08DY@8@
Q0036<HLiacW00DHaP8DY@0G36<@Q1246<HLiaBU48@HaAcW5:D@Q0aS48@DY1245:DHaQcW5:DLibU:
=Jd]J`018@P00007@Q0mkcF]8@PLibDY:DX00Re[00LQ21cW8@PaS3W>=JdaS0028@P012U:;F/icSW>
0Re[00TYBR489BT]JcF]>Lh]Jb489BT00Re[00<aS2e[9BT00RU:00DQ21cW:DXaS3F]008]J`03:DX]
JbU:008]J`<YBP8]J`039BTQ22U:008aS08U:@04:DXaS2U:9BT27>L58@P012DY:DXYBRDY0R480RU:
00DQ22DY:DXe[BU:008Q2005:DX]JbU::DX]J`02:DX042DY:DX]Jbe[<H`]Jc6<=JdmkcW><Ha>LfLi
JeYBU4Ha0UJe00A242e[:DXaS08icP07;F/Q22U:=Jdmkbe[8@P00RU:0R4800<U:C6<;F/00bU:00D]
Jc6<;F/]JbDY008Q208Li`048@PU:BU::DX37>L03RU:8@PLiacW8@PicTHa@Q0icRU:9BT]Jb487>L6
5:D27>L29BT04B48:DX]JcF]<H`YBRDY7>LQ22DY6<HLibDY;F/Q21BU6<H00RDY00@Q21cW9BTLi`8D
Y@037>LU:B48008HaP037>LQ224800<Q208U:@03:DXU:B48008HaP048@PYBRU:8@P26<H00bDY8@PH
aP0248@00acW8@PLi`025:D011S69BTQ21cW0R4812U:0RDY00@Q22DY;F/]J`8aS003=Je244ic009S
6007F]IBU4YBBU96<D8@=Jd012U:0R480QcW00<U:BU:<H`00Re[00@aS2e[:DXU:@8HaP8DY@058@PL
iaBU5:D@Q0035:D01QcW8@PQ21cW6<HDY@8@Q08DY@0548@DYA246<H@Q0055:D011246<H@Q1240QBU
00@HaQBU36<@Q08HaP085:D@Q0aS36<@Q12536<DY@8Li`036<D@Q1BU008HaP4DY@0000E2436<8@PL
ibDY008YBP8U:@0=;F/YBRU:;F/aS2U:;F/YBRDY=JdicSF];F/00R4800DU:B48:DXaS3F]008]J`0;
:DX]Jbe[;F/YBRDY8@PLib48:DXaS003;F/01cF]:DXU:BU:=JdicRe[008Q2005:DXU:B488@PYBP03
;F/01RDY;F/aS2e[9BTHaP@Q20037>LQ22U:008YBP039BTQ22U:008]J`05:DXQ2248:DX]J`02:DX2
8@P4:DX012DY8@PYBRU:0Re[00LaS3F]=Jdmkd8@AS5:DP04F]H00dYBCW<mk`02=Jd03be[<H`]Jc6<
9BTLibU:=Jdmkbe[7>LU:Be[9BTYBP029BT2:DX012e[9BT]JbU:0Re[00DU:B488@PQ22DY008Q208U
:@0A8@PLibDY:DXU:AcW8@PYBSW>?NlicS6<:DXU:BU:8@PHaP035:D011245:DHaR480RDY00DYBRe[
:DXU:BU:00<]J`039BT]Jb48008Li`078@PYBR486<HLibU:9BT00QS60R4800@LiaBU7>LQ208Li`06
8@PU:BU::DXU:B480QcW00lU:BU::DXU:AcW9BTYBRDY8@PDYAS67>LQ21cW6<H00QBU00@HaQBU6<HD
Y@<Li`8HaP8Li`04<H`e[CF]<H`28@P29BT2<H`01cF]<H`e[DicF]I[FV<H009>L`96<@08@Q0icSF]
;F/aS2e[:DXU:@<Li`0?:DX]Jc6<;F/U:BU:;F/YBQcW6<HLiaBU48@DYAS6008U:@055:D@Q0aS48@Q
2002:DX011cW5:D@Q1S60QBU00@@Q1S66<HHaP@DY@036<H@Q0aS008@Q0036<H@Q1BU00DDY@0336<<
I124008@Q00936<8@Q2336<DYAS67>LHaaS6008DY@4@Q04Ha@0000=JeU:DAS400S6<00P]JbU:=Jdm
kd8@>LhYBRe[0S6<00@]JbU:;F/aS08]J`08<H`e[Cg_>Lhe[Be[:DXaS08YBP<e[@05<H`U:BU::DXU
:@02:DX00be[<H`]J`02;F/01BDY8@PLiacW9BT00RU:00@U:AcW6<HQ208U:@<YBP04;F/YBR489BT2
<H`01RU:8@PQ22e[:DXU:@8YBP8U:@03:DX]Jc6<008YBP04;F/e[CW>>Lh2@Q001dHa@Q0icSF]<H`]
JcW>008mk`04<H`YBS6<=Jd2:DX01Re[=JdicSF]<H`e[@8icP05@Q16<DHaAS4mk`02>Lh00c6<;F/Y
BP06:DX01R487>LQ22U:8@PU:@<Q2005:DXLiaS67>LQ2002:DX28@P00acW6<HQ20028@P37>L28@P0
1BDY7>LDYAcW:DX00SW>00HYBRe[=JdYBR486<H27>L36<H01b489BTU:BDY8@PU:B48008YBP059BTL
iacW7>LU:@028@P29BT26<H01AcW9BTU:B487>L00R4800<LiaS66<H00QS60R4800@YBRDY9BTLi`<Q
20@Li`048@PU:BDY8@P57>L011S65:D@Q1BU0QS60aBU00<Lib487>L00QcW0R4800DHaR48;F/]JbDY
008HaP<Li`056<HLib48:DXe[@02>Lh04C6<CW=S66]JE[DicSg_BU9F]E:D@Q0icS6<=Je243W><H`0
1Be[00<YBR488@P00R4800DYBR488@PQ22DY008Q20037>LQ21BU008HaP057>LQ21cW5:D@Q0025:D0
31cW6<HLib487>L@Q0aS48@Lib486<H@Q0<DY@8HaP075:D@Q0aS48<DYA2548@00PaS00HDYQS57>PU
:1S76<D25:D27>L16<H00003CW<icSW>008aS003>Lhe[CW>008e[@8mk`08;F/U:AcW:DXe[C6<;F/Y
BP8]J`03=JdaS36<00<]J`0<<H`YBRDY;F/icT8@?NlYBRDY8@PLibU:0Re[00PYBRDY;F/]JbU:8@PL
ib480RU:0RDY0R4800<U:BU::DX00RU:0R4800/YBS6<<H`Q21S69BT]JbDY7>LQ22e[008U:@8Q2003
<H`icSF]008YBP0:<H`mkcF]>Li6<DYBAS4icRU:;F/2=Jd02T8@AS4mkcW>;F/U:BU:<H`icS6<0Re[
00@aS3W>>Li240=6<@03@Q0mkcg_008aS08e[@0::DXLiacW9BT]JbDY7>LQ22DY:DX29BT01B489BTU
:BDY8@P00QcW0bU:00HU:AS65:DQ21cW8@P39BT00acW8@PLi`047>L012DY:DXaS36<0be[00<YBR48
6<H00QBU11S600DLibU::DXYBRDY00<YBP@Q20059BTQ22488@PU:@027>L00aS67>LYBP02:DX011cW
6<HHaQcW0R480acW00<Q22DY8@P00QS60b4800DLiaS67>LU:B48008U:@038@PLiaS600@HaP0@5:D@
Q1BU5:DHaQBU6<HQ22DY7>LHaQBU7>LQ22DY8@P27>L28@P47>L01R489BTYBRe[=JdaS08mk`06DYAW
>EkgDY@mkd8@0U:D00]6<D8@@Q1243g_<H`e[C6<=JdaS2e[008YBP05;F/LiaS66<HLi`029BT00b48
9BTU:@029BT27>L28@P011cW6<HDYABU0QS60QcW00<HaQcW6<H00aBU00<LiaS648@00QBU00TQ21cW
6<HHaQ2436<@Q0aS5:D00PaS00TDY1BU5:D<HaBU8@PU:AcW6<H00QcW00<HaQBU5:D00ABV00003E:D
F]IJeUkgF]IF]E[FE[EJeUJeF]I>Ld8@008mk`=6<@06?Nm243W>?NlicSg_0T8@00<icSF]<H`00cF]
00@]JbU:8@PYBP8]J`<YBP03<H`]Jbe[00@]J`097>LHaQcW9BTaS2U:7>LQ22U:00@U:@078@PLib48
:DX]Jc6<9BT00QcW00DQ22U:8@PLib48008U:@8Li`069BTYBRDY9BTYBS6<0RU:00<]Jc6<<H`00RU:
00TaS2U:8@PU:Be[<H`YBRDY;F/00S6<00@]JbDY:DX]J`8aS004:DXQ22e[;F/2:DX012e[?Nm244Ha
0UJe00AJeTic>LhicP<]J`03:DXU:B48008U:@03:DXU:B48008Li`8Q2004:DX]JbU:8@P47>L29BT0
0b487>LLi`027>L58@P02AS67>LU:C6<>LhaS2DY8@PLi`028@P37>L012486<HHaQcW0RDY00@Q22U:
:DXU:@8Li`07:DXaS2e[:DXQ22DY;F/00SF]00DaS2DY9BTYBRe[008YBP066<HDYAS648@DYAcW0RU:
00HQ21S67>LHaQBU6<H27>L26<H02248:DXLia2436<HaQcW6<H37>L01B485:D@Q1245:D01AcW0b48
00XLib489BTQ21S67>LQ22U:8@PHaP8Li`0:6<H@Q1BU8@PYBR489BTYBSW>AS42BU82@Q001DYBAS52
448@AS400TYB00=6<Cg_=Jd00S6<00<YBSF]?Nl00THa0T8@00=6<D8@@Q000SF]00<]JbU::DX00RU:
00@U:B488@PU:@DQ20076<HLibDY:DXLiaS65:D00QcW00DHaR48:DXYBR4800<DY@8HaP<DY@0=5:HD
Y@aS5:DLib487>L@QA235:HLibU:8@P00AcV0003HaP01e:DBU9BU5[FHaQJeU:D009>L`05@Q0mkcW>
?Nm6<@03@Q0033W>=JdmkdYBCW=2436<;F/e[CW>=JdaS0<YBP038@PU:BU:008YBP03;F/aS2e[00<]
J`8YBP<Q2003:DXU:B4800@Q20037>LQ22U:00@U:@8]J`8Q208Li`059BTQ22488@PU:@06:DX00bDY
:DXYBP03:DX01c6<;F/YBRDY:DX]JbU:008]J`04<H`]JbU:9BT4;F/00bU:<H`aS002;F/29BT04bU:
;F/e[CF]>Li6<DYBG_MS65:DAS4aS3F]<H`U:B48:DX]JbDY008Li`039BTQ224800DQ20039BTQ21cW
008Li`048@PU:B489BT48@P27>L00bDY8@PLi`026<H01Re[=Jde[CF];F/Li`8HaP038@PYBR4800<L
i`@Q20039BTYBRDY008U:@06:DX]JbDY9BTYBRe[0RU:00P]JcF]=Jd]JbU:9BT]Jc6<0RU:00LDY@aS
48@DYBDY8@PLi`038@P01AcW5:DHaQS65:D01B4800<Lib487>L00acW00DHaQBU5:DDYAcW00DHaP03
7>LHaQS600@Q20045:DHaQcW6<H57>L26<H011BU6<HHaQcW0R4800<]JcF]AS400THa00/mkd8@AS52
44Ha?Nm244YBAS5243F]008icP8aS003=JdicTHa00E24006>Lhe[C6<<H`]JbU:0be[00<U:AcW7>L0
0acW0b4800@U:B487>LLi`8HaP8DY@8Li`04:DXU:AcW6<H25:D26<H01ABU6<HLiQBV5:@00PaS00<D
YAcW7>L00aBU00@Q22U:9BTQ1`4Ha`000cW>0Re[00HaS3F]@Q1243g_@Q02BU801EJeDYABU5[FHaP0
0W_N00Qg_G>LJeYcW6<HCW<mkc6<0Sg_0SW>00<mkbe[9BT00RDY00TaS2e[;F/]Jc6<>Lhe[C6<;F/0
12U:00<U:B488@P00RDY0RU:0RDY0QS600@Q22DY=Jde[@8YBP037>LQ22DY008U:@@Q20097>LQ21cW
7>L]JcF]@Q0mkcF]008]J`0=>Lhmkc6<:DXQ22U:=JdaS48@AS5:DTHa?Nl00T8@00De[C6<9BTYBR48
008U:@<Q2004:DXU:BDY8@P2;F/03S6<=JdmkdicE[EJeUJe@Q1:DSF];F/Q21cW9BT38@P29BT01B48
:DXYBRe[:DX00b480QcW00<Q22U:8@P00QS600@U:B487>LHaP8Li`0:6<H@Q1BU7>LU:BU:9BTQ22DY
:DX28@P01aBU6<HHaQBU6<HQ22DY008YBP@Q20039BTQ236<00<icP05;F/YBRe[;F/aS002=Jd022DY
7>LU:Be[=Jd]JacW6<H27>L012DY7>LHaR480RU:00@U:ABU6<HHaP8Li`<Q20<Li`066<HDYAcW8@PL
iaBU0Q240QcW00HQ22U:9BTLiaS67>L29BT011cW6<HHaRDY0R4800<LiaS65:D00acW0QBU00<HaR48
7>L00QBU00DLibDY7>LHaQcW008Q208U:@04;F/e[CW>BU83CW<013g_=JdaS36<0SW>00<mkcW>?Nl0
0T8@00A:DTicF]IS609JeP05DYA>LdYB@Q0mk`02;F/012DY:DXYBRU:1R4800DLib488@PLiaS600<D
Y@056<HQ22DY9BTQ20027>L031S65:DDYQBT5:DDYQcW6<HDYA246<DLi`8HaP037>LQ21S7004@Q000
0Re[0S6<00<]JcF]>Lh00SW>00@mkdYBE[EF]@9BU005E[EW>F<HLiag_@02Li`01f<HIcUF]DHa?Nla
S3W>008mk`07<H`]Jb48:DX]Jc6<;F/00RU:00D]JcF]<H`aS2e[008YBP099BTYBRe[:DXQ22DY:DXa
S2DY008Li`088@PLib48:DX]Jc6<;F/U:@8YBP8Q20039BTYBQcW008Li`8U:@0I8@PLiacW;F/e[DHa
?Nle[C6<=JdicSg_<H`YBQBU7>Le[D8@E[EBU4HaBU8mkcW><H`00RU:00@Q22DY9BTQ208U:@058@PL
iacW:DXaS002;F/01C6<>Li2448@E[D00U[F00EBU48@@Q0]JbDY008Li`<Q20049BTQ22DY9BT2:DX3
7>L01b489BTLiaS68@PU:AcW00<HaP037>LDYAS6008Q20<HaP0;8@PYBRU:9BTLiaS67>LU:B487>LH
aP025:D01aS67>LQ22DY8@PHaQcW008Q2005<H`]Jc6<>Lhe[@02;F/012U:=JdaS2e[1BU:00<]Jb48
8@P00QBU00HLib488@PLiaS69BT2:DX011cW5:DHaR480RDY00HLiaS67>LU:AcW6<H27>L00b487>LH
aP026<H011BU6<HLibU:0R480QcW00HQ22DY7>LHaQBU6<H27>L46<H27>L012487>LHaQcW0R4800LH
aQcW8@PU:AcW5:DHaP029BT3;F/00cF]>Li>L`02BU802DHa>LhaS36<>Li6<Cg_=JdicP02@Q000dHa
BU9:DP02HaP02ekgF]I:DTYBAS4e[BU:9BT]JbU:9BT00QcW00DQ21S67>LLib4800<Li`078@PDYABU
5:DHaR487>L00QS600LLib489BTQ21S65:DHaP025:D27>L01ABV48<8@`aS6<H00QcW00<HaQS55:D0
0AS60004:DX02AcW8@PU:CF]<H`icSg_AS524002?Nl01dHa>LhaS3g_AS5F]Dic009:DP9>L`=:DP=2
400?AS5BU4YBF]IW>F<HDYA:DTicG_MJeUJeDYA>Ld8@008e[@8icP06=JdaS36<;F/YBRe[0SW>00HY
BR488@P]Jcg_>Lh2=Jd2:DX29BT012489BTYBRDY0R4800PLibDY:DXYBR487>LQ22e[0SF]00<]JbU:
9BT00Re[0RDY00<Q22U::DX00RDY00<Q22DY:DX00RDY0bU:0b480QcW00@Q22U::DXU:@8Q2004;F/a
S3F]>Lh3=Jd3>Lh013F]<H`]Jbe[22U:00HQ21cW8@PU:BU:9BT27>L01b48:DXYBQcW6<H@Q1BU008L
i`058@PLiacW7>LQ20026<H01acW9BU244YB>LhYBR48008aS0099BTHaQS69BTLiaS65:DHaR48008Y
BP098@PU:BU:;F/U:BU:<H`icS6<00DYBP048@PU:AcW6<H27>L01RDY:DXaS2U:8@PLi`<Q2006:DXQ
22U:<H`e[Cg_0SF]00H]JacW7>LDYAS67>L26<H00acW6<HHaP035:D011S67>LHaQS60QBU00TLib48
6<H@Q1BU6<HQ21cW6<H00QcW0R480acW00DQ21cW5:DDYAS600<Li`8DY@0>7>LU:B487>LYBSg_AS4m
kcF]>Lhmkd8@AS52409:DP0=DYA>LdHa<H`]JbDY:DXaS2e[>LhmkcW><H`00Re[00<e[Be[;F/00be[
00<aS2e[:DX00RDY00DYBRe[;F/YBRDY008Q20036<HDYAS600<Li`8DY@036<HDYAS6008HaP0=5:DH
aQBU5:DHaA255:@DYABV5:DHaABV6<H00QBU00001Be[:DXYBR489BT00Re[00@e[C6<>Li24096<@09
?Nle[Cg_>Lhmkd8@AS5>Le:D009>L`=6<@924004>LhmkdYBCW<2HaP2E[D00dYBDYAF]@02DY@015Je
DYA:DTHa0SW>00/]JbU:;F/e[CW>;F/YBSF]?NlicRe[008Q2004;F/aS3g_<H`2;F/012U:8@PQ21cW
12DY0R4800<Lib48:DX00bU:00<U:Be[<H`00Re[00<U:B489BT00b4800@YBRe[;F/U:@8Li`089BT]
JbU::DXU:B489BTYBP8Q20037>LQ2248008Q20079BT]JbU::DXaS3F]?Nl00SF]00TaS3g_BU9242e[
8@PYBSF]:DX00R4800<aS2e[:DX00bDY0R4800<U:B487>L00QcW0R4800PLib489BTLiaS65:DHaQcW
0aS600@LiaS67>LYBP<aS009=JdicRe[8@PHaQcW8@PU:B48008Li`046<HLibDY9BT2;F/02RDY8@PU
:C6<>LhaS2U:;F/aS2U:0bDY00@YBR486<HHaP8Li`03:DX]JbDY008U:@8Q208U:@06:DXU:C6<=Jdi
cS6<0RU:00@]JbDY7>LHaP8DY@<HaP045:DHaQS65:D26<H011cW6<H@Q1BU0QcW00<HaQBU6<H00QBU
0QS60QcW0b4800LLiaS66<HLiaS65:DHaP028@P011BU36<HaR480RDY00THaQcW<H`mkdHa=Jd]JcW>
BU800THa0Tic00ABU4YB@Q0mk`8aS08YBP09<H`icT8@>Lhe[C6<=JdaS3F]008aS0<]J`@YBP06;F/Y
BRU:9BTLib480QcW11S600@DY@aS5:DHaP8Li`046<HDYABU5:D36<H01A245:D@Q1BU6<H00QBU00<H
aQBU36<00@aS00000c6<=JdicP02=Jd01Re[=JdicSF]>Li6<@9>L`A:DP03AS4icSW>00De[@8]J`03
:DX]Jbe[008]J`07<H`icSg_BU96<E:DE[D00Ukg0U[F0Ukg00MJeUJeDYABU5JeDYA>L`03AS404D8@
?NlicSg_>LhmkcF]<H`icTHa@Q0icRe[<H`e[Be[8@P00RDY00@Lib487>LQ208U:@03:DX]Jbe[008Y
BP05<H`e[Be[9BTYBP02<H`01BU:8@PQ22487>L00R4812U:00@U:AcW7>LYBP8]J`048@PLibDY<H`2
:DX2>Lh022U:8@PYBSW>=JdYBR48:DX5<H`023W>?NlaS2e[:DX]Jc6<;F/39BT00bU:;F/Q20028@P0
0bDY:DXYBP03:DX38@P37>L02aS67>LLibU:9BTYBRe[>LhmkcF]>Lh00d8@00De[BU::DXYBRe[008Y
BP8U:@8Q20039BTYBRe[008YBP05;F/e[Be[:DXQ2003:DX2;F/2:DX02QcW5:DQ22DY>Li243W>:DXL
ia240QS600<Lib487>L00RDY00LYBRe[;F/YBRDY8@PU:@027>L011S67>LU:B480RU:00@Q21S648@D
Y@8Li`066<HDYAS66<HLib480acW0QS60QcW00<U:B488@P00R480QS60QBU0QcW00DHaQcW7>LLib48
00@Li`038@P]Jbe[00<YBP04=JdicSg_AS43@Q03AS402CW>@Q1243F]:DXQ22DY:DXQ20027>L01B48
7>LLib489BT00Re[00<aS2e[=Jd00THa00TicS6<>Li244Ha?NlicSg_9BT00QS600DQ22DY8@PHaQcW
008Q200:7>LHaQS65:D@Q1S65:DHaQBU48@25:D26<H148@136<0000<<H`icSW><H`YBS6<>Li243W>
=Jdmkdic0U:D0TYB00<mkcW>=Jd013F]00@aS2e[;F/]J`<YBP09;F/e[CW>@Q0mkdHaCW=JeUJe009J
eP09HaQW>FLiE[EBU4YBDYAJeUJe009BU009AS4e[CW>@Q16<Cg_<H`]Jc6<008icP924004>LhaS2e[
;F/2<H`00bU:8@PQ20027>L00b487>LU:@049BT3;F/01BU:;F/aS2e[9BT00R480acW0RDY00/YBR48
7>LQ21cW:DXU:B48:DX]JbU:00<Q2004=JdmkcF];F/28@P012U:<H`aS36<0RU:00LaS3F]:DXYBSF]
>Lhe[@02:DX012e[9BTU:BDY0RU:0bDY00@Q21cW8@PQ20<YBP8Q20059BTYBR487>LHaP028@P27>L0
1248:DX]Jc6<1CW>00Le[CW>@Q0aS2U:7>LU:@02<H`022DY7>LQ22DY8@PYBRDY;F/3<H`3:DX042DY
:DXQ2248:DX]Jb487>LDYAS6;F/aS3g_@Q0aS2480QS600LLiaS65:DHaQcW:DXU:@02:DX012DY:DXY
BR480QcW00LQ21S65:DQ22DY;F/YBP036<H01ABU6<HDYAS67>L00R4800DHaQBU7>LLiaBU008HaP8Q
20<Li`HHaP8DY@8HaP8Q20057>LHaQcW8@PU:@02;F/2:DX00be[:DXicP02AS400d8@?Nlmk`02BU80
1dHa>LhicS6<=Jd]JbU:008U:@<Q20077>LQ21cW7>LU:Be[<H`00Re[00haS3g_@Q0mkcF]<H`e[DHa
BU92436<:DXLib480acW00<HaQcW7>L00QcW00PHaQBU48@@Q1BU6<HDYA240QBU00D@Q1BU5:D@Q0Q2
004<H`0000EBU4YBAS5F]Ekg009S6007E[EBU5JeG_MS65[FDY@00dYB00E243F];F/]Jc6<00@icP<e
[@8aS006=Je243W><H`e[D8@0Tic00@icSF]=Jde[@92408icP0:=Je:DU:DDYA6<Cg_AS5F]E[FHaP2
Kg/056<HF]I[FW_NLiaS64YBCW=F]E:DBU9243W><H`e[C6<=JdicSg_=Jd3;F/00c6<;F/]J`02<H`0
3Re[:DXYBS6<;F/U:BU:;F/YBRDY:DXU:BU:9BT3:DX38@P00bDY:DXYBP029BT28@P3:DX27>L01248
:DX]Jbe[0R4800DYBS6<?NlicS6<008]J`05:DX]JbU:8@PU:@04:DX00be[:DXU:@028@P01BU:8@PL
ib489BT00bU:00<U:BU:9BT00be[00dU:B488@PYBS6<=JdicRe[<H`mkcW>=JdU:@028@P27>L58@P0
1RDY7>LHaQS68@PU:@8Q20039BTYBRDY008Li`038@PLiaS6008Li`8YBP03;F/aS3F]00<e[@07<H`L
iaS636<DYAcW6<H00QcW0R4800DU:AcW8@PYBS6<008icP09:DXU:BU:=JdicS6<9BTQ22DY008Q2003
9BTQ21S6008DY@036<HU:B48008Q20046<HDYAS67>L3:DX01b487>LDYAcW5:D@Q1S6008Li`8DY@07
7>LYBR487>LDYAcW:DX00Re[00PYBQcW7>LLiaS6:DX]JcF]13W>0Sg_0THa00LicSF]=Je243g_<H`Q
20036<H27>L011S67>LQ22480QcW00PQ236<<H`aS2e[=JdicSg_0THa00e243g_?Nm6<Cg_=JdQ21cW
6<H@Q1S648@DY@027>L02QS648@@Q1cW8@PLia2436<DY@aS0A240003DY@014icDYAJeUkg0f<H00=J
eUJeCW<00Tic00E:DT8@?Nle[C6<00<icP07=JdaS36<>Lh]Jc6<;F/01CF]00I6<DYBBU96<CW>=Jd2
>Lh04Sg_>LhicTHaCW=BU4ic@Q16<DYBCW=S66]JKg][FV<HF]IW>@9_N`0<IcUJeTicCW=:DTHa?Nm2
43g_;F/YBS6<0SW>00@aS2U:<H`aS08]J`03<H`e[Be[008YBP8]J`05:DXU:BU::DXQ2003:DX01BDY
8@PYBS6<;F/00RU:00L]JbU::DXQ21cW8@PU:@02:DX27>L58@P29BT01BU:;F/aS36<=Jd00c6<00@]
JbU:8@PQ208YBP03;F/YBRU:008U:@038@PHaR48008YBP039BTLib48008U:@067>LYBRe[=JdYBRDY
0Re[00<Q22DY:DX00SF]00<]Jc6<=Jd00Sg_00Le[Be[9BTU:BU:8@PU:@048@P02QcW6<HLiacW9BTQ
22U:;F/YBR480QcW00DU:AcW6<HLib48008Li`8Q208aS006=JdaS2DY:DX]JacW0QBU01@HaR487>LL
ibDY7>LHaQcW8@PYBSF]>LhaS2U:8@PU:C6<=JdaS2U:0b4800@Lib487>LQ208HaP8U:@038@PHaQS6
008Q20037>LHaRDY008YBP038@PDYABU008HaP038@PHaQBU00<HaP057>LHaQS66<HQ20027>L03B48
9BTYBRDY8@PU:B486<HQ22e[?Nm243W>008e[@03?Nm6<DHa008mk`0@@Q0icSF]:DXU:B487>LQ21BU
6<HDYAS67>LQ22DY7>L28@P2:DX00be[<H`e[@02>Lh3AS42>Lh01DYB=JdU:ABU48@00QS600<DYAS6
5:D00QcW00XDY@aS36<DYAcW5:D<Ha245:D<H`48@P000dHa00A>LdYBDYABU09>L`04AS5244HaAS42
@Q0013W><H`]JbDY12U:0Re[00<aS2e[<H`00S6<00<]JbDY:DX00RDY00H]Jc6<@Q16<CW>;F/29BT0
0bU:;F/]J`02=Jd023W>=JdicT8@>LhaS2U:<H`5>Lh00dHaCW=F]@02DY@00eJeDYABU005DY@015Je
HaQS66<H0U:D00M>Le:DHaQW>F<HJeYJeP02DY@2AS42BU800dHa@Q0e[@03=Jd00cg_=Jde[@04<H`0
1be[9BTQ22DY:DXU:BU:008]J`04:DXQ2248:DX29BT03AcW5:DaS4HaBU8icR48:DXe[C6<=JdaS3F]
008aS00::DXU:Be[<H`mkcW><H`]JbU:9BT3:DX01R487>LQ22U:<H`]J`@Q20<YBP0=<H`e[Be[:DXU
:BU:>LhmkcW><H`Q22DY:DX00b4800<U:BU::DX00RDY0R480RDY12e[00<YBRDY8@P0124800HLiaBU
6<HU:Be[:DX27>L01BU:<H`]JbU:8@P00QBU0Q240aS60QBU00lHaRDY7>LLib48;F/YBR48:DXe[C6<
;F/Lib489BT00R4800<LiaS66<H01B480QcW0R4812U:124800<LiaBU5:D00aBU00@HaQcW7>LQ208U
:@8Li`069BT]Jc6<:DXLib480acW00<HaQcW7>L00RDY00T]Jd8@BU9243F]<H`icUJeF]H00UJe00E:
DSW>;F/Q21cW008Q20056<HDYABU6<HLi`026<H01QBU6<HLibDY:DXU:@DYBP06;F/YBR487>LHaR48
1QcW0QBU0QS600<LiaS65:D00Q240@Q20@aS00001DicDYA>LdYBDY@00Tic0dYB00A6<D8@?Nm6<@8m
k`8aS08U:@048@PYBRe[<H`2;F/01BU:;F/aS2e[:DX00R4800dU:B48<H`icT8@AS4e[Be[9BTLibU:
;F/e[@02>Lh2=Jd0136<;F/aS2e[0SF]00@mkc6<=Jdmk`9>L`05BU9>Le[FF]IF]@04DY@01eJeDYAJ
eV<HG_MS65kg00ABU005G_MS66<HG_MF]@02DY@01TYB@Q16<DYBAS4mk`8aS006>Lhe[CW>?NlicSF]
0S6<00<]JbU::DX00bDY0RU:0RDY00`YBRe[9BTQ21S67>L]Jc6<?NlicS6<;F/2:DX023F]>LhicS6<
;F/YBRe[<H`2;F/2<H`013F]<H`aS2U:0RDY00@Q22DY9BTU:@<YBP069BTLiaS67>LQ22DY0R4800PY
BS6<;F/YBSF]>LhmkcF]0RU:00PU:BU::DXU:B48:DX]JbU:1BDY00HQ21cW:DXe[CW>;F/28@P01bU:
8@PLiacW8@PYBR48008U:@03:DXU:B4800<Q20039BTQ21cW00@DY@<Li`076<HDYAS67>LU:BU:;F/0
0RU:00LQ236<=JdaS2486<HLi`02:DX01bDY5:D@Q1S68@PYBRDY008Li`0;8@PU:BDY8@PU:Be[<H`]
JbDY6<HLi`046<H25:D26<H01B489BTYBRDY:DX00R4800/YBRe[=Jd]Jb48:DXQ21S65:DHaRDY008Q
2004<H`icT8@?Nl2=Jd014HaCW=F]EJe0Tic00A243F];F/HaP8Li`<Q20036<HLiaS600<HaP<Li`03
8@PU:Be[008]J`03:DXU:B4800<Q208Li`036<HLiacW00<Li`8HaP<@Q08DY@<<H`4DY@000T8@00Tm
kcF]=Je244HaDYAF]D8@<H`00Re[00/icS6<8@PLib489BTYBRDY7>LQ22DY00@aS007;F/aS36<<H`]
JbDY8@P00RU:0S6<0Re[00<aS2e[;F/012U:0S6<00@]JcF]<H`aS08]J`DaS004:DXU:BU:=Jd2>Lh2
;F/2=Jd00d8@BU9:DP03@Q001TicDYA>Le:DF]INm`=JeP9W>@MS600;F]IS66<HG_M[FW_NOomcW5Je
>Lhe[@02;F/01CF]<H`]JbU:;F/00S6<00H]JbU::DX]JbU:9BT28@P2:DX02C6<;F/aS3F]>Lhe[C6<
:DX]J`02:DX2=Jd013W><H`aS3g_0SW>00<e[C6<>Lh013F]00/icSg_>LhaS2489BTQ22DY:DXU:BU:
008]J`03:DXQ224800<YBP8U:@8Li`8U:@08;F/YBRDY8@PYBRe[<H`U:@8Q2005:DXe[CF]:DXQ2002
9BT00c6<=Jd]J`029BT02B489BTQ22487>LQ22DY8@PU:@058@P01acW9BTYBQcW5:D@Q1BU00DLi`8Q
200;9BTYBRU::DXU:BU:7>LHaQBU6<HLi`028@P27>L012489BTQ22480QBU00PHaQcW:DXU:BU:9BTQ
22DY0bU:0QcW0QS600HLiaS67>LHaQcW:DX2;F/02BU:<H`icSg_>LhYBRDY7>LHaP047>L00b487>LL
i`027>L012U:;F/icSW>0THa00]:DTicDYA:DTHaBU96<D8@>LhU:B48008HaP038@PLiaS6008HaP03
5:DLibDY008U:@058@PLib487>LHaP0248@00aBU6<HLi`026<H27>L00aS65:D@Q0025:D00aS65:D@
Q00248@35:D00004>Li2448@@Q02>Lh01CF]@Q16<DHa>Lh00SF]00DicS6<9BTLib48008U:@<Q2003
9BT]JcF]008icP03=Jd]Jbe[008U:@058@PU:BU:;F/YBP039BT00be[:DX]J`02:DX2<H`3=Jd3;F/2
:DX2<H`2;F/3:DX0236<=JdaS36<;F/YBSF]?Nl3BU80148@AS5:DU:D0dic00=BU5[FG_L00V<H00MN
mf<HIcUS65[FE[EJeP02HaP02VLiHaQW>F<HIcUg_G>LG_M:DRU:0c6<00@]JbU::DX]J`@aS003;F/Y
BRU:008U:@<Q2003:DXe[C6<008aS003;F/aS2U:00<]J`<aS08e[@0;>LhmkcW>;F/aS3g_AS4e[Be[
:DXaS002?Nl01Be[:DXQ2248;F/00RU:0RDY00DLib489BT]Jb48008Li`049BTYBRDY9BT28@P01RU:
;F/]Jbe[:DX]J`<YBP038@PU:BDY00<YBP068@PU:BU:;F/aS2e[0R4800@Lib487>LLi`@Q208Li`0?
8@PU:Be[:DXQ21S69BTHaQ245:DHaRDY7>LHaQcW00<U:@8Li`048@PU:BU:8@P57>L26<H37>L26<H3
5:D27>L01R48;F/YBRU:8@PU:@8YBP079BTHaQ245:DHaRDY8@P00QcW0RDY00@YBRe[;F/e[@8icP03
<H`U:B48008HaP048@PLib487>L48@P00bDY:DX]J`02>Lh00dHaBU9>L`02DY@01TicBU96<D8@>Lha
S08Li`8HaP067>LHaQS66<HLiaS60QcW0R480QcW00<Q21cW7>L00aBU00@@Q1S66<HHaP8DY@8@Q004
6<HDYAcW7>L25:D236<248@16<h00007;F/YBRe[;F/YBS6<>Lh00S6<00@YBS6<>LhaS08e[@04>Lhe
[BU::DX2<H`01bU:;F/e[DHa?Nle[C6<008e[@03>LhaS2e[008]J`8aS08YBP0;;F/e[D8@CW=:DT8@
>LhYBRDY:DXaS002>Lh00be[:DX]J`02<H`2:DX012DY;F/e[C6<0Re[00/Q21S68@PYBSF];F/U:CF]
?NlicS6<008YBP03<H`]Jc6<00@e[@8mk`<icP<mk`9:DP0;HaQ[FV]JIcUJeVLiKg][FV<HE[EBU004
BU8014Ha@Q12448@0dHa00=243W>=Jd00c6<00<e[Be[;F/00S6<00D]Jc6<=Jdmkc6<00<]J`03=Jdi
cSF]00@e[@05;F/YBRe[;F/aS002;F/2:DX00c6<;F/YBP037>L01B489BTQ21cW8@P00RU:00DU:AS6
6<HLib48008U:@8Li`059BTQ22DY8@PLi`028@P29BT01B487>LQ21cW8@P00RU:0b480bDY014Q21S6
6<HLiaS648@HaRDY=Jd]JacW5:DLibU:;F/e[BDY008HaP047>LQ22487>L26<H28@P00acW8@PQ2002
7>L28@P2:DX29BT01AcW5:DDYABU6<H00QBU11S600<DYAS66<H00QS600<@Q1S67>L00RDY0b4800DD
YA245:DLib4800<Li`8Q200?:DXQ22DY;F/icSg_>LhYBRe[9BTLiaS68@PU:AcW008DY@056<HQ21cW
8@PU:@02:DX00be[=JdicP02=Jd00cg_AS56<@02@Q001Cg_@Q1242e[:DX00QcW00@Q21cW7>LHaP@L
i`036<HQ2248008Q20055:D<H`aS5:DLi`025:D01A245:DDYABU6<H00QcW00LQ21S66<HHaQBU7>LH
aP015:H00004<H`YBRU:;F/3<H`00be[:DXaS006=Jd5<H`00bU:;F/aS002?Nl01CF]>Lhe[CF]<H`0
0RU:00HaS3F];F/YBR489BT2>Lh03D8@BU92436<;F/Q22DY?Nm243W>=JdYBR48008]J`8e[@03;F/Y
BRe[00<YBP8]J`8U:@04:DXaS36<<H`5;F/012U:;F/]JcW>0cF]0SW>00XmkcW>>LhicT8@BU9BU5Je
DYAS609_N`08IcUNmfLiKg]cW6<HDYA:DP8mk`05CW=:DTicAS4mk`04@Q001CW>=JdaS3F]>Lh00cF]
00<aS2e[<H`00SF]00<aS2U::DX00Re[00HaS3W>=JdaS2e[<H`3=Jd2;F/2<H`00cF];F/]J`03;F/0
12U:7>LQ22DY1B4800TU:BU:9BTQ21cW8@PU:BU:9BT00b480QcW0R480RU:0R4800<HaQcW8@P00R48
00LU:B488@PLib48:DXQ20027>L38@P03acW6<HQ22U:;F/YBRDY7>LYBS6<=JdYBR485:DHaP027>L2
8@P00acW8@PQ20028@P02AS67>LLiacW:DX]JbU:8@PHaP028@P00acW6<HDY@026<H00acW6<HDY@02
5:D66<H38@P012DY8@PQ22480QS600PQ22U:9BTLiaBU6<HQ22DY0bU:0SF]00@icS6<:DXU:@8Li`03
8@PLiacW008Q208Li`056<HLibDY8@PaS002=Jd03SW><H`e[CW>AS5:DTHa@Q0mkcW>?NlicRe[:DX3
7>L02R489BTHaQS65:DLib487>LHaQcW0QBU00<@Q1BU6<H00QBU0a2400<DYA2448@00aS60aBU00@H
aR488@PHa@4DY@0000D]Jc6<;F/]JbU:00<U:@03;F/aS2e[00D]J`8U:@038@PYBRU:008YBP06;F/Y
BRU::DX]Jc6<0RU:00<U:BU:=Jd00SW>00D]JbU:;F/icS6<008icP09@Q0mkcW>:DXU:B48:DXicSF]
008aS003:DXU:Be[00@YBP0>=JdaS36<;F/Q21cW:DXe[Cg_<H`YBRe[=JdaS0<YBP@]J`@YBP8]J`03
<H`e[CF]008icP=24003?Nm243g_009:DP03DYA:DTHa008mk`03>Lhmkcg_00<mk`0;BU9BU5JeF]IF
]DYBCW=:DUJeDYA>L`02AS401TYBCW=:DTHa>Lhmk`924003?NlicSF]00@aS0D]J`0;:DXU:AcW:DXm
kd8@?NlaS2DY;F/YBP058@P87>L26<H011BU7>LQ22480QcW00<HaR488@P00b4800PLiaS67>LQ22DY
8@PLiaS60acW0aS600<DYAcW7>L00acW0R48014HaQBU7>LQ22U:8@PU:BU:6<H@Q0aS6<HLiaBU36<D
YAcW008HaP075:D@Q1BU48@LibDY8@P00QBU00<HaR485:D00Q2400<HaQcW6<H00QcW0R480QBU0Q24
1QcW0R480QcW00HHaQcW7>LQ21cW8@P27>L36<H02AcW8@PQ22e[<H`e[CW>:DXU:@027>L69BT8:DX3
8@P2:DX022e[=JdicTHaCW=6<Cg_<H`2=Jd012e[9BTQ22480QS600@LibDY9BTQ208DY@046<HLiaS6
5:D248@36<H0212436<8@PaS6<HLib486<H248@16<H17>L16<H00009;F/aS3F]<H`]Jb489BTYBRDY
008YBP<]J`07:DXU:BDY9BTYBRDY:DX00Re[00@aS2U:;F/]J`@YBP8]J`08<H`e[C6<=JdYBRDY<H`i
cP96<@0:?NlicSF]:DXQ22U:<H`e[C6<9BT3:DX2;F/00c6<;F/YBP03;F/012U:9BTU:BU:0Re[00LY
BRDY;F/aS2e[:DXU:@07:DX02BDY:DX]Jc6<=JdaS2e[=JdicP02@Q0023g_>Lhmkd8@CW=BU4icAS42
?Nl2@Q02?Nl2>Lh023g_AS5BU5:DCW=:DTicDY@2F]H01dYBAS56<DYBE[EBU4Ha008mk`08>Li243g_
>Lhe[C6<;F/YBP8]J`05<H`YBRU::DX]J`03:DX01c6<=JdicSW><H`]JbU:008U:@068@PU:AcW6<HL
iaS60b4800@LiaBU6<HLi`8Q20037>LQ2248008Li`036<HQ224800<Q20<Li`038@PU:BDY008U:@0;
7>LDYAS67>LU:AS648@DYAcW:DXQ20025:D26<H011cW8@PU:BDY0b4800PHaQBU48@DYAS648@DYA24
1QBU0QcW11S600<LiaS65:D00Q2400@HaQBU6<HHaP8DY@8HaP8DY@037>LQ21S6008HaP038@PLiaS6
008Li`8Q20037>LQ224800@Li`088@PYBQS65:DLibe[?Nle[@8]J`068@PLiacW7>LU:B480RDY00LY
BR486<HQ22DY:DXU:@028@P29BT2:DX03be[:DXYBSF]>Li:DTHa?Nle[Be[=JdaS2DY7>LHaP028@P0
0acW9BTQ20028@P01ABU6<HHaQS65:D00Q240QBU00PHaQBU48@DYA2436<DYAS60QcW0aBU0Q240002
=Jd00c6<=Jde[@02>Lh04CF]<H`aS36<?Nm243g_=JdaS2DY8@PU:BU:;F/YBRDY8@P00RU:0be[0RU:
0R4800DYBRe[>LhicS6<008YBP03;F/e[CF]008]J`@YBP059BTQ22488@PLi`029BT012e[:DXU:BU:
0S6<00@YBR48:DXU:@8Q2005:DX]JbU:9BTLi`028@P39BT2:DX38@P00bU:;F/YBP028@P01RU:;F/Y
BRDY8@P]J`8icP03=Jd]Jc6<00@icP8e[@07<H`YBRDY8@PYBS6<;F/00SF]00HmkcW>@Q0mkdHaCW<2
E[D00dYBAS5:DP02AS400d8@BU9BU003DY@01UJeF]IS65[FDYAF]@9JeP06E[E:DTicBU96<D8@0SF]
00@mkdHa@Q0icP@aS003:DXU:B4800@Q20059BTYBRU::DXU:@02:DX012DY8@PQ21cW0R480QcW00@H
aQcW9BTQ208U:@058@PLiacW7>LU:@028@P27>L01QS67>LYBRe[9BTLi`8DY@@Li`8HaP8Li`0?6<HQ
22488@PHaQBU6<HDYA2436<DYAcW6<HDYAcW008Q20045:DHaQcW7>L25:D04QS67>LQ21cW6<HDYB48
;F/Q21245:DLic6<:DXQ22U:8@PLi`8HaP8Li`068@PU:B489BTLibDY0RU:0R4800<U:BU::DX00R48
00DU:AcW6<HLibDY008aS0059BTQ21cW7>LU:@027>L02b48:DXaS2e[:DXU:B489BTYBRe[:DX00RDY
0RU:00TQ21cW9BTe[CW>=JdicSg_AS40148@00DicSF]:DX]JacW00<HaP8Q208DY@056<HDYAS65:DH
aP0248@00aBU6<HHaP025:D00acW8@PHaP036<H248@00003=JdicSF]008e[@0;;F/aS2e[;F/aS3F]
>LhmkcW>=JdaS0028@P03BU:<H`aS36<:DXQ22U:;F/e[C6<9BTQ22DY008]J`03<H`]JbU:008YBP03
<H`e[C6<00<]J`8YBP049BTYBRDY8@P2:DX02bDY8@PLibU:;F/YBR48:DX]JbU:8@P00bU:00<Q21cW
8@P00RU:00XU:B488@PLib489BTQ22DY8@PU:@8Q208YBP048@PLiacW:DX3;F/012U:<H`aS3W>0SF]
00@aS3F]=Jdmk`8icP@YBP@]J`03=JdicT8@0096<@924004BU9BU5:DCW<2AS400dicDYABU002BU80
1E:DF]I>LdicE[D00Ukg00EF]DYBCW=F]E[F009BU004?Nle[CF]>Lh2AS4013g_<H`aS36<0SF]00H]
JbDY7>LHaQcW8@P26<H00bU:<H`]J`027>L2:DX012487>LQ22DY0R480QS600@Lib488@PLi`8Q2004
:DXQ22488@P37>L021BU6<HLibDY;F/U:B487>L26<H00acW6<HHaP026<H00aBU6<HLi`028@P01BDY
6<H@Q1245:D00QS60QBU00<HaQcW8@P00acW00DQ21cW6<HDYAS6008Li`048@PLib487>L38@P01QS6
5:DLibDY<H`YBP8Q20067>LDYA245:DQ22DY0b4800@HaQcW8@PQ20<YBP8Q20037>LU:BDY008Q2003
7>LU:BU:008]J`03:DXU:B48008Q208Li`048@PYBS6<<H`39BT022U:<H`e[Be[9BTQ21cW9BT28@P0
12U:;F/icSF]0SW>00U6<DYBBU9243F]<H`]JbDY7>L011S60QcW0QS60aBU0aS60Q2400@DYAS65:DH
aP8Li`046<HDYABU7>L26<H000039BTQ22U:008e[@8mk`05;F/YBRU:;F/icP04=Jd2?Nl023F];F/Y
BRe[:DXQ22U:<H`2AS4013g_>LhicS6<0cF]00LYBRDY9BTU:C6<=JdicP02<H`012DY:DXaS36<0RU:
00@LiaS68@PQ208YBP079BTQ22U:<H`mkcW><H`01BU:00@U:B487>LQ208YBP059BTQ21cW7>LYBP02
<H`012U:9BTYBRU:0b4800LYBR489BTQ22DY;F/aS002:DX28@P01be[=JdicRe[9BTQ22DY008]J`8Y
BP038@PU:BU:008YBP069BTYBS6<>LhmkcW>0cF]00@icT8@?Nm240=:DP06@Q0icSg_AS5>LdYB0T8@
0TYB0T8@00=:DUJeF]H00UJe00=JeV<HHaP00VLi0Ukg0TYB00<e[C6<;F/00be[00<YBS6<>Lh00SW>
0SF]0SW>00DaS2e[:DXU:BU:00<U:@0;8@PU:BDY:DX]JbDY8@PHaQcW8@PLi`026<H01B487>LLiaS6
7>L00b4800DLiaS65:DDYA24008HaP058@PYBRU:8@PLi`026<H28@P02QcW48@@Q1S6:DXQ21cW8@PY
BR480QS60R4800HLiaS66<HQ22DY:DX2<H`2=Jd012e[:DXLiacW0RU:00LaS3W>:DXLia2436<Li`02
6<H47>L00b48:DX]J`02:DX00be[<H`YBP027>L28@P01AcW:DXYBS6<;F/012U:00TQ21cW7>LHaR48
6<H@Q1BU6<H00R4800<Lib487>L00QcW00@HaQcW8@PU:@8Li`056<HLibe[<Ha:DP03E[D00dYB@Q0m
k`03>Lh013F]:DXYBR480QcW00LQ21cW5:DDYA245:DHaP025:D01AS65:D<HaBU6<H00QcW11240ABY
00000bDY;F/]J`02=Jd2>Lh013F]<H`aS2U:0SF]00PicSF]>LhicSg_<H`]Jb480bDY00P]JcW>AS5:
DT8@<H`]Jc6<0SW>00@e[BDY9BTaS08mk`03<H`U:B48008U:@077>LYBRe[:DXQ21S67>L00bDY00`Y
BRe[:DXYBSW>@Q0icRe[8@PYBRe[:DX39BT28@P00bDY:DXU:@038@P2;F/012DY7>LHaQcW0RDY00PQ
22DY:DXU:AcW8@PYBRe[0RDY00<YBS6<<H`00S6<00<]JbU::DX00RU:00@]JbU::DXYBP<U:@8YBP07
9BT]Jc6<=JdicSF]<H`00cF]00Y244YBBU9>Ld8@?Nm243W>?Nm>L`9BU007BU8mkd8@AS5:DTicBU80
0U:D0U[F0ekg0V<H00ANmeJeAS4mk`8e[@06<H`]Jbe[:DX]JcF]0SW>0S6<00@icSF];F/U:@8YBP03
9BTQ21cW008Q208YBP058@PU:BDY9BTQ20057>L48@P27>L36<H01AcW6<HDYABU6<H00acW00@Q22DY
8@PHaP8Li`8Q20046<HDYAS65:D37>L2:DX01B486<HHaQcW8@P00QcW0RDY00PQ22DY;F/e[C6<:DXL
ibDY0RU:00DaS3F];F/]JacW00<DY@8HaP8DY@036<HQ224800DYBP06;F/YBRDY9BTLib480QcW00@U
:BU::DXYBP8U:@<Q20047>LHaQS65:D27>L00b487>LLi`028@P36<H58@P27>L28@P013W>?NmBU5Je
0Tic00=6<Cg_?Nl013W>00DU:AcW5:DDYAcW00<DY@046<HLiacW6<H45:D248@26<H236<00a246<HH
aP016<H0008YBP8]J`05:DXQ22DY9BTYBP029BT00b487>LQ2002:DX02S6<:DXmkdYB@Q0aS2U:>Li6
<CW>0S6<00HicSF]<H`YBR48:DX3;F/2:DX022e[:DX]Jc6<=JdaS2e[:DX3;F/01CF]>Lhe[Be[:DX0
0Re[00dYBRDY8@PU:BU:9BTaS3W>=Jd]Jb48:DXaS0029BT02R48:DX]JbDY8@PU:AcW6<HU:BU:0Re[
00HYBRDY:DXYBRe[:DX39BT28@P03QcW8@PU:BDY8@PYBRe[8@PLiaS67>LQ22DY:DX58@P011cW8@PQ
22480RDY0RU:00@Q22U:;F/aS08]J`04<H`icSW>=Jd2<H`012e[:DX]Jc6<0SF]0RU:00<]Jc6<>Lh0
0cF]00Y245JeG_MW>F<HDYAF]DYBDYA>L`96<@05BU9>LeJeDYA>L`02DY@01TicE[EF]DHa?NlaS0<e
[@03>Lhe[Be[008]J`03<H`YBR4800<Q20039BTYBR48008DY@0348@DYAcW008Li`<HaP038@PLib48
00DQ20097>LHaQcW5:D<HaS6:DXaS2U:00<HaP075:DHaQcW8@PLiaBU6<H00QcW00@HaQBU5:DLi`8Q
20077>LHaQS68@PLiaS69BT00bU:124800HLiaS65:DDYAS65:D36<H012U:;F/aS36<0RU:0Re[00<a
S2U:9BT00acW0R4800LHaR48;F/aS2U:8@PLi`038@P011cW6<HDYAS60R480QcW00<HaQBU6<H00QcW
0QS600DLib489BTU:AS6008Li`046<HYBRe[?Nl2AS401cg_=JdaS3g_>Lhe[DHa009BU005AS4U:BDY
9BTDY@046<H25:D02AS68@PQ21BU48@<HaBU7>LHaP025:D148@000059BTaS2e[<H`e[@02:DX37>L0
0b489BTQ20028@P01RU:<H`aS3W>?NlicP<e[@03?NlicSF]00D]J`0::DX]Jc6<;F/YBRDY8@PYBRDY
;F/2<H`2:DX00bDY;F/e[@05<H`2;F/02BU:8@PU:BDY:DXaS2e[<H`]J`02<H`01Be[9BTLiacW9BT0
0bU:00<U:AcW7>L00QcW00HYBRe[<H`]JbU:9BT2:DX01Be[:DXQ22489BT00RU:0R480QcW00PQ22DY
:DXQ21cW8@PYBRDY0QcW00DU:B487>LHaR48008]J`07:DXU:B489BTYBRe[<H`00Re[0RU:00@]Jc6<
=Jde[@<]J`059BTYBRe[;F/e[@03<H`042e[:DX]Jc6<?Nm6<DicHaQW>EkgDYA>Le:DE[EBU4Ha0T8@
00A6<E:DE[EF]@9BU09F]@9:DP8icP8e[@08>Lhmkcg_;F/YBRDY<H`YBP<Q2004:DX]Jb486<H25:D0
2B486<HHaQcW8@PLiaS65:DLi`068@P57>L00aS648@Q2002;F/0124848@DYAcW0QBU00PHaQcW7>LH
aQcW8@PLiaS60QBU00LLib488@PDYA245:DQ2003:DX01R489BTU:B489BTLi`8DY@8HaP087>LHaQBU
48@DYAcW<H`]J`8aS08YBP06;F/aS36<:DXQ21cW0R4800<HaQcW8@P00RU:0bDY0R4800<LiaS65:D0
0QBU00@HaQcW8@PLi`8DY@056<HLiaS65:DLi`028@P57>L012487>LaS48@0TYB00DicS6<=JdaS3W>
0096<@9:DP06=JdaS2487>LQ21cW0QS600HLiaBU48@DYAS67>L25:D011cW6<H@Q1240QcW0ABU0@aS
000011cW9BTYBRU:0R4800<YBRDY8@P00QS600@Q22DY:DX]J`8YBP05;F/aS36<:DX]J`029BT3:DX2
9BT00b48:DX]J`05:DX02BDY8@PLib48:DX]Jc6<>Lhe[@03:DX00be[>Lhe[@02>Lh0136<9BTYBRe[
0SF]00<]Jc6<<H`00SF]0Re[0RDY00P]JbU:9BT]Jc6<;F/YBRDY2BU:00D]JbU::DXU:BU:008U:@8L
i`079BTaS36<:DXLiaS68@P00bDY0R4800<YBRDY8@P01R4800@YBS6<>LhicP8e[@03<H`icSg_008i
cP8]J`03:DXQ22U:00HYBP04;F/aS2U:8@P27>L3:DX3;F/00cF];F/e[@02>Lh02Cg_>Lhe[CF]>Lha
S3W>?Nm>L`03DY@00dicDYAF]@02DY@01eJeF]IW>FLiF]I>LdHa00924004AS5243W>>Lh2=Jd00be[
9BTU:@02:DX27>L01B48:DXYBRU:9BT012U:12DY00@Q22DY8@PLi`8HaP088@PU:BDY8@PLiaS67>LH
aP<Li`066<HDYAS67>LQ21cW0aS600<DYAS65:D00QS600<LibDY:DX00Re[00@HaQBU5:DDY@8Li`<H
aP035:DHaQBU00DHaP<U:@078@PLibDY9BTQ21S67>L00R4800DLiaS648@Q22U:008e[@03:DXU:BDY
00<Li`058@PHaQ245:D@Q0038@P37>L012486<HHaQS60QcW00<DYA246<H011cW00/U:B489BTU:Be[
=JdicSg_@Q1:DTHa009JeP06G_MJeTHa@Q0aS24811cW0QS60QcW11S600<@Q1BU6<H00AcW000012DY
:DXYBRDY0R480RDY00HQ21cW7>LQ22DY;F/29BT012e[=Jde[Be[0RDY0Re[0bU:00DQ22DY:DX]JbU:
008U:@03;F/aS2U:008Q20069BTYBRe[=JdicS6<0bU:00DicSg_@Q0mkbe[008YBP049BT]Jc6<<H`2
;F/01C6<>Lhe[C6<:DX00bDY1BU:00PaS2e[9BTLib48:DXe[C6<0RU:00@]JbDY:DXYBP8]J`039BTQ
224800<YBP069BTQ21cW8@PLibDY0QcW00DQ22U::DXLibDY008YBP079BTLib489BTQ22e[<H`00SW>
00HaS3F]?Nm243g_=Jd4;F/00bU:9BTU:@02:DX03B489BTU:C6<=JdYBRDY8@PU:C6<;F/YBRe[008i
cP06=JdicSF]>Lhe[CW>0Sg_0cF]0THa00i>Le[FG_MF]E:DBU9>Le:DBU9F]F<HIcUNme:D0TYB00I2
44Ha@Q0mkcF]<H`2;F/29BT28@P00bDY7>LQ20028@P2;F/00bU:8@PQ2002:DX022487>LQ22U:8@PL
iaS67>L26<H01B48:DXYBR485:D00aS600<LiaS66<H00aS600LLiaBU5:DDYAS67>LHaP025:D00acW
6<HLi`03:DX02AcW5:DDYA2436<@Q1cW8@PLi`025:D01AS65:D@Q1S67>L00R4800@Lib488@PU:@<Q
208HaP045:DHaR488@P27>L01248;F/]JbU:12480acW0QBU00@HaQcW7>LLi`@HaP<Li`8HaP8DY@03
8@PLib48008Li`038@PYBRDY008YBP8aS003=Jdmkd8@009:DP07E[ENme:DDY@icSF];F/00QcW00<D
YAS66<H00QS600<DYAS66<H00QcW00@DY@Q236<DY@4Li`0000XYBSF]=Jdmkd8@=Jd]JbDY8@P]J`8Y
BP<U:@07:DXicSW>?Nm243F]<H`00Re[00DaS2U:;F/]Jc6<008mk`8e[@049BTYBRDY:DX2;F/01bU:
8@PU:BU:;F/aS2U:00@U:@8YBP09;F/YBRU::DXaS3F]>Lhe[C6<00<YBP03<H`]Jbe[008YBP05;F/a
S3W>?NlicP02=Jd3;F/00c6<;F/YBP058@P29BT01BU:9BTU:BDY8@P00QcW00LQ22U::DXU:AcW5:DH
aP028@P011cW8@PYBRe[0bU:00d]Jb487>LU:Be[<H`e[BDY8@PYBS6<?NlicP02:DX01248:DX]JbU:
0R4800@U:B488@P]J`8aS003;F/Q21cW008Q2003;F/U:AcW008Q20049BTYBRDY7>L28@P01C6<=Jda
S3F]:DX00Re[00HYBRe[>Li244YBAS42>Lh01Sg_AS5BU5:DBU9>L`=BU004CW=:DTHaAS42?Nl3AS40
3Cg_@Q1:DTicAS4icSF]?Nm6<DicAS4mkdHa009:DP06@Q0]Jbe[;F/YBRe[0bU:01<Q22U::DXaS2e[
:DXU:BU:8@PU:Be[=JdYBQcW5:DLibDY8@PLi`026<H01AcW9BTLiaBU7>L00RDY0R4800LYBR486<HD
YAS67>L@Q0025:D36<H011245:DDYAS60acW00XU:AcW6<HHaR48:DXQ21S65:DHaP8Q20049BTQ2248
8@P3:DX29BT28@P01QS65:DDYAS67>LHaP8DY@/Li`056<HLiacW7>LU:@05:DX01Be[:DXQ22U:;F/0
13W>00e244HaCW=JeUJeDYA6<CF]<H`LiaS67>LU:@02:DX011S67>LHaQS60aBU00001CW>?Nle[Be[
<H`00Re[0R4800LU:B48;F/]Jc6<=JdaS003=Jd00cW><H`]J`029BT012e[<H`icSF]13W>00De[C6<
<H`]Jc6<008YBP089BTQ22DY8@PU:BU:;F/YBP8U:@8]J`8YBP07;F/e[C6<;F/e[CW><H`00Re[00<a
S3W><H`00S6<00PYBR48<H`icTHa?NlaS2e[0S6<00DYBRe[=JdaS2e[00<Q208Li`048@PYBRU:8@P2
7>L39BT28@P01BDY8@PQ22487>L00R480RDY0RU:00<Q22DY:DX00bDY00<YBSF]:DX00R4800DYBT8@
AS4e[BU:008Li`DYBP048@PU:BDY8@P2;F/012DY8@PLib480RDY0R4800DU:BU:;F/YBRDY008Li`05
9BTYBSF]>LhaS003:DX013F]<H`aS3W>0T8@00TicSg_BU9:DT8@AS5>LeJeCW<00THa00=>LdYBBU80
0dHa00A244HaAS5:DP9>L`04BU9243g_@Q02?Nl014HaBU9>Le:D0THa0SF]00laS2e[;F/YBRDY:DX]
Jb486<HYBSF]?NlaS2489BT01BU:00<Q21cW7>L00QcW0aS600PLib489BTLib487>LQ22DY0b4800@D
Y@aS48@DY@8Q20066<HDYABU5:DQ21cW0QBU00<HaQcW6<H00QS60QcW00<Q22DY8@P01AcW00@HaQcW
8@PYBP8]J`03:DXQ224800<Q208DY@0:6<HQ22486<HDYAS68@PLib487>L28@P27>L00aS67>LQ2002
8@P00bDY8@PYBP02;F/05BU:9BT]Jc6<:DXQ22U:>LhmkcF]<H`e[DYBDYANmf<HE[E:DSW>9BTYBP02
7>L01B48:DXU:B486<H00QBU00<@Q1BU5:D00AcW0002:DX02RDY;F/]Jc6<:DXU:BU:9BTQ21cW1248
00XYBRe[<H`aS2U:9BTYBRe[<H`]J`8U:@05<H`icT8@BU8icP02<H`01BDY7>LLiaS6:DX00S6<00@U
:AcW6<HYBP8aS08e[@0:;F/YBSF]?Nm6<CW>=Je244Ha@Q02>Lh01Sg_AS5:DT8@?Nle[@8icP8e[@03
;F/aS2e[00DYBP06<H`e[Be[:DXLib480QcW1B4811cW00XYBRe[<H`]JbDY:DX]JbU:8@PLi`8Q2007
9BT]Jbe[=JdicSF];F/00RDY00@YBRe[;F/aS08]J`8YBP04;F/aS2e[;F/2:DX00bDY8@PQ2002:DX0
12DY8@PU:BDY0b480bDY00TQ22DY8@PU:B487>LYBRe[=Jd00Re[00<icSF]:DX00RU:00<icSg_>Lh0
0SW>00De[C6<?NlmkdYB009>L`03BU96<CW>00<aS004=JdaS36<<H`3=Jd0236<>Li:DU:DCW=243g_
AS42?Nl2BU801fmkMkecW6]JE[E:DU:D009>L`06BU9244HaBU9243g_0Re[00<aS3F]=Jd00bU:00@]
JbDY7>LLi`8Q20039BTHaQS6008HaP8Li`@HaP<Li`8HaP035:DHaQcW008Q20035:D@Q1BU008Q2003
7>LQ2248008Li`036<HDYAcW00<Q20037>LHaQS6008Li`0>8@PLiacW7>LQ22DY:DXQ22DY;F/aS2DY
7>L@Q0<DY@0=6<HQ21cW6<HDYAcW8@PU:AcW5:DHaPaS48@00QS60R4800<LibDY8@P011cW0QS60QBU
00@HaQcW8@PU:@8Li`8YBP8icP04@Q1:DTHaBU82@Q03?Nl0136<:DXLiaS60acW0B480AcW00001bU:
;F/]Jc6<;F/YBRe[008YBP048@PHaQcW7>L3;F/00bU:;F/aS002;F/2:DX2;F/022DY:DXYBSF]?Nli
cSg_>Lh2<H`27>L01248:DXYBRU:0R4800DU:C6<<H`icSF]00<]J`08=JdicSF]=Je244YBAS4mk`8i
cP8mk`09>Lhe[CW>?Nm243W>=JdaS3F]008icP05;F/U:BDY:DXe[@03<H`012U:8@PQ21cW124800@L
ibDY:DXQ208Li`048@P]Jc6<:DX27>L02B48<H`YBR487>LU:Be[:DX]J`03<H`01BU:9BTYBRU:;F/0
0c6<00<]JbU:;F/00Re[0RU:00<U:BU:;F/012480Re[00<Q21cW7>L00RU:00HQ21S67>LU:B489BT3
7>L012DY;F/]Jc6<0SF]01LicS6<:DXYBRe[=JdmkcW>?Nm6<Cg_>Lhe[CW>AS5BU4YBCW<mkc6<=JdY
BRe[00@aS004;F/aS3g_AS43BU82AS42=Jd034YBDYA[FV<HKg]oofLiE[E244HaE[EBU09:DP05AS52
448@>Lhe[@02;F/02C6<=Jde[Be[:DXQ22DY:DXU:@028@P47>L00aS67>LHaP036<H48@P00aS65:DD
Y@026<H27>L021S65:DHaQcW9BTLiaS67>L28@P021S65:DHaRDY8@PLib487>L26<H02ABU7>LLib48
7>LHaR487>LYBP02;F/01BDY7>LHaQcW6<H00QBU00LHaQcW6<HHaQBU7>LQ20029BT00acW6<HDY@02
5:D28@P2:DX012DY8@PHaQS60QBU00<HaQBU6<H00QcW0RU:124800<]Jc6<?Nl00dHa0TYB00I6<D8@
>LhaS3W>:DX28@P01BDY:DXLiaS65:D00AcW00003SW><H`YBRU:;F/YBR487>LQ22U:8@PU:B489BT2
:DX3;F/00c6<:DXaS002;F/2:DX01BDY8@PYBRe[<H`00Sg_00A6<DYB<H`U:@8Q2007<H`]Jbe[:DXa
S3F]>Lh00Tic00I243g_;F/aS3W>?Nl3BU801D8@AS5244Ha?Nl00cW>0SF]0Re[00daS3W>=Jde[Be[
8@PYBS6<=JdaS2U:9BTYBP02;F/3:DX022DY:DXQ22DY8@PU:BU:9BT28@P04RDY;F/]JbDY8@PYBS6<
;F/YBQcW8@PaS3W>=Jd]Jb48:DXaS08e[@03:DXU:BDY008]J`06:DXaS36<?NlicSF]0S6<0SF]00Da
S2U:8@PU:BU:008U:@<Q208U:@8YBP8U:@<Q20039BTQ22e[008]J`03<H`U:B48008Li`05:DXQ22U:
9BTYBP02=Jd02CW>=JdicSW>AS5:DTHa@Q0aS0029BT03B48:DX]JbU:8@PLibU:<H`e[Be[9BTYBRe[
008aS00=;F/YBRe[=JdicRU:DYA_NgNmG_LmkdYBE[D015:D00=S66LiE[D00TYB00=F]FLiG_L00UJe
00AJeUJeE[E6<@<icP03?NlaS2U:00<U:@04:DXLiacW6<H28@P01RDY8@PQ2248:DXU:@8Li`8Q2005
5:DHaQS68@PU:@028@P01BDY7>LDYAS67>L00R480QS600DQ21cW7>LLiaS600@Q20037>LQ21cW00<H
aP077>LHaQS66<HDYAS65:D00aS60acW00LHaQcW8@PDYAS67>LU:@02:DX01R489BTU:Be[:DXQ20<L
i`036<HDYAS600<Li`<HaP037>LYBRU:008]J`<aS00>:DX]JdHaCW=W>E[FCW=F]CW>;F/Q21cW9BTQ
204Li`0000<YBS6<<H`00RDY00<Lib488@P00R480RU:00XU:BU:9BT]JcF]<H`]JbU:;F/YBP8]J`08
:DXU:BU:8@PU:C6<=Je240<mk`04:DXU:B489BT4;F/00cF]AS56<@02BU801cW><H`aS3F]BU96<D8@
0096<@08BU9243g_>Lhe[CW>=JdaS08YBP03<H`]Jc6<008aS08YBP058@PU:BU::DX]J`03:DX012e[
<H`]JbDY0R480RU:0R4800HU:BU:8@PU:BU:;F/3:DX00be[:DXYBP028@P29BT00c6<=JdaS002;F/0
2SF]>Lh]JbDY:DXaS2U:9BTYBRe[0S6<0Re[00DaS3W>>Lhe[Be[00<Q208U:@HQ20039BTYBR48008Q
20069BTQ21cW8@PU:C6<0be[00LYBR488@PLibDY8@PU:@02:DX00cW>?NlicP02=Jd00cW>AS56<@02
>Lh00c6<:DXYBP02:DX38@P00bDY:DX]J`02;F/2:DX4;F/06C6<;F/aS3g_@Q1Nmf]JF]IBU48@BU9J
eUkgF]IBU4icDYANme[FDYA>Le[FG_MBU4ic009F]@03DYA6<CW>00<icP03;F/aS248008Q200:9BTQ
21cW6<HLibDY8@PHaQcW9BT2:DX021cW6<HHaQcW9BTQ21S67>L38@P27>L00aS65:DHaP047>L26<H0
1ABU6<HLib489BT00R4800<YBR488@P00aS60QcW0R4800HDYA2436<DYAcW6<H25:D26<H27>L00b48
9BTQ20048@P012DY8@PU:BDY0R480aS600@@Q1BU5:DHaP8Q20046<HDYAS67>L3:DX032e[<H`aS3F]
;F/aS48@DYAW>F<HBU92408YBP039BTLib48008Q20000SF]00<]JbDY7>L00QS60R4800DU:B488@PU
:BU:008]J`8YBP0<;F/aS2e[:DX]JcW>AS4mkcF]<H`icSg_0T8@00<mkcW>?Nl00T8@00@aS2U:9BTY
BP<e[@03;F/aS3F]008icP0<=JdaS3F];F/U:Be[?Nm:DT8@;F/Q22U:0S6<00TicS6<:DXU:B48:DX]
Jc6<:DX00Re[0RDY00XYBRe[=JdaS2U:8@PU:BU:<H`YBP8Li`058@PU:BU::DXQ20029BT02BU:9BTY
BRU:<H`icT8@AS4icP02<H`00bDY:DXYBP02;F/00bDY<H`mk`02AS402S6<=Jde[BU:9BTLib48:DX]
Jc6<0Re[00@e[C6<<H`U:@<YBP<U:@077>LHaR48:DXaS2e[8@P00acW0bU:00@]JcF];F/YBP8U:@0;
:DX]Jbe[<H`]JbU:9BTQ22DY8@PU:@04<H`00bU:;F/YBP02:DX28@P03RDY:DXaS2e[9BTLib48:DX]
JbDY7>LQ22e[9BT2:DX02C6<>Lhe[C6<:DXe[DHaBU924002=Jd013g_=Jde[Cg_0T8@00PicS6<<H`e
[D8@E[EJeUJe0e:D00EF]E[FHaQJeUJe009S6006LiaW>E[FE[E:DT8@0cg_0SW>0RU:00DaS3W>?Nle
[BDY008Q20037>LU:AcW008Li`<Q20037>LHaQS6008Q208DY@037>LYBR48008Li`048@PYBRDY8@P2
6<H02QcW8@PU:B486<HDYAS68@PLiaS60Q240QBU0R4800XHaQ2448@HaRU:8@PHaR489BTYBP<Li`04
8@PLiacW7>L28@P00acW6<HHaP025:D37>L00aS67>LLi`039BT38@P29BT2:DX02Re[<H`aS4YBE[ES
65[F?NlicSF]0RU:000022DY;F/]Jb487>LHaQcW:DX28@P011cW9BTYBRU:0bDY0c6<00@]JbU:=Jdi
cP8mk`03>Lhe[CW>00<icP05?Nm2448@?NlicP03<H`012U:9BTYBRe[0cF]00TaS2e[=JdaS2e[:DXU
:C6<=Jd00SW>00Pe[BDY9BTYBRe[=JdaS2U:0b4800<]JbU::DX00R4800HU:BU:;F/U:Be[=Jd2;F/0
1B489BTU:BU:9BT00acW00XQ22DY8@PQ22U:9BTYBRe[:DXe[@96<@05?NlaS2U:;F/U:@028@P2:DX0
1bDY<Ha244YB?NlaS24800<YBP0=;F/YBRDY8@PYBRe[<H`]JbU:;F/aS2e[:DX00R4800XHaQcW6<HD
YBDY:DX]JbU:7>LHaP8Q20039BTYBRDY008YBP0:;F/U:BDY9BT]JbU:;F/aS2e[:DX27>L04RDY:DXQ
22e[=JdicS6<9BTYBRe[:DXU:AcW8@PU:BU:;F/U:@8Q208]J`05:DXQ21cW8@PYBP028@P01Re[=Jdi
cS6<;F/e[@924003?NlicSF]008e[@0;>Lhe[CW>?Nle[C6<;F/e[DHa@Q1BU002E[D2AS400e:DHaQF
]@02BU800eJeIcUW>@02G_L00e:DCW=:DP02>Lh00d8@AS4e[@029BT01be[?Nle[C6<=JdU:B48008L
i`058@PLiacW7>LQ20027>L01AS65:DHaQcW6<H00QBU00PHaR486<HHaQcW9BTQ21cW0QS600LLib48
8@PQ21S65:DLi`026<H011BU48@DYABU0QS600LDYAS65:D@Q1BU7>LU:@027>L00bDY<H`YBP027>L2
9BT00aS648@HaP028@P01QcW6<HLiacW8@PLi`8@Q0056<HQ22487>LQ20027>L01B487>LQ2248:DX0
0Re[00<icSF]DY@00U[F00AF]CW>=Jd]J`8Q2000\
\>"], "Graphics",
  Evaluatable->False,
  ImageSize->{344, 310},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:00001h1000`40O003h00O0`@Q00h000@Q1244
8@Q2124000@Q248U:DYB>LhQ22U:0be[00<aS2e[:DX012U:00<Q21cW8@P00QcW00@U:BU:<H`e[@8a
S005=JdaS36<;F/aS002;F/3<H`012e[:DXYBRe[0RU:0bDY00@YBR488@PLi`8Q20<Li`048@PLib48
7>L29BT00b489BTU:@039BT2:DX012e[:DXYBRU:0RDY0R4800TLib489BTQ22e[=JdicSF];F/012U:
00<]JbU::DX00bDY0b480QS600HLib488@PQ21S67>L66<H28@P012DY:DXU:BDY0R480RDY00<Lib48
7>L00R480QcW00DHaQBU6<HLib4800@HaP067>LDYABU5:DLiaBU0QS60QcW00@Q21S67>LLi`8HaP<L
i`096<HDYA2448@DYAcW6<HQ21cW008Q20057>LDYAS66<HLi`026<H00aBU6<HHaP025:D00aS65:DH
aP0448@35:D46<H01ABU6<HHaQBU6<H00R4800@LiaS67>LLi`8HaP035:DHaQBU008<H`8@Q00336<@
Q1BU00<DY@<@Q08DY@036<HDYAS600<DY@8HaP8DY@0448@DYABU5:D248@35:D00aS65:DDY@055:D2
48@26<H011cW6<HHaQcW0QS600<DYAS66<H00aS600<DYAS66<H00QS60QcW0R4800<LiaS65:D00Q24
00<<Ha2448@00QBU00DHaQBU48@<Ha24008HaP8DY@8@Q0045:DHaQBU5:D348@011BU48@DYABU0QS6
00HDYAS66<HDYA245:D26<H00acW6<HHaP026<H011BU6<HLiaBU0a2400@DYA2448@DY@<@Q0045:DH
aQBU5:D648@01ABU6<HHaQS65:D00Q2400H<Ha2448@<Ha2436<748@236<00`Q236<<H`0436<248@2
36<348@00aBU48@DY@0348@01aBU48@@Q0aS248<Ha24008DY@8@Q0<<H`<@Q00836<@Q12448@<H`Q2
36<@Q0<<H`03248<H`Q200@<H`03248<H`Q2008<H`88@P0536<@Q1BU48@8@P0236<00`Q25:DDY@02
6<H25:D01a2436<@Q0aS48@8@PaS0088@PL<H`03248<H`Q200H<H`88@P0436<@Q12436<448@336<0
10Q236<8@PaS0`Q20`aS0`Q210aS00D8@PaS36<8@PaS0088@P8<H`88@P8<H`<8@P0436<@Q1245:D9
36<4248436<00`Q236<<H`0248@336<348@236<0112436<8@PaS0Q2410aS0`Q200<@Q0aS36<00Q24
10aS0Q240`aS00<8@PaS24800`aS00<@Q0aS36<00PaS00D8@PaS36<<H`Q200<<H`<8@P<<H`04248<
Ha2448@236<2248336<724800`aS2488@P02248112412480000300048@@Q00848@0300048@@Q00<4
8@05248]Je[F@Q0Q2002;F/2:DX69BT012489BTU:BDY0RU:00DU:BU:<H`aS48@00=BU004AS4e[CF]
<H`3;F/00cF]<H`aS002<H`012DY:DXYBRU:0Re[00@U:B487>LLi`@Q208Li`8Q20037>LU:BDY00<]
J`8YBP8]J`8YBP8Q20039BTQ2248008Q20067>LU:BU::DX]JbU:0S6<00@]JbU:;F/aS08]J`04:DX]
Jc6<=Jd2;F/012487>LQ22480bDY00@LiaS66<HHaP<Q208HaP089BT]JbU:9BTHaQcW8@PLi`8U:@05
:DX]JbDY:DXLi`036<H011cW8@PQ22480QS600/Lib488@PQ22DY8@PLiaS65:DHaR48008Li`<DY@8L
i`8Q20046<H@Q1BU48@37>L01R489BTQ21cW6<HQ208Li`036<HDYAS600<Li`046<HDYAcW7>L26<H0
1ABU6<HHaQcW6<H00QBU00DHaQBU5:DHaQBU008HaP068@PU:BDY9BTLiaBU0QS600@LiaS65:D@Q08D
Y@0348@DYABU00<DY@8HaP<DY@036<HLiacW008HaP8DY@047>LHaQcW7>L36<H45:D26<H37>L35:D0
11S65:D@Q1BU11S611cW0QS60QcW00<Q21cW7>L00QS600<DYAS66<H00R4800DLib486<HHaQBU008@
Q0HDY@D@Q0045:DHaQS66<H27>L25:D248@00aS65:DDY@025:D011S67>LLiacW1aS600@DYAS66<HH
aP8DY@8HaP047>LHaQBU5:D248@011BU48@DYA240QBU00<HaQBU5:D00Q2400@DYAS66<HDY@8@Q004
5:DHaQBU48@336<01A245:D@Q0aS48@00aBU00D<Ha245:D@Q0aS00@@Q00336<8@PaS008<H`06248<
H`aS5:D<Ha240aBU00D<Ha245:DDYA24008<H`055:DHaQS65:D@Q00236<248@25:D01Q245:D<Ha24
36<8@P8<H`0448@<H`Q236<248@00`aS2488@P0236<248@236<448@00aBU48@<H`0236<348@45:D5
48@25:D01124248<H`Q20PaS0a240PaS00D8@PaS36<@Q1BU008<H`03248<Ha24008@Q0H<H`055:D@
Q0aS36<8@P0248@236<00`Q236<<H`0536<3248436<6248336<00a2436<<H`0236<448@436<01A24
2488@PaS24800PaS0PQ20PaS00<8@PaS48@00Q241@aS0`Q20`aS00<@Q0aS48@00`aS00<@Q0aS48@0
0PaS0a2400<<Ha2436<00a240PaS00<8@PaS24801`aS0Q240PaS00@8@PaS36<@Q0H<H`03248<H`aS
00@@Q00436<8@PaS248336<010Q236<<H`Q20`aS0`Q210aS000212400`0012400003124020Q21244
8@Q2<HaS648@9BT2<H`01Be[:DXU:BU:9BT012480RDY0R4800XU:BU::DXYBRDY;F]245JeIcUBU092
408]J`8YBP8aS08e[@03<H`e[C6<00DYBP039BTQ21cW008Li`038@PLib4800<Li`038@PU:BDY00LY
BP04;F/YBRDY9BT27>L38@P01AcW8@PQ22U:9BT01bU:00@]Jc6<<H`]J`8YBP07<H`e[Be[;F/Q21cW
8@P00RU:00<Q21cW5:D00QS600<Lib486<H00b4800LU:B487>LHaQcW8@PU:@028@P01bDY;F/YBRDY
8@PLiaBU00<Li`8Q208HaP8Li`069BTYBRDY8@PHaQBU1AS60QBU0QS611cW00HHaQ2448@HaQcW9BT4
8@P011cW6<HQ21cW0aBU0QcW00PDYAcW7>LQ21cW6<HLiaS60QBU0QcW00@HaQ2448@HaP@DY@036<HL
ib4800@Q208HaP045:DHaQS65:D248@35:D00aS65:D@Q0025:D76<H35:D37>L26<H00acW6<HDY@02
5:D00a245:DHaP026<H011cW6<HHaQS60QBU00D@Q1BU5:DHaQcW00<HaP8Li`038@PLiacW00<Li`09
8@PHaQS65:DHaQcW6<HLib48008Li`045:D@Q1S648@35:D00aS65:DDY@0336<00aBU48@HaP026<H2
7>L26<H00a245:DDY@036<H00aBU6<HDY@036<H00acW6<HLi`025:D36<H01acW5:DHaQS648@DYAS6
008Li`035:D@Q1BU00@@Q08DY@036<HDYABU008@Q08DY@037>LHaQBU008DY@0548@DYA2448@<H`04
48@010aS48@@Q1BU0Q2400<DYA245:D00Q2400<<Ha2448@02`aS00<@Q1S648@00Q240aBU00L<H`Q2
36<@Q1BU6<HDY@0248@336<248@736<348@020aS2488@PQ236<8@PaS248636<011BU6<HDYABU1@aS
00LDYAS65:D@Q0aS48@DY@0348@00aBU48@@Q00536<248@336<248@00`aS248<H`0348@00`aS2488
@P0236<01A2436<<H`aS48@01@aS0Q2400<<H`Q236<00`aS00@8@P@Q248<H`8@Q08<H`88@P0336<8
@PaS00@<H`0524848@aS36<@Q00936<00`Q236<<H`0236<00`Q236<<H`0836<01A245:D@Q0aS2480
10aS0PQ20PaS00<@Q1BU36<00PQ200L<Ha2436<8@PaS248<H`0348@010aS48@<Ha240PaS0PQ21PaS
0Q241@aS0`Q200D<Ha2436<<H`Q2008<H`88@P0436<@Q12448@636<5248336<224800`aS248<H`02
36<1248000H48@030008@P@Q00848@07248icW>LDY@Q22e[=Jd00S6<0RU:00@U:BU::DXYBP8Q2003
7>LQ224800<Q2006:DXU:C6<>Lhmkdic0TYB00E2436<;F/U:BU:008]J`07<H`]Jbe[;F/e[C6<;F/0
12U:0R480acW0b480RDY0R4800<U:BU::DX00RU:0Re[0RU:1BDY00<Q21cW7>L00R4800DLib489BTY
BRe[00<YBP@U:@8YBPHaS003;F/YBRU:008YBP049BTLiacW7>L29BT28@P00acW8@PU:@028@P26<H2
7>L012U:;F/YBRDY1acW12DY0QcW0R4800@YBRDY7>LQ208Li`066<HDYAS66<HDYAS60aBU0aS600TD
YAS66<HLibDY:DXU:B487>L00R4811cW00PHaQBU5:DLiaS67>LHaQcW124800<LiaS67>L00QS61ABU
0a2400<HaQBU7>L00QcW00@HaQBU5:DDY@8HaP8DY@8@Q0035:DHaQS6008DY@037>LQ21S6008HaP8L
i`036<HDYAS6008Li`086<HDYAcW8@PYBRDY7>LDY@8HaP035:DLiacW00@HaP<Li`@DY@067>LQ21cW
7>LDYAcW0QS600@DYAS67>LHaPDLi`096<HDYAS66<HLib487>LHaQBU008@Q0035:D@Q1S600<DY@05
48@HaQS65:D@Q0025:D00aS65:DHaP046<H25:D011245:DHaQcW0aBU00<HaR487>L00QBU00D@Q1BU
6<HHaQBU008@Q0036<HLiaS6008DY@8HaP045:D@Q0aS48@65:D26<H011BU6<HHaQS60QBU0aS600<D
YA2448@00Q2400DHaQBU48@DYA24008DY@@@Q0035:DHaQcW008DY@8<H`@@Q003248<H`Q200@<H`8@
Q0035:D@Q1BU008HaP035:D@Q1BU00D@Q0@<H`8DY@8@Q00636<@Q12436<8@PaS0PQ21`aS0Q240`aS
00H8@PaS5:DDYAS65:D236<248@011BU48@<Ha240aBU10aS0QBU00HHaQBU48@@Q0aS48@536<01124
5:D@Q0aS0Q2400<DYA2436<00`aS00<@Q0aS48@00`aS00<8@Q2448@00`aS0Q2400<<H`Q224801@aS
0PQ210aS0`Q210aS00<8@PaS36<01`aS00@@Q0aS36<8@P@<H`8@Q0<8@P0348@<H`aS00@@Q08<H`8@
Q00336<@Q0aS00H<H`03248<H`aS00<<H`04248<Ha2448@236<00a2436<@Q00548@436<010Q236<<
H`aS0PQ200<<Ha245:D00a240PaS00<8@PaS36<00`aS00<8@PaS36<010aS0a240QBU10aS00<8@PaS
24800PQ200<<H`Q224800PQ21PaS00001P@Q00048@00124000848@09248000@Q36<icWNmDY@YBSF]
008aS003;F/aS36<00<YBP039BTYBRDY00<Q208U:@0<8@PLib489BT]Jc6<>Lhmkd8@AS4e[C6<0RU:
0Re[0RU:00DaS3F]=Jde[C6<00<]J`07:DXU:BDY8@PHaQcW6<H00b480RDY0R480QcW00DYBS6<=Jda
S2DY008YBP039BTQ2248008U:@058@PHaQcW7>LQ20039BT01b48:DX]Jc6<:DXU:B4800<U:@8YBP0;
;F/aS3F]=JdaS2U:;F/YBRe[:DXQ20027>L01RDY:DXU:B486<HLi`8U:@098@PLiacW48@DYBDY<H`i
cS6<00@Li`078@PLiacW8@PU:BU:9BT00acW00<U:BU:8@P00b4800TLiaS65:DHaQBU6<HDYAS65:D0
1QS600<DYAcW7>L00RDY00<Q22DY9BT00R480QS600<LiaS66<H00aS600<DYAS67>L00RDY0R4800<H
aQcW8@P00R4800<LiaS648@00Q240QBU00@HaQBU5:DDY@8HaP8DY@036<HLiaBU00<DY@8@Q0055:D@
Q1S65:DHaP027>L012487>LLiacW0QS60QBU00HHaQcW7>LDYA248@P2:DX00b487>LHaP037>L26<H3
7>L01AS65:DHaQS67>L00QBU00HHaQBU9BTU:B486<H25:D26<H25:D00aS67>LLi`027>L02ABU7>LH
aQBU7>LQ22DY8@PDY@0348@35:D0112436<DYABU0QS600<DYAS66<H00QBU0Q240QS60QBU00@@Q1BU
7>LDY@8HaP087>LDYABU6<HLib486<HDY@8@Q08DY@8HaP@DY@036<HDYABU008DY@0448@DYABU5:D2
48@00aBU6<HHaP025:D00a246<HHaP026<H55:D00a245:DDY@035:D348@25:D248@00`aS6<HDY@02
5:D248@011BU48@<H`aS0Q240PaS00D@Q0aS36<8@PaS008@Q0035:D@Q12400<HaP045:D<Ha2448@2
36<248@236<248@25:D01A2436<<Ha2436<010Q200<@Q0aS36<00`Q21@aS00<8@Q245:D00QBU00<@
Q0aS48@010aS0a2400HDYA2436<<H`Q236<248@25:D348@00`aS48@<H`0236<248@236<248@236<0
0a2436<<H`0336<00a2436<<H`0836<248@A36<3248436<010Q236<@Q0aS0PQ200@<Ha2436<8@PD<
H`0348@<H`aS0088@P8<H`T@Q0035:D@Q0aS008<H`03248<Ha24008<H`0324848@Q2008<H`0348@<
H`aS00H<H`045:D@Q1BU48@436<00a2436<8@P0636<011245:D@Q1240`aS00<8@PaS36<010aS00<8
@PaS36<00`aS00L8@Q245:DHaQ2436<8@P0236<010Q236<<H`aS20Q20PaS0@Q200000`0012448@05
124020Q2124000aS<Ha[FU:D;F/2>Lh00cF];F/]J`02;F/3:DX01Re[:DXaS2e[:DXU:@@Q20079BTQ
22DY<H`e[Cg_>Lh00S6<0RU:12DY0RU:00@]Jc6<<H`]J`8YBP04<H`]JbU:7>L68@P022DY8@PLiacW
8@PLibe[:DX2<H`2:DX00bDY8@PQ20047>L28@P01AcW8@PQ21cW9BT00RU:0bDY0RU:0RDY0bU:00<U
:B489BT012DY0Re[00@U:B487>LQ20<U:@8Q20059BT]JbU:8@PHaP027>L00aS67>LHaP028@P29BT0
12487>LLiacW0RDY0b4812DY0R480acW00LHaQcW5:D@Q1BU6<HQ20037>L46<H57>L28@P29BT28@P0
11cW6<HDYABU11S60acW00LU:BU:<H`]JbU:9BTQ20029BT012486<HDYABU11S60aBU00<@Q1BU5:D0
0aBU0QS60QBU0a2400<DYAcW7>L00R4800<LibDY9BT00QcW00DHaQcW7>LLiaS600<DY@8Li`048@PH
aQBU48@26<H27>L01b487>LHaQBU6<HLiaS6008DY@046<HDYABU5:D27>L00b487>LQ20026<H25:D2
6<H02aBU6<HHaQcW6<HLiaS67>LHaQcW:DX00RDY00<DYA245:D00QBU0QS600@@Q0aS48@DY@DLi`04
6<HDYABU48@35:D011245:D@Q1S60QcW00DQ21S648@DYAS6008Q20086<H@Q1S65:D@Q1S65:DLi`8H
aPPDY@0348@DYAS6008DY@8@Q0035:DHaQBU008@Q0035:DHaQBU00DDY@8@Q0035:DHaQS6008DY@H@
Q0045:D@Q1BU5:D248@236<00aBU48@DY@0348@010aS48@@Q0aS0Q240PaS00L@Q1BU5:DHaR486<HD
Y@0236<01A245:DDYABU48@00PaS1A2400@DY@aS36<<H`88@P@<H`P8@P<<H`0548@DYABU36<8@P03
36<01A2436<@Q1BU6<H00QBU0Q2400@<H`Q236<8@P<@Q00336<@Q12400<@Q0@<H`D@Q00336<@Q124
00D<H`8@Q0<<H`8@Q00736<8@PaS36<@Q0aS248010aS0PQ20`aS0PQ200<<H`Q236<00`aS0`Q20`aS
00D8@PaS36<<H`Q200@<H`0448@<H`aS248236<0112436<<H`Q21PaS0Q240QBU00LHaQBU48@<H`Q2
36<8@P0336<00a2436<8@P0236<348@010aS248<Ha240`aS0Q2400@<Ha2448@@Q0X<H`0348@<Ha24
008@Q0H<H`<8@PH<H`03248<Ha24008@Q08<H`0448@8@PQ2248336<2248236<00a2436<<H`032480
00@48@0300048@@Q00@48@07248]JfLiDY@aS3g_>Lh00SF]0S6<0Re[00<YBRe[:DX00Re[0c6<00@U
:B488@PLi`8U:@04:DXU:BU:;F/2<H`4;F/00bU:9BTU:@02:DX012DY;F/]Jbe[0RU:00D]JbU::DXQ
21cW008Q20<U:@8Q20039BTQ21cW008Q200:9BTaS3F]<H`YBR487>LU:B487>L29BT011cW6<HHaQcW
0R4800<Lib489BT00RU:0RDY0bU:00@U:B48:DXU:@<Q20DU:@8YBP039BTQ2248008YBP038@PU:B48
00<YBP049BTQ21S67>L26<H67>L48@P012DY8@PQ21cW0R480bDY0QcW0aS600@DYAS65:DDY@8HaP05
7>LHaQS66<HDY@066<H27>L48@P27>L36<H00aBU6<HHaP026<H00aBU9BTYBP02<H`00bDY8@PU:@02
;F/00bDY6<H@Q0076<H45:D36<H00aBU48@DY@025:D348@01aBU6<HLiacW8@PLiaS600<Q208HaP<L
i`066<HDYABU6<HLiaS60QBU1QS60acW00<HaQBU6<H00aS60QBU00@HaQcW6<HHaP<Li`046<HDYAS6
5:D26<H00aBU6<HLi`028@P01aS65:DLibDY:DXU:AS6008DY@0448@DYAS66<H348@011BU6<HHaQS6
0R4800<LiaS65:D00aBU11240aS600HLiaS66<HDYAS67>L28@P011S648@@Q1BU0QS60aBU00<@Q1BU
48@00aS600@DYA245:DDY@8HaP045:D@Q1BU48@25:D00aS65:DDY@025:D01AS65:DDYAS65:D00a24
00@HaQcW6<HDY@D@Q0045:D@Q12448@25:D011245:D@Q0aS0a240`aS00@@Q1BU5:D@Q08<H`0:48@D
YABU36<HaR487>LHaPaS248248@35:D336<00a245:D@Q00448@536<01@Q236<<Ha2436<00`Q20PaS
00@8@P@Q248@Q08DY@0348@<H`aS0088@P0636<@Q1BU48@<Ha240QBU0a2410aS0Q2400<<Ha2448@0
0`aS0a240PaS00<@Q0aS48@00Q240`aS00@@Q0aS36<<H`8@Q003248<Ha2400<@Q0<<H`0748@<H`Q2
36<8@PaS24800PaS00<@Q0aS248010aS00<8@PaS36<00PaS00H8@P@Q248<Ha2436<2248010aS48@<
H`Q22PaS00<@Q0aS36<00PaS11240QBU00<@Q1BU36<00PaS00<8@PaS36<01PaS00@8@Q2448@@Q0<<
H`<@Q0<<H`D@Q0<<H`03248<H`aS00D<H`@@Q0`<H`88@P0436<@Q12436<348@336<2248336<42480
10aS248<H`aS0@Q200000`001240000312400`0024848@02124020Q2>Li[FTHa9BTe[Cg_>Lh2<H`0
0cF];F/aS005<H`2;F/2<H`00be[:DX]J`03;F/49BT00bU:9BTU:@08:DX29BT28@P01BDY8@PYBRDY
:DX01BDY00DQ22DY8@PLib48008Li`8U:@03:DX]JbU:008YBP049BTYBRU::DX27>L00aS67>LU:@03
8@P29BT28@P00bDY8@PU:@028@P2:DX00be[9BTQ20038@P39BT2:DX29BT2:DX01Be[:DXU:BDY8@P0
0RU:00HU:B488@PU:BU:9BT27>L011S67>LLiaS60QBU00TQ22e[<H`aS2DY8@PU:B486<H00QcW00<Q
21cW6<H00acW0aBU11S61AcW00<HaR486<H00aS600<Lib488@P00acW11S60aBU0QS600<LiaS68@P0
12480RDY00HYBRDY7>LHaQBU6<H47>L25:D00a245:DLi`026<H011BU48@@Q1BU1Q240QBU0QS60QcW
00@U:BU:9BTHaP8DY@HHaP047>LHaQBU6<H25:D011cW6<HLiacW0QS600<DYAS66<H021S60QBU00HL
ib488@PLiaBU48@25:D00acW8@PLi`036<H02AcW6<HHaQcW9BTYBQcW5:D@Q0026<H00aBU48@@Q003
6<H011BU6<HDYAS60acW1QS61ABU00<HaQBU6<H00QBU0QcW00DQ21S67>LLiaBU00@HaP047>LHaQS6
6<H35:D00acW5:D@Q0025:D00aS65:D@Q0025:D01A245:DHaQS65:D00Q2400LDYA245:D@Q1BU6<HD
Y@056<H01Q245:D<H`aS48@DY@8@Q08<H`0448@<Ha2436<648@236<248@01QBU48@<Ha2436<DY@8@
Q0065:DLib486<H@Q1BU112400@<Ha245:D@Q08<H`8@Q003248<Ha24008@Q088@P8@Q00336<@Q0aS
00<<H`<8@P0436<@Q12448@636<348@00`aS48@DY@0348@011BU48@@Q1241@aS0Q241`aS0a2400<D
YA2448@01PaS0a2400<<Ha2436<010aS0Q2400H<Ha2436<@Q0aS48@736<3248536<224800`aS248<
H`0236<00`Q236<<H`0248@010aS2488@PQ20PaS00<8@PaS36<00PaS00D8@PaS48@DYA2400<<H`05
48@DYAS65:D@Q00936<010Q236<@Q1240PaS0PQ230aS00<@Q0aS48@00`aS0PQ21@aS00<@Q0aS36<0
20aS00@8@PaS36<@Q0L<H`<@Q0@<H`03248<H`aS00@<H`03248<H`Q20088@P000`@Q00<000@Q0000
0P@Q00X8@P@Q000<Hc6<IcU:DRDY<H`icP8e[@8icP<]J`04<H`icS6<<H`3;F/00c6<;F/aS003;F/0
1BU:;F/]JbU:;F/00RDY00<Q22DY:DX00bDY12U:0bDY00HLib488@PQ22DY;F/29BT00acW8@PU:@05
8@P011cW8@PQ22U:0Re[00<YBRDY9BT00bU:0RDY00<Q21cW8@P01B480bDY00<YBRDY7>L00QcW00<U
:Be[;F/00bDY0QcW0R4812DY1RU:00DU:B488@PQ22DY008Q20<U:@03:DXU:B4800<HaP065:DHaR48
;F/aS2e[0RDY0R4800@Lib487>LDY@8HaP048@PLiaS65:D26<H01QBU7>LLib487>LHaP<Li`046<HL
iaS65:D36<H00acW8@PQ20047>L26<H00aBU6<HDY@036<H27>L032487>LQ21cW8@PU:BU:7>LHaQBU
6<HQ208Li`<HaP037>LHaQBU008HaP0448@DYABU5:D248@236<248@01ABU48@DYABU6<H00QcW00@U
:BU:9BTLi`8DY@077>LHaQcW6<HLiaS67>L01AS61acW00DDYAS66<HHaQcW008DY@046<HLiacW6<H2
5:D01QcW8@PLiaS648@DY@DHaP<Li`035:DHaQcW008Q20046<HDYABU48@55:D26<H25:D01AS65:DL
iacW8@P00QcW0QS600<DYAS65:D00Q240QBU0QS600LDYAS65:DDYAcW8@PLi`026<H45:D011S67>LH
aQS60QBU11S600@DYAS65:DDY@@@Q08DY@036<HDYABU008@Q0055:D@Q1BU5:D@Q0035:D46<H00aBU
48@@Q00648@536<00a245:D@Q00236<00a245:D@Q00648@010aS48@DYAcW0QS600<LiaS65:D00a24
0PaS0aBU00@@Q0aS48@<H`@@Q0@<H`8@Q0D<H`0548@<H`Q2248<H`0248@010aS48@@Q0aS0`Q21Q24
00<DYA2448@010aS112400H<Ha2436<<H`Q236<248@00`aS48@@Q00448@010aS48@<H`Q20PaS1124
0`aS00<@Q0aS48@00`aS0Q241PaS00@@Q0aS36<<H`<8@P0336<8@PaS008<H`<8@P<<H`05248<H`aS
36<@Q00436<3248336<224800`aS48@@Q00236<00`Q236<@Q00248@236<348@336<010Q236<<H`Q2
1PaS00<@Q0aS36<010aS00<@Q0aS36<01@aS00@@Q0aS36<<H`88@P0636<8@PQ236<8@QBU0Q2400<<
H`Q236<00PaS0PQ200<@Q0aS36<00`aS00<8@PaS36<00`aS0a2410aS00D8@PaS248<H`Q2008<H`03
48@<H`Q2008<H`48@P0000<000@Q124020@Q00H8@Re[F]I6<BU:<H`3?Nl01CW><H`]Jbe[<H`00cF]
00@]Jc6<;F/YBP<]J`8YBP04;F/aS2U:9BT2:DX2;F/01BDY8@PU:BDY:DX00RDY00DQ22DY9BTQ21cW
00<Q20@U:@04:DXU:BDY9BT3:DX29BT01b487>LQ22489BTQ22DY00<YBP<U:@8Q208Li`058@PU:BU:
:DXU:@038@P39BT28@P29BT6:DX29BT38@P01BDY:DXYBRU:8@P00RDY0RU:0bDY0b4800DLiaS67>LD
YB48008U:@038@PHaQS600<Q20089BTQ22DY:DXQ21cW5:DHaP<DY@036<HLib4800<Li`8Q20<HaP8L
i`056<HLib488@PLi`026<H00acW8@PQ20037>L00b487>LLi`026<H011cW6<HQ21cW11S600@LiaS6
6<HHaP8Li`<HaPLLi`<HaP8Li`066<HDYABU5:D@Q1BU112400<<Ha2436<00a240aBU00HQ22DY8@PH
aQ246<H27>L011S68@PLiaS60QBU00DHaQcW7>LHaQBU008HaP8Li`8Q20057>LDYABU48@HaP025:D3
6<H03ABU6<HHaQcW9BTQ21S65:DHaR487>L@Q1BU00<Li`8DY@046<HLiacW6<H25:D01QS648@@Q124
6<HLi`8HaP045:DHaQBU6<H25:D27>L012486<H@Q12411S600L@Q1BU6<HDYAS65:DLi`036<H37>L0
0aBU6<HHaP027>L021BU48@DYAcW6<HDYA245:D36<H01QcW5:DHaQBU48@HaPDDY@<@Q08DY@8@Q08D
Y@<Li`036<HDYABU00<DY@<@Q0035:D@Q0aS00<<H`<@Q0L<H`8@Q0045:D@Q12448@35:D01aS65:DD
YABU6<HDYAS6008@Q00336<@Q0aS008@Q0<<H`<@Q0<<H`0348@<H`Q20088@P8<H`0348@<H`aS00<<
H`<@Q0<<H`0348@<H`aS0088@P<@Q0<<H`<@Q00336<8@PaS00D<H`<@Q08<H`04248<Ha2448@636<3
48@836<00a2436<<H`0248@011BU48@DY@aS0Q2420aS00<8@PaS36<00PaS00<8@PaS36<00Q2400<8
@PaS24800PaS00D@Q0aS36<8@Q24008<H`0348@<H`aS00@8@P0336<8@PaS00D<H`0348@<Ha2400D<
H`@@Q00736<8@P@Q124<HaBU48@00PaS0`Q21PaS0`Q20Q2400D<H`Q2248<Ha24008<H`0448@8@PQ2
248436<00a2436<@Q00436<324801`aS248<H`aS248<H`Q200<<H`<@Q0<<H`07248<H`aS36<8@PaS
48@00PaS00<8@PaS36<00PaS0@Q200000`@Q00048@021240300012448@Q200048@Q2;F]S64Ha9BTa
S08e[@03?NlicSW>008e[@8]J`@aS08]J`<YBP8U:@8]J`06:DXU:BDY;F/aS2e[0RDY00@Q22DY:DXY
BP<U:@<Q20067>LQ22488@PU:BU:0bDY00LYBRDY9BTU:BU:;F/YBP029BT011cW8@PQ22DY0bU:1RDY
00@Lib488@PLi`@U:@8Q208U:@8Q20037>LQ2248008U:@07:DX]Jbe[;F/U:B489BT00R481BDY00<Q
22DY:DX00RU:00@U:B488@PU:@<Q20<Li`<U:@8Li`8Q20039BTQ21cW00<Q20047>LHaQS66<H25:D0
0a245:DHaP028@P01AcW8@PU:B487>L00QBU00<LiaS66<H01acW00DHaQcW8@PYBRDY008Q20037>LH
aQS6008HaP8Q20DHaP035:DHaQS6008Li`8HaP065:DLib489BTLiaS60QcW0aS600<LiaS66<H00QBU
0Q2400LHaQBU48@@Q0aS48@DY@0548@25:D37>L26<H25:D02QcW8@PU:AcW5:D@Q1BU6<HDYAcW0QS6
00<DYAcW7>L01AcW00@HaQBU6<HLi`8HaP085:DHaQS65:DHaR489BTQ208HaP8Li`<HaP<Li`8DY@03
6<HLiacW00<DY@8@Q08DY@8HaP035:DHaQBU008DY@036<HLiacW00DHaP045:D@Q1BU5:D26<H25:D0
11S65:DDYAS60QcW11S600@DYAS66<HLi`<DY@8HaP055:DHaQBU5:D@Q0025:D01AS67>LHaQBU48@0
0aBU00H@Q1BU6<HDYA2436<25:D0112436<<HaBU0acW00LDYA245:DHaQcW6<HDY@0748@00`aS48@8
@P0236<248@236<248@236<248@011BU48@DYA240QBU0QS60QBU00@@Q1S65:D@Q0<<H`<@Q08<H`@@
Q08<H`08248<H`aS248<Ha2436<8@P8<H`0548@<H`aS36<DY@0248@01@aS48@<H`aS24801`aS0Q24
0PaS00@@Q0aS36<@Q0@<H`8@Q0<<H`0348@<H`aS00<<H`03248<Ha24008@Q0@<H`0548@<H`aS48@<
H`0548@01@aS48@@Q1BU48@010aS00<8@PaS36<00Q2400@<H`Q236<8@PL<H`88@PP<H`0348@<H`aS
008<H`@8@P8<H`0424848@Q236<348@00`aS48@<H`0336<348@00`aS48@<H`0536<00a2436<@Q004
36<2248236<224800`aS248@Q00736<3248336<224800`aS48@<H`0224800`aS248<H`0236<010Q2
36<8@PQ21PaS0Q2400<<Ha2448@00`aS00<8@PaS24800PaS00H@Q0Q2248<Ha2436<2248000<48@03
00048@@Q00848@0824848@0036<aS6]JDY@]J`8aS003;F/aS36<00<aS08e[@8aS0<]J`04<H`]JbU:
9BT2;F/2:DX28@P012U:;F/aS36<1RU:12DY00<Q21cW8@P00R480bDY0RU:00<]JbU::DX012DY00DY
BRe[;F/YBRDY008YBP06;F/aS2e[:DXU:AcW0b4800XU:B48:DXYBR489BTQ21cW8@PU:@8]J`039BTQ
2248008Q20039BTQ22U:008]J`04:DXU:BDY:DX4;F/00bU:9BTU:@02:DX01B489BTU:BDY8@P00QcW
0R4800<U:AcW7>L00QcW00@YBRDY9BTQ20<Li`038@PU:B4800<HaP047>LHaQBU48@25:D56<H01AcW
8@PHaQS648@00QS600@DYA245:DLi`DHaP<Li`DQ208HaP047>LQ22488@P47>L00aS65:D@Q0035:D0
0aS65:DHaP026<H37>L46<H37>L36<H00aBU48@@Q0025:D00aS65:D@Q00248@00aS65:DDY@025:D0
11S65:DDYAS60QBU0acW00@HaQ245:DHaP<Li`036<H@Q1S6008HaP047>LQ22487>L25:D011S67>LL
iacW0aBU0QS611BU0acW00<HaQBU6<H00R480QS600@LiaS66<HHaP<Li`8DY@8@Q08DY@8HaP<DY@03
6<HDYABU00<HaPHDY@0848@DYAS67>LHaQ245:D@Q08DY@096<HLiacW5:DHaQcW8@PHaQ2400@DY@8@
Q08HaP<DY@076<HDYA2448@DYAcW6<H00QBU00HLiaS65:DDYAS65:D348@011BU48@DYABU0aS600HD
YAS65:DDYAS65:D26<H02QBU6<HDYABU48@<Ha2436<@Q1BU0Q240`aS00@@Q0aS36<<H`<@Q0045:D@
Q1245:D448@00aBU6<HDY@0336<448@00aBU48@<H`0248@00aBU48@<H`0336<00`Q236<<H`0436<2
24801PaS48@@Q12436<@Q0<<H`05248<H`aS36<8@P0436<348@636<348@436<448@436<00`Q236<<
H`0248@636<0112436<<H`aS0a2400<<Ha2448@00a2400<DYA245:D010aS00@@Q0aS36<8@P@<H`88
@P@<H`04248<H`aS36<2248436<0112436<@Q0aS0PQ200<<H`Q236<00PaS00<8@PaS36<00PaS00@8
@PaS36<<H`88@P8@Q0<8@P0448@<H`aS248236<01A2436<8@PaS48@00QBU00@8@PaS36<8@P<<H`06
248<H`Q2248<Ha241@aS10Q200<<H`Q224800PaS0PQ20`aS0`Q20PaS0`Q20PaS00<8@PaS48@00a24
00<8@PaS36<00a240`aS00<@Q0aS36<00PQ20`aS0@Q2000212401P0012448@@Q0008@P<48@0A248a
S6]JDY@]Jcg_>LhaS2e[:DX]JbU:;F/aS3F]>LhaS003;F/01C6<;F/YBRU:9BT00RU:0bDY0R4800@Y
BRe[=JdaS0@]J`04:DXU:BU:8@P29BT01B487>LQ22487>L00RU:00@]JbU::DXU:@@YBP<U:@05:DXU
:BU:9BTYBP03;F/01BU:9BTQ22489BT00R4800LLib489BTU:B487>LQ20039BT01B489BTU:BDY8@P0
0RDY0bU:0RDY00HQ22DY;F/aS3F];F/2:DX39BT3:DX00bDY8@PQ20027>L38@P01AS67>LU:Be[:DX0
0R4800<U:AcW8@P00R480QcW0QS60acW00DHaQBU5:DHaQBU00<HaP<Li`046<HDYABU5:D26<H25:D0
0aS67>LLi`027>L00aS67>LLi`028@P00acW9BTQ20027>L00aS67>LQ20028@P27>L012486<HHaQ24
1aBU0QS600<DYAS67>L00aS600HDYAcW7>LQ21cW6<H248@25:D011S65:D@Q1S60QBU0Q2411BU0QS6
00DLiaS65:DDYAcW008HaP<DY@<HaP<DY@036<HDYAcW008Q20037>LDYAS6008Li`046<HDYAS66<H2
5:D36<H25:D011S65:DHaQBU0aS600LLib487>LHaQBU6<HLi`036<H01AcW6<HHaQBU48@01ABU0QS6
00@@Q1BU5:DHaP8Li`035:D@Q12400@DY@8HaP<DY@056<HDYA245:DHaP025:D011S68@PU:B480QBU
00H@Q1BU5:D@Q0aS48@25:D248@00aBU6<HDY@035:D011S65:DHaQS60QBU00@HaQcW6<HHaP<@Q08D
Y@0448@DYAS66<H45:D46<H55:D01PaS48@@Q1245:D@Q0<<H`@@Q08<H`03248@Q124008DY@8@Q0DD
Y@8HaP<@Q08<H`0648@DYABU48@<HaBU0Q240PQ200<<H`Q236<03PaS0a240PaS0PQ220aS0Q240`aS
0Q2400<<H`Q236<00Q2400<<H`Q236<00a2400@8@PaS2488@P<<H`8@Q0@<H`0448@<H`aS248248@0
11BU48@<Ha240PaS00D@Q1BU5:DDYA2400<<H`0448@<H`Q2248636<3248336<524801@aS48@@Q0aS
24800`aS00@8@PaS36<<H`@@Q0@<H`88@P<<H`03248<H`aS00<<H`03248<Ha24010<H`03248<H`aS
00P<H`03248<H`aS008<H`<8@P0336<8@PaS00@8@P8<H`03248<H`Q2008<H`06248<H`Q2248<H`Q2
1PaS00<@Q1BU36<011240`aS00<8@PaS36<00PaS00001@0012448@@Q00000`@Q00/8@P001248@Re[
JeY>LcF]?NlicSF]008]J`04<H`YBRU::DX2<H`03cF]>LhmkcF];F/U:BU:;F/YBRDY:DX]JbU:9BTQ
2002:DX02bDY:DX]JcF]>Lhe[C6<:DXQ22DY:DX00bDY0R4800PU:B489BTU:BU:9BTQ22DY0bU:00HQ
21cW9BTYBRe[:DX28@P29BT3:DX29BT012489BTQ22480bDY00LQ22DY:DXYBR487>LHaP029BT00b48
9BTQ20029BT4:DX01BDY8@PU:BDY:DX00RDY0Re[00<aS2e[:DX00bU:00@U:AcW8@PLi`<Q208HaP8L
i`8U:@048@PYBRDY9BT38@P01acW5:DHaQcW8@PLiaS6008DY@8HaP057>LHaQcW6<HLi`026<H01QBU
6<HDYABU48@DY@8HaP<DY@<HaP8Li`8Q208U:@<Q208Li`046<HLib488@P27>L26<H01ABU48@DYA24
6<H00QBU00@HaQcW7>LLi`8HaP8Li`8HaP8DY@<HaP8DY@0448@DYABU5:D26<H01ABU48@<Ha247>L0
0QS60b480QS600<DYAS65:D00QS60aBU00@HaQcW5:DDY@8@Q0046<HDYAS67>L66<H37>L00aS65:DH
aP026<H348@01QS67>LLiacW6<HDY@8HaP097>LHaQBU7>LQ21cW5:D@Q1BU008HaP8DY@8HaP045:DH
aQBU6<H95:D26<H55:D248@25:D011S65:DDYABU0QcW00@HaQcW7>LLi`DHaP<DY@0348@DYA2400<@
Q0046<HLiaBU5:D248@36<H01AcW6<HHaQS65:D00Q2400@DYA2436<@Q08DY@<HaP035:DHaQBU008H
aPPDY@0536<@Q12448@<H`0248@336<248@236<248@00aBU48@@Q00248@25:D00aS65:DDY@0348@0
0aBU48@DY@0248@65:D448@:36<248@00aBU48@@Q00248@536<224801PaS48@<H`aS248<H`@@Q004
36<8@PQ236<248@236<00a2436<8@P0236<248@236<2248236<348@236<010Q236<@Q12410aS0a24
0`aS00<@Q0aS36<00Q2400<DYA2436<01`aS00D@Q0aS36<<H`Q200<<H`88@P0536<@Q0aS36<8@P05
36<010Q236<<H`Q20PaS00D@Q0Q2248<Ha24008<H`04248@Q0aS248236<01Q2436<<H`Q236<8@P8<
H`0348@<H`Q200D<H`8@Q0@<H`04248<H`Q236<2248010aS48@<H`aS10Q21@aS0`Q200<<Ha2436<0
0PQ210aS00@8@PaS36<<H`<8@P8<H`03248<H`aS008@Q08<H`03248<HaBU008HaP0348@<H`aS00D<
H`<8@P0000@48@00124000@48@0924848@@Q248e[G>LE[DYBSF]00<icP03=JdaS2e[008]J`03:DXa
S2e[00@icP04<H`YBRDY9BT2:DX69BT3:DX00be[<H`e[@03<H`00be[9BTYBP028@P01RDY:DXU:BDY
7>LQ208U:@04:DXQ22488@P29BT28@P39BT28@P01BDY8@PU:B489BT0124800HU:B488@PU:BU:;F/3
9BT28@P01RDY8@PQ22DY8@PU:@@Q20@YBP8U:@8YBP8U:@05;F/aS36<:DXU:@02:DX012e[9BTLiacW
0R480QcW00<HaQcW7>L00QcW00TQ21cW8@PU:B489BTQ21cW6<H011cW00HHaQcW6<HDYAS65:D27>L6
6<H01QBU6<HDYAS65:DHaP@DY@@HaP037>LQ22DY00@Q20037>LQ224800<Li`8Q20047>LHaQBU5:D2
6<H011BU48@DYA2411S61AcW00@HaQBU5:DDY@8HaP<DY@8@Q0075:DHaQS65:D@Q1BU6<H00QcW00@H
aQcW6<HLi`LHaP<DY@8HaP045:D@Q1BU48@35:D26<H00aBU6<HLi`047>L00aS67>LDY@025:D26<H2
48@011BU7>LLiaBU11S60QBU00LHaQcW7>LHaQBU6<HLi`025:D00a245:DDY@026<H011cW6<HDYABU
0QS60QBU00<@Q1S65:D00QBU0QS600LDYA245:DHaQBU48@DY@026<H25:D01AS67>LHaQcW8@P00QcW
0aS60aBU0Q240QBU0Q2400@<HaBU6<HLi`8DY@0348@HaQBU008HaP037>LHaQS6008DY@H@Q0036<HD
YAS6008HaP<DY@8HaP035:DHaQBU00<DY@0648@DYA2436<@Q1BU0Q2400@<H`Q248@<H`<@Q00436<@
Q1245:D448@011BU48@@Q1S60QBU0Q2400<DYA2448@01ABU00<HaQBU5:D00Q240`aS00@@Q0aS36<@
Q0@<H`0348@DYABU008DY@0448@<Ha2448@336<0112436<<H`Q20PaS00D8@PaS48@DYA24008<H`8@
Q0<<H`8@Q0`<H`<@Q00336<@Q124008<H`04248@Q0aS48@236<348@436<00a2436<<H`0448@236<0
212436<<H`Q236<@Q0aS48@536<01A2436<8@P@Q248020aS0PQ200<<H`Q236<00PQ20a2400D<H`Q2
36<<Ha24008<H`03248<Ha24008<H`88@PT<H`<@Q0<<H`0348@<H`aS0088@PH<H`05248<H`aS36<@
Q00224801P@Q2488@PQ236<8@P@<H`03248<H`aS008<H`D8@P8<H`03248<H`Q2008<H`0548@<H`aS
248<H`0248@25:D548@436<1248000D48@0@00048@@Q24848@0036<e[G_NF]HaS3W>=Jd]Jc6<;F/2
<H`012e[:DXYBRe[136<0Re[0bU:0bDY00DQ22DY9BTYBRDY008Q20039BTYBRU:00@YBP03;F/YBRDY
008YBP8]J`04:DXU:BDY9BT4:DX00b489BTYBP029BT022489BTQ22487>LDYAS68@P29BT021cW8@PQ
22486<HQ22U:;F/4:DX01Be[:DXYBRDY8@P00RDY00<Q22DY8@P00b480RDY00PYBRe[;F/]JbU:;F/U
:B480RU:00Pe[C6<;F/]JbU:<H`]JbDY0QcW0b4800<HaQcW6<H01acW00<Q21cW7>L00QcW00<HaQcW
6<H00QS60QcW00@HaQBU6<HLi`HHaP035:DHaQBU008DY@036<HDYABU008DY@066<HDYA245:DHaR48
0bDY11cW0QS600DLib488@PLiaS6008DY@047>LHaQS66<H35:D36<H25:D26<H37>L00b487>LHaP02
6<H00aBU6<H@Q00248@011BU7>LHaQBU0Q240QS60aBU00<HaQcW6<H01AS600<LiaS65:D00QBU0QcW
00<HaQBU5:D00Q2400@HaQcW8@PLi`8DY@036<HDYAS6008Li`048@PLiaS66<H25:D448@01AS67>LH
aQS67>L00QBU11S600@DYA246<HLi`8U:@036<HDYABU008DY@087>LHaQS648@DYAS65:DHaP<@Q0<H
aP055:D@Q1245:D@Q0025:D011S65:DDYABU0QS600@LiaS65:DLi`8Q20057>LDYAcW7>LDY@0248@0
11BU48@@Q1BU0acW00<DYAS65:D01QBU0acW00<HaQBU5:D011BU00<@Q0aS48@00QBU00DHaQBU5:DD
YAS600DDY@046<HDYABU5:D348@011BU48@@Q0aS11240`aS0a2400@<Ha245:DDY@<@Q0045:D@Q1BU
48@45:D00a2436<<H`025:D00acW5:DDY@025:D348@236<248@236<011245:DDYABU11240PaS00H8
@PaS48@<Ha2436<348@010aS248<H`aS0a240`aS00@@Q0aS36<@Q0@<H`0348@<H`aS00<<H`0348@<
H`Q2008<H`0348@DYA2400<<H`8@Q0<<H`8@Q0<<H`06248<Ha245:D@Q1BU0Q241PaS0a241@aS00H8
@Q245:D@Q0aS248236<4248236<00`Q236<8@P0336<2248336<248@936<248@536<010Q236<<Ha24
10aS00@@Q0aS36<8@PD<H`0348@<H`aS00<<H`8@Q08<H`88@P<<H`@8@P0336<8@PQ20088@P0336<8
@PaS008<H`@8@P0436<8@PaS36<2248336<010Q236<<H`aS0Q2400@DYAS65:D@Q0<<H`88@P<<H`00
00@000@Q124000848@030008@P@Q00848@07248e[G_NG_LicT8@>Lh00Re[00@YBS6<;F/]J`@YBP8a
S0D]J`04:DX]JbU:9BT48@P29BT01BU:9BTYBRU:;F/00RU:00@U:BU:9BTQ208YBP03;F/YBRe[008]
J`039BTQ22DY008YBP04;F/YBRDY9BT3:DX00b489BTQ20028@P57>L00b487>LQ20028@P012DY:DXY
BRU:0be[0bDY0bU:00<Q22DY8@P00QcW00<HaR488@P00RDY00<YBRe[;F/00RU:0RDY00<YBS6<;F/0
0bU:0S6<00<YBR488@P00R4800@LiaS66<HHaPTLi`<HaP058@PLiaS65:DHaP028@P011cW6<HLiaS6
0QcW00<Q21S66<H011S61aBU0aS60acW0R4800<U:B487>L00QcW0QS600HLiaS67>LLiaS67>L36<H0
1ABU6<H@Q1245:D00QS60QBU11S61AcW0QS600DDYA2448@DYA2400LDY@0348@DYA24008HaP<DY@TH
aP087>LQ21cW5:D@Q1BU6<HDY@<Li`8HaP8DY@8HaP<Li`046<H@Q1S648@236<01Q246<HHaQcW6<HL
i`@HaP037>LQ21S6008@Q0046<HQ22487>L46<H27>L25:D248@01ABU48@@Q1245:D00Q2400@HaQBU
6<HHaP<DY@8@Q0045:DHaQS66<H25:D01AS67>LLib487>L00QS60QcW00@HaQBU36<@Q08<H`0348@D
YAcW008HaP8DY@036<HDYABU008DY@046<HDYABU5:D36<H45:D26<H01ABU48@DYA246<H00QBU0Q24
0QBU00<HaQBU5:D00QS60QBU00<@Q1BU48@00a2400<<Ha2436<01@aS0Q240QBU0Q2400HDYA2448@<
HaBU6<H348@25:D00a2436<@Q0025:D011S65:DDYAS60aBU00D<Ha2448@@Q1BU00@@Q00536<@Q1BU
48@DY@0348@010Q236<8@PaS0a240PaS0Q240`aS00<DYA2436<00PaS0aBU00<<H`Q248@00Q2400D8
@PaS36<<H`Q200@<H`88@P8@Q00536<@Q0aS36<@Q00236<248@736<01@Q236<DYAS65:D01`aS0Q24
00<<Ha2436<01PaS0Q240PaS0PQ21PaS00<8@PaS248010aS0PQ21`aS00@@Q0aS36<<H`<@Q08<H`03
248@Q0aS00@<H`0348@<H`aS00D<H`88@P0536<@Q12436<8@P0236<00`Q236<<H`0636<3248010aS
248<H`aS10Q20PaS0PQ20PaS10Q200L<H`Q2248<H`Q236<8@P0336<00`Q248@<H`0248@25:D00aS6
48@@Q00636<00005124000@Q1240000312402@Q200048@aS<Ha[FTYB:DXicP02<H`012U:9BTU:B48
0RDY0bU:0Re[0S6<0RU:00<U:BU:<H`00S6<00HU:B487>LQ22U:9BT2;F/2:DX29BT032U:9BTU:B48
9BT]Jc6<=JdaS2e[=JdaS08]J`0::DXaS2e[;F/aS2e[=JdaS2e[:DX28@P00bDY8@PQ20058@P01acW
8@PQ22489BTYBRDY00<YBP069BTYBRDY;F/YBRDY0RU:00<U:B487>L01QcW00@U:BU::DXYBP8Q2004
:DX]JcF]<H`2:DX2;F/4<H`2;F/00bU:9BTQ20027>L00b486<HHaP027>L00b487>LLi`026<H01aBU
7>LLiacW6<HDYA24008HaP057>LHaQS67>LU:@028@P011S67>LHaQcW11S600DLiaS65:D@Q1BU00<H
aP035:DHaQcW00<Q20039BTLiaS600LHaP037>LHaQcW008HaP037>LHaQBU00<DY@056<HDYAS66<HL
i`025:D26<H011cW6<HLiacW0QBU00D@Q1BU48@DYA2400DDY@036<HDYABU008HaP@DY@8Q20069BTQ
21S65:DHaR480RDY00<HaQ2448@00QBU0QcW1ABU0QS60aBU1AS600DDYA2448@@Q1S6008DY@056<HL
iacW6<HDY@036<H25:D01AS68@PYBRDY7>L00QBU00P@Q1BU7>LQ21S65:D<Ha240QBU1A2400XDYAS6
6<HLia245:D@Q1BU6<HDY@8@Q0045:DHaQS66<H27>L36<H47>L011BU48@@Q0aS0a2400@DYAS65:DD
Y@8HaP037>LDYABU008HaP035:D@Q1BU008HaP8DY@<HaP8DY@056<HDYABU5:D@Q0035:D248@65:D0
0aS65:DDY@025:D248@00aBU48@@Q00248@01PaS248<Ha246<HDY@8<H`8DY@<@Q0@DY@8@Q0HDY@8@
Q0<DY@0348@DYA2400@DY@0336<@Q12400<@Q0<DY@8@Q0@<H`0348@<Ha24008<H`065:D@Q12448@<
Ha240aBU0PaS0a2400<<Ha2436<00`aS00@@Q0aS36<<H`8@Q00336<@Q124008<H`88@P0448@<Ha24
48@336<00a2436<<H`0236<248@010aS248<H`aS1a2410aS00<8@PaS248010aS00H@Q0aS248<Ha24
36<224801@aS48@<H`aS24800`aS00@8@PaS36<8@PH<H`0648@<H`aS36<@Q0aS1A2400@<Ha2436<D
Y@8@Q1<<H`03248<Ha24008<H`88@P8<H`<8@P8<H`@8@P@<H`L8@P0336<8@PaS0088@P0336<8@PQ2
00<<H`@8@P8<H`0348@<HaBU008HaP045:D<H`aS36<3248000848@0300048@@Q00H48@0936<e[FLi
AS4YBSF]>LhaS2e[008U:@048@PYBRDY8@P49BT012U:<H`]JbU:0RDY00TYBSF]<H`aS2U:8@PU:B48
9BT00RU:00<]Jc6<:DX00bDY00dYBRDY7>LU:BU:<H`YBS6<>Lhe[Be[9BTYBP02<H`2;F/4<H`3;F/2
9BT28@P39BT01AcW8@PQ22489BT00R4800<U:BU::DX00bDY0bU:00/U:BU:9BTYBRDY8@PU:AcW6<HL
iaS6008Q2004:DX]Jbe[9BT28@P00bU:;F/]J`02;F/2:DX012e[<H`aS36<0Re[00<aS2e[;F/00R48
0QS611cW0R4800@LiaBU48@HaP8Q20067>LDYABU5:DHaQcW0QBU00DHaQcW9BTQ21cW008HaP<Li`05
6<HLiacW7>LHaP025:D01QS65:DHaQBU6<HLi`DQ20046<HLiaS66<H27>L36<H37>L01aBU6<HLiaS6
5:D@Q1S6008DY@8HaP067>LHaQS66<HLiaS60QcW00<Q21cW5:D00Q2400@HaQBU5:D@Q0<DY@8@Q003
5:DHaQS6008DY@8HaP8DY@036<HLib4800<Li`056<HLiacW7>LHaP045:D36<H00aBU6<HHaP045:D0
0acW6<HHaP035:D00aS648@@Q0025:D248@00aS68@PLi`025:D01AcW8@PHaQBU48@00QBU00DQ22DY
9BTLiaBU008@Q08HaP0;7>LHaQ2448@DYA245:D@Q1BU48@DY@0248@01QS67>LHaQBU48@DY@8HaP03
5:D@Q1BU008DY@037>LHaQS600PHaP045:D@Q0aS36<248@55:D56<H00acW6<HHaP025:D01aS65:DH
aQS65:DHaQBU00@HaP8@Q0035:DHaQBU008@Q0DDY@036<HDYA2400<DY@H@Q08DY@0448@<Ha245:D2
48@236<011BU48@@Q1BU0QS600DDYA2448@DYAS600<@Q08DY@8@Q0@DY@0348@DYA24008DY@8@Q08<
H`0348@DYA24008@Q0<DY@0348@<H`Q200D<H`D@Q08<H`035:D@Q124008<H`0748@<H`Q236<@Q1BU
48@010aS00D8@PaS36<@Q1BU008@Q00536<8@PaS36<@Q00336<00a2436<<H`0224801@aS48@@Q124
36<00Q240`aS0a2400DDYA2448@@Q0aS0088@PD<H`0448@<H`Q2248536<4248536<01Q2436<8@PQ2
1248@PT<H`0348@<H`aS00D<H`8@Q08DY@8@Q0075:D<H`Q2248<Ha2436<00PQ20PaS00<@Q0aS36<0
1@aS0PQ20`aS00<8@PaS36<00PaS1@Q20`aS10Q200D<H`Q22488@PaS00<8@P8<H`88@PH<H`88@P08
36<@Q0aS248@Q1S67>LHaPD<H`48@P0000D000@Q12448@0000<48@09248000@Q248]Jekg@Q0Q22e[
00<YBP@]J`03:DX]JbU:00@U:@8YBP<U:@8YBP@]J`03:DX]Jbe[00<]J`06<H`]JbDY9BTYBRe[0S6<
0Re[00@aS3F]=Jde[@@YBP8aS003=JdaS36<00@aS00@9BTQ22486<HYBSF]?Nm2436<9BTQ21cW8@PU
:BU:9BT28@P2:DX01B487>LLibU:9BT00R480RU:00DU:B489BTU:B48008Li`039BTYBRe[008aS003
;F/YBRe[00<]J`8Q20039BTQ22DY008Q20039BTYBRDY008Q20039BTYBRDY00@Li`048@PHaQS66<H3
7>L26<H25:D46<H25:D011S65:DDYAS60QcW00<HaQcW7>L00b4800@]JbU::DXLi`8HaP8DY@076<HL
iacW6<HLiaS69BT00Re[00<U:AS65:D00acW0aS600LLiaS66<HHaQBU6<HDY@046<H25:D46<H27>L0
1AS67>LLiacW6<H00aBU00<@Q1BU5:D00Q240aBU00<@Q1BU6<H00QS600XDYAS66<HDYAS67>LYBRe[
:DXQ208HaP038@PLiaS600<DY@0348@DYABU00<DY@8@Q0<DY@0:6<HDYABU5:DHaQBU48@<Ha245:D2
6<H35:D011S68@PQ21S60Q2400DDYAS65:DHaQcW008U:@038@PLiaS6008DY@@HaP8@Q0035:D@Q124
008DY@8@Q08DY@<HaP035:DHaQBU00<HaP035:D@Q1BU008HaP0548@HaQcW8@PLi`035:D26<H00a24
36<<H`025:D011S648@<HaBU0QcW00<HaQ2448@00aS600@LiaS66<HHaP<DY@036<HLiaS600@HaPHD
Y@8@Q08DY@8@Q0045:DHaQBU5:D548@336<248@011BU48@<H`aS1A2400<<Ha2448@00QBU00DHaQBU
48@DYA24008HaP8DY@067>LDYA2436<@Q1BU0Q240QBU0a240QBU0a2400PDYA2448@HaQBU36<8@PaS
0Q2400<8@PaS24801`aS0Q2400<<Ha2436<010aS0Q240PaS00@8@PaS48@@Q08<H`03124<H`aS00X<
H`03248<H`aS008<H`0348@<H`aS00<<H`03248<H`aS00D<H`@@Q00336<8@PaS008<H`88@P<<H`88
@P<<H`03248<H`aS00L<H`0448@<Ha2448@336<2248836<00`Q236<@Q00248@236<348@00`aS48@@
Q00636<00a2436<<H`0436<00a2436<<H`03248236<224801`aS2488@PaS248<Ha24008<H`<8@P03
36<8@PaS00<8@P0536<8@PQ224848@02248010aS248<H`Q20`aS0`Q200<<H`Q236<00PQ20PaS00<@
Q0aS5:D00aBU0PaS0PQ2000312400`001240000512401@Q2;F]Nmd8@9BT00Re[0bU:00H]Jc6<;F/]
JbU:9BT4:DX01B489BTU:BU:9BT00RU:00<]Jc6<;F/00RU:00@]Jc6<=Jde[@8aS004;F/YBRU::DX2
<H`00cF]<H`]J`02<H`013F]<H`]JbU:0RDY00@YBRe[<H`e[@<aS005;F/YBRU::DXU:@038@P01C6<
?Nm243W>;F/00R480bDY0R480RU:00<Q21cW7>L00b4800@U:B489BTU:@8YBP078@PLiacW6<HLib48
:DX00cF]00<aS2U:;F/00Re[00LU:B487>LQ22DY:DXU:@048@P00bDY8@PQ20028@P67>L00aS67>LH
aP026<H02AcW6<HDYABU6<HLiaS65:D@Q0025:D36<H021BU6<HHaQcW8@PLibDY:DX2<H`01bU:8@PL
iaBU48@HaQcW008Q20046<HDYAcW9BT2;F/012DY8@PLiaS60QcW00<DYAS67>L00QcW00<DYAS67>L0
0aBU11S600DLiaS66<HHaQBU00<HaP8Q208Li`035:D@Q1BU00DDY@046<H@Q12448@56<H25:D26<H0
22489BTYBRU:8@PLiaS65:D26<H00acW5:DDY@025:D01AS65:DDYABU6<H01ABU00<@Q1BU5:D00aBU
0Q2400@DYAS66<HHaP8@Q0077>LQ22DY7>L@Q1BU6<H00aBU00DHaRDY;F/U:AcW008DY@@HaP045:DH
aQ245:D248@01ABU48@@Q1245:D00QS600<DYAcW6<H00QBU0aS600<DYA246<H00QBU00@HaQcW7>LH
aP<DY@046<HLiaS648@236<248@011S648@@Q1BU0aS600<DYA245:D00QcW00<HaQBU6<H00aS600<D
YAS67>L00QcW00<HaQBU5:D011BU0Q241ABU0Q2400<HaQcW6<H00Q240QBU0PaS00H@Q1BU36<<Ha24
5:D348@00`aS48@@Q00248@35:D021245:DHaQS67>LHaQBU48@25:D26<H448@011BU48@@Q1240aBU
112400HDYA245:DLiaS648@236<01Q242488@PQ236<@Q0<<H`8@Q0L<H`@@Q00336<@Q0aS00<<H`05
48@DYA2448@8@P0236<248@00`aS48@<H`0336<00a2436<<H`0736<248@336<00a2436<<H`0236<0
1Q2436<@Q1BU48@<H`88@P8<H`04248<Ha2436<2248236<2248236<00`Q236<<H`0536<00a2436<<
H`0248@336<00`Q236<@Q00236<010Q236<8@PaS0Q2400<DYA2448@00Q240PaS00<@Q0aS48@00`aS
00<@Q0aS48@00PaS00<@Q0aS36<010aS00D@Q0aS248<Ha24008<H`88@P8<H`03248<H`aS00<<H`<8
@P8<H`88@PD<H`<8@P0436<8@PQ2124336<00`Q236<<H`02248436<00`Q236<<H`0336<00aBU48@@
Q00236<12480000300048@@Q00D48@09248000@Q248YBU[F@Q0U:Be[00<aS004;F/aS2e[:DX4;F/2
:DX022489BTQ22489BTQ22U:;F/3<H`2;F/013F]>LhmkcW>0be[0RU:00<]JcF]?Nl00Sg_00E243g_
?Nle[C6<00<U:@<YBP03;F/aS36<008aS003;F/YBRDY008U:@038@PU:BU:00DYBP@]J`04:DX]JbU:
:DX48@P01RDY8@PHaQS67>LQ208U:@038@PLib4800<Li`8U:@8]J`8YBP<]J`04:DXQ22489BT27>L0
11S67>LQ22480QcW0QBU00PLib489BTQ21S65:DHaQcW0R480acW00@HaQBU48@@Q08DY@@@Q0035:DH
aQS600<Li`8DY@056<HLiacW7>LQ20039BT27>L25:D011S67>LLiacW0QS60QcW0RDY00LQ22DY9BTQ
21cW6<HLi`046<H00acW5:DDY@0248@25:D26<H25:D00aS67>LHaP035:D011S67>LLiacW0aBU00HH
aQBU5:DDYAS67>L26<H35:D27>L011S648@@Q1BU0QcW0b4800DU:AcW6<HHaQBU008HaP035:DHaQBU
00HDY@056<HDYA245:DHaP045:D26<H25:D248@25:D011S648@@Q1cW0RU:00<Li`aS48@00QBU0QcW
00LQ22U::DXQ21S65:DHaP027>L26<H011BU48@DYA2411BU00<@Q1S66<H00QS60QcW00HQ21cW7>LL
iaS648@35:D011S65:DHaQcW0QBU00L@Q1BU5:DDYA245:DHaP025:D00a246<HDY@025:D011S67>LL
ia240aBU00@HaQBU5:DHaP<DY@8@Q08HaP8Q20037>LHaQS6008@Q08DY@056<HDYABU5:DHaP045:D0
0a245:DHaP025:D248@011BU48@<H`aS0Q2400DDYA2436<<H`Q2008@Q00336<@Q1BU00<@Q0035:DH
aQS600DHaP8@Q0055:DLiaS65:D@Q0036<H35:D248@01@aS48@@Q0aS5:D00QcW00@DY@aS36<@Q0H<
H`0348@<Ha2400<<H`0348@<Ha2400<<H`8@Q08<H`8@Q0@<H`@@Q0`<H`0448@DYA2448@436<00`Q2
36<<H`0936<010Q236<<H`aS0Q2410aS00D@Q0aS2488@PaS0088@P0336<8@PaS0088@P0336<8@PQ2
00<<H`8@Q08<H`8@Q0095:D@Q0aS36<@Q0aS248<H`Q2008<H`0348@<Ha2400<DY@@@Q00536<8@PaS
248<H`0348@236<00a2436<8@P0236<00aBU36<<H`0436<224800`aS248<H`0336<2248010aS48@@
Q0aS0PQ200@<H`Q22488@P<<H`03248<H`aS00@8@P0436<8@PaS36<424800`aS2488@P02248010aS
2488@PQ20PaS0Q241PaS000212401P0012448@@Q0008@P<48@0<248]Jf<HBU8U:BU:=JdicT8@>Lha
S2U:0be[00@aS2U::DXYBP8U:@<Q20039BTYBRU:008YBP8aS005;F/aS3W>@Q0icP03=Jd2:DX012e[
=JdicSF]0Sg_00I243g_=JdicS6<:DX29BT01be[:DXU:BDY;F/e[C6<008]J`04:DX]JbU::DX49BT0
12U:9BTYBRU:0be[0S6<0Re[00HYBR488@PQ22U:8@P37>L58@P37>L28@P00bDY:DXYBP02;F/4:DX0
1BDY8@PLiacW8@P00acW00<Q21cW7>L011cW00@Q21cW6<HHaP<Li`8Q20067>LHaQBU6<H@Q1BU0Q24
00DDYA2448@@Q1BU008HaP8Li`056<HLiaS67>LHaP047>L38@P01QcW6<HHaQS65:DHaP8Q20037>LH
aQcW008U:@068@PU:BDY9BTQ21cW0QS600<DYAS67>L00QS600<DYA2448@00aBU00@<HaBU6<HLi`8D
Y@036<HLiaS600<HaP037>LHaQS6008HaP035:DHaQS600@HaP067>LDYABU5:DHaQcW0aS60QBU0QS6
124800DLiaS66<HHaQBU008@Q0<HaP035:D@Q124008HaP037>LDYA2400<DY@0648@DYAS66<HDYA24
11BU00h<Ha246<HHaR489BTHaQ2436<@Q1cW6<HLibU:0Re[00<Q21S66<H00QS60QcW0QBU0Q240aBU
00X@Q1BU5:DDYAS65:DLiaS67>LQ20<Li`8HaP8DY@8HaP045:DHaQBU48@45:D01A245:DDYABU48@0
0aBU00`@Q1BU5:DHaQBU6<HDYAS65:DHaQBU6<H85:D021S67>LQ22487>LHaQBU48@45:D00aS65:D@
Q00248@26<H55:D348@010aS48@@Q1BU0a2400<<Ha2448@00PaS0Q2400<DYA2448@011BU0QS600<D
YAS65:D00aBU00@HaQcW6<HDY@8@Q0<DY@0348@DYABU008DY@<@Q0<DY@8@Q0P<H`03248<H`aS00D<
H`0348@<H`aS008<H`D@Q08<H`<@Q00536<@Q12448@8@P0336<00a2436<<H`0236<348@00`aS48@<
H`0236<010Q236<8@PQ22@aS00<8@PaS36<00`aS00@8@PaS36<8@P<<H`03248<H`aS008<H`@8@PP<
H`@@Q0@<H`8@Q08<H`03248<H`Q2008<H`8@Q0036<H@Q1BU00<<H`0348@<H`aS008<H`0348@<Ha24
00<<H`0348@<H`aS00@<H`0448@<H`Q2248636<2248236<00a2436<<H`0236<00`@Q2488@P0236<0
10Q236<8@PaS1PQ20PaS00@8@PaS36<@Q08<H`03248<H`Q200H<H`88@PL<H`0000D000@Q12448@00
00<48@0924848@00248]Je[F@Q0]JcF]008mk`05>Lhe[Be[<H`icP02<H`00bU:;F/YBP029BT2:DX0
0bDY8@PQ20029BT00bU:;F/aS002<H`2>Lh01Sg_@Q0icSW>=Jdmk`924009?NlicSW>=JdaS3F]>Lhe
[C6<008U:@04;F/YBRU:<H`2>Lh00cF]<H`aS002:DX28@P39BT01bU:9BTLiacW9BTYBRe[008YBPD]
J`03:DXU:BDY00@U:@037>LQ2248008Q20039BTLib48008Li`<Q20049BTQ22487>L28@P3:DX01RDY
8@PU:Be[:DXQ20<Li`036<HLiaS600<Li`048@PLiaS67>L26<H28@P01AS65:D@Q1BU6<H00Q240QBU
0Q2400<DYAcW6<H02QcW11S611BU0QS600LQ21cW7>LLib489BTQ20037>L2:DX012DY6<HLiaS60QcW
00DHaQBU5:DHaQ24008DY@046<HDYA2448@75:D46<H01QcW6<HDYABU6<HLi`<DY@036<HDYABU008D
Y@<Li`036<HDYABU00DHaP047>LQ21cW7>L26<H00a245:DHaP026<H35:D011S65:DDYA240QS600HD
YAcW7>LLiaS65:D26<H25:D01Q245:DDYABU48@<H`8@Q08Li`0;6<HDYABU6<HQ21cW8@PYBRe[:DXQ
20047>L36<H01ABU6<HDYAS648@00aBU0QS60QBU00@HaQcW8@PQ20<Li`@HaP8DY@@HaP<DY@8@Q003
5:DHaQBU008@Q0035:DHaQBU008@Q0<DY@056<HDYABU48@DY@026<H25:D26<H35:D76<H25:D011S6
7>LHaQS60QBU0QS600HDYA2436<<HaBU6<H45:D248@25:D448@00aBU48@DY@0448@00`aS48@@Q002
6<H00aBU48@@Q0026<H011BU48@<Ha240QS600DDYA2448@DYAcW008HaP0748@<Ha2448@HaQ2436<0
1A240`aS00L@Q0aS36<<Ha2436<@Q00536<01A2436<<Ha245:D00Q241@aS00T@Q0aS36<@Q0aS48@<
Ha2436<011240PaS00D8@Q2448@DYA2400<DY@8@Q00336<8@PaS008@Q00336<8@PQ200/<H`8@Q0D<
H`04248<H`Q236<4248010aS2488@PQ20PaS00<@Q0aS24800PQ20PaS0a241PaS00<@Q0aS36<00`aS
0aBU00D@Q0aS36<<H`Q2008<H`04248<H`aS48@236<248@236<010Q236<<Ha241@aS0PQ200<<Ha24
24800PaS00<@Q0aS24800PQ21@aS0PQ200<<Ha2424800PQ200<<H`Q224800`aS1@Q20PaS00<8@PaS
36<01PaS00<8@PaS36<00Q2400@<H`Q236<@Q04<H`000`@Q00<000@Q00001@@Q00H8@Re[G_M6<BDY
<H`6>Lh2=Jd3<H`02be[:DXU:Be[:DXU:B489BT]JbU:9BT00RU:0Re[0SF]00<mkd8@@Q000cW>0cg_
0T8@00<mkcW>=Jd00SF]00TaS2e[<H`YBRDY:DX]Jc6<?Nl00cW>00L]JbU:9BTU:B487>LQ20029BT2
8@P00acW8@P]J`02:DX29BT00bU:;F/aS002;F/01BU:9BTYBRDY8@P00QcW0QS60R4800HU:AcW7>LL
ib487>L28@P02bDY8@PLiacW8@PU:BU:9BTQ22DY:DX00Re[00DYBRDY8@PHaQcW00<HaP8Li`8HaP07
7>LQ21cW6<HLib487>L01ABU0Q2400<DYA245:D00QBU00<HaQBU7>L00R4800<LiaS67>L00R4800<L
iaS65:D00QS600<LiaS65:D011S61AcW00<Q21cW7>L00R480RU:00<U:B486<H00QS60QcW00DQ21S6
5:DDYA2400<DY@8@Q0<DY@8@Q0045:DHaQS67>L46<H45:D46<H35:D26<H01AcW6<HHaQS65:D011S6
0b4800<LiaS67>L00QS600DDYAS66<HLiaS600@DY@056<HDYABU5:DLi`028@P00aS65:DDY@026<H0
1aBU48@DYA245:D@Q1BU008<H`075:DLiaS65:D<HaBU8@P00QcW00@Q22U:9BTU:@<Li`056<HLiacW
7>LHaP075:D46<H25:D26<H48@P46<H25:D26<H25:D01aS65:DDYABU48@DYA2400DDY@8@Q0LDY@03
6<HDYAcW00<HaP055:DHaQBU48@DY@026<H27>L011S65:DDYABU0acW00@HaQBU5:DHaP8DY@8@Q004
5:D@Q1BU48@35:D01QS65:DDYABU48@DY@<@Q08<H`8@Q0075:D@Q12436<@Q1BU48@00QBU0QS60QBU
00@HaQBU48@DY@8HaP0348@DYAS6008Li`045:D@Q1245:D348@011BU48@DYA240PaS0Q240PaS0a24
2@aS0Q240PaS0a2410aS00@8@PaS48@DY@8<H`04248<Ha2448@336<348@236<25:D00a246<HHaP02
6<H236<010Q236<DYA240`aS00<8@PaS36<00PaS00<@Q0aS36<00`aS00D@Q0aS36<<H`Q200D<H`<8
@P8<H`06248<H`Q2248<Ha240PaS0PQ20`aS00<@Q0aS36<00PaS00X@Q0Q236<8@Q2436<8@PaS48@H
aP<DY@0348@<H`aS00<<H`0648@<H`Q2248<Ha241@aS00@8@PaS36<@Q08<H`88@P0336<@Q12400@<
H`0348@<H`aS008<H`0724848@Q236<8@PaS24800PaS10Q200@<H`Q22488@P<<H`88@P<<H`03248<
H`aS008<H`0324848@aS008@Q088@P0336<@Q12400<<H`48@P0000<48@0012401@@Q00T8@P001248
@RU:DY@mkb48;F/00S6<00@icS6<=Jde[@<icP8e[@03<H`]Jbe[008]J`<YBP8]J`0<<H`]Jc6<;F/Y
BSF]?Nm6<Cg_>Lhmkd8@0SW>00Te[CW>>LhicTHa@Q0mkcW><H`013F]00<]Jc6<:DX00S6<00He[C6<
<H`YBRe[9BT28@P29BT37>L01B487>LLiacW9BT00bU:00@aS2e[;F/YBPHU:@DQ20067>LQ22DY9BTQ
21cW0b4800<HaQcW7>L00acW0RDY00@Q21cW8@PU:@DYBP039BTQ22DY00<HaP8Li`@HaP@Li`8DY@<@
Q0035:D@Q1BU008DY@036<HDYAS6008Li`039BTQ224800<Li`8HaP8DY@036<HDYAS6008DY@8HaP03
7>LQ21cW00<Li`DQ208YBP039BTQ21cW00@Li`096<HLiaS66<HDYA245:D@Q1BU008@Q08DY@046<HD
YABU5:D36<H00acW5:DHaP025:D36<H00aBU48@DY@026<H25:D76<H25:D27>L012487>LDYAS60QcW
00<DYAS67>L00RU:00TQ21cW48@@Q1BU48@DYA245:D011S600<DYAS66<H00QBU00PHaQBU48@@Q0aS
48@DYA240QBU0QS600XDYAS65:D@Q1BU9BT]Jc6<9BTLi`8HaP045:DHaQS66<H37>L56<H01R487>LH
aQBU48@HaP@Li`8HaP037>LHaQS600<Li`8DY@8HaP045:D@Q1BU5:D248@00aBU6<HLi`025:D00a24
5:DDY@0348@35:D248@01ABU6<HHaQS65:D011S60Q240QBU00@HaQBU5:DHaP8Li`036<HDYAS6008L
i`036<HLiaS6008@Q0035:DHaQBU00<@Q0036<HDYABU008HaP@DY@0448@DYA2436<948@26<H35:D0
2AS65:D@Q0aS48@HaQBU48@HaP035:D248@00`aS48@DY@035:D00`aS48@@Q00348@00aBU36<<H`05
36<248@236<01@Q236<<Ha245:D00a2400D<Ha2436<<Ha2400<<H`0448@<H`aS36<348@236<348@3
36<01ABU9BTYBRU:7>L00QBU00<<H`Q236<00Q2420aS0a240`aS0Q240PaS00<8@PaS36<00PQ20`aS
00D8@PaS36<8@PaS0088@P<<H`8@Q08<H`04248<H`aS36<2248336<01A2436<8@PQ236<00a2400<<
Ha2448@00Q240`aS00<@Q0aS36<02@aS00<8@PaS248010aS0Q241PaS0Q240PaS00D8@PaS36<<H`Q2
00@<H`88@P8<H`L8@P0336<8@PaS00<<H`@8@P0636<8@PaS248<Ha240PaS00<8@PaS36<00PaS0`Q2
00000`0012448@0212400`0012448@0212401`00248YBUJe@Q0U:BU:008]J`<aS004=Jdmkd8@>Lh2
=Jd4<H`2;F/3:DX2;F/2<H`2;F/2<H`2>Lh3?Nl00dHa@Q0e[@02<H`00cW>?NlicP02@Q000cg_>Lhe
[@03=Jd3<H`013F]<H`aS36<0Re[00@YBR488@PLi`<Q20<Li`<Q20049BTQ22U::DX3;F/00bU:;F/Y
BP049BT00b487>LLi`028@P00bDY8@PQ20049BT37>L28@P00acW8@PU:@029BT27>L01B489BTU:BDY
8@P00RDY00TYBRDY8@PQ21cW6<HLiaS67>L00QS600@Lib488@PLi`8DY@8@Q0035:D@Q1BU008DY@DH
aP<Li`088@PYBRDY8@PHaQcW8@PLi`8HaP8DY@0748@DYABU8@PLib487>L00b4811cW00@U:B489BTQ
20<Li`068@PLib487>LHaQcW0QBU00<@Q1BU48@00Q240aBU00<@Q1BU6<H01AS611BU00@HaQBU5:DD
Y@8HaP045:DHaQBU5:D26<H01ABU6<HDYABU6<H00QcW0QS611cW00PHaQcW7>LHaR48:DXU:AcW0QBU
00<LiaBU48@00QBU0QS600<DYAS65:D00QBU00L@Q1BU5:DHaQBU48@<H`0648@01AS67>LHaQBU48@0
0QS600HQ22U:;F/U:B485:D26<H011BU6<HDYAcW0R480QcW00@HaQcW7>LHaP8Li`046<HDYABU5:D4
7>L36<H01AcW6<HHaR486<H00aBU00<HaQ2436<00Q240QBU0QS60QBU00<@Q1BU48@00Q2400@DYAS6
5:D@Q0@DY@086<HDYAS66<HDYAS65:D@Q0<DY@0448@DYABU5:D37>L36<H011cW6<HHaQS61ABU00@@
Q1BU48@@Q08DY@<HaP055:DHaQBU48@<H`0248@00aBU48@@Q00236<35:D36<H01A245:DHaQS65:D0
112400<HaQBU6<H00QS600@@Q0aS48@DY@8HaP0548@DYA2436<@Q0035:D436<248@336<248@01@aS
248<H`aS48@00PaS00H@Q1BU5:D@Q0aS48@636<00a2436<@Q00236<248@336<248@020aS48@DYBDY
=JdaS2DY7>L236<01A2436<<H`aS24800Q241`aS0Q2410aS00<@Q0aS36<00`Q20PaS0Q240PQ20`aS
0`Q20`aS00@@Q0aS36<<H`88@P<<H`0348@<Ha2400D<H`T@Q08<H`<@Q00536<8@PaS36<@Q00236<2
248636<00a2436<<H`02248236<00`Q248@<H`0224800`aS5:D<H`03248011242488@PQ20`aS00<8
@P@Q24800PaS0`Q200D<H`Q236<@Q0aS0088@P05124<H`Q236<8@P0336<248@00`aS2488@P0236<2
2481124000848@0300048@@Q00H48@05248]Je[F@Q0Li`03;F/0236<=Jde[C6<;F/aS3W>?Nl3>Lh0
13g_@Q1243W>0SF]00<icS6<;F/00RU:0S6<0SW>00De[CW>=Jde[Cg_0096<@04>LhYBRDY;F/3<H`4
=Jd2>Lh2=Jd5<H`3:DX29BT01B489BTU:BDY7>L012480RDY0RU:12DY00LYBRe[;F/aS2U:9BTYBP02
9BT28@P022DY;F/YBRDY8@PLib489BT38@P01acW8@PQ21S67>LQ22DY008Q20047>LHaQcW8@P27>L0
12489BTYBRe[0RDY00HQ22DY8@PQ21cW6<H27>L01aS67>LHaQBU48@DYA24008HaP037>LHaQBU00@H
aP055:DHaQS67>LQ20029BT28@P012DY:DXQ21cW0aS60QcW00DHaQcW7>LLib4800<Li`036<HLib48
00<Q20@HaP067>LHaQcW7>LQ21cW0QS60aBU00<HaQ245:D00QS60QBU00<@Q1BU6<H00acW00@HaQcW
7>LHaPHDY@8HaP065:DHaQS66<HDYAS60QcW00<HaQBU5:D01acW00@Q21cW7>LHaP<Li`036<HDYAS6
00DDY@046<HLiaS648@25:D00aS65:D@Q00348@55:D248@25:D26<H45:D01AcW:DXU:B487>L00QBU
00@HaQBU5:DHaP8DY@<HaP047>LHaQcW8@P26<H35:D00aS65:DDY@026<H00acW6<HHaP036<H25:D0
0aS65:DHaP0248@236<25:D46<H25:D011245:DDYABU0Q240QBU0a2400<DYAS65:D01ABU0a2400<D
YA2448@00QBU00LHaQBU5:DLib487>LHaP035:D36<H35:D00a245:DDY@076<H00a245:D@Q00548@0
11BU48@@Q1240QBU00DHaQBU5:DDYAS6008@Q00336<@Q124008DY@0348@DYABU008DY@8@Q08DY@03
48@<H`aS00@@Q08<H`0348@<H`aS008<H`@@Q0D<H`0348@<Ha24008@Q0D<H`0348@<Ha2400@<H`03
48@<Ha2400D@Q088@P0:48@HaRU:<H`YBSF]<H`Q21BU248336<348@836<248@00aBU48@<H`0248@2
36<00`Q236<<H`0336<2248536<00a2436<<H`0424801`aS248<H`Q236<8@PaS0088@P0336<8@PaS
00@<H`0748@DYA2436<8@PaS48@00`aS00<@Q0aS36<00a242PaS0`Q21PaS00@@Q0aS2488@PD<H`88
@P8<H`0348@<H`aS00L8@PT<H`88@P<<H`03248<H`aS00H<H`<8@P8<H`48@P0000P48@0012448@00
124000Q20P@Q00L000aS;F]JeTHa8@PU:@02;F/3<H`01cF]>Lhe[C6<>Li6<Cg_008aS004?Nm6<D8@
>Lh2@Q0013g_=JdYBRe[1S6<00<icSF]>Lh00T8@00<mkcW>:DX00RU:00<]Jc6<;F/00Re[0cF]00Hi
cSF]=Jde[C6<=Jd2<H`2;F/01BDY8@PQ22U:9BT00R4800<Lib488@P00RDY00HQ22DY:DX]JbU:9BT5
:DX2;F/2:DX012DY:DXYBRDY0b4800<U:B488@P00R480bDY00<Q21cW7>L00QcW00<Q22DY8@P00RDY
0QcW00@HaQcW8@PQ20<YBP049BTQ22489BT38@P00acW8@PU:@027>L00a246<H@Q0035:D46<H00acW
6<HLi`035:D011S68@PLiacW0R4800HU:B488@PLiaS67>L28@P01QcW6<HDYAcW8@PU:@8Li`<HaP8L
i`<Q20037>LHaQcW00@HaP<Li`8HaP0548@DYABU5:DHaP025:D00aS65:DDY@026<H27>L01aS67>LQ
21cW6<HDYAS600@DY@8HaP035:DHaQBU008HaP057>LHaQBU5:DHaP097>L00b487>LLi`027>L00aS6
7>LHaP0248@00aBU7>LHaP025:D26<H011BU48@HaQBU0Q2400<DYAS65:D00a2400@HaQBU5:DDY@8@
Q08HaP0@8@PHaQBU36<@Q2DY<H`YBQcW48@HaQcW6<HDYA245:D46<H00aBU6<HLi`027>L01QS648@D
YABU48@DY@<Li`<HaP037>LHaQS6008HaP035:DHaQBU008DY@@@Q0035:DLiacW008Li`8DY@8@Q004
5:D@Q1BU48@25:D01AS65:DDYA246<H00QBU00@@Q1BU5:DHaP<DY@0548@<HaBU6<HLi`035:D011cW
9BTLiacW0QBU0QS600<@Q1BU6<H00QBU00@@Q1BU5:DDY@8HaP045:DHaQS65:D348@25:D248@00`aS
48@@Q0075:D00a245:DDY@025:D248@00`aS48@@Q0035:D00a245:DDY@0448@00aBU48@@Q00448@0
0`aS48@<H`0348@636<00a2436<@Q00236<548@01PaS48@@Q12436<@Q0<<H`0448@<Ha2448@236<2
48@336<01aS69BTYBSW><H`U:AS600<<H`04248@Q1245:D736<348@01PaS48@@Q12436<@Q0<<H`03
248<H`aS00<<H`<8@P0536<@Q0aS36<8@P0236<00`Q236<<H`0536<00a2436<<H`04248336<248@2
36<2248236<348@336<248@336<248@01@aS2488@PaS48@00PaS00<8@PaS36<010aS00D8@PaS36<<
H`Q200@<H`03248<H`Q200H<H`88@P0436<8@PaS36<424800`aS2488@P0236<224800`aS2488@P02
248936<32480000300048@@Q00D48@0924848@@Q248aS6<H@Q0Q22e[00<aS008=JdicSF]=JdicSg_
=JdaS08]J`8icP07?NlicSg_AS5>LdHa@Q000SW>00Le[CW>>LhicSF]>LhaS002;F/3=Jd02Be[9BTU
:BU:<H`]JbU:8@PU:@02:DX4;F/01S6<>Lhe[CF]<H`YBP8U:@8YBP8Q20047>LU:B488@P3:DX01BDY
:DXaS36<;F/01bDY12480RDY124800DU:B489BTU:BU:008U:@078@PU:B487>LQ22DY:DX00Re[00<Y
BRDY9BT00R480acW00<Q22DY9BT00R4800DU:BU:8@PQ21cW00<Q20<Li`8HaP8DY@8@Q00;5:DHaQS6
5:DHaQBU6<HDYAS65:DHaP027>L26<H67>L58@P67>L36<H37>L36<H011BU6<HDYAS60acW00DHaQ24
5:DHaQBU00@HaP8DY@8HaP067>LHaQBU6<HLib480QcW00DQ21S65:DDYA2400HDY@056<HDYAS66<HD
Y@026<H47>L00aS67>LLi`027>L01B487>LLiaS65:D00QS611BU00H@Q0aS48@DYAcW6<H45:D011S6
5:D@Q1240QBU00<@Q1BU6<H00QBU0Q2400<DYA245:D00QcW00DHaQBU36<DYB48008U:@037>L@Q1BU
00<HaP<@Q08DY@0448@DYAS66<H25:D26<H35:D00aS67>LLi`036<H27>L25:D36<H25:D448@35:D0
0aS67>LDY@065:D00a245:DHaP026<H011BU48@DYAS611BU0a2400@DYA245:DDY@<@Q08DY@<HaP8L
i`8HaP8DY@8HaP037>LDYABU008DY@0336<@Q1BU00<HaP085:D@Q12448@DYAS648@<H`8@Q08HaPD@
Q0PDY@0448@<Ha2436<25:D01Q246<HHaQBU48@<H`H@Q0<<H`0348@<H`aS00<<H`0448@<H`aS36<3
48@010Q236<<H`aS0Q2400@<Ha2436<<H`<@Q0<<H`8@Q0035:D@Q12400<<H`8@Q08<H`0448@DYAcW
9BT27>L00aS648@@Q00248@836<248@010aS48@@Q1240`aS0a2400<<Ha2436<00PaS00<@Q0aS48@0
0`Q200@<Ha2448@@Q08<H`03248<H`aS008<H`0448@<H`aS248236<00`@Q2488@P0336<00`Q236<<
H`0236<00a2436<<H`0236<348@00`aS48@@Q00248@336<348@010aS248<Ha2410Q20Q240`aS00<@
Q0aS36<00PQ20PaS00<8@PaS36<00PaS10Q20`aS0`Q200@48@aS2488@P848@8<H`<8@P8<H`03248<
H`Q200@<H`03248<H`aS00D<H`03248<H`aS0048@P000`@Q00<000@Q00001@@Q00H8@Re[IcU>LbU:
;F/3<H`00be[:DXaS004>Lh02Cg_>Lhe[C6<=JdicS6<>Li6<@02BU801T8@>LhicSg_>Lhmk`@icP06
=JdaS2e[<H`]Jc6<0bU:00<]Jc6<<H`00RDY00DQ22DY:DXYBRe[00HaS08]J`8U:@038@PU:BDY00<Q
20@YBP039BTYBRU:008aS08]J`8U:@038@PU:BDY008Q20069BTYBRDY8@PLib480RDY00<Q22DY9BT0
12DY00PQ22DY8@PU:B487>LQ22U:0Re[00<YBRDY:DX00R481QcW00@Q22DY9BTU:@8Q20<U:@@Li`04
8@PLiaBU5:D248@25:D56<H25:D00aS65:DHaP026<H00acW8@PLi`037>L00b487>LQ20038@P00acW
8@PLi`027>L011S67>LLiaS60R480QcW00<DYAS66<H00aS60QcW0QS600DDYA245:DHaQcW008HaP8D
Y@8HaP067>LHaQS65:DHaQcW0R4800@LiaBU6<HHaP<DY@0;6<HDYABU48@DYAS65:DHaQcW6<HLi`03
6<H37>L01aS68@PQ22DY8@PLiaS600<DY@036<HDYAS600<DY@8@Q0055:DHaQS65:D@Q0025:D011S6
5:DHaQS60a240QBU0Q240aBU1AS60QBU00DLib48:DXLiaBU008HaP8DY@0848@DYA245:D@Q1BU6<HD
Y@8HaP<DY@0548@DYA246<HDY@066<H27>L01QS65:DHaQS67>LHaP8@Q00436<DYABU5:D26<H27>L3
5:D26<H00aBU48@DY@026<H25:D01A245:DLiaS65:D00Q2400@DYA2448@DY@H@Q08DY@8HaP037>LH
aQS600HHaP037>LHaQS6008@Q0<DY@8HaPHDY@H@Q08DY@066<HDYA2436<@Q1BU0aS600DDYAS648@@
Q0aS00<@Q0DDY@0448@<Ha2448@25:D248@236<248@010aS48@@Q1240`aS00@@Q0aS48@<H`@@Q08<
H`8@Q0045:D@Q12436<248@010aS248@Q1240QBU0Q2400<<Ha2448@00Q2400<<Ha245:D00aS600@D
YAS65:DHaP8@Q00436<@Q12448@236<448@236<00a2436<<H`0236<011245:DDYA241@aS00<@Q0aS
36<00PaS00H8@PaS36<@Q0aS248436<224802A2436<<H`aS248<H`Q236<8@P0536<01`Q236<@Q124
36<8@PaS00<@Q0@<H`8@Q0045:D@Q12436<448@636<00`Q236<@Q00636<2248236<5248436<00`Q2
36<@Q00236<4248010aS248<H`Q20PaS00@8@P@Q2488@P8<H`@8@P@<H`0348@<H`aS00@<H`0000<0
00@Q00001@@Q00/8@P001248@S6<HaQ6<Be[>Lhmkbe[008YBP05<H`]JbU:;F/e[@03<H`00cg_@Q12
4002>Lh00cF]>Lhmk`03@Q001DHa?Nle[CF]?Nl00TYB00<mkcW>;F/00S6<00@]JbDY9BTYBP<U:@06
:DX]JbU:9BTYBRe[0RU:12DY0RU:00DU:B488@PU:BU:00DU:@03:DX]JbU:008]J`8aS08YBP059BTQ
22U::DX]J`02<H`00bU:9BTLi`027>L01b489BTU:B489BTQ21cW008Q20<U:@058@PU:BDY9BTYBP02
;F/00bU:8@PU:@02:DX01RDY8@PU:AcW8@PLi`HQ20047>LQ21cW7>L38@P26<H27>L01AS65:DHaQBU
48@00QBU0QcW00@DYAS66<HHaP8DY@DHaP8Li`038@PU:BDY008U:@068@PLibU:;F/aS2U:0b4800DL
iaS67>LLib48008HaP045:DHaQS67>L46<H011BU6<HDYABU0QS60acW0QS600@LiaS65:DHaP8DY@8H
aP048@PU:B487>L56<H00acW6<HHaP025:D011245:DDYAS60QcW0aS60acW0QBU00PHaR489BTQ21cW
8@PHaQBU0QS600DLiaS65:DDYAS600D@Q0<DY@DHaP035:D@Q124008@Q08DY@036<HDYA24008@Q003
5:DHaQBU008@Q0058@P]Jbe[8@PHaP037>L35:D00a245:DDY@025:D26<H01AcW6<HHaQBU6<H00QBU
00D@Q1BU5:D@Q1BU008HaP057>LHaQS67>LHaP035:D00aS67>LHaP035:D77>L00aBU48@DY@045:D0
0aS65:DDY@026<H27>L00aS65:DDY@026<H00aBU48@@Q00236<25:D26<H25:D26<H27>L00aS65:DH
aP027>L01QS648@@Q1245:D@Q08DY@036<HDYABU00@HaP8DY@@@Q0@DY@<@Q08<H`045:DHaQcW7>L3
6<H248@010aS48@@Q1S60QcW0a240aBU00<@Q1BU5:D00QBU0`aS00<DYA2448@0112400<<Ha2436<0
0PaS0Q240PaS0Q2400<DYA2436<00`aS112400@DYA2448@@Q08DY@8@Q0045:DHaQS65:D448@25:D0
0a2436<@Q0025:D0112436<<Ha240`aS0Q2400@DYA2448@@Q0<<H`0348@<H`aS008@Q0<<H`0448@<
H`Q2248736<00a2436<<H`02248636<01@Q236<<H`Q236<00PQ20PaS0Q241`aS0a2400<<Ha2448@0
0Q2400<<Ha2436<00PaS00@@Q1BU48@@Q0L<H`05248<H`Q236<8@P0436<2248236<00`Q236<<H`04
248236<224800`aS2488@P09248236<2248536<2248436<3248136<1248000H48@030008@P@Q0084
8@09248e[FLi@Q0U:Cg_@Q0icS6<008]J`03:DX]Jbe[008aS006;F/e[CF]?NlicSF]13W>00TmkcW>
>Lhe[CW>?Nm243F]>Lh00Sg_00HicS6<<H`e[C6<;F/39BT2:DX29BT00bU:;F/YBP029BT4:DX01BDY
8@PU:BDY8@P00bU:00P]JbDY8@PQ22DY:DX]JbU:0Re[136<0bU:00hU:BU:<H`e[C6<;F/Q22DY7>LH
aQcW9BT]JbDY0QcW0R480RDY0R480RDY00@Q22DY:DX]J`@YBP8Q200>9BTQ22DY8@PLiaS67>LQ22DY
8@PLib489BTLi`8Q20049BTQ21cW6<H27>L36<H011BU48@@Q1BU1AS600@Lib486<HHaP8DY@046<HD
YAS68@P29BT28@P3:DX02R487>LYBSF]>LhYBQcW6<HQ21cW0QS600LQ21cW7>LDYAS67>LHaP057>L0
11BU6<HDYA240QS60R480QcW00THaQBU48@DYAcW6<HDYAcW8@P00QcW0QBU1AS60a241QS60QcW00<H
aQcW6<H00QS600@LiaS65:DLi`8Q20<Li`8HaP055:DHaQS66<HDY@0448@00aS65:DDY@0248@011BU
6<HHaQBU0Q2400<DYAS65:D00Q240aS600@@Q1BU5:D@Q08DY@<HaP8U:@04:DXU:AcW7>L26<H248@0
21BU48@DYABU48@HaQcW6<H35:D26<H00aBU48@@Q0026<H00acW5:DHaP036<H25:D26<H00acW6<HD
Y@035:D01A246<HHaQcW8@P00QcW0QS600<DYA245:D00QS60QBU0aS60aBU0QS600DDYAS65:D@Q0aS
008@Q0035:D@Q1BU008DY@046<HDYABU5:D86<H25:D348@35:D011246<HLiaS60aBU00<HaQBU36<0
112400@DYA2448@DY@8@Q08DY@<HaP097>LHaQS648@<Ha245:DHaQcW00<DY@8@Q08<H`045:DHaQcW
5:D236<248@00`aS48@<H`0648@236<01A2436<@Q12436<011240PaS00<@Q0aS48@01a2400<DYA24
48@00Q2400@HaQcW5:DDY@<@Q0046<H@Q12448@336<348@536<348@436<748@436<00`Q236<@Q002
36<010Q236<<Ha240PaS00D8@PaS36<<Ha2400D<H`88@PL<H`0348@<Ha2400@<H`8@Q0@<H`<@Q0@<
H`0348@<H`aS00@@Q0<<H`08248<H`aS248<H`Q236<8@PH<H`07248<H`Q2248<Ha2436<00PQ200<4
8@aS36<01PQ200<<H`Q236<00PQ20`aS0`Q21PaS00<8@PaS36<00PaS00<@Q0aS36<00@Q2000010@Q
00048@001`@Q00D8@RU:E[DicRe[008mk`04=JdYBRe[=Jd2<H`3;F/01bU:;F/e[C6<;F/YBRe[00<e
[@04;F/aS36<=Jd3<H`3=Jd0136<=JdaS2U:0RDY00<]JbU:9BT01BDY0RU:0RDY00<YBRe[:DX00RU:
0RDY0b480RDY00LYBRDY:DX]Jc6<=JdaS003;F/2<H`00be[:DXU:@049BT012U:;F/]JcF]0Re[00LY
BRDY9BTU:B489BTYBP03;F/01BU:9BTU:BU:9BT00R480QcW1R480RDY00@Q22DY7>LHaP8Li`05;F/e
[C6<:DXQ20047>L011S65:DHaQS60QcW0QS60QBU00<HaQcW6<H00QS60QBU1AS600<DYAS66<H00QS6
0QcW00HQ21cW6<HLibDY;F/2:DX00c6<:DXU:@026<H37>L49BT37>L00aS67>LHaP027>L01B486<HD
YABU6<H00QBU0QS60QcW0QS611BU00THaQBU48@Lib489BTLiaS68@P00QcW0aS60QBU00<@Q1BU6<H0
0QS600DQ21cW6<HDYAS6008Li`068@PHaQBU5:DLib480QcW00HHaQBU6<HLiaBU6<H27>L00aS648@@
Q00248@65:D26<H00aBU48@DY@035:D02Q245:DHaQS67>LHaQBU36<@Q1BU0QS600HDYB48:DXaS2U:
9BT38@P00acW6<HHaP025:D011S65:DDYABU0QS600<LiaS66<H00QS60QBU0a240aBU00<HaQcW7>L0
0QS600<Lib488@P00aS600<@Q1BU5:D01AS61AcW0QS600<DYAS65:D00QBU11S60acW00<HaQBU6<H0
0Q2400<<Ha2448@00a240aS60QBU00<HaQcW5:D00QBU00<HaQcW6<H00QBU0Q241ABU00<HaQcW6<H0
0QBU00<@Q1BU5:D011BU00<HaQBU6<H00QBU0Q240QBU0QcW0QS600TDYAS66<H@Q1BU6<HLiaS65:D0
112411BU00@<Ha2448@@Q08<H`8@Q0035:D@Q12400D@Q08<H`8@Q0<<H`<@Q08DY@8@Q00436<@Q1BU
5:D336<448@25:D36<H25:D011245:D@Q1BU0Q240PaS1A2400D8@PaS248<Ha24008DY@<<H`0448@<
Ha2436<448@236<010Q236<<Ha241`aS00<@Q0aS36<01@aS00<@Q0aS36<00PaS00<@Q0aS36<00PaS
1A240PaS00<@Q0aS36<00PaS00H@Q0aS248<Ha2436<2248336<348@01PaS248<H`aS48@<H`8@Q08<
H`88@PH<H`D8@P<<H`88@P<<H`88@P0436<8@P@Q248236<2248336<010Q236<<H`aS0`Q210aS00H8
@PaS2488@PaS248336<12480000300048@@Q00848@0300048@@Q00<48@05248YBU[F@Q0YBP02=Jd0
1be[<H`aS3F]<H`YBRe[008aS003;F/aS36<008aS08YBP8]J`8aS08]J`8aS08]J`04<H`e[C6<<H`2
=Jd01c6<:DXU:BDY:DX]JbDY008Q20049BTYBRDY9BT5:DX00be[:DXYBP02:DX00bDY8@PLi`028@P0
0bDY:DXYBP02;F/4<H`2;F/012U:;F/]JbU:0bDY0RU:0Re[00@aS2U:9BTQ20<U:@07:DXU:BU:;F/e
[Be[9BT00RU:00D]JbU:7>LLib48008U:@058@PLib489BTQ20047>L011S67>LLibe[0S6<00@]Jb48
8@PU:@8Li`036<HLiaBU008DY@<HaP035:DHaQS6008HaP@DY@047>LHaR488@P25:D248@36<H27>L2
6<H27>L29BT012U:9BTU:BDY0R4800DLiaS67>LHaQcW00<U:@048@PHaQS66<H27>L66<H45:D37>L2
6<H01ABU6<HHaQS648@00QBU00<HaR488@P00R481QS600<DYAS66<H00QBU11cW0aBU00@Lib487>LH
aP8DY@046<HLiacW7>L25:D011S67>LLiaS60aBU0Q2400HDYA2448@@Q1BU48@35:D26<H35:D00a24
5:DDY@046<H55:D01AS67>LDYA24:DX00SF]00@U:AS67>LQ20@HaP035:DHaQS600@HaP8DY@8HaPHD
Y@0448@DYABU5:D36<H00aBU6<HQ20028@P25:D00aS65:DHaP046<H47>L00aBU6<HHaP026<H01QBU
48@DYA246<HDY@<HaP037>LDYAS600<DY@0548@<Ha2448@DY@0248@65:D26<H25:D01A245:DHaQS6
5:D00Q2400<HaQcW6<H00aBU0QS60QBU0Q2400@DY@aS48@DY@8HaP8DY@0348@DYAS600<DY@066<HL
iaS65:DLiaS60Q2400DDYAcW6<H@Q1BU008HaP045:D<Ha245:D248@25:D336<248@236<448@236<0
0a245:D@Q00236<248@236<011245:D@Q1BU0Q2400<DYA2448@00a240PaS0Q240PaS00@@Q1BU6<HH
aPL@Q08<H`0748@DYABU48@8@PaS48@00`aS0a240PaS00<8@PaS36<00Q240`aS0a240PaS00@@Q0aS
36<<H`88@P0536<8@PaS36<@Q00436<00a2436<<H`0336<00a2436<<H`0336<248@236<248@436<0
0aBU48@<H`03248236<2248636<00a2436<@Q00236<3248836<224800`aS248<H`03248436<32482
36<424801@aS24848@Q236<00PQ20`aS0PQ200@<H`Q236<8@P<<H`D8@P4@Q04<H`48@P000P@Q00H0
00@Q12448@00248212402@00248]JekgBU8]JcW>=JdaS003;F/01BU:;F/YBRe[<H`00SF]0S6<0Re[
00<YBRe[:DX00RU:00P]JbU::DXYBRe[<H`]JbU:0Re[0SF]00<aS2U:<H`00S6<00DYBRDY9BTQ21cW
008U:@<]J`04<H`e[CF]<H`29BT01B48:DXYBRDY7>L00R480acW00@U:BU:;F/YBP8U:@03:DX]Jbe[
008YBP<U:@@Q208YBP8U:@8Q20039BTYBRU:008]J`<aS003;F/YBRU:008]J`8U:@8Li`058@PU:B48
9BTLi`036<H01AcW6<HHaR489BT00Re[0RDY00<Q21cW8@P00RU:00<Q21cW5:D00aBU0QS600<LiaS6
5:D00QBU00<HaQcW7>L00QcW0b480QcW0aS611cW00DHaQBU6<HLib4800@Li`<HaP037>LHaQcW00<L
i`<Q20037>LQ2248008Li`048@PLiacW7>L26<H011BU48@DYABU0aS600<LiaBU5:D00QBU00<HaQcW
6<H00QS600@LiaS67>LHaP8Li`8HaP035:DHaQcW00@HaP8Q208Li`<HaP045:DHaQS66<H25:D47>L0
1QS67>LHaQS65:DHaP8DY@046<H@Q1BU5:D36<H021245:DDYAS67>LHaQBU48@25:D66<H011BU6<HD
YAcW0aS600TQ21cW5:DYBSg_>LhYBQ246<H00QcW00<HaQBU6<H00QcW0QS60QBU0QS611BU0aS600LD
YA245:DDYAS65:D@Q0035:D011S67>LLiaS60QBU0QcW00LHaQcW8@PQ21cW6<HQ20027>L02AS65:DH
aQBU6<HDYAS65:DHaP035:D56<H25:D011245:DDYA2411BU00<@Q1BU5:D00QBU00LHaQBU5:DDYA24
5:DHaP035:D00aS67>LLi`026<H45:D00aS67>LHaP0248@236<35:D00aS65:D@Q0025:D26<H011BU
6<HHaQcW0QS600DLiaS648@@Q1BU008Li`046<H@Q1245:D26<H01Q2436<@Q1BU48@<H`8@Q0@<H`03
48@8@PaS008@Q0<<H`<@Q00536<@Q12436<DY@026<H01ABU36<@Q12436<0112400D<Ha2448@@Q1BU
00<@Q0056<HDYABU48@<H`0548@236<00a245:DDY@0336<00a2436<@Q00:48@436<248@00`aS48@D
Y@0248@636<00a2436<<H`0236<00a2436<@Q00336<01A2436<<H`aS48@00`aS0Q240`aS0Q240`aS
00D8@PaS36<<H`Q200<<H`03248<H`Q20088@P8<H`88@P<<H`03248<H`Q200H<H`0348@DY@aS008<
H`03248<H`aS00H<H`03248<H`Q2008<H`03248<H`Q20088@P@<H`06248<H`aS248<H`Q210aS1@Q2
0`aS0`Q20A240@Q200001@@Q00048@@Q00000`@Q00h8@P@Q1248@Re[HaQ6<Be[>Lhe[C6<:DX]Jc6<
0bU:0be[0c6<00@e[C6<;F/YBP<]J`03:DXU:BU:00DYBP049BT]Jc6<=Jd2<H`01be[<H`aS36<:DXU
:B48008U:@0:8@PU:BU:<H`e[C6<=JdaS2e[:DX29BT2:DX29BT012487>LLiacW0RDY00<YBRDY9BT0
0R4800DYBRe[:DXU:B4800<U:@048@PLib488@P79BT2;F/0136<=JdaS2e[0RU:0Re[0bU:0R480QcW
00<U:B487>L00aS611cW00<Q22U::DX00RU:00<U:B489BT00bU:00PLiaBU5:DHaQBU6<HDYA240aBU
1AS60acW00<Q21cW8@P00QcW00<HaQcW8@P00QcW00DHaQcW6<HHaQcW00<Q20036<HLiaS6008HaP@L
i`<Q200;6<HLibDY9BTLiaS67>LU:B486<HDY@036<H65:D01AcW5:DHaQS67>L00aBU00<HaQcW8@P0
0QcW0QS61AcW00@DYA245:DHaPHLi`056<HLiaS66<HLi`035:D01aS68@PHaQS65:DHaQBU00<HaPDD
Y@0436<DYAS67>L35:D36<H65:D01aS67>LLiacW5:DLiaS6008DY@0:6<HQ21S65:D]Jcg_@Q0aS1S6
8@P27>L011S65:DHaQS60QcW0QS600<LiaBU5:D00QBU0QS60QBU00<HaQBU6<H00QBU11240QBU0QS6
00HLiaS66<HDYAS65:D37>L28@P00acW6<HHaP027>L00b486<HDY@025:D26<H01ABU48@@Q1S65:D0
0aS600@DYAS648@DY@8@Q08DY@<@Q08HaP8DY@0448@DYAS66<H45:D011S65:DHaQBU11cW00@DYA24
5:DDY@8HaP<DY@8@Q0<DY@8HaP@DY@8HaP<DY@056<HLib486<HDY@0248@011BU7>LLiaBU0a2400DH
aQBU5:DDYA24008<H`<@Q0D<H`<@Q0035:D@Q12400D@Q08<H`8DY@036<HDYA24008@Q0<<H`0548@D
YABU48@DY@0448@00aBU48@DY@025:D01A2436<@Q1245:D00Q240`aS00<@Q1BU48@010aS00D@Q1BU
48@@Q0aS00<@Q0P<H`D@Q00536<@Q0aS36<@Q00336<0112436<<H`Q20PaS00<@Q0aS48@00`aS00@@
Q0aS36<8@P8<H`0548@<H`aS36<@Q00936<2248436<00`Q236<8@P0736<00`Q236<<H`0736<00a24
36<<H`0536<324800`aS48@<H`0324801Q2436<<H`aS48@<H`88@P<<H`04248<H`Q2248236<00a24
36<<H`02248336<3248236<1248136<0000300048@@Q00848@0300048@@Q00<48@06248e[Ekg@Q0Q
22e[0cF]00TaS2e[:DXU:BU:;F/aS2U:;F/00c6<0Re[12U:00@]JbU:9BTU:@8YBP05;F/YBRDY;F/a
S002=Jd01C6<=JdicSW>=Jd00Re[0RDY0RU:0SF]00HicSg_=JdaS2e[9BT2:DX29BT00bU:9BTU:@03
8@P49BT01bU:;F/]JbU:9BTYBRDY00<Li`048@PLib487>L38@P29BT28@P012U:;F/]Jbe[0RU:0S6<
00<]JbU::DX00c6<00<]Jb488@P00b4800DLiaS67>LQ21cW008HaP037>LQ2248008U:@047>LQ21cW
7>L38@P46<H011cW8@PDYABU0Q241AS60QBU00@HaQcW9BTU:@@Li`8Q20039BTQ224800<Q208HaP<L
i`8HaP8Li`048@PHaQcW6<H47>L28@P67>L28@P011cW6<HHaQBU0QS611BU00XHaQcW6<HLiaS65:DH
aQBU48@HaP8Li`8HaP<Li`HHaP057>LU:BU::DXU:@026<H011cW8@PQ21S60QBU0QS600<DYAS67>L0
0QS600<DYAS66<H00QcW00<HaQBU5:D00aS600HDYA245:DDYAcW8@P27>L25:D26<H01QcW6<HDYABU
48@Li`8Q20096<HDYA246<HDYAcW5:DHaRe[008icP07:DXLiacW8@PLiaS67>L011S60QcW00<HaR48
8@P00QS600<DYA246<H00aS600<DYAS65:D00aBU00LHaQBU48@DYAS67>LHaP025:D011S65:DDYAS6
0acW0aS600LLib488@PLiaBU48@DY@026<H45:D011S65:DHaQBU0QS611BU0aS600<DYAS67>L00QS6
00DDYA245:DDYAS600<DY@036<HDYABU008DY@036<HDYAS6008Li`036<HDYABU008HaPDDY@8@Q0DD
Y@8HaP@DY@<HaPDDY@0948@DYAS65:D<Ha245:DHaQBU00<@Q00436<DYA2448@436<0112436<@Q1BU
0Q240`aS00@@Q1BU48@DY@8@Q0@DY@8@Q0<<H`0448@DYA2436<35:D00a2436<<H`0548@010aS48@@
Q1240PaS00<8@PaS48@00QBU00<@Q0aS36<00a240`aS0a2400D<H`Q248@@Q1BU00D<H`03248<Ha24
008DY@L@Q08<H`0548@<Ha2436<@Q00436<00`Q236<<H`0248@236<00a2436<<H`0236<00`Q248@<
H`0336<0112436<<H`Q20`aS00<DYA2436<00PaS00<@Q0aS36<00PQ21@aS00<8@PaS36<01PaS0PQ2
00D<Ha2448@<H`Q200H<H`03248<H`Q200H8@P0436<8@PQ236<3248236<00a2436<<H`04248336<0
1Q242488@PQ236<@Q04<H`000`@Q00<000@Q12400P@Q00/8@P00124<Hbe[HaQ:DRDY;F/aS2e[00<a
S0<YBP03;F/aS2e[00H]J`03<H`YBRU:00<]J`03:DXU:BU:00<YBP0:9BTYBRU:;F/YBRe[<H`e[CW>
=Jd2<H`01bDY:DXU:BDY;F/aS3W>008mk`04>LhaS2U::DX29BT2:DX29BT00b489BTU:@028@P29BT5
:DX012e[9BTQ21cW0b4811cW00<Q21cW8@P00R480RU:0Re[0RU:0Re[00LaS2U:9BTYBS6<=Jd]J`04
8@P01AcW8@PQ22487>L00QS600DDYAS67>LLib48008U:@038@PHaQS600@Li`<HaP8Li`056<HDYA24
48@HaP035:D01aS65:DDYABU6<HLiaS6008U:@8Q20037>LQ22DY008Li`068@PU:B487>LHaQcW11S6
11cW00<HaQcW7>L00QcW00@HaR487>LQ20<Li`046<HLiacW7>L46<H27>L011S65:D@Q1BU0QcW0aS6
00DDYA245:DDYAcW008HaP047>LHaQS66<H37>L01QS65:DDYAS65:DQ208U:@038@PLib48008Li`8H
aP037>LHaQS6008HaP8DY@<HaP8DY@036<HLiacW008HaP8DY@8HaP037>LDYAS6008DY@036<HDYAS6
008HaP077>LQ21cW6<H@Q1BU6<H00acW0aS60QBU00@@Q1BU8@PU:@8e[@8YBP<Li`036<HLiaS600DH
aP047>LQ22487>L25:D36<H011cW6<HDYABU0Q2400@DYA245:D@Q08DY@036<HDYA24008Li`066<H@
Q1BU6<HLiaS60QBU0acW00@Q21cW5:DDY@8HaP037>LHaQ2400<DY@8HaP045:DHaQBU5:D36<H25:D0
1a245:DHaQS67>LHaQBU00@HaPDDY@056<HDYA2448@DY@086<H01ABU6<HHaQS65:D01Q240QBU0QS6
00<@Q1BU6<H00QS60aBU0QS600DDYA245:DDYAS600<DY@0348@DYABU008DY@0548@<Ha2436<@Q005
36<35:D0112436<<H`aS0Q2400DDYA2448@@Q1BU00@@Q00336<8@PaS008@Q0035:D<Ha24008@Q08H
aP8DY@8<H`0448@<H`aS36<448@536<01A2436<@Q1BU48@00`aS00<@Q0aS24800PaS0Q2410aS00<@
Q0aS36<00PaS0a2400<DYA2448@00PaS1A2400D<Ha2448@DY@aS00<8@P0348@<H`aS00<<H`0348@<
H`aS00@<H`0448@<H`aS248:36<00a2436<@Q00436<248@436<00`Q236<8@P0536<00`Q236<<H`06
36<00`Q236<@Q00248@010Q236<8@PQ20`aS00D8@PaS36<48@Q200<<H`88@PD<H`P8@P0436<8@PaS
48@236<0000500048@@Q12400003124020Q2124000aS=Je_NdHa9BT2=Jd01Be[:DXaS3F]<H`00RU:
0Re[00<aS2U::DX00Re[00<aS2e[:DX012U:00<]Jc6<<H`01Re[00<aS2e[:DX00RDY0be[00/YBRe[
:DXU:Be[<H`e[CW><H`e[CW>008e[@8aS08YBP039BTYBRDY00<U:@8YBP<U:@03;F/aS2e[00@YBPDU
:@038@PHaR48008Q20<U:@037>LQ22U:008]J`8YBP8]J`03<H`YBRU:008U:@04:DX]Jbe[:DX28@P0
0bDY8@PQ20037>L00aS67>LHaP028@P00bDY8@PLi`047>L28@P46<H27>L36<H25:D26<H35:D00aS6
7>LHaP035:D011cW9BTU:B480bU:00<Q21cW6<H00b4800<LiaS65:D00QS611cW00<Q21cW7>L00QS6
00@Q21cW9BTU:@8Li`@HaP078@PLiacW6<HLiaS67>L00QBU00@HaQcW7>LHaP8DY@8HaP047>LHaQBU
6<H37>L26<H011cW8@PLiaS60QBU0acW00<HaQcW8@P00acW124800<LiaS66<H00QcW00@Q21cW7>LQ
208Li`035:DHaQcW00<HaP8Li`<HaP035:D@Q1S6008Li`036<HDYABU00<HaP<Li`<HaP078@PU:AcW
7>LDYA246<H00QBU00@U:Be[=JdaS08U:@037>LQ224800<Q20067>L@Q1245:DLibDY0QcW00HQ21S6
6<HDYAS68@P57>L35:D348@011BU6<HHaQS611BU00<LiaS66<H00aS600@DYAcW7>LHaP8DY@056<HD
YABU5:DHaP035:D26<H01ABU6<HHaQcW6<H01aBU1AS611BU00@HaQBU7>LHaP8DY@0:48@DYABU48@<
Ha246<HDYAS65:D26<H01QBU6<HLiacW6<HDY@8@Q00336<@Q12400<DY@0348@DYABU00@DY@<HaP@D
Y@036<HDYAS6008DY@8Li`086<H@Q0aS36<@Q0aS48@<H`8@Q00736<@Q12448@DYA245:D00a2400D<
Ha2436<@Q1BU00D@Q08<H`@@Q00436<@Q12448@25:D01A245:DDYAS65:D010aS1A241@aS0a2400<D
YA2448@01PaS112400<<Ha2436<00PaS00H8@PaS48@<HaBU48@436<248@236<448@010aS48@@Q124
0`aS00<@Q0aS36<00`aS00@8@PaS36<DY@<@Q0@<H`8@Q0<<H`@8@P0436<@Q12448@836<00a2436<<
H`0936<00`Q236<<H`0236<00`Q236<<H`0236<2248010aS248<H`aS0Q2400<<H`Q236<020aS00<8
@PaS24800PaS0`Q200<<Ha2436<01@aS0@Q2000212401P0012448@001248@P<48@05248e[G>LE[D]
J`02=Jd3<H`3;F/00bU:;F/]J`02;F/00c6<:DX]J`03:DX012e[:DXYBRe[0RU:00@]Jc6<<H`]J`@Y
BP04<H`]JbU:9BT3:DX012e[:DXU:BDY0Re[00@icSF]>Lhe[@<aS0D]J`03:DXU:BDY008U:@03:DX]
Jbe[00<YBP04<H`e[C6<:DX2;F/01BU:9BTYBRDY8@P00QcW0R480bU:00PU:Be[9BTU:B489BT]JbU:
0Re[12U:00@U:BU::DX]J`8YBP8U:@8Q208Li`046<HLiacW6<H27>L00b489BTQ20057>L00b487>LH
aP026<H011cW8@PLib481AS600<DYAS65:D00QBU1AS600<Lib489BT00bDY00@YBRDY9BTQ20<Li`03
6<HLiaS6008Li`036<HLiacW00<Q20047>LHaQcW7>L38@P00acW6<HHaP027>L00aS67>LHaP027>L2
6<H25:D36<H01AcW6<HDYABU6<H00QcW0aS600<LiaS66<H00QS60b4800@LiaBU6<HHaP8Li`046<HL
ib488@P37>L29BT47>L01AS67>LLib489BT00R4800<LiaS66<H021S611BU00@LiaS66<HDY@8HaP09
7>LHaQcW7>LDYAS67>LQ21cW008HaP055:DHaQBU48@DY@027>L0136<=JdaS2DY0QcW00<U:B487>L0
0QcW00DHaQBU5:DHaR48008Li`8Q20066<HDYABU8@PLib480QS600DDYAS67>LHaQBU00<@Q0055:D@
Q1BU6<HLi`026<H00aBU6<HHaP026<H01QBU6<HDYABU6<HLi`8HaP045:DHaQS66<H45:D76<H00aBU
6<HDY@055:D26<H25:D011S65:DDYABU0aS611BU00@HaQBU5:DDY@8HaP035:DHaQS600@HaP8Li`8D
Y@8<H`<@Q0055:D@Q1BU5:D@Q0025:D011245:DDYAS60aBU0QS600HDYAS65:DDYA245:D27>L011S6
36<<Ha240`aS0Q2400/<Ha2448@@Q1BU48@<Ha245:DHaQBU008<H`8@Q0035:D@Q0aS008@Q0035:D@
Q0aS00<<H`0448@<H`aS48@26<H00aBU48@DY@0548@236<00a2436<<H`0736<748@236<00`Q236<<
H`0536<00a2436<<H`02248236<348@236<248@00aBU48@<H`0236<248@236<348@636<0112436<<
H`Q20a2400D<Ha2436<<Ha24008<H`0348@<Ha2400H<H`0948@<H`aS36<@Q1BU48@<H`Q200<<H`8@
Q00636<8@PQ236<@Q0aS0`Q210aS0PQ20PaS0Q240`aS0`Q21@aS00<8@PaS36<00PQ210aS1@Q20`aS
0PQ200D<H`Q22488@PaS0048@P0000<48@0012400`@Q00`000@Q248000@Q36<e[FmkDY@YBSW>?Nl3
=Jd00cg_=JdaS002=Jd2<H`4:DX4;F/0136<:DXYBRDY1BU:00LU:BU:<H`aS2e[<H`]J`02:DX01Re[
<H`]JbU:8@PU:@8YBP08<H`e[C6<;F/YBRe[<H`e[@8aS004;F/YBRe[:DX29BT3:DX01Be[:DX]Jbe[
<H`013F]0RU:00<U:B489BT00R480QcW00@U:BU:;F/YBP@Q20@YBP<U:@03:DXU:BU:00<YBP039BTY
BR4800@Q20067>LHaQBU6<HLib480RDY0QcW00<HaQcW7>L00R480acW00<HaQBU5:D00QcW00<Q21cW
7>L00aS600<Lib487>L00aBU00<HaQcW5:D00QS60acW12480RU:00@Q21cW5:DDY@8HaP048@PLib48
7>L29BT00b489BTQ20027>L26<H011cW8@PQ22DY0aS600<DYAcW7>L00QcW00<Q21cW7>L00QS600DL
ib488@PQ21cW008DY@0448@DYAS66<H37>L012487>LLiacW0aS60QcW0QS600<Lib486<H01QcW00DU
:B488@PLiaS600<Li`<HaP8Q208Li`056<H@Q1S65:DHaP027>L02B487>LDYAS65:D@Q1BU6<HLi`02
6<H01QcW8@PQ21S65:DHaP8Q20047>LQ21cW5:D26<H01B487>LHaQcW9BT00SW>0Re[1acW0aBU0QS6
00DLiaS65:DDYAS6008Li`076<HQ21cW7>LHaQBU6<H00a2400<HaQBU6<H00aBU00@<Ha245:DDY@8H
aP8DY@0348@HaQBU008DY@0348@DYAS6008HaP0448@DYAcW6<H25:D86<H25:D01AS65:DDYABU48@0
0aBU00<HaQBU5:D011BU00@HaQBU5:D@Q0<DY@066<HDYA2448@DYAS60aBU00DHaQcW8@PLiaS600<D
Y@0448@<Ha2448@65:D236<011245:DHaQS61ABU0QS60QBU00HHaQBU5:DDYA2436<448@01@aS48@@
Q12436<00Q240QBU112400<DYA2436<00Q2400HDY@aS36<@Q0aS48@236<448@00`aS48@@Q0055:D2
48@536<00a2436<@Q00336<248@336<348@010aS48@<Ha2420aS00<@Q0aS36<01@aS00<8@Q2448@0
0a240`aS0a240PaS1Q2400<DYA2448@00Q241`aS00<@Q0aS36<00PaS0a241@aS0PQ20PaS0PQ200@<
Ha2436<<H`88@P8<H`8@Q0@8@P0536<8@PaS248<H`0224800`aS48@DY@0936<00`Q236<<H`042480
0`aS2488@P0336<5248436<4248336<2248136<000<48@0300048@0000848@0824848@@Q248e[Fmk
E[D]J`8mk`@icP8mk`06=JdaS36<<H`e[C6<12U:00@]Jc6<;F/aS08]J`@YBP8U:@04:DX]JbU:;F/2
<H`012e[:DXYBRe[0S6<0RU:0RDY00H]Jc6<<H`aS2e[:DX3;F/3<H`00be[9BTU:@02:DX00be[:DXU
:@02:DX012e[<H`e[C6<0SF]00<aS2e[9BT00RDY00LQ22DY8@PQ22DY8@PU:@03:DX012DY8@PLib48
0RDY00@YBR489BTQ208YBP<U:@<YBP049BTQ22DY9BT36<H27>L01AS67>LQ22DY8@P01QcW00<Q21S6
6<H00aBU00<HaQcW8@P00QS600<DYAS67>L00QcW00<HaQBU6<H00QcW0QS60R4800@LiaS66<HQ20<U
:@<Q208Li`046<HDYAS66<H47>L01B489BTYBRDY7>L00QS60QcW00DU:B488@PQ21cW00@HaP038@PL
iacW008HaP037>LU:B4800<Q20057>LHaQBU5:DHaP035:D26<H28@P27>L26<H27>L00aBU6<HDY@03
6<H28@P00acW6<HHaP038@P27>L26<H47>L26<H37>L011S65:D@Q1BU11cW00@HaQBU5:D@Q08DY@<H
aP8Q200<7>LHaQBU6<HLiaS68@PU:AcW5:D@Q1BU0R480QS600DLic6<=Jde[C6<008U:@068@PLiacW
7>LQ21cW0QBU00DHaQcW6<HDYAS6008DY@8HaP0?8@PLiacW7>LHaQcW5:DHaQBU6<H@Q1S67>LHaQBU
00D@Q0035:DHaQS6008@Q0035:DHaQBU008DY@056<HLiacW6<HDY@046<H25:D36<H27>L26<H55:D3
48@00aBU6<HHaP035:D00aS65:DHaP035:D348@65:D01aS65:DDYABU48@DYAS6008Li`056<HDYAS6
48@DY@0348@55:D448@01AS65:DHaQS65:D00a2400DDYAcW7>LDYAS6008DY@046<H@Q12436<548@3
5:D248@011BU6<H@Q1240aBU0Q2400<<Ha2436<00a2400@<Ha2436<<H`@@Q0045:D@Q1BU48@26<H0
11BU48@<H`Q2112400<<Ha2448@00Q241@aS0a2400L<Ha2448@@Q0aS48@DY@0248@236<00a2436<<
H`0248@010aS2488@PaS0Q240PaS00<@Q1BU48@010aS00H@Q1BU36<<H`Q248@25:D448@00aBU48@8
@P0836<01Q2436<<Ha245:D@Q0H<H`88@PD<H`<@Q08<H`88@P0436<@Q12436<2248236<00`Q236<<
H`0;36<00`Q236<8@P0236<00`Q236<<H`0236<624800a2436<<H`02248436<010Q21248@PQ21@aS
0@Q200000`0012448@0812403@Q2;F]W>Dic<H`e[D8@?Nm6<DYBAS4mkcW>008e[@05>Lhe[C6<;F/Y
BP04;F/02BU:;F/e[CF]<H`]Jb489BTYBP02;F/2:DX012e[>LhaS36<0be[00@aS3F]<H`]J`8YBP05
;F/aS36<;F/YBP039BT2:DX29BT012e[=Je243g_0S6<00@YBRDY:DXU:@8YBP03;F/aS36<008]J`<Y
BP<U:@048@PU:B488@P59BT3:DX012DY:DXU:BDY0R4812DY0R4800DU:BU:;F/YBRDY00<Q20037>LH
aQcW00@Li`066<HLiacW6<HLiaS60QcW00PHaQBU48@DYA247>LHaQcW11S600<DYAS66<H00QcW0QS6
00@Lib487>LLi`8Q20037>LHaQS600<Li`068@PLiacW7>LDYA240QBU1AcW0R4800<LiaBU7>L00RDY
00@Q21cW7>LLi`@Q20067>LHaQS66<HLib4811cW0R480QcW11S60QBU00LHaQBU5:DHaQBU7>LHaP02
7>L011S65:DDYABU0aS60QcW00<Q21cW8@P00QcW00HDYAS66<HQ21cW6<H25:D37>L00aS65:DDY@05
6<H25:D00a245:DHaP027>L011S65:DHaQS60QcW0QS600<DYAS66<H00QBU00H@Q1BU5:DLib487>L2
6<H011BU6<HLib480RDY00XaS3F]>Lhe[BDY8@PLib489BTLi`8HaP<Li`8@Q08DY@8HaP055:DHaQcW
7>LHaP037>L00aS65:DHaP035:D01aS67>LDYABU48@HaQBU008@Q08DY@8HaPDDY@@HaP067>LHaQS6
6<HDYA240aBU0QcW00@Q21cW6<HLi`8HaP0:5:D@Q1BU5:D@Q1BU48@DYA246<H25:D248@25:D00aS6
5:DDY@035:D348@25:D01A245:D@Q1246<H00QcW00HHaQ246<HHaQcW6<H25:D011245:DDYABU1124
00@DYA2448@HaP<DY@0548@DYAS66<HLi`026<H25:D011S65:DDY@aS11240QBU112400@DYA2448@@
Q08<H`8@Q0085:D@Q12436<@Q0aS48@DY@@@Q00336<@Q1BU00D@Q0045:DHaQBU48@236<548@00`aS
48@<H`0536<348@00`aS48@<H`0348@436<548@00`aS48@<H`0236<00`Q236<<H`0248@336<01A24
5:D@Q0aS24800`aS1a240QBU0Q2400<<Ha2448@00PaS00<8@PaS24800`aS00@8@Q2436<@Q08<H`05
248<H`aS36<8@P0336<00a2436<<H`0436<010Q236<<Ha240PaS10Q24@aS00<8@PaS24800PQ210aS
0PQ22@aS0PQ200<48@Q236<00PQ20`aS0@Q20@@Q00001@@Q00048@@Q00000`@Q00X8@P@Q1248@SF]
JeY>Lbe[?Nm2408mk`05@Q16<DYB@Q0mk`03>Lh01C6<;F/]JbU:;F/00S6<0Re[00Le[CW>=JdYBRDY
;F/YBP029BT01BU:;F/]JbU:;F/00c6<0Re[0S6<0SF]00T]JbU::DX]Jc6<;F/YBRDY:DX00RDY0RU:
00daS2e[>Li243W>=JdYBRDY:DXQ22U:;F/aS002;F/00bU:;F/]J`02;F/022U:9BTQ22DY8@PU:BU:
9BT2:DX00bDY:DXU:@02:DX00be[:DXYBP029BT012489BTQ22DY124800/U:BU:9BTU:BU:9BTQ21cW
6<HLib48008Li`038@PLiaS6008HaP037>LQ2248008Li`8HaP@DY@036<HDYAS6008Li`DHaP035:DL
ib4800@Q20<Li`<HaP077>LU:B488@PLiaBU6<H00QBU00THaQcW7>LLiaS67>LQ21cW6<H00QcW00HQ
21cW6<HLib487>L48@P011cW6<HHaQS60QcW00HDYAcW8@PYBRDY8@P27>L26<H25:D00aS65:DDY@02
5:D26<H00acW6<HDY@036<H35:D27>L26<H00b487>LQ20076<H35:D00aS68@PLi`036<H35:D26<H6
5:D00aS65:DDY@036<H37>L021S65:DHaQBU6<HDYAS65:D46<H00aBU6<HHaP028@P29BT01b48<H`i
cS6<:DXLiaS6008Q208Li`056<HLiacW7>LHaP0248@25:D67>L01B486<HHaQBU6<H00QBU00@@Q1BU
6<HHaP<DY@8@Q0DDY@046<HDYABU5:D26<H01QBU6<HHaQS67>LHaPDDY@<HaP067>LQ21cW6<HLiaS6
1ABU0a2400<DYA2448@01ABU00<@Q1BU48@01QBU00H@Q1BU5:DDYA2436<25:D27>L36<H25:D01AcW
6<HDY@aS48@00aBU00T<Ha2448@@Q1BU6<HLiaBU48@00QBU0QcW0aS600PDYAS66<HDY@aS48@<Ha24
0aBU0Q240aBU00@@Q1BU48@@Q08<H`<@Q0065:D@Q0aS36<@Q0aS0a240`aS00<@Q0aS48@0112411BU
00D@Q0aS36<<Ha24008<H`0448@<Ha2448@436<248@436<448@336<348@01@aS48@<H`aS48@00PaS
00H8@PaS36<@Q1BU48@336<248@236<01Q2436<<H`aS48@<H`8@Q00436<@Q1245:D248@436<01Q24
36<<Ha2436<8@P<<H`0448@<H`aS248236<01A24248<H`Q236<00`Q21PaS0`Q200<<Ha2436<00`Q2
1PaS0`Q200@<Ha2448@<H`88@PD<H`<8@P<<H`<8@PL<H`<8@P0336<8@PQ200D8@P8<H`000P@Q00H0
00@Q12448@00248212403`00248YBVLiDY@icTYB@Q0icSF]>LhmkcW>=JdicP03@Q02>Lh01C6<;F/]
JbU:<H`00SF]00<aS2e[:DX00Re[0S6<00D]Jc6<=JdaS2e[008YBP04<H`icSF]<H`3;F/013F]>Lha
S2e[0RU:00<]Jc6<<H`00RU:00@Q22DY;F/]J`8aS003:DXaS2e[008YBP03;F/aS3F]00<]J`05<H`]
Jbe[;F/U:@05:DX39BT00be[=Jde[@03<H`3;F/2<H`012e[9BTU:Be[0bDY00DYBRDY7>LLib48008Y
BP049BTLiacW7>L28@P47>L28@P012DY8@PQ22480acW0QBU0aS600<DYAS648@00QBU00<HaQBU6<H0
0QBU00HHaQBU6<HLib489BT37>L01B486<HHaQcW8@P00QcW00HQ22DY9BTQ21S65:D27>L01BDY8@PL
iaS67>L00QS611cW0R480QcW00<Q21cW9BT00bU:00<Q21S67>L00QBU00@HaQcW8@PLi`<Q20DLi`03
6<H@Q124008DY@<HaP095:DHaQS65:DHaQBU6<HLiaS6008DY@0<6<HU:B488@PU:B486<HDYAcW8@PL
iaS60Q2411S600<DYA245:D00QBU0QcW00<HaQBU5:D00aBU0a240QBU00<@Q1BU48@00QBU00<HaQBU
5:D00QS60acW00<HaQBU5:D00aS600<Lib487>L00QcW00DU:Be[<H`YBRDY008HaP@Li`8Q20047>LH
aQBU5:D36<H35:D36<H01ABU6<HHaQS65:D00QS600<LiaBU48@00QBU00<HaQBU48@00Q2400LDYAS6
48@DYAS68@PLi`055:D00aS65:DDY@025:D01Q245:DDYAS65:DHaPDLi`@HaP@DY@067>LHaQBU48@<
Ha241aBU0Q2411BU0a241ABU00@HaR488@PLi`@HaP068@PHaQBU48@DYAS60QBU00@@Q1BU5:DDY@8@
Q0<DY@<HaP<Li`038@PDYA24008@Q0036<HDYA2400<<H`0348@<H`aS008@Q0035:DHaQ2400<<H`03
48@DYA24008@Q0<<H`<@Q0L<H`H@Q0<DY@<@Q0035:D@Q0aS00@@Q0H<H`8@Q08<H`04248@Q12448@3
36<0112436<<H`aS0Q2410aS1a240`aS0a2410aS0Q240PaS00<@Q1BU5:D00Q2420aS0a242PaS00@@
Q0aS36<<H`8@Q08<H`03248<H`aS00@<H`03248<H`aS008<H`88@P<<H`88@P<<H`03248<H`aS00D<
H`03248<H`Q200<8@P8<H`08248<H`Q2248<H`Q236<8@P8<H`0448@<H`aS248236<4248010aS248<
H`aS0@Q200000`0012448@0212400`0012448@0312401PQ2;F]JeT8@<H`mk`924004>Lhe[CF]=Jd3
>Lh2@Q001Sg_>Lh]Jbe[<H`e[@8icP<aS08]J`04:DX]Jc6<<H`2=Jd0636<;F/U:BU:<H`YBRe[<H`e
[C6<;F/aS3W>=JdaS2U:;F/aS2e[:DX]Jc6<:DXU:@8YBP03=JdaS36<00@]J`04:DX]Jbe[=Jd2<H`5
;F/2:DX2;F/2:DX01RDY:DXYBRU:;F/e[@8icP8aS004;F/aS3F];F/3:DX29BT38@P00bDY8@PLi`02
8@P29BT01B487>LLiacW8@P00QcW00@Q21cW9BTQ208U:@<Q20HHaP@DY@<HaP035:DHaQBU008HaP03
5:DHaQcW00@Q20037>LQ21S600<HaP8Q200;7>LU:BU:8@PHaQBU6<HQ22DY8@PLi`026<H27>L011S6
7>LLib480acW00DHaQcW8@PQ22DY008YBP039BTHaQS6008Li`8HaP037>LQ22DY008U:@<Li`036<HD
YA24008DY@0348@DYAS6008HaP8DY@046<HDYAS66<H27>L02ABU6<HDYAS67>LQ22DY8@PLi`025:D2
7>L011S65:DDYABU0aS600<@Q1S66<H00aBU00HHaQcW7>LLiaS65:D248@35:D00a245:DDY@045:D3
6<H00aBU6<HDY@047>L01AS648@HaQS67>L00R4800HLiaBU8@P]JcF];F/37>L00aS67>LLi`037>L0
0aS67>LHaP026<H35:D26<H011cW5:D@Q1S60QcW0aBU0aS600@DYAS65:DDY@<@Q0045:D@Q1245:D3
7>L75:D26<H248@35:D01AS65:DHaQS65:D00QS600@LiaS66<HDY@8HaP8DY@8HaP035:D@Q1BU008D
Y@<@Q0045:DHaQS66<H35:D248@00aBU48@DY@0348@00aBU48@DY@056<H011cW8@PLiaS60QBU0QS6
1aBU00<HaQ245:D00QBU0aS600LDYAS69BTLiaBU36<@Q0025:D00a2436<<H`0236<548@25:D01@aS
48@@Q1BU48@00`aS00H@Q0Q236<@Q1BU48@736<348@020aS5:DDYABU48@<Ha245:D348@336<01124
36<<Ha240`aS0Q2400<<Ha2436<00PaS0Q2400<8@PaS36<00Q241PaS0Q2400<<Ha245:D00QBU0PaS
0a240PaS00<@Q1BU36<00`aS00D@Q0aS48@@Q1BU008@Q0045:D@Q0aS36<2248436<348@236<248@4
36<00a24248<H`0736<01@Q236<<H`aS24800PaS00<8@PaS36<010aS00@8@PaS248<H`@8@P8<H`07
48@<H`aS248<Ha2436<010Q200<<H`Q224800PQ200<<H`Q236<02@aS00H8@PaS36<8@PaS248336<1
24800005124000@Q1240000512401P00248YBU[F@Q0YBP8e[@0;<H`e[CF]>Lhe[C6<=JdicSg_>Lha
S002;F/00c6<?Nm24002@Q000cg_>Lhe[@07;F/00cF]<H`aS002;F/5<H`2;F/012U:;F/]Jbe[0RU:
00H]Jc6<=Jde[C6<;F/2:DX2;F/2<H`00cF];F/YBP03:DX29BT01be[<H`aS2e[<H`e[C6<00<U:@<i
cP05;F/YBRDY;F/aS003;F/3<H`4;F/00bU:9BTQ20028@P01bDY8@PQ21cW8@PLib48008Li`098@PL
iaS67>LQ22DY8@PLib48008Li`038@PLib4800@Q20047>LQ21cW7>L26<H00acW6<HDY@036<H25:D0
1AS65:DHaQcW6<H00acW0aS60QcW00LQ21cW6<HQ22DY:DXU:@028@P39BT00b487>LHaP027>L01B48
6<HHaQS67>L00RDY0R480acW00HQ22U:9BTU:B489BT28@P02QcW6<HLiacW9BT]JbU:8@PLiaS60QcW
00@HaQBU5:D@Q0LDY@066<HDYABU5:DHaQBU0QS600<Q21cW6<H00QS600<LiaS66<H00QBU0QS60QBU
00<@Q1S65:D00QBU0QS60aBU0QS60QBU00@HaQBU5:DDY@D@Q0<DY@8@Q0066<HLiaS66<H@Q1BU0QS6
11cW00/HaQcW7>LLib487>LHaRU:<H`icSF]00<Li`036<HLiacW008Li`8HaP035:DHaQcW008Li`04
5:DHaQS66<H45:D01A245:DDYABU6<H011BU00@@Q1BU5:DDY@8@Q0085:D@Q1246<HDYAS67>LHaP<D
Y@<HaP075:DHaQBU5:D@Q1BU6<H01ABU00<HaQcW6<H00QcW0QS60Q2400DDYAS66<HDYA2400<HaP03
5:D@Q1BU00<HaP8DY@0948@DYABU5:D@Q1BU48@DYA24008DY@8HaP<DY@8HaP045:DHaQcW7>L36<H2
5:D01a245:DDYA245:D@Q1BU008HaP055:D@Q1BU7>LHaP025:D00aS67>LDY@0248@00aBU48@@Q004
48@00`aS48@@Q00748@01PaS48@<H`aS48@8@P<<H`8@Q08<H`0548@8@PaS36<@Q00236<01a245:DD
YA2436<@Q1BU008<H`P@Q08<H`@@Q0045:D@Q0aS36<248@236<248@00aBU48@<H`0436<02`Q236<<
Ha2436<U:C6<:DXLi`Q236<011240`aS00<@Q0aS48@00PaS00@@Q0aS36<<H`@@Q0D<H`0548@<H`aS
36<@Q00336<00a245:DDY@0736<00a2436<8@P0436<01PQ236<<Ha2436<8@P@<H`03248<Ha2400<<
H`<8@P<<H`05248<H`aS48@<H`0224800`aS2488@P03248636<424801@aS48@<H`@Q24800`aS00<8
@PaS36<00`aS0A240@Q2000212400`0012448@0612403PaS;F]Nmd8@:DXaS3W>=JdaS3F]>LhaS3F]
<H`2=Jd00cW><H`aS002;F/02CF]>Li244YB@Q0mkcF];F/aS004:DX00c6<;F/aS003<H`01Re[<H`a
S36<=JdaS08]J`03:DXaS36<008]J`8YBP05;F/aS36<=JdaS004;F/4<H`01Be[:DXYBRU:;F/00RU:
0Re[00@aS3F]<H`]J`8U:@04:DXaS3F]=Jd4;F/00bDY:DXYBP03;F/00c6<;F/YBP03:DX01R487>LQ
2248:DXQ208Li`048@PHaQcW8@P37>L00aS67>LQ20038@P27>L00b487>LQ20058@P011cW6<HDYAcW
0R4800@HaQBU5:DLi`8HaP065:D@Q1BU5:DLib480QcW0QBU00<LiaS68@P00QcW00@HaQcW7>LQ208Y
BP078@PLiacW9BT]JbU:8@P00QcW00<HaQcW6<H00QS600<Lib488@P00bDY0acW1BDY00<Q21cW7>L0
0QcW00<HaR489BT00Re[0b4800<LiaS65:D011BU00<@Q1BU48@00aBU00<HaQBU6<H00QS600HDYAS6
7>LLiaS65:D38@P011BU48@DYAS60QcW00D@Q1BU6<HHaQ24008DY@066<HDYA2448@HaQcW0aS60QBU
0Q240aBU00<@Q1BU48@00QBU00H@Q1BU5:DHaR486<H248@01AS67>LLiaS65:D00QcW00/Q21cW7>LL
iaS69BT]Jc6<=JdYBR4800@Li`048@PLiacW7>L26<H27>L56<H00aBU48@DY@035:D00a245:DDY@07
5:D00a245:DDY@035:D248@36<H35:D011S65:D@Q1BU0QS600@DYA246<HHaP<DY@8HaP8DY@<Li`@H
aPLDY@046<HDYA2448@25:D00acW6<HDY@0248@25:D448@01QBU48@DYAS65:D@Q08DY@037>LHaQBU
008DY@046<HLiaS65:D26<H00acW6<H@Q0025:D248@01ABU6<HHaQBU48@01aS600@DYA2436<@Q08D
Y@0436<@Q1245:D348@01ABU48@@Q1245:D00Q2400D<Ha2448@DYA240088@P0336<@Q12400<<H`8@
Q0045:D<H`aS36<248@00aBU48@@Q00236<248@011BU48@@Q1BU0`aS0a240PaS00<DYA2448@00PaS
0a240`aS0a241`aS00@@Q0aS248Li`8aS0078@P8@PQ236<@Q1BU48@00`aS0Q240PaS0Q240QBU00<@
Q0aS36<00Q241@aS0PQ200<<Ha2436<00PaS00@@Q0Q236<<H`8DY@0348@<H`aS00X<H`03248<H`aS
008<H`03248<H`Q200<<H`03248<H`aS00<8@PH<H`8@Q08<H`88@P031248@PQ200H<H`06248<H`Q2
36<8@PaS0PQ200<<Ha2448@00PaS00<8@PaS24800PaS00<@Q0aS36<00@Q20000100012448@000P@Q
00`000Q2248000@Q248icW>LDY@U:CW>?Nl2=Jd00cW>AS5:DP02@Q000cg_=JdaS002:DX2;F/2>Lh0
1Cg_@Q1243g_>Lh00S6<00D]JbU:9BTYBRe[008aS08]J`8YBP03;F/aS3F]00<aS00:;F/aS3F]>Li2
43g_=JdaS2e[9BT3:DX2;F/3<H`013F]<H`aS2e[0RU:00<U:Be[<H`012e[00DaS2U::DXU:B48008]
J`03=JdaS36<008]J`8U:@038@PU:BDY00@YBP059BTYBRDY:DXQ20027>L28@P012DY7>LLiaBU0QS6
0R480QcW00<HaQBU6<H00QcW0aS60R4800DLiaS66<HLib48008U:@8Q20047>LQ21cW8@P27>L45:D3
6<H00acW6<HHaP045:D26<H37>L26<H01QcW9BTYBRDY8@PLi`@Q208YBP048@PLiaS66<H47>L01b48
:DXQ22487>LHaR4800<U:@8Q20@U:@088@PU:BDY:DX]JbU:9BTQ208Li`8DY@0648@<HaBU6<HLiaS6
0Q2400<DYAS67>L00QS60QBU0acW0aS611cW00<HaQ245:D00QBU0aS600<LiaBU5:D00Q2400<HaQBU
48@00Q2400<HaQBU5:D00Q2400D<Ha2448@DYAS6008DY@8@Q0<DY@8HaP075:DHaQS67>LQ21cW6<H0
0aBU00LHaQcW7>LLiaS69BT]J`02=Jd00be[:DXU:@028@P00bDY7>LLi`026<H011cW6<HDYABU0QS6
11BU00<HaQBU5:D00a2400<DYAS65:D00Q2400H<HaBU5:DDYA245:D348@00aBU6<HDY@055:D248@0
0aBU6<HLi`026<H00aBU6<HHaP026<H248@25:D01AS67>LLiacW6<H00QBU0QS60QBU00@@Q1BU6<HD
Y@8@Q08HaP085:DHaQS65:DHaQ246<HDY@@@Q0045:DHaQBU48@25:D02AS65:D@Q1S67>LHaQBU48@H
aP045:D011S65:DHaQS60aBU00H@Q1BU5:DLiaBU48@25:D01B487>LLiaS65:D00QS600D@Q0aS48@@
Q1BU00L@Q00336<@Q12400D@Q00336<@Q124008<H`88@P@@Q08<H`0348@<Ha2400<@Q0035:D@Q0aS
008<H`065:D@Q0aS36<@Q1BU0a2410aS0a2400HDYA2448@DYA245:D348@01`aS48@@Q1BU48@<Ha24
00<<H`05248<H`aS36<HaP027>L01QS648@<Ha2436<DY@8@Q0@<H`@@Q00436<@Q1BU48@236<248@0
1@aS248<H`aS48@00PaS00D8@PaS48@<H`Q2008@Q0045:D@Q12448@536<248@<36<01a2436<<Ha24
36<8@PaS0088@P<<H`05248<H`aS36<@Q00236<010Q236<<H`aS0`Q200<<H`Q224800PQ200<<H`Q2
36<00`Q200<<H`Q236<00PaS00@@Q0aS36<8@P<<H`8@Q08<H`0010@Q00D000@Q12448@Q200848@05
248e[GNmG_LaS002?Nl013F]>LhicSg_0d8@0cg_00@aS2U:9BTYBP8aS007=JdicT8@?NlicSF]>Lh0
0S6<00DYBRDY:DXYBRe[00<YBP03<H`]JbU:008aS005=Jd]Jbe[;F/icP02?Nl0148@?NlicSF]0Re[
00/U:BU:9BTYBS6<;F/e[C6<;F/e[C6<008]J`8YBP08;F/aS36<:DX]Jc6<=JdaS0<YBP039BTYBRe[
008aS003;F/YBRU:00@Q20099BTYBRU:;F/YBRe[:DXU:B48008Li`8U:@057>LHaQS67>LQ20026<H0
0acW8@PLi`026<H28@P00acW5:DLi`047>L38@P01BDY7>LQ22489BT00R4811cW0QS600DDYAS66<HH
aQcW008HaP<DY@8HaP045:DHaQS65:D36<H01AcW9BTU:BDY7>L00R4800<Lib489BT00RDY00<Q21cW
7>L00QcW1R4811cW00TQ22DY9BTU:AcW8@PU:BU:9BT00R480RDY00LYBRe[9BTQ22DY7>LHaP035:D3
48@00aS65:DDY@027>L00b486<HHaP025:D36<H01QBU48@LibDY:DXLi`8DY@<HaP8DY@036<HLiaS6
00PDY@<@Q0<DY@8@Q08DY@036<HDYA24008@Q0066<HDYABU5:DHaQBU0QS61AcW00<@Q1BU5:D01AS6
00LYBSW>=JdaS2DY7>LU:@028@P29BT00acW6<HDY@026<H35:D01AS65:DHaQBU6<H00aBU00D@Q1BU
48@DYAS6008DY@<@Q0035:D@Q124008DY@8@Q00<6<HDYABU5:D@Q1S648@DYAS65:DHaQcW0QBU00<@
Q1BU6<H011S60QBU00LLib488@PLia245:DHaP027>L011BU48@@Q1BU0Q2400<DYAS66<H00aBU00<H
aQBU5:D00Q2400<DYAS648@00Q240QBU0Q240QBU00@@Q1BU6<HHaP@DY@036<HDYABU008DY@@HaP03
5:D@Q12400<DY@8HaP035:D@Q1BU00HHaP8DY@0448@DYABU5:D248@35:D448@236<348@336<00a24
36<<H`0236<348@436<248@00`aS48@@Q0025:D248@236<00a2436<@Q00236<448@236<01Q245:DD
YA2436<@Q08DY@@@Q00336<@Q0aS00H@Q0D<H`<DY@046<H@Q12448@45:D436<548@011BU48@@Q124
10aS112400<8@PaS36<00`aS00@@Q0aS36<DY@<@Q003248<H`aS008@Q0055:D@Q12436<8@P0236<0
0a2436<<H`0336<448@336<00`Q236<<H`0236<2248236<348@00`Q236<8@P0336<4248010aS48@<
H`aS0PQ200D<H`Q236<8@PaS0088@P8<H`8@Q003248<H`Q20088@P4<H`4@Q04<H`0000<000@Q0000
0P@Q00h000@Q1248@P@Q0008@Re[HaQ:DSF]?Nm6<DYB0THa00A243W>@Q12408mk`03=JdYBRe[008Y
BP03;F/aS36<008aS08]J`06=JdaS3W>>LhaS2U:0RDY0bU:0c6<00L]JbU:;F/]Jc6<=JdicP02=Jd0
1CW>?NlmkcW><H`00Re[00HaS3F];F/U:BU:<H`2>Lh3<H`012U:;F/]Jbe[0c6<0Re[00DYBSF]>Lhm
kcW>008]J`05:DXU:BDY:DX]J`02:DX28@P29BT6:DX01be[9BTQ22DY:DXU:B48008HaP037>LHaR48
00@Q20057>LHaQcW6<HLi`026<H00aBU6<HHaP027>L01AS67>LQ21cW8@P01AcW0R480QcW00@DYAS6
7>LLi`8HaP035:DLiaS6008DY@076<HLiaS66<HDYAS65:D011S600DDYAcW8@PQ21cW008HaPDQ208H
aP058@PU:BU:9BTLi`029BT28@P011cW8@PU:BDY0R4800@LibDY9BTLi`<Q208Li`049BTYBRDY8@P4
7>L00aBU6<HDY@045:D248@01QBU8@PU:B486<HLi`8Q20046<HDYA2448@35:D01AS65:DLiacW8@P0
0QcW11S61QBU112400DHaQBU5:DHaQBU008@Q0045:DHaQBU5:D248@00aBU6<HHaP025:D56<H00acW
5:DDY@036<H02QBU48@DYAcW8@P]Jc6<;F/YBR480acW0b4800DLiaS66<HHaQcW008HaP035:DHaQBU
00<@Q0@DY@0348@DYABU008HaP@DY@0548@DYA2448@DY@026<H25:D26<H45:D011S67>LHaQBU0aS6
0QBU0QS600@DYA245:DHaP@Q20046<HDYABU6<H25:D02a245:DHaQ2436<DYAS67>LHaQBU7>L00QBU
00@@Q1BU5:DDY@D@Q0045:DHaQBU48@65:D01aS65:DHaQBU6<HDYA2400@DY@0348@DYABU00<DY@03
6<HDYAS6008DY@056<HLiacW6<HDY@026<H00acW6<HHaP025:D00a245:D@Q0025:D348@35:D336<4
48@00`aS48@<H`0336<448@536<748@010aS48@<H`aS0Q240QBU00<@Q0aS36<01Q240PaS00<@Q1BU
48@00PaS1Q2400<<Ha2448@00`aS112410aS00<@Q0aS48@00a2410aS0a240PaS00<@Q0aS36<00PaS
112420aS00<@Q0aS36<00PaS0a2400<<H`Q236<01A241@aS00X@Q0aS36<<H`Q236<@Q1S65:D@Q0@8
@P8<H`04248<H`aS48@236<00`Q236<<H`0236<324800`@Q2488@P04248536<01`Q236<8@PQ236<@
Q0aS00<8@PH<H`002`@Q00H8@RU:G_M242e[>Lh3@Q02?Nl01T8@?Nm6<DHa>Lhe[@<]J`03:DXU:BU:
00@]J`03<H`]Jc6<00<e[@05<H`YBRU:9BTQ2002:DX2<H`01Be[:DXYBRDY:DX00S6<00<icSF]>Lh0
0SW>00=243g_=Jd012e[00@YBRe[<H`e[@DaS004;F/YBRe[:DX2;F/00c6<;F/YBP02;F/01CF]>Lhe
[C6<:DX00RDY0be[00@U:AcW9BTU:@@YBP<]J`03:DXU:B48008U:@06:DXU:AcW7>LHaQcW0R4800<L
ib488@P00R481AcW0aS600DLiaS66<HDYAS6008Q20@Li`038@PLiacW00<Li`8HaPDLi`045:D@Q124
5:D26<H45:D00aS65:DHaP026<H01AcW8@PQ22486<H011cW00<U:BU:7>L00QS600LQ22U:8@PQ21cW
9BTQ20039BT28@P01BDY8@PU:B487>L00b480RDY0R4800<U:B488@P00R480QcW0QS61ABU0Q2400<H
aQcW8@P00QcW00<Q21S66<H00aS600<LiaBU48@00Q240aS60acW00@Q21cW7>LHaP<DY@8HaP035:D@
Q1BU008@Q08DY@037>LHaQBU008DY@0348@DYAS6008HaP035:D@Q124008@Q0@HaP8DY@@HaP085:DH
aQBU6<HDYAS65:DU:@8e[@07;F/Q21cW9BTQ21S67>L00R4800<LiaS67>L01AS60QBU00@@Q1BU5:D@
Q0<DY@0348@DYABU008HaP@DY@0348@DYA2400@@Q0045:DHaQS66<H45:D011S67>LHaQBU0QS60aBU
00@HaQBU6<H@Q08HaP067>LU:B488@PLiaS61QBU0a2400<DYAS65:D00QcW00HDYA2436<@Q1BU48@2
36<011245:DHaQBU0Q2400<DYAS65:D00a240aS61aBU11S600L@Q1BU5:DDYA245:DHaP035:D37>L0
0aBU6<HLi`056<H35:D011245:DDYA240QBU1Q240`aS0a240`aS0Q240QBU0a240PaS0Q2400<DYA24
36<00PaS0a240PaS00<DYA2448@00a240PaS0Q240`aS0Q240`aS00H@Q0aS5:D@Q1BU48@436<00a24
36<<H`0748@01@aS48@@Q1BU48@00PaS00<@Q1BU48@00PaS0Q240`aS0a240`aS00@DYA2448@@Q0@<
H`0348@<H`aS00<<H`0548@DYA2436<@Q00436<548@436<248@336<248@01QBU48@<H`aS248<H`@8
@P<<H`0448@<H`Q236<224800`aS2488@P02248010aS2488@PQ20PaS10Q200L<H`Q236<8@PaS48@<
H`02248336<00`Q236<<H`0136<0000400048@@Q000212402`001248@P001248@Re[G_M:DRU:=Jd0
0c6<0SF]00@aS3F]<H`aS08e[@05<H`e[Be[;F/YBP02;F/2<H`2;F/2<H`01Cg_>LhaS2e[8@P00RDY
00PQ22U:;F/aS2e[:DXU:BU:0RDY00<YBRe[=Jd00SF]00dicSF]>Lhe[C6<;F/YBS6<;F/YBRe[<H`e
[@04<H`8;F/012U:9BTU:BU:0Re[0RU:00D]JbU:;F/]Jc6<008]J`059BTQ22DY:DX]J`029BT012U:
<H`aS2e[0RDY00@Q22DY9BTU:@8Li`8HaP037>LQ22DY008Q20069BTYBRU:9BTLib481acW00@HaQBU
5:DHaP8Li`056<HDYABU6<HLi`046<H67>L26<H00aBU6<HDY@035:D26<H00aBU6<HHaP028@P27>L0
11S67>LHaQBU1aS600<DYAS67>L00R4800<U:B488@P00b4800@U:B489BTU:@8Q20047>LQ22487>L3
8@P37>L012486<HHaQBU1QS60aBU00<HaQBU6<H00QcW00@Q21cW7>LLi`8HaPDDY@8@Q08DY@076<HD
YAS66<HLiaS65:D00QS600<LiaBU48@00a240aBU00@@Q1BU6<HLi`<HaP035:DHaQS6008DY@0348@D
YABU008DY@HHaP035:DHaQBU008HaP037>LDYABU008HaP0:9BT]Jc6<:DXQ22U:;F/U:AcW5:D36<H0
1QBU6<HHaQBU48@DY@HHaP037>LDYABU00<@Q0<HaP8DY@056<HDYA2448@DY@026<H01ABU48@@Q124
6<H00QBU00<HaQcW8@P00acW00<HaQBU5:D00acW0QBU0a2400@HaQcW8@PQ208Li`045:DHaQBU48@3
5:D01Q245:D@Q1245:D@Q08HaP055:D@Q0aS48@DY@026<H01A2436<<Ha245:D00a2400<DYAS65:D0
0aBU00DHaQcW6<HDYA24008DY@046<H@Q12448@45:D248@25:D26<H00aBU6<HDY@036<H01ABU6<HL
iacW6<H00Q2400<DYAS648@011BU00<@Q1BU5:D00Q2400@<Ha2448@@Q08DY@T@Q00336<@Q0aS00@@
Q0035:D@Q124008<H`<@Q08<H`@@Q0<<H`8@Q00536<8@PaS5:D@Q00236<00a245:D@Q00336<248@6
36<00a2436<@Q00348@25:D348@00`aS48@@Q00348@236<448@236<02A2436<<Ha245:D@Q0aS248<
H`0248@010Q236<<H`Q20PaS00D@Q0aS48@@Q1BU00H@Q00336<8@PaS008<H`0748@<H`aS36<DYAS6
48@00`Q200<@Q0aS48@00Q240PaS0PQ20`aS00D8@PaS36<DYA24008<H`88@P0336<8@PQ20088@P03
36<8@PQ200<8@P8@Q0<<H`03248<H`aS008<H`88@P<<H`03248<H`aS008<H`48@P0000D48@001244
8@0000848@0;24848@@Q1248@RU:G_M:DRe[=JdicP02=Jd3<H`2=Jd00c6<;F/aS002<H`3;F/00bU:
<H`aS003<H`01be[<H`icT8@?Nle[BU:008U:@077>LU:Be[<H`e[Be[:DX00bDY0RU:0S6<0cF]00ha
S3F]=Jde[C6<;F/Q22DY:DX]JcF]<H`]JcF]0c6<1Be[00@YBRe[;F/YBP8U:@03:DX]Jbe[00DYBP05
<H`e[Be[9BTLi`02:DX39BT02Be[<H`e[BU:9BTQ22DY;F/U:@027>L26<H27>L49BT01BU:9BTU:BDY
8@P01acW0QS60QBU0aS600<DYAS66<H01AS60QBU00DHaR488@PHaQBU008HaP@DY@8HaP<DY@@Li`<H
aP8Li`036<HDYAS6008DY@8HaP087>LHaQS66<HQ21cW9BTYBP<U:@058@PU:BDY9BTQ20027>L01248
9BTU:B4811cW0aS60acW11BU0QS60QBU00D@Q1BU6<HLiaS6008Q20037>LHaQBU00<HaPHDY@046<HD
YABU5:D36<H00aBU6<HHaP026<H25:D011245:DDYA240QBU0aS600@LiaS65:DHaP8Li`036<HDYABU
008DY@0448@HaQS67>L25:D01aS67>LDYA245:DHaQcW008DY@8HaP035:DLibDY008]J`0;9BTYBRe[
:DXU:AS67>LHaQBU6<HDY@026<H01ABU48@@Q1245:D00QS600@Q21cW6<HDY@8@Q0@HaP8DY@076<HD
YABU5:D@Q1BU6<H00QBU11240QBU0acW00@HaQcW6<HDY@8HaP8Li`046<HDYAS648@25:D00a246<HH
aP027>L00aS65:DDY@025:D00aS65:DDY@0248@45:D00aS65:D@Q00236<011BU6<HDYABU112400<D
YA2448@01aBU0aS611BU0a240aBU00D@Q1BU5:DDYAS600@DY@046<HLiacW6<H25:D011S67>LHaQS6
0QBU0aS600<DYA2448@00aBU0Q2400<<Ha2448@00Q2400P<Ha245:D@Q1BU48@<Ha240QBU00<@Q0aS
36<01Q2400<DYA2436<00PaS00<DYA2448@00PaS0Q2410aS0Q240PaS212400<<Ha2436<00Q2400<<
Ha2436<00PaS00@8@PaS36<<H`8DY@<@Q08<H`<@Q00336<8@PaS00<<H`0448@<H`aS36<648@636<2
48@01PaS2488@PaS5:D@Q0<<H`0548@DYA2436<8@P0436<01PQ236<<H`aS48@<H`@@Q00336<@Q0aS
008<H`0548@DY@aS36<8@P0336<4248010aS48@@Q0aS1PQ200@48@Q236<<H`<8@P8<H`0448@<H`Q2
248236<3248436<6248000848@0500048@@Q1240000412402@Q2:DYS64YB<H`mkcF]<H`]J`02<H`0
2Be[:DXYBRe[<H`]JcF]>Lhe[@02<H`01CW>=JdaS36<;F/00SF]00HaS3W>>LhicS6<;F/3<H`4;F/2
:DX01Be[9BTU:Be[<H`00SF]00`]Jc6<=Jde[C6<;F/YBRDY;F/YBRDY:DX2;F/0136<;F/YBRe[0c6<
00H]JbDY9BTU:Be[:DX39BT00be[:DXYBP029BT00b489BTYBP02<H`2;F/01C6<;F/YBRU:9BT012U:
00<U:BU:;F/00Re[0RDY0b480QcW00<HaQcW8@P00RU:00@]JbDY9BTQ20@U:@068@PU:B489BTLiaS6
1acW0R4800DLiaS66<HHaQBU008HaP037>LHaQcW008Li`8Q20<Li`@HaP<Li`<HaP068@PLiaS66<HD
YAS61ABU0acW00DHaQcW7>LU:B4800<U:@8YBP04;F/YBRU:9BT58@P57>L36<H00aBU6<HHaP026<H0
1ABU48@@Q1S65:D00QS60QcW00<Q21cW7>L00aS600<DYAS66<H00aS60aBU0aS600DLiaS66<HHaQBU
008HaP035:DHaQBU008DY@0348@DYABU008HaP@Li`8HaP035:DHaQBU008HaP065:DHaQBU48@DYAS6
0QBU00@@Q1BU7>LLi`<HaP<DY@8HaP045:DLibDY;F/2<H`01Re[:DXQ22486<HDY@8HaP037>LHaQ24
00<@Q0<DY@0948@DYAS66<HLib487>LHaQBU00<Li`<DY@<Li`8DY@@HaP8DY@8@Q0035:DHaQBU00<D
Y@8HaP<Li`8HaP045:DHaQS66<H248@011BU7>LU:B480QS60Q2400<DYA245:D00aS60QBU00L@Q1BU
5:D@Q0aS48@<H`025:D00aS65:D@Q00236<248@00aS648@DY@025:D248@011BU6<HHaQBU0aS600@D
Y@aS48@@Q08DY@8@Q08DY@8HaP065:DHaQ245:DLiaS60QcW00XHaQBU48@DYAcW6<HDYA245:D@Q0@D
Y@0648@DYA245:DHaQBU1A2400@<HaBU5:DDY@8<H`<DY@<<H`8@Q08DY@036<H@Q124008DY@L@Q0H<
H`0348@<Ha2400<@Q08<H`8@Q0045:D@Q1245:D348@00aBU48@<H`0236<0112436<<Ha240QBU0Q24
0QBU0a240aBU112410aS00@@Q0aS36<<H`<DY@0548@8@PaS48@DY@0436<2248010aS48@<H`aS0a24
1PaS00D8@PaS248<Ha2400D<H`0348@DYA2400<@Q0035:D<H`aS00D<H`@8@P<<H`03248<H`aS00D<
H`<8@P@<H`03248<H`aS0088@P8<H`0348@<H`aS008<H`88@P@<H`48@P4<H`48@P0000<000@Q1240
0P@Q00h000@Q1248@P001248@RU:G_M6<C6<?NlicSF]1C6<0bU:00H]Jc6<<H`icSg_>Lh3=Jd01c6<
;F/]Jbe[<H`e[CW>00@aS003=JdaS36<008aS005;F/YBRDY9BTYBP02;F/00c6<:DXYBP02<H`2=Jd2
;F/00bU:9BTU:@03:DX00bDY:DX]J`05;F/0136<;F/U:BDY12U:00@U:B489BT]J`8YBP8Q20039BTY
BRDY008]J`8e[@8aS003;F/YBRU:008YBP8]J`08:DXQ22DY:DX]JbU:8@PU:@HLi`038@PU:BDY008Y
BP<Q20047>LQ22488@P2:DX01bDY8@PHaQS68@PU:AcW00<HaP048@PLiacW7>L56<H87>L66<H00acW
6<HDY@026<H37>L01AS65:DDYAS648@00QBU00@HaQcW6<HHaP<Li`046<HQ22488@P29BT012U:;F/Y
BRU:0bDY00DLib487>LLib4800HLi`036<HDYABU00@DY@056<H@Q1BU48@DY@027>L00aS67>LLi`02
7>L36<H27>L01QS65:DDYABU6<HDY@8HaP035:DHaQBU00<HaP@DY@056<HDYABU5:D@Q0026<H27>L0
1AS67>LHaQBU6<H00QBU00DHaQBU6<HHaQBU008HaP037>LDYABU008@Q0055:DHaQS67>LHaP025:D2
6<H25:D01QS65:DU:CW>?Nle[@8U:@05;F/U:AS648@DY@036<H25:D011246<HDYABU0Q240QBU00DL
iaS66<HHaQcW00@HaP0648@DYAS67>LQ21cW11S60aBU0Q240QBU0aS60aBU00DHaQcW7>LLiaBU008H
aP<DY@056<HLiaS67>LQ20027>L01QBU6<HDYA245:D@Q0@DY@036<HDYA2400D@Q08HaP055:D<H`aS
48@DY@0248@35:D248@00aBU48@DY@036<H01ABU48@HaQBU48@00PaS0Q2400@DYA2448@@Q08HaPDD
Y@8Li`8HaP0348@DYABU008DY@056<HDYAS66<HDY@0548@01ABU6<HDYAS648@00`aS1a2400<DYA24
48@00Q2400D<Ha245:DDYA2400DDY@8<H`0648@<H`aS48@DYA240PaS00<@Q1BU36<00PaS00<@Q0aS
36<00PaS00<@Q1BU48@00Q2400@<Ha245:D@Q0@<H`0448@<H`aS36<548@00aBU48@@Q00248@01QBU
48@DYABU48@<H`8@Q0035:D@Q12400<<H`0448@<Ha245:D336<011BU48@<H`Q20`aS0PQ20PaS0Q24
00@<Ha2436<@Q0`<H`88@P8@Q0046<HDYA2448@436<348@010Q236<8@PQ20`aS00<8@PaS24800PQ2
00@<H`Q22488@P8<H`031248@PQ2008<H`03248<H`aS0088@P0436<@Q0Q2248236<248@224800`aS
2488@P0236<124800005124000@Q12400006124030Q2:DYJeTHa;F/mkcW>;F/YBS6<>Lh]J`8U:@<]
J`06>Lhmkcg_>Lhmkd8@0TYB00A6<CW><H`aS08e[@<aS005=JdaS36<<H`]J`03:DX012e[9BTQ2248
0RU:00<U:Be[;F/00S6<0Re[00DYBRDY9BTQ22DY00HYBP03<H`]Jc6<008]J`HYBP8U:@058@PU:BU:
:DX]J`02:DX00bDY:DXU:@05:DX0136<>Lhe[C6<0Re[00<e[C6<;F/00RDY0R4800@LiaS67>LLi`8U
:@038@PU:BU:008YBP05;F/YBRU:9BTQ20027>L00aS67>LHaP028@P00bDY7>LLi`028@P29BT011cW
6<HLiacW0R480acW00<Q21cW7>L00acW0QS60acW00dQ21S66<HDYAcW8@PU:AcW6<HLiaS65:DHaP02
7>L00aS65:D@Q0045:D00a246<HLi`028@P26<H01acW6<HQ22489BTQ21cW008Q2003:DXU:BU:008U
:@8Q20039BTQ2248008Li`8Q20<Li`036<HDYAS6008DY@0948@DYABU7>LHaQBU7>LQ21cW008DY@06
6<HLiaS65:DHaQcW0QS600<DYAS66<H00QcW21S600@LiaS66<HDY@<@Q0096<HDYABU5:DLib487>LD
YAcW008HaP8DY@HHaP035:DHaQBU00<HaP<DY@0:6<HQ22DY8@PLiaBU6<HLiaS69BT2>Lh01CF]9BTQ
22DY7>L00QBU0QS600<LiaS66<H011BU00@HaQBU48@@Q08HaP8DY@036<HDYABU008DY@<HaP8Li`03
8@PLiaS6008Li`048@PLiaS648@35:D26<H00acW6<HHaP025:D36<H37>L00aS65:DDY@045:D01QcW
8@PQ21S65:D@Q0<HaP<@Q0<HaP0348@DYA2400<@Q0055:D@Q1245:D@Q00236<248@01ABU48@DYA24
5:D00Q2400@DYAS66<HHaP8@Q08DY@046<HDYA2448@35:D348@00aS65:DDY@0248@00aS67>LHaP03
5:D011cW5:DDYABU0aS60aBU0Q240aBU0Q2400<DYA245:D00a2400<<Ha2448@01Q240PaS1Q2400<<
HaBU48@00a2400<<Ha2448@00aBU0a241@aS11240`aS21240PaS00<@Q0aS48@01a2400<<Ha2448@0
0Q240aBU00<@Q1BU48@00a241PaS0Q2410aS0a240`aS00D8@PaS36<@Q0aS0088@P8<H`03248<H`aS
008@Q0@<H`0348@<H`aS00<<H`0348@<H`aS008@Q08DY@0448@8@PQ236<248@00`aS2488@P0236<2
48@00`aS48@8@P0236<3248236<724800`aS248<H`0436<248@236<2248336<3248236<000848@03
00048@@Q00D48@070008@RDYE[E2436<>Lh00SF]00<aS2e[;F/012U:0Re[136<00@icT8@@Q1:DP92
4003?Nle[CF]00@e[@DaS007=JdaS2e[:DXU:BU:9BT012U:00<U:BU:;F/00Re[00@YBRDY:DXYBP8U
:@8YBP039BTYBRU:008]J`03:DX]Jbe[00<U:@04:DX]JbU::DX39BT5:DX29BT012U:;F/]JbU:0RDY
0c6<0Re[0c6<00<]JbU:9BT00RDY00HLiaS66<HLib489BT38@P012U:;F/]Jbe[0RDY0RU:00@Q21S6
5:DLi`8Q208Li`8Q208U:@0<:DXQ22487>LQ22DY8@PLiaS67>LHaR4811cW00@HaQBU6<HHaP<Li`03
6<HLiaS6008Li`048@PLiaS66<H27>L26<H27>L01AS65:DDYAS65:D00QS600DLib487>LLiaS600<L
i`@Q208Li`8Q2005:DX]JbU:9BTLi`028@P47>L38@P01aS67>LQ21cW6<H@Q0aS008@Q08HaP<Li`8D
Y@046<HLiaS66<H25:D56<H00aBU6<HLi`037>L36<H00aBU6<HHaP027>L011S65:DHaQBU0Q2400@D
YAS66<HHaP8Li`0<5:DHaQS67>LHaQBU48@DYAS65:DHaQcW0QS611BU00@HaQBU5:DU:@8YBP038@PD
YAS6008Li`099BTYBS6<=Jd]JbU:9BTHaQcW00@HaP035:DHaQBU008DY@@HaP035:D@Q1BU008HaP03
5:D@Q1BU00<DY@8HaP065:DHaQS67>LQ21cW0b4800DLiaS648@DYA2400<HaP8Li`8HaP8DY@056<HD
YAS66<HLi`025:D011245:DDYABU0QS600DLib486<HHaQ2400DDY@8HaP085:DHaQS65:D@Q0aS48@D
Y@<@Q08DY@@@Q0065:D@Q1BU48@DYA241aBU0QS611BU00@HaQ2448@@Q0DDY@0348@DYAS6008HaP04
5:DLiaS66<H25:D46<H55:D248@55:D348@00aBU48@<H`0236<548@01@aS48@DYA245:D00Q2400D<
Ha245:DDYA2400@<H`<@Q08DY@D@Q08<H`8@Q0@<H`0348@<Ha2400<@Q00336<@Q12400@<H`0348@<
H`aS008@Q0035:D@Q124008<H`D@Q08DY@@@Q08DY@0536<8@PQ2248<H`0348@010aS48@<Ha240PaS
00H8@PaS36<@Q0aS248<36<0112436<<H`Q22@aS0Q2410aS00<DYA2436<010aS00<8@PaS48@010aS
10Q20PaS1`Q210aS0PQ20PaS0Q240PaS00<8@PaS24800PQ20PaS0@Q200001@0012448@@Q00000`@Q
00P8@P@Q1248@Re[G_M242U:0SF]00<aS2DY:DX012e[00TaS2e[;F/YBRDY=JdmkdHa?Nl00SF]00<m
kcW>=Jd00Sg_00A243g_>LhicP8e[@<icP06=JdaS3g_@Q0icRe[12U:00<U:B489BT00bU:00<U:BU:
;F/00RDY00<Q22U:9BT00R4800@U:BU::DXYBP8U:@PYBP8U:@04:DXU:BU:;F/2:DX29BT00bU:9BTQ
2002:DX2;F/5:DX012DY8@PQ22480RDY0QcW00<HaQcW9BT00b4800/U:B488@PQ21cW8@PU:BU:;F/Q
21cW008HaP048@PLiacW7>L28@P00acW8@PQ20039BT00bU:9BTU:@038@P011cW6<HLiacW0QS600@L
ib486<HHaP8DY@@Li`068@PLiacW7>LQ22DY0R480acW00LQ21cW6<HDYAS648@DY@027>L01B486<HH
aQcW8@P011cW0aS600<Lib488@P00RDY0R480QcW00<Q21cW7>L011cW0RDY00HYBRDY7>LLiaS65:D2
6<H27>L00aS65:DDY@0448@25:D26<H011BU6<HDYABU1QS600DDYAcW7>LQ21cW00@HaP047>LHaQBU
6<H27>L01aBU6<HLib486<HDYAS6008Li`DDY@@HaP8@Q08DY@0?7>LDYAS65:DHaSg_BU96<C6<48@H
aQcW5:DU:C6<008mk`03=JdU:B4800HDY@HHaP8DY@@HaP8DY@8HaP8DY@0848@DYA245:DHaQ246<HL
i`8DY@0436<@Q1cW8@P27>L011BU48@HaQS60QcW00@HaQcW7>LHaP8DY@0448@DYABU5:D26<H45:D0
0aS67>LLi`027>L36<H00acW5:DDY@025:D01aS65:DDYAS648@DYA2400HDY@<@Q0<DY@8@Q0055:D@
Q1BU48@DY@026<H00aBU48@@Q0025:D248@00aS65:D@Q00648@02aBU48@<Ha245:DHaQBU48@DYAcW
6<H00QBU0QS600@DYAS65:DHaPDDY@8@Q0@DY@8@Q0<<H`0548@<Ha2448@DY@0548@00aBU48@@Q002
48@236<01A2436<<H`aS48@00PaS1a2400D<Ha245:D@Q1BU008@Q0075:D<H`aS36<@Q1BU48@00`aS
0a2400<<Ha2448@00PaS0a240PaS1Q2400<<Ha2448@00Q2400<<Ha2448@01A240PaS0Q240PaS00L8
@PaS36<<H`Q236<@Q00236<00a2436<8@P02248248@336<01PQ236<<Ha2436<@Q0@<H`8@Q08<H`03
48@<H`aS0088@P0336<@Q0aS008@Q08<H`8@Q00536<8@PQ236<@Q00336<01Q2436<8@PQ236<8@P<<
H`D8@P0336<@Q0aS008<H`05248<H`Q236<8@P0536<3248136<1248000<48@0A00048@@Q0008@P@Q
00048@Q2;F]JeSg_9BTe[CW><H`]J`02<H`2:DX2<H`033F]<H`U:BDY;F/aS3g_@Q0mkcW>=JdaS0<i
cP04@Q16<D8@>Lh2<H`00cF]?NlicP02=Jd013W>?NlmkcW>0SF]00<aS2e[9BT00bDY00<YBRDY9BT0
0RU:00<]JbU:8@P00b480bDY00<YBRDY8@P00RDY00<YBRe[;F/00be[00DYBRDY9BTU:BU:00<]J`8Y
BP<]J`04:DXQ22DY:DX3;F/28@P00bDY8@PU:@038@P01RDY8@PHaQS68@PU:@@Q208U:@087>LHaQcW
7>LU:Be[:DXU:@<Q20TLi`058@PU:B489BTYBP029BT26<H01AcW6<HHaQcW6<H00R4800@LiaS65:DH
aP8Li`8HaP8Li`056<HLiacW8@PU:@028@P011cW8@PQ21cW0QS60aBU00<HaR487>L00QS60QcW00DH
aQcW7>LQ21cW00@HaP067>LQ22DY9BTLiaS60QcW00@Q21cW6<HHaP8Li`<U:@03:DXQ2248008DY@8H
aP8Li`0;6<HLiaS65:D@Q0aS48@HaQcW6<HDY@0248@36<H37>L46<H57>L26<H00acW6<HHaP056<H0
0acW6<HHaP027>L28@P00acW6<HDY@025:D36<H011BU48@DYAS60QBU00XHaQcW5:D@Q2U:>Li>LdYB
8@PHaP8@Q08U:@06:DY2448@=JdU:ABU0QcW0QBU0Q240QBU0QcW0QS60QBU1aS600<DYA2448@00QBU
00<HaQBU5:D00aS600<DYA2448@00Q2400@HaQBU6<HHaP8Li`036<HLib48008Q208HaP@DY@<HaP03
5:D@Q1BU008HaP0348@HaR48008Q20<HaP<DY@037>LHaQBU00<DY@8@Q08DY@<@Q0036<HDYA24008@
Q0065:D<Ha245:D@Q0aS0Q2400<DYAS65:D00QBU0QS60aBU00@@Q1BU5:D@Q08<H`0448@DYABU5:D2
48@25:D011245:DDYABU11S600<DYAS66<H00aBU0QcW00@HaQBU5:DDY@@@Q0035:DHaQ24008@Q08D
Y@L@Q08DY@0448@DYAS648@236<248@00aBU48@@Q00236<01@Q236<@Q12436<00Q2410aS0aBU00<@
Q0aS36<00aBU0Q2400H<Ha2436<<Ha2436<348@236<448@01@aS48@@Q1BU48@00`aS00@DYA2448@<
H`@@Q00336<@Q12400<@Q00536<@Q0aS36<@Q00836<248@010aS2488@PQ2112400<<H`Q236<010aS
0PQ20PaS00L@Q0Q248@@Q1BU48@<H`0248@00`Q236<@Q00248@436<01@Q236<<H`aS48@00`aS00@8
@PaS2488@P8<H`@8@P0536<8@PaS36<@Q00236<00`Q236<<H`02248010aS248<H`Q20`aS10Q20000
0`0012448@021240100012448@Q20P@Q00l8@RU:F]Hmkb48:DXaS2U:;F/U:Be[>Li244Ha>Lh00SF]
00<]JbU::DX00S6<00D]JbU:;F/e[CW>008mk`04>Lhe[CF]=Jd4>Lh00cF]>LhicP02?Nl2@Q000dHa
@Q0icP03>Lh01SF]:DXU:B489BTYBP<]J`<YBP049BTQ22DY:DX29BT38@P00bDY;F/]J`02;F/0136<
;F/]JbU:0Re[136<13W>00@aS2e[:DXYBP8]J`069BTQ22489BTYBRDY0R4800DU:AcW7>LHaQcW008Q
20<U:@038@PLibDY00<U:@8Q20039BTLib4800HU:@058@PLiacW8@PLi`026<H57>L00b487>LQ2003
7>L00aS68@PQ20027>L26<H00acW6<HQ20027>L36<H011cW8@PLiacW0aS60b480QcW00<HaQcW7>L0
0QS60acW00<HaQcW8@P011cW0QS60acW0QS62QcW124800TLiaS65:DDYAcW6<HLib487>L00QS600@D
YAS636<<H`8@Q0036<HDYABU008HaP045:D@Q1BU7>L36<H37>L38@P011cW6<HDYAS60QcW0QS600@@
Q1BU5:DDY@<HaP8Li`8Q208HaP055:DHaQBU48@DY@026<H248@00aBU6<HHaP025:D011cW5:DDYBDY
0S6<00<U:ABU6<H00acW00PQ22DY=JdicSF]:DXLib480QcW0aBU00<HaR487>L00QS600DLiaBU5:DD
YA24008HaP037>LHaQBU008DY@0648@DYABU48@HaQBU0QcW00HHaQBU36<@Q1BU6<H25:D00a245:DD
Y@026<H00acW6<HHaP036<H25:D01AS65:DDYAS67>L00QS600P@Q1BU5:D@Q1S67>LU:B481AS60aBU
00<@Q1BU6<H00QBU0Q2400<DYA2448@021BU0a2400<DYA2448@00Q2400@HaQBU48@DY@8HaP035:D@
Q1BU008@Q00536<@Q1BU48@<H`0248@25:D248@25:D01AS65:DDYAS67>L00QS60Q2400@DYAS66<HD
Y@8@Q0055:DHaQBU5:D@Q0055:D348@25:D00a2436<@Q00248@021BU48@@Q1BU48@<Ha2436<248@0
0aBU48@@Q00248@00`aS48@@Q00348@536<00a2436<<H`0348@25:D348@00aBU48@@Q00436<@48@0
1aBU48@@Q12436<8@PaS008@Q0<<H`<@Q00436<@Q12448@336<248@436<01@Q236<<H`aS48@01@aS
00<@Q0aS36<00Q2400D<H`Q236<@Q0aS0088@P<<H`0348@<Ha2400@<H`06248<H`aS48@<Ha240`Q2
00<<Ha2436<00PaS00<@Q0aS36<00PaS0PQ200<<H`Q236<01@aS00D@Q0aS2488@PaS00<8@P8<H`88
@P8<H`88@P4<H`48@P4<H`000`@Q00<000@Q12400P@Q00P8@P@Q0008@RU:E[DmkbDY0Re[00LYBRDY
9BT]Jc6<=Jdmk`02@Q000cW><H`aS003<H`2;F/012U:<H`e[CW>0Sg_1CW>00<e[C6<=Jd00cW>0cg_
1D8@00DicSF];F/aS2e[008U:@05:DXaS36<;F/YBP029BT4:DX29BT27>L012DY;F/aS2e[136<00<]
JbU:<H`01C6<00De[CW>?NlicSF]008]J`<YBP8U:@8Q20@U:@8Q20@Li`038@PYBRDY008U:@038@PU
:BU:00<U:@@Q20<U:@<YBP8U:@038@PLiaS6008Li`048@PLiacW8@P37>L28@P67>L56<H011cW8@PL
iaS60QcW00<Q21cW7>L00QcW00@HaQcW7>LQ208Li`036<HLiaS6008Li`8HaP037>LQ21cW00@Li`06
8@PLiacW7>LQ21cW0aS60R481AcW0QS600`Lib489BTQ21cW8@PLiaS65:DHaQcW6<H37>L00aS65:D@
Q00348@35:D26<H011BU6<HHaQS60QcW00@HaQBU7>LLi`@Q20047>LHaQS66<H27>L26<H00aBU48@D
Y@026<H00acW6<HHaP027>L02R487>LDYABU48@DYAS67>LDYAS60Q2400<DYA245:D011BU00@LibDY
:DXQ208Li`8HaP047>LHaRDY<H`2>Lh00c6<:DXYBP028@P26<H35:D021S67>LLiaS67>LHaQBU48@2
6<H01AcW8@PHaQS65:D00a2400@DYA2448@HaP8Li`035:D<Ha24008DY@046<HDYABU6<H27>L00aS6
5:DHaP096<H25:D46<H248@011BU6<HQ22480QcW0aS60QBU00@@Q1BU5:DDY@8HaP8DY@@@Q0035:DH
aQ2400@@Q0035:D@Q12400@@Q08DY@0<6<HDYABU5:DHaQcW6<HDYA2436<@Q1BU1A2400LDYA245:D@
Q1BU48@DY@036<H27>L00aS65:DDY@0248@00aBU48@DY@035:D00aS648@DY@025:D01QS65:D@Q124
5:DHaP8DY@0548@DYA2448@DY@0548@00aBU48@@Q00236<01Q245:DDYA2436<8@P<@Q0035:D@Q124
00<<H`0348@<H`aS00H@Q0055:D<Ha2448@DY@0248@336<00a2436<<H`0248@25:D248@010aS48@@
Q0aS0a2400<DYA2448@011240PaS00<@Q0aS48@00PaS0a2410aS00<DYA2448@00PaS00<@Q1BU36<0
0PaS0Q241PaS11240`aS0Q2400<<H`Q236<02@aS00D8@PaS48@DYA240088@P0336<@Q0aS00<<H`<@
Q088@P8<H`04248<H`aS48@536<00`Q236<<H`0236<424802@aS2488@PQ236<8@PaS248<H`012480
0005124000@Q1240000612401`Q29BU:DS6<6<HU:BU:008U:@0=8@PYBRU::DXaS3F]?Nm243g_>Lha
S3F]<H`00RU:00TaS3W>=Jde[CW>@Q16<Cg_>Lh00cg_010e[C6<;F/YBRe[=Jdmkd8@>Lhe[CW>?Nm2
44Ha@Q0e[@8aS004;F/aS36<=Jd2;F/012DY;F/]Jc6<0Re[0bDY00HQ22U::DXYBS6<=Jd2>Lh01T8@
AS4mkcF]<H`icP96<@03>LhaS3F]008aS0<icP03?NlicSW>008aS003:DXU:BDY00LLi`038@PU:BDY
008U:@068@PLib489BTYBRDY0b4812DY00HQ21cW8@PYBS6<=Jd3;F/28@P46<H00acW8@PYBP02:DX2
9BT57>L26<H27>L26<H00aBU6<HLi`046<H47>L38@P00acW8@PLi`045:D27>L012487>LLiacW0R48
00LLiaS66<HDYAS65:DHaP077>L00aS65:DHaP027>L011S67>LQ22480acW0QS60QBU00<HaQcW7>L0
0QcW00@DYA2436<<H`8@Q0045:DHaQcW6<H25:D248@35:D01QS67>LLiaS67>LQ208Li`036<HDYABU
008DY@8Li`8DY@8@Q0DHaP048@PLiacW6<H45:D00aS65:DHaP025:D00a245:DDY@056<H00aBU6<HH
aP026<H031BU6<HHaQcW6<HLibe[<Ha6<Cg_<H`YBP8HaP047>LHaQcW5:D26<H27>L46<H01QBU48@@
Q1S65:DHaP<DY@056<HDYABU48@DY@046<H348@35:D248@25:D26<H011BU6<HDYAS60aBU00<HaQcW
7>L011S611BU00@HaQcW8@PQ20<HaP035:DHaQ2400DDY@0348@DYAS6008HaP<@Q0DDY@@@Q08DY@05
6<HDY@aS48@HaP035:D27>L25:D00aS65:D<H`0236<00aBU48@@Q00248@01aBU48@<H`aS48@DYB48
00<Li`<HaP8DY@8@Q0065:DHaQBU48@<Ha240QBU0Q2400<DYA2448@00aBU00@@Q1BU5:DHaP<@Q004
5:D@Q12448@25:D01A2436<<Ha2436<01A240PaS0Q240QBU0Q2410aS0Q2400D<Ha2448@@Q0aS008@
Q0035:D@Q0aS008<H`<@Q08<H`@@Q0045:D@Q0aS36<448@010aS48@<H`aS112400<<Ha2436<00`aS
00<@Q0aS48@00PaS0a241@aS00<@Q0aS36<00PaS00<@Q0aS36<00Q240PaS00<8@Q2448@00Q2400P8
@PaS48@@Q0aS248<H`Q21PaS00D8@PaS36<@Q0aS0088@P<@Q0D<H`8@Q0045:D@Q0aS36<2248010aS
2488@PaS0`Q20PaS0Q240PaS0`Q20`aS0PQ20PaS0`Q20PaS0@@Q00021240100012448@000`@Q00T0
00@Q248U:DHa<H`LibDY:DX00R480bDY00<YBRe[;F/00SW>00<e[CW><H`013F]0S6<0SF]00@icSg_
@Q124096<@05?Nm243W>?Nle[@02;F/0136<=JdicSW>0SF]00HicSg_AS5:DSW>=Jd2;F/01C6<=Jda
S3F]<H`00be[0RU:0Re[00PYBRDY9BTYBRDY;F/YBRe[0S6<00Q244YBBU8mkcW>?Nm243g_0cW>00@e
[C6<<H`aS08e[@09>LhmkcW>=Jd]JbU:9BTQ22DY008Li`046<HLiacW7>L28@P2:DX012DY7>LQ22DY
0RU:00<Q21cW8@P00R4800@U:Be[:DXU:@8Q2005:DX]Jbe[<H`]J`02:DX28@P01AcW6<HLiacW9BT0
0RU:00HaS2e[9BTLiaS67>L28@P26<H01ABU6<HHaQcW6<H00QBU00DHaQcW8@PQ21cW008HaP047>LQ
21cW7>L28@P26<H00aBU6<HLi`027>L01AS68@PU:BDY8@P00acW11S600<LiaS68@P00QcW00HQ21cW
5:DDYAS67>L36<H27>L012486<HLiacW0QS600<DYAS67>L00R4800<HaQ2448@00Q2400@DYA246<HH
aP8Li`036<HDYABU008DY@8HaP075:D@Q1S67>LQ21cW6<H00QcW0aS600<DYAS66<H00QS611BU00@L
iaS66<HHaP8Li`046<HDYABU5:D36<H448@00aBU6<HDY@025:D36<H25:D00aS67>LHaP025:D02QS6
5:DLib48:DY244YB?NlaS1S60QcW00<U:B487>L00QBU00HLiaS66<HHaQcW6<H25:D36<H25:D00aS6
5:DDY@035:D011245:DHaQS60QBU00@@Q1S65:DHaP8DY@8@Q08DY@<HaP037>LHaQS600<DY@<HaP03
5:DHaQS6008HaP8DY@046<HDYAcW7>L28@P00acW6<HDY@035:D00a245:D@Q0075:D01A245:D@Q1BU
6<H00aBU0Q240aBU00D@Q1BU48@DYA24008DY@0348@DYAS6008Li`8DY@@@Q00336<@Q124008@Q005
36<@Q12448@DY@037>L01ABU6<HLiaS65:D00Q2400@DYAS65:D<H`8@Q0076<HDYA2448@DYA245:D0
0a2400@DYA245:D@Q08DY@0536<@Q12448@DY@0348@336<248@436<248@336<648@336<248@01PaS
48@@Q0aS48@<H`<@Q00436<8@Q2448@35:D448@236<448@236<00a2436<@Q00748@00`Q236<@Q002
48@00`aS48@DY@0336<448@536<00a2436<<H`0248@020aS48@<Ha2436<@Q0aS248236<00a2436<<
H`0436<248@236<00`Q236<@Q00236<01PQ236<@Q12436<8@PD<H`07248<Ha245:D@Q0aS12400PQ2
2@aS00@@Q0aS36<<H`<8@P@<H`<8@P<<H`88@P0000<000@Q12401@@Q00P8@P@Q12448B48BU8aS1cW
0R481RDY00DYBRe[<H`e[C6<00@]J`03<H`e[CF]008e[@04>Lhe[CF]?Nl3@Q02?Nl3@Q000cW><H`]
J`03<H`00cF]<H`aS007<H`02SW>=Jde[C6<=JdaS2e[:DX]JbU:0bDY0RU:00@]JbU::DX]J`<aS004
:DX]Jc6<<H`2?Nl00cW>=JdaS002;F/2=Jd0136<;F/YBRU:0S6<00Le[CW><H`e[C6<;F/YBP029BT4
8@P59BT01b487>LU:Be[:DXQ22DY008YBP039BTQ224800<U:@8Q20037>LU:BDY008U:@088@PLib48
7>LHaQcW8@PYBP8]J`03:DXU:BU:008]J`04:DXLib487>L66<H35:D36<H27>L00aS67>LHaP037>L0
12487>LLiaS611cW00LHaR48:DXU:AcW5:DHaP027>L01QS67>LQ22489BTLi`<HaPPLi`038@PLiaS6
00<Li`078@PHaQS66<HQ21cW6<H00Q2421BU00@HaQcW7>LLi`8HaP<DY@8@Q0045:DHaQcW6<H25:D0
11246<HHaQcW0QS600<DYAS66<H00aS600<DYAS67>L00QS600<DYAS65:D00QBU00D@Q1BU6<HHaQBU
008@Q08DY@036<HDYAS6008DY@<HaP8DY@<HaP065:DHaQcW7>LU:CF]0Sg_00<aS1cW7>L00QcW00<Q
21cW6<H00QS600<DYAS65:D00aS600<DYAS65:D00aBU00@HaQcW7>LLi`<DY@8HaP035:D@Q12400@D
Y@0648@DYABU5:D@Q1BU0aS60QcW0aS60QcW00DQ21cW6<HDYA2400<HaP8DY@036<HLib4800<U:@05
8@PLiaBU5:D@Q0085:D00a245:DDY@025:D248@55:D011245:DDYAS61aBU0QcW0QS60a240QBU0PaS
00@@Q1S66<HDY@8<H`8@Q0<Li`036<HDYAS6008HaP035:DHaQBU008DY@0448@DYA2448@25:D01AS6
5:DDYA2436<00a2400@<Ha245:DDY@8<H`8DY@8@Q00336<@Q12400<<H`D@Q00636<8@PaS48@DYA24
0PaS0a2400<<Ha2448@00QBU0Q2400DDYA2448@@Q0aS00@@Q0<<H`0848@DYABU48@DYA245:D@Q08D
Y@8@Q00336<@Q1BU008@Q0<DY@0548@<H`aS48@DY@0248@436<01a2436<@Q12436<@Q0aS008@Q0@<
H`0448@<H`Q236<448@336<448@636<010Q236<8@PQ20`aS00<8@PaS36<00PaS0PQ20PaS00<@Q0aS
36<00`aS00@8@PaS36<@Q0@<H`@8@PH<H`D8@P<<H`<8@P0436<@Q0aS248336<2248000<48@030004
8@0000<48@0700048@Q2:DY6<CF]7>L00RDY00@Q22DY9BTYBP8U:@038@PU:C6<008e[@07<H`YBRU:
<H`]Jc6<=Jd00c6<00Le[CW>>Lhe[CW>?Nm24002?Nl00d8@?NlicP03=Jd01S6<;F/aS36<>Lhe[@<a
S0<]J`@e[@03<H`]Jbe[00DYBP<U:@04:DX]Jc6<<H`2;F/00bU:;F/aS003;F/2=Jd013W><H`]Jc6<
1Re[00<YBRe[<H`00SF]00HaS2e[<H`aS2e[:DX38@P012DY:DXU:BDY0RU:0R4800<LibDY9BT00RDY
00@YBRDY:DXU:@8Q20<U:@<Q20047>LQ22DY9BT28@P26<H27>L01bDY:DXYBRDY:DXQ22DY008YBP03
9BTQ21S600DHaPDDY@036<HDYAcW008Q208HaP8Li`038@PLiacW00DLi`<HaP8Q20059BTLiacW7>LH
aP037>L012U:9BTQ22480aS62AcW00@HaR488@PQ208Li`036<HLiaS6008Li`8DY@<@Q0085:DHaQBU
48@DYAS68@PLi`DHaP045:DHaQBU48@25:D00aS65:D@Q0025:D56<H011BU6<HHaQcW0aS600DDYAS6
6<HHaQBU00<HaP<DY@8HaP8DY@0348@DYABU00<DY@056<HDYABU5:DHaP027>L00aS65:DDY@027>L2
5:D012e[?Nm6<CF]11cW00<Q21cW6<H00QS60QBU0QS600TDYA245:DDYAS65:D@Q1BU6<H00R480QBU
00H@Q1S66<HHaQBU6<H25:D00a245:DDY@035:D26<H45:D00aS65:DHaP036<H011cW8@PLib480QS6
00<DYAS66<H01AS600HLib489BTU:B486<H348@26<H00aBU48@DY@035:D248@25:D011S648@<HaBU
0QS600<DY@aS48@00Q240QBU0QS60aBU11S600<DYA2436<00a2400@<Ha2448@DY@<@Q08<H`8DY@<H
aP<DY@066<HDYA245:DHaQBU0Q2400D<HaBU6<HDYAS600<@Q0<DY@8@Q0<DY@0348@<H`aS008@Q003
5:D@Q12400<<H`8@Q08DY@0648@<Ha2436<@Q0aS0Q2400<<Ha2448@00a240QBU00@@Q0aS36<<H`<@
Q00336<@Q124008DY@8@Q0<<H`<@Q0035:D@Q1BU008@Q0055:D@Q1BU48@DY@0248@010aS48@@Q1BU
0a2400<DYA2448@00PQ20Q2400@DYA2436<8@P8<H`8@Q08<H`<@Q08<H`0348@<H`aS008<H`@@Q08<
H`8@Q08<H`88@P<<H`88@P<<H`88@P05124<H`aS48@<H`0224801@aS48@<H`aS48@00PaS00<8@PaS
48@00PaS00<@Q0aS24800`Q20PaS00@8@PaS36<8@P<<H`H8@P0336<8@PaS00<<H`04248<H`aS36<2
2480000300048@0000L48@070008@RDYCW<icQcW9BT00RU:00<]JbU::DX00bU:0Re[0c6<00@]Jc6<
>LhicP8]J`04<H`YBRe[<H`3=Jd2>Lh2AS400d8@>Lhe[@02=Jd2<H`2;F/0136<=Jde[CF]0S6<0Re[
0S6<00He[C6<<H`]Jc6<;F/59BT00b489BTYBP02;F/00c6<;F/YBP03:DX00bDY:DXU:@029BT00bU:
;F/YBP029BT2:DX00bDY8@PYBP028@P29BT2=Jd2>Lh0136<9BTU:BDY0RU:00<U:Be[<H`00S6<0be[
00<Q21cW8@P00RDY00HQ22DY9BTU:B487>L28@P00bDY:DXU:@028@P27>L01AS68@PQ22487>L00QBU
00<HaR48:DX00RDY0QcW0RDY00<YBRDY7>L00QS60acW00<HaQcW7>L01AS600PDYAcW8@PU:AcW5:DH
aR480aS60QcW0aS600<LiaS68@P00R4800<LiaS65:D00aS611cW11S600@LiaS67>LHaP@Q200<6<HL
iacW9BTYBR487>LDYAS68@PLiaBU0Q2400D<Ha2448@@Q1BU008HaP8DY@037>LQ21cW00HHaP@DY@03
48@DYABU00DDY@036<HLiacW00@HaP037>LHaQBU00@DY@086<HDYAS66<HDYAS67>LHaP8DY@0448@D
YABU48@26<H011cW6<HDYABU0QS60QBU00<@Q1BU6<H00QBU00X@Q1BU;F/icTHa>LhU:B485:DHaP<L
i`<DY@036<HDYAS6008HaP055:DHaQBU6<HDY@0248@00aBU7>LLi`035:D26<H27>L35:D00a245:D@
Q0025:D01QcW5:DDYA245:DHaP<DY@8HaP057>LQ21cW7>LDY@056<H27>L36<H01QcW9BTU:BU:8@PD
Y@8@Q0036<HDYA24008@Q0055:DHaQBU5:D@Q0035:D011245:D@Q1242QBU00L@Q1BU48@DYAS65:DL
i`036<H00aBU48@@Q00236<00aBU48@@Q00236<011245:D@Q1240aS600@DYA245:DDY@8HaP8@Q003
5:DHaQBU00<@Q0045:DHaQBU5:D348@00aBU48@@Q0025:D00aS65:D@Q00248@236<25:D248@010aS
48@@Q0aS0a2400<DYA245:D00Q241`aS00<@Q1BU5:D00PaS00D@Q1S66<H@Q0aS00<@Q0035:D@Q0aS
00<<H`0348@<Ha24008<H`8@Q0035:D@Q12400<@Q08<H`035:D@Q1BU008@Q0045:D@Q1BU6<H25:D0
0`aS248<H`0348@010aS48@DYA240PaS00<8@PaS48@00PaS00<48@aS48@00Q240PaS00<@Q0aS48@0
0a2400@<H`Q236<<H`8@Q00336<8@PQ20088@PX<H`88@Q4<H`<8@P@<H`03248<H`aS008<H`@8@PP<
H`0348@<H`Q20048@P001@@Q00<000@Q12400`@Q00l8@Re[E[DicQcW9BT]JbU:;F/aS2e[:DX]JbU:
9BT00be[00DU:BU:<H`icSF]00<aS08]J`04:DX]Jc6<=Jd2>Lh01Cg_@Q12448@>Lh00S6<00Le[CW>
<H`]JbU:;F/icP02=Jd2<H`3;F/01S6<?NlicSW>;F/Q20@U:@8Q20069BTYBRe[<H`]JbU:0be[00<Y
BRDY9BT00RDY00@YBRe[;F/YBP<U:@8Q20@U:@048@PLibU:=Jd2?Nl02Be[8@PU:BDY:DXU:B489BTY
BP02=Jd0136<>LhaS2U:0R4800@U:B487>LU:@8YBP038@PLiacW008U:@03:DXU:B4800@Li`8Q2003
7>LQ21cW008Li`036<HLib4800<Q20037>LQ22DY00<U:@/HaP035:DHaQS600@Li`038@PLiacW008H
aP8Li`058@PHaQS67>LHaP028@P27>L011S67>LLiaS60acW0R4800<Lib486<H00aS611cW0R4800DU
:AcW7>LLib48008U:@058@PLiaS66<HLi`025:D010aS48@DYABU0QS60aBU00@HaQcW7>LHaP8Li`03
6<HDYABU00<DY@0348@DYABU00DDY@036<HDYAS600<HaP035:DHaQcW008Li`8DY@036<HDYAS6008H
aP8DY@8HaP8Li`<HaP0348@HaQS600@HaP037>LDYABU008DY@8HaP0<5:D@Q1BU5:DHaQcW9BTmkdHa
>Lh]JaS60QcW00<HaQcW6<H00QS600<DYAS66<H01AS611BU00@@Q1BU5:DHaP8DY@<HaP8DY@076<HD
YAS648@<Ha245:D00QS600<DYA245:D00QS611BU0aS60QcW0aBU00dHaQcW8@PLib486<HDYAcW8@PY
BRDY7>LDY@026<H25:D248@65:D348@25:D00a245:DDY@025:D248@25:D01AS65:DDYABU48@00QBU
00DHaQBU5:DDYAS600@DY@8@Q08<H`H@Q0036<H@Q1BU008HaP065:D@Q1BU6<HDYA240QBU00DHaQBU
48@DYA2400DDY@0448@DYAS65:D248@35:D348@00`aS48@@Q0025:D00a2436<<H`0236<248@021BU
48@<H`aS48@<H`Q236<248@336<00a2436<@Q00248@01ABU6<HDYA245:D00a2400<<Ha2448@00`aS
112400<<Ha2448@00QBU21240aBU1a241@aS0Q240`aS00<8@PaS36<00Q240PaS00<8@Q2448@00Q24
0PaS00<@Q0aS36<01A241@aS0`Q210aS00D8@PaS36<@Q0aS0088@Q8<H`8@Q0<8@P0336<8@PaS00<<
H`88@P<<H`88@P@<H`0348@<H`aS008<H`48@P0000@000@Q124000@48@0924848@@Q248]JeJe>LhQ
236<008e[@<aS005;F/YBRe[<H`]J`02:DX2;F/3:DX3<H`01SF]<H`YBRDY:DX]J`@e[@8aS003=Jda
S3W>008mk`8e[@03;F/aS3F]008e[@03<H`]Jc6<00<icP8e[@05<H`e[Be[9BTLi`038@P012DY8@PQ
22U:0S6<00D]JbU:;F/U:B48008U:@03:DXU:BU:00<YBP039BTYBRU:00@Q20049BTQ22489BT4:DX0
12DY8@PLiacW0bDY00LQ22DY8@PU:Be[<H`e[@04<H`2;F/012U:;F/YBRDY0R480bDY00<YBRDY7>L0
0acW00/Q21cW8@PLiaS65:DHaQcW8@PLiaS6008Li`048@PU:B488@P27>L28@P76<H00acW8@PQ2004
7>L28@P27>L00aS67>LHaP027>L46<H37>L00b487>LLi`046<H00acW8@PLi`027>L02R487>LHaQS6
7>LU:B487>LHaR480RDY00<YBRDY8@P01B4800<LiaS65:D00Q2400<DYAS66<H02QS60QBU0QS600<D
YAS66<H00QS60aBU0QS60aBU00DHaQBU5:DHaQBU008HaP035:DHaQBU008HaP087>LHaQS65:DHaQcW
6<HLi`8Q20047>LHaQS66<H27>L011S67>LDYAS60QBU0aS600<LiaS65:D00QBU00<HaQBU6<H00QcW
00PmkdHa?Nl]JaBU7>LQ21cW0QBU00LLiaBU5:DHaQcW8@PHaP025:D26<H00aBU48@@Q00248@65:D0
11S65:DDYABU0a2411BU0QS60acW00<HaQBU5:D00QBU0aS600@DYA2448@DY@<HaP8@Q0066<HLiaBU
5:DHaR480QcW0QBU00<@Q1BU48@00Q240QBU00<HaQBU48@01ABU0Q240aBU0Q2400<HaQBU6<H00QBU
00D@Q1BU5:DHaQBU008@Q0055:DHaQS65:D@Q0025:D00a2436<@Q00536<01Q245:D@Q12436<@Q08D
Y@<@Q0<DY@8@Q0066<HDYABU48@<Ha240aBU00@@Q1BU5:D@Q08<H`@@Q00536<@Q1BU6<HDY@0248@2
5:D01`aS48@@Q12436<@Q0Q2008@Q0045:D@Q0aS36<348@00`aS48@@Q00248@00`aS48@DY@035:D0
0`aS48@<H`0348@236<00a2436<@Q00648@01ABU48@<Ha245:D02A2400<<Ha2448@00Q240`aS00L@
Q1BU48@@Q0aS48@<H`0248@00`aS48@@Q00236<00`Q236<<H`0436<248@00aBU36<<H`0248@236<2
48@01PaS248<Ha2436<8@P8<H`0348@<H`aS00H<H`06248<H`aS36<@Q0aS0Q2410aS0Q2400<<H`Q2
36<01`aS00X8@PaS248<H`Q236<8@PaS24848@8<H`0348@<H`Q200<<H`88@P4<H`48@P0000<48@00
12401P@Q00h000@Q248]JeJe?NlLibDY=JdicSg_>LhaS2e[0S6<00D]Jc6<;F/YBRDY008YBP04<H`]
JbU:;F/4<H`3:DX5<H`4=Jd2>Lh00cF]<H`aS002<H`3=Jd3<H`3=Jd01cW>=Jd]JbU:;F/YBRDY008L
i`8Q20<U:@<]J`04:DXQ22DY9BT3:DX012DY:DXYBRU:0Re[00<YBRDY9BT01B4800XU:BU::DXYBRe[
:DXQ21cW8@PU:@8Q20067>LQ22DY8@PU:BU:0be[00DaS3F]<H`YBRe[008aS009:DXU:BU::DXU:B48
9BTYBRDY008Li`8U:@038@PLib4800@HaP<Li`056<HLib489BTQ20027>L00aS68@PLi`027>L011S6
5:DHaQcW0R4811cW00DHaQcW9BTYBRDY00LLi`8HaP0;7>LHaR488@PLiaS65:DHaQcW6<HLi`026<H4
8@P97>L00b489BTYBP029BT48@P27>L26<H011245:D@Q1BU2AS60aBU11S600@DYAS66<HLi`<DY@03
6<HDYABU00<HaP<DY@8Li`8HaP<DY@<HaP045:DHaQcW8@P46<H00acW6<HHaP036<H37>L26<H00aBU
6<HDY@046<H03QBU6<HDYABU6<H@Q1S6;F/mkdHa=JdQ22DY8@P46<H25:D01QcW8@PQ21cW5:DHaP8D
Y@<HaP8DY@0348@DYABU008DY@046<HDYAS648@25:D02A245:D@Q1245:DLiaS65:DHaP028@P01AS6
5:DDYAS648@01QBU0Q240aBU00<HaQBU6<H011BU00LQ22DY7>LDY@aS48@DY@0348@01ABU48@DYABU
48@00aBU1A2400HDYA245:D@Q1BU48@25:D011S65:DDYA2411BU00LHaQBU48@<Ha245:D@Q00236<2
48@336<348@01@aS48@DYAS65:D00a2411BU00@HaQBU6<HDY@@@Q08DY@X@Q00336<@Q124008DY@@@
Q0085:D<Ha2436<@Q0aS48@<H`<@Q00436<@Q12448@336<248@236<248@25:D448@010aS48@@Q124
0`aS00<@Q0aS36<00a2400<DYA2448@00a2400H<Ha2436<<Ha245:D548@536<448@01ABU48@@Q0aS
48@00`aS0Q2400H8@PaS36<@Q0aS248236<248@336<348@00`aS48@@Q00236<2248836<00`Q236<<
H`0236<00`Q236<@Q00236<00a2436<@Q00236<00`Q236<<H`0236<348@336<01@Q236<<H`aS2480
0`aS1PQ20PaS00@@Q0aS2488@P@<H`48@P000P@Q00L000@Q00048@001248@P0312401b48BU8icRe[
>Li243g_008icP05?NlicSW>?NlicP02<H`2:DX3;F/3:DX4<H`3;F/0136<;F/YBRe[0c6<00@e[C6<
<H`]J`<aS006=JdicSF]=JdaS3F]0SW>00Le[C6<<H`aS2e[:DXU:@048@P29BT012489BTQ22DY0RU:
00<]JbDY9BT01BDY00<]JbU:;F/00SF]00LaS2e[9BTQ22DY8@PYBP029BT012489BTQ22480RDY0acW
0RDY00<LiaS67>L0124812DY0RU:00<]JcW>>Lh00THa00DicSF];F/YBRe[00<YBP039BTQ224800@L
i`8Q20047>LHaQS66<H27>L011S67>LLib480acW00<HaQcW7>L00R4800<Lib487>L00R4800<U:AcW
7>L00QS60R480RDY00<LiaS66<H00QcW0R480QcW00@HaQcW7>LLi`8HaP8Li`048@PLiacW6<H27>L3
8@P011cW6<HLiacW1B4800<HaQcW9BT00bU:0b480QcW00<HaQBU6<H00QS60QBU0QcW00XHaQcW9BTL
iaS648@DYAcW8@PLi`8HaP0648@DYAS66<HDYAS60QBU0QS60QcW00@HaQBU5:DDY@<HaP045:DHaQBU
48@25:D36<H47>L00aS65:DLi`027>L01QS65:DHaQcW6<HLi`8HaP087>LHaQS66<HDYAS65:DHaP8D
Y@8HaP0=7>LDYA24:DXicSg_;F/LibDY8@PLiaBU6<H011cW00@Q21S66<HDY@8HaP055:D@Q12448@D
Y@026<H35:D26<H00aBU48@@Q00248@25:D00a245:DDY@025:D021245:DHaQcW6<H@Q1BU48@35:D3
6<H25:D0212436<@Q1BU7>LHaQBU48@25:D01AS67>LLiaS65:D00Q240aBU0Q240QBU0QS60QBU0aS6
0QBU00@@Q1BU48@DY@<HaPHDY@0348@HaQS6008HaP<DY@0348@<H`aS00D<H`H@Q0035:DHaQS600LD
Y@0748@DYABU5:DHaQ2436<00Q240aBU00@@Q0aS48@@Q0<DY@<@Q0<DY@0448@DYABU5:D248@236<2
48@011BU48@@Q0aS0Q2400<<Ha245:D010aS0a2400<DYA2448@00a241@aS00L@Q0aS36<<Ha245:D@
Q00236<00a246<H@Q00248@01ABU48@@Q1BU48@00`aS00D@Q1BU48@<Ha2400D<H`<@Q00436<DYABU
48@336<348@00aBU48@@Q00736<248@536<00a2436<<H`0736<00a2436<<H`0336<00`Q236<<H`03
36<010Q236<<Ha2410aS00<8@PaS36<00a2410aS00D@Q0aS36<<H`Q200<<H`03248<H`Q2008<H`88
@P8<H`0448@<H`aS36<2248436<0000300048@@Q00@48@0:24848@@Q0008@R48BU8icRU:<H`3>Lh0
0cg_=Jde[@03>Lh2?Nl0136<;F/U:BU:12e[00@aS2e[<H`YBP<]J`<aS004:DX]Jbe[=Jd2<H`00be[
<H`aS002<H`012e[<H`e[CW>0S6<00<e[CW>>Lh00SF]00<aS2e[;F/00RDY0R4800@U:B488@PU:@<Q
20039BTYBRDY008U:@09:DXU:B488@PYBRe[:DX]JcF]008icP03;F/YBRe[008U:@068@PU:BU::DXU
:B480bDY00<Q21cW7>L00QcW0b4800@LiaS67>LLi`<U:@8YBP8U:@0;:DXaS3W>>LhmkdHa>Lhe[Be[
:DX]J`02:DX012DY8@PHaQcW0b481AcW0QS60QcW0QS600@Lib488@PLi`<HaP047>LQ22488@P47>L0
1B487>LDYAcW8@P00RDY00<Q21cW6<H00QcW00<Q21cW7>L011cW00<HaQcW7>L01AcW11S600@Q22U:
8@PLi`8DY@057>LQ22487>LQ20027>L49BT48@P00acW8@PLi`035:D26<H01a246<HLibDY8@PLiaS6
008DY@046<HLiacW7>L55:D00aS67>LDY@035:D27>L00aS65:DDY@025:D26<H00acW6<HDY@035:D0
1aS65:DHaQcW8@PLiaS6008DY@046<HLiacW6<H25:D46<H00acW6<HLi`027>L011S65:DHaQBU1AS6
00H@Q1BU7>LQ236<=Jd2;F/36<H00aBU6<HLi`028@P01AcW6<HDYAS65:D00aS600<DYA2448@00aBU
00@HaQBU5:DDY@<@Q0045:DHaQBU36<348@011BU48@@Q1BU1AS600<DYA2448@00QBU00<HaQBU5:D0
0QBU00/@Q1BU5:DDYAS65:DHaQBU48@DYAS6008Li`035:D@Q1BU00@@Q0<DY@0348@DYABU008HaP03
5:DHaQS6008@Q00636<@Q1S66<HDYAS60QBU00<HaQBU5:D011BU11S600HDYA2448@<Ha2436<248@0
1@aS48@<Ha245:D00Q2400L<HaS66<HHaQBU36<@Q0035:D00aS648@@Q00648@25:D448@00`aS48@@
Q0035:D248@00aBU6<H@Q00236<011BU6<HDYA240PaS00<@Q1BU48@00PaS00<@Q0aS48@011240PaS
112400<DYA2436<00PaS00P@Q0aS48@DY@aS48@8@PaS0Q240QBU00D@Q0aS5:D@Q0aS00@@Q00336<@
Q12400<<H`0548@<Ha2448@<H`0348@236<00a245:D<H`0236<348@00`aS48@@Q00448@010aS48@@
Q1242@aS0Q241`aS00D8@PaS48@@Q0aS008@Q00536<8@PQ236<DY@0248@236<224801@aS48@@Q124
24800PaS00<8@PaS36<00Q2420aS00<8@PaS24801@aS0`Q20`aS0PQ20PaS10Q200001`@Q00048@@Q
00048@0000@48@06248YBU:D>LhYBS6<13W>01DmkcF]<H`aS3F]?Nm243W><H`]Jc6<>Lhe[C6<;F/Y
BRe[<H`]JbU:9BT00Re[00<YBRe[;F/00Re[00<YBRe[<H`00be[0S6<0Re[136<00@e[Cg_@Q0mk`8i
cP03;F/YBRDY00@U:@<Q20DU:@8YBP@Q20<U:@<YBP08;F/aS3F];F/YBR487>LU:@<YBP8Li`048@PU
:BDY9BT28@P00bDY8@PLi`026<H00acW8@PLi`057>L01B48;F/aS36<;F/00RU:0SF]00E244YBAS52
43F]008]J`039BTYBRU:008Q20059BTLiaS65:DHaP027>L00aS67>LLi`026<H37>L26<H01AcW8@PQ
21cW5:D00QcW0RDY0acW0R4800<Lib487>L00acW00<Q22DY;F/00RDY00<HaQcW8@P01b480acW0QS6
0b480QS60R480QS600<Lib488@P00QS60acW00<Q22DY9BT00R480RU:00@Q21cW7>LLi`8HaP055:DH
aQS65:DHaP027>L26<H47>L26<H25:D26<H00aBU6<HHaP025:D26<H27>L00aS65:DDY@026<H27>L0
0b487>LHaP025:D01AcW6<HHaQS67>L012480QS611BU1AS60acW0QS600DLiaS67>LDYA24008DY@8H
aP085:DHaQcW;F/YBRDY8@PHaP<DY@056<HDYABU5:DHaP045:D46<H01aBU48@DYA246<HDYAS600<D
Y@0348@DYABU00<DY@0336<@Q124008@Q0<DY@@HaP8DY@036<HDYAS6008DY@046<HDYABU5:D248@0
0aS65:DHaP025:D01a245:DHaQcW8@PLiaBU008@Q0<DY@8@Q0055:DHaQcW7>LHaP035:D00aS65:D@
Q00248@00aBU48@DY@035:D248@011BU48@@Q1BU0aS611BU1a240PaS00<@Q1BU6<H00Q2400DDYAcW
6<HDYA24008DY@0348@DYABU008DY@@@Q08DY@0648@DYA2436<@Q0aS0a2400<DYA245:D011BU0Q24
0aBU0Q2400<DYA2448@010aS0Q2400@<Ha245:D@Q08<H`8@Q08<H`0348@DYA24008@Q00>6<HDY@aS
248<HaBU48@<H`Q236<DYAS65:D@Q08<H`8@Q0055:DHaQ2448@<H`0348@010aS48@@Q1240PaS0Q24
0`aS00D@Q0aS36<@Q1BU008@Q00536<8@Q2448@DY@0236<248@00`aS248<H`0248@00`aS48@@Q002
48@010aS248<H`aS0Q240`aS00<8@PaS24801`aS11241@aS00@@Q0aS48@@Q0<<H`04248<H`aS36<2
48@236<2248336<0112436<<H`Q20PaS0PQ200<48@Q236<00PaS0a2400<8@PaS24800`aS0PQ20002
12400`0012448@0312402@Q200048@Q2:DYBU48@9BT]J`02=Jd3>Lh013g_>Lhe[C6<0SF]0Sg_00Di
cS6<<H`e[CW>008e[@07<H`]JbU::DX]JbU:;F/00bU:00<]JbU::DX012e[0S6<00@]JbDY;F/]J`8e
[@8aS005=JdicSW>?Nle[@02<H`01Re[9BTU:BU:;F/YBP<Q208U:@<YBP<U:@048@PLiacW9BT4:DX3
;F/2<H`02bU:9BTLibDY:DXU:B487>LQ21cW9BT00R480RDY00<Q21cW6<H01QcW0b4800<LibDY:DX0
0Re[00@U:BU::DXU:@8icP06@Q1:DT8@>LhaS2U:12DY00@Q21cW7>LLi`<HaP037>LHaQBU008HaP8Q
208Li`<HaPDLi`038@PLiacW00@Q20<Li`<Q20057>LU:BU:;F/U:@048@P01RDY8@PQ21S67>LQ208U
:@048@PLiaS68@P29BT37>L02B486<HHaQS67>LQ22DY7>LDY@026<H68@P39BT28@P011cW6<HHaQS6
0QBU00<HaQBU6<H00QcW0QS60acW00@HaQBU6<HLi`<HaP@DY@<Li`8HaP065:D@Q1cW7>LU:B480acW
0QS60QcW00@HaQBU5:DHaP<Q20037>LHaQS600@DY@@Li`056<HLib488@PHaP025:D56<H01ABU6<HD
YABU9BT00Re[00HYBQS65:DHaQBU6<H35:D26<H01ABU48@DYAS65:D00QS600DDYAS65:DHaQBU008@
Q0085:DHaQBU36<DYAS67>LHaP@@Q0035:D@Q124008@Q08DY@036<HLiaBU00<DY@8HaP8DY@046<HD
YA2448@35:D36<H25:D01a245:DLib487>L@Q0aS008@Q0@DY@036<HLiacW00@HaP055:D@Q1BU48@D
Y@0248@25:D011S65:D@Q12411BU00<@Q1BU6<H00QBU0Q2400@DYA2448@<H`<@Q08<H`0648@DYAS6
5:D@Q1BU0QcW0aBU1A240QBU112400<DYA2448@00QBU00<@Q0aS36<00PaS0Q240aBU00<@Q1BU5:D0
0a240QBU11240`aS0a2400<<Ha2448@010aS1Q2400`<Ha2448@@Q0aS48@DYA2436<@Q0aS5:D348@0
0aBU48@DY@0248@00aBU6<HDY@0248@01`aS48@@Q1BU36<@Q0aS00<@Q0<<H`0548@<Ha2436<8@P02
36<248@336<01A245:DDYA2436<00Q240`aS11241PaS00<@Q0aS36<01@aS00<8@PaS36<00`aS1A24
00@<H`Q236<DY@8<H`05248@Q12436<8@P0736<010Q236<@Q0aS0PQ200<<Ha2448@00PaS00D8@PaS
36<<H`Q2008<H`8@Q0L<H`48@P4<H`48@P0000D000@Q12448@0000H48@06248aS5[F>LhQ22e[2CW>
00Le[C6<;F/]Jc6<=Jdmk`02>Lh00cF];F/YBP04;F/00bU:9BTU:@02;F/2<H`01be[:DXYBRU:;F/a
S2e[00<YBP03<H`]JbDY008U:@LaS0H]J`05:DXU:B489BTYBP029BT01BU:;F/U:B487>L00RDY0R48
00@U:BU::DXYBP8]J`06:DX]Jbe[:DX]JbU:0RDY0b480QcW0b480acW00<Q21cW8@P00QcW00HHaQcW
6<HLib48:DX2=Jd00c6<;F/Q20039BT00bU:;F/aS002<H`01SF]>Lhmkcg_=Jd]J`<Q20049BTQ2248
6<H47>L36<H02AcW5:D@Q1BU6<HQ21cW6<HLi`046<H00acW8@PU:@028@P26<H00acW8@PU:@02:DX2
9BT48@P29BT01R489BTQ22489BTQ208U:@8Q20039BTQ22DY008Li`8DY@8Li`058@PLiacW7>LQ2002
7>L011S67>LQ22480acW00<Q21cW7>L00QS60QcW00<HaQBU5:D00QS600<Q21cW7>L00acW00DHaQcW
7>LHaQcW00<DY@8HaP<DY@8HaP075:DHaQBU5:D@Q1BU6<H00b4811cW0R480QcW00TDYAS65:DDYAcW
8@PU:B486<H00QBU00h@Q1S648@@Q1BU6<HLib487>LHaQBU6<HDYA240aBU0aS600DLiaS66<HLibDY
008YBP8Q20046<HLiacW6<H248@011BU6<HDYABU0a2411BU0Q2400DDYAS66<HHaQBU00DHaP8@Q005
5:DHaQBU5:D@Q0035:D00a245:D@Q0035:D00aS67>LHaP045:D00aS65:D@Q00348@25:D01AS65:DD
YABU48@00QS600TDYA2448@DYAS65:D@Q1BU6<H00aBU00@HaQcW6<HLi`<HaP@@Q0056<HDYABU5:DH
aP035:D248@01QBU48@@Q1245:D@Q08<H`8@Q0035:D@Q124008DY@0348@DYAS6008HaPLDY@@@Q003
6<HDYA2400HDY@8<H`8@Q0045:D<Ha2448@25:D548@01ABU6<HDYABU36<02a240QBU00<@Q1BU48@0
0a2400P<Ha245:D@Q1BU48@<Ha240PaS0a240PaS0Q2400<DYA2436<00a2400<DYA245:D00QBU00@@
Q0aS36<<H`<@Q00336<@Q124008@Q0035:D@Q0aS008@Q0<<H`0448@<H`aS36<248@00`aS48@@Q002
5:D010aS48@@Q0aS11240PaS00<@Q0aS36<010aS00D@Q0aS248<Ha2400L<H`04248<H`aS48@436<0
112436<@Q0aS112410aS00<8@PaS36<00Q2400<<H`Q236<010aS00<@Q0aS24800PQ200H<H`Q22488
@PaS48@:36<1248000<48@0300048@@Q00D48@0;248YBUJe@Q0U:Be[<H`]JcF]>Lhmk`03=Jd00cg_
>LhaS002;F/3<H`2=Jd2>Lh0136<:DXU:BU:12e[0bU:1Be[00DaS2e[:DXU:BU:00<]J`03:DXQ22DY
008YBP03;F/aS36<008aS08]J`<aS005=Jd]JbDY8@PU:@02:DX29BT2:DX01BDY8@PQ21cW8@P00RDY
00<YBRDY9BT00RDY12e[00@YBRDY:DXYBP8U:@048@PLiacW7>L48@P02BDY7>LQ21cW8@PLib487>LD
Y@027>L00bU:<H`]J`02<H`012e[:DXQ22480bU:00X]Jc6<;F/YBSF]>Li6<Cg_<H`YBPHQ20047>LH
aQS66<H37>L00aBU6<HDY@036<H37>L36<H02acW8@PQ22489BTLiaS67>LHaRDY:DX00S6<00<YBR48
8@P00R480bDY00DQ21cW7>LLib48008U:@8Q20057>LU:BDY8@PLi`056<H28@P87>L36<H011cW8@PQ
21S60QcW21S60acW00DHaQcW6<HHaQcW00DHaP045:DHaQBU5:D36<H35:D01aS648@<HaBU7>LQ21cW
008HaP038@PLiacW008HaP<Li`075:DHaQBU9BTYBRDY6<H00Q2400<DYA245:D00QBU00<HaQBU6<H0
0QcW00LHaQBU48@DYA246<HDY@026<H03aBU6<HHaQS65:DQ22e[<H`YBQS65:DLiaS67>LHaP0248@3
5:D348@36<H00aBU48@DY@025:D36<H25:D27>L35:D26<H45:D01AS65:DDYABU48@00QBU1QS60QBU
00<@Q1BU5:D00QBU00L@Q1BU5:DHaQBU48@DY@036<H25:D00aS65:D@Q00248@01AS65:DDYA246<H0
0QBU11S60aBU00H@Q1BU6<HHaQBU48@26<H011BU48@@Q1240aBU0a2400DDYA2448@@Q1BU00@@Q0@D
Y@@HaP8DY@056<HDYA2436<@Q0035:D01Q245:DDYABU6<HDY@8<H`0748@DYABU48@<Ha245:D00Q24
00<<Ha2448@00Q241QBU0Q2400DDYA2436<@Q0aS00<@Q0<DY@H@Q00336<@Q124008@Q00336<8@PaS
00<@Q0<<H`<@Q0035:D@Q124008<H`8@Q0035:D@Q124008<H`0448@<Ha2436<348@011BU48@@Q1BU
0Q240PaS0Q2400L<H`Q236<<HaBU48@<H`0248@00aBU48@@Q00248@010aS48@@Q1241@aS00<8@PaS
36<00Q240PaS00<@Q0Q224800PQ22@aS0Q2400D8@PaS36<@Q1BU008<H`@@Q00336<8@PQ200/<H`88
@P<<H`03248<H`Q20088@P8<H`0448@<H`aS248436<1248136<12480000300048@0000848@0=0004
8@@Q248000@Q248aS5kg@Q0Q236<>Lh00SF]1c6<00<e[C6<<H`00SF]0d8@00Lmkc6<<H`]JbU:9BTY
BP03;F/2:DX01be[<H`]Jbe[:DX]Jc6<008]J`<YBP8U:@8YBP039BTQ22DY008]J`8aS003;F/aS36<
00<e[@04<H`]Jc6<<H`2;F/01RU:;F/aS36<:DXU:@8Li`039BTQ224800<U:@8YBP0=;F/aS36<;F/Y
BRDY;F/YBR489BTYBRDY7>L00QS61B4800@U:B488@PQ20DLi`048@PYBRe[;F/2<H`01be[:DXU:Be[
:DXU:B48008U:@048@PU:AcW8@P2<H`2>Lh012e[=Jd]JbU:0bDY0QcW00PHaQcW8@PQ21S65:D@Q1BU
11S600DLiaS66<HHaQcW008Q20@U:@8Q2006:DX]Jc6<<H`YBRDY0RU:00<]JbU:9BT00R4800PLiaS6
6<HQ22DY8@PLiaS60QcW00<HaQcW8@P00QcW0QS600@Q22DY:DXU:@8Li`8Q20057>LHaQcW8@PLi`03
8@P27>L46<H35:D00a246<HLi`027>L00aS67>LHaP026<H25:D01QS67>LLiaS648@DY@8HaP@Li`03
6<HDYABU00HDY@046<HQ21cW8@P46<H27>L02ABU7>LU:BU:8@PDYAS65:D@Q0035:D021S648@@Q124
5:D@Q1BU6<H25:D248@35:D46<H01QBU48@Q22U:;F/YBP8Li`8HaP045:D@Q1246<H27>L02AS648@D
YABU36<@Q1S68@PHaP025:D00aS67>LHaP035:D36<H011BU6<HDYAS61ABU1AS60QBU0QS600<DYA24
48@00QBU1A2400<DYAS65:D00QBU00<@Q1BU48@01AS60Q240QBU00<HaQBU5:D00QBU0QS611BU00@H
aQBU5:DHaPDDY@H@Q00:5:DHaQBU48@<Ha245:D@Q1BU48@35:D011245:D@Q1240QBU0aS60QBU0Q24
11BU0Q2400DDYA245:DHaQcW008HaP035:D@Q124008DY@@@Q08<H`8DY@@@Q08DY@<@Q0<DY@0848@<
Ha245:DHaQBU48@<H`8DY@8@Q00636<@Q12448@DYA240`aS0Q240`aS0aBU0a2400<DYA2448@00PaS
0Q2400<DYA2448@00Q2400<DYA2448@00a2400PDYAS65:D@Q0aS48@DYA2410aS0Q240`aS00@@Q0aS
36<@Q08<H`0448@<Ha2448@236<248@01ABU48@@Q0aS24800PaS00<DYA2448@01`aS10Q21`aS00<8
@PaS36<00PaS0Q2410aS0Q240`aS1@Q200<<Ha2436<01`aS00@8@PaS2488@P@<H`88@P0536<8@PaS
36<8@P01124000H48@0300048@Q200848@06248]Jekg?NlQ236<0SW>0c6<00<YBRe[<H`00c6<00/]
Jc6<=JdaS3W>?Nm244YBAS4mkcF]00<YBP8]J`05:DXU:BU:;F/aS004;F/00c6<;F/YBP02:DX012e[
:DXYBRU:12DY00@YBR489BTe[@8mk`04=Jd]Jc6<<H`3;F/3<H`2;F/3<H`00bU:8@PU:@028@P29BT2
:DX012DY:DX]Jbe[136<00T]JbDY:DXU:BU:9BTQ21cW6<H00acW00DU:B489BTU:B4800@Li`066<HL
iaS67>LYBRe[0S6<0Re[00<YBRDY9BT00RU:00<U:B487>L00acW00@U:BU:;F/]J`8e[@05>Lhe[Be[
;F/U:@047>L00bDY7>LHaP035:D26<H01AcW6<HDYAS67>L00aS600<Lib488@P012DY1RU:0bDY00XY
BRe[:DXU:AcW6<HLib489BTQ208Li`8Q20DLi`8HaP8Li`8U:@038@PLiacW00<Q20047>LHaR488@P3
9BT012486<HHaQBU0QS600XDYA245:DDYA246<HLib487>LHaP8Li`056<H@Q1BU6<HLi`035:D00aS6
5:DHaP037>L00aS65:DDY@045:D011S65:DHaQcW0R4800<LiaS66<H00QcW0aS600@Lib488@PQ208H
aP075:DHaQBU5:D@Q1BU48@00QBU0QS600@DYA2448@@Q0PDY@056<HDYAS66<HQ20039BT00b486<HH
aP025:D011S67>LHaQBU0Q241ABU00XHaQcW5:DDYAS68@PHaQBU48@DY@8Li`036<HDYAS600PDY@LH
aP@DY@0348@DYA24008DY@<@Q0<DY@086<HDYA2436<DYAS67>LHaPDDY@0348@DYA24008DY@8HaP<D
Y@<HaP8DY@8HaP055:D@Q12448@DY@0348@01ABU6<HDYABU36<01A240QBU00<@Q1BU5:D00QBU0a24
00<DYAS65:D00Q2400<DYA245:D00QBU0QS60a2411BU0Q2400<DYA245:D0112400<<Ha2436<00Q24
00@DYA2448@@Q0<DY@0348@DYA2400<@Q0075:D@Q1245:DHaQBU48@00PaS00X@Q1BU48@@Q0aS48@D
Y@aS248<H`8@Q08<H`045:D@Q12448@35:D548@236<011245:DDYA240PaS0a2400@<Ha2448@@Q0<D
Y@@@Q0<<H`0348@<Ha2400@@Q08<H`@@Q00636<@Q1245:D@Q1BU0Q2410aS00<@Q0aS48@01`aS0PQ2
0`aS0`Q21@aS00D8@PaS36<8@PaS008@Q08<H`03248<H`aS008@Q0<<H`88@PX<H`03248<H`Q20088
@P@<H`88@P<<H`<8@P0000D000@Q00048@0000D48@060008@R48CW<mkbU:0c6<00@e[C6<<H`]J`8Y
BP03;F/aS2e[008]J`04<H`e[CW>>Lh2?Nl3@Q0013g_=JdaS2e[0bU:0Re[00DYBRe[:DXaS3W>008m
k`08>LhaS36<:DX]JbU:;F/YBPHU:@8]J`03<H`YBSW>00924004>Lh]Jc6<=Jd2<H`3>Lh00c6<;F/]
J`03:DX012DY:DXYBRU:0RDY0RU:00<e[C6<=Jd012e[0bU:00<U:B487>L00QS60QcW00<Q22DY:DX0
0bDY0b480acW00<U:BU::DX00RU:00<U:B488@P00RDY00<Q21cW7>L00acW0aS600HQ21cW7>LU:B48
>Lh2AS401DYB>LhYBRDY8@P00bDY0QS600DDYAS67>LLiaS600@Li`8HaP037>LQ21cW00<Li`038@PU
:BDY008YBP8U:@077>LQ21cW7>LU:B48:DX00RDY0R4800PLib488@PQ22DY8@PLiaS60QcW00<Q22DY
6<H00QBU00HLibDY:DXU:B487>L38@P01QcW8@PQ22U:9BTQ208U:@037>LHaQS6008Li`036<HDYABU
00<HaP8Q20047>LHaQBU6<H37>L01QBU6<HHaQcW8@PHaP8DY@046<HQ22486<H45:D46<H00acW6<HD
Y@026<H01ABU6<HHaQcW6<H00QBU0QcW00<HaQ246<H00QS611BU00@HaQBU48@@Q08DY@0348@<H`aS
008@Q08DY@0348@DYABU008DY@0;48@HaQS65:DQ22e[<H`YBQcW5:DHaP025:D00aS65:DHaP036<H0
1ABU48@DYABU6<H01ABU00DHaQcW6<HHaQBU008HaP047>LHaQBU6<H57>L01AS67>LHaQS65:D011S6
00DDYA245:DDYAS600<DY@0548@DYABU48@DY@026<H248@010aS5:DDYABU0QcW0QS60aBU00LHaQBU
5:D@Q1BU6<HLi`036<H011cW6<HDYABU0Q2400DDYA245:D@Q1BU00@@Q00336<@Q124008@Q00336<@
Q1BU008DY@<@Q0DDY@0348@HaQS6008HaP035:D@Q124008@Q0085:DHaQBU48@DYA245:D@Q0<DY@03
6<HDYA24008@Q0056<HDYA2436<@Q0045:D448@010aS5:D@Q1BU0a240aBU00<HaQBU48@00Q240aBU
00<@Q0aS48@00PaS00<@Q0aS36<00`aS0a2400D<Ha2436<<Ha24008DY@L@Q00436<@Q12436<348@0
10aS48@<H`aS0Q2400@DYA245:DHaP@@Q0055:D@Q0aS36<8@P0>36<248@00aBU48@<H`0236<948@6
36<324801`aS48@@Q0aS248<H`Q2008<H`0548@<H`aS36<@Q00236<348@00`Q236<<H`0236<010Q2
36<<Ha240`aS0Q240PaS0PQ20PaS0PQ210aS0`Q20`aS0@Q2000;12402`Q29BU:DS6<7>L]JcF]<H`Y
BRe[<H`02Be[00PaS3F]=Jde[CW>?Nm244Ha0Sg_12e[00<aS2U:;F/012e[00HaS3F]?Nlmkd8@?Nl2
<H`2:DX3;F/00bDY8@PU:@02;F/01BU:9BTYBRe[=Jd00Sg_00DicS6<;F/]JcW>008e[@8icP04<H`Y
BRDY:DX3;F/2:DX00bDY:DXU:@02:DX2;F/2<H`00be[:DX]J`02:DX01BDY7>LLiacW8@P00QcW00<Q
21cW:DX00RU:12480QcW00@HaR489BTU:@8YBP039BTYBRDY00<Q20039BTQ21cW008Li`036<HLiacW
008HaP<Li`07;F/aS3g_BU9243g_=Jd00bDY00<Q22DY8@P00QcW00DHaQBU6<HLib4800<Li`048@PL
iaS66<H27>L011S67>LLibDY0R480RDY0QcW00HHaQcW9BTQ22DY:DX28@P00acW8@PU:@037>L29BT2
7>L00b487>LHaP026<H27>L00b489BTQ20028@P27>L012487>LU:BDY0RU:00<U:B487>L00QcW11S6
0QBU0QS600@LiaS65:DHaP8Li`@HaP055:DHaQcW8@PLi`026<H27>L00b487>LHaP035:D27>L25:D0
11S67>LHaQBU0aS60QBU11S60QBU0QcW00@HaQBU5:DHaP<DY@046<HDYAS648@35:D0112436<<H`aS
11240QBU00<HaQBU5:D00Q2400HHaRDY<H`aS2487>L36<H00aBU48@DY@026<H00aBU48@DY@026<H2
5:D26<H011BU6<HHaQS60aBU00@HaQcW7>LHaP<DY@@Li`8HaP037>LHaQcW00<HaP035:D@Q124008D
Y@047>LHaQBU5:D248@03ABU6<HHaQBU48@DYAS65:D<Ha245:DHaQcW00<HaP@DY@0648@DYABU6<HQ
21cW0QS600LDYAS67>LHaQBU48@DY@0248@011BU48@DYA240PaS112400<<Ha2448@00QBU00<@Q0aS
48@00QBU0Q2400TDYAS65:D@Q1BU6<HDYAS648@00QBU00<@Q1S66<H00QS600D@Q1BU48@@Q1BU008H
aP045:D@Q12436<35:D0112436<@Q12411BU0PaS00<@Q1BU48@00a2400@DYA245:D@Q0DDY@<@Q003
5:D@Q124008<H`<@Q08<H`06248<H`aS36<@Q1BU0Q240PaS00D@Q1BU5:D@Q0aS008@Q0035:D@Q0aS
008@Q0035:D@Q0aS00<<H`0348@DYA24008<H`0348@DYA24008DY@0448@DYA2448@236<248@00`aS
48@@Q00348@436<01Q2436<<H`aS48@DY@8@Q004248<Ha2436<348@336<348@336<00`Q236<<H`02
36<2248236<01@Q236<<H`aS248010aS0Q241PaS0Q2400<<H`Q236<00PQ210aS00<@Q0aS36<00`aS
1PQ200@<Ha2436<<H`88@P448@0000H48@00124000@Q0005124020Q28@Q:DS6<8@PYBS6<:DX2;F/0
136<;F/YBRDY0RU:0Re[1S6<0Re[0SF]00@aS2e[:DXYBP@aS00C;F/aS36<;F/aS2U:<H`e[CW>AS5:
DT8@>Lhe[Cg_@Q0e[Be[:DX00S6<0Re[0bDY00<]JbU:;F/00SF]0c6<00@icS6<<H`]J`<aS003;F/Y
BRe[008aS003;F/U:BDY008YBP06;F/YBRU::DXU:Be[0S6<00<e[BU:9BT00QcW00<Q21cW7>L00acW
0RDY0R480RDY1R4800<U:BU::DX00RDY0R4800<U:B489BT011cW1AS60QcW00/U:B489BTU:Be[<H`i
cSg_@Q0mkcW>008aS005:DXQ21cW7>LQ20027>L00b489BTQ20028@P01BDY8@PLiaS67>L00aS611cW
00DHaQcW7>LHaQcW00@Q208YBP038@PLiacW00<U:@068@PLib488@PU:B480QcW0QS60QcW00<Q21cW
7>L00QS60R4800/U:BU:8@PU:B489BTYBRDY8@PHaQcW00DHaP065:DHaQcW8@PLiaBU0QS60QBU00@H
aRDY8@PQ20<DY@046<HLiacW7>L38@P011S65:DHaQS60aBU0QS60QcW0QS600<LiaS67>L00aBU00L@
Q1BU5:DHaQBU6<HDY@036<H25:D01A245:DDYA245:D01A2400DDYA2448@@Q1BU008@Q08DY@8Li`07
5:D@Q1S68@PYBRe[8@P00QcW00<DYAcW7>L00acW0QS61QBU00<@Q1BU5:D00QS600@DYA245:DDY@<L
i`036<HDYABU00@HaP085:DLib487>LHaQ246<HLi`8HaP035:DHaQBU008DY@8HaP035:D@Q1BU00<D
Y@0448@DYA245:D248@00aBU6<HHaP045:D27>L01AS65:DHaQS65:D00Q240QBU00H@Q1BU6<HDYA24
36<248@00aBU48@<H`0548@010Q236<<H`aS0Q2400TDYA2448@DYAS65:DHaQBU6<H00QBU0Q2400<D
YA2448@00aBU00D@Q1BU5:DHaQcW008DY@0336<@Q1BU008@Q0085:DHaQS66<HDYAS648@DY@8HaP04
5:D@Q12448@45:D348@01QBU48@<H`aS48@<H`8@Q0045:D@Q12448@25:D348@00aBU48@<H`0436<3
48@236<00`Q236<DY@0248@00`aS5:DDY@0248@01@aS48@<Ha2436<00a2400<DYA2448@00a240`aS
1Q240PaS0Q2400<DYA2436<00PaS00<@Q0aS48@00Q2400@8@PaS48@@Q0<<H`065:D@Q1245:DHaQBU
0PaS00<@Q0aS36<00PaS1A241PaS10Q200<<H`Q236<00PaS0PQ200<<Ha2436<00`aS0aBU1PaS00<@
Q0aS36<00PaS00<8@PaS36<00QBU00@@Q0aS1248@P<<H`03248<H`aS00@<H`04248<H`aS36<12480
000300048@@Q00H48@0700048@@Q9BU6<CF]9BT00Re[12U:00<]JbU:;F/00bU:0Re[00<aS3F]<H`0
1c6<12e[0S6<00<e[C6<;F/00Re[00<aS2e[<H`00S6<0SW>0cg_00=243W>>Lh01C6<0Re[0RU:00<U
:BU:;F/00S6<0RU:00DaS3F]=JdaS2e[00@aS003;F/aS2e[00<]J`HYBP8U:@0?:DX]JcF]>LhaS2e[
8@PLib487>LU:AcW6<HLib48008U:@058@PLiacW8@PU:@028@P01acW8@PU:B489BTYBRDY00<Q2003
:DXQ21cW008Li`056<HLiaS67>LDY@026<H00acW9BTU:@049BT012U:>Li2448@0cF]00<aS2e[8@P0
0RDY0acW1B4800@U:B487>LHaP<Li`8HaP037>LQ2248008Li`036<HLib4800@Q20039BTQ2248008U
:@8Q20037>LHaR48008U:@038@PHaR48008Li`036<HLib48008Q20076<HLiaS67>LQ22DY:DX00R48
00@U:BU:9BTQ208Li`LHaP8Li`8Q208HaP0548@HaQcW6<HQ20027>L35:D01QS65:DHaR489BTQ208H
aP035:DHaQcW008DY@0348@DYAcW00<Li`8HaP8Li`036<HDYAS6008DY@<HaP@DY@<HaP035:D@Q124
00H@Q0035:D@Q12400@@Q00>5:D@Q1S65:DHaQ245:D@Q248;F/aS2U:6<HDY@DHaP8Li`<HaP045:DH
aQ2448@25:D011S65:DDYAS60aBU00<HaQcW6<H00aBU00<HaQBU5:D00QS60QBU0aS600LDYAS67>LL
iaS65:DHaP025:D00aS65:D@Q0035:D248@25:D248@25:D01Q245:DHaQS65:DHaP8Li`036<HDYABU
008HaPHDY@036<HDYA24008<H`D@Q00336<@Q1BU00<@Q08<H`@@Q0045:D@Q1BU5:D248@011S65:D@
Q1240QS60a2400<HaQBU48@00QBU00<HaQBU5:D00QBU0a2411S600HDYAS65:DDYA245:D26<H00aBU
48@@Q0055:D248@00`aS48@@Q00348@25:D011245:DHaQBU0Q2400D<Ha245:DDYA24008<H`0448@<
Ha2436<248@236<0112436<<H`aS0Q240PaS00<@Q1BU48@00PaS00<@Q1BU48@01A2400L<Ha2448@@
Q0aS48@<H`0248@236<011BU48@@Q0aS11240`aS0Q240PaS00<@Q0aS36<00PaS00<@Q1BU5:D01124
00@DYA2448@@Q08<H`03248<H`aS008<H`0348@DY@aS008<H`8@Q08<H`03248<H`Q200<<H`03248<
Ha24008<H`04248<H`aS48@236<348@336<00a2436<<H`0336<224801`aS48@DYABU36<8@PaS00<8
@P0636<@Q0aS36<8@PaS0Q240PaS0@Q20@aS0@Q2000212401P0012448@@Q0008@P<48@06248Q24YB
<H`LibDY0be[00<aS2e[9BT00R480bU:00<]Jc6<=Jd00c6<00De[C6<<H`aS3F]008icP05<H`YBRU:
;F/e[@02<H`2=Jd00c6<;F/aS004=Jd01CW>;F/YBRe[<H`00SW>00De[CW><H`aS2e[00@YBP8U:@8Y
BP03;F/aS36<008aS005;F/YBRe[;F/e[@04;F/3<H`00bU:9BTU:@03:DX39BT2:DX2<H`012e[:DXQ
21cW0R481AcW00<HaQcW6<H00acW12480QcW00<Q22U:9BT012DY124800DU:AcW6<HDYAS6008Li`05
9BTQ22488@PU:@03:DX29BT2:DX00bDY;F/aS002>Lh0136<;F/Q21cW124800@Lib489BTQ20<Li`@H
aP8Li`8HaP037>LHaQS6008Li`048@PLiacW7>L29BT00b489BTU:@028@P00acW8@PU:@029BT27>L0
12489BTQ21S61QcW00<HaQcW7>L00QcW00<Q21cW7>L011cW0R4800<LiaS66<H011cW0QS60acW00DH
aQBU6<HLib48008Li`038@PHaQS6008DY@8HaP<Q20037>LHaQBU00@HaP035:DHaQcW00<Li`8HaP03
7>LQ21cW008DY@<HaP8DY@046<HDYAS66<H35:D00a2436<@Q0025:D011S65:DDYA240aBU00P@Q1BU
5:DDYAS65:DHaQBU0QS600HDYAcW;F/aS2e[8@P36<H00aBU6<HLi`028@P26<H25:D248@26<H01AcW
6<HHaQBU48@00QBU1aS61aBU0QS60QBU0QS600<LiaS66<H00QBU00D@Q1BU5:DHaQBU008@Q0<DY@8@
Q08DY@8@Q0055:DHaQcW7>LHaP025:D00a246<HHaP046<H00a245:DDY@025:D0112436<<H`aS1A24
0PaS00D@Q1BU5:DDYA24008<H`0;48@DYABU48@DYA245:DHaQBU48@DY@026<H01aBU48@<Ha245:DH
aQcW00HDY@8@Q00436<@Q1245:D248@25:D26<H45:D27>L26<H248@011BU48@@Q1240PaS21240PaS
00@@Q1BU48@DY@8@Q0045:D@Q1BU48@336<248@00`aS48@@Q00248@00`aS48@@Q0025:D0112436<<
H`aS212400@DYA245:D@Q08<H`8@Q0035:D@Q124008@Q00336<@Q0Q2008<H`0948@DYA2436<8@PaS
48@DYA24008<H`<@Q0<<H`035:D@Q124008@Q00436<@Q0aS248636<00a2436<<H`0336<248@00`aS
2488@P0336<01Q2436<<H`aS248<H`<@Q0<<H`<@Q08<H`88@P0536<@Q12436<8@P0436<248@236<0
0`Q236<8@P03248536<248@00`aS2488@P0224800005124000@Q12400007124012DYBU8icR480RU:
12e[0RU:00<U:BU:9BT00RU:12e[1S6<0SW>0SF]0S6<00L]JbU:;F/e[CW>=JdaS002;F/013F]>Lhi
cSF]0Re[0RU:00TaS2e[<H`aS3F]<H`]JbU:;F/00RU:00DU:B489BTYBS6<008]J`<aS004;F/YBRe[
:DX3;F/3<H`012e[:DXYBRe[0bDY00<YBRe[:DX00RDY0RU:00<]JbU::DX00RDY00@Q22DY8@PQ208L
i`<HaP068@PLiacW7>LHaQcW124800PU:BU::DXU:B489BT]JbU:1B480QS600HLib489BTYBRDY8@P2
9BT00be[:DXU:@02:DX39BT01RU:=JdicS6<;F/Q20@U:@8Li`<Q208Li`8Q20057>LHaQS67>LHaP02
7>L36<H47>L00aS67>LQ20039BT012487>LQ21cW0R4800@U:B489BTQ208U:@8Q208Li`8Q20077>LH
aQcW7>LQ21cW8@P00acW0QS600dQ21cW8@PLib486<HDYAcW8@PU:AcW6<HLi`028@P00acW6<HHaP02
6<H021cW6<HQ22487>LQ21S65:D26<H00acW9BTQ20027>L46<H00aBU6<HDY@036<H00acW8@PQ2003
6<H27>L01aS65:DHaQBU48@DYA2400<HaP@DY@0348@<Ha24008DY@<@Q0046<HDYABU5:D348@03QS6
7>LLiacW5:D@Q1S69BTaS3F]9BTHaR487>L36<H38@P00acW5:D@Q0035:D27>L012487>LHaQS61QBU
11S600DDYAS66<HDYA24008DY@8Li`056<HDYAS65:DLi`026<H65:D0112436<@Q1240QBU00@@Q1BU
5:DDY@8@Q0055:DLiacW6<HLi`055:D46<H45:D348@010aS48@@Q12410aS1A2400@<Ha2448@DY@<@
Q08DY@0848@DYA246<HDYAS67>LDY@<@Q0035:DHaQS600@DY@8HaP065:D<H`aS48@HaQBU0Q2400LD
YAS65:DDYA245:DHaP027>L36<H01ABU48@@Q1BU48@00PaS0Q2400<DY@aS36<01a240QBU0Q2400@<
HaBU48@@Q08<H`0348@<H`aS008@Q0@<H`045:DHaQBU5:D248@011BU36<@Q0aS0Q240PaS00<@Q1BU
48@0112400@DYA2448@<H`@@Q00?5:D<H`aS36<8@Q2436<@Q0aS48@<H`Q248@DYA2400<<H`0648@<
H`aS48@DYA240PaS00<@Q1BU5:D00Q2400<8@PaS36<010aS0a241`aS0PQ22@aS0Q2400<<Ha2436<0
0PaS0Q2420aS0`Q200@<Ha2448@<H`88@P@<H`03248<H`aS00<<H`0348@<H`aS008<H`48@P0000@0
00@Q124000L48@05248YBTic<H`Li`04:DX00bDY:DXYBP03;F/2<H`2;F/3:DX4;F/2<H`01D8@BU96
<CW>:DX0136<0be[0c6<0SW>00<e[Be[9BT00bU:00<U:BU::DX012U:00@U:B489BTU:@@YBP8]J`05
:DXaS2e[:DX]J`02:DX00be[:DX]J`02;F/00c6<:DXYBP03:DX012e[:DXYBRDY0RU:00TU:AcW9BTY
BS6<;F/YBRDY8@P012DY11S600<Q21cW7>L00QcW0R4800XLib488@PYBS6<=JdaS2e[9BTYBP<U:@05
:DXU:B487>LHaP028@P02BDY;F/]JbU:9BTYBS6<=Jd]J`029BT012U:9BTLiacW0R4800<DYAS68@P0
0bU:0Re[00<YBR488@P00RDY00@Q21cW7>LHaP/Li`058@PLiaBU6<HLi`028@P00acW8@PU:@078@P0
1AcW9BTYBRU:;F/00bDY0R480QcW0QS600HLiaS67>LQ21cW6<H35:D46<H47>L00aS67>LQ20038@P0
21cW6<HLiaS67>LHaQBU7>L28@P011cW6<HHaQcW12480QcW0aS600<LiaS65:D00QBU0R4800DLib48
7>LHaQBU008HaP037>LHaQBU008HaP065:D@Q1BU6<HDYAS60QBU0a240QBU00D@Q1BU6<HHaQBU008@
Q0<DY@046<HDYAS67>L35:D02AS68@PQ22U:>Lhmkc6<7>L@Q0026<H031246<HQ21cW6<H@Q0aS48@D
YAS67>LHaP<Li`066<HDYABU5:D<Ha240QS60aBU0QS60QBU0aS600<DYAS65:D00QBU0QS60QcW00<D
YA2448@00QBU1A2400<DYA2448@00aBU00L@Q1BU6<HQ21cW6<HDY@0248@25:D00aS65:D@Q0065:D5
36<0112436<<H`aS0aBU00L<Ha2448@DYA2436<@Q0025:D00a245:D@Q00248@25:D26<H00acW8@PL
i`025:D011245:DDYAS60Q2400HDYAS66<HLia245:D448@01ABU48@@Q1246<H00QBU0PaS00/DYAcW
8@PHaQ245:DHaQBU48@<Ha2400<DY@8<H`03248@Q12400@@Q08DY@<@Q0045:D@Q12448@536<448@0
10aS48@@Q1240aBU00@HaQBU5:D<H`D@Q0045:D@Q12436<748@236<348@00`aS48@<H`0636<01Q24
36<@Q1BU48@<H`88@P@@Q08<H`0348@<H`aS00@@Q00436<8@PaS48@236<01`Q236<<H`aS248<Ha24
008<H`88@P<<H`8@Q00536<8@PQ236<@Q00336<00a2436<@Q00248@236<00a2436<<H`02248236<0
0`Q236<8@P0336<248@010aS2488@PaS0`Q20PaS00D8@PaS36<@Q0aS0088@P4@Q048@P001@@Q00<0
00@Q12400P@Q00X000Q29BU>LcW>9BTYBRe[:DXU:@HYBP8]J`03<H`]JbU:008YBP8]J`8YBP039BTY
BT8@009:DP0:>Lh]JcF]=Jd]JbU:<H`e[C6<;F/2:DX01SF]?Nle[C6<9BTYBP8]J`03:DXU:BDY00<Y
BP8U:@06:DXQ22488@PYBRe[0bU:00@]JbU:;F/aS08]J`04:DXU:BDY;F/3<H`2;F/3:DX012DY:DXY
BRe[0RDY0R480RDY00HYBS6<;F/YBR489BT2:DX28@P01QcW6<HHaQS67>LQ208Li`046<HQ22489BT2
8@P012DY;F/aS2e[1BU:0RDY0R480acW00TQ22U:;F/YBRDY:DX]Jc6<:DX00RDY00<YBRDY9BT00R48
00<HaQcW7>L00QcW00PHaR48<H`icS6<9BTQ22DY0R4800<HaQcW8@P00R4800<LiaS67>L00b4800@U
:B489BTQ208HaP8Li`048@PLiacW7>L78@P27>L00b487>LYBP029BT00bU:9BTU:@057>L36<H27>L0
12487>LHaQS60QBU1AS61AcW00<U:B488@P00RDY0QcW0QBU0QcW0R480QS60QcW00LU:B488@PQ21cW
8@PHaP045:D36<H01QcW8@PLiaS67>LHaP8Li`056<HDYABU5:DHaP025:D01A245:DDYA246<H00QBU
0Q2400D<HaBU5:DDYA2400DDY@0348@DYABU008HaP<DY@0;7>LHaQcW6<HQ23W>@Q0mkbDY5:DHaP02
5:D011S67>LHaQS60Q2400@HaQ245:DDY@8Li`056<HDYABU5:DHaP025:D00a245:DHaP025:D00a24
5:DHaP036<H37>L00aS65:D@Q0035:D01AcW6<HHaQS65:D00Q2400PDYA2436<@Q1BU6<HDYA240QBU
0QS600@DYA245:DLi`8Q20036<HDYABU00@DY@0348@DYAS600@DY@8@Q00336<@Q12400<@Q00436<@
Q1BU5:D448@01ABU36<<HaBU6<H00Q2400<<Ha246<H00QBU0QS600@LiaS66<HHaP<DY@0<6<HDYABU
48@DYAS65:DHaQBU48@<Ha240QBU00H@Q0aS5:DDYAS65:D236<011245:DHaQcW0QBU00<HaQ2448@0
112400<<Ha2448@00`aS0QBU0a240PaS00@@Q1BU5:DHaP8@Q0@<H`0348@<Ha24008@Q0035:D@Q124
008@Q08DY@0648@DYA245:D@Q0aS0Q240QBU112400@DYA245:D<H`8@Q00436<@Q0aS36<248@536<0
1A2436<<H`aS48@010aS0Q240PaS11240`aS00<@Q0aS48@01@aS00<@Q0aS36<01`aS0PQ20PaS0PQ2
00<<Ha2436<00PaS00<@Q1BU36<00PaS00<@Q0aS36<00QBU00<<H`Q2248010aS00<8@PaS36<00PQ2
10aS0`Q20`aS00<8@PaS36<010aS00<@Q0aS24800`Q200000`001240000812401@Q29BU:DSF]8@P0
0be[00<YBRe[<H`00bU:0be[12U:0be[00@YBRDY:DX]J`8aS004:DX]JbU:<H`2:DX01Be[=Jdmkcg_
>Lh00cF]0SW>00<aS2DY9BT00RDY00<YBR488@P00bU:0RDY0RU:0RDY0RU:1be[00/YBRDY9BTU:BU:
;F/YBSW>?NlicSF]008YBP03;F/U:B4800<YBP079BTQ22489BTQ22U:;F/00S6<00<YBRDY9BT00RDY
0R4800DLiaS67>LLib4800<Li`@U:@038@PYBRU:008]J`@YBP8Q208Li`038@PLiacW00<U:@8Q2003
9BTYBRe[008YBP039BTYBRU:008Q208Li`088@PLiaS67>LQ21cW8@PU:@8]J`04:DX]Jbe[:DX29BT0
0bU:9BTU:@027>L36<H00acW8@PU:@039BT28@P00aS68@PQ20037>L01BDY7>LQ22489BT00R4800<H
aQBU7>L00RDY00<Q21cW8@P00bDY00XLiaS66<HLiaS65:DHaQcW8@PLi`<HaP055:DHaQS66<HLi`02
6<H02aBU7>LLiaS65:DHaQcW:DX]JbDY8@P00acW00@Q21cW5:DHaP8Li`039BTQ2248008U:@8Q2004
6<HLiaS66<H35:D00aS67>LHaP027>L01B487>LLiaS67>L011BU0a240aS60QBU0QS60a2400<DYA24
48@00a240QBU1aS611BU00/LiaBU8@PaS3g_>Lh]JaS67>LHaQBU00<HaP8DY@046<HDYABU5:D46<H3
5:D01aS65:DDYABU48@HaQBU00<HaP<DY@0548@DYABU6<HLi`026<H35:D00a245:DDY@035:D336<0
11245:DDYABU0Q240QBU0QS600@DYA245:DHaP8Li`8HaP035:D@Q124008@Q0035:D<Ha2400<DY@P@
Q00336<@Q1BU00@@Q0045:D@Q1245:D348@01aBU48@@Q0aS48@DYAS6008DY@036<HLiaS600<HaP08
5:D@Q12448@HaQBU6<HLi`8DY@@@Q08DY@0448@DYABU5:D348@25:D46<H25:D248@35:D0112436<<
H`aS112400<DYA2436<01a240`aS00D@Q0aS48@@Q0aS008DY@0748@<Ha245:DHaQBU48@00QBU0Q24
00<<Ha245:D00aBU1Q2400<<Ha2448@00PaS00D8@PaS48@<Ha24008<H`035:D@Q124008<H`D@Q005
248<H`aS36<@Q00336<248@?36<248@536<2248536<3248336<348@336<248@436<00`Q236<8@P03
36<2248236<324800`aS2488@P02248336<2248348@4248000<48@0300048@0000@48@090008@RU:
CW<e[AcW:DX]JbU:00H]J`03:DX]JbU:008]J`LYBP8U:@8]J`08<H`]JbU:;F/YBRDY;F/aS08mk`03
=JdaS3F]00@icP03<H`]Jb4800<Q20<U:@<YBP<U:@8YBP8]J`04:DX]JbU::DX2<H`03Re[9BTU:B48
9BTYBRDY;F/aS3g_@Q0icSF];F/39BT2:DX00bDY8@PU:@029BT3:DX00be[<H`YBP039BT012U:9BTL
iaS60QcW0R4800<Lib488@P00b480bDY12e[00@U:B488@PLi`8Q208Li`036<HQ22DY008YBP<U:@03
8@PU:BDY008YBP06;F/YBRDY8@PU:B4811cW00@HaQcW8@PYBP8U:@8YBP03;F/YBRU:00<YBP049BTL
iacW6<H27>L38@P39BT28@P01AcW8@PLib489BT00R480acW0RDY0QcW0QS600<Q22DY9BT00QcW0R48
00<U:AcW7>L00QcW00HHaQcW7>LLib487>L26<H00aBU6<HLi`037>L00aS67>LHaP026<H011BU6<HL
ibDY0bU:00@U:AcW7>LLi`8Q20077>LHaQcW8@PLiaS68@P00RDY00<Q21cW6<H00QS60QBU00<HaQBU
6<H00QS60QcW0R4800<U:AcW6<H011BU00<@Q1BU5:D00QS61ABU00<@Q1BU48@00aBU00<@Q0aS48@0
0QBU0QS60QcW00@HaQcW6<HHaP8DY@056<HDYAcW8@PU:@02>Lh012e[9BT@Q1BU11S600<DYA245:D0
11BU0aS600@@Q1BU48@HaP@DY@036<HDYAS6008HaPDDY@DHaP@DY@036<HDYABU008@Q00336<@Q0aS
00<@Q0@DY@8HaP065:D@Q1BU6<HLiaS60aBU00<HaQ2448@00Q240aBU212400@DYA2448@@Q08DY@03
48@DYABU00<DY@0336<@Q12400<DY@0448@<Ha2448@35:D26<H011cW6<HDYAS60a240QBU00<@Q1BU
6<H00QS600@DY@aS48@@Q08DY@046<H@Q1BU48@25:D248@00aBU6<HHaP025:D01QS648@DYA2436<@
Q08DY@0348@<H`aS00<<H`8@Q08DY@8<H`8@Q08DY@0548@<Ha2436<@Q00336<00a2436<<H`0348@4
5:D348@011BU48@@Q1240aBU11240aBU00<@Q0aS36<00Q240PaS00H@Q0aS36<<Ha245:D248@00`aS
48@@Q00248@536<448@010aS48@DYABU1PaS00<@Q0aS36<00PQ20PaS0Q2400@<H`Q236<8@P<<H`88
@P@<H`06248<H`Q224848@aS0a241PaS00<8@PaS48@00PaS0PQ21`aS0PQ200<<Ha2436<00PQ21`aS
00<@Q0aS36<00@Q200000`0012448@0512402PQ212448@Q2:DYBU3F]7>LYBRe[0bU:00D]JbU::DXU
:BU:00<]J`04<H`YBRU::DX4;F/39BT2;F/7:DX2;F/00cF]>LhicP02@Q0013g_>LhYBRU:0R4800DU
:B489BTYBRe[008YBP8U:@04:DX]Jc6<<H`4;F/2<H`012e[:DXU:B480RDY00TQ22DY9BTYBRDY;F/a
S3F]<H`00Re[00<aS2U::DX01RDY12e[0RU:0R4800@U:AcW7>LHaP8Li`038@PLib48008U:@03:DXU
:BU:008U:@038@PU:BDY00<YBP059BTQ22488@PU:@028@P37>L59BT01B487>LHaQS68@P00bU:00@U
:B488@PU:@8Q20<Li`048@PLib488@P29BT28@P01BDY:DX]Jbe[<H`00RDY0QBU0QcW12480bDY00<L
ib487>L02R4800@LiaS66<HHaPDLi`038@PU:B48008Li`038@PLiaS6008HaP048@PU:AcW7>L25:D3
7>L022DY8@PQ21cW6<HQ21cW5:D26<H37>L26<H28@P29BT00acW6<HHaP047>L38@P021cW5:DHaQS6
5:DHaQBU6<H27>L02B487>LHaQcW8@PU:B487>LHaP027>L011S648@@Q1BU0QS611BU0QS60aBU00<@
Q1BU5:D00QBU00@@Q0aS48@DY@8Li`085:DHaQS67>LDYAS65:DHaP8Li`0;6<HLibDY;F/YBQcW6<HL
iaS65:D@Q0035:D011245:DHaQS60QBU00XHaQBU5:DDYAS648@DYA245:DHaPDDY@036<HDYABU00<D
Y@0348@DYAS6008Li`056<HDYABU5:DHaP025:D236<00a245:DHaP0348@021BU6<HLiaS65:DHaR48
7>L36<H27>L01aBU36<@Q1245:DHaQBU00d@Q0055:D@Q12436<@Q0026<H00aBU36<DY@025:D748@0
0aBU48@HaP026<H45:D348@00aBU6<HDY@045:D348@020aS5:DDYABU6<H@Q1BU48@55:D26<H00aBU
48@@Q00548@010aS48@<H`aS0Q2400<DYA2448@00PaS0a2400DDYA2436<<Ha2400D<H`<@Q0<<H`03
5:D@Q12400<@Q0@DY@8@Q0035:DHaQBU00<@Q0055:DHaQBU48@<H`0248@436<248@336<01ABU48@@
Q0aS48@00QBU0Q2400P<Ha2448@@Q0aS48@<H`Q20PaS1A2400D<H`Q236<<Ha24008<H`0348@<Ha24
00@<H`03248<H`aS00<<H`88@P0336<@Q0aS0088@P<<H`03248<H`aS00D<H`0348@8@PaS00@<H`08
248<Ha2448@<Ha2436<8@P8<H`88@P0336<8@PaS008<H`88@P<@Q0@<H`48@P000`@Q00<000@Q0000
0`@Q00P000@Q248YBUJe@Q0Q22e[12U:00<U:BU::DX00RDY00<YBRe[;F/00Re[0S6<00D]Jc6<<H`]
JbU:008U:@8YBP09;F/YBRe[9BTQ22DY;F/e[C6<008]J`03=JdicSF]008mk`03<H`]Jb4800<U:@<Y
BP8U:@04:DX]Jbe[:DX2;F/2<H`01Be[<H`]Jc6<;F/00RU:00<U:B489BT012DY1BU:00D]Jc6<<H`a
S2e[00<YBP059BTYBRU::DX]J`02<H`00be[9BTU:@038@P47>L00aS67>LLi`028@P49BT012U:9BTQ
22480bDY00@Q22DY9BTU:@8Q20039BTQ2248008Q20049BTQ22DY9BT28@P27>L01b489BTQ22DY8@PU
:B4800<U:@03:DXQ224800@Li`8Q20059BTQ22489BTYBP02;F/00bDY8@PQ20027>L00aS67>LU:@02
9BT27>L00b489BTLi`027>L01BDY8@PQ21cW8@P00RDY00<Q22DY7>L011cW0QS600@Lib488@PQ208L
i`8Q20@Li`098@PLiacW8@PU:AcW6<HDYAcW008U:@038@PLiacW008Q20037>LDYAS6008Li`036<HD
YAS6008Li`078@PU:B487>LHaQcW8@P011cW00@Q21cW8@PLi`8HaP055:DHaR488@PLi`028@P00aS6
7>LLi`029BT012486<HHaQS60QcW00<DYA2448@00QS60QBU00@HaQBU6<HHaP8DY@8HaP037>LDYABU
008@Q0046<HDYABU5:D36<H011BU6<HDYABU1AS60QcW0RU:00<LiaS65:D00QS600DDYA2436<@Q1BU
00<HaP<DY@<@Q0@DY@8@Q0036<HDYABU00DDY@8HaP8DY@066<HLiacW6<HDYAS611BU0a2411BU00<<
Ha246<H00QcW0QS600dLib486<HDYAcW8@PLiaS648@DYA245:D@Q0045:D548@02QBU48@@Q1BU6<HD
YA2436<@Q1S611BU0Q2400<<HaBU48@0112400DDYA2448@@Q1BU00<HaP8DY@076<HDYABU48@DYA24
6<H011BU00@@Q1BU48@@Q0<DY@8@Q0<DY@0348@DYAcW008DY@0548@DYABU48@DY@0548@336<00a24
5:D@Q00948@936<648@35:D348@35:D248@35:D:48@436<448@01@aS48@@Q1245:D0112410aS1124
0PaS00@@Q0aS48@<H`8@Q0L<H`<@Q08<H`88@P@<H`88@P<<H`04248<H`Q2248236<01Q2436<<H`Q2
36<@Q08<H`<8@P<<H`05248<H`aS36<@Q00236<4248236<3248010aS248<H`Q20PaS00D@Q0aS248<
Ha24004<H`0000<000@Q12401@@Q00`8@P@Q1248@S6<HaQ24248:DXaS2e[:DX39BT00be[:DXU:@02
:DX3;F/02BU:<H`e[Cg_AS4mkc6<:DXQ2009:DX012e[<H`e[CF]1C6<00@]JbU::DXU:@8YBP07;F/a
S36<;F/aS2e[:DX00Re[00DYBRe[;F/]Jc6<00@]J`03:DXU:BU:008YBP<U:@8Q208U:@@YBP<]J`03
:DXU:BU:008]J`04:DXU:BU::DX29BT012489BTQ22DY21cW00<HaQcW8@P00bDY1b4800@U:AcW7>LQ
208U:@8Q20057>LQ22488@PU:@047>L01B487>LLib489BT00RU:00<U:B489BT00bU:0R480RDY00<Y
BRDY8@P00R480QcW0R4800DLiaS66<HLibDY00<YBP058@PLiacW7>LHaP037>L26<H38@P27>L28@P0
1bDY8@PQ21cW8@PLiaS6008Li`8Q20046<HQ22487>L25:D27>L01aS67>LYBRU:8@PLib4800<U:@8L
i`8Q20049BTQ21cW7>L46<H37>L25:D011S67>LU:AcW0QS600<LiaS66<H00QcW0bDY0b4800<LiaS6
6<H00QcW00XHaQcW7>LU:AcW6<HQ22DY8@PLi`8HaP055:D@Q1245:DLi`026<H01a245:DHaQS68@PL
iaBU00@HaP035:D@Q1BU00<Li`036<HDYABU008HaP@DY@0548@DYABU6<HDY@036<H01S6<>LhaS248
36<@Q08DY@8HaP065:DHaQBU5:D@Q1BU0QS60QBU0QS600<DY@aS36<00a240QBU0QS600<LiaS66<H0
1AS600<DYAS65:D00QS600@DYA2448@@Q0DDY@0348@DYA2400<DY@046<HDYAcW7>L26<H011cW8@PQ
21cW0aBU0Q2400PDYA245:DDYA246<HDYA240aBU0a2400@DYA2448@@Q0<DY@<@Q00536<@Q1BU48@D
Y@0648@25:D26<H45:D248@00aBU48@DY@045:D011245:DDYABU0a2400HHaQBU5:D@Q1BU6<H37>L2
48@45:D248@011BU36<<H`aS0Q240PaS00<@Q1BU5:D00Q2400HDYA2436<<Ha245:D548@00`aS48@<
H`0236<548@00aBU48@DY@035:D00aS67>LDY@0348@25:D011245:D@Q1240aBU00<@Q0aS36<01124
00D<Ha2448@@Q0Q2008<H`035:D@Q0aS008@Q0035:D@Q12400D@Q0035:D@Q0aS008<H`8@Q0035:D@
Q0aS008<H`<@Q00336<8@PaS00D<H`0548@<H`aS36<8@P0336<3248436<00`Q236<@Q00236<020Q2
36<@Q12436<8@PaS248336<00`Q236<<H`0636<2248236<01Q242488@PQ236<8@P@<H`0348@<H`aS
0048@P000P@Q00@000@Q124000848@08248000@Q248aS6]JBU8YBP8e[@8YBP079BT]JbDY8@PU:BU:
;F/00RU:0Re[00@YBRe[;F/icP96<@03?Nle[BU:008YBP059BTYBRU::DXU:@02:DX8<H`00be[:DX]
J`07:DX012e[<H`]Jc6<0RU:12e[00DYBRe[;F/]JbU:008U:@8YBP04;F/YBRDY9BT38@P00bDY:DXU
:@029BT01Re[<H`aS2e[9BTYBP<]J`049BTYBRDY8@P29BT01bU:9BTLiacW9BTQ21cW00<HaP8Li`03
8@PLib48008Q208U:@8Q20069BTQ22487>LQ22DY124800@Lib488@PQ208U:@037>LHaQcW00<Q208L
i`059BTYBRe[:DXU:@068@P49BT012489BTU:AcW0QS60R480QBU00<HaRDY;F/00bDY0R480QcW00<H
aQcW7>L00QcW00HHaQcW8@PU:B487>L28@P02bDY7>LQ22DY7>LHaQBU6<HQ21cW8@P011cW00@HaQBU
5:DDY@8Li`<Q20059BTQ22DY9BTQ20027>L38@P27>L011S67>LQ21cW0QS600<LiaS65:D00QS611cW
0QBU0QS600<U:B488@P012DY00DQ21cW7>LHaQcW008HaP8Li`8Q20087>LQ22DY9BTQ21S65:D@Q0<D
Y@0;6<HDYABU5:D@Q1S67>LHaQcW6<HDY@036<H35:D38@P01AcW5:DDYA245:D0112400<DYAS66<H0
0QBU0Q2400DYBS6<=JdaS1S6008DY@066<HLiaBU5:D@Q1S611BU0QS600@LiaS66<HDY@L@Q0045:DH
aQBU6<H25:D36<H011BU6<HDYAS60QBU112411BU0a240QBU00D@Q1BU5:DDYAS600<Li`036<HDYAS6
00<HaP8DY@<@Q0045:D@Q1BU48@35:D00a245:DDY@025:D548@00aBU48@DY@0248@00aBU48@@Q003
48@25:D248@01aBU48@DYABU48@DYAS600HDY@0548@DYA2448@DY@0448@35:D01A245:DHaQBU48@0
0QBU0QS611BU00<HaQBU5:D011240`aS1A240aBU0Q2400L<Ha2448@@Q1BU48@DY@0248@010aS48@<
Ha240PaS11240QBU00L@Q1BU5:DDYA245:DHaP025:D248@011BU48@DYA2411BU00<@Q0aS36<00a24
00<DYA2448@00PaS00@@Q0aS36<<H`X@Q0<<H`<@Q0045:D@Q12448@436<0112436<<Ha241@aS00H@
Q0aS48@@Q0Q236<2248336<2248436<010Q248@<Ha240`aS00D8@PaS36<<H`Q200@<H`88@P0436<8
@PQ2248436<3248010aS248<H`Q21@aS00<@Q0aS36<00@Q200001@0012448@@Q00000`@Q00T8@P@Q
1248@SF]MkeJeRe[>Lh00SF]0S6<0bU:0RDY12U:0R480RU:0SF]00<aS3F]<H`00be[0S6<00@YBRDY
9BT]J`<aS003;F/YBRe[00<U:@<YBP<U:@<YBP05;F/aS2e[<H`]J`03<H`01BU:;F/aS36<:DX00RDY
0RU:00<U:B489BT012DY0QcW00@Q22DY9BTQ208U:@03;F/aS36<00H]J`03:DXU:BDY00LQ20@Li`<H
aP058@PLib487>LQ20049BT38@P00acW8@PQ20029BT00b489BTQ20037>L38@P00aS67>LLi`038@P2
7>L29BT2:DX01BDY:DX]JbU:9BT00QcW00DQ21cW8@PQ22DY008Q20047>LHaR487>L26<H25:D01b48
7>LU:Be[<H`]JbU:00<Q20<HaP8Li`@Q20077>LQ22DY8@PLiaS68@P00QcW0QS600<Q21cW7>L00QcW
00LHaQBU5:DHaQBU48@DY@037>L01ABU6<HQ21cW8@P00acW0b4811S600<Q21cW6<H01QBU0aS60QcW
00HHaQcW9BTYBRe[:DX29BT012e[:DXYBRDY0QcW00@HaQBU7>LLi`8Q208U:@0;8@PU:BDY8@PU:AS6
5:D@Q1BU6<H@Q0025:D011cW6<HDYAS60QcW00<HaQBU6<H00aBU00T@Q1BU6<HLiaS65:DHaQcW6<H0
0QBU00@@Q1BU5:DDY@<@Q0075:D@Q1249BTaS3g_<H`00aBU00@@Q1S65:DDY@8@Q0035:DHaQcW008D
Y@037>LHaQS600DDY@0748@DYABU5:D@Q0aS48@01ABU00DLiaS65:DDYAS600TDY@0348@DYA2400DD
Y@8HaP8Li`8HaP8DY@066<HLib487>LDYA240QBU00<HaQBU48@00Q2400HDYA2448@@Q1BU48@25:D0
0aS65:D@Q00348@010aS48@DYAS60a2400<DYA2448@00QBU00D@Q0aS36<@Q1S600HDY@0448@DYABU
6<H25:D02A246<HDYABU48@DYAS648@DY@0248@35:D248@00aBU6<HHaP055:D01a245:DDYAS65:D@
Q0aS008@Q0<<H`T@Q0@DY@H@Q0<<H`<@Q00436<DYA246<H25:D011245:DDYABU0QS600<DYA2448@0
0QS600@DYA2448@DY@@@Q00336<@Q12400<@Q0<<H`<@Q00536<@Q1245:D<H`0248@35:D00a2436<<
H`0748@00`aS48@@Q00348@00`aS248<H`0336<00`Q236<<H`0336<02`Q236<<H`aS248<H`Q236<8
@PaS248010aS0PQ200<<Ha2436<00PQ20PaS00D8@PaS248<H`Q200H<H`0448@<H`aS248236<00`Q2
36<<H`0336<4248236<1248000<48@0500048@@Q0008@P03124020Q2<HakgV<H?Nm243F]>Lh2<H`0
0be[:DXYBP02:DX39BT01BU:9BTU:BDY:DX00S6<0cF]00@]Jc6<;F/]J`8aS005;F/YBRU::DX]J`03
<H`00bU:9BTU:@03:DX00b489BTYBP02:DX29BT2:DX00be[<H`e[@02<H`2;F/0136<=JdaS36<12U:
00@U:BU::DXYBP<U:@048@PLib489BT2:DX00b489BTYBP02;F/00c6<;F/YBP02;F/2:DX012DY:DXY
BRDY0R4800XLib489BTQ21cW8@PHaQBU6<HDY@8Li`048@PLiacW7>L29BT28@P29BT38@P00bDY8@PU
:@029BT28@P27>L00b487>LLi`027>L48@P27>L02B489BTU:B489BTYBRe[:DXU:@068@P57>L00b48
7>LDY@025:D37>L022DY;F/e[CF]<H`YBQcW8@P26<H011BU6<HLiacW0b4800@U:B488@PQ20<Li`04
6<HLiacW6<H47>L36<H27>L35:D011S65:DHaQS60acW0b480QcW00<HaQcW7>L00QcW00<HaQcW7>L0
0QBU00<@Q1BU6<H00QS600LDYAS67>LLiaS65:DLi`02:DX012DY:DXYBRe[0bU:00<Q22DY6<H00QS6
00<DYAcW8@P00b4800DYBRe[9BTLia24008HaP@DY@0748@DYAS66<HLiaS65:D00QS600@DYAS67>LH
aP8@Q0045:DLiacW6<H25:D01acW6<HDYAS648@DYA24008DY@@@Q08HaP05:DXe[BU:8@P<H`025:D3
48@36<H25:D00aS65:DHaP026<H25:D00a245:DDY@035:D336<35:D011245:DHaQS61ABU00<HaQBU
5:D01ABU1A240QBU1AS60aBU00HHaR487>LHaQBU48@25:D00a245:DDY@025:D348@25:D248@25:D2
6<H248@236<011245:DDYABU0Q241aBU00H@Q1BU48@@Q1BU48@85:D00a245:DDY@045:D00a245:DD
Y@0248@011BU6<HHaQBU0Q2400<HaQBU5:D01QBU112400<DYA2448@010aS0Q240QBU0Q2400<<Ha24
48@00Q240QBU0Q2410aS00<@Q0aS48@00a2400<<Ha2448@0112411BU00@@Q1BU6<HHaP8DY@<@Q006
5:D@Q12436<@Q0aS0a2410aS0Q240`aS1A2400<DYA2448@01A2400<DYA2448@00aBU00@@Q0aS48@@
Q08<H`8@Q00536<8@PQ2248<H`0248@01@aS248<H`aS48@00PaS0PQ220aS0PQ200@<Ha2436<<H`88
@PH<H`88@P0336<8@PaS00<<H`88@P0436<8@PQ2248436<01@Q236<8@PaS48@00PaS00000`@Q0004
8@0512402PQ2124000Q2;F]_Ne[F=Je243W>0c6<00@e[C6<:DX]J`8aS005;F/U:BDY:DXU:@05:DX0
1Re[<H`aS2e[:DX]J`<e[@03>LhaS36<008YBP04;F/aS36<:DX28@P29BT00bU:8@PU:@069BT012U:
;F/]Jbe[0bU:00PaS3W>=Jd]JbDY8@PYBRDY0bU:0b4800HU:BU:9BTQ22DY:DX2;F/29BT2:DX2;F/0
12U:9BTU:BDY0b4800DLib489BTU:BU:00<U:@048@PLiacW8@P27>L26<H38@P01RDY8@PQ22DY8@PU
:@8Q20037>LQ224800<Q208U:@048@PLiaS67>L68@P26<H011cW8@PU:B480bDY0b4800<Lib487>L0
0b4811cW0QS600@LiaS66<HDY@8HaP045:DHaQS68@P2;F/2=Jd2:DX00acW8@PLi`026<H01QcW9BTQ
22487>LQ20<Li`046<HLib487>L36<H27>L26<H00a246<HHaP026<H25:D00acW6<HHaP027>L00aBU
6<HHaP028@P01acW5:DDYABU6<HLib48008HaP@DY@@HaP045:DHaQS66<H27>L011S68@PU:BU:0bDY
0RU:00PU:B488@PLiaS65:DHaQcW0R480QcW0b4800<HaQcW7>L00R4800DHaQ245:D@Q1BU008HaP04
5:DHaQBU5:D26<H27>L00aS65:DHaP026<H25:D36<H45:D248@00aBU6<HHaP055:D01B48:DXYBRDY
6<H00aBU0a240QBU00@HaQcW5:DDY@8HaP8Li`035:D@Q1BU00<HaP@@Q0@DY@066<HDYAS65:D@Q0aS
0Q240aS600@DYAS66<HHaP8DY@<@Q0@DY@046<HLiacW6<H35:D00acW8@PLi`026<H448@00aBU48@D
Y@025:D00a2436<@Q0025:D01Q245:DDYABU48@<H`8@Q08<H`<@Q0035:D@Q12400<@Q0035:D@Q124
008DY@8HaP0648@DYA245:DHaQBU0a240QS600<DYA2448@00aBU00<HaQBU5:D00QBU0a240aBU00<@
Q1BU5:D00QS600<DYA2448@00Q2400<<Ha2448@00Q2400H<Ha245:D@Q1BU48@25:D01a2436<<H`aS
48@DYAS600X@Q08DY@<@Q08DY@@@Q08DY@H@Q0035:D@Q12400H@Q08<H`0348@<H`aS008<H`0348@<
H`aS008DY@0448@<H`aS36<35:D348@25:D348@010aS48@@Q1240QBU0Q2400@<H`Q248@@Q0@<H`04
48@<H`aS36<248@00`aS248<H`0536<010Q236<<H`Q20`aS0PQ200@<Ha2436<8@P8<H`88@P@<H`@8
@P/<H`04248<H`aS48@236<3248236<1248000848@0400048@@Q000512402@Q2<Ha[FTic=Je6<D8@
?Nle[@02<H`3;F/01RU:;F/aS2e[:DXU:@8YBP8U:@088@PYBRe[<H`e[C6<;F/YBP8]J`<icP03=Jd]
JbU:008]J`0<=JdYBRDY7>LQ22DY7>LU:BU:;F/U:B480RDY0RU:0RDY0RU:00<aS2e[<H`00Re[00Da
S2e[;F/U:B48008U:@8YBP039BTQ22DY00@U:@03:DX]Jbe[00@YBP03;F/YBRU:00<YBP8U:@@Q2008
9BTQ22489BTYBRDY8@PHaP8Li`8HaP047>LQ21cW8@P39BT00b489BTQ20029BT011cW6<HLiacW0RDY
0R4800DU:B488@PQ21cW008Q208Li`036<HLib48008Q20077>LQ21cW8@PU:BU:8@P00acW0R4811cW
00<Q21cW6<H00QcW0QS60QBU1AS600LLib48>LhicSF]:DXLi`029BT37>L00b489BTU:@027>L36<H2
7>L00aS67>LLi`057>L35:D00aS67>LHaP026<H01ABU6<HHaQS65:D00QS60QcW00@HaQcW6<HLi`<H
aP8Li`8HaP@DY@076<HLiacW7>LHaQBU6<H00acW00<HaQcW:DX00bDY0RU:0bDY00@LiaS66<HHaP<L
i`<Q20039BTLiacW008HaP057>LQ21cW5:D@Q0025:D27>L011S65:D@Q1BU0QS60QcW0QS60QBU0QS6
0QBU0QS61ABU0Q2400TDYAS66<HDYAS65:D@Q1S67>L00RU:0QcW00DDY@aS48@@Q1BU00<@Q0046<HL
iaBU5:D27>L75:D00aS65:D@Q00248@35:D26<H00aBU48@@Q00448@25:D00aS65:DHaP025:D00a24
5:DDY@0248@25:D01aS65:DHaQcW6<HLiaBU00@HaP047>LHaQBU48@45:D248@00aBU48@DY@0348@4
5:D348@236<00a2436<@Q0035:D348@25:D448@011BU6<HHaQ240aBU00D@Q0aS48@DYAS6008DY@03
48@DYA2400<DY@8HaP@@Q0035:D<HaBU00<DY@0348@DYAS6008HaP8@Q00336<DYA2400@@Q0<<H`@@
Q0065:D@Q0aS36<@Q1BU112400@DYA2448@DY@<<H`8@Q00336<@Q1BU008DY@@@Q0035:D@Q12400<D
Y@0648@DYA245:D@Q1BU1a2400<<Ha2448@0112400<DYA2448@00`aS00H@Q1BU5:D@Q1BU48@35:D2
48@336<00a245:D@Q00336<00a245:D<H`0336<01Q245:D<H`aS248<H`8@Q0<<H`<@Q00636<8@PaS
36<8@PaS0PQ210aS00@8@PaS36<@Q08<H`88@P@<H`@8@P0436<@Q0aS36<424800`aS248<H`0336<0
10Q236<8@PQ20PaS0A240@aS00001@0012448@@Q00000`@Q00P8@P001248@RU:HaQ:DSW>0Tic00A2
42e[<H`aS0<]J`8e[@04<H`]Jc6<<H`2;F/3:DX00be[<H`aS002;F/4:DX00be[<H`aS003<H`2=Jd0
136<:DXU:B4812DY0R480RDY00DYBRDY8@PQ22DY008YBP03;F/YBRU:008YBP03;F/YBRDY00<Q2004
9BTYBRU::DX59BT2:DX01S6<=JdaS36<:DXU:@8YBP<U:@037>LQ2248008Q200:7>LQ22DY:DXQ21cW
8@PU:BU:9BT48@P00bDY8@PQ20028@P00acW9BTU:@028@P012DY7>LQ22480acW0b4800@LiaS67>LL
i`8Q20037>LQ21cW00@Li`8U:@@Q208U:@058@PLiaS67>LQ20037>L00bDY8@PQ20027>L00aS65:DH
aP056<H02AcW6<HLiacW8@P]Jc6<=JdaS002;F/01RDY8@PQ22DY:DXU:@@Li`8HaP035:DLib48008L
i`035:DHaQcW00@HaP8DY@036<HLiaS6008HaP8Li`<HaP8Li`068@PLiaBU5:D@Q1S611cW00<HaQcW
6<H00aBU11cW00<DYAS66<H00QcW00<DYAS68@P00RDY00<Q21cW7>L00RDY0QcW00<HaQBU7>L00R48
00<U:B488@P011cW00<HaQcW7>L00QcW00@DYAS66<H@Q08HaP8Li`DHaP8@Q0045:DHaQS67>L46<H0
11cW6<HHaQBU0QcW00HHaQBU5:DHaQBU6<H27>L021S65:DHaQS6<H`e[BU:9BT55:D01a2436<DYABU
6<HLiaS6008DY@8HaP8Li`<HaP@DY@<HaP035:D@Q1BU008DY@036<HDYA2400<<H`8DY@046<HDY@aS
36<248@26<H55:D00acW6<HHaP066<H37>L011S65:DHaQBU0a2400DDYA2436<<Ha2400@DY@0348@D
YA2400@@Q00436<@Q1245:D348@01ABU48@@Q0aS48@00QBU00P@Q1BU5:DDYA245:DHaQBU0Q2400<D
YAS65:D00aBU0QS61ABU00@@Q1BU5:DDY@8@Q0<DY@0348@DYABU008DY@8@Q0035:D@Q1BU00H@Q007
36<@Q1245:D@Q0aS48@00QBU0Q2400PDYA2436<<Ha246<HDYA240PaS0Q2400HDYA2448@HaQBU48@2
36<00aS65:DDY@025:D348@35:D248@02@aS5:DDYA245:D<Ha2436<8@P0236<01a245:DDYA2436<@
Q1BU008@Q00336<@Q1BU008@Q00336<DYA24008@Q08<H`0348@<Ha24008@Q08DY@0348@<H`aS00D<
H`0348@<H`aS00L<H`0348@<H`aS0088@P0336<8@PQ20088@P0336<@Q0aS00@<H`<@Q0<<H`08248<
H`aS36<8@PaS24848@<@Q0065:D<H`Q236<8@PaS0PQ22PaS0PQ2000312400`0012448@05124030Q2
<HaNmdHa=Je244icDYA243W>;F/YBP8aS005;F/aS36<=JdaS002;F/2:DX4;F/01C6<=JdaS2e[:DX0
0RDY00<YBRe[;F/00Re[0S6<00@icSF];F/YBP<U:@<Q20<U:@048@PU:B489BT28@P2:DX00be[:DXY
BP03:DX68@P01RU:;F/]Jbe[:DXU:@<Q2006;F/e[CW><H`YBRDY12U:0bDY0QcW00<Q21cW8@P01R48
0RDY0b481BDY0R480QcW00LQ22DY7>LQ22DY8@PLi`026<H57>L36<H00acW8@PQ20037>L00aS68@PL
i`038@P27>L01B48:DXU:B486<H011cW12480acW00@HaQBU5:DHaP<Li`035:DHaQS6008Li`089BTY
BS6<<H`e[C6<;F/YBP8U:@03:DXQ2248008Li`038@PLiaS6008DY@036<HLiaS600DHaP045:D@Q1BU
5:D26<H27>L36<H27>L00aS67>LLi`037>L25:D01AS67>LLiacW6<H00QcW1AS600DDYAS67>LLiaS6
008DY@097>LHaQcW8@PU:B486<HLib48008U:@8Q20047>LHaQcW7>L68@P27>L011S67>LQ21cW0aS6
11BU00LHaQcW6<HHaQBU6<HLi`026<H01A2436<DYABU7>L00QS60acW1QS611BU0QcW0QS60QBU00DU
:Be[<H`aS1cW008HaP0448@DYA245:D248@00aBU6<HDY@035:D76<H25:D011S65:DHaQS60aBU00X@
Q1BU5:DHaQ2436<@Q1BU6<HDY@D@Q0035:D@Q12400HDY@HHaP0448@HaQcW7>L26<H021BU6<HHaQBU
48@DY@aS248236<00aBU48@DY@025:D00aS65:D@Q00336<248@010aS48@DYABU0Q240QBU00@@Q1BU
5:DDY@8@Q0HDY@0748@<Ha245:DHaQBU48@00QBU0Q2411BU00D@Q0aS48@@Q1S600<DY@8@Q0075:DL
iacW5:D<Ha246<H00QBU00<@Q1BU48@00PaS0a2400<<Ha2448@01ABU1A2400@<Ha2448@DY@<@Q0@<
H`035:D@Q12400<DY@8@Q0@DY@0348@DYA2400<@Q00536<DYA2448@DY@0248@236<248@336<348@0
11BU48@@Q0aS1A2400@DYA2448@@Q08<H`8@Q0<<H`D@Q0@<H`0548@<H`aS36<@Q002248236<00a24
36<<H`0636<3248236<224800`aS48@<H`0336<00a2436<<H`02248010aS48@@Q0aS0PQ20`aS0PQ2
0PaS00@@Q0aS36<8@PH<H`06248<H`Q236<8@PaS0@Q200000`001240000212403`0012448@Q20004
8@Q2;F]S64Ha<Ha:DTicAS4e[@02<H`02BU:;F/aS3W>=JdaS2U:<H`]J`02:DX01Re[<H`e[CF]>Lhe
[@8aS00;:DX]JbU:9BTYBRDY;F/YBRe[<H`e[@02<H`013F]>LhaS2U:0bDY0b4800<U:B488@P012DY
0R480RU:0Re[124800HU:B489BTYBRe[=Jd2<H`00cF]:DXYBP029BT012U:;F/aS2e[0RU:00<]Jc6<
<H`00RU:00@Q22DY8@PLi`8HaP037>LHaQcW008Li`<Q20039BTQ2248008U:@@YBP03;F/YBRDY00HQ
20047>LHaQBU5:D37>L011S67>LLiacW0R480QcW00<HaQcW8@P00R480bDY0R480RDY00@Q21cW7>LH
aP8Q20<HaP038@PLiaS6008Li`046<HDYAS66<H37>L01aS67>LHaR487>LQ22DY008YBP099BTYBS6<
?Nm6<CW><H`U:B48008YBP03;F/U:B48008HaP<Li`036<HDYAS6008HaP<DY@0348@DYAS6008Li`<H
aP8Li`036<HLiaS6008Li`8DY@8HaPDLi`036<HLiaS6008HaP8Li`PHaP<Li`048@PLiaS67>L39BT0
0b487>LHaP037>L022486<HLib489BTQ21S65:D27>L36<H25:D46<H35:D01AS67>LLiacW6<H00aBU
00<HaQcW6<H00QcW00HHaQBU48@HaQcW6<H38@P00acW6<HDY@047>L00aS68@PLi`03;F/01C6<9BTU
:AcW6<H011BU0a2400<DYA245:D00QS600@DYA245:DLi`@DY@8HaP055:DHaQBU6<H@Q0025:D748@0
0aBU48@DY@0236<00`Q236<DY@025:D248@25:D00aS65:DHaP025:D26<H25:D00acW8@PQ20026<H3
5:D348@00`aS48@@Q0025:D00a245:DDY@045:D348@00`aS5:DDY@0248@35:D248@00`aS48@HaP02
5:D348@01ABU48@@Q0aS5:D00QS600@DYA2448@@Q08DY@8@Q0035:D@Q1BU00DDY@0448@DYAS66<H3
48@00aS648@@Q00248@01aBU48@HaQS65:DHaQ2400<<H`035:D@Q12400L@Q0035:D@Q0aS008@Q0<D
Y@<@Q08DY@8<H`0548@DYA2436<@Q0035:D348@35:D248@25:D348@25:D248@336<00`Q236<@Q002
48@336<348@011BU48@@Q1240QBU00@@Q0aS48@DY@@<H`0348@<Ha2400<@Q00336<@Q0aS00@<H`03
248<H`aS00<<H`8@Q0<<H`03248@Q0aS00D8@P8<H`<@Q0D<H`03248<H`aS00D<H`03248<H`aS008<
H`8@Q0055:D@Q0aS36<8@P0448@00`aS248<H`0436<248@136<000@48@0400048@@Q2483124030Q2
:DYNmdYB=JdmkdHaCW=243W>;F/YBP8]J`8aS003=JdaS36<00@YBP06=JdaS36<=JdicSF]0be[0bU:
00L]JbU:9BTYBS6<=JdaS002;F/00c6<>Lhe[@02;F/29BT48@P012DY:DXYBRDY0R4800<U:BU::DX0
0Re[00HYBRDY7>LHaQcW9BT3:DX2;F/2=Jd012e[:DXU:BDY12U:0be[00HYBRe[<H`e[Be[9BT27>L0
0b487>LLi`047>L00b489BTQ20027>L01248:DXYBRU:0bDY0RU:0bDY00<Q21cW7>L00R480acW0QS6
11cW00<U:B488@P011cW0b4800<U:BU::DX00R4800@U:B488@PQ208U:@047>LHaQS67>L28@P27>L0
11S65:DHaQS60QcW0QS60QcW00PQ21cW7>LQ21cW8@PU:B480RDY00<YBSF]?Nl00Sg_00<aS2e[:DX0
0Re[00DYBRDY7>LLiaS6008Li`HHaP8DY@0448@DYABU5:D36<H011BU6<HLib480QcW00@HaQcW7>LH
aP8DY@8HaP8Q208Li`036<HDYAS600<HaP065:DHaQS66<HLiaBU0QS600DDYAS68@PU:B4800<Li`8U
:@8Li`8HaP067>LQ22488@PLib480QcW0QS600<DYAcW7>L01aS60QBU0aS600DDYAS67>LHaQBU00@H
aP<Li`<HaP095:DHaQS67>LQ22DY:DXLiaS6008DY@046<HLiacW7>L28@P01QcW:DXaS3F]<H`Li`8H
aPDDY@<@Q0035:DHaQS6008DY@<HaP035:D@Q12400<HaP0348@DYAS6008Li`<@Q08DY@036<H@Q124
00H@Q0<<H`<@Q0<DY@036<H@Q1BU008DY@046<H@Q1246<H28@P00aS65:DHaP035:D01QS648@@Q0aS
48@HaP<@Q08DY@036<HDYABU00<@Q08DY@0348@DYABU00@DY@0548@DYABU48@DY@0548@01ABU6<HD
Y@aS48@00QS60Q2400<DYAS66<H00QBU0Q241ABU00<HaQBU5:D00Q240aBU0Q240aBU0a2400DDYAS6
5:D@Q0aS00<@Q0035:D@Q124008<H`<@Q08DY@0448@<H`aS36<25:D348@00aBU36<@Q00348@010aS
48@@Q0aS0Q240QBU00D@Q1BU48@DYAS600@@Q0066<H@Q1245:DHaQBU1A240PaS00<@Q0aS48@00Q24
0PaS0a2400H8@Q2448@DYA2436<348@336<648@011BU48@@Q12420aS0Q2400@<H`Q22488@P@<H`03
248<H`aS00<<H`04248<H`Q236<348@236<010Q248@<H`Q240aS00<8@PaS36<00a2400<<H`Q236<0
10aS00000`0012448@0312402`0012448@@Q0008@RDYDY@mkbe[=Jd00SW>0S6<00<]JbU:;F/00Re[
0cF]00<icSF]=Jd00cF]136<0bU:0Re[00DYBRe[;F/aS2e[00<YBP8U:@HYBP<]J`04:DXU:BU::DX3
9BT2:DX01BDY<H`e[CF];F/00R4800@U:B488@PQ20<YBPD]J`05<H`]JbU::DX]J`02<H`2:DX00be[
<H`]J`02;F/012U:9BTQ21cW124811S60acW00HQ22DY9BTU:AcW8@P59BT00b489BTQ20029BT28@P0
0bDY8@PHaP036<H38@P27>L36<H01B487>LLiacW8@P012DY0R4800HLib488@PYBRDY8@P27>L01248
7>LLiaBU0QS63AcW0R480RDY00/Lic6<>Li243F]<H`icTYBAS4icRe[008YBP8U:@058@PLib488@PL
i`036<H25:D248@01aS65:DHaQS65:DHaQBU00THaP065:DLiacW9BTQ21S60acW00/HaQBU5:DHaR48
7>LHaQBU6<HLiaBU008HaP8Q20<Li`DQ20039BTLiacW008Li`HQ208U:@058@PHaQBU48@DY@026<H3
5:D00a246<HHaP027>L36<H27>L28@P56<H37>L26<H01B487>LLiaS65:D00QS600<LiaS66<H00QBU
0QcW0R4800@HaQBU7>LU:@8e[@07;F/LiaS65:DLiaS65:D00PaS00@@Q1S67>LDY@8@Q0045:D@Q1BU
5:D248@25:D26<H01QBU6<HLiacW6<HDY@<@Q0045:D@Q12448@25:D448@00`aS48@<H`0248@45:D3
48@25:D01AS65:DHaQBU6<H00b4800DHaQBU5:DHaQBU008@Q0045:D@Q1245:D26<H45:D348@00aBU
48@@Q00248@35:D011245:DHaQBU0PaS00L@Q1BU5:D@Q1BU48@DY@0248@011S65:DDYABU0Q240QBU
00<HaQBU48@00Q2400<DYAS65:D011BU0QcW00@DYA2448@@Q0DDY@0348@<Ha2400<HaP<@Q00636<@
Q1245:D@Q0aS112400<<Ha2448@00Q240aBU00<@Q1BU5:D00Q240PaS0a240QBU00<@Q1BU5:D01ABU
112400@DYA2448@@Q0@DY@<@Q0<DY@D@Q08<H`0348@<Ha24008@Q00536<@Q0aS36<@Q00436<348@8
36<248@424800`aS48@@Q00248@236<4248636<01PQ236<<H`Q236<8@P8<H`88@P0836<@Q0aS36<8
@PaS48@<H`88@P0436<@Q12436<248@01@aS48@<H`aS24800PaS00D8@Q2448@<Ha24008<H`<@Q04<
H`000`@Q00<000@Q00001@@Q00/8@RDYDY@mkbU:<H`icSF]>Lhe[C6<00<YBP03;F/e[C6<008icP03
=JdicSF]00De[@03<H`YBRU:00@]J`04:DXaS36<;F/2:DX49BT3:DX29BT5:DX2<H`00be[:DXU:@03
:DX01Re[<H`aS3F]:DXU:@8Q20@U:@8YBP039BT]Jc6<008aS004:DXU:BDY:DX3<H`012e[:DX]Jbe[
0S6<0RDY1B480QcW0QS600<LiaS68@P01B4800<U:AcW7>L0124800PU:B489BTU:B489BTLib480acW
0aS600<Lib488@P00acW00<HaQcW7>L00R4800HLib488@PU:B489BT28@P37>L38@P27>L28@P01QcW
5:DHaQcW8@PLi`8HaP<Li`<HaP8Q20037>LQ2248008U:@07:DX]Jc6<;F/aS3F]>Lh00THa00A243W>
:DX]J`<U:@8Li`8Q20036<HDYABU00<HaP8@Q0035:DHaQcW008DY@DHaP8Li`056<HDYAS66<HDY@02
7>L01B487>LDYABU6<H00QBU0QS600@LiaS66<HHaP@Li`8HaP8Li`HQ20<Li`036<HLiaS600DQ2006
7>LU:B487>LHaQBU0QS60QBU00X@Q1BU6<HHaQcW6<HDYAS67>LHaP<Q20059BTQ21cW6<HDY@027>L0
1AS67>LHaQcW6<H00QcW00DHaQcW6<HHaQBU008HaP055:D@Q1BU6<HQ20027>L021S67>LLibU:<H`]
JbU:7>L45:D00a245:DDY@025:D01aS65:DDYABU48@DYA2400LDY@047>LHaQcW7>L26<H00aBU48@@
Q00248@00aBU48@@Q0025:D248@236<448@36<H00aBU36<<H`0248@55:D37>L011S65:DHaQS60QBU
00@@Q1BU5:D@Q0HDY@@@Q0<DY@0448@DYA245:D248@00aBU6<HDY@0248@25:D0112436<<HaBU0Q24
00DHaQBU6<HDYA2400XDY@0448@DYABU5:D27>L26<H25:D0112436<<HaBU0QS600HDY@aS48@DYA24
6<H45:D248@00`aS48@@Q00848@010aS48@DYAS60a240aBU0Q2400<<Ha245:D00aBU0Q2400@HaQBU
5:D@Q08DY@T@Q0035:D@Q124008@Q0035:D@Q124008<H`0448@DYA2448@236<25:D0112436<<Ha24
0QBU0`aS0Q2410aS0a240`aS0Q240PaS0PQ22`aS00<@Q0aS248010aS00D@Q0aS36<<H`Q200@<H`03
48@<H`aS00@<H`04248<H`aS36<224800`aS48@<H`0236<348@636<0112436<<H`Q20PaS0A240@aS
00000`@Q00048@0812401@Q2:DYBU3W>:DX00cF]00L]Jc6<<H`]JbU:9BTYBP02<H`00cW>=Jde[@04
=Jd3>Lh01SF];F/YBRDY:DXaS08]J`04:DXU:BU::DX39BT3:DX28@P00bDY:DXYBP029BT012U:;F/Y
BRU:0Re[00<e[CW>>Lh0136<00<YBRe[;F/00Re[00<YBRDY9BT00bU:0RDY1BU:00<aS2e[;F/00RU:
00<U:BU:;F/00Re[00<YBR488@P00b480QcW00<HaQcW6<H00acW00@HaQcW7>LQ208U:@068@PU:B48
7>LQ21S60QcW00@Q22DY9BTQ20<Li`8Q208HaP047>LQ22489BT38@P02acW6<HHaQcW8@PU:B487>LQ
21cW9BT00R480aS60QcW0QS600<Lib488@P00R4811cW00<Q21cW5:D00QS61QcW00@Q21cW7>LQ20<U
:@0;8@PU:BDY8@PaS3g_AS5F]DYB<H`U:@027>L012487>LHaQBU1AS60QBU00HHaQcW7>LHaQBU6<H3
5:D01aS65:DHaQS65:DHaQBU00<HaP037>LQ21cW008HaP<Li`036<HLiacW00DHaPDLi`<Q20037>LH
aQcW00<U:@<Li`036<HLiacW008U:@058@PLib487>LQ20036<H011BU7>LQ21cW0QS600HDYAcW7>LH
aQcW6<H27>L01248:DXYBRU:0R480QS60QBU00DHaQBU6<HLib48008Li`8HaP037>LHaQS600@DY@8@
Q0046<HQ22488@P27>L01bDY<H`aS2U:7>L@Q1BU00<HaP035:D@Q12400<DY@046<H@Q1BU5:D248@3
5:D248@36<H00aBU6<HDY@025:D248@011BU48@DYA240QBU00<@Q0aS36<01A240QBU00T@Q1BU6<HD
Y@aS48@DYAS67>L00QBU00D@Q1S67>LLiaS600HDY@<@Q0065:D@Q1BU5:D@Q1BU1A2400<DYA2448@0
0PaS00H@Q1S66<HHaQBU48@55:D01A2436<@Q1246<H00Q240QBU00<HaQBU5:D00QBU112400DDYAS6
48@@Q1BU00<HaP8DY@8@Q0046<H@Q1245:D26<H01ABU48@@Q0aS48@011BU00<@Q1BU5:D01A240PaS
1A240aBU0Q240aBU00<@Q0aS48@00Q240aBU0aS60Q240aBU00@HaQBU48@DY@<@Q00336<@Q12400D@
Q0045:DHaQS66<H548@00aBU48@@Q00348@011BU48@@Q1BU0Q240PaS0a240`aS00@8@PaS48@@Q0H<
H`88@PH<H`03248<H`aS00@<H`88@P<<H`0348@<H`Q200<<H`04248<H`Q248@536<00a2436<<H`02
248536<248@736<00a2436<<H`0336<248@136<000848@0600048@@Q124000Q20P@Q00X000Q2:DYF
]Cg_:DXaS3W>=JdaS0D]J`06:DX]Jbe[<H`]Jc6<0SF]0c6<0cW>00@aS2e[;F/]J`8aS009;F/YBRU:
9BTYBR489BTYBRe[008YBPPU:@<YBP049BTYBS6<<H`2>Lh0136<;F/YBRU:1Be[0RU:00<U:BU::DX0
12U:0Re[0bU:12e[12U:00<]JbDY8@P00QcW00@Q21S66<HHaP<Li`8HaP045:DHaQcW8@P39BT2:DX0
1bDY8@PQ22487>LHaQcW008U:@048@PLiacW7>L26<H57>L38@P27>L26<H27>L28@P27>L00b489BTU
:@067>L26<H00acW8@PU:@028@P26<H01248:DXQ22480QBU11cW00HQ21cW7>LQ21cW9BT38@P27>L2
8@P03BDY;F/e[DHaBU9243W>8@PU:AcW8@PLiaS6008DY@8HaP057>LHaQBU6<HLi`026<H25:D36<H0
21245:DDYABU6<HDYAS65:D26<H00acW8@PLi`027>L00aS67>LLi`027>L00aBU6<HLi`026<H00aBU
6<HLi`026<H27>L28@P01AcW8@PLiacW9BT00RU:00<U:AS66<H00acW0R480RDY00<Q21S66<H011S6
0QcW0QBU00<Lib487>L00QS600HQ21cW6<HDYAcW9BT48@P26<H25:D01AS65:DLiacW8@P00QcW0QS6
00<LiaS66<H011BU00@@Q1BU5:DQ208Li`088@PYBRe[;F/aS2U:7>LHaP8DY@046<HDYABU48@35:D0
1A245:DDYA245:D01A240QBU0QS600DDYAS67>LHaQBU008@Q08DY@8HaPL@Q08<H`0748@DYABU48@D
YAS65:D00a2400@HaQBU5:D@Q0<DY@097>LHaQBU6<HDYA245:D@Q1BU008@Q00736<DYABU48@DYA24
5:D00Q240QBU00<@Q0aS36<00PaS0Q2400@DYAS66<HDY@D@Q0035:D@Q124008@Q0035:D@Q12400`D
Y@0748@DYABU48@DYAS65:D00Q241ABU00<HaQBU5:D00aBU0a2400<DYAS65:D00PaS00<@Q1BU48@0
0Q240QBU00D@Q0aS48@@Q1BU00<@Q08<H`0748@DYAS65:D@Q0aS48@00QBU0Q2400@DYAcW6<HHaP8D
Y@0348@DYABU00P@Q00336<@Q0aS008@Q00336<@Q1BU008DY@@@Q0065:D@Q1BU5:D@Q1BU0Q240`aS
0a241@aS0Q240`aS00<@Q0aS36<00`aS0PQ21@aS00D8@PaS48@@Q0aS00<8@PD<H`<8@P0636<8@PaS
248<H`Q20PaS0Q240`aS0Q240PQ200<<Ha2436<010aS00@@Q0aS36<<H`8@Q00336<8@PQ2008<H`05
48@<H`aS36<@Q0012480000500048@@Q12400003124020Q200048@Q2<Ha_Ne:D<H`2?Nl013W><H`a
S36<0bU:0be[00DaS3F]=JdaS2e[00@aS08e[@06<H`]Jbe[<H`e[C6<0Re[1BU:0be[0bU:00<]JbU:
;F/00RU:00D]JbU::DXYBRe[00<aS005=JdicSF]<H`YBP03;F/01S6<;F/]Jbe[:DX]J`8YBP05;F/Y
BRDY9BTYBP02;F/012U:;F/]Jbe[0bU:0R4800<LiaS67>L00QcW0aS600<LiaS66<H00aS60QcW00HH
aQcW8@PYBRDY:DX2;F/01BU:9BTLib489BT00R4800DHaQcW8@PQ21cW008HaPDLi`036<HDYB4800<U
:@8Li`038@PLib48008U:@088@PLib488@PU:AcW6<HQ208Li`<HaP8Q20079BTLiacW7>LQ21cW8@P0
0acW12480acW00@HaQcW7>LLi`8Q208Li`066<HLib487>LU:Be[0SF]00H]JbU::DXU:B485:D26<H5
5:D36<H37>L011S65:D@Q1240QBU0aS600<LiaBU6<H00QS60b4800HLiaS66<HLib489BT57>L00aS6
5:DHaP027>L38@P011cW6<HLib480acW00<U:B488@P00QcW1R480QcW00<Q21cW7>L00aS600<DYAcW
7>L01AcW0R4800@LiaS66<HHaP8Q20049BTQ21cW6<H45:D26<H00acW6<HHaP025:D56<H00a245:DD
Y@026<H03QcW48@<HaS69BTe[BU:7>LQ22U:8@PHaQBU6<H25:D00a245:DDY@026<H011BU48@@Q1BU
112400@DYA245:D@Q08DY@036<HLiaS600@@Q0<DY@8@Q0065:D@Q12448@<Ha240QBU0Q240QBU0QS6
00HDYA2448@@Q1BU6<H55:D27>L00b487>L@Q00248@011BU48@@Q0aS1Q2411BU0Q240`aS112400<<
Ha2448@00QBU00<@Q1BU5:D00a2400<DYAS648@00Q2400DDYAS65:D@Q1S6008DY@8@Q0035:D@Q124
008DY@8HaP045:D@Q0aS48@55:D248@25:D00aS65:D@Q00248@01QBU6<HDYA245:D@Q08DY@0348@<
Ha24008@Q0<<H`0348@DYABU00<@Q0035:DHaQS6008@Q00536<@Q1BU5:D@Q0025:D26<H45:D01AS6
5:D@Q1245:D00a240PaS00@@Q0aS48@DY@<@Q08<H`0348@DYABU008@Q00@5:DLiaS648@<Ha245:DH
aQBU48@<Ha245:D@Q0aS248236<01a245:D@Q0aS248@Q0aS008@Q00336<@Q0aS00<<H`<8@P<<H`04
248<H`aS48@236<010Q236<<Ha241@aS00@8@PaS36<<H`<8@P@<H`07248<H`aS36<8@PaS24800a24
10aS0a2400@<H`Q236<8@P8<H`0348@<H`aS008<H`4@Q04<H`000`@Q00<000@Q00001@@Q00D8@Re[
JeYBU3F]0092408mk`04=JdaS2e[<H`2:DX5;F/00cF]<H`aS002:DX3<H`2;F/0136<=Jde[C6<12e[
00PYBRDY:DX]Jc6<;F/U:Be[0S6<00X]JbDY9BTU:Be[<H`]JbU:;F/e[@8aS08]J`07<H`e[Be[:DXU
:BU:<H`00Re[00PYBRe[:DXYBRe[<H`]JbU:0bDY00@YBRe[;F/]J`8YBP09;F/YBRDY8@PLib486<HL
iaBU008HaP8Li`056<HDYAcW6<HLi`026<H37>L28@P2:DX2;F/00bU:8@PU:@028@P77>L011S67>LH
aQS60QcW0aS60R4800<U:AcW7>L00QcW0R4800DU:B488@PQ22DY00HQ20047>LHaQcW7>L28@P01BDY
7>LLiaS67>L01B480RDY00@Q21cW6<HHaP8Li`038@PHaQS600LLi`098@PYBRU:;F/YBS6<>LhaS2U:
008Li`048@PHaQBU48@35:D011cW5:DLiacW0QS60QBU00HHaQBU6<HDYAS67>L36<H00aBU7>LLi`04
7>L01aS67>LQ22489BTQ21S600@Li`8HaP8Li`8U:@037>LHaQcW008Q20<Li`<U:@8Q20037>LQ21cW
00<Li`038@PLiacW008Q208Li`@HaPTLi`085:DLiacW8@PU:B487>LHaP8DY@<HaP8DY@8HaP8DY@03
6<HLiaS600<DY@8HaP065:DHaQBU48@HaQcW0RDY00DQ22U::DXQ21cW008@Q08DY@036<HDYA2400HD
Y@0348@DYA2400DDY@0548@DYAS66<HDY@026<H0112436<<Ha240aBU1Q2400<<Ha2448@00QBU00/@
Q1BU7>LHaQ2436<@Q1S648@DYA2400<DY@046<HLiacW6<H25:D011245:DDY@aS0a2400HDYA2448@@
Q1BU6<H25:D248@00aBU48@@Q00248@336<00a245:D@Q00748@25:D348@00aBU6<HHaP026<H35:D0
0a245:D@Q00248@25:D00aS65:DDY@025:D00a245:DDY@025:D348@25:D00a245:D@Q0025:D011S6
5:DHaQBU0Q240aBU11240PaS0a2400<DYA2448@00PaS00DDYAS65:D@Q0aS008@Q08HaP055:D@Q1BU
5:DHaP055:D00a2436<@Q00448@00`aS48@@Q00336<348@00aBU48@@Q00248@55:D00a245:DDY@02
5:D248@01`aS48@@Q12436<@Q1BU008@Q00336<@Q124008@Q08<H`04248@Q0aS48@336<2248236<0
1PQ236<<Ha2436<8@P8<H`04248<H`aS48@236<3248436<3248736<2248536<00`Q236<<H`0248@2
36<00`Q236<8@P0236<248@336<12480000300048@@Q00D48@0824848@@Q248e[G>LE[DaS0=24003
?NlicSF]00<aS005;F/aS36<>Lhe[@06<H`00cF]<H`]J`06;F/00bU:9BTYBP03<H`00bU:9BTU:@04
:DX0136<>LhicS6<0RU:00H]JbDY:DXaS3F];F/2:DX0136<>Lhe[Be[0RU:00<U:BU:9BT01BU:0S6<
00d]JbU:8@PU:Be[:DX]JbDY:DX]Jc6<;F/YBP029BT00acW6<HHaP026<H25:D56<H77>L01R487>LU
:BDY:DX]J`8YBP069BTQ22487>LHaQcW0R4800LLiaS66<HLiaS67>LHaP037>L01b489BTYBR487>LQ
22DY008Q208U:@038@PLib4800<U:@047>LU:BDY9BT38@P27>L2:DX012486<HDYAS60b480QcW00<Q
22DY7>L00R4800<U:B487>L00acW00LHaQcW7>LLiaS67>LQ20029BT28@P39BT012e[<H`]JbDY0QS6
00<LiaS66<H00QcW0QS60QBU00@HaQBU6<HLi`8HaP<DY@037>LQ21cW00<HaP037>LHaQBU008HaP03
7>LHaQcW00<Li`058@PLiaS67>LHaP027>L00aS67>LLi`067>L00aS67>LLi`029BT012487>LHaQcW
0R480QcW00<Q21cW8@P00acW00HQ21cW7>LHaQcW8@P47>L022487>LLiaS65:DHaQcW6<H37>L46<H0
1AcW6<HLiacW6<H00QBU00<@Q1S65:D00aS600/DYAS65:DDYAS67>LDYA245:DHaR48008Li`048@PU
:BDY7>L56<H25:D00a245:DDY@065:D00a245:DDY@036<H00a245:DDY@026<H01aBU48@DYA245:D@
Q0aS008@Q08DY@D@Q0DDY@036<H@Q1BU008@Q0<DY@8HaP085:D@Q1S66<HLiaS65:D@Q0<DY@0448@<
Ha245:D448@35:D348@25:D0112436<@Q0aS0Q240aBU0Q2400<DYA2448@00a2400<DYA245:D00QBU
11S600<DYA2448@00a240QBU00<@Q1BU48@00QBU0Q2400DDYA245:DHaQBU008HaP<@Q0<DY@0948@D
YABU5:D@Q1BU6<H@Q0aS00<@Q0<<H`<@Q0<<H`0448@DYABU5:D236<01A245:D@Q1245:D00a2400<D
YAS66<H01ABU00<@Q1BU5:D00Q2400<DYA2448@00Q2400<DYA2436<00Q2400HDYA2436<DYA245:D2
48@65:D26<H25:D748@336<348@336<0112436<<H`aS0a242`aS00D8@PaS36<<H`Q200<<H`0748@<
H`aS36<8@PaS24800PaS0`Q20PaS0PQ21PaS00<8@PaS36<00Q240`aS00@8@PaS36<8@P8@Q0@<H`4@
Q048@P000P@Q00@000@Q124000@48@0=000<Hc6<Kg]F]CW>AS5243g_>LhmkcW><H`00Re[0cF]00<a
S3F]=Jd00SF]00@aS2e[;F/]J`8e[@03<H`YBRe[008aS003;F/U:BU:00D]J`03:DX]JbDY008YBP03
9BTaS3F]008e[@03;F/aS2e[008YBP03;F/e[C6<00<YBP05=JdicS6<;F/U:@02:DX00bDY8@PLi`02
9BT01bU:;F/]Jbe[:DX]JbU:008]J`09:DXU:BDY:DX]Jc6<;F/YBRDY008Q20037>LHaQS600@HaP04
5:DHaQBU5:D26<H27>L58@P01RDY:DXYBRDY:DXU:@8Q208HaP8Li`8Q20PLi`046<HLiacW8@P39BT9
8@P39BT28@P29BT48@P39BT00b486<HHaP026<H27>L58@P27>L01B489BTQ21cW6<H011cW00@HaQcW
7>LQ20<U:@058@PU:B48:DXaS002;F/28@P27>L00aS65:DHaP035:D36<H00aBU6<HHaP026<H01aBU
6<HLib487>LHaQBU00<HaP047>LHaQS66<H97>L00b487>LLi`026<H00acW8@PLi`026<H02QcW8@PL
iacW6<HLib48:DXU:B480acW00<Q21cW6<H01R4800LLiaBU6<HLib489BTQ20026<H011cW8@PLiaS6
0QBU00THaQcW7>LQ21cW8@PLiaS65:D00QS600@LiaS66<HLi`8DY@0448@DYAS66<H25:D26<H021BU
6<HHaQS648@DYAcW8@P26<H00acW9BTU:@037>L00aS65:DDY@065:D348@35:D011245:DHaQcW0QS6
00<@Q1BU6<H00QS60QBU1A240QBU00H@Q0aS36<<HaBU6<H25:D248@011S65:DHaQBU0Q240QBU00<H
aQBU5:D01QBU0QS60Q2400D<Ha245:D@Q1BU00P@Q0035:D@Q1BU008@Q08<H`0348@<Ha2400<@Q003
6<HDYA2400H@Q0<DY@0548@DYABU7>LHaP035:D011245:D@Q1BU0Q2400<DYA245:D01A2400<DYA24
5:D00QS600<DYA245:D00aBU00<@Q1BU5:D00aBU11240QBU0a240PaS00<@Q0aS36<02A2400P<Ha24
5:DDYA2436<@Q1BU0Q240QBU00<LiaBU5:D02Q2400@<Ha2448@@Q08DY@0448@<Ha2436<448@25:D0
11245:D@Q1BU0Q240QBU0Q2400@<Ha2436<<H`<@Q08<H`0348@<Ha2400<<H`8@Q0035:D<H`aS00<<
H`<8@P8<H`0548@<H`aS36<8@P0236<00`Q236<<H`0236<01@Q236<<H`Q236<00`Q200L<H`Q21248
@PaS48@<H`02248236<248@336<348@436<00a2436<<H`0336<248@136<0000500048@@Q12400003
12403PQ200048@Q2=Je_Ne:D:DXe[CW>?Nm243g_=Jd4<H`02CF];F/icSg_>LhaS2U:<H`icP03<H`0
1CF];F/YBRDY:DX00Re[00<YBRDY;F/00Re[0RU:00@U:B489BTU:@8YBP8]J`<aS08]J`8e[@04<H`Y
BRDY:DX2;F/2<H`2;F/01BDY8@PQ22489BT00R481BDY00<YBRe[;F/00be[0S6<00<]JbU:9BT00bDY
00DLiaS66<HLiaS6008DY@036<HLiaS600<DY@8HaP<Li`038@PLib48008Q200;9BTQ2248:DX]JbU:
9BTLiaS68@PLi`038@P26<H27>L01R486<HLib489BTQ20<U:@0;8@PLib489BTQ21cW8@PU:BU:9BTY
BP029BT38@P00bDY8@PQ20028@P01BDY:DXYBRDY6<H00QcW0b4800DLib488@PQ21cW00<Q208HaP8L
i`038@PLiacW008Li`<Q20057>LU:B488@PU:@02:DX01B489BTYBRe[9BT00b4811S600DLiaS65:DD
YAS6008Li`<DY@DLi`HHaP037>LQ2248008HaP8Li`038@PHaQcW00<Li`HHaP037>LHaQS6008HaP06
7>LHaQcW8@PU:B481AcW0QS60QcW0R4811S60acW00<HaQcW7>L00QS60QcW00@HaQBU7>LLi`8HaP8L
i`8HaP035:DLiaS6008HaP067>LHaQBU5:DHaQcW0QS600<DYAcW6<H011BU0QS60QBU00<HaQcW7>L0
0QS60QcW00DQ22DY9BTLiaS6008DY@8HaP035:D@Q1BU00<@Q0036<HDYAS600<DY@0648@DYABU7>LH
aQBU0QS600<DYA2448@00Q2400D<Ha2448@@Q1BU00D@Q0035:D@Q1BU008DY@036<H@Q1BU008DY@<@
Q0@DY@0348@DYAcW00<Li`@@Q00336<@Q124008<H`0548@DYAS648@<H`0248@00aBU48@DY@0248@2
36<00a245:DDY@026<H00a245:D@Q00248@00aBU48@@Q00248@00aBU48@@Q0025:D01QS67>LHaQBU
36<@Q0HDY@036<HDYABU00<DY@076<HDY@aS48@DYAS65:D00Q240QBU00<@Q1BU5:D00QBU00<<Ha24
48@00QBU00@@Q0aS36<DY@8@Q00336<@Q0aS00<<H`<@Q00336<@Q124008@Q0<<H`045:D@Q1BU48@2
5:D011S65:DHaQBU0Q2400DDYA2448@@Q0aS008@Q08DY@0548@<H`aS48@DY@0248@010aS48@@Q0aS
0Q240aBU0a2400<DYA245:D010aS00<@Q1BU5:D00Q2400<<Ha2448@01@aS1a240`aS00H@Q0aS36<8
@PaS48@336<2248536<010Q236<<H`Q210aS0PQ200@<H`Q236<<H`88@P0336<@Q0aS00@<H`0348@<
H`aS00<<H`0348@<Ha2400X<H`000`@Q00<000@Q12400P@Q00P8@P@Q1248@RU:IcUBU36<0SF]00Ha
S3W>>LhmkcW>=Jd2<H`2=Jd4>Lh4=Jd01C6<=Jde[C6<;F/00RU:00@U:B489BTYBP<]J`06<H`YBRDY
9BTQ22DY0RU:00D]JbU:<H`aS3F]00<aS00<=Jd]JbU:9BTYBS6<;F/e[C6<;F/YBR481BDY1B4800DU
:BU::DX]JbU:008]J`8YBP<]J`03:DXQ224800DLi`8HaP045:DHaQS65:D36<H01aBU6<HHaQcW8@PL
ib48008Li`8Q20039BTYBRU:008U:@068@PLiacW7>LQ22DY0acW00@HaQcW6<HLi`8Q20039BTQ2248
00<U:@8Q20037>LHaQcW008Q20@YBP059BTYBR488@PLi`068@P01RDY:DXYBRDY7>LHaP8Li`8Q208L
i`038@PLiacW00<Li`038@PLiacW008Li`8Q208Li`8Q20037>LQ224800LU:@<YBP058@PHaQBU5:DH
aP027>L26<H25:D66<H27>L56<H25:D01QS68@PU:B487>LHaP8Q20<Li`DHaP<Li`055:DHaQS66<HL
i`026<H01AcW9BTU:BDY7>L00R480QcW00DHaQcW7>LLib48008Li`046<HDYABU6<H27>L012487>LL
iacW11S600<LiaS65:D00QS60acW00XHaQBU5:DLiaS67>LHaQBU6<HDY@@HaP057>LHaQBU6<HDY@02
6<H25:D011246<HLiacW0aS600PQ21cW7>LU:BU:9BTLiaBU0aS60QBU0a240aS60Q2411BU00@HaQBU
5:DDY@8HaP8DY@0336<@Q124008<H`8DY@<@Q0<DY@<@Q0035:DHaQBU008DY@0348@DYABU008@Q003
36<@Q1BU008DY@0336<@Q1BU008Li`036<HDYABU00D@Q00436<@Q1S65:D348@00aBU48@@Q00348@0
1aBU36<<Ha245:DHaQBU008@Q0<DY@8@Q00836<@Q1BU48@DYA245:DHaP8DY@8@Q0046<HDYAS65:D5
48@25:D46<H25:D248@45:D36<H348@00`aS48@<H`0248@00aBU36<<H`0236<448@336<348@01ABU
48@<H`aS48@00`aS1Q2400@DYA245:DHaPD@Q0035:D@Q1BU008DY@@@Q00436<@Q1BU48@436<348@3
5:D01A245:D@Q1245:D00Q240`aS0aBU00<@Q0aS36<010aS0Q240`aS1Q2410aS0`Q23@aS0PQ20PaS
00@@Q0aS36<8@P8<H`03248<H`aS008<H`04248<H`aS48@436<00a2436<<H`0236<248@436<00a24
36<<H`0236<124800003124000@Q00848@0300048@@Q00<48@08248]Je[F@Q0U:CF]?NlicP8e[@<a
S08]J`8aS08e[@@icP<e[@8]J`04:DX]Jc6<;F/3:DX012DY;F/aS2e[0RU:00<U:BU:9BT00RU:00<]
Jc6<=Jd00cW>0T8@00XicS6<=Jde[C6<:DX]JcF]<H`]J`DU:@8YBP038@PU:B4800<U:@8YBP8]J`8a
S004;F/YBRe[;F/3:DX012DY8@PLiaS60QcW0QS60aBU00HLib488@PLiaS67>L26<H00acW8@PQ2003
7>L38@P012DY:DXU:BDY0acW0RDY0R4800@Lib487>LQ208Li`058@PU:BDY8@PLi`038@P37>L28@P2
7>L29BT01c6<;F/YBRDY8@PLib48008U:@8Q20036<HQ22DY008YBP058@PLib489BTQ20047>L46<H2
7>L01AS67>LLiacW8@P00QcW00PQ21S67>LQ22DY8@PLib480RU:0RDY00<YBRe[;F/00bDY0RU:00@U
:AcW5:DHaP8Li`056<HLiaS67>LQ20026<H27>L28@P27>L01QS67>LLiaS65:DHaP@Li`036<HQ21cW
008Li`<HaP@Li`8HaP035:DHaQcW00@Li`8U:@@Q20057>LHaQS66<HLi`026<H00acW6<HLi`036<H3
7>L36<H01AcW6<HLib487>L011S60QcW0QS60QcW0aS600<DYAS67>L00acW0QS600<DYAS65:D00aS6
0QBU00@HaQcW7>LLi`@DY@076<HDYAS68@PU:BU:9BT00aS600DQ21cW5:D@Q0aS00DDY@8@Q0@DY@06
6<HDYAS66<HLiaBU1A2400<DYA2448@00a240aBU0Q240QBU00DHaQ2448@DYAS6008@Q0<DY@<@Q0@D
Y@046<HLiaS66<H248@011BU48@@Q1240QBU0a240PaS00<@Q0aS48@00a2400<DYA2448@00Q2400@D
YA245:DHaP<DY@<@Q0045:D@Q1BU48@55:D01A245:D@Q1BU48@00aBU00<HaQBU48@00PaS0QBU0QcW
00DDYA2448@@Q1S600@DY@<HaP055:D<H`aS48@<H`0248@00aBU48@@Q00648@00aBU48@DY@0948@2
36<00a245:D<H`0236<011245:DHaQBU1A2400<DYA2448@00a2400HHaQ2448@@Q1BU48@236<248@0
10aS48@@Q1BU0Q2400DDYAS65:DDY@aS00@DY@0748@<H`aS36<@Q1BU48@00PaS0Q240PaS00<@Q1BU
5:D010aS0a242PaS00<@Q0aS36<00PQ200<<Ha2448@00PaS00<8@PaS36<00PaS00<8@PaS24800PQ2
0PaS00@@Q0aS36<8@P<<H`06248<H`aS36<8@PaS11241PaS00<@Q0aS36<00PaS0@Q200001@001244
8@@Q00000`@Q00X8@P001248@S6<HaQ242DY;F/mk`8icP06=JdaS36<;F/aS3F]0S6<0SF]00@icS6<
<H`e[@8icP8aS005;F/YBRU::DX]J`02:DX00bDY:DXYBP02;F/01C6<;F/U:BDY:DX00Re[00LYBRDY
:DXe[CW>AS5:DP02@Q000cW><H`e[@03<H`01Be[=Jde[Be[:DX00R480RDY00<Q22DY8@P00bDY00<Q
22DY9BT00be[00<aS2e[;F/00RU:0Re[00<YBRDY:DX00R4800@LiaS67>LLi`8HaP045:DHaQS66<H5
7>L012487>LQ224811cW00<U:B488@P00RDY00@Q21cW7>LLi`8U:@8Q208Li`0<8@PLiaS67>LQ22DY
8@PHaQcW8@PU:B480QcW00@HaR489BTU:@<Q20039BT]JbU:008U:@0;8@PLib488@PU:B486<HLibDY
:DXU:@058@P01BDY7>LLiacW5:D00QS60acW0QS600HLib488@PLiaS67>L38@P00acW8@PU:@039BT0
1BU:;F/YBRe[:DX00QcW00@U:C6<<H`YBP8Li`<HaP035:DHaQBU008HaPTLi`<HaP035:DLiaS600<L
i`036<HLiacW00<Li`8HaP8Li`038@PHaQS6008HaP047>LQ21S66<H27>L00bDY:DXU:@028@P00acW
6<HDY@066<H27>L66<H25:D26<H012487>LHaQS60QBU00<HaQcW7>L00R480QBU00XHaQcW7>LLiaS6
7>LQ21S67>LHaP8Li`8HaP<DY@8HaP<DY@037>LQ21cW008DY@056<HDYABU5:DHaP039BT01b486<HL
iaS65:DHaQ24008DY@0348@DYAS6008DY@8@Q0035:DHaQBU008DY@<HaP045:D@Q1BU48@236<01124
5:DDYABU0PaS00H@Q1S65:DDYA245:D26<H01a245:D@Q1245:D@Q1BU00<@Q0035:D@Q124008@Q08L
i`8HaP@@Q0035:D@Q0aS008@Q08DY@8@Q0<DY@0548@<H`aS5:DHaP0248@010aS48@@Q1S611BU00@@
Q1BU5:DDY@8@Q00436<@Q12448@45:D248@00aBU48@DY@0348@25:D00a245:D@Q0026<H00acW6<HD
Y@0248@55:D00aS65:D@Q00348@336<00a245:D<H`0348@011BU36<<H`aS0Q2400DDYA2436<@Q0aS
00L@Q00336<@Q0aS008@Q0045:D@Q12448@236<01Q245:DDYAS648@<H`<@Q0045:D@Q0aS36<448@4
36<01A245:DDYA245:D00Q2400<HaQBU5:D00Q2400@HaQBU48@<H`8@Q08<H`8@Q00636<8@PaS36<@
Q1BU0Q240`aS0a240PaS00<@Q0aS36<00PaS0Q240PaS0`Q200<<H`Q248@01PaS00@8@PaS248<H`@8
@P<<H`0448@8@PQ236<248@00`aS2488@P0236<248@536<00`Q236<<H`0336<2248000848@030004
8@@Q00<48@0824848@@Q248aS6mkDY@U:@<aS0@e[@03>Lhe[C6<00<icP04=Jd]Jbe[;F/4<H`2;F/3
9BT00bU:;F/]J`03;F/00bU:;F/]J`02<H`2;F/00c6<;F/]J`02:DX4<H`02cW>?Nm244YB@Q0icSF]
;F/e[Be[:DX012DY0RU:00H]JbU::DXYBRe[:DX29BT4:DX2;F/3<H`012e[9BTQ22480RDY00<Q21cW
7>L00QS600PDYAS67>LDYAS67>LQ22DY0QcW0b4800<Lib489BT00R4800<Lib487>L02b4800<Lib48
7>L00R480RDY00TYBRe[9BTQ21cW8@PU:B486<H00QcW00<Q21cW8@P00b4800LLib487>LLib489BTY
BP029BT48@P2:DX29BT57>L46<H45:D011S67>LQ22480QcW0QS60QcW00DQ22DY8@PQ21cW00<Q200<
7>LQ21cW9BTLib48:DXaS3W>=JdU:B480acW0aBU00LLiaS67>LLib489BTQ20029BT28@P00acW6<HL
i`037>L26<H00acW6<HHaP047>L26<H27>L00b489BTQ20036<H00b48:DXQ20028@P29BT01B487>LD
YABU6<H00acW00HHaQBU5:DHaQBU6<H27>L25:D01AS67>LLiaS67>L00R4800DLiaS65:DLiaBU008L
i`048@PLiaS66<H47>L011S67>LHaQcW0b480acW11S600HDYA247>LU:BU:8@P25:D27>L36<H25:D0
12489BTU:BDY11cW00HHaQBU48@DYAS67>L25:D26<H02ABU48@@Q1BU36<@Q1S67>LHaP0248@01aS6
5:D<H`aS48@HaQBU00@@Q08HaP0348@DYABU00<@Q00336<DYABU008DY@0348@<Ha2400@@Q0@DY@07
6<HLiacW6<HDYA245:D00a2400<<Ha2448@01a240PaS1A2400<DYA2448@0112400HDYA2448@DYAS6
5:D248@36<H011BU48@DYA240QBU00<@Q1S66<H00Q240PaS0a2400<DYA245:D00QBU00@@Q1S66<HD
Y@D@Q00336<@Q0aS00<<H`8@Q0045:DHaQBU48@236<248@010aS48@@Q1BU212400@DYA2448@<H`<@
Q08DY@@@Q0085:D<Ha2448@DYA2436<@Q08DY@0348@DYA2400@@Q08DY@0448@<H`aS48@25:D248@0
0aBU48@DY@025:D248@00`aS48@@Q00248@336<248@336<00a2436<@Q0025:D248@35:D00a2436<<
H`0236<0112436<<H`Q21@aS00<8@PaS36<00`aS0`Q200@<Ha2436<8@P8<H`8@Q00636<8@P@Q248<
H`Q20`aS00H@Q0aS36<8@PaS248236<248@01@aS48@<Ha2436<00`Q20@aS0@Q200000`@Q00048@02
12400`0012448@0312402PQ2;F]_Ne:D<H`icSF]<H`e[C6<0cF]0c6<00<e[CW>>Lh00c6<00<]Jc6<
<H`00S6<00<]JbU::DX00RU:00D]JbU:;F/aS2e[008YBPD]J`8aS0H]J`07<H`e[CW>>Lhmkd8@?Nl0
0cF]0S6<00<Q22DY9BT00RDY00@YBRe[9BTU:@<]J`03:DXQ2248008U:@<YBP03;F/aS36<00<]J`06
:DXU:B488@PLib480aS600<DYAS66<H00QS600<Lib487>L01b4800HU:B488@PLib487>L29BT01248
7>LLib480RDY0R4800<U:AcW8@P00QcW00PU:BU:;F/]JbDY8@PLiaS60b480acW0RDY0R4800<U:B48
7>L00QcW00DU:B488@PQ22DY008YBP069BTQ22488@PU:BU:0RDY00<LiaS67>L011S60aBU0QS600@D
YAS68@PQ208Li`036<HQ21cW00<Li`8Q20DLi`DQ2003:DX]Jc6<008aS08U:@046<H@Q1BU48@26<H4
7>L68@P00bDY8@PLi`026<H57>L01AS67>LHaQBU6<H00acW00<HaQcW9BT00R480QcW1B480RDY00<Q
21S65:D00QS60acW00@HaQBU5:DDY@@Li`036<HDYAS600HLi`066<HLiaBU5:DHaQcW0R4800@LiaS6
6<HHaP8Li`036<HDYAS600<Q208Li`046<HLiacW7>L26<H011245:DHaQcW0R4800HLiaS66<HDYAcW
6<H35:D26<H01bDY:DXU:B487>LHaQcW00<HaPDDY@8HaP8DY@<@Q0045:DLiaS65:D248@35:D01Q24
5:DDYABU48@DY@8@Q0045:DHaQBU5:D448@25:D348@011BU48@@Q0aS11240QBU0QS60QcW00<HaQBU
5:D00PaS00<@Q1BU48@00PaS0a2400<<Ha2448@00Q2400@<Ha2448@@Q08<H`0448@DYABU5:D348@3
5:D348@00aBU48@HaP026<H011BU48@DYABU0Q240QBU00@HaQ2448@DY@@@Q0<DY@@@Q08DY@D@Q003
36<@Q124008@Q00336<DYABU008@Q00436<@Q12448@336<348@01QBU48@@Q12436<@Q08DY@H@Q08D
Y@@@Q08DY@H@Q0035:D@Q1BU00<@Q00436<@Q1245:D548@00aBU48@DY@0248@00aBU48@DY@025:D4
48@00aBU6<H@Q00236<00a2436<<H`0236<248@55:D348@00aBU48@<H`0236<00a2436<<H`0@36<0
1A242488@PQ236<00Q240`aS0PQ200<<Ha2448@00`aS00<8@PaS24800PaS0PQ200@<Ha2448@@Q0D<
H`88@P0000D000@Q12448@0000<48@0824848@00248aS6mkF]HaS0@icP04?Nm2448@?Nl3>Lh2?Nl0
0cW>=Jde[@02<H`2;F/01BU:9BTU:BDY:DX00RDY00<]JbU:=Jd00cF]0Re[00<aS2e[<H`01Re[0RU:
00D]Jc6<;F/YBRe[008aS007;F/YBRe[<H`]JbDY:DX00S6<00<]JbU:<H`00SW>00He[CW>@Q0e[Be[
8@P39BT01B487>LU:BDY;F/00S6<00<YBRDY8@P00R4800<U:B487>L01AS600LDYAS66<HHaR487>LQ
20029BT00b487>LQ20028@P00bDY8@PQ20028@P00acW8@PQ20028@P00bDY:DXQ20029BT2:DX01BDY
:DXYBRe[:DX00RDY0be[00HYBR488@PU:B487>L78@P27>L022487>LHaQS68@PU:BU:9BT48@P2:DX2
9BT00b487>LLi`037>L00aBU6<HLi`045:D00aS67>LQ20037>L68@P01RDY7>LHaQS67>LQ208Li`0;
8@PU:BU::DX]JbDY;F/aS3F];F/Li`036<H011cW6<HDYAS60QcW00DDYAS67>LYBRDY008Q20047>LH
aQcW7>L29BT27>L01B487>LLiaBU6<H00QcW00DQ21S66<HHaQcW00LQ20<Li`048@PLiacW6<H25:D3
6<H01B487>LLib486<H00QBU00@HaQcW6<HLi`8HaP047>LQ21cW8@P37>L36<H011cW8@PQ224811cW
11S60QcW00HQ21cW7>LHaQcW8@P29BT022487>LHaQcW8@PLiaS648@25:D46<H01aBU6<HDYBDY:DX]
JbU:00<Li`8DY@0548@DYAS65:DHaP045:D01AS65:DDYABU48@011BU0QS600DLiaS67>LDYAS600@D
Y@036<HDYABU00<@Q0035:D@Q124008<H`0548@DYAS65:D@Q00436<248@25:D36<H00acW6<HDY@03
48@336<248@00aBU48@<H`0248@00aBU48@@Q00636<01Q2436<@Q1BU48@DY@8@Q0DDY@036<HDYAS6
00<HaP035:D@Q124008HaP8DY@8@Q0035:DHaQ24008@Q00436<DYABU5:D448@011BU48@@Q0aS1124
1@aS0a2400<<Ha2436<011240PaS00<@Q0aS48@00QBU0a240QBU1a240QBU00@<Ha245:DDY@8@Q08D
Y@<@Q08DY@8@Q00336<@Q0aS00@@Q00336<DYA2400@@Q0035:D@Q1BU008DY@8@Q0035:D@Q12400<@
Q0<<H`8@Q00336<8@PaS00@<H`D@Q08<H`<@Q00336<8@PaS00<<H`03248<H`aS00D<H`<8@P<<H`03
248<H`aS0088@P@<H`03248<H`aS0088@P8<H`05248<H`aS36<@Q00236<010Q236<<HaBU10aS00@8
@PaS36<<H`48@P000`@Q00<000@Q12400P@Q00P8@P001248@S6<LiaF]C6<0Sg_0cW>0cg_00<icSg_
>Lh00cW>00Te[CW>=JdicSF]<H`]JbDY:DX00bDY0bU:00@aS3W>>Lhe[@8]J`04<H`e[CF]<H`2;F/2
<H`01BU:;F/]Jc6<;F/00RU:0Re[00DaS2e[:DXYBRe[008aS006:DXU:BU:;F/e[Be[0S6<00DicTHa
BU9243W>008YBP039BTQ22DY00<Q2003:DX]JbU:008]J`8U:@<Q20057>LQ21cW6<HLi`036<H37>L0
0b489BTU:@029BT28@P29BT28@P00bDY8@PQ20038@P01acW9BTYBRU:9BTQ21cW008U:@@YBP04;F/Y
BRDY:DX3;F/39BT01AcW8@PQ22DY8@P00QcW0bDY00@HaQBU6<HLi`8U:@037>LU:BU:008U:@037>LQ
22DY00<YBP<Q20047>LQ21S66<H25:D46<H011cW6<HLiacW124800DU:AcW7>LLibDY008Q208Li`<Q
208Li`038@PYBRU:008U:@06;F/aS36<:DXU:AcW0QS600DDYAS67>LQ21S600<DY@LQ20@Li`<Q2004
7>LHaQBU6<H57>L01b487>LHaQcW8@PU:BU:008U:@037>LQ21cW00@Li`046<HDYABU5:D27>L00b48
7>LLi`027>L56<H01acW8@PLib487>LHaQBU008HaP068@PLiacW8@PU:B4811cW0aS60QcW00DHaQcW
7>LHaQcW008HaP0;8@PYBRDY8@PLib489BTQ21S65:D@Q0085:D01acW9BTaS2e[9BTQ21cW008HaP04
5:D@Q1BU6<H25:D00a245:DHaP027>L02ABU48@@Q1S648@<Ha245:DLi`026<H00acW6<HDY@025:D2
6<H00aBU48@DY@045:D00a245:D@Q00548@00`aS48@@Q00248@236<248@26<H37>L25:D248@236<2
48@011BU48@<H`aS21240PaS112400@<Ha2448@HaP@DY@0448@DYABU5:D27>L26<H45:D26<H00aBU
48@@Q00248@26<H448@00aBU6<HDY@0248@00`aS48@@Q00248@35:D00a2436<<H`0236<00a245:DD
Y@0336<00a245:D@Q00248@00`aS48@@Q00248@00aBU48@@Q00248@25:D648@00aBU48@@Q0045:D2
48@35:D348@35:D348@236<011245:D@Q1240QBU0Q2400<DYAS66<H00Q2400@DYAS648@DY@@@Q0<<
H`8@Q0<<H`T@Q0@<H`8@Q0P<H`0348@<H`aS0088@P0536<8@PQ236<8@P0;36<224800`aS48@<H`03
36<00`Q236<<H`0248@436<0212436<<H`Q236<8@PaS48@136<0000300048@0000848@0400048@@Q
248212402@aS=JecW5[F<H`icT8@?Nm24002AS42@Q02?Nl01CW>=JdicSg_>Lh0136<00@]JbU:9BTY
BP8U:@04;F/aS36<<H`2:DX2;F/00cF]>Lhe[@02>Lh013F]<H`e[CW>0S6<00<YBRe[;F/00S6<0Re[
00<YBRe[;F/00RU:00H]JbDY9BTQ22U:;F/29BT00bU:;F/e[@02>Lh3=Jd01BU:9BTLibDY8@P00QcW
00<Q22DY8@P012DY124800<U:AcW7>L00QS600DQ21cW7>LHaQcW00<Q20<Li`DU:@048@PLiacW7>L2
8@P49BT01RU:;F/YBRe[:DXQ208U:@03:DX]Jc6<008aS08]J`03<H`]JbU:00<YBP8U:@8Q20057>LQ
22DY9BTQ20057>L26<H00b489BTQ20027>L00b48;F/]J`02:DX03BDY8@PQ22487>LHaQBU6<HDYAS6
5:DHaQBU008HaP8Q208U:@8Q20@Li`046<HU:BDY:DX29BT00acW8@PLi`027>L012489BTU:Be[12U:
00D]JbU:9BTQ21cW00<Q20046<HDYA245:D26<H00acW6<HLi`038@P02acW6<HQ22487>LQ22DY7>LH
aQBU6<H00QcW00<HaQcW7>L00QcW0R4800@YBRe[:DXQ208Li`058@PLiacW5:DHaP025:D28@P011cW
6<HHaQcW0RDY00@Q21cW7>LLi`8Q20DLi`@Q20@Li`038@PLiaS6008DY@036<HLiaS6008HaP035:DH
aQS6008Q20087>LDYABU7>LU:Be[9BTQ208U:@048@PLiaS65:D248@00`aS48@DY@026<H02ABU6<HL
ibU:;F/YBRDY6<HDY@026<H00acW6<HDY@095:D548@336<01aBU6<HDYA2436<@Q1S6008DY@0448@D
YA2448@65:D548@336<01A245:D@Q1245:D00QS600<DYAS65:D01ABU00D@Q1BU6<HDYA24008<H`/@
Q00336<@Q0Q2008<H`8@Q0065:D@Q1BU5:DHaQBU0a2400DDYAS65:DDYA2400@HaP8DY@@@Q0<DY@8@
Q0DDY@8@Q00336<@Q1BU008DY@<@Q0035:D@Q12400@@Q08<H`H@Q08DY@0448@DYA245:D248@00aBU
48@@Q00248@011BU36<@Q1240QBU00<@Q1BU5:D00aBU00@@Q1BU5:DDY@8@Q08DY@0348@<H`aS00L@
Q0055:D@Q12448@DY@0248@010aS48@DYABU0QS61a240`aS0a240`aS0Q2400<DYA2448@00`aS00@@
Q0aS36<<H`8@Q0<<H`03248@Q0aS00<<H`<8@P8<H`<8@P@<H`03248<H`aS00L<H`<8@P0436<@Q124
48@336<45:D01PaS2488@PQ248@<H`88@P0010@Q00@000@Q1248@P<48@06248]Jf]JDY@aS3g_0SW>
00M244Ha@Q1243g_>Lhmk`02>Lh013F]>LhicSW>0S6<00<]JbU::DX00RU:0RDY00D]JcF]>LhaS2U:
008]J`05:DXaS36<=JdaS002=Jd3>Lh6<H`01RU:;F/]Jbe[<H`]J`@YBP078@PU:BU::DXU:B489BT0
0be[13W>0S6<00<YBRDY8@P00R4800<Lib488@P00R4800TU:B488@PQ21cW8@PU:B487>L00QS600@L
iaS67>LLi`@Q20<Li`038@PLib48008YBP059BTQ21S66<HLi`058@P3;F/012U:9BTU:BU:0RDY0RU:
00@]Jc6<;F/YBP8]J`04<H`YBRDY9BT2:DX39BT00b487>LQ20029BT37>L012DY6<HHaQS60R480QcW
00PQ22U:9BTYBRe[:DXU:B480QcW00<HaQcW6<H01aS60QcW00@U:B488@PHaPLLi`8U:@038@PU:B48
008Li`8Q20039BTLib48008U:@078@PU:Be[<H`YBRDY8@P00bDY00<LiaS65:D00QS60QBU00<HaQcW
7>L00QcW0R480QcW00@HaQcW7>LLi`8HaP035:DLiaS600DLi`098@PHaRU::DX]JbU:7>LQ21cW008H
aP037>LQ21BU008DY@8Li`8HaP057>LU:BDY8@PLi`026<H57>L00b489BTLi`026<H00acW9BTQ2002
7>L38@P01AcW6<HDYAS67>L00aS60acW00DHaQcW6<HLib48008U:@0;8@PU:Be[:DXU:AS65:DHaQ24
5:D@Q0025:D00a245:DDY@026<H01B489BTYBRDY8@P00aBU0aS600<DYAS65:D00aBU112400@DYA24
36<@Q08DY@0448@<HaBU5:D348@25:D01A245:D@Q1BU6<H00QBU00<@Q1BU5:D0112400<DYA2436<0
0PaS00<@Q1BU48@00a2400HLib486<H@Q1S67>L25:D00a245:DHaP035:D348@236<348@336<00a24
36<<H`0236<00`Q236<<H`025:D011245:DHaQBU0Q241ABU00@HaQBU5:DHaP8Li`036<H@Q124008<
H`0348@DYAS6008DY@0548@DYABU6<HDY@0248@25:D01A2436<@Q12436<00Q2400DDYA2448@@Q0aS
008@Q08DY@<@Q0<DY@0448@<Ha2448@25:D548@25:D00a2436<<H`045:D248@45:D248@35:D348@0
0`aS48@@Q00748@01@aS48@@Q1245:D01A2400PDYAS67>LHaQ2436<@Q0aS0Q240`aS00<@Q1BU48@0
0`aS00L@Q0aS36<<Ha245:D@Q00336<248@01`aS248<H`aS48@<H`Q200<<H`0348@<H`Q20088@P8<
H`88@P0336<@Q0Q20088@P0336<@Q0aS0088@P8<H`@8@P0336<@Q1BU00@<H`@@Q00336<@Q0aS00<8
@P4<H`48@P0000<000@Q12400`@Q00/000@Q12448@0036<aS6<HAS4YBS6<008icP04?NlicSW>?Nl2
@Q02=Jd00cW>=Jde[@02<H`00cF]<H`]J`02:DX02248:DXYBRe[?Nm243g_=Jd29BT2;F/3<H`2=Jd0
1Cg_>LhicSW>=Jd00S6<0SF]0S6<0be[00HYBRe[<H`aS2e[9BT3:DX012DY8@PU:B480RU:00<]JbU:
:DX00Re[00<YBR487>L00R4811cW0R4800LLiaS67>LQ22DY8@PLi`028@P00acW8@PLi`027>L00aS6
7>LLi`038@P01RDY8@PLiacW8@PU:@<Q20@Li`036<HLib4800<U:@8YBP03;F/YBRU:00DQ20<U:@0;
8@PU:Be[<H`]JbU:;F/aS2e[9BTQ20029BT01acW9BTYBRU:9BTLib48008Li`036<HDYAS6008Li`03
9BTQ22DY00DU:@038@PLiacW00@DY@036<HDYAS6008Li`048@PLibDY8@P46<H011cW6<HLiacW1248
00TLiaS66<HQ22U:8@PLiaS68@P00acW00XQ22DY8@PYBRe[<H`icS6<;F/U:@8Li`8HaP037>LQ2248
00@Li`8HaP@Li`<HaP037>LHaQcW008HaP035:DHaQcW00DQ20039BTQ224800<Li`038@PHaQS600<D
Y@037>LHaR4800<Q20056<HLiacW7>LQ20026<H27>L01B487>LHaQS67>L00b480QcW00DQ22DY8@PU
:AcW00DHaP035:DHaQBU00@HaP038@PLiacW008Q20039BTLib48008Q20037>LHaQBU00@DY@<@Q08D
Y@8HaPDLi`<HaP037>LHaQBU008HaP055:D@Q12448@DY@0448@02ABU48@<H`aS48@<HaBU48@DY@02
48@02PaS48@<H`aS48@DYAS67>LHaQBU0Q240aBU0a2400<DYA2436<01ABU00<@Q1S65:D00QS600@L
iaS65:DDY@<@Q0046<HLiaS65:D448@011BU48@@Q1240`aS00@@Q1BU48@@Q08<H`8@Q0075:D@Q1BU
48@DYA245:D0112400TDYAS65:D@Q1BU6<HQ21cW5:D0112400<DYA245:D00QS600HDYA245:DLiaS6
5:D248@35:D00aS648@@Q00236<00a245:DDY@0748@45:D448@45:D348@35:D248@010aS48@DYABU
0Q240aBU00@@Q1BU5:D@Q0<DY@<@Q0035:D@Q0aS00L@Q08<H`0348@DYABU00@@Q08DY@086<HDYA24
5:D@Q1BU48@DY@D@Q00336<@Q1BU008@Q08<H`0648@<H`aS248<Ha2410aS0Q241`aS00D@Q0aS36<<
H`Q2008<H`<8@P<<H`88@P@<H`03248<H`aS00@8@P<<H`@@Q0@<H`0348@<H`Q20088@P4<H`48@P4<
H`0000H48@00124000@Q000212402@Q212448@Q2:DYS64YB:DXaS002=Jd01CW><H`aS3W>?Nl00T8@
00Le[Be[=JdicSg_>Lh]J`02<H`02Re[9BTYBRe[:DXU:CF]?Nm243g_0Re[00@YBRe[<H`]J`8aS08e
[@DicP03=JdaS36<00HaS006;F/YBSF]>Lhe[Be[0RDY0RU:00@U:B488@PU:@<YBP8U:@8YBP039BTQ
21cW008Q208Li`056<HLiacW7>LQ20027>L00b487>LQ20027>L28@P00bDY7>LLi`027>L01B487>LQ
22487>L00R4800<Lib489BT00RDY00<Q21cW7>L00QcW0b4812DY00DYBRe[:DXYBRDY008Q20<U:@06
8@PU:B488@PU:Be[0S6<00@]JbU::DX]J`@U:@03:DXU:B4800<Q20@HaP037>LQ2248008Q208U:@06
8@PU:BU:9BTQ21S611BU00HHaQBU6<HHaQcW6<H28@P29BT26<H00aBU6<HLi`037>L48@P47>L00b48
7>LQ20028@P57>L28@P02BU:<H`icSW><H`U:B487>LHaP067>L00b486<HHaP026<H27>L26<H011BU
6<HLiacW0QS600@LiaS66<HHaP8Li`038@PU:BDY008Q20057>LHaQS65:DQ20027>L26<H25:D01B48
7>LU:BDY8@P011cW00DHaQcW7>LLib48008Li`8HaP037>LQ21cW00@Li`8U:@048@PLiaS65:D36<H0
0aBU6<HHaP026<H25:D26<H29BT00b487>LHaP038@P26<H25:D348@010aS48@DYABU0aS60QcW00<H
aQBU5:D011S600<DYAS66<H00QS60QBU1Q240QBU00@@Q0aS36<<H`8@Q08DY@0448@<Ha245:D248@2
5:D26<H248@011BU48@DYA240aBU0Q2400DDYAS66<HDYA2400@DY@@HaP8DY@8@Q0045:DHaQS66<H2
48@25:D348@00`aS48@@Q00548@536<248@25:D011S65:DDYABU0a240aS600<DYAS67>L00QS600<@
Q1BU36<00Q2400@DYAcW7>LDY@8@Q0035:DHaQcW008DY@036<HDY@aS008@Q0045:D@Q0aS36<548@2
36<011BU48@DYA241ABU0PaS00<@Q1BU6<H00a2411BU112400<DYA2448@00Q241aBU1a2400D<Ha24
5:DDYA24008<H`0348@<Ha24008@Q08DY@<@Q00436<DYA2448@25:D01A245:D@Q1245:D00Q240PaS
00D@Q1BU48@DY@aS008@Q0/<H`0348@<Ha2400<<H`04248<H`aS48@436<00`Q236<8@P0936<22483
36<00`Q236<8@P0536<248@25:D436<01A2436<<H`Q236<00@Q2000;12401@Q2<HaS64Ha;F/00cW>
00@e[C6<=JdicP8mk`8icP08?Nm243g_=JdaS2e[:DXaS08]J`05:DX]Jc6<=JdicP02=Jd00cW><H`a
S003<H`02bU:9BTU:CF]?NlicT8@?NlicT8@;F/00RU:0c6<00L]JbU:<H`aS3F]<H`]J`04<H`29BT0
12487>LQ22DY0RU:00LU:AcW7>LLib48:DXU:@028@P00acW6<HLi`037>L36<H01b489BTU:AcW5:DH
aR48008YBP059BTLiaS67>LQ20029BT47>L26<H022489BTQ21cW6<HLib489BT37>L00aS69BTU:@02
9BT00b489BTU:@029BT00acW6<HLi`028@P011cW8@PQ22U:12e[00@U:BU::DX]J`8YBP@Q20057>LQ
22487>LHaP027>L01R487>LQ22489BTQ208U:@8YBP039BTLiacW008DY@8Li`058@PLiaS66<HDY@02
6<H27>L36<H00acW8@PLi`047>L48@P37>L011S67>LDYAS60QBU0QS60acW00`Q22DY8@PYBSF]?Nla
S2U:6<HQ22DY8@P57>L26<H27>L011S65:D@Q1240QBU0acW0QBU00@HaQcW7>LHaP8Li`058@PLib48
8@PLi`056<H25:D01AS65:DHaQBU6<H00acW00@Q21S66<HHaP<Li`8HaPPLi`076<HQ22U:;F/U:AcW
6<H00QcW00DDYAS67>LLiaS600HDY@8Li`<HaP<Li`036<HDYA2400@DY@8@Q00336<@Q124008DY@8H
aP097>LHaQS67>LQ21cW5:DHaQBU008Li`036<HDYABU008HaP055:D@Q1245:D@Q00236<248@236<2
48@236<35:D01A2436<<Ha245:D00a2411BU0a2400<DYAS66<H00QS60aBU0QS60QBU0QS600<DYA24
5:D00QBU0PaS00D@Q1cW6<HLiaS6008DY@0648@<Ha2436<@Q1BU0a2400<<Ha2448@01Q240QBU00<H
aQBU6<H00aBU11240QS600@LiaS65:D@Q08DY@@@Q0035:DHaQS6008HaP035:DHaQS6008DY@8@Q08D
Y@8@Q08<H`0348@<Ha24008DY@8@Q00436<@Q12448@35:D336<35:D348@35:D248@011BU48@@Q1BU
31240QBU1A240aBU0Q2400D<Ha2436<@Q0aS00<@Q08<H`8@Q0035:D@Q124008@Q08DY@0548@DYABU
48@DY@0248@021BU48@@Q0aS48@HaQBU48@236<01A2436<<H`aS48@010aS00<@Q0aS36<00PaS00<4
8@Q224800`aS00<8@PaS36<00`Q200<<H`Q236<00PaS00@@Q0aS36<8@P8<H`03248<H`Q200@<H`0:
248<H`Q2248@Q1BU6<HDYA2436<348@00`Q21248@P0236<00008124000@Q00048@001248@P848@07
0008@SF]Kg]>Lbe[=Jd00Sg_0SW>00<e[C6<=Jd00SF]00@mkcW>>Lhmk`8e[@07;F/aS2e[:DX]JbU:
;F/00c6<00le[Cg_@Q1243W><H`e[C6<;F/YBRDY:DXaS3W>@Q000Sg_00<icSF]=Jd01Re[0c6<12e[
00DaS2e[9BTYBRDY008Q20059BTYBRDY9BTQ20029BT28@P39BT01AcW6<HHaQS68@P011cW00<Q21cW
8@P00R480acW00@Q22DY8@PQ208Li`8Q208Li`046<HLiacW9BT28@P27>L01aS67>LQ22489BTQ21cW
008HaP057>LU:B488@PLi`048@P27>L02QS68@PQ22487>LQ22DY;F/aS2e[0bU:00H]Jc6<;F/U:B48
7>L38@P011cW6<HHaQS60QcW0R4800@U:B488@PQ208U:@8YBP039BTLiaS600<HaP<Q20047>LHaQBU
5:D27>L26<H02QBU6<HQ22DY8@PHaQcW8@PYBR480QS60acW00DHaQcW7>LLiaS6008DY@8HaP047>LH
aQS67>L28@P2<H`01SW>=JdYBRDY8@PU:@8Q20DLi`046<HLiacW6<H25:D011245:DHaQcW0QS60QBU
00@LiaS66<HHaP<Li`8Q208Li`8DY@8Li`036<HDYABU00<HaP045:DHaQcW9BT27>L26<H77>L01AS6
7>LQ22487>L00QS600TLibDY:DXYBRDY7>LQ21cW6<H00acW00@HaQBU48@HaP8@Q08DY@037>LQ21cW
00DLi`<DY@0448@DYABU5:D348@011BU48@@Q1BU0acW00HHaR488@PLiaS65:D27>L01AS67>LLiaS6
7>L00QBU0a2400<DYA2448@02A2400<DYA2448@00PaS0Q240QS600D@Q0aS48@@Q1S600DDY@@HaP8D
Y@0548@DYA246<HDY@036<H00aBU6<H@Q00348@25:D011S68@PLiaBU0`aS00@@Q0aS36<<H`8@Q08D
Y@0448@<Ha2448@95:D26<H35:D01A245:DHaQcW6<H00aBU11240QBU0Q240QBU0QS600<LiaS66<H0
112400PDYA2448@@Q0aS48@DYA240aBU0a2400<DYA245:D00a240PaS0Q2400<HaQBU5:D00QBU1124
0QBU0Q240PaS112400DDYA2448@<Ha2400<DY@8<H`0548@DYA2448@DY@0248@236<248@011BU36<<
H`aS0Q2400@<Ha245:DDY@<@Q0035:D@Q124008@Q0035:D@Q12400<@Q0035:D@Q1BU008DY@<@Q0<<
H`<@Q003248<H`aS008@Q00536<8@PaS36<@Q00:36<00`Q236<<H`0236<00a2436<<H`0436<01@Q2
36<8@PaS48@00`aS00@8@PaS48@@Q08HaP0948@<H`aS48@DYA2436<8@PaS0048@P0000<000@Q1240
0`@Q00<000@Q24800P@Q00H8@S6<LiaF]C6<AS42@Q02>Lh00cg_>Lhe[@02>Lh2<H`02be[<H`aS36<
:DXU:BU:;F/e[Cg_>Lh00Re[00DU:B48<H`e[Cg_008icP07?NlicSW><H`YBRe[<H`00SF]00<aS2e[
<H`00S6<00L]JbU:;F/]JcF]<H`]J`02:DX29BT022U:9BTYBRU:;F/U:B489BT3;F/00bU:9BTLi`04
8@P27>L012486<HHaQS60QcW0R480aS611cW0b480QcW0b480bDY00<Q21S67>L00R4821cW0R4800@L
iaBU6<HLi`8Q20047>LHaQcW7>L38@P27>L03R487>LLiacW6<HQ22DY:DXU:B48:DX]Jc6<:DX29BT0
1R487>LHaQcW8@PLi`8HaP8Li`036<HQ224800<U:@03:DXQ21cW008Li`<U:@057>LHaQcW8@PU:@03
8@P011cW6<HLiaBU1QS60QcW00@HaQcW7>LQ20<U:@@Li`066<HLiacW7>LHaQBU1aS600<Q21cW8@P0
0RU:0SF]0Re[12DY00HQ21cW7>LLiaS67>L26<H35:D26<H00acW5:DHaP037>L00aS65:DHaP057>L0
1QS67>LHaQS65:DHaP8Li`086<HDYABU5:DHaQcW6<HLi`8DY@8HaP058@PLiaS66<HLi`029BT01248
9BTLib480QcW0b480RDY00TLiaS65:DHaQcW8@PLiaS648@011BU0aS600DDYAS65:DHaQBU008HaP03
7>LHaQBU008DY@0448@DYAS66<H348@01@aS6<HLib486<H00QBU00LLib489BTU:AcW6<HLi`026<H3
5:D348@011BU48@DYA240QBU0a2400@DYA2448@@Q0<DY@0548@DYA2436<DY@026<H00aBU36<@Q003
5:D01A245:D<H`aS5:D00QcW00<DY@aS5:D00aBU00<HaQBU5:D00a2400@DYA245:DDY@8@Q0<HaP04
5:D<H`aS5:D348@010aS48@@Q1BU1A2400HDYA245:D@Q1BU48@25:D00aS65:DHaP0248@01QBU7>LQ
22486<HDY@8@Q0055:D@Q12448@HaP025:D448@01ABU6<HHaQS65:D00a2400D<Ha2448@DYA24008<
H`0348@DYA2400L@Q0<<H`8@Q08<H`0648@<Ha245:D@Q1S611BU11240PaS0Q2400HDYA2448@@Q1BU
48@35:D348@25:D0112436<@Q1BU3a2400T<Ha245:D@Q1BU48@<Ha2436<00a240PaS00D@Q1BU48@@
Q0aS00@@Q0<<H`H@Q0@<H`04248<H`Q236<248@436<248@00`aS2488@P0236<00a2436<8@P032485
36<00`Q236<<H`0336<011246<HDYA240PQ200<<Ha2436<00`Q20A240@aS000312400`0012400002
12402PQ200048@aS=JecW5:D=Je244Ha0d8@0cg_0SF]0S6<12e[00DYBRDY:DXYBS6<008icP03=Jda
S2DY008]J`07<H`e[C6<=JdicSg_>Lh00c6<0Re[0S6<0SF]0S6<0be[0c6<00<]JbU:;F/00RU:0bDY
00<YBRDY9BT00RDY12e[00<YBRDY8@P01B480acW0aS600<Lib488@P011cW00DQ21cW7>LLib48008U
:@038@PU:B48008U:@8Q20DLi`@Q20@Li`038@PLib4800<Li`8HaP047>LQ22DY:DX28@P011cW8@PQ
22480acW0R4800<U:B489BT00RDY00@aS2e[9BTU:@HLi`8HaP037>LHaQcW008Li`049BTQ22U::DX5
8@P00bDY8@PQ20037>L49BT27>L25:D021cW6<HLiaS65:DHaQBU6<H27>L02AS67>LLib489BTYBR48
6<HLi`028@P46<H00acW6<HHaP026<H051cW5:DHaQcW8@PYBRDY<H`icSF]<H`U:BU:;F/YBRDY7>LQ
21cW8@P26<H00aBU6<HDY@025:D37>L00aBU6<HLi`027>L00aS65:DHaP038@P01AS67>LLiaS67>L0
0QS60acW00LHaQBU5:DHaQBU6<HLi`026<H25:D00aS67>LLi`037>L28@P37>L01RDY7>LLiacW9BT]
J`8U:@038@PHaQBU008HaP057>LHaQBU5:DHaP035:D01aS65:DDYAS68@PLiaS6008DY@047>LHaQS6
6<H25:D26<H35:D01A2436<@Q1BU6<H00QcW00<DYAS68@P00RDY1AcW0QS600@DYA245:D@Q08DY@<@
Q0035:D@Q1BU008DY@T@Q08DY@<@Q08DY@0348@<Ha2400<DY@0536<DYAS66<HDY@0248@01ABU48@@
Q1BU6<H011BU112400HDYA2448@LiaS65:D336<01a2436<@Q1245:D<Ha2400<DY@<@Q0035:D@Q1BU
00<@Q08DY@046<HDYABU5:D36<H011cW8@PHaQBU112400<DYA246<H00QS60QBU0Q240QBU00DHaQBU
5:DDY@aS00<@Q0075:D@Q12448@<Ha245:D01A240`aS00@@Q0aS36<<H`@@Q00736<@Q1BU48@DYA24
6<H00QBU0Q2400<DY@aS36<00PaS0QBU11240aBU00<@Q0aS48@00QBU0Q2400<DYA2448@00PaS00@D
YA245:DDY@L@Q00436<@Q12448@25:D00a245:D@Q0025:D948@35:D336<0112436<@Q0aS0Q2400<D
YA2436<00PaS0PQ20PaS00<DYA2436<00PQ200D<Ha2436<<H`Q2008<H`045:D<H`Q2248248@22482
36<010Q236<@Q1240PaS00D8@PaS5:D@Q1BU00H<H`04248<Ha2448@12480000300048@@Q00D48@09
24848@00248]JfmkE[DicTHa009:DP03@Q16<DYB00=2408mk`05>LhaS36<:DX]J`02:DX01be[<H`a
S3W>=JdaS2e[008YBP04<H`e[CW>>Lh4=Jd013W>=JdaS2U:0Re[00TYBSW>?NlmkcF]:DX]Jc6<;F/0
0c6<00HYBRDY8@PQ22DY8@P2:DX01RDY8@PQ22DY;F/e[@8aS005;F/YBRDY9BTYBP029BT37>L00aS6
7>LHaP027>L38@P37>L38@P00bDY8@PU:@029BT00b489BTU:@029BT00acW8@PLi`028@P00bDY8@PU
:@029BT37>L38@P01aS67>LLiaS67>LHaR4800@U:@038@PU:B48008U:@<YBP0?9BTLiacW8@PU:BU:
9BTYBS6<:DXU:AcW8@PU:B4800DLi`8Q208HaP047>LYBRDY8@P27>L39BT38@P39BT01B487>LQ22DY
8@P00QS600<LibDY8@P00QS60acW0QS60aBU00<HaQcW7>L00b480QcW00HDYAS67>LHaR487>L38@P0
0aS65:DDY@026<H01AcW6<HLib487>L00Re[00HicTHa=Jd]Jb487>L28@P47>L00aS65:D@Q0025:D0
0acW6<HHaP037>L011BU6<HLib480acW00<Q21cW7>L00QcW11S600DLiaS67>LLiaS6008DY@036<HL
iaS600@HaP035:DLiacW008U:@038@PLib48008U:@06:DXU:B488@PLib480QcW2AS600DLiaS65:D@
Q1BU00<Li`046<HDYABU5:D27>L00aS65:DDY@0248@35:D248@011BU6<HHaQS611BU00@LibDY:DXY
BP8Li`036<HLiaS600<DY@8HaP055:D<H`aS36<@Q0035:D01aS648@<Ha245:DHaQBU008@Q0045:D@
Q12436<25:D011245:D@Q1S60QBU00D@Q1BU36<@Q1S600<Li`@@Q0035:D@Q12400@@Q0@DY@8@Q08H
aP067>LHaQ2448@DYA241QBU00DHaQBU48@<Ha2400<DY@<@Q00336<DYABU00<@Q0035:DLiacW008L
i`0;6<HDYABU5:D@Q1S648@HaQcW6<HDY@0348@00aBU48@DY@025:D448@00`aS48@DY@0348@010aS
48@@Q1240aBU00D@Q0aS36<@Q1BU00H@Q08<H`0448@DYABU5:D248@25:D348@011BU48@@Q0aS0a24
00<<Ha2448@00QBU0QS60Q2400<<Ha245:D00QBU0Q2400<<Ha2448@011240QBU112400@<Ha2448@D
Y@8@Q08DY@@@Q0035:D@Q124008@Q00736<@Q12448@<Ha2436<00Q241@aS11240`aS00<8@PaS36<0
10aS00<@Q0aS36<01@aS10Q20PaS0Q2420aS0Q2400DDYA2448@<Ha24008<H`88@PD<H`48@P000P@Q
00H000@Q00048@00248312402@Q2<HaW>DYB<Ha6<DicAS524002BU800dHa@Q0mk`03@Q000cW>=Jd]
J`02:DX2;F/02RU:<H`icSW><H`YBRDY:DXaS2e[0S6<00<icSg_>Lh00S6<00@]Jc6<<H`]J`8YBP05
<H`e[Cg_?Nle[@02;F/00bU:=JdaS003;F/01bDY7>LLib48:DX]JbU:008U:@038@PYBRe[00<aS08]
J`03:DXU:B48008U:@098@PLiacW7>LDYAS68@PU:B4800<Li`068@PLiacW7>LQ22DY0RU:1BDY00<Q
22DY7>L00R480RDY0R4800@U:BU::DXU:@8Li`8Q20039BTQ21cW00<HaP@Q20<U:@03:DXU:BDY008U
:@03:DXU:AcW008Li`<U:@8YBP03;F/U:BDY008U:@8Q200;7>LQ22488@PLiaS67>LQ22DY7>LQ2002
9BT00b487>LQ20048@P012DY8@PLiacW0R4800@U:AcW6<HHaP8Li`8Q20<HaP037>LHaQS6008DY@03
6<HDYAS6008Li`048@PLiacW7>L26<H00aBU6<HLi`027>L01b487>LQ21cW6<HDYAS600<Li`8HaP03
8@PU:CF]008icP03<H`YBRDY008U:@DLi`076<HDYAS65:DHaQBU6<H011cW00DHaQcW6<HHaQcW008H
aP@Li`<HaP<Li`8HaP065:DHaQcW6<HLiaS60QBU00DHaQ245:DHaQcW008U:@<Q200:7>LQ22DY9BTQ
21cW8@PU:B487>L35:D46<H00aBU6<HDY@035:D26<H27>L00aBU6<HDY@026<H01QBU6<HHaQS65:D@
Q08DY@8HaP065:D@Q1BU6<HLiaS60QBU0aS60bDY00<LiaBU6<H01AS600@DYA2448@DY@8<H`0548@D
YAcW6<H@Q0025:D01Q245:DDYABU48@DY@8@Q0075:D@Q1245:D@Q1BU48@00QBU0a2400D<HaS67>LU
:AcW008@Q08<H`@@Q08DY@8@Q0055:DHaQBU48@<H`0248@00acW6<HHaP0248@00`aS5:DDY@0248@0
1ABU6<HHaQBU48@00`aS1a240QBU00H<Ha2448@HaQBU6<H37>L01ABU48@HaQBU48@00QBU0QcW00DH
aQ2448@<HaBU00@@Q0035:D@Q12400L@Q08DY@8@Q08DY@8@Q00336<@Q1BU008DY@0336<@Q124008@
Q08<H`0348@DYABU00<@Q0035:D@Q0aS00D@Q00536<@Q12448@<H`0348@011BU48@DYABU1a2400<D
Y@aS36<00PaS1A2411BU0PaS1ABU0Q2400<DYA245:D00a240PaS0Q240`aS00<@Q0aS48@00Q2400@<
Ha2448@<H`88@P0336<DYA24008<H`0348@<Ha24008<H`88@P0536<@Q12436<8@P0436<424800`aS
248<H`0:36<011BU6<HHaQBU10Q210aS0PQ200000`0012448@05124030Q200048@Q2<HaW>DYB;F/m
kdYBAS5:DP9>L`07BU96<DHaAS5243g_=Jd00c6<0SF]00LaS3F];F/YBRe[:DX]J`02<H`00cF]>Lhi
cP05=Jd012e[<H`aS2e[0RU:0be[00HaS3W>?Nlmkc6<=Jd3<H`2:DX012DY:DXaS36<0Re[12DY0RU:
00D]JcF]<H`aS2e[008YBP8U:@038@PYBR48008Li`035:DLib48008U:@HQ20037>LQ224800HQ2003
9BTQ21cW008Q208YBP03;F/YBRU:00DYBP049BTLib487>L38@P012DY8@PU:BDY0bU:00@U:B489BT]
J`8aS0@YBP059BTLibDY8@PU:@02<H`00bU:9BTQ20029BT38@P00bDY:DXU:@028@P26<H011cW8@PQ
22480QcW0RDY00<YBR487>L00QcW00@U:BU::DXU:@@Li`036<HLiacW00<HaP<Li`8HaP<DY@056<HL
ib488@PLi`026<H011BU7>LLiacW0QS600LDYB48:DXYBR485:D@Q0076<H02AcW9BT]Jc6<;F/icSF]
>Lhe[@02;F/01AcW6<HHaQBU7>L00aS600LLiaS67>LHaR487>LQ20047>L36<H27>L26<H00acW8@PL
i`027>L011S67>LLiacW0QBU00@HaQcW7>LLi`@DY@8Li`<U:@04:DXU:BDY7>L36<H00acW6<HHaP02
7>L28@P27>L021BU7>LHaQS65:D@Q1BU6<H27>L35:D02AS65:DDYAS65:DHaQBU48@DY@0248@00aS6
8@PLi`035:D00aS67>LHaP026<H25:D02QS67>LLiaS68@PU:B486<HDYA241AS600@DYA2448@<H`<D
Y@0448@<Ha245:D448@25:D348@00aBU6<HDY@035:D02a245:DDYABU36<@Q1S67>LQ21S65:D00QS6
00<DY@aS36<01A2400@HaQBU5:DDY@8@Q0096<HQ22487>L@Q0aS48@DYA24008DY@8@Q00336<@Q1BU
00<@Q0035:D@Q124008<H`0348@DYAS6008DY@046<HDYA245:D38@P00acW5:DDY@046<H248@25:D0
0aS65:D@Q00448@010aS48@@Q1BU0Q2400@<Ha2448@@Q0<DY@0348@<HaBU008DY@8<H`0348@DYA24
008@Q0065:D@Q12436<@Q0aS0a2411BU1Q240PaS2A2400<DYA2448@00PaS0Q2400<DYA2436<00PaS
00L@Q0aS48@@Q0aS48@<H`0448@010aS48@@Q1BU0a2400@DYA2448@<H`<@Q08DY@0448@<H`aS36<4
48@01QBU36<8@PaS5:D@Q0<<H`@@Q00336<@Q0aS00<<H`@@Q0<<H`0348@<H`aS00@8@P@<H`88@P8<
H`0548@<H`aS36<@Q0025:D248@00`Q236<<H`0536<00a2436<<H`01248000848@0400048@@Q0005
12401`aS=Je[FTYB;F/mkdYB00924003BU9>LdYB00E6<@8e[@03;F/aS3W>008icP03<H`]JbU:00<Y
BP04;F/aS3F]<H`2>Lh01cF]>Lhe[C6<=Jd]Jc6<00<YBP8]J`05:DX]Jc6<=JdicP03=Jd2<H`012e[
:DXYBRDY0Re[00DaS2e[;F/]JbU:008Q20079BTaS36<=Jd]JbU:9BT00bU:12480QcW0R480RDY00`Q
21cW8@PQ21cW8@PU:BU:9BTQ21cW8@P27>L012DY:DXU:AcW0QS600<YBRDY:DX01BU:00H]JbU:9BTU
:B489BT28@P00acW8@PU:@02:DX01BDY:DXU:BU:9BT00RU:0Re[00@YBRe[9BTU:@8Q20079BTQ22DY
:DX]Jc6<;F/00RDY0R480bDY0RU:00HU:B487>LLib489BT88@P00bDY8@PQ20029BT012U:9BTQ2248
0acW0R4800@HaQBU6<HLi`8HaP035:DHaQS600@HaP@Li`046<HLiacW7>L46<H021cW8@PU:BDY8@PL
iaS65:D26<H01AcW5:DDYAS68@P00RU:00h]JbU:<H`icSg_>LhaS2DY8@PDYAS67>LHaQcW11S60QcW
00<Q21cW7>L00acW0aS600@Lib487>LHaPDLi`@HaP<Li`8HaP045:DHaQcW6<H25:D37>L01bDY;F/]
JbU:7>LQ21cW00<DY@DLi`036<HDYAcW00<Li`8DY@0348@DYAS6008Li`056<HDYA245:DHaP025:D4
6<H01a245:DDYA245:DLiaS600<DY@057>LHaQBU6<HLi`036<H00acW8@PQ20028@P26<H25:D00aS6
5:DDY@065:D548@00aBU48@@Q00248@011BU48@@Q1241aBU0a240PaS00@@Q1S68@PQ208HaPL@Q08D
Y@@@Q0095:D@Q1S67>LQ21S65:D@Q1S6008@Q0035:DHaQBU00<@Q0035:D@Q12400@@Q08<H`<@Q003
5:D@Q124008@Q0055:DLibDY9BTLi`055:D00a245:DDY@026<H00aBU48@@Q00348@01PaS48@@Q124
36<@Q08DY@H@Q08DY@0348@DYA24008@Q00536<@Q12448@DY@0348@636<248@35:D00a2436<8@P03
48@25:D00a2436<@Q0025:D348@25:D01Q2436<<H`aS48@DY@@@Q00336<@Q124008@Q0@<H`<@Q08D
Y@0348@DYABU00@@Q0035:D@Q0aS00D@Q00336<8@Q2400<@Q08<H`<@Q0@<H`8@Q00736<@Q12436<@
Q0aS48@00`aS00<@Q0aS48@01`aS0`Q20`aS0PQ20`aS00<@Q0aS24800PaS0Q242@aS0Q240PaS0004
1240300012448@@Q24848@00248aS6]JE[De[@A24004?Nm2448@?Nl3AS401Cg_=JdaS36<>Lh00S6<
0Re[136<0be[0SF]0cg_0cW>00@aS2e[9BTYBP8aS005;F/YBRU::DX]J`05<H`2=Jd2:DX00bDY;F/]
J`02;F/00bU:;F/aS002;F/01BU:;F/]Jc6<:DX00be[00@YBRDY8@PQ20HLi`8U:@8Q20037>LQ22DY
008U:@03:DXU:BDY008Q208U:@DQ208Li`098@PYBRe[:DXU:BU:<H`]JbU:008U:@048@PU:BU:;F/2
9BT01R48:DX]Jbe[9BTYBP<aS006;F/YBRU:9BTYBRDY1BU:0RDY0R4800@YBS6<;F/]J`<Q20037>LQ
22DY00<U:@@Q20079BTQ22DY:DX]JbU:9BT011cW00DQ22DY8@PQ21S6008Q20TLi`<HaP@Li`038@PL
iacW00<Li`036<HLib4800LLi`8Q20DLi`8DY@036<HQ224800DU:@09:DXaS3g_?Nle[C6<9BTQ21cW
008Q20047>LHaQS67>L38@P27>L01AS67>LLiacW6<H00acW0aS600PU:B488@PQ22DY8@PLiaS60QcW
00@HaQBU5:DHaP8Li`<DY@056<HYBRDY9BTYBP029BT00b487>LHaP025:D26<H39BT01B487>LQ2248
9BT00QcW00<DYA245:D00QS600<LiaS65:D00QS600`DYAS68@PU:AS65:D@Q1S65:D@Q1BU6<H28@P2
7>L36<H00acW6<HHaP056<H01BDY:DXYBR4848@00QBU00<HaQBU6<H00aS60QBU00<@Q1BU5:D01124
00<<HaBU48@0112400<<HaBU5:D00QS600<DYAS65:D00QBU00HHaQcW6<HDYAS67>L28@P25:D236<3
48@01ABU48@@Q1245:D01A2400DLib488@PQ21BU008@Q0<DY@@@Q08<H`<@Q0045:D<H`aS36<248@0
0aBU48@@Q0025:D02aS65:DDYAcW8@PLia245:DHaQcW6<H011BU0a240QBU1Q240PaS0Q240QBU0Q24
00LDYA2448@@Q1BU6<HDY@0536<348@35:D248@00`aS48@@Q00448@00aBU48@HaP0248@236<00a24
5:D@Q00348@25:D248@00aBU6<HDY@0348@00aBU48@<H`0248@236<648@236<01A245:D@Q12436<0
0aBU00<<Ha2448@00a240QBU0Q2400<DYA2448@00`aS00<DYAS65:D00PaS00@@Q1BU48@@Q0D<H`8@
Q08<H`@@Q003248<Ha24008@Q004248<H`aS248436<00`Q236<<H`0336<348@2248336<0112436<<
H`Q21`aS00@@Q1BU5:D@Q048@P0000@48@00124000@48@09248000@Q248aS6LiBU8aS3g_0096<@92
40<mk`A2408e[@8aS003>Lhe[C6<008]J`03:DX]Jbe[00@aS008=JdicSg_?NlicS6<=JdaS08]J`8Y
BP04;F/aS2e[;F/2:DX0136<=Jde[CF]0c6<00@]JbU:;F/YBP8aS08]J`8YBP<]J`03<H`]Jbe[008]
J`07<H`]Jbe[9BTYBRDY8@P00QS60QcW00<Q22DY8@P00R4800<Lib488@P00b4800@YBRDY9BTU:@8Q
20<U:@8Li`066<HLib488@PU:BU:0Re[00@YBRe[;F/YBP8U:@088@PU:BDY:DXQ22DY:DX]J`@YBP04
<H`]Jbe[<H`2:DX01BDY8@PU:BDY;F/00bU:00L]JbDY8@PQ22U:<H`]J`039BT00b489BTQ20028@P0
12DY8@PQ22DY124800/U:B489BTQ22DY8@PLiaS67>LQ22DY008Q20037>LHaQcW008Li`058@PLib48
7>LQ20026<H87>L38@P47>L28@P00acW6<HLi`027>L00b487>LDY@026<H28@P00aS65:DDY@027>L0
0bDY:DXYBP039BT02RU:<H`aS48@?NlaS2U:8@PU:B480QcW0QS600@Lib489BTQ20@Li`046<HLib48
8@P37>L01AS67>LQ22DY8@P00acW00<Q21cW6<H00QS600DDYAS67>LLiaS6008DY@036<HLiacW008Y
BP069BTYBQcW7>LHaQ240aS600LQ22DY9BTU:B487>LQ20039BT011cW5:DHaQ240QS600<LiaS65:D0
0QS60QcW1AS60aBU0QS60QBU0QcW00LQ21S65:DDYAS67>LQ20027>L26<H67>L45:D36<H00aBU6<HD
Y@045:D00a245:D@Q00348@010aS48@@Q1241ABU00<HaQBU6<H00QBU0aS600DDYAcW8@PQ21S600D@
Q08<H`0448@DYABU5:D348@00`aS6<HLi`027>L75:D248@020aS48@@Q0aS48@DYA245:D248@336<3
48@02aS65:D@Q1BU7>LU:AcW5:D@Q1BU6<H00aBU0Q240QBU00@@Q0aS36<@Q08DY@8@Q08DY@0536<@
Q1246<HDY@0348@00`aS48@DY@025:D348@236<248@25:D848@45:D00a245:D@Q0025:D01Q2436<<
Ha245:D@Q08<H`0548@DYABU48@DY@0248@00aBU48@@Q00548@00aBU48@@Q00236<548@336<00a24
6<HDY@025:D348@010aS48@@Q1240QBU00X@Q1BU48@DY@aS248<HaBU7>LDY@<<H`L@Q00336<8@PQ2
008@Q08<H`0348@<Ha2400<@Q00336<8@PQ2008<H`0348@<H`aS008<H`88@P<<H`8@Q0D<H`<@Q0H<
H`88@P8<H`0348@<H`aS004<H`0000<000@Q12400P@Q00@000@Q1248@P848@08248aS6LiBU8]Jcg_
AS5240@mk`924008?Nle[CF]<H`e[CW>=JdaS08]J`@YBP049BT]Jc6<<H`2?Nl2@Q002c6<;F/YBRU:
<H`YBRDY8@PU:BU:;F/00RU:00@]JbU:<H`]J`DaS006;F/YBRDY:DXaS2e[0S6<00D]JbU:;F/]Jc6<
008]J`03:DX]JbU:008YBP03;F/aS2e[008U:@057>LHaQS66<HLi`028@P27>L00b487>LU:@039BT2
7>L28@P29BT01R489BTU:B487>LQ20<U:@038@PU:BU:008U:@038@PU:AcW008Li`038@PYBRe[00<]
J`8aS003;F/YBR48008YBP<]J`8YBP@U:@048@PU:BDY9BT2:DX012DY:DXYBRe[0b480RDY0R480RDY
124800<YBR487>L00QcW00<U:B488@P00R4800TLiaS67>LQ22DY7>LHaQcW8@P00acW00<Q21cW7>L0
0acW00THaQcW8@PU:B487>LU:B489BT00b4800@Lib489BTU:@8Q20036<HLiacW008Li`046<HLiaS6
6<H87>L01R489BTYBRU:9BTQ208YBP<]J`05>LhmkcW>=JdU:@038@P00bDY7>LHaP026<H47>L012DY
8@PQ22480QcW124800<Lib488@P00RU:0QcW00<DYAS66<H00QS60acW0aBU0QS60QcW00<Q21cW7>L0
1AcW00DQ22U:<H`aS2e[008YBP05=JdicSF];F/Q20036<H00aBU6<HHaP026<H01ABU6<HHaQcW6<H0
0QcW1AS60aBU0QS600@LiaS67>LDY@8HaP048@PLiaS66<H27>L00aS67>LLi`037>L36<H011cW5:D@
Q1240QS600DDYAS66<HLiaS6008@Q0035:D@Q0aS008<H`0448@DYAS65:D26<H01AcW6<HHaQS65:D0
0aS600<LibDY8@P00R4800<DYA2448@00Q2400<<Ha2448@00QBU00D@Q1BU6<H@Q1BU008<H`0:48@H
aRDY:DXLiaBU48@<Ha245:D348@336<948@010aS5:D@Q1BU0a240aS60QBU00@@Q1BU48@DY@8@Q0<<
H`8@Q08DY@<@Q0<DY@8@Q0055:DHaQS66<H@Q0025:D348@02ABU48@@Q1245:D@Q0aS248<H`0248@0
0aBU48@@Q00648@01QBU48@DYAS65:DHaP<@Q08<H`8@Q0045:D@Q12448@25:D248@00aBU48@DY@02
5:D248@35:D00a2436<8@P0236<00aBU48@<H`0;48@011BU48@@Q0aS0Q2400HDYA245:DDYA2436<2
48@00aBU48@@Q0025:D01Q2436<@Q1BU48@<H`88@P0436<@Q12436<2248236<248@010aS48@@Q0aS
0PQ20PaS00@@Q0aS36<<H`88@PL<H`8@Q0<<H`<@Q00436<8@PaS48@236<00`Q236<@Q00236<148@1
36<136<000@48@0300048@@Q00<48@08000<Hbe[IcU>Lbe[>Lhmk`92400:?NlicSW>>Lhmkd8@>Lha
S3F]>Lh2=Jd4:DX01be[:DX]JbU:9BT]Jc6<00<icP04?NlicS6<<H`3;F/01BU:9BTU:BU:9BT00Re[
00LYBRe[:DX]Jc6<=JdaS002=Jd2;F/00bDY:DXYBP03;F/2<H`012e[<H`]JbU:12e[00<YBRe[;F/0
0Re[0RU:00<Q21cW7>L00acW00<Q21cW7>L00QcW0R4800@U:B489BTU:@@Q208U:@03:DXU:B48008L
i`039BTQ224800@U:@08:DXU:B487>LDYAS68@PU:@<YBP0:;F/aS36<;F/U:B489BTYBRe[:DX69BT0
0bU:8@PQ20029BT022U:9BTQ22489BT]JbU:9BT47>L012487>LQ22480RDY00<Q21cW8@P00QS60QcW
1B480acW00<Q21cW7>L011cW0b480QcW0QS600<Lib489BT00R4800@Lib489BTYBP8Q20047>LQ22U:
:DX29BT27>L26<H37>L36<H27>L36<H011cW6<HQ22480RU:00HU:B487>LU:C6<;F/2:DX00be[@Q0m
k`02<H`78@P27>L01AS67>LLib487>L00R4800<Lib488@P00R4800@U:B487>LQ208YBP058@PDYAS6
7>LDY@026<H27>L00aS65:DDY@026<H00acW6<HLi`048@P27>L03QS65:DU:Be[=JdaS2U:9BTaS3g_
AS4mkbU:7>L36<H37>L01ABU6<HHaR486<H00QcW00<Q21cW6<H00QS60QcW0aS600LDYAS67>LLiaS6
5:DHaP027>L26<H27>L26<H01AcW8@PU:AcW6<H00QBU00@HaQcW6<HDY@8HaP0:5:DHaQS67>LHaQBU
48@<Ha245:D436<25:D27>L26<H00aBU6<HHaP035:D01AS68@PU:BU:9BT00QBU0a240PaS00d@Q1BU
5:DDYAS65:DHaQBU36<@Q1BU48@Li`029BT012486<H@Q1BU0Q240PaS0Q2400DDYA2436<@Q1BU00D@
Q08<H`H@Q0035:DHaQS600@DY@8<H`8@Q0<<H`<DY@H@Q0<DY@036<HDYA24008@Q0<DY@046<HDYABU
5:D248@736<348@00aBU48@@Q00348@00aBU48@DY@035:D248@010aS48@@Q0aS21240QBU00<@Q1BU
5:D00a240aBU0a240`aS00<@Q0aS36<011240`aS00<@Q1BU48@00Q2400<DYA2448@00PaS0Q240aBU
00<@Q1BU48@00aBU00<@Q0aS36<00Q241@aS00@@Q0aS36<8@PH<H`0348@<H`aS008<H`0348@<H`aS
00D<H`03248<Ha2400<<H`8@Q08<H`04248@Q1245:D236<00`Q236<@Q00336<00`Q236<<H`0248@1
36<0000300048@0000P48@05248aS6LiDY@icP03AS401T8@>Lhe[C6<=JdicP@e[@05>Lhe[CF]<H`]
J`02:DX01Be[:DXYBRDY:DX00Re[00@aS2e[;F/]J`8aS005;F/aS36<;F/aS002;F/012DY:DX]Jbe[
0S6<0RU:0Re[0cF]0S6<00L]JbU::DXYBRe[:DXU:@02:DX012DY;F/]Jc6<0bU:0be[0RU:00<Q22DY
9BT00QcW00@HaR487>LLi`8Q20049BTLib488@P29BT01R487>LQ22489BTYBP8U:@@Q20067>LQ2248
9BTQ22DY0RU:00<U:B487>L00R4800@Lib488@PU:@8YBPL]J`03<H`]Jbe[008U:@DYBP8U:@03:DX]
JbU:00DU:@0;8@PLib489BTYBRDY8@PLib489BTQ2002;F/29BT37>L38@P01AcW6<HLib489BT00R48
00@U:BU::DXU:@8Q2005:DXU:AcW6<HLi`026<H48@P00acW8@PQ20047>L29BT012U:;F/YBR480acW
0QS600LLib487>LHaQ245:DHaP027>L00aS67>LQ20028@P00aS67>LQ20029BT28@P01BDY:DX]Jbe[
<H`00cg_0SF]00@aS2U:9BTQ208U:@DLi`038@PLiacW00@Li`8U:@0>:DXU:BDY8@PLib487>LDYAS6
7>LQ21cW6<H@Q08DY@8Li`036<HLib48008U:@8Q20037>LHaQS6008HaP8DY@097>LQ236<<Ha245:D
BU96<C6<008U:@057>LQ22U:;F/U:@027>L00b48:DXU:@028@P00acW6<HLi`025:D37>L00aBU48@D
Y@026<H27>L36<H01QBU48@HaQcW8@PLi`<DY@046<HLiaBU6<H27>L01ABU48@DYABU6<H00QBU11S6
00<DYAS65:D00QBU00P@Q0aS48@DYAS67>LHaQBU0QS600HDYAS66<HLiaS67>L39BT00b485:DDY@02
48@01ABU48@@Q1245:D011S600@DYAS65:DDY@8@Q00:7>LYBRU:8@P@Q0aS5:DHaQBU48@236<348@2
36<248@00aBU48@@Q00348@021BU48@<Ha245:DLiaBU48@25:D01AS648@DYAcW48@00`aS0Q2400<<
Ha2448@0112400@DYA2448@DY@<HaP035:D@Q1BU00<DY@<@Q0045:D@Q0aS36<248@236<348@00`aS
48@@Q0025:D448@35:D00aS65:DDY@0248@236<648@236<348@011BU48@DYABU0Q2400<HaQBU48@0
0`aS0Q240PaS11240`aS0a2400D<Ha2448@@Q1BU008@Q08DY@8@Q08<H`0348@DYA24008@Q0@DY@04
48@DYA2448@236<01@Q236<<H`aS48@00`aS0Q240`aS00<@Q0aS24800PaS0PQ200D<HaBU48@<H`Q2
00D<H`<@Q00336<@Q1BU008DY@0336<8@PQ2008<H`<@Q08<H`04248<H`aS48@136<000D48@040004
8@@Q248212403@Q2;F]W>Dic<H`mkdHaBU96<D8@>Lhe[CW>00@e[@8icP03=JdaS36<00<]J`HYBP03
;F/aS2e[00@aS0<]J`8aS0H]J`8aS005;F/YBRU:;F/e[@04<H`3;F/00c6<;F/]J`039BT2:DX01Be[
:DX]JbU:<H`00be[1BDY0acW0R4800<Lib488@P00R4800<LibDY9BT00RDY0QcW00<Q22U:9BT00R48
00<U:BU:9BT00R480bDY0QcW00DU:BU:;F/YBR48008Li`039BTQ2248008Q2003:DX]Jbe[008]J`<Y
BP03;F/aS36<008YBP039BTYBS6<008]J`DYBP03;F/YBRU:008U:@8Li`8Q208YBP059BTQ21cW8@PU
:@02:DX012487>LLiaS60b480acW00<Q21cW6<H00R480RU:00@U:BU::DXYBP<Q208Li`046<HDYAS6
7>L29BT47>L28@P02BDY8@PU:BU:9BTYBRe[8@PLi`026<H00b487>LLi`027>L26<H00aBU6<HHaP04
7>L01bDY:DXU:AcW5:DLib48008U:@038@PYBRU:00<icP8e[@8mk`09=JdYBR48:DXU:B487>LQ21cW
008HaP057>LU:B487>LHaP028@P00bDY:DXU:@049BT011cW6<HHaQS60QcW11S600`DYAcW7>LLiaS6
7>LQ22U:9BTQ21cW6<H55:D02QS6:DX]JdHaBU96<Dic@Q0e[Be[0QcW00@YBRe[;F/YBP8Q20079BTY
BRU::DXQ21cW6<H011cW11BU11S60QcW00@Q21cW6<HDY@8HaP037>LHaQ24008DY@8Li`8HaP057>LH
aQS65:DHaP035:D00aS67>LHaP035:D01A245:D@Q1S65:D00Q2400PDYAS66<HDYAS65:DHaQcW0QS6
0QcW00HU:B488@PU:AcW6<H448@00aBU48@DY@025:D00aS65:DHaP026<H25:D01`aS5:DU:Be[9BTH
aQ2400<DY@D@Q08<H`0448@DYA2436<648@00`aS48@@Q0035:D00aS65:DHaP035:D00a245:DDY@02
48@236<648@25:D02a245:D@Q1BU6<HDYA245:D@Q1S65:D00a2400@DYA245:D@Q0@<H`0548@<Ha24
36<DY@0548@00aBU48@@Q00248@46<H011BU48@@Q0aS1A2400HDYA2448@<Ha2436<248@00aBU48@<
H`0248@35:D448@236<00a245:DDY@0236<248@336<00aBU36<@Q00248@00aBU48@@Q00648@030aS
48@@Q1BU48@DYA245:DHaQBU48@<H`88@P<<H`0448@<H`aS248536<248@336<00a2436<8@P022482
36<448@00`aS48@@Q00248@01`Q236<@Q2487>L@Q0Q200X<H`48@P4<H`4<H`0000@000@Q12400084
8@0B0008@P@Q124000Q2;F]W>DYB<H`icT8@AS5:DU:DBU96<Cg_0cW>00Le[BU:9BTU:BU:;F/YBP02
;F/01cF]<H`aS3F]<H`e[C6<00<]J`<aS007=JdicSg_=JdaS2U:;F/00SF]00I243g_@Q1243W>=Jd3
<H`00cF]<H`]J`02;F/00bU:;F/aS002;F/6:DX4<H`3;F/4:DX39BT012489BTU:BDY0RU:00HU:B48
9BTU:BU:9BT27>L01248:DXYBRe[12DY00PQ22DY:DXYBRDY8@PU:BU:0RDY124800<U:BU::DX00b48
0Re[00PYBS6<;F/]JbU:;F/aS3F]0be[0SF]00hicTHa@Q0icS6<:DX]Jc6<;F/YBRDY8@PU:BU:0bDY
0b480QcW00HQ21cW9BTYBRDY8@P37>L68@P29BT2:DX012DY8@PQ21cW0bDY0RU:00@Q21cW6<HHaP8Q
20049BTLiaS65:D27>L00b487>LLi`027>L39BT38@P27>L38@P01AcW6<HDYAS65:D011S600<Lib48
8@P01b480RDY00dYBRe[<H`aS2e[:DXaS3F]@Q1:DTHa?Nl]J`039BT00b487>LHaP048@P02AcW6<HH
aR489BTYBRDY8@PU:@038@P37>L36<H35:D66<H00aBU48@<H`0536<03PQ236<<H`aS8@PU:DHaDYA>
LeJe?Nl]JacW6<H28@P02RDY8@PQ22U:;F]244icAS5242U:0acW00<Q21cW5:D00QBU00@HaQ245:DH
aP8Li`035:DHaQS6008DY@0348@DYAS600<DY@0648@DYAS67>LHaQcW0QS60aBU0a2400LDYAS65:DD
YAS67>LHaP045:D448@00aBU6<HHaP027>L03R487>LHaQcW8@PLiaS67>LU:AcW5:D<Ha245:D236<0
1A245:DHaQBU6<H00QcW00hHaQBU7>L@Q0aS5:DU:C6<;F/HaQ245:D@Q0aS0Q2400<HaQBU48@00PaS
00@8@Q245:DDY@8@Q00336<@Q1BU00D@Q08DY@8HaP8DY@066<HDY@aS36<@Q1BU1A2410aS0Q2400<D
YA2436<00Q240QBU00<<HaBU48@011240QS60QBU00<@Q1BU48@00`aS0Q2400D<Ha245:DDYA2400@<
H`<@Q08DY@056<HDYA2448@<H`0448@021BU48@DYA2436<@Q0aS48@25:D00a2436<<H`0348@236<2
48@336<348@236<348@436<248@011S648@<H`aS1A240PaS00<@Q1BU6<H00a240aBU00@<Ha2448@@
Q0D<H`8@Q0<8@P0336<DYA24008<H`04248<H`aS248236<00aBU48@<H`02248336<00a2436<@Q003
48@00aS65:D@Q002248236<00`Q236<<H`0336<00`Q236<@Q00236<000848@0300048@@Q00H48@08
248YBUkgBU8aS3W>?Nm240I:DP03AS4icSF]00@]J`06:DXQ22DY;F/e[C6<0Re[00He[CW>>Lhe[C6<
;F/4<H`01SW>@Q0icS6<;F/aS08]J`04>Li244HaAS42>Lh01cF]>LhmkcW>=JdaS2e[008YBP8]J`8a
S0<]J`039BTYBRe[00<aS006;F/aS36<;F/YBRe[0RU:12DY0RU:00LU:BU:9BTYBRDY:DX]J`029BT0
1B487>LU:B489BT00Re[00<YBRDY8@P01RDY12U:12480bDY00DYBR488@PQ22U:008aS005;F/YBRe[
;F/aS003;F/2<H`02RU:=Je244icDY@mkc6<;F/YBS6<0Re[0bDY0RU:00DU:B488@PU:B4800<Li`04
9BTQ22U::DX28@P011S67>LQ21cW0b480RDY12U:0b4800<LibDY:DX00RU:00DU:AS66<HHaQcW008Q
208Li`<HaP@Li`<U:@058@PLib489BTQ20037>L032487>LLiacW6<H@Q1BU6<HQ21cW6<HQ208U:@8Q
208Li`8Q20@U:@03:DX]Jbe[008]J`0:>Li244HaBU92436<;F/Q22DY7>L26<H012489BTU:AcW0QS6
00<Q22DY:DX00RDY0R4800<U:AcW7>L011cW00@HaQ245:DDY@@HaP8DY@046<HDYA2436<524804@aS
2488@Q246<HaS3F]@Q1F]DYB=JdU:A246<HQ21cW8@P00RDY00<Q23W>BU800Tic00he[BU:9BTLibDY
8@PLiaBU6<HDYA245:DHaQcW11S60aBU00<HaQBU6<H00aBU00<@Q1BU5:D00acW0QS60aBU11241ABU
0QS600<DYA245:D00Q240QBU0QS600DLib488@PLiaS600LLi`036<H@Q12400@@Q0035:D@Q124008H
aP098@PLiaS66<HDYA245:DHaR48008]J`048@PDY@aS48@25:D00a245:D@Q00248@00`aS48@DY@04
48@00`aS48@@Q0035:D248@36<H25:D01A245:DDYA245:D00a240PaS00@@Q1BU48@<H`@@Q00336<@
Q0aS008@Q00436<@Q1246<H25:D248@25:D00aS65:D@Q00348@00`aS48@@Q00348@00aBU48@DY@09
48@45:D448@00aBU48@@Q00248@011BU48@<H`aS0QBU00<@Q0aS36<00Q240`aS1A2410aS00L@Q0aS
48@<Ha245:D@Q00236<01Q245:DDYABU48@DY@@@Q08<H`8@Q08DY@<@Q08<H`8@Q0045:D@Q12448@2
36<2248336<00a2436<<H`0=36<00a2436<8@P0236<02ABU48@<H`Q248@HaQcW6<H@Q00324800`aS
48@@Q00736<12480000500048@@Q1240000312402`Q212448@Q2<HaS64Ha9BTaS3g_>Lh00T8@0THa
0dYB00A6<D8@>LhicP8]J`05:DXU:BDY9BTYBP04;F/2=Jd2>Lh2=Jd01CW>=Jde[C6<=Jd00SW>0Re[
00DaS3W>?NlmkcF]00<icP03@Q16<DHa0096<@03>Lhe[Be[008aS003=JdicSW>008]J`8U:@06;F/Y
BRe[<H`]Jc6<0be[00<YBR48:DX00be[0RU:00`]JbU::DXU:B48:DX]Jc6<;F/YBRe[:DX38@P01BDY
:DX]Jbe[:DX00bDY0b480RDY00@YBRDY9BTLi`8Q20037>LYBRU:008]J`0>:DXU:B488@PYBRDY:DX]
JbU:;F/YBS6<=Jd]J`8YBP06;F]:DUkgHaQNmdYB0S6<0Re[00PYBRDY:DXU:C6<>Lhe[Be[0bDY0R48
00<Lib488@P00RDY00DYBRDY8@PQ21cW00<Q2004:DX]Jc6<<H`2=Jd2<H`012DY8@PLiaS60QcW00@H
aQcW8@PQ20@Li`058@PLiaS65:DHaP038@P00acW8@PQ20028@P011cW8@PU:BDY0b4800@U:B488@PL
i`8HaP068@PLiaS66<HLib480QcW0QS600<Q22DY8@P00QS600XLib487>LQ22DY:DXU:BU:<H`e[@8i
cP06@Q16<DYBBU8e[Be[0R4800HU:AcW7>LHaQcW6<H27>L29BT00b487>LLi`027>L39BT012487>LD
YABU0PaS0Q2400<DY@aS24801@Q200<48@Q224800`@Q0PQ20`@Q00D@Q1BU6<HHaQBU00D@Q0<DY@8U
:@05=Je244HaAS4icP02<H`3>Lh012e[8@PQ21S60aBU00@HaQcW6<HHaP@DY@<@Q08DY@0548@DYABU
5:DHaP027>L00aS65:DDY@035:D448@011BU48@DYA240QBU0QS60Q240aBU00DHaQBU6<HLib4800<L
i`038@PLiacW008HaP@DY@0548@<Ha2448@DY@0348@25:D01AS67>LQ21S648@00QBU00LLibe[;F/Q
21BU36<@Q0045:D011245:D@Q1240PaS0QBU0Q2400<DYA2436<00Q240aBU11S60QBU0Q240QBU1124
00DDYA2448@@Q1BU008@Q0@<H`0348@<Ha2400T@Q0DDY@@@Q0045:D@Q12436<248@010aS48@@Q124
0PaS0Q2400<<Ha2448@00QBU112400D<HaBU5:DHaQBU00H@Q0035:D@Q12400@<H`<DY@0448@<H`Q2
36<448@010aS48@@Q1240aBU0Q240PaS00<@Q1BU5:D02a240QBU0a2410aS00L@Q0aS36<<Ha2436<@
Q00236<348@00aBU36<@Q00236<00a2436<<H`0248@236<00`Q236<<H`0236<01A2436<8@PaS5:D0
0QS61`aS00<8@Q2448@01@aS0A240@aS000312400`0012448@0412401`0036<aS5kgAS4YBSF]00<i
cP8mk`03@Q16<DHa0096<@05@Q0mkcg_<H`]J`02:DX022e[:DXYBRU:;F/YBRDY;F/2=Jd0136<;F/e
[CW>0SF]00<icSF]=Jd00c6<00<]Jc6<>Lh00cW>0SF]00LicSg_@Q1:DTHa@Q0icP05=Jd00cW><H`a
S003:DX00bDY:DXYBP03<H`00be[:DXU:@04:DX3;F/2:DX01Be[9BTQ22DY;F/00S6<0Re[00DU:B48
8@PLib48008]J`03:DXU:AcW008U:@@Q208U:@8YBP8U:@066<HLib48:DXaS2e[0bDY00<Lib489BT0
12U:00@]JbU:;F/YBP8]J`09:DXicTicG_MS65JeAS4mkc6<008]J`03:DXU:BU:008aS08icP05=Jd]
JbDY8@PU:@038@P39BT012489BTQ22DY124800TU:BU::DXicSF]>Lhe[BU:9BT00acW00<HaQcW7>L0
0acW00@Q21cW7>LLi`8HaP035:DHaQcW00<Q20037>LHaQcW008Q208U:@LQ20<Li`<HaP057>LQ21cW
7>LHaP027>L02QS67>LHaQS67>LU:B487>LHaQcW0RDY0RU:0S6<00@icT8@?Nm6<@924003?NlYBRDY
008Li`039BTQ224800<HaP048@PU:BDY9BT27>L38@P01AcW8@PQ21S65:D00`aS0Q2400<<H`Q22480
0PQ200<<H`@Q24800P@Q00@8@P@Q24848@@8@P8<H`8DY@8<H`88@P<<H`0648@DYAcW7>L]JcF]0SW>
0SF]00<icSF]=Jd00Sg_00De[C6<6<HLiaBU00@HaP035:DHaQBU008HaP@DY@036<HDYA24008@Q08H
aP037>LHaQBU00@DY@<@Q00336<@Q124008DY@056<HDYABU48@DY@036<H00aBU48@DY@027>L01B48
7>LHaQcW6<H00QcW0aS60QBU00<@Q1BU48@00a2400D<Ha245:DDYAS6008DY@8HaP087>LDY@aS5:DQ
236<;F/Q20@@Q0036<HDYABU00P@Q08DY@0348@DYA24008@Q0045:DHaQS65:D46<H548@00aBU48@@
Q00248@00aBU48@DY@0248@236<248@00aBU48@@Q00336<248@00aBU48@<H`0248@25:D248@00`aS
48@@Q00248@336<448@25:D0112436<<H`aS1A2400DDYA245:D@Q1BU00D@Q0035:D@Q0aS00@@Q0<<
H`<@Q0045:D@Q0aS36<348@336<348@01PaS48@DYABU48@<H`<@Q00336<@Q1BU008@Q08<H`<DY@03
48@<H`aS008<H`<@Q0D<H`8@Q0<8@P0336<@Q124008@Q0045:D@Q12436<348@336<248@00`Q236<<
H`03248636<35:D00a24248<H`0236<00a2436<8@P0236<00`Q236<<H`0236<00003124000@Q0084
8@0=00048@@Q248000@Q248]JfLiBU8]JcF]?Nl00cW>00<e[C6<;F/00S6<00<e[C6<:DX00RU:0Re[
00<aS2e[;F/00be[00TYBRDY;F/e[C6<:DXU:Be[=Jd00c6<00@icSg_?Nle[@<aS08icP04=JdaS2e[
<H`5=Jd01S6<=JdaS36<=JdicP8mk`03=JdaS2e[008]J`8YBPDU:@03:DXU:BDY008U:@8YBP05;F/Y
BRDY9BTYBP029BT2;F/00c6<;F/U:@049BT012U:;F/YBRU:0bDY1R4800<YBRDY9BT00QcW00XQ21cW
6<HLib48;F/YBRDY;F/YBP<Q20<YBP0?8@PU:BU::DXaS2e[<H`YBSg_CW=NmfLiDYA6<D8@008icP03
<H`]JbU:008U:@04:DXaS3F]=Jd2<H`012DY:DXQ22480RDY12U:00<]JbU::DX00bDY0RU:00DU:B48
9BTYBRe[008YBP048@PHaQcW6<H27>L00b487>LLi`027>L25:D26<H01BDY7>LLib489BT00R480QcW
00<U:B489BT00RDY00<Q21cW9BT00RDY00@Lib489BTQ20<Li`048@PLiacW7>L26<H00acW6<HHaP02
6<H38@P37>L01b489BTYBRU:<H`e[CW>008e[@DicP03?NlaS2U:008Q208U:@8Q20057>LQ22487>LQ
20046<H011cW6<HDYA240PaS0Q2400<8@P@Q24801@@Q00<8@P@Q24800P@Q00@8@P@Q12448@D8@P06
1248@PQ21248@P@Q0PQ200<48@Q224800QBU00lQ21cW:DX]Jc6<=JdaS3F]>LhaS2U:;F/e[C6<9BT0
0QcW0Re[0RDY00DQ21S66<HDYAS6008DY@@@Q08DY@8HaP035:DHaQBU008HaPHDY@8@Q08DY@0748@H
aQcW6<H@Q1BU6<H00QcW00HDYA245:DHaQcW8@P27>L00b487>LHaP026<H01ABU6<HDYAS65:D00a24
00@DYA2436<@Q08HaP045:DHaQcW7>L35:D00acW8@PLi`027>L00a245:D@Q00448@01ABU48@@Q1BU
48@00QBU00<HaQBU5:D00Q2400<DYA245:D00QS60QBU00<@Q1S65:D00Q240QS60QBU00D@Q1BU5:DH
aQBU008HaP045:D@Q0aS36<348@010aS48@<H`aS0a240PaS0Q2400<DYA245:D00a240aBU0Q241PaS
0QBU0Q240PaS00@@Q0aS36<@Q08DY@0348@DYA24008@Q00536<@Q1245:D@Q00436<448@01@aS248@
Q1245:D00Q2400D<Ha2436<@Q0aS00H@Q0035:D@Q0aS00@<H`@@Q00336<@Q1BU008DY@8@Q08DY@<@
Q00336<@Q12400<@Q0<<H`8@Q08<H`03248<H`aS00<@Q00336<@Q12400D@Q0D<H`04248<H`aS2483
36<01`Q236<@Q1BU48@<H`Q200<<H`8@Q0<<H`8@Q0D<H`0000D000@Q12448@0000H48@05248]Jf<H
CW<]J`06>Lh3<H`2=Jd2;F/012U:;F/YBRe[0S6<1Be[0RU:12e[00@YBRe[;F/e[@8aS08e[@07>Lhe
[CF]=JdaS3W>=Jd00c6<0SF]00<aS3F]=Jd01C6<00<]Jc6<<H`00SW>00<aS3F];F/00RU:00<U:BU:
9BT00bDY00L]JbU:9BTU:B489BTYBP039BT2:DX00bDY:DX]J`02;F/3:DX39BT3;F/3:DX01bDY8@PQ
21cW8@PU:B4800<U:@048@PLiaS66<H28@P012DY:DXYBRU:12DY00<YBRe[:DX00bDY00PYBRe[<H`a
S2U:<H`icTYB0V<H00=JeTic=Jd00cF]0Re[0RDY00HYBS6<=JdicS6<;F/59BT00b489BTU:@02:DX2
<H`00bU:9BTQ20089BT00b487>LLi`027>L01B489BTQ22487>L00QS600<LiaS66<H00QS600DLib48
9BTU:B4800<Li`8Q208U:@037>LQ2248008U:@LQ20037>LHaQcW008Li`038@PLiacW00@HaP<Li`03
8@PLiacW008Q20<YBP0=;F/aS3F];F/aS3F]>Lhe[CW>?Nm243W>:DX00RDY0b4821cW0aS600DDYA24
48@<Ha24008<H`0524848@@Q1248@P0312400`Q212448@0324821242248312400`Q212448@032482
1243248236<011BU6<HLibU:0be[00<aS3W>=Jd00S6<00DicSF]:DXLib48008YBP05<H`]JbDY8@PL
i`026<H01aBU6<H@Q12436<@Q1BU00<HaP077>LDYAS65:DHaQcW6<H00QBU0a241ABU00HHaQBU48@D
YAS67>L26<H01QcW6<HHaQBU7>LQ208Li`046<HLiaS66<H27>L01AS65:D@Q1245:D011240QBU00<H
aQBU6<H00QcW0aS60acW00DQ21cW6<HDYA24008DY@<@Q0<DY@8@Q08DY@046<HDYA245:D248@25:D2
6<H01ABU6<HHaQ2436<00Q240QS60QBU0Q2411BU00@HaQ2448@@Q0<<H`0448@DYA2448@236<00a24
36<<H`0248@336<25:D448@00aBU48@<H`0236<248@236<00aBU48@<H`02248236<348@00`aS48@@
Q00848@336<748@236<648@00`aS48@@Q00436<548@336<00`Q236<<H`0248@236<45:D00a2436<@
Q00348@336<348@336<348@336<248@436<00aBU48@<H`0236<548@00`aS2488@P0324800`aS48@<
H`0336<00a2436<<H`0436<448@636<000848@0600048@@Q124000Q20`@Q00P8@Re[G_M6<Be[>Li2
43W>0SF]0S6<00D]JbU:;F/]Jc6<008YBP038@PU:BU:00HYBP8U:@8YBP03<H`]JbU:008YBP03;F/a
S36<008aS003=JdaS3F]008aS003=JdicSF]008aS0<icP03;F/YBRU:00HYBP03;F/aS36<008e[@08
<H`e[CW>=JdaS2e[9BTYBP8U:@038@PU:B48008Q20067>LU:B489BTQ22DY0Re[0S6<12U:12e[0RU:
00<U:BU:9BT00RU:0R480QcW00LQ22DY9BTQ21cW6<HLi`036<H00acW9BTU:@03:DX032e[<H`aS2e[
:DX]JbDY8@P]JcF]<H`]J`8U:@8icP07BU9S66<HE[E242e[<H`00bU:0bDY0RU:00DaS2e[<H`]Jc6<
008]J`8YBP8Q208U:@<]J`07:DXU:BU::DX]JbU:;F/00bDY00<Q22DY7>L00QcW00@HaQcW7>LLi`8Q
20037>LHaQBU008HaP8Li`<HaP047>LQ22489BT28@P01BDY8@PQ22DY8@P00bDY00HQ21cW7>LQ22DY
8@P37>L28@P37>L28@P27>L00b487>LHaP027>L28@P00bDY:DXYBP02:DX29BT00b489BTYBP02<H`0
2be[=JdmkdYBDYA6<D8@<H`Q22DY8@P00RDY00DQ21cW7>LHaQcW008DY@0348@<H`aS0088@PD48@03
24848@@Q00D48@0324848@@Q00848@88@P848@<8@PD48@0624848@@Q0008@P@Q0`Q200L<HaBU48@H
aQBU6<HYBP02;F/00b487>LQ20038@P00acW<H`mk`02?Nl00c6<9BTU:@047>L35:D00a246<HDY@04
6<H25:D00aS67>LQ20027>L35:D011245:D@Q1BU0R4800<LiaS648@00aS600<DYAS67>L00QS600DD
YAS68@PQ21cW008HaP<Li`035:DHaQBU00<HaP035:D@Q1BU008DY@DHaP<Li`076<H@Q1BU7>LQ22DY
7>L0112400DDYA245:D@Q1BU00@@Q0045:DHaQS648@25:D36<H236<00a245:DDY@0248@25:D00aS6
5:DDY@026<H00aBU6<HHaP035:D348@00aBU48@@Q00348@010aS48@@Q0aS0Q240QBU00D@Q0aS48@@
Q1BU00D@Q0<<H`8@Q00336<@Q12400<@Q00436<@Q12448@236<248@25:D00a2436<<H`0236<248@0
1@aS48@@Q1245:D00Q240`aS0Q2400@<Ha2448@@Q08<H`0348@<H`aS00<@Q08<H`0348@DYA2400<<
H`04248<H`aS48@236<648@01ABU6<HHaQBU48@00PaS0Q241@aS0a240PaS00<@Q0aS36<00a240`aS
0Q2400D8@PaS36<<Ha2400D<H`0348@<H`Q2008<H`0548@<H`aS36<@Q00236<2248236<011245:DD
YA240PaS00<@Q0aS36<00@aS00000`@Q00048@021240300012448@Q200048@Q2;F]S64YB:DXe[@@i
cP03=Jd]Jbe[00<]J`06:DXU:BDY:DXU:BU:0be[00@YBRDY:DXU:@@YBPH]J`<aS005;F/aS36<<H`]
J`08=Jd01C6<;F/]JbU:9BT01RU:0c6<0cF]00DicSF]=JdaS2e[00<YBPDQ20037>LQ22DY008Q2004
9BTYBS6<<H`3:DX2;F/0136<:DXYBRe[0RU:00HU:B489BTYBRDY8@P27>L38@P29BT00b487>LLi`02
7>L02AS67>LLibDY:DX]JbU:;F/aS002=Jd01S6<:DXYBRDY:DX]J`<YBP8aS009>LiF]F<HIcUBU3W>
=Jd]JbU:00<U:@8Q20069BTYBS6<<H`]JbU:0Re[00@YBRDY8@PLi`8U:@8]J`03:DXU:BU:008U:@07
;F/aS2e[:DXQ22DY:DX01B4800<LiaS66<H011cW00HHaQBU7>LLib487>L26<H00acW6<HQ20027>L2
8@P29BT28@P39BT27>L26<H37>L28@P00acW8@PQ20038@P47>L012487>LHaQS60QcW0RU:00<U:BU:
9BT00RDY00XLib487>LQ22e[<H`icSF]>Li2409:DP05?Nle[Be[8@PYBP029BT28@P27>L26<H01124
36<@Q0aS0PQ20P@Q00<8@P@Q12401@@Q00<8@P@Q12400`@Q0PQ200<<H`@Q12400PQ210@Q00<8@P@Q
12400P@Q00<8@P@Q248010Q200P<Ha2448@@Q1S67>LQ22DY124800PLib487>LU:BU:=Jdmkc6<0RU:
00DLib487>LLiaS600<DY@066<HDYA245:DHaQBU0QS600<DYAcW8@P00RDY00<HaQBU5:D00aBU00<@
Q1BU6<H00QcW0QS60Q2400<HaQcW7>L00aBU1AcW0QS60acW0QS60QBU00@@Q1BU48@@Q0<DY@036<HD
YAS6008HaP037>LQ21S6008DY@046<HLibDY7>L26<H348@00aBU48@DY@0548@35:D011S65:D@Q124
0aS600DDYA246<HDYA24008<H`065:DHaQS65:D@Q1BU0QS61aBU00@@Q1BU48@<H`8@Q0055:D<H`Q2
36<@Q0035:D248@25:D248@011BU6<HDYA240`aS00@@Q0aS36<<H`<@Q0@<H`8@Q0035:D@Q0aS008@
Q08DY@0348@<H`aS00<@Q08<H`8@Q0035:D@Q124008<H`D@Q08DY@0348@<H`aS00<<H`0348@<Ha24
00X<H`T@Q0045:D@Q1BU5:D236<448@236<248@00aBU48@<H`0248@011BU48@@Q1240PaS00@8@PaS
48@<H`D@Q0D<H`07248<H`aS36<@Q0aS48@02@aS00@DYAS65:DDY@8<H`0348@<H`aS004<H`0000@0
00@Q124000L48@08248]Jf]JDY@]JcF]<H`]J`<e[@03<H`]JbU:008aS005;F/aS36<;F/YBP02;F/2
<H`00be[:DXU:@03:DX28@P01RDY:DXYBRe[=JdicP<aS005=Jd]Jbe[:DX]J`02<H`00cF]<H`e[@02
>Lh013F]<H`]Jbe[0RU:0RDY12e[00@YBRDY;F/aS08icP04=JdaS36<<H`2=Jd00c6<:DXU:@028@P0
1BDY8@PQ21S67>L00RDY00@YBRDY9BTU:@DYBP039BTYBRDY008U:@8Q20<U:@8Q208Li`079BTQ22DY
9BTQ22DY8@P00QS600@Lib488@PU:@8Q20039BTYBRe[00@aS005:DXU:BU:;F/YBP029BT022U:=Jda
S3W>E[EW>F]JE[D2<H`00b489BTU:@029BT00b487>LQ2002:DX00be[:DXYBP039BT012U:9BTU:BDY
0bU:0b4800DU:B489BTU:B4800HLi`@Q20037>LHaQcW00<Li`8HaP0:7>LU:BDY:DXQ21cW6<HQ22DY
8@P27>L00bDY;F/YBP038@P00bDY:DXU:@048@P00acW8@PQ20027>L01AS67>LQ22487>L00R4800<L
iaS65:D00QS600LQ22DY8@PU:Be[<H`]J`028@P37>L02R487>LYBRe[>Lhe[C6<:DXaS3g_0THa00Ti
cRe[:DXYBRe[8@PHaQ245:D00Q240PaS10@Q0PQ210@Q00<8@P@Q12400P@Q0`Q200D48@Q21248@P@Q
0088@P031248@PaS0088@PD48@0324848@Q200<48@@8@P<<H`0548@DYA2436<@Q0026<H011BU48@H
aR480RDY00@YBRDY7>LHaP8Li`03:DXaS2DY008HaP058@P]JbDY6<HDY@056<H03BDY:DX]Jc6<8@PH
aQBU48@DYA245:D@Q1S6008Li`036<HDYABU00@DY@046<HQ22487>L26<H37>L01AS65:DHaQBU6<H0
0aBU0QS6014DYAS648@@Q1BU6<HQ21cW6<HLiaS648@DYA246<HDYA24008HaP038@PHaQBU008DY@<@
Q0<DY@0348@<H`aS008DY@0348@DYAcW008Q20046<HDYABU5:D26<H35:D00aS65:DDY@025:D01A24
6<HLiacW5:D00Q240QS600@DYA2448@DY@8@Q0035:D@Q0aS008<H`045:DHaQBU6<H25:D248@02@aS
5:DDYAS65:D@Q0aS248<H`0248@436<248@00aBU48@@Q00236<248@35:D248@00`aS48@@Q00336<0
1124248<H`aS0Q240`aS00<@Q1BU48@00Q240PaS0Q240PaS112400<<Ha2436<010aS10Q200<<H`Q2
48@01A2400<DYA245:D00a2400@<HaBU48@DY@8@Q00436<@Q1BU48@236<010Q248@HaQBU0Q240PaS
00<@Q0aS36<0112400<<Ha2436<00`aS00<@Q0aS36<00Q240`aS00<@Q0aS36<010aS00<@Q0aS36<0
0Q2400<<H`Q236<00Q240@aS0@Q2000412401@0012448@@Q24800P@Q00D8@S6<Kg]F]C6<00<icP8a
S08]J`04<H`]Jbe[;F/3<H`2;F/00bU:;F/aS002<H`2:DX012DY:DXYBRU:0bDY00@YBRe[;F/aS08i
cP05<H`]Jbe[=JdaS002;F/5<H`2=Jd3<H`7:DX01S6<;F/]JbU:;F/e[@8icP@aS004=JdicRe[:DX3
9BT00b487>LLi`028@P01AcW:DXYBRe[9BT00R480RU:00<]JbU:9BT00RU:00@Q21cW7>LQ208U:@03
8@PLib48008Q20069BTQ22DY:DXU:B480acW00@HaR488@PQ20<U:@8]J`8aS004;F/YBRU:9BT2:DX2
9BT02RU:;F/U:C6<AS5BU6]JG_M:DSg_0RDY00@YBRDY9BTLi`8Q20049BTYBRU::DX59BT28@P00bDY
:DXYBP02:DX88@P47>L00b487>LQ20027>L28@P011cW6<HDYAcW0QS600<Lib489BT00RDY0QcW00DQ
22DY8@PHaQcW00<U:@8Q20039BTQ22DY008YBP<Q208U:@058@PHaQcW7>LDY@027>L00b489BTU:@02
6<H25:D01QcW6<HLiacW:DX]J`8aS004:DXLiacW6<H28@P01AcW8@PU:Be[=Jd0136<0SW>00DmkcW>
=Jd]JbU:008Q20036<H@Q124008@Q00336<8@P@Q0088@P848@0324848@@Q00H48@0324848@@Q0084
8@0524848@Q224848@02248010@Q2488@PQ20`@Q00@8@P@Q12448@<8@P031248@PaS00<8@PH@Q08<
H`0348@DYA24008HaP038@PU:B48008Li`0;6<HDYBDY;F/YBQcW5:DQ236<;F/Q20027>L25:D01AS6
8@PQ21S68@P00RU:00TU:A245:DHaQ2436<DYAS67>L01AS60QBU1aS611cW0QBU00<HaQBU5:D00QS6
0QBU1AS600<DYAS66<H00QcW00/HaQcW5:DDYA2436<@Q1S67>LU:B48008DY@0:48@<Ha245:DHaQBU
48@<Ha245:D248@25:D01A246<HLib487>L01ABU0QS611BU0aS61ABU00<@Q1BU5:D01ABU00L@Q0aS
48@@Q0aS48@DY@036<H00a245:D<H`0448@01ABU6<H@Q12436<00Q240PaS0Q240`aS00@@Q0aS36<@
Q08DY@0348@DYA2400@@Q0@<H`8@Q0@<H`@@Q00336<@Q124008@Q0@<H`03248<H`aS008@Q08<H`05
48@<H`aS36<@Q00236<010Q236<@Q12410aS0QBU00<@Q1BU48@011240PaS112400<<Ha245:D00`aS
0Q2400D<Ha2448@@Q1BU00@<H`0348@<H`aS008@Q08<H`04248<H`aS48@436<01A2436<<H`aS48@0
10aS00<8@PaS48@00PaS00H@Q0aS36<@Q0aS48@12480000300048@0000<48@030008@P@Q00848@07
248e[GNmE[D]Jcg_>Lh00S6<00<]Jc6<:DX00bU:0SF]00DicS6<9BTU:BU:00<]J`05:DXU:BU:9BTY
BP069BT01Be[<H`aS3W>=Jd00c6<00DicSF]<H`aS3W>008aS08]J`07<H`]Jc6<;F/YBRDY:DX00RDY
00HaS3F]AS56<CW>=Jd2:DX2;F/00c6<=JdaS002<H`2:DX28@P39BT38@P69BT01bU:9BTU:B489BTY
BRDY008Q20@U:@@Q20037>LQ2248008U:@06:DX]Jbe[:DXU:B480RDY0R4800<U:BU:9BT00Re[0S6<
0RU:00HU:B488@PU:BU:9BT28@P02bDY<H`YBS6<AS5JeV]JG_M243W>8@P022DY1b480QcW00<Q21cW
8@P00b480RDY00<LiaS65:D00acW00@HaQcW7>LLi`@Q20<Li`8HaP8Li`038@PLiaS600@Li`DQ20<U
:@05:DXU:B488@PU:@02:DX00be[:DXU:@028@P29BT01AcW8@PLibDY:DX00RDY11cW11S60QcW00LQ
22DY9BTU:BU:9BTQ20027>L28@P032DY7>LLibU:;F/mkdHa>LhaS2U:8@PYBP8aS005=JdaS1cW5:D<
H`0248@010Q212448@Q20`@Q00D8@P@Q12448@Q200@48@0424848@@Q248412401@Q236<8@PaS48@0
0PaS00<8@P@Q248010@Q00@8@P@Q1248@P848@T8@P0336<8@PaS00<8@P0336<8@PaS008@Q08DY@<@
Q0095:DQ22487>LHaQBU6<HQ22U:008]J`03:DXQ21cW008HaP@Q20<HaP8DY@0448@DYABU5:D26<H2
7>L56<H01ABU6<HDYAS65:D00QS60QcW00<HaQBU6<H00aBU00<@Q1BU5:D011BU00L@Q1BU6<HLiaBU
6<HLi`036<H01ABU6<H@Q1245:D00acW1ABU0Q2400@<Ha245:DDY@8@Q08<H`056<HLibDY9BTHaP04
5:D56<H55:D36<H011BU48@<H`aS0QBU00HHaQBU48@DYA245:D648@00aBU6<HDY@0248@011BU48@@
Q0aS0Q2400@LiaS648@@Q0D<H`L@Q08<H`0448@DYABU5:D548@00aBU48@@Q00236<00a2436<8@P02
36<248@236<011245:D@Q1240PQ20PaS00<@Q0aS48@00PaS0Q2400<DYA2436<00`aS00L@Q0aS36<8
@PaS48@<H`0248@00`aS48@@Q00348@336<011245:DDY@aS0Q2400<DYA2448@00a240PaS00HDYA24
36<<H`Q236<348@236<00`Q236<@Q00248@636<348@436<00a2436<<H`0336<01@Q236<<H`Q236<0
0PQ20PaS0@Q2000512402`0012448@Q200048@aS<HacW5Je<H`00Sg_00@icS6<<H`]J`8YBP8U:@8a
S004>Lhe[Be[;F/2:DX2;F/00bU:9BTQ20029BT8:DX01Be[<H`icSF]<H`00Re[0S6<00Le[C6<=Jda
S2e[<H`]J`02<H`2:DX012489BTU:BDY0Re[00Dmkd8@AS4mkc6<008YBP03;F/aS3W>00<aS004;F/Y
BRDY8@P49BT28@P29BT3:DX39BT38@P29BT2:DX012DY8@PQ21cW0R4800TLib488@PU:B489BTQ22DY
:DX00Re[0RDY0R4800<YBRe[:DX00RDY00XYBRe[<H`e[C6<:DXU:B489BTQ208Li`088@PU:BU::DXQ
22e[=Je2409S6009F]I:DRe[:DXU:B489BTQ22DY00<YBP069BTLib488@PU:B480acW00@Q21cW7>LQ
208U:@8Q208Li`045:DHaQcW8@P27>L28@P00bDY8@PLi`067>L011S67>LLib480QcW0b480QcW0R48
00@Lib489BTYBP<U:@03:DXU:BDY008]J`049BTQ21cW7>L39BT02B487>LQ22U:;F/U:B487>LDY@02
6<H27>L36<H29BT2:DX29BT00b486<HHaP038@P02QS68@PQ23W>@Q0mkcW>:DXQ22U:0R4800DaS3W>
<H`Q20Q2008<H`88@PH48@0324848@@Q00L48@0324848@@Q00848@D8@P0436<@Q0aS2482124010Q2
1248@PQ210@Q1@Q20P@Q00<8@PaS36<00PQ20PaS0PQ20PaS0PQ200H<Ha2448@@Q0aS48@236<04QS6
7>LQ21cW5:D@Q1S69BTYBRe[9BTQ22DY8@PLib487>LQ20@Li`@DY@0348@DYABU008HaP037>LHaQS6
00<HaP<DY@036<HDYABU008HaP8Li`8HaP<DY@@@Q0@DY@0648@DYABU5:DHaQBU0QcW00@HaQBU5:DD
Y@<@Q0086<HDYAcW7>LHaQBU48@<H`<@Q08DY@@@Q08DY@096<HQ22487>LHaQ245:DHaQBU00PHaP03
5:DHaQBU008@Q0<DY@0448@DYABU5:D848@00aBU48@@Q0035:D00a245:DDY@0248@35:D348@01@aS
248<Ha245:D00PaS00<@Q1BU48@00Q2400<DYA2448@00QBU00DHaQBU48@@Q0aS008@Q08DY@8<H`03
248<H`aS008<H`0:48@DYA2448@<Ha2436<@Q0Q236<2248448@336<348@236<348@00`aS48@8@P02
36<248@336<00a2436<<H`0236<00a2436<@Q00348@236<00a245:DDY@0348@00`aS48@@Q00236<0
1Q2436<<H`aS48@8@P8<H`8@Q00536<@Q1BU36<8@P0236<248@736<00a2436<<H`0636<010Q236<8
@PaS0@@Q00000`001240000712402@00248aS6<HBU8e[D8@AS4mk`02=Jd01SW><H`aS2U:;F/aS0<i
cP06<H`]Jc6<;F/aS2e[0bU:0R4800<U:BU::DX00RU:0S6<00<]JbU:;F/00c6<00<]Jc6<=Jd00SF]
00@icS6<<H`]J`8aS004;F/YBRU:;F/2:DX28@P01S6<>Li:DTHa=JdicP8aS008=JdaS36<;F/YBRDY
8@PLi`@Q20039BTYBR48008Q208YBP059BT]Jbe[;F/aS0039BT2:DX00b487>LLi`02:DX012DY8@PL
iacW0b4800DU:Be[;F/YBR4800@U:@038@PU:Be[008]J`<YBP<]J`HYBP0A8@PLiaS67>LU:B489BTQ
22U:=Je246<HIcUF]DHa9BTYBP039BT2:DX00bDY8@PU:@02:DX01BDY:DXYBRDY8@P00QcW00<Q21cW
8@P01R4800LHaQcW8@PQ22DY8@PLi`048@P00acW6<HLi`027>L00aBU6<HLi`047>L01B489BTQ22DY
8@P00QcW0R480RU:0RDY0RU:00D]Jc6<:DXU:B48008HaP047>LQ22DY9BT47>L012489BTU:B480acW
11S60R4800/U:B487>LHaQcW8@PU:B486<HDYAS600<Q20036<HYBS6<008icP03:DXQ21S6008DY@04
6<HDYABU5:D236<31242248312400`Q21248@P04124010Q212448@Q20P@Q00P8@P@Q24848@Q21248
@PaS0a240`Q200<48@Q212400`@Q00<8@P@Q24800PQ20P@Q0PQ20P@Q0`Q20P@Q2PQ200D<H`Q236<<
H`Q200<<H`0648@DYAcW7>LHaQcW0aS60R4800D]Jc6<:DXQ21S600<Li`036<HDYABU008DY@067>LH
aQS65:DHaQcW0QS600DDYAS66<HHaQBU008@Q08DY@@HaP8DY@046<HDYABU5:D348@236<248@011S6
5:DDYAS60aBU0QS60aBU00D@Q1BU5:DHaQcW008HaP035:D@Q124008@Q08DY@0848@DY@aS248HaR48
:DXQ20HDY@036<HLib48008HaP035:DHaQS600<HaP8Li`056<H@Q12448@DY@0248@236<248@00aBU
36<@Q00448@236<011245:DDYA240PaS0Q2400<HaQBU5:D02Q240aBU00D@Q0aS48@@Q1BU00<@Q0<D
Y@D@Q00336<8@PaS008<H`@@Q00536<@Q12436<8@P0236<324801@aS48@@Q0aS48@00PaS11240PaS
00<@Q0aS36<01a240PaS0Q2400<<H`Q236<00Q240PaS1A2410aS0Q2400<<Ha2448@01@aS00@@Q0aS
36<<H`<@Q005248@Q1BU5:D@Q00536<248@01@aS248<H`aS48@00`aS0`Q21@aS000412401@001244
8@@Q24800P@Q00H8@S6<HaQ6<BU:=Jd2?Nl00cW>?Nle[@02<H`2;F/2<H`2=Jd3<H`2=Jd0136<:DXY
BRe[12DY0RU:0Re[00<aS2e[<H`00be[00<aS2e[<H`00S6<0cW>00He[C6<;F/]JbU:;F/4:DX29BT0
1RU:<Ha244Ha?NlicPHaS003;F/YBRU:00@Li`8U:@038@PU:BDY00@U:@8YBP8aS003;F/YBRDY00<U
:@038@PLib4800<U:@058@PLiaS66<HLi`029BT2;F/2:DX01BDY8@PU:BDY8@P00RU:1Be[00DYBRDY
;F/]JbU:00<U:@8Q20<Li`8Q200:7>LU:BDY<HaF]EkgJeYJeSF]<H`29BT2:DX69BT02B48:DX]JbU:
9BTLib489BTQ20027>L28@P02bDY8@PLiacW8@PLib487>LHaR487>L00b481QcW00<HaQcW7>L00QS6
00<Lib487>L00R4800<U:B488@P00QcW0RDY0RU:0RDY00DYBRe[<H`YBR4800@Li`038@PLibDY008Q
20057>LQ22DY9BTQ20027>L00b487>LLi`026<H011cW8@PQ22DY124800<U:AcW7>L00QS60QcW0b48
00LU:BU:;F/YBRDY8@PHaP025:D26<H01QBU48@<H`@Q24848@88@P@48@<8@PD48@88@P0336<8@P@Q
00848@88@P0436<8@PaS36<248@00`aS2488@P02124224800`@Q24848@0412422482124524800`@Q
2488@P05248336<00`Q21248@P03248336<0112436<DYABU0aS600PDYAS66<HHaRU:<H`]JbU:0aS6
0QcW0QS600H@Q1BU6<HLib487>L25:D00aS65:DHaP046<H45:D36<H011BU6<HHaQS60QBU1A2400<<
Ha2448@00aBU00<HaQ2448@00aBU00<HaQ2448@00QBU00<@Q1BU6<H00QS60a2400DDYAS648@@Q0aS
00<@Q08DY@8Li`066<HDYA2436<@Q1BU0QS600LDYAcW9BTQ21S648@DY@047>L26<H25:D848@00`aS
48@<H`045:D348@00aBU48@<H`0348@00aBU6<HHaP025:D010aS48@<H`aS1Q2400<DYA2448@00a24
00@DYA2448@@Q08DY@@@Q08<H`04248<H`Q2248248@00aS648@<H`0248@336<01Q2436<<H`aS248@
Q0<<H`<@Q0<<H`035:D@Q0aS008<H`8@Q08DY@@<H`0348@DYA2400P<H`8DY@036<HDYA2400<<H`03
48@DYABU00L<H`03248<H`aS00L<H`D@Q0<<H`0848@8@PaS248<Ha245:D<H`<8@P@<H`88@P0000@0
00@Q124000848@0300048@@Q00848@06248]JeJe@Q0U:C6<0SW>0SF]0c6<00@YBRe[<H`icP8mk`8e
[@@aS0P]J`09:DXU:BU:;F/YBRe[=JdicSF]00PaS004;F/U:BDY:DX4;F/4<H`01SF]<H`icSW>?Nli
cPDaS08]J`HU:@08;F/U:BDY9BTYBRDY:DXU:@8YBP8]J`DaS003:DXQ224800<U:@<Q20@Li`038@PU
:B48008U:@8YBP069BTQ21cW8@PU:B480RU:0bDY00<Q22U::DX00Re[00HYBRDY8@PLib487>L26<H0
2b489BTU:BDY8@P]Je:DHaQJeT8@:DX00S6<0bU:00@aS2U:9BT]J`8aS004;F/YBRU:9BT28@P39BT2
8@P39BT27>L26<H27>L00b489BTLi`027>L01aS67>LLiacW6<HLiaS600<Li`8HaP057>LQ22DY9BTQ
20027>L01B489BTYBRDY8@P01RDY0RU:00LQ21cW7>LQ21cW6<HDY@026<H57>L00b487>LQ20046<H3
8@P00acW8@PQ20029BT011cW6<HLiacW0aS60acW0QS60QcW1AS60Q2400<<H`Q236<010@Q00<8@P@Q
12400`@Q0PQ210@Q0`Q210@Q00P8@P@Q1248@P@Q24848@Q20Q2400H<H`Q21248@P@Q2482124010Q2
12448@Q20P@Q00@000@Q2488@P848@0724848@Q21248@P@Q248010@Q30Q200D48@Q236<<Ha24008<
H`<@Q0035:DHaQS600<HaP0:8@PYBRU:9BTLiaS67>LDYAS67>L29BT01R485:DDYABU6<HLi`8HaP03
5:DHaQ24008@Q0<HaP<DY@8Li`046<HDYA246<H348@010aS48@@Q1240`aS00HDYA2448@@Q1BU48@2
5:D01AS65:DDYA245:D00aS611BU00@@Q1BU48@@Q08HaP067>LQ21cW7>LHaQBU0a2400@DYAS66<HD
Y@<Q20037>LDYABU008HaP<Li`8DY@8@Q0045:D@Q12448@236<348@00aBU48@@Q00336<25:D448@3
5:D26<H25:D348@00aBU36<<H`0248@00aBU48@<H`0448@35:D01Q245:DDYABU48@<H`8@Q0035:D@
Q0Q200<<H`<@Q0055:D8@PaS36<8@P0336<01@Q236<8@PaS24800PaS00<@Q0aS36<00PaS0Q2410aS
0a2400PDYA245:DHaQBU48@<Ha240QBU0PaS0Q240PaS00L8@PaS48@@Q1BU48@<H`0348@536<01`Q2
36<<Ha2436<8@PaS008@Q0<<H`8@Q00336<@Q0aS00<<H`<@Q0@<H`0448@<H`aS36<2248336<148@1
36<1248000848@0300048@@Q00<48@0:248000@Q248]Jekg@Q0YBSF]>Lh4=Jd4;F/013F]<H`e[CW>
0SF]0c6<0RU:0Re[00<aS2e[;F/01Be[00@YBRe[;F/aS0<e[@03<H`e[C6<008aS003=JdaS36<008Y
BP03;F/aS36<00<]J`8e[@8]J`03<H`icSg_008icP03=JdaS36<00<aS006;F/YBRU:9BTQ22DY0RU:
00@]JbU::DXYBP8U:@03:DX]Jbe[008YBP03;F/aS36<008aS08]J`039BTQ22DY00<U:@058@PLiacW
8@PLi`028@P29BT3:DX00b489BTQ20028@P29BT3:DX49BT012U:;F/]JbDY12480acW00/Q22DY:DXL
ib48>Li:DV<HE[DicSF]008YBP8]J`<YBP03;F/aS36<008]J`DYBP8U:@8Q20059BTQ22489BTQ2004
7>L01B487>LU:BDY8@P00QcW0QS600<LiaS67>L011S600<Lib487>L0124800<Lib488@P00RDY00HQ
22DY8@PU:BU:9BT3:DX012DY8@PQ22480QcW0QBU0QS600@LiaS66<HLi`8Q20<Li`8HaP8Li`<Q208U
:@038@PLiacW008Li`8HaP035:DHaQS600<HaP8Li`8HaP045:DHaQBU48@336<00a242488@P021242
2485124010Q21248@PQ210@Q00<8@P@Q12400P@Q00H8@P@Q1248@PaS248236<01@Q236<48@@Q2480
0P@Q10Q210@Q1PQ20P@Q00<8@P@Q12400P@Q0PQ20`@Q00@8@PaS24848@<8@P848@0324848@Q20088
@P0336<8@PaS0088@P8<H`035:D@Q1BU00<DY@8Li`049BTYBRU:7>L26<H01b489BTQ21cW8@PLiaBU
008HaP8Li`<HaP8DY@0348@DYABU008DY@0348@HaQcW008Li`<@Q0055:D@Q12448@DY@0848@00`aS
48@DY@045:D00a245:D@Q0046<H00aBU48@@Q0045:D248@27>L012487>LDYA240QBU00H@Q1BU5:D@
Q1BU6<H29BT011cW5:DHaQcW0QBU00@HaQcW7>LHaP8DY@D@Q0035:D@Q0aS00H@Q00336<@Q1BU008D
Y@0536<@Q0aS48@DY@026<H00acW5:DDY@025:D548@00aBU48@DY@0348@25:D848@00`aS48@@Q003
48@010Q236<@Q0aS0aBU00<<H`Q236<00Q2400<8@PaS24800`aS00<8@PaS48@00Q241`aS00<@Q0aS
5:D01A2400<DYA2448@0112400<DYA2448@0112400<<Ha2448@0112400<DYA2436<01@aS0Q2400@<
H`Q2248<H`8@Q08<H`0:48@<Ha2448@<H`Q236<@Q1BU48@236<248@236<00aBU48@@Q002248536<1
2480000500048@@Q12400006124020Q2;F]Nmd8@9BT]Jc6<=Jd2<H`00be[:DXYBP02;F/2=Jd0136<
=JdaS36<0Re[12U:0be[00HYBRDY<H`icT8@>Lh2<H`01SF]<H`aS3F]>LhaS08]J`04<H`e[C6<<H`3
;F/29BT2:DX012e[<H`]Jc6<0SF]01DaS3F]>LhicSF];F/e[CW>=JdaS2U:9BTQ22DY7>LQ22DY:DXa
S2e[:DX00Re[0RU:0be[00@YBRDY9BTYBP<]J`05:DXU:BU:9BTQ20039BT01BU:8@PU:AcW8@P00QcW
12480acW0R4812U:00@Q22DY9BTQ208U:@04:DX]Jbe[:DX29BT01BU:8@PLiacW8@P00RDY00XYBR48
9BU245:DE[E6<Be[:DXU:@8YBP<U:@07;F/YBRU:;F/aS3F]<H`012e[00@YBR488@PQ20<U:@8Q2003
9BTQ21cW008Li`088@PLiacW6<HDYAS65:DLi`<HaP047>LQ22487>L26<H57>L38@P011cW8@PQ2248
0bU:0bDY00LYBR487>LQ22DY8@PHaP025:D26<H27>L01B48:DXYBRU:8@P00acW0aS60R480RDY0b48
0QcW00`HaQcW7>LHaQBU7>LHaQBU6<HQ22DY7>L448@00`aS24848@021243248312400`Q212448@04
2480100012448@@Q0PQ210@Q00<8@P@Q12400`Q200D<H`Q22488@P@Q00@8@P031248@PQ20088@PD4
8@<8@P848@0424848@@Q248212400`Q212448@03248312401PQ212448@@Q36<8@P@48@0324848@Q2
0088@P<<H`04248<H`Q236<248@021S67>LLib487>LHaQcW<H`2>Lh01RU:9BTaS36<9BTLi`<Q208L
i`036<HDYA24008DY@046<HDYABU6<H25:D00a245:DDY@0348@25:D448@236<348@00`aS48@@Q003
5:D248@55:D46<H011BU48@@Q1BU0QS600<DYA246<H00QS6112400DDYAS66<HHaQBU008HaP<Li`04
6<HDYA245:D26<H011cW6<HDYABU0Q2400DDYA245:D<HaBU008HaP035:D@Q12400<@Q00636<@Q124
5:D@Q0aS0Q2400DDYAS66<HHaQBU008@Q0HDY@8@Q0035:D@Q1BU00DDY@8@Q0<DY@0448@DYA2448@4
36<01@Q236<@Q1245:D00Q2400<8@PaS36<00Q240PaS00D8@PaS2488@PaS008@Q00336<8@PQ2008<
H`0348@<H`aS008<H`0548@DYA2448@<H`025:D00a2436<@Q0025:D0112436<@Q12410aS11240PaS
0a2420aS00H8@PaS36<@Q0aS248:36<011245:DDYA241PaS0Q2400@<H`Q236<@Q08<H`48@P000`@Q
00<000@Q00001@@Q00L8@Re[F]I242DY<H`e[@04<H`2:DX01BDY;F/aS36<=Jd00c6<0be[00<YBRe[
:DX01BU:0S6<0cW>00<mkcW><H`00SF]00PicSF]<H`]Jc6<;F/YBS6<0SF]00HaS2e[9BTYBRDY:DX2
;F/00cF]<H`aS003<H`013F]<H`aS36<1Be[00@U:AcW7>LLi`8Q20039BTYBRe[00<]J`03<H`]Jbe[
00@YBP03;F/YBRU:008YBP8U:@038@PU:B48008U:@038@PU:BDY008U:@038@PU:B4800<Li`<Q2007
7>LQ22DY9BTYBRDY8@P00RDY00@Q21cW8@PU:@<]J`039BTQ22DY008U:@<Q208U:@048@PU:Be[=Jd2
E[D01D8@=JdQ22DY:DX00R4800@U:Be[:DX]J`8YBP04;F/e[C6<<H`2;F/01BU:9BTU:BDY:DX00RDY
0R480bDY00<Q21S67>L00QcW0QS600@DYAS66<HDY@8HaP<Li`036<HLiaS6008DY@037>LU:B48008L
i`068@PU:B488@PLib480RU:00DU:B489BTYBRDY00@Q20097>LHaQBU5:DHaQcW5:DLib48008YBP8Q
208Li`036<HLib4800<Li`8Q20039BTQ2248008Li`036<HLiacW008Li`036<HDYAcW008Q20047>LH
aQ2448@436<412432483124224821242248:1243248010@Q2488@PQ20P@Q0`Q200D48@Q212448@Q2
00848@<8@P848@0324848@Q20088@P848@@8@P<48@0324848@@Q00@8@P031248@PQ200848@092484
8@Q224848@Q21248@P@Q00<8@P0336<8@PaS0088@P0636<@Q1BU7>LQ21cW0QS600<YBSW>=Jd00RDY
00PaS3F]:DXQ22DY:DXU:B480QcW11BU00@HaQBU5:DDY@8HaP045:D@Q12448@35:D01a245:DDYABU
36<@Q0aS008@Q0085:DHaQ2436<@Q1BU6<HDY@@@Q0035:D@Q1BU00@HaP8DY@0348@DYABU008DY@03
6<HDYABU008@Q00:5:D@Q1BU48@DYAS65:DHaQBU6<H27>L26<H25:D01A245:DHaQcW6<H00Q240aBU
00<@Q1BU48@011BU112400@DYA2448@@Q08<H`<@Q08HaP8DY@0548@DYABU48@DY@0348@25:D348@3
5:D348@25:D00a2436<@Q00348@236<248@336<548@236<00`Q236<<H`0236<3248010aS48@@Q124
0PQ21`aS0Q2400@DYA245:D@Q08<H`8@Q08DY@L@Q08<H`T@Q0@<H`03248<H`aS00<<H`0448@<H`aS
36<348@336<00`Q236<<H`0648@00`aS48@<H`0248@236<01@Q236<@Q12436<00@@Q00000`@Q0004
8@05124020Q200048@Q2;F]NmdHa:DX2;F/012U:;F/e[CF]0S6<00<]Jc6<<H`00be[0S6<00<e[C6<
:DX01be[00<YBS6<=Jd00SF]00XaS3g_?NlicSF]>Li243g_<H`]J`<aS0PYBP04<H`]Jbe[:DX3;F/0
2CF]>Lhe[CF]:DXU:BU:8@PU:@038@P00bDY:DXU:@038@P012DY:DX]Jc6<0RU:00D]JcF]=Jd]JbDY
00<YBP<Q20<U:@048@PU:BDY:DX29BT032489BTYBRU:9BTQ22DY:DXQ21cW6<HLi`8U:@05:DX]JbDY
9BTQ20027>L01AS68@PLib48;F/00S6<00<U:B48:DX00RU:1RDY00L]JcW>>Li6<D8@<H`YBP028@P0
1RDY8@PQ22489BTYBP8]J`05:DX]Jbe[=JdaS002:DX00bDY8@PLi`078@P37>L48@P37>L25:D01QS6
5:DHaQBU6<HDY@8HaP075:DHaQcW7>LQ22DY8@P00acW0bDY0R480bDY00<Q22DY9BT00RDY00@Q21cW
8@PHaP<DY@037>LHaQcW008U:@<Q208U:@<Q20067>LQ21cW7>LQ21cW0RDY00@YBRDY7>LHaP@Li`03
6<HDYAS6008DY@<<H`04248<H`Q2248312400`Q21248@P071243248712402`Q21248@P@Q24848@Q2
1248@P@Q24800P@Q00@8@P@Q12448@88@P031248@PQ20088@P@48@88@P848@<8@P@48@88@P@48@03
24848@@Q00D48@88@P<48@88@P031248@P@Q0088@P0336<8@PQ200<8@P<<H`0548@DYABU6<HQ2003
9BT012U:;F/]Jbe[0RU:00DaS3W>>Lhe[BU:00DLi`8DY@056<HDYABU5:D@Q0025:D26<H011245:DD
YA240PaS00D@Q1BU48@DYA24008<H`0348@DYAS6008DY@0336<@Q124008@Q0035:D@Q12400@DY@8@
Q08DY@0548@DYAcW7>LHaP0348@25:D26<H25:D00a245:DLi`037>L00a245:D@Q00248@01QS65:DD
YABU48@<H`8@Q08DY@8HaP037>LHaQS600<@Q08DY@<@Q0046<HDYABU48@35:D00acW6<HHaP035:D3
48@01aBU48@DYABU48@DYA2400DDY@8@Q0<<H`<@Q0055:D@Q12436<8@P0236<448@636<00`Q236<<
H`0236<0112436<@Q0aS0a241PaS00<8@PaS36<00a2400L<H`Q236<HaR486<H@Q00236<248@436<2
48@01ABU48@@Q0aS48@00QBU00<@Q0Q236<00Q240`aS00D@Q0aS36<8@PaS0088@P8<H`8@Q0<<H`03
248@Q0aS00T<H`0348@<Ha2400@<H`48@P0000<000@Q12400P@Q00<000@Q12400`@Q00L8@RU:HaQ:
DRU:=JdaS002;F/012U:;F/]Jbe[0SF]0Re[0RU:00<]JbU:<H`00SW>00HaS2DY9BT]JbU:;F/2:DX0
0be[<H`e[@04=Jd2>Lh2@Q02>Lh00c6<;F/aS002<H`00be[:DX]J`05:DX3;F/2:DX00be[<H`]J`03
;F/012U:9BTQ22DY1B4800<U:B488@P00R4800<U:BU::DX00RU:0c6<1Be[00<YBR488@P012DY0b48
12DY00TYBRDY9BTQ21cW8@PU:BU:8@P00QcW00<U:Be[9BT00bU:00/Q21cW7>LQ21cW8@PU:BU:<H`]
JbU:00<U:@04:DXU:BDY9BT3:DX01bDY:DXmkdHa?NlaS248008U:@<Q20<YBP049BT]Jbe[;F/2<H`2
;F/00bDY8@PQ20028@P01AcW6<HLib489BT01B481AcW0QS600<@Q1S65:D00aBU00<HaQBU6<H00aS6
00@Q22DY8@PQ20<Li`058@PU:BU::DXU:@038@P59BT012487>LHaQS611BU0b4800<U:B489BT00b48
00/U:BU:8@PHaQBU8@PYBQcW6<HLib48008U:@8Q208HaP057>LHaQcW6<HDY@0248@336<224831240
10Q21248@PQ210@Q00D8@P@Q1248@P@Q00<8@P848@0324848@Q200D48@0324848@Q20088@PT48@88
@P848@0324848@@Q00D48@<8@P@48@0824848@@Q24848@Q21248@P848@88@P848@0424848@Q22484
124010Q212448@@Q0PQ200<<H`Q224800PQ200@<H`Q2248<H`8@Q08HaP037>LQ22DY008U:@07:DX]
Jbe[;F/YBRe[<H`00SW>00@]Jb486<HQ208Li`035:DHaQBU008HaP0748@DYAS67>LHaQBU48@00aBU
112400<DYA245:D01QBU11240QBU00@@Q1BU48@@Q0HDY@0748@DYAS67>LHaQBU48@011BU00H@Q1BU
5:DHaQBU6<H47>L25:D348@25:D00a2436<@Q00248@00aS65:DDY@025:D27>L021S648@<HaBU48@<
Ha245:D26<H01A245:DDYA245:D00aS61QBU00@@Q1BU5:DDY@8@Q00336<DYA2400@DY@0348@<Ha24
008<H`D@Q08<H`88@PH@Q00736<8@PaS36<8@PaS24800`aS00<@Q0aS36<00`aS00<@Q0aS36<01@aS
00<@Q0aS36<00Q240PaS00DDYAcW6<H@Q0aS00<@Q00536<@Q12448@<H`0648@011BU36<<Ha2410aS
00<@Q0aS36<00`aS00<8@PaS36<00`aS0Q2410aS0Q2400L<H`Q236<@Q1BU48@8@P0736<224800084
8@0300048@@Q00H48@05248]Jekg@Q0]J`02=Jd3<H`013F]<H`aS2e[0S6<00<]JbU:;F/00bU:00D]
Jc6<;F/]JbU:00D]J`<aS0<]J`@aS006>Li243g_>Lhe[BU:0be[00DaS2e[;F/aS2e[00TYBP039BTQ
2248008U:@<Q208Li`8HaP8Q20039BTYBRU:008]J`04<H`]Jbe[;F/2:DX00bDY8@PYBP03:DX01B48
7>LQ22DY;F/00RU:00DQ22DY9BTQ22DY008YBP<U:@@Q2005:DX]Jbe[<H`e[@02<H`01BU:;F/YBRe[
:DX00RDY00HQ22DY9BTU:B489BT3:DX01Be[:DXU:BDY8@P00RDY00PYBRe[;F/aS3F];F/U:B480bDY
00<Q22U:;F/012U:00@]Jc6<;F/]J`8U:@068@PLib487>LQ21cW0b4800<U:B488@P00R4800DLibDY
8@PQ21cW00@HaP035:DHaQS6008DY@0348@DYABU008HaP037>LHaQcW00<Li`@Q20@Li`<Q20@U:@8L
i`036<HLiaS600<HaP037>LQ224800<Li`8YBP@Q20039BTQ224800HLi`076<HDYABU7>LQ21cW6<H0
10aS0`Q200@48@Q2124000848@88@P@48@0424848@@Q1243248412400`Q212448@0=12400`Q21248
@P0212400`Q212448@0324800`@Q24848@07124424851242248612422484124424800`@Q2488@P02
124224801@aS2488@PQ236<00PQ200@48@Q236<<H`8@Q08HaP057>LU:BDY:DXU:@028@P012DY;F/a
S36<0Re[00Te[CW><H`]Jb487>LQ21cW8@P00QcW00DDYAS65:DDYAS600<DY@<@Q0<DY@0348@<Ha24
008@Q08DY@<@Q08DY@0348@<H`aS008DY@8@Q0<DY@0448@DYAS66<H25:D00a245:DHaP056<H00acW
5:DDY@025:D01B487>LHaQS648@00aBU1A241QBU0QcW0QS60QBU00<@Q1BU5:D00QBU00DHaQBU6<HD
YAS600<DY@036<HLiaS600HDY@@@Q08DY@0348@DYA2400<DY@8@Q08DY@0548@<Ha245:D@Q00736<0
0a2436<<H`0336<224801`aS248<H`aS248<Ha2400@<H`0348@<H`aS008<H`0348@<H`aS00@<H`03
48@<H`aS008<H`8@Q08<H`/@Q08DY@8@Q0035:D@Q0aS008<H`8@Q00336<@Q0aS00H<H`8@Q0L<H`03
48@<H`aS00D<H`8@Q08<H`04248@Q12448@224800008124000@Q124000@Q0008@P<48@06248aS6Li
AS4U:C6<0SW>0S6<00T]Jc6<=Jde[C6<;F/aS2e[<H`00RU:00@U:BU:<H`aS0L]J`8aS08]J`8YBP8]
J`04<H`e[CW>>Lh2=Jd0236<=JdaS36<;F/YBRe[<H`4;F/2:DX012DY:DXYBRU:0RDY00<Q22DY9BT0
0R480RDY00@Q21cW7>LLi`8Q20@U:@05:DX]JcF]<H`]J`03:DX00be[9BTU:@029BT00bU:9BTQ2004
9BT2:DX39BT01B489BT]JbU:9BT00R4812DY00TQ23F]?Nm243F];F/aS2e[:DX00RDY00@YBRDY8@PQ
208YBP038@PLib4800@YBP079BTYBRU:9BTQ22DY:DX00SF]0Re[00@Q22DY9BTQ208U:@8YBP039BTY
BRU:008]J`04:DX]JbU:;F/29BT38@P37>L48@P27>L02bDY8@PLiacW8@PU:AS648@DYAS67>L00QS6
00<LiaS66<H01QS611cW00HQ22DY8@PLib487>L68@P49BT27>L26<H02acW6<HLib489BTLiaS68@PU
:BU:9BT00QcW00DQ21cW9BTU:B4800<Li`8Q208Li`036<HLiaS6008HaP035:D@Q0aS00<<H`88@PD4
8@0724848@@Q1248@P@Q00001P@Q00<8@P@Q12401`@Q00<8@PaS24800`@Q0PQ200<48@0012400P@Q
00@8@P@Q12448@D8@P<48@0324848@@Q00848@0324848@Q200<8@P848@0324848@Q200@48@032484
8@@Q00@48@<8@P<48@L8@P848@T8@P8<H`8@Q0036<HDYB48008U:@058@PLiacW9BT]J`02<H`2;F/0
1C6<?Nlmkc6<;F/012480QcW0aS600HDYAS65:D@Q1BU48@35:D648@00aBU48@@Q00348@00aBU48@@
Q00548@25:D248@00`aS5:DLi`027>L448@25:D26<H27>L01aS65:DHaQS67>LHaQBU00<@Q0055:DH
aQBU48@<H`0448@01QBU6<HHaQBU6<HLi`8HaP<@Q0035:DHaQS600DHaP<DY@DHaP<DY@0548@DYA24
48@<H`0348@35:D021245:DDYABU48@DYA245:D548@010aS48@<Ha241@aS00@@Q0aS36<<H`@8@P03
36<@Q124008<H`03248<Ha24008<H`0448@<H`aS48@236<00`Q236<<H`0636<01A245:D<H`aS2480
0Q240`aS0a2410aS0QBU0Q242PaS00@@Q0aS248<H`8@Q00336<8@PaS00@<H`0348@<H`aS0088@P8<
H`0348@<H`aS00<<H`8@Q04<H`48@P0000<000@Q12401@@Q00/8@P001248@SW>OomS63F]AS4mkcW>
00<aS005:DX]Jc6<>Li24002>Lh01CF];F/YBRU:;F/01CF]00@]JbU::DXYBPH]J`07<H`]Jc6<<H`e
[C6<;F/00c6<00P]JbU:;F/e[C6<=JdaS3F]0c6<00<]JbU:9BT00RU:00XU:AcW7>LQ22U:9BTQ22DY
:DXQ20<Li`049BTQ21cW7>L2:DX01CF]>LhaS3F]<H`00SF]00<aS2e[9BT00RDY00<YBR488@P00R48
0RU:00@U:B489BTLi`8Q20059BT]JbU::DXU:@048@P00bDY;F/e[@02?Nl023W>?Nle[CW><H`e[Be[
9BT28@P02RU:<H`aS2U:9BTQ22DY:DXU:B480RU:0bDY0bU:00<]Jc6<;F/012DY00<Q22DY9BT00RU:
00@U:BU:;F/YBP8U:@048@PYBRU::DX28@P00acW9BTQ20048@P012DY7>LLiacW0b480QcW0aS60QBU
0QS60R480aS600<DYAcW5:D00aS611cW00@HaQcW7>LLi`8HaP8Li`8Q20057>LQ22DY9BTQ20067>L0
1b489BTQ22487>LHaQcW008HaPLLi`076<HDYAS67>LHaQBU7>L00b4800<DYA2436<00PaS00D8@PaS
24848@Q200L48@88@P0536<48@Q21248@P0512400`Q212448@0212401@Q212448@@Q248030@Q0PQ2
1@@Q0PQ210@Q00@8@P@Q00048@@8@P<48@0324848@Q200848@0324848@Q200H48@88@P<48@P8@P05
1248@PQ224848@09248040@Q248<H`aS248<Ha2436<HaR48:DXaS2e[9BTYBSg_0Tic0SW>00=>LdYB
?Nl00bU:00HU:B487>LLiaS65:D348@00`aS48@@Q0025:D348@01aBU48@@Q1BU48@<Ha2400<DY@8@
Q00336<@Q124008DY@<@Q0035:DHaQS600@DY@056<HDYABU48@DY@027>L011S65:DDYAS60R4800DH
aQBU6<HDYAS6008@Q00536<@Q12448@DY@036<H248@45:D01A245:DDYABU48@00aBU00@@Q1BU6<HL
i`@DY@046<HDYA2448@25:D01QS65:D@Q1246<HDY@8@Q0DDY@8@Q0035:D@Q124008<H`0448@DYABU
5:D248@336<648@236<010Q236<8@PQ20PaS00T@Q0aS248<Ha2436<@Q0aS48@01PaS1A241PaS00<@
Q0aS48@00Q240`aS0Q2400DDYA2448@<Ha2400H<H`0348@<Ha2400P<H`06248<H`aS48@<H`Q210aS
00<8@Q2448@00Q241`aS00@8@PaS36<@Q048@P000`@Q00<000@Q00000P@Q00P8@P@Q1248@SF]NmiJ
eSg_0Tic00Q6<CW>>Lhe[Be[:DX]Jc6<0SW>00Y244YB=JdYBRDY:DXicSg_=JdicP8aS0X]J`8aS004
=JdaS3F]=Jd2<H`4;F/01C6<=Jde[CW>=Jd00S6<0be[0bU:0RDY0b4800PU:BU::DXU:AcW8@PLib48
11cW0RDY00P]JcF]?NlmkcF];F/aS3F]0S6<00/]JbDY:DXU:B487>LQ22U:9BTYBRDY008Q20037>LU
:B48008YBP<U:@<Q200<9BTYBRU:>Li243g_<H`]Jc6<>Lhe[Be[0RU:00DU:BU::DXYBRe[00<YBP03
9BTQ22DY00@U:@048@PU:BDY:DX2>Lh0136<:DXLib480RDY00@Q22DY:DXU:@@YBP04;F/U:B489BT2
:DX00bDY8@PQ20028@P01bDY8@PQ21cW6<HQ21cW00<Q20037>LHaQcW008Li`036<HDYAS6008HaP8L
i`038@PLiaS6008HaP@Li`8HaP068@PLib487>LHaQBU0QS60acW00@HaQcW8@PQ208U:@8Q208Li`03
6<HLib48008U:@038@PLiacW008Li`<HaP<Q20049BTLiacW7>L46<H27>L01B487>LDYABU48@00PaS
0PQ200H48@Q21248@P@Q2482124010001248@PaS0PQ200D000@Q12448@Q200<48@88@P<48@042484
8@@Q1242248212400`Q212448@0212401@Q212448@@Q24801@@Q00<8@P@Q24801P@Q00<8@P@Q1240
1PQ200<48@Q212400PQ200<48@Q212400`@Q00<8@P@Q124010@Q00<8@P@Q248020Q210@Q1PQ200<4
8@Q212400`Q20PaS01H@Q0aS48@DYB487>LQ22U:;F]244HaBU96<D8@AS5>LdHa>Lhe[C6<:DXU:@<L
i`066<HDYA2436<@Q1BU0QS60Q2400<<Ha2448@00Q2400<<Ha2448@00QBU0Q2400HDYA245:D@Q1BU
6<H35:D00a245:DHaP026<H00aBU48@DY@045:D011246<HHaQS60QBU1QS611BU0Q240PaS0QBU00<H
aQBU48@00QBU00<HaQBU48@011BU00<HaQ245:D00Q2400HDYAS66<HHaQBU48@25:D021S65:D@Q124
5:DHaQ2436<25:D348@00aBU6<HHaP025:D848@00aBU48@@Q0025:D0112436<<H`aS0a240`aS00@8
@PaS36<<H`88@PH<H`0548@<Ha2436<8@P0336<00a2436<<H`0348@00`aS48@@Q00248@00`aS48@<
H`0636<248@336<01A245:D@Q12436<0112410aS00@@Q0aS36<<H`8@Q003248<Ha2400<<H`03248<
H`aS00@<H`8@Q0d<H`0000<000@Q00001@@Q00T8@P001248@S6<LiaNmcW>BU800Tic00=:DTHa?Nl0
0S6<00<]Jc6<>Lh00cW>00TaS2e[<Ha244Ha@Q0e[C6<>Lh00S6<0be[00@aS2e[;F/YBPDaS004=Jda
S36<<H`3=Jd4<H`01cW>?Nlmkcg_>LhaS2e[008YBP8U:@<Q20079BTYBRe[;F/YBR486<H00acW00TU
:B488@PLibDY;F/e[Cg_=Jd00S6<00@]Jc6<<H`aS08]J`07<H`e[CF];F/YBRDY:DX012DY00@Q21cW
6<HLi`8U:@8YBP@U:@07:DXU:BDY;F/aS3W>=Jd00S6<00H]JbU::DXYBRe[:DX2;F/01C6<;F/]JbDY
8@P00RU:0Re[00/YBRDY9BTQ22DY;F/e[C6<:DXQ22DY008YBP048@PU:BDY7>L29BT00bU:;F/YBP03
8@P2:DX01R489BTYBRe[:DXU:@<Q20037>LQ22DY008Li`068@PU:BDY8@PHaQBU0QS600<LiaS65:D0
0QBU00DLiaS66<HHaQBU00<HaP@Li`066<HU:Be[9BTLiaBU0aS600<DYAS67>L00QcW0R4800@U:B48
8@PU:@@Li`@Q20059BTQ22487>LHaP038@P01AcW8@PU:B487>L00QBU0acW00@U:BU:7>LDY@8<H`03
48@<H`aS008@Q00336<8@P@Q0088@PD48@04248<H`aS24851243248;1242248212400`Q212448@02
12401`Q212448@@Q24848@Q200848@@8@PH48@0524848@Q21248@P0312462487124624800`@Q248<
H`0236<324831242248212400`Q21248@P0224801`@Q2488@PQ21248@P@Q0088@P<<H`0;5:DLib48
9BTicTHaBU8mkcW>?Nm>L`02DY@015[FCW=2436<0QcW00@DYAS648@@Q08DY@036<HDYA24008@Q0<D
Y@0348@<H`aS00<DY@8@Q00336<@Q12400HDY@8HaP075:DHaQcW6<HDYA245:D00QS60aBU00X@Q1BU
6<HLiaS65:DHaQBU6<HDY@<@Q0046<HDYA2448@236<25:D01Q245:D@Q1245:D<H`8@Q08DY@056<H@
Q0aS36<@Q0035:D00a245:D@Q00348@00aBU48@DY@025:D021S648@@Q1BU48@HaQBU6<H348@25:D0
1A245:DDYA245:D00a2400<<Ha245:D00aBU00H@Q0aS48@@Q1BU6<H248@436<00`Q236<<H`0236<0
0`Q236<<H`0236<010Q236<<Ha240PaS00<8@PaS48@00Q240`aS112400<<Ha2436<00`aS00H@Q0aS
48@<Ha2436<448@00`aS48@8@P0236<248@336<00a2436<<H`0236<00a2436<<H`0536<00`Q236<<
H`0236<324801@aS48@<H`aS24800PaS00<@Q0aS36<00PaS0A240@aS0@Q2000512400`0012448@03
12401@Q2;F]cW5[F>Lh00THa0TYB00I>LdYB?Nle[Be[<H`2=Jd01Sg_@Q0aS2U:;F/e[@96<@06?Nli
cSW>>Lhe[C6<12e[0S6<00<]JbU:;F/0136<00He[C6<<H`]Jc6<=Jd2>Lh2=Jd02CW>@Q0mkcW>=Jda
S2U:;F/U:@028@P01BDY:DXQ2248;F/00S6<00HYBR487>LLiaS67>L38@P00bDY:DXe[@02>Lh033F]
<H`aS36<=JdaS2e[:DX]JcF]<H`e[@@YBP049BTYBRDY8@P27>L00aS67>LLi`049BT01bU:9BTU:BDY
:DX]JbU:008aS08e[@04;F/YBRDY9BT2;F/00bU:<H`YBP02;F/2:DX29BT4;F/01bU:8@PQ22DY;F/a
S2e[008YBP048@PYBRU:9BT38@P01bDY:DXYBRU:9BTQ22DY008YBP8Q2003:DXaS2e[008Q20039BTQ
224800@Q200<7>LQ22488@PHaQBU6<HLib486<HDYA240QS600HLiaS66<HHaQBU6<H37>L00b486<HL
i`029BT01RU:9BTQ21cW6<HDY@HHaP@Q20039BTQ21cW008HaP037>LQ2248008U:@8Q208Li`048@PL
ib489BT2:DX01BDY7>LHaQBU6<H00QcW0RDY0R4800@@Q1BU36<<H`@@Q00336<8@PQ200H48@04248@
Q0aS24841242248712400`001248@P03248212400`Q212448@0312400`0012448@05124010Q21248
@P@Q0PQ200<48@Q212401P@Q00<8@P@Q24800`Q210@Q00<8@P@Q00000P@Q0PQ210@Q00<8@P@Q1240
0`Q20`aS00H8@P@Q1248@PaS2482124010Q21248@PQ21@@Q0PQ20`@Q00P8@PaS248@Q0aS48@HaR48
0S6<00de[Cg_@Q0mkdHaBU9F]F<HF]IBU48@:DXLi`026<H011BU36<@Q0aS0QBU0Q240PaS0Q2400@D
Y@aS36<@Q0<DY@0336<@Q12400<@Q0@DY@056<HLiaS66<HLi`026<H011BU48@DYAS62aBU00@HaQ24
48@@Q0@DY@0348@<Ha24008@Q0035:D@Q124008DY@046<H@Q12436<25:D00aS648@@Q00248@01@aS
48@DYABU48@00PaS11240QBU00H@Q1BU5:DDYAS65:D348@25:D248@011BU48@@Q0aS1Q240PaS00<D
YAcW5:D00PQ200@<HaS65:DDY@<<H`0648@<H`aS36<@Q0aS0PQ200<<Ha2448@010aS00<8@PaS36<0
0`aS0Q240PaS00<@Q1BU48@0112400D<Ha2448@@Q0aS008@Q0045:D<Ha2448@25:D336<00a2436<@
Q00536<02A2436<<H`aS48@<Ha2436<8@P0436<00`Q236<8@P0236<2248236<348@836<148@136<1
2480000300048@0000D48@0924848@00248]Jg>LF]HaS3W>008mk`03AS5243g_008icP04=JdicT8@
@Q02?Nl3<H`00cF]>LhicP02?Nl2>Lh013F]>LhicSW>0SF]136<0cF]1Be[136<00@]JbU:<H`icP96
<@03>LhaS3F]008e[@04:DXU:AcW7>L58@P29BT012489BTQ22DY0R480RDY0Re[00<aS3W>=Jd00be[
0S6<00@]JbU:;F/]J`8YBP049BT]Jbe[;F/3<H`00be[9BTU:@047>L00b489BTYBP02:DX01BDY:DX]
Jbe[<H`00be[00@YBRe[:DXYBP8U:@<YBP079BT]JbDY9BT]Jc6<>Lh00cF]00<aS2e[;F/00R4800L]
Jc6<;F/U:B489BT]J`02:DX00bDY8@PQ20029BT3:DX79BT012U:;F/]JbU:0bDY00<Q21cW7>L01248
00DLiaS66<HHaQcW00<HaP8Li`<HaP055:DHaQS66<HLi`026<H00acW8@PU:@028@P02RDY8@PU:AcW
8@PLiaS65:DHaQcW0QS600<DYAS67>L00QcW00@Q21cW7>LLi`<U:@037>LQ2248008Q20056<HLiacW
7>LU:@03:DX00bDY8@PQ20028@P00acW6<HLi`037>L02A2436<<H`Q248@Lib487>L@Q00324800`@Q
2488@P03248612400`Q212448@041242248312400`Q236<8@P0<1240100012448@Q210@Q00<8@P@Q
24800`Q200<48@0012400PQ20P@Q0PQ20`@Q00<8@P@Q12400`@Q00<8@P@Q12401@@Q0`Q20`@Q10Q2
00<48@Q224800P@Q0PQ200D48@00248<H`Q200848@<8@P<48@@8@P0336<8@PaS008<H`0848@DYABU
8@PLicF]@Q1BU09JeP9[FP04HaQBU36<;F/26<H00aBU48@<H`0248@35:D00a2436<@Q00648@45:D0
11245:DDYABU0Q2400TDYAS66<HYBRe[8@PLiaBU48@00QS611BU00<@Q1BU6<H01QBU00T@Q1BU5:D@
Q1BU48@DYA2436<011240PaS11240aBU00<@Q0aS48@00QBU00<@Q0aS48@00QBU00<HaQ2448@00Q24
0aBU00<@Q1BU5:D00QBU0Q2400@DYAS66<HDY@8<H`0548@DYABU48@DY@0248@00aBU48@@Q00248@2
5:D011S65:D@Q1BU0Q240PaS112400@<Ha2436<@Q08<H`04248<Ha2448@224801`aS48@<H`aS248<
Ha24008<H`07248<Ha2448@<H`Q236<00QBU00D@Q0aS36<@Q0aS00L@Q08DY@8@Q08<H`8@Q0P<H`04
48@<H`aS48@436<01Q2436<<H`Q236<@Q0<<H`0448@<H`aS36<348@01PaS48@@Q0aS248<H`8@Q04<
H`48@P000`@Q00D000@Q124000Q200<48@0736<icWNmE[DaS3W>@Q000cg_00=243g_>Lh00SW>00He
[C6<@Q1:DTHa>Lh2;F/5>Lh3=Jd2>Lh00cF]<H`e[@02=Jd01Re[<H`aS36<=JdaS08]J`8aS08]J`8a
S003;F/aS3W>00924003>Lhe[C6<008icP03<H`YBQcW00LQ208U:@@Q20077>LQ2248;F/YBS6<>Lh0
0SF]00<aS2e[;F/00S6<00H]JbU:9BT]Jc6<:DX29BT7;F/29BT011cW8@PQ21cW0R480bDY00<YBRe[
;F/00Re[00HYBRe[;F/]JbU:9BT2:DX29BT2:DX2;F/2:DX01cF]>LhicSW>=JdaS2e[008U:@04:DX]
Jbe[:DX28@P01BDY:DXYBRU:9BT00R4800@U:BU::DXYBP8U:@8Q20049BTQ22DY9BT5:DX012487>LQ
21cW124800<HaQcW6<H00QS600<DYAS66<H00QcW0QS600@DYAS66<HLi`DHaP0:7>LQ22U::DXU:B48
7>LQ21cW8@P27>L00b487>LLi`025:D26<H01aBU7>LLib487>LHaQcW008Q20059BTQ22DY8@PLi`03
8@P01AcW8@PU:Be[<H`00RU:00DQ21cW8@PLib4800<Li`8DY@036<H<H`Q2008<H`096<HLiaS636<8
@P@Q36<8@P@Q0088@P8<H`848@0300048@@Q00@8@PT48@88@PP48@0300048@@Q00<48@@8@P031248
@P@Q00D8@P031248@P@Q00D48@88@P061248@P@Q24848@Q210@Q00<8@P@Q12401@@Q0PQ200D48@Q2
2488@PaS00<8@P848@D8@P848@88@PD48@0324848@@Q00848@H<H`<@Q00=6<HDYBe[<Ha:DTicDYAS
66LiKg]NmdYB>Lh00R4800H@Q0aS36<<Ha2436<248@35:D01Q245:D@Q12436<@Q0<DY@0448@DYABU
6<H348@00aBU6<HHaP048@P01ABU6<HDYABU6<H00QBU00@@Q1BU6<HDY@8HaP0348@DYA24008DY@8<
H`0348@HaQBU008@Q08DY@L@Q0065:DHaQBU5:D@Q0aS0Q2400LDYA2448@@Q1BU48@DY@0348@236<3
48@00aBU48@@Q0075:D248@35:D00a2436<@Q00448@25:D348@25:D011S65:D@Q1240`aS0Q2410aS
0Q240PaS00<8@PaS36<00`aS0a2400D<H`Q2248<H`Q200<<H`D@Q0055:D@Q0aS48@<H`0548@011BU
48@DYABU0Q2400<<Ha2436<00Q2400D<H`Q2248<Ha2400D<H`0348@<H`aS008<H`8@Q0@<H`0348@<
Ha24008<H`0348@<H`aS008<H`0548@DYA2436<8@P0536<12480000300048@@Q00848@0>00048@@Q
24848@00248aS6mkDY@]JcW>?Nle[@<icP8e[@8aS08icP03?NlicSF]00<icP05?Nle[CF]<H`e[@02
<H`2;F/013F]?Nm243g_0S6<00De[C6<>LhicSg_008e[@8aS0De[@8aS0<e[@03<H`]Jc6<008]J`06
9BTQ22DY9BTYBRDY0R4800<U:B487>L00acW00DQ22DY:DXaS3F]008icP8e[@04<H`]JbU::DX29BT2
:DX39BT4:DX3;F/01BU:;F/YBRDY8@P00bDY00@Lib488@PQ20LU:@04:DX]Jbe[;F/3:DX00be[:DXY
BP029BT3:DX29BT02BU:;F/e[Cg_=JdaS2U:9BT]J`02:DX49BT01Be[:DXYBRe[:DX00RDY00<Q22DY
9BT00RU:00HU:B488@PQ22DY8@P27>L00bDY:DXU:@028@P39BT2:DX012DY:DXQ21cW0QS60QcW00@H
aQcW7>LDY@<HaP8Li`035:DHaQS6008DY@046<HLibDY7>L38@P01BDY7>LLiaBU6<H01QcW00@HaQcW
6<HLi`HHaP8Li`8Q208YBP088@PLib48:DXaS2U:9BT]J`8YBP038@PLiaS6008HaP055:D@Q0aS48@<
H`02248212400`aS48@<H`0336<01Q2436<<H`aS1248@P848@<8@P@48@88@P@48@0324848@Q200<4
8@88@P848@0324848@@Q00H48@0324848@Q200848@04248<Ha2448@236<224831243248212400`Q2
12448@021242248212400`Q212448@0412422484124224800`@Q2488@P07248212400`Q21248@P03
12400`Q212448@0312401PQ21248@PQ21248@P<<H`848@0A248<Ha2448@HaQBU<H`mke[FJeYW>F]J
HaQF]E:D=JdYBP025:D02A2436<@Q0aS48@DYAS648@<H`0248@25:D248@011BU6<HHaQBU1A240QBU
00<LiaS68@P00b4800DDYA245:D@Q1S600<DY@0348@DYABU00@@Q0<DY@0448@DYA2436<35:D648@0
10aS48@@Q1BU0QS60QBU0Q2400@DYA2448@DY@8@Q0085:DHaQS66<HDYAS67>L@Q08<H`0448@LiaS6
48@336<25:D00a245:DDY@0248@010aS48@DY@aS0Q2400LHaQBU5:D@Q1BU48@<H`0248@25:D;48@4
36<0112436<<H`Q20PaS00<DYA2436<010aS00<@Q0Q236<010aS112410aS00@@Q1BU5:D@Q08<H`8@
Q0035:D@Q1BU008@Q08DY@8@Q0D<H`03248<H`Q200D<H`<@Q08<H`0348@<H`aS008<H`<@Q0H<H`04
248<H`aS36<348@1248000<48@0300048@@Q00848@0;248000@Q36<aS6mkE[DaS3g_>Lhe[@04>Lh2
=Jd013W>=JdaS3F]0Sg_00De[C6<=JdicSg_008icP8e[@8aS006;F/e[CW>?NlicSF]0SW>0S6<00<i
cSg_>Lh00S6<0SW>00<e[C6<=Jd00c6<00<e[CW>>Lh00S6<00<]JbU::DX00RU:00<Q22DY9BT00bDY
00<Q21cW8@P00b4800`LibDY9BT]JbU:<H`icSg_>LhaS2U:;F/29BT3:DX00bDY8@PYBP07:DX012e[
:DXYBRU:0bDY00DYBR487>LLib48008YBP049BTQ22U:9BT8:DX2<H`02bU:9BTYBRU:;F/YBRDY8@PU
:BU:=Jd0136<00D]JbU:9BTYBRDY00<YBP8U:@<YBP039BTQ2248008YBP8U:@06:DXU:B487>LQ22DY
0b480RU:00DU:B488@PQ22DY00@YBP047>LHaQS67>L28@P02AcW6<HLiacW6<HDYAS67>LHaP027>L0
11BU6<HDYABU0QS600<Q22DY8@P00b481AcW00<Q21cW8@P00QcW00<HaQcW6<H00aS60acW0QS60QcW
0bDY00HQ22DY;F/aS2U:9BT2:DX01RDY8@PQ22DY7>LHaP<<H`0748@<H`aS1248@PaS12400PQ20PaS
00H8@PaS36<@Q0aS2486124010Q212448@@Q0PQ200<<H`Q200000P@Q00<8@P@Q12400`@Q0`Q20P@Q
00<8@P@Q124010@Q00D8@P@Q12448@Q200@<H`0548@<H`aS36<8@P08124424821242248412432486
12400`Q21248@P0824800`@Q2488@P02248312401PQ212448@Q21248@P<48@88@P0436<8@P@Q1246
248348@03248<Ha>LekgF]IW>F<HJeYW>DHa>LhDY@D@Q08<H`0348@DYABU008DY@0448@<Ha2436<2
5:D26<H011BU48@DYA240QBU00@HaQcW6<HLi`8Q20037>LDYAS600<DY@8@Q0DDY@056<H@Q12436<@
Q0025:D548@45:D248@236<248@75:D01Q245:DDYABU6<HDY@8HaP035:DHaQBU00TDY@<@Q08DY@8@
Q0035:D@Q0aS008@Q08DY@0448@<Ha2448@25:D248@35:D01Q2436<@Q1245:D@Q08<H`8@Q0035:D@
Q124008<H`0348@<H`aS008<H`88@P0348@DYA2400D<H`04248<H`aS48@636<00aBU48@@Q00236<0
11245:DDYABU0PaS00D@Q0aS48@@Q1BU00<@Q0045:D@Q0aS36<248@00`aS248<H`0236<00`Q236<<
H`0336<00a2436<<H`0236<0112436<@Q0aS0Q240`aS00D@Q0aS48@<Ha2400<<H`0348@<H`aS004<
H`0000D000@Q12448@0000<48@0;24848@00248aS6]JCW<YBSF]>Lhe[@07<H`4>Lh4=Jd2>Lh013g_
>Lhe[CW>0d8@0SW>0SF]0cW>0SF]00HicSg_@Q1243W>?Nl5>Lh00cF]>LhicP02>Lh01c6<9BTU:B48
9BTYBR48008U:@04:DX]JbDY8@P67>L39BT2:DX01C6<>LhicSW><H`00be[00DYBRe[:DXU:BU:00HU
:@HYBP0:;F/YBRDY9BTQ22DY7>LQ22DY:DX59BT00b489BTU:@06:DX2;F/2:DX3;F/49BT4:DX01248
9BTYBRDY0RU:0RDY00@YBRe[:DXQ20<U:@<YBP039BTQ22DY008U:@078@PLiacW7>LHaR489BT00RU:
00DU:B489BTU:B48008U:@8Q208Li`098@PYBRU:7>LHaQcW8@PU:B4800DHaP8DY@0648@HaQcW7>LQ
21cW0QS60QcW00@Q21cW7>LQ20@Li`059BTYBRU:9BTQ20037>L36<H01AcW6<HLib489BT00R4800LL
ib489BTQ22U:9BTYBP039BT28@P01QcW5:DDYA2436<8@P<48@0724848@@Q24848@Q2124020Q22@@Q
00<8@P@Q24800PQ20`@Q00<8@P@Q24800`Q22P@Q00L8@P@Q12448@Q248@Li`036<H248@324891245
248;12401@Q212448@0012401@Q200@<H`Q212448@<8@P@48@0324848@@Q00<48@0324848@Q200<4
8@0324848@Q200848@L8@P8<H`076<HLicF]AS5F]F]JG_L00V]J00E6<CF]6<HLiaBU00<<H`<DY@04
48@DYABU48@46<H35:D248@25:D248@01QBU6<HLiaS67>LQ208Li`045:D@Q1BU48@65:D448@00`aS
48@@Q0035:D348@011S65:D@Q1240QBU1Q240aBU0Q240aBU0QS600<Lib487>L00QcW00@DYAS65:DH
aPDDY@066<HDYABU5:D@Q1BU0Q2400<<Ha2448@00Q2400@DYA2448@<H`8@Q08DY@8@Q08DY@0748@D
YA2448@<Ha2436<00Q2400<<Ha2448@00a240`aS0Q241PaS0Q241`aS00<8@PaS48@00`aS00<@Q0aS
48@00`aS00<@Q0aS48@00a2400<<Ha2448@01A2400D<Ha2448@@Q1BU00<<H`8@Q08<H`88@PD<H`04
48@<H`aS36<448@00`aS48@<H`0436<00a2436<<H`0236<248@2248000848@0400048@@Q00051240
1@aS<Ha[FTic;F/00SF]00@aS3F]=JdaS0<]J`03=JdicS6<00<icP<aS0<e[@08>Lhmkcg_>Li244Ha
@Q0mk`<e[@8icP8e[@03>Lhmkcg_00@icP05?NlicS6<<H`e[@02>Lh01CF]>LhicSF]<H`00RU:00<Q
22DY9BT00RU:00H]JbDY9BTU:B489BT28@P011cW6<HQ22DY0bU:0S6<0Re[00LaS3F];F/YBRDY:DX]
J`02:DX00bDY8@PQ20029BT01b48:DXYBRU:8@PU:BU:008]J`8YBP8Q20039BTQ22DY008]J`06:DXQ
22488@PU:B4812DY12U:1Be[00@YBRDY9BTU:@<YBP8]J`049BTQ22488@P3:DX01BDY8@PYBRe[:DX0
0bDY0bU:0RDY00HYBR488@PLibDY8@P37>L59BT28@P49BT27>L02B489BTYBR487>LHaQcW8@PLi`02
8@P01AcW6<HHaQcW6<H00QBU00DHaQcW8@PLiaS600<Li`038@PLiacW00@Q208YBP079BTQ22DY9BTQ
21cW6<H00acW00DHaQcW7>LLibDY008Q208Li`@U:@8Q208U:@05:DXU:AcW6<HDY@0248@224800`@Q
2488@P03124524800`aS2488@P02248212400`Q21248@P02124224821242248612400`Q212448@04
248212400`Q212448@0812401@aS5:DDYAcW6<H00QBU00<@Q0aS12400PQ210@Q10Q200<48@Q22480
0`Q21`@Q0PQ200<000@Q12401@Q20PaS10Q20P@Q0PQ21@@Q00<8@P@Q12400P@Q0`Q20`@Q00<8@P@Q
24800`Q200<48@Q236<00PQ200T48@aS5:D@Q2DY>LiBU5kgE[D00V]J00UNmdic9BTQ21BU48@DY@aS
48@011BU00@@Q1BU48@DY@<HaP037>L@Q124008@Q08DY@8@Q08DY@056<HLib488@PLi`025:D01A24
5:DDYA245:D00Q2400HDYA245:DDYA245:D236<011245:DDYABU1A240QBU0a2400<DYAS648@00PaS
0aBU0aS60aBU0QcW00<Q22DY8@P00QS600<@Q1BU5:D00aBU0QS60QBU00<@Q1BU5:D00QBU00<@Q1BU
48@01Q240QBU0Q240aBU0Q2400@<Ha2448@DY@8@Q0<<H`@@Q0<<H`<@Q08<H`03248<H`aS00<<H`8@
Q0P<H`D@Q004248<H`aS36<348@336<0112436<@Q1240aBU0Q240PaS0Q240`aS00H8@Q2436<@Q0Q2
36<2248348@636<348@436<00a245:D@Q00336<011245:D@Q0aS0@Q200000`@Q00048@0512402@Q2
00048@Q2:DYJeT8@;F/e[@02>Lh0136<;F/]JbU:0S6<00De[CW>>LhicSF]008icP04=JdaS36<;F/2
=Jd00cg_@Q124003BU800d8@>LhicP03?Nl00cW>=JdaS004=Jd2?Nl00d8@?NlicP02=Jd3>Lh013F]
<H`]Jbe[0RU:12DY00LYBRDY9BTU:B489BTQ20037>L28@P29BT00bU:;F/]J`02<H`2=Jd2<H`00be[
:DXYBP02:DX49BT38@P00acW8@PQ20049BT012489BTU:BDY0R4800HU:BU:;F/]JbU:9BT28@P29BT0
1B487>LQ22489BT00b4812DY00DQ22DY9BTU:BU:008U:@038@PLib4800HU:@04:DXU:BDY9BT48@P4
:DX69BT28@P00acW8@PU:@029BT38@P012DY8@PU:B480RDY1b4800<Lib487>L00QcW0b4800@LiaS6
6<HDY@8HaP@Li`DHaP8Q20049BTYBRU:9BT2:DX29BT00bU:9BTU:@026<H00acW8@PU:@028@P27>L0
0b489BTLi`027>L29BT01B487>LU:BDY6<H0112400<<H`Q236<00PQ200<48@Q2124010@Q0PQ200@4
8@Q212448@L8@P031248@P@Q00<48@88@P8<H`<8@P<48@0324848@@Q00848@88@P@48@@8@P848@04
248@Q1247>L26<H011BU36<<H`aS0PQ200@48@Q22488@P@48@0324848@@Q00H48@0324848@@Q00<4
8@0324848@@Q00<48@04248<Ha2436<2248236<010Q212448@Q20P@Q0PQ20P@Q00<8@P@Q24800`@Q
00<8@P@Q12400P@Q0PQ20`@Q00H8@P@Q24848@Q2124236<01PQ236<<HaS69BTicP9F]@07Kg][FU[F
BU8Q21cW48@00PaS00@@Q1BU48@@Q08HaP@@Q0036<HLiaBU00<@Q0HDY@8HaP0:5:DHaQcW7>LHaQBU
6<HLiaBU6<H248@00aBU6<HDY@0248@26<H236<00aBU6<HDY@0348@65:D00aS65:DDY@025:D01Q24
5:D@Q1BU6<HDY@8@Q00H5:DHaQcW6<HDYAS65:DHaQcW8@PLiaS648@DYAS67>LDYA245:DHaQBU6<HD
YAS60QBU0QS60QBU00H@Q1BU5:DDY@aS48@65:D011S65:DDY@aS0a2400D<Ha2448@@Q0aS00@@Q005
36<@Q1245:D@Q00836<248@536<248@336<448@436<248@336<00a2436<<H`0336<348@336<011BU
48@<H`Q20`aS00<8@PaS24800Q2400@<H`Q2248<H`8@Q0H<H`0348@<H`aS00D<H`0348@<H`aS00@8
@P000`@Q00<000@Q00001@@Q00H8@RU:G_M242DY;F/2=Jd2<H`2;F/00c6<=Jd]J`02<H`3>Lh023g_
=Jde[C6<;F/aS3F]>Lh2?Nl0148@BU96<DYB0Sg_00DicSg_?Nm243W>008e[@04<H`e[CW><H`8>Lh2
=Jd2<H`012e[:DXYBRDY0b480bDY1B480QcW0b480bDY00DYBRe[<H`]JcF]008aS0<YBP04;F/YBRU:
:DX29BT38@P01RDY8@PQ22489BTQ20<U:@03:DXU:BDY008Q208YBP8]J`03:DXQ224800PQ20039BTQ
2248008Q208YBP<U:@038@PU:BDY00@Q20039BTYBRU:00<U:@038@PYBRU:00<U:@8Q208U:@<YBPDU
:@8Q208U:@05:DXU:B488@PU:@028@P011cW9BTU:BDY0b4800@U:B488@PLi`8HaP8Li`8Q20087>LQ
21cW6<HLiaS67>LHaP<Li`@HaP@Li`8Q2003:DX]JbU:00<U:@8YBP0<9BTLiaS67>LU:BU:9BTLib48
9BTQ21S60QcW00<U:AcW7>L00QcW0R4800DLiaS65:DDY@aS0088@P031248@PQ200@8@P848@042484
8@Q2248312482484124224800`@Q2488@P02248612400`Q212448@0512400`Q21248@P0212442480
0`aS5:DDY@025:D0112436<8@PaS0PQ220@Q00<8@P@Q24800`@Q0PQ210@Q00<8@P@Q24800PQ210@Q
0PQ210aS1PQ200<48@Q224800PQ200<48@Q212400P@Q00<8@P@Q12401@@Q00@8@P@Q12448@88@P84
8@0324848@Q200<<H`8@Q0049BU245:DKg/2HaP00ekg=JdYBP0248@01ABU48@@Q1245:D00Q2400HD
YAS65:D@Q1BU6<H25:D248@25:D00aS65:DDY@035:D011246<HLib481AS600@DYA245:DHaP8DY@03
48@DYABU00<DY@0448@DYA245:D248@01ABU6<HHaQBU48@011BU0QS600HDYA2448@DYA245:D248@0
21S67>LLiacW5:D@Q1S65:D27>L36<H25:D00aS67>LHaP025:D46<H00aBU6<HDY@035:D01AS65:D@
Q1245:D00Q240QBU00<@Q1BU5:D00QS60Q240QBU0Q2400<<Ha2436<00Q2400<DYA2436<00PaS0Q24
00<<Ha2436<00PaS0PQ200@<Ha2448@<H`8@Q0L<H`H@Q00436<8@PaS36<248@736<00a2436<<H`03
36<348@336<0112436<<H`Q20PaS00<@Q0aS36<00PQ20`aS00H8@PaS36<@Q0aS248236<00a2436<<
H`0736<124811240000300048@@Q00D48@0:24848@00248]JeJe?NlU:C6<>Lh8=Jd2<H`2=Jd013g_
@Q1243g_0SF]00<icSF]>Lh00cW>00<e[D8@@Q000dHa0TYB00=6<D8@?Nl01Cg_0SW>13F]1C6<00<Y
BRDY8@P00bDY00@Q22DY9BTYBP8Q20077>LQ22DY9BTQ21S67>L00R4800XYBRDY:DXYBS6<=JdaS2e[
:DXQ20<U:@05:DX]JbDY9BTLi`038@P00bDY7>LQ20028@P29BT38@P00bDY:DXYBP039BT00bU:9BTQ
20027>L01B489BTU:B489BT00R480QcW00@Q21cW7>LQ20<U:@<Q20069BTQ21cW8@PLib480RDY0R48
00DU:BU::DXU:Be[008e[@03;F/Q2248008U:@03:DX]JbU:00<U:@<]J`07:DXU:BU:;F/aS2e[:DX0
0RDY0QcW1b4800<U:B486<H00QS60acW00@U:BU::DXQ20<Li`<HaP057>LQ22489BTQ20027>L011BU
6<HHaQBU0QcW00<Q22DY9BT012DY12480RU:0Re[00<YBR489BT00RDY11cW00@HaQcW6<HDY@<@Q08<
H`@48@L8@P<48@88@P071248@P@Q1248@P@Q24800P@Q00@8@P@Q2488@P<48@04248<H`Q236<42484
124224821243248412400`Q21248@P02248236<324800`aS248<H`0312400`Q236<48@0212400`Q2
12448@02124010Q212448@Q210@Q0PQ20P@Q00<8@P@Q124010@Q0PQ20PaS0PQ200<<H`Q212401@Q2
00D48@Q224848@Q200<48@0524848@Q21240000512422483124824802`aS248Lid8@HaQkgUkgDYAF
]C6<9BT00Q2400<DYA2448@00Q2400<<Ha2448@00QBU0Q240QBU112400<DYA2448@00Q2400DHaQBU
6<HDYAcW008DY@0348@DYABU00<DY@0348@DYAS6008DY@0648@HaQBU5:D@Q1BU0a2400@DYA245:D@
Q08DY@036<HDYAS600<HaPDDY@036<HDYA24008@Q0@DY@036<HDYAS600LDY@0448@DYABU5:D26<H0
0acW6<HHaP026<H01ABU48@DYABU6<H00aBU0a2400PDYAS65:D@Q1BU7>LHaQBU0PaS0Q240QBU1A24
00DDYA2448@@Q1BU008@Q00336<8@PQ2008<H`0348@<H`aS00<<H`0348@<H`Q200D<H`8@Q0035:D@
Q12400L@Q00436<@Q0aS48@236<010Q236<<Ha241PaS00<@Q0aS36<00PaS00<@Q0aS36<010Q20PaS
00<8@PaS48@00PaS00<@Q0aS36<02@aS00D@Q0aS36<8@PaS0048@P0000H48@00124000@Q00031240
2@001248@Re[G_M24248;F/e[@02>Lh00cF]<H`aS004=Jd013W>=Jde[CW>0T8@00<mkcW>>Lh00SW>
0S6<00@e[CW>?Nlmk`=24006AS5:DTYBCW=:DT8@0Sg_00=244Ha?Nl00Sg_0SW>0S6<00<icS6<<H`0
0S6<00<]JbU:9BT012DY00@Q22DY9BTU:@8Q20037>LQ224800<Li`<Q20089BTQ22DY:DXaS3F]<H`Y
BP@U:@03:DXU:BDY008U:@8Q208U:@038@PLiacW008Q20039BTQ2248008U:@@YBP039BTYBRU:00<Q
20057>LU:B489BTQ20027>L38@P01acW8@PU:B489BTLib48008U:@038@PLib48008Li`0A8@PU:BDY
9BTQ22DY:DXU:B48:DXe[CW><H`Q22DY:DXU:@04:DX01BDY:DX]Jbe[<H`00bDY00@YBRe[<H`YBP<U
:@<Q208U:@<Q208Li`8Q208Li`8HaP048@PYBRe[:DX27>L01AS67>LLiacW6<H00QcW00<Q22DY8@P0
0QcW00<HaQcW6<H00QS60QcW00<Q22DY:DX00RU:00<Q21cW7>L00bDY00LYBRe[;F/]JbU:9BTQ2002
7>L26<H01AcW6<HHaQS65:D00Q2410Q200P48@Q212448@Q21248@P@Q1@Q20`@Q10Q200@48@Q21244
8@<8@P848@P8@P031248@P@Q00848@@8@P06124000@Q24848@Q20P@Q0`Q200<48@Q224800PQ20`aS
10Q20P@Q00<8@P@Q24800`@Q00<8@P@Q12401P@Q0PQ200<48@Q212400PQ20P@Q00L8@P@Q1248@P@Q
36<8@P0236<2248010aS2488@P@Q0`Q20P@Q10Q21@@Q00D8@P@Q12448@Q200848@88@P@48@H8@P0<
36<48A24;F]:DV]JF]INmf<HAS4aS1240aBU00H@Q1BU36<<H`Q236<448@011BU6<HDYABU0Q2400@D
YAS65:D@Q08DY@036<H@Q1S600@HaP8DY@8HaP8DY@0348@DYAS600HDY@<@Q0045:D@Q1BU48@25:D2
48@01ABU6<HDYAS65:D00aS600DDYAS65:D@Q1BU008HaP8DY@8@Q0035:DHaQBU008DY@<HaP8@Q08D
Y@THaPDDY@8HaP@DY@0548@DYABU5:DHaP065:D010aS48@@Q1BU1Q240PaS0Q2400<DYA2436<00PaS
00<8@PaS24800`aS00P@Q0aS36<<H`Q236<@Q0aS0Q240QBU112400@<Ha2448@@Q08<H`8@Q0<<H`04
48@<H`aS36<248@236<248@536<010Q236<<H`aS0PQ20`aS1A2400<8@PaS48@010aS00@@Q0aS36<8
@PD<H`88@P0020@Q00T8@P@Q1248@SF]IcU6<B48>Lh00TYB0T8@0SF]00@icSF]<H`e[@<aS003=Jdi
cT8@008icP04=JdicSF]>Lh2=Jd00cW>?Nm24003@Q02?Nl00d8@AS5>L`02CW<2BU802dHa@Q1243g_
@Q0mkcW>?Nle[C6<;F/00S6<00<]JbDY8@P00RDY0R480RDY0b480bDY00LQ22DY8@PQ21cW8@PLi`02
8@P02RDY;F/e[CW>?NlicRe[9BTQ21cW124800@Lib488@PU:@<YBP8Q208U:@03:DXU:BDY00TU:@@Q
20059BTLiacW7>LQ20029BT01B487>LQ22DY:DX00Re[00<U:B488@P00RDY00@Q22DY:DXYBP<U:@03
:DXU:BDY008Q208U:@04:DXU:BU::DX2;F/3:DX29BT012489BTU:AcW0R4812DY00DYBRe[;F/YBRDY
00<Q208U:@8Li`8U:@037>LHaQS6008Li`8HaP057>LQ22DY9BTQ20027>L00b486<HLi`028@P00bDY
8@PQ20037>L01aS67>LLiaS68@PLib48008YBP8U:@046<HLiacW7>L39BT01Re[:DXYBRDY8@PU:@<L
i`8HaP<DY@0348@<H`Q200@48@0324848@@Q00@48@@8@P041248@PQ2248312400`Q21248@P021240
10Q21248@P@Q10Q200<48@Q2124010Q20P@Q00<8@P@Q12400P@Q00<8@P@Q24801@@Q10Q200D<H`Q2
2488@PaS00D8@P848@<8@PL48@<8@P041248@P@Q24821243248212422483124324800`aS2488@P0;
248612400`Q21248@P0812422482124424800`@Q24848@0236<01A247>LaS4YBAS400UJe00TicSF]
7>LLiaS65:D@Q0aS48@00PaS0a2400<<Ha2436<0112400LDYAS66<HDYA2436<@Q0026<H00aBU48@@
Q0026<H00aBU48@@Q0035:D348@011BU48@@Q1240QBU0Q2400<DYAS66<H00QBU0Q240aBU0QS611BU
0QS600PDYAS66<HDYA245:DHaQBU0a240QS60QBU0Q240QBU00P@Q1BU6<HHaQBU48@DYAS60QBU00@@
Q1BU5:DHaP<DY@046<HLiacW5:D26<H00a245:DDY@026<H011BU48@DYABU0Q240aBU112400<DYA24
48@00Q2400HHaQcW5:DDY@aS248336<0112436<<H`aS0PQ200<<Ha2448@00PaS0Q2400@<Ha2448@D
Y@P@Q00336<@Q1BU008@Q0<<H`8@Q0H<H`8@Q0<<H`0348@<H`Q2008<H`0548@<H`Q2248<H`0348@2
36<010Q236<@Q0aS0PQ210aS00H8@PaS36<<H`Q236<124800006124000@Q00048@000P@Q00T8@P@Q
1248@S6<JeY>Lbe[=Jd00T8@0dHa00DmkcW><H`e[C6<00<e[@8aS007=JdmkcW>>Lhe[C6<>Lh013F]
0T8@00I6<D8@@Q0mkdHa@Q02AS400dYBCW=>L`02CW<014HaBU8mkcg_0cW>13F]00HaS2U:9BTU:B48
7>L28@P39BT012487>LQ22480RDY0b4800<Lib487>L00RDY0RU:00L]JcF]=JdicS6<:DXU:@038@P2
9BT27>L00b489BTU:@039BT28@P39BT28@P00bDY:DXU:@029BT02bU:9BTU:B487>LU:BU:9BTQ21S6
7>L01R4812U:00<]JbDY8@P00R480bDY0RU:00XU:B489BTYBRDY7>LQ22DY;F/YBP8U:@<]J`04<H`]
JbDY9BT38@P00bDY8@PQ20029BT012U:;F/YBRU:0RDY0RU:00@U:B489BTU:@8Q20089BTYBR487>LH
aR487>LDY@8HaP048@PU:AcW8@P37>L012487>LQ22DY0R480acW00DQ21cW6<HDYAcW00<Q208U:@03
;F/U:B48008Q208Li`068@PU:BU:;F/YBRDY0R4800<Lib487>L00aS60QBU0Q240`Q200<48@Q21240
0`@Q20Q21@@Q0`Q20`@Q0`Q20`@Q00D8@P@Q12448@Q2008<H`<48@0324848@@Q00D48@88@P848@L8
@P0436<8@PaS248236<2248212401@Q21248@P@Q248010@Q00<8@P@Q12400P@Q10Q210@Q0`Q200<4
8@Q212400P@Q0PQ20PaS2PQ200<<H`@Q12400P@Q0`Q200@48@001248@PD48@88@P<48@0324848@Q2
0088@P041248@PQ2248212403@aS48@HaSF]@Q1JeU:DAS5242U:9BTLiaBU00<@Q0<<H`8@Q08<H`07
48@DYABU5:D@Q1BU48@01ABU00<@Q1BU5:D00QS600<DYA2448@00QBU0QS60QBU0a2400XDY@aS48@D
YAS648@<HaBU6<HDY@8@Q0056<HDYA2448@DY@026<H01ABU48@@Q1BU7>L00QS600<DYAS66<H011BU
00@@Q1BU6<HHaP<@Q0035:DHaQBU008@Q0<HaPDDY@8@Q00436<DYAS66<H25:D00aS67>LHaP036<H3
5:D01QS65:DDYABU6<HDY@@@Q08DY@P@Q0036<HDYABU00<@Q00336<8@PaS008<H`0348@<H`aS00`<
H`0348@DYA24008@Q0<DY@0348@<H`aS008@Q08<H`@@Q08<H`03248<Ha24008@Q00336<8@PQ200H<
H`05248<H`aS36<@Q00436<0112436<<H`Q20`aS00<8@PaS24800`aS00<8@PaS36<00@Q200000`00
12448@0512402@Q200048@Q2<Ha[FTYB;F/mk`06@Q000cg_>LhicP04=Jd01SW>=Jde[C6<=JdicP8m
k`03>Lhe[C6<008icP924003?Nm243W>008icP03@Q16<DHa009240A:DP06DYA>Ldic@Q0icSg_0T8@
00@icSF];F/aS0@YBP039BTYBR4800LQ20@Li`068@PU:BDY:DXaS2U:0RDY00XYBS6<>Lhe[Be[:DXU
:BU:9BTQ208Li`<Q20049BTQ22486<H28@P01RU:9BTQ22489BTQ208U:@038@PU:BDY00DU:@05:DXU
:BDY8@PLi`038@P27>L28@P00bDY8@PQ2002:DX38@P29BT38@P27>L00b489BTYBP029BT28@P2:DX3
9BT4:DX01bDY8@PU:B486<HLib4800@YBP05;F/YBRDY:DX]J`02:DX28@P01RU:;F/YBRU:9BTQ208L
i`038@PHaQS6008DY@<Li`036<HLiacW00<U:@8Q208Li`058@PU:BDY7>LHaP027>L011S67>LQ22DY
0Re[00<YBRDY8@P0124800HLib488@PU:BU:9BT28@P29BT01acW6<HDYAS67>LHaPaS0088@P040004
8@@Q1242248010@Q2488@P@Q0PQ200<48@Q212400`Q200<48@Q212400P@Q0PQ200<48@Q2124010@Q
00<8@P@Q24800PQ20`@Q0`Q200<48@Q212400P@Q0PQ20P@Q1@Q20`aS0Q241`aS10Q20P@Q00<8@P@Q
24801`@Q00@<H`Q236<<H`88@P031248@PQ200@8@P031248@PQ200D8@P0336<8@PQ200X8@PP48@05
00048@Q21248@P03124324800`@Q24848@0424800`@Q36<<H`0324800a248@P]J`02E[D01f<HJeXi
cRe[48@<HaBU008<H`0348@DYA2400<@Q0035:D@Q1BU00<DY@0336<@Q12400@@Q0066<HLiacW6<H@
Q0aS0Q2400<DYA245:D00QS600@DYAS648@DY@8<H`8@Q0036<HDYABU008DY@@HaP8DY@0548@DYABU
5:D@Q0025:D56<H?5:D248@010aS48@DYABU0Q2400DDYA245:DDYA24008DY@DHaP@Li`045:DHaQS6
48@25:D01AS67>LDYABU6<H00QBU0Q2400DDY@aS36<<Ha24008DY@0948@<HaBU7>LHaQBU248<Ha24
008<H`05248<Ha2448@DY@0236<348@336<011245:D@Q1BU0Q2400@DYA2448@DY@D@Q08DY@0348@<
H`aS00D<H`0348@<H`aS008<H`8@Q08<H`88@P@<H`04248<H`aS248236<248@010aS248<H`Q210aS
00P8@PaS36<<H`Q236<8@PaS0@Q2000312400`001240000212402PQ2124000Q2;F]S64ic;F/e[D8@
0Sg_00=6<D8@?Nl00Sg_00=243g_>Lh00S6<00@e[CW>>LhicP<e[@8mk`8icP8e[@<mk`03@Q0icSW>
008icP03@Q16<DHa00924096<@=>L`03DYA:DTHa00=24003?NlicS6<00D]J`05:DXU:BDY8@PU:@02
8@P29BT28@P02AcW9BTQ21cW8@PU:Be[:DXU:@04:DX012e[<H`e[CF]0RU:0R4800TU:B488@PLib48
7>LQ21cW8@P00acW00@Q22DY8@PQ208U:@<Q2003:DXU:BDY008U:@04:DXU:BU::DX29BT00b487>LQ
20027>L00b48:DXU:@028@P39BT28@P39BT28@P27>L01B489BTYBRDY8@P00RDY0b4800HU:BU:;F/Y
BRe[:DX39BT58@P29BT2;F/4:DX2;F/2:DX00bDY:DX]J`02;F/01BDY8@PQ22487>L00QBU0QcW0aS6
0QcW00<Q21cW7>L01AcW0R4800@U:AcW7>LHaP8Li`036<HQ22U:00<YBP038@PU:B48008Q20047>LQ
22488@P29BT01BU:8@PQ22DY7>L011S600@Lia2436<8@P@48@0424848@Q2248412401`aS2488@P@Q
24848@Q200<48@88@P031248@P@Q00<8@P@48@0424848@@Q36<2248312400`Q21248@P0224831243
24801@@Q2488@Q2436<00PQ200<@Q1BU48@00Q2400<<H`Q236<00PaS00L8@P@Q1248@P@Q24848@03
248412400`Q236<<H`0336<00`Q21248@P02124524800`@Q2488@P0A248812400`Q21248@P061243
2482124224801PaS2488@P@Q36<8@P8@Q0086<HmkdYBKg]cW4YB@Q0Li`8DY@0436<@Q12436<648@2
6<H01ABU48@@Q1245:D00Q240QBU00@HaQBU6<HHaP8DY@0348@DYA24008DY@0348@DYAS600<DY@03
48@DYA2400<@Q0046<HDYAS648@25:D26<H35:D01a245:D@Q1246<HDYAS6008Li`8HaP0348@DYABU
00@DY@0348@DYABU008HaP<DY@<@Q0035:D@Q1BU00DDY@<@Q0DDY@036<HLiacW00@HaP<DY@8HaP05
5:DHaQS66<HDY@0348@25:D00a245:D@Q00348@25:D01AS65:D@Q0aS24801@aS11241@aS0Q240PaS
0Q2400<DYA2448@011BU0Q2400<DYA2448@01Q240`aS0a240PaS00D8@PaS36<<H`Q200@<H`04248<
Ha2448@336<010Q236<<H`Q21`aS00<@Q0aS36<00PQ20@aS0@Q200000`0012448@0312400`002484
8@0212401PQ2;F]S64YB;F/e[@8icP05@Q0mkd8@?NlicP02?Nl2>Lh2=Jd01cW>?Nlmkcg_>Lhmkd8@
008mk`8icP04?Nm243W>>Lh2=Jd00cg_>LhicP03?Nl3>Lh2@Q06BU801dicE[E>LdHa>LhaS3F]008i
cP06;F/YBRU:<H`e[C6<0R4800<U:B488@P00QcW0R480RDY0RU:00H]Jc6<;F/]JbU:9BT2:DX03be[
:DX]JbU:;F/YBRDY8@PLibDY8@PU:BU:9BTLi`026<H28@P27>L01B48:DXU:BDY:DX00be[0bU:0be[
00<YBRe[:DX00RDY0b4800DU:B488@PU:B4800<U:@8Q20039BTQ21cW008HaP8Li`8U:@04:DXU:B48
8@P2:DX00bDY8@PLi`039BT3:DX01be[:DXQ22489BTYBRDY008Q20@U:@038@PYBS6<008aS08YBP03
9BTQ2248008YBP8]J`039BTQ21cW008Q20037>LHaQcW008DY@036<HDYAcW008Q2003:DXU:B48008Q
208U:@038@PLiacW00@U:@048@PU:BU::DX59BT28@P29BT00b489BTU:@028@P00acW6<HHaP036<H0
0a2424848@0212400`Q212448@0212422483124824800`@Q24848@021242248010aS24848@Q20P@Q
00<8@P@Q24800P@Q00H8@P@Q2488@P@Q2482124524800`@Q2488@P0324803@aS48@@Q1245:DLib48
9BTLiaS65:D@Q0aS00@8@P<48@88@P03124000@Q00<8@P848@05248<Ha2448@<H`02248212400`Q2
1248@P032483124010Q236<8@PQ20P@Q0PQ200<<H`Q212400`Q210@Q00X8@P@Q12448@Q21248@P@Q
00048@<8@PD48@8<H`0624848@@Q1248@P@Q10Q200D@Q1BU6<I244ic009g_@05BU9241cW6<HDY@03
36<25:D00a2436<<H`025:D348@25:D010aS48@@Q1cW0QS600@Lib487>LDY@8@Q0<DY@8@Q0046<HD
YAS65:D348@00aBU6<HDY@055:D01QS65:DHaQS65:DHaP8DY@046<HDYAS66<H35:D36<H25:D02124
5:DHaQBU48@<Ha246<H35:D56<H25:D0212436<@Q1BU6<HDYA2436<248@00`aS48@DY@025:D26<H2
7>L011S65:DDYA240QBU0QS600LLiaS66<HDYA245:D@Q0045:D348@011BU48@HaQS60QBU0a240PaS
00@8@PaS36<@Q08DY@8@Q08<H`D@Q08<H`0748@DYABU48@<Ha245:D0112400<<Ha2448@00a240`aS
00<@Q1BU48@00`aS00@8@Q2436<@Q0<8@P8<H`0348@<H`aS008<H`8@Q00436<8@PQ236<248@436<0
0a2436<8@P02248336<1248000848@0300048@0000D48@070008@Re[HaQ:DRe[?Nl00SW>00<e[CW>
?Nl00cW>0T8@00<mkcF]>Lh01SW>00Dmkd8@?NlicSg_00<icP04?NlicSW>=Jd5>Lh01Cg_>Lhe[CW>
?Nl00THa00=:DTHaAS400TYB00E>Le:DDYA>Lcg_008e[@05>Lhe[BU::DX]J`02<H`2:DX01BDY8@PU
:AcW8@P00QcW0R4800HU:B489BTYBS6<;F/6:DX01B48:DX]Jbe[:DX00acW0bDY1B4800DHaQcW8@PQ
22DY008YBP039BTQ22U:008aS08YBP<]J`08<H`e[Be[9BTQ22DY:DXQ208Li`039BTYBRDY00<Q2004
9BTYBRDY8@P37>L00aS68@PLi`03:DX39BT012U:8@PU:B481BDY00@]JbU::DXU:@8Q20<YBP039BTQ
21cW008U:@058@PU:BU:<H`]J`02<H`012U:9BTU:B480bDY0RU:00DU:B487>LLib48008Li`056<HD
YAS68@PLi`026<H011cW9BTQ22480bDY00DQ21cW8@PQ22U:00DU:@8Q20<U:@8Q20059BTQ22DY:DXU
:@028@P37>L01ABU48@LiaBU48@00P@Q00<8@P@Q124010@Q0`Q20`@Q10Q200<48@Q224800P@Q00D8
@PaS2488@P@Q00D8@P848@0324848@@Q00848@0424848@@Q1242248412432482124224801`aS5:DD
YABU48@DYB48008YBP037>LHaQ24008@Q00636<8@P@Q24848@Q20`@Q0PQ210@Q00H000Q2248@Q1BU
48@236<2248212400`Q21248@P0224800`@Q2488@P0224800`@Q24848@0524821243248:12422484
1243248312400`Q212448@021242248010@Q2488@Q240PaS00@YBSg_Kg][FP9JeP03;F/Q21BU00D@
Q0075:D@Q0aS48@DYAS65:D01A240QBU0QS612480Q2400@<Ha2448@<H`8@Q0046<HDYABU48@25:D0
11245:DDYAcW0QS600<DYAS648@00QBU00HHaQcW5:DHaQBU6<H75:D36<H01QBU48@DYABU6<HDY@@@
Q0035:DHaQcW008Li`035:D@Q1BU008HaP<@Q08DY@H@Q08DY@0348@DYAS6008HaP035:DHaQS6008D
Y@0348@DYAcW008Li`8DY@046<HDYABU5:D248@35:D01Q2436<@Q1BU6<HDY@8@Q08DY@0336<8@PaS
00L@Q08<H`0448@<H`aS36<248@01@aS48@DYA2436<00Q240QBU00@@Q0aS48@DY@<@Q08<H`0348@<
Ha24008@Q0045:D@Q0Q2248236<00a2436<<H`02248236<00`Q236<<H`0536<00`@Q2488@P0248@0
10aS248<H`aS0PQ20`aS00<8@PaS48@00@Q200051240100012448@Q20P@Q00T8@Re[G_M6<BDY<H`i
cSF]>Lh00SF]00DaS3F]>Lhmkd8@008mk`<icP04?NlicSW>>Lh2?Nl013W>=JdaS36<0SF]00HaS3F]
=Jde[C6<=Jd2>Lh2=Jd0136<>Lhe[C6<0SW>0cg_00=244HaAS400THa0TYB0Tic00I:DSW>=JdYBRe[
<H`4:DX00bDY8@PQ20038@P29BT00bU:;F/YBP06:DX28@P00bDY:DXYBP04:DX39BT2:DX00b487>LQ
20028@P00bDY7>LU:@02:DX00b487>LLi`039BT2:DX2;F/00c6<;F/aS002=Jd0136<9BTU:BU:0RDY
00<Lib487>L00R480RDY00DYBRDY8@PLib48008Li`058@PLibDY8@PLi`028@P2:DX01RDY8@PLiacW
8@PLi`8Q208U:@05:DXU:B489BTYBP02;F/2:DX012DY8@PQ22480RDY00<Q22DY8@P00bDY0R4800<U
:BU::DX00RDY0R4800<Lib488@P00R4800<Lib488@P00acW00@U:BU:9BTU:@8Q20037>LQ21cW00<U
:@03;F/YBRDY008U:@03;F/YBRU:008YBP04;F/aS36<;F/39BT01b489BTLiaS65:DHaQ24008<H`<8
@PH48@88@P848@@8@P031248@PQ20088@P848@88@P09124<H`aS48@<H`Q21248@P@Q00<8@P031248
@P@Q00<48@88@PD48@<8@P091248@PaS24848@Q26<HQ21S6008@Q00;;F]6<EJeHaQ>LcW><H`Q21cW
36<8@P02124224800`@Q2488@P0212400`0012448@0212401@Q236<<HaBU6<H00QBU0PQ21@@Q10Q2
00<48@Q2124010Q20`@Q00<8@PaS36<010@Q0PQ210@Q00<8@P@Q12400P@Q00<8@P@Q12401@@Q0`Q2
10@Q00@8@P@Q24848@88@P8<H`0548@aS3W>G_MJeP02@Q001BDY6<HHaQ245:D00Q240QBU00D@Q0aS
48@@Q1BU00@@Q00336<@Q1BU00<Li`068@PU:AcW6<H@Q0aS0a240PaS00H@Q1BU5:D<Ha245:D348@0
0aBU6<HHaP025:D011245:DHaQS60aBU00D@Q1BU5:DHaQcW008HaP0548@DYA246<HDY@0348@35:D0
1Q245:D@Q1BU48@DY@8Li`068@PLiacW7>LDYAS60QBU0Q240QBU0Q2400D<Ha2448@@Q0aS00@@Q08D
Y@056<HDYAS65:DHaP0248@46<H00a245:DHaP0448@01PaS48@<H`aS48@DY@8HaP035:DHaQ24008@
Q0<<H`03248<H`Q2008<H`0448@<Ha245:D248@336<548@011BU48@@Q0aS0a2400<<Ha2448@00`aS
0Q2400<<Ha2448@00Q240PaS00<@Q0aS48@01@aS0PQ21@aS00L8@PaS48@<H`Q236<8@P0248@00`aS
2488@P0336<3248236<12480000400048@@Q000712401`Q2=JeS648@9BTaS3W>00@e[@8aS004=Jdi
cSg_?Nl3>Lh00d8@?NlicP02>Lh3?Nl013W>=JdaS36<0SF]0c6<13F]00<icSF]=Jd00S6<0SF]00Di
cSg_>LhmkcW>008mk`03@Q16<DHa0096<@04BU9BU4YB@Q02<H`5;F/2:DX69BT2:DX01be[<H`]Jbe[
:DXU:BU:00<U:@038@PYBRDY00@YBP039BTYBRU:008U:@@Q20087>LQ2248:DXU:B486<HLi`<Q208U
:@05:DX]Jc6<;F/aS002=Jd00c6<;F/YBP059BT00b489BTLi`028@P39BT012489BTU:B480QcW00@Q
22U:9BTQ208Li`039BTYBR48008Li`<U:@<Q20DU:@8YBP<]J`8U:@038@PLibDY008U:@8Q2006:DXU
:B488@PLibDY0bU:12480acW00<U:B488@P00RDY0R4800DLib489BTYBR48008Li`038@PU:B48008Q
2003:DXU:BDY00@YBP068@PU:Be[;F/e[C6<0bU:00/U:B488@PLiaS648@<HaBU36<8@P@Q0088@P03
124000@Q00<48@0324848@@Q0088@P<48@0624848@Q21248@P@Q10Q200L@Q0aS36<8@PaS48@<H`03
12402PQ21248@PQ21248@P@Q24848@Q210@Q1@Q20P@Q00<8@PaS5:D00QcW00PDYAcW<Ha:DVLiF]I:
DTHa0RU:00@DYA242488@P<48@<8@P@48@88@P848@04248@Q1245:D248@01@Q212448@@Q24800`@Q
0`Q200@48@Q212448@<8@P041248@PQ236<3248412400`Q212448@0212400`Q212448@0612401`Q2
1248@P@Q24848@Q200848@0424848@@Q124524803`aS7>LYBTYB@Q1:DUJe>Lh]JaBU48@DYA245:D@
Q00236<35:D011245:D@Q1240PaS00TDYAS66<HHaQBU8@PU:BU:9BT00QBU11240PaS0Q240QBU0Q24
00<<HaBU5:D011BU00@HaQ2448@DY@8HaPHDY@056<HDYABU5:DHaP035:D248@25:D448@56<H011cW
6<HHaQBU0QS61ABU0a2400HDYA2448@@Q0aS48@35:D011245:DHaQS61aBU00DLiaS66<HHaQ24008D
Y@8<H`0348@DYABU00<@Q0<DY@0448@DYABU5:D248@236<2248236<448@00`aS48@@Q00236<248@0
11BU48@<H`aS0a240PaS00<@Q1S648@00a240`aS0a241@aS00<@Q0aS36<01@aS00<@Q0aS24801@aS
00<8@PaS36<00PaS0PQ200@<H`Q236<@Q08<H`88@P0348@<H`Q20048@P0000D48@0012448@0000<4
8@0824848@@Q248aS6]JCW<YBP8aS08e[@@aS006=JdicSW>?NlicS6<0SF]00<mkcW>=Jd00SW>0Sg_
00@e[C6<<H`e[@8aS08YBP<aS0<YBPDaS004=JdaS3W>?Nl2>Lh3=Jd2;F/013F]@Q16<CW>0Sg_00Q>
Le:DBU8mkbe[<H`e[C6<0be[0RU:00@U:BU::DXYBP8]J`03<H`]Jbe[00PYBP03;F/YBRU:00LU:@05
:DXU:BDY9BTQ20049BT68@P39BT2:DX3;F/00c6<;F/]J`02:DX00be[:DXYBP027>L00b487>L]J`02
;F/012U:9BTQ22480RDY0R4800<Lib488@P00b4811cW0R4800<U:BU::DX00Re[0RDY0RU:00<]JbU:
8@P00RU:00<Q21cW7>L00R4800DU:AcW7>LLib48008U:@037>LQ22DY008Q20047>LQ22489BT28@P0
0aS67>LHaP027>L48@P01RDY8@PU:BDY7>LHaP8Li`059BTQ22487>LQ20029BT28@P29BT01C6<:DXa
S36<;F/00RU:00H]JbU:9BTHaPaS48@25:D00a2424848@02248312400`Q212448@0212400`Q21248
@P0524800`@Q2488@P03248010@Q36<<Ha241@aS00@8@PaS2488@P<48@0324848@Q200L48@032484
8@@Q00848@<8@P0@124<HaBU8@PDYAcW:DY>Lf<HG_M[FV<HIcUS648@=Jd25:D01A242488@P@Q36<0
0PQ200D000@Q12448@Q200<48@0436<@Q1BU48@336<3248212400`Q21248@P03124724801@aS248<
H`Q236<00`Q22P@Q00<000@Q12400P@Q10Q21@@Q0`Q20P@Q10Q200D<H`Q248@HaQcW008aS004AS5B
U3W><H`25:D01aS648@@Q0aS5:D@Q0aS008@Q08DY@8@Q0085:D@Q1245:DQ21cW5:DLi`8U:@036<H@
Q12400<DY@0348@DY@aS00<@Q0065:D@Q12448@<Ha2411BU00<HaQBU48@00aBU0a240aBU00<@Q1S6
5:D01AS60QBU00<@Q1BU5:D00Q240QBU0QS60Q2400@DYAS67>LLi`<HaP<@Q08DY@036<HDYA2400<@
Q0045:DHaQcW6<H348@35:D26<H25:D01AS65:DHaQcW5:D00a240QBU0a2400D<Ha2436<@Q1BU00<H
aP055:D@Q1BU48@<H`0224801P@Q36<@Q0aS48@<H`<@Q0L<H`045:D@Q0aS36<248@00`aS48@@Q002
5:D00a2436<<H`0248@436<25:D336<011246<H@Q1240PaS00<@Q0aS36<00PaS00@8@Q2448@@Q0<<
H`0348@<H`Q200<<H`88@P0436<@Q0aS248436<1248000848@0300048@@Q00D48@09000<HcF]Kg]:
DRU:=JdicS6<00<e[@04<H`]Jc6<=Jd2>Lh3=Jd013W>?NlicSW>0SF]00<icSg_>Lh00S6<00<e[C6<
;F/00Re[00<aS2e[;F/00Re[0bU:0be[0S6<0SF]1CW>0S6<00@]Jc6<<H`e[@8icP04BU9>LdHaAS45
>Lh00c6<;F/YBP029BT01BU:;F/U:BU:;F/00S6<00D]JbU:;F/YBRe[00<U:@8YBP0<;F/YBRe[:DXU
:B489BT]JbU:9BTQ22DY0RU:0RDY124800<Lib488@P00b4800<LibDY:DX00bU:00@]Jc6<<H`]J`8Y
BP06;F/aS2U:8@PHaQcW0RDY00LYBS6<:DXU:B487>LQ20029BT00b487>LLi`047>L01B487>LHaQS6
7>L00bDY0RU:00D]JbU::DX]JbU:008U:@8]J`04:DXQ21S67>L38@P27>L29BT00b487>LLi`068@P0
1BDY8@PQ21cW6<H00acW00@HaQcW8@PU:@8Q20079BTYBRDY8@PHaQcW8@P00QcW0b481RDY0bU:0be[
00DYBRDY9BTQ21S6008@Q0035:D@Q0Q200d48@8<H`88@P848@88@P<48@04248<H`aS36<2248436<0
1@Q21248@PaS48@00`@Q0PQ20`@Q0PQ200<48@Q2124010@Q0PQ200@<H`Q2248<H`8@Q0068@PU:CF]
BU9JeW>L0Vmk00MW>E[FF]HaS24824848@0424800`@Q2488@P031242248010@Q2488@PaS0Q240PaS
00@8@PaS1248@P@48@0324848@Q20088@P848@88@P0536<8@PaS36<@Q00236<224800`@Q24848@04
12401@Q212448@@Q24801`@Q0PQ210@Q0PQ210@Q0PQ200l<H`Q2248@Q1cW:DXQ23g_E[E>Lcg_6<HD
YAS65:D011240PaS1Q2400X<Ha247>LQ21cW5:DLibU:;F/Q208@Q0035:D@Q1BU00P@Q0@DY@<@Q004
5:D@Q1BU6<H25:D01A245:D@Q0aS48@00aBU00L<Ha245:DDYAS67>LHaP045:D248@011BU6<HHaQS6
0Q240QBU0QS600<DYAS66<H00QS60a2400@DYAS66<HDY@8@Q08DY@<@Q0035:DHaQ24008DY@057>LH
aQBU5:DHaP025:D46<H248@011BU48@@Q1BU0Q2400@<Ha2448@HaPDDY@<@Q00336<8@PaS00<<H`<@
Q0035:D@Q0aS00D<H`0448@<Ha2436<448@010aS48@<Ha240`aS00D8@PaS36<<Ha24008<H`8@Q0<<
H`8@Q0@<H`8@Q0P<H`06248<H`aS36<@Q0Q20PaS00<@Q0aS36<00`aS00<8@PaS36<00@Q200001@00
12448@@Q00000`@Q00T8@P001248@S6<HaQ:DRU:>Lh00Sg_0SW>00He[C6<<H`aS3F]?Nl2>Lh013F]
<H`aS36<0SW>00@aS2e[:DXaS08]J`04<H`e[Cg_>Lh2=Jd02C6<=Jde[CF]<H`YBRDY8@PYBP02;F/0
2C6<=Jde[CF]>LhmkcW>=JdaS003:DX2;F/00bU:;F/aS002<H`00cF]>Li24002BU801DicBU9243W>
=Jd00cW>00H]JbDY9BT]Jc6<;F/2:DX02Be[=Jde[Be[:DXU:BU:<H`]J`03:DX49BT012U:9BTU:BDY
0bU:00LQ21cW7>LQ21cW9BTLi`028@P29BT01RU:9BTYBRU:8@PU:@8]J`<Q2008;F/YBR489BTYBRe[
:DX]J`8aS009;F/YBRDY;F/U:BU:8@PU:B48008Li`@Q20HLi`099BTYBRU:9BTYBS6<=JdaS2U:008U
:@8YBP037>LHaQS6008Li`068@PLiacW7>LQ22DY1b4800LLib487>LQ22DY7>LQ20027>L28@P47>L2
8@P00bDY8@PQ20048@P01AcW6<HQ21cW8@P00RDY00@YBRDY8@PLi`8U:@8YBP048@PU:AcW5:D248@3
36<412400`Q212448@0612400`Q212448@0224801@@Q24848@Q212401@Q20PaS00@@Q0aS36<@Q0@8
@P0336<8@PQ20088@P<48@0324848@@Q00848@0324848@Q200<48@H8@P0648@DYA248@PaS5:D0g>L
0fmk00AkgWoo?NlYBP848@06248<Ha2424848@0010@Q00@000@Q2488@P<48@0336<8@PQ200848@<8
@P@48@0324848@Q200@8@P0336<@Q0aS008@Q0045:D@Q12436<2248;124224851243248010@Q2488
@P@Q0PQ20`@Q10Q200X<Ha245:DYBRe[CW=S65:D@Q0Li`8DY@0436<@Q12436<348@336<00a245:D@
Q0065:D36<H01ABU48@@Q1245:D00a240QBU00@@Q0aS48@@Q08DY@0348@DYA24008DY@0448@DYA24
48@35:D00a2436<@Q0035:D348@01ABU6<HLiacW6<H00QBU0aS600DDYA2448@HaQ24008DY@8HaP05
5:D@Q12448@HaP025:D448@01ABU48@DYABU48@011BU0QS60QBU00<@Q1BU5:D00QS60a2400<DYAS6
5:D00QS600DDYA2448@@Q1BU008<H`0648@DYABU48@<Ha240QS600<DYA245:D00Q2400<<Ha2436<0
0`Q200<<Ha245:D0112400<<Ha2436<00PaS1A240`aS00<DYAS648@00`aS00<@Q0aS48@00PaS0Q24
00<<H`Q236<00Q240`aS00@@Q1BU48@@Q0P<H`8@Q0@<H`<@Q00536<@Q0aS248<H`0248@136<12481
248000<48@0500048@@Q0008@P0312401PaS<Ha[FTic:DXe[@<mk`04>Lhe[CF]=Jd2<H`013W>?Nli
cSW>0Re[0SW>00He[C6<;F/]Jc6<;F/2:DX01Be[=Jde[C6<=Jd00c6<00DmkcW><H`YBR4800@YBP03
;F/e[CF]00@icP03=Jd]Jbe[00<YBP@]J`8aS006;F/e[CW>AS5>LdYB0THa13g_00<e[C6<;F/00be[
0RU:00D]Jc6<<H`]JbU:008U:@05;F/aS36<;F/YBP029BT28@P29BT012U:9BTU:BU:12DY0R4800DL
ib489BTQ22DY008Q20<U:@058@PU:Be[:DXU:@028@P01BDY8@PQ22489BT00RU:00@]Jc6<<H`aS08]
J`03:DXU:BDY008U:@8Q208Li`0?8@PU:BU:9BTQ21cW8@PHaQcW9BT]JbU:9BTQ22U:008aS007;F/Y
BRDY:DX]JbDY8@P00QS60b480QcW00<Q22DY9BT00QcW224800<Lib488@P00R4800<Lib488@P00QcW
0QS60R4800DU:B487>LQ21cW00<Q20037>LQ2248008U:@03:DXU:AcW00<Q2009:DXU:BDY9BTQ21BU
48@<Ha24008<H`88@P031248@P@Q00L48@030008@P@Q0088@P<48@88@P<48@<8@P<<H`0348@<H`aS
008<H`H8@P848@88@PP48@88@P848@H8@P0;48@8@QS69BU246LiKg]kgW>LIcUS6002Ool00f]J@Q08
@P0224821242248312400`Q212448@03124224800`aS1248@P0524800`@Q24848@02248010@Q2488
@PQ20P@Q00<8@PaS36<00a240QBU00@@Q1BU36<<H`@48@0324848@@Q00H48@0524848@001248@P02
124224861244248020aS2488@PQ248@Q21cW@Q02DY@015Je;F/Q21BU1a240`aS1A2400<HaQcW5:D0
0Q2400@DYAS65:D@Q08DY@<@Q0035:D@Q1BU00<@Q0036<HDYA24008@Q0046<HDYABU5:D236<648@2
5:D011245:DDYABU0Q2400@DYAcW7>LHaP8Li`8HaP065:DHaQS66<H@Q1BU0aS600@DYAS65:D@Q0@D
Y@8@Q0<DY@0648@DYA245:D@Q1BU0Q2400HDYAcW7>LLiaBU48@25:D01AS65:DDYABU48@01aBU0Q24
00<<Ha2448@0112411BU00HHaQBU48@<Ha245:D236<00`Q236<<H`0336<0112436<<H`aS0a2410aS
00@@Q0aS48@<H`D@Q0<<H`@@Q0D<H`03248<Ha24008@Q08<H`0;48@DYA2436<8@PaS48@<H`Q236<@
Q00336<348@536<0112436<8@PQ20PaS0@Q200000`0012448@0212403P0012448@Q200048@Q2>Lig
_EJe;F/icT8@?Nl3>Lh02CF]?Nlmkcg_AS5:DT8@>Lh]J`02<H`023F]<H`aS2e[<H`e[C6<;F/2:DX0
1c6<>Lhe[C6<;F/aS3W>008e[@06;F/YBRDY9BT]Jc6<0SF]00Pmkd8@AS56<Cg_=JdaS2U:0c6<0RU:
00L]Jc6<<H`aS2e[:DX]J`02<H`043F]>Lhmkd8@DYA>Le:DE[E:DT8@=JdaS3F]>Lhe[BU:0RDY0S6<
00D]JbU::DXYBRDY008]J`<YBP<U:@038@PU:B4800DQ20099BTYBRDY9BTQ22DY:DXU:BU:00<U:@HY
BP079BTLiaS67>LQ22DY7>L00R4800D]Jc6<=JdaS2e[00<aS003;F/U:B48008U:@09:DXU:AcW6<HL
ib489BTYBRDY008Q2008:DXaS36<8@PYBSF]>LhaS08U:@03;F/YBRDY008Li`038@PU:BDY00@Q208L
i`068@PU:BDY9BTQ22DY0b481QcW00<Q21cW8@P011cW0R480QcW0R480acW0RDY00HYBRDY9BTYBRe[
:DX29BT00b489BTU:@028@P00acW5:D@Q00248@2248412400`Q212448@0512401@0012448@@Q2480
10@Q00D8@P@Q12448@Q200<48@0324848@@Q00@8@P848@0324848@@Q0088@P848@@8@P848@032484
8@@Q00848@0400048@@Q1242248336<030Q248@DYC6<>Li:DVLiKg]g_G>LJeYNm`9oo`05JeY240@Q
1248@P0712401@Q212448@0012400`Q200<48@Q212400P@Q0`Q200@<H`Q224848@<8@P848@<8@P<<
H`8@Q0<<H`05248<H`Q236<8@P031242248812400`Q212448@031244248412401@Q21248@P@Q2480
0PaS00h@Q2488@Q6<EJeBU8icQcW5:DHaQ245:D@Q1BU0a240aBU00P@Q0aS5:DHaR486<H@Q0aS0aBU
1a2400@DYA2448@@Q08<H`D@Q00436<DYABU5:D648@25:D248@00aBU48@DY@025:D00a245:DHaP02
7>L01aBU6<HHaRDY8@PLiaS6008DY@036<HDYABU008DY@8HaP8DY@0348@DYABU008DY@0548@<Ha24
5:DHaP025:D01A245:D@Q12436<00QBU0QcW00@HaQ2448@DY@8HaP045:D@Q12448@25:D00a245:D@
Q00348@236<848@35:D248@236<248@436<348@00aS65:D<H`0336<00a24248<H`0636<25:D01Q24
36<<Ha245:D@Q08<H`03248<Ha2400<<H`8@Q0P<H`07248<H`aS36<8@PaS24801A2400H<Ha2448@@
Q0aS248236<0112436<8@PQ20PaS000312400`0012448@02124020Q2124000aS=Jeg_EJe<H`4?Nl0
13W>=JdicSW>0Sg_00M243g_@Q1243g_>Lhe[@02<H`012e[<H`YBRU:1Re[00He[C6<<H`e[C6<=Jd3
<H`3:DX00c6<>Lhe[@02>Lh01dHaBU96<D8@>Lh]Jc6<008]J`04<H`]JbU:;F/3<H`012e[<H`]JcF]
0S6<00@icSg_BU96<@9BU007CW=:DT8@@Q0mkcF]<H`01Re[0RU:0be[00<YBRe[:DX00RU:00<U:B48
9BT00b480bDY0RU:0bDY0RU:0bDY0bU:00DU:BU::DXYBRDY008YBP038@PLiacW008Q20039BTQ2248
008U:@03;F/aS36<008aS004=JdaS2U::DX49BT28@P00acW6<HQ20029BT28@P012DY:DXYBRU:0S6<
00<icS6<;F/00RU:00XU:BU:9BTQ21cW6<HQ22DY:DXU:@8Li`8Q20049BTQ22488@P39BT38@P021cW
8@PLib487>LQ21cW8@P67>L012487>LQ21cW0R4812DY0RU:00<]JbU:9BT00RDY00XYBRDY8@PU:AcW
6<HDY@aS48@<H`@8@P`48@0324848@@Q00T48@0324848@Q200<8@P041248@PQ2248312401@Q21244
8@Q236<00PQ20P@Q00@8@P@Q12448@88@P848@0324848@@Q00848@0336<@Q0aS0088@P0648@U:Be[
@Q1BU5kg0W>L00=_Nf]JKg/00W_N00=cW3F]5:D020@Q0`Q20P@Q00@8@P@Q1248@P<48@0424848@@Q
124224800`aS24848@021242248010@Q2488@PQ20PaS00@@Q0aS36<@Q08<H`<8@P848@0424848@Q2
1245248412400`Q212448@022484124224801@@Q24848@Q2124010Q200P<HaS66<HicT8@BU96<BDY
0QcW00<@Q1BU48@00Q240QBU0a240QBU00<@Q1BU6<H00QBU0QS600LDY@aS36<<HaBU48@DY@0948@0
0`aS48@DY@0248@01PaS48@DYABU48@<H`8@Q08DY@8@Q00=5:D@Q12448@DYAS648@<HaBU6<HLiaBU
6<H00QcW00<Q21S66<H01AS600@@Q1S65:DDY@8HaP8DY@0348@DYABU00<@Q08DY@036<HDYABU008D
Y@0448@<H`aS36<46<H248@25:D00aS65:D@Q0025:D26<H011245:D@Q1240`aS00<@Q0aS5:D00QBU
00H@Q0aS48@@Q1BU48@436<00a2436<<H`0336<248@45:D01Q2436<@Q0aS48@8@P8<H`H@Q0<<H`<@
Q08<H`8@Q0@<H`0348@<H`Q20088@P8<H`0348@<H`aS008<H`88@P0336<@Q0aS008<H`0348@<H`aS
008<H`8DY@0348@<H`aS008DY@0436<8@PQ236<124800005124000@Q12400006124020Q2<HaW>DYB
;F/mkdHa@Q02>Lh00d8@?Nlmk`02?Nl2@Q03AS400d8@>Lhe[@03=Jd2<H`01Re[<H`]JbU:;F/aS0<]
J`04<H`e[C6<;F/2<H`2;F/0136<=Jdmkcg_0T8@0Sg_00<icSg_>Lh00SW>0SF]00@aS3F]<H`aS08]
J`8YBP04;F/e[CF]<H`2;F/013W>@Q1244Ha0TYB0THa0Tic00EBU4Ha<H`]JbU:00D]J`DU:@8YBP8]
J`06:DXQ22DY:DX]JbU:0RDY0RU:0be[12U:0Re[00<aS2e[:DX00bU:00<]JbU:9BT00RDY124800@U
:B488@PQ20DYBP03;F/e[Be[00<U:@038@PLiacW008Q20<Li`<U:@05:DX]Jc6<<H`]J`02:DX3;F/3
:DX01R487>LHaQcW8@PU:@8Q208Li`<U:@8YBP<U:@038@PU:BDY008U:@047>LQ22488@P27>L00aS6
7>LQ20037>L01B489BTQ22487>L00RDY0be[00<YBRDY:DX00Re[00LYBRDY9BTYBRDY6<HDY@0248@0
0`aS2488@P02248:12400`Q212448@031242248212400`0012448@04124010Q212448@@Q0`Q200<4
8@Q212400P@Q00<8@P@Q12400P@Q00D8@PaS1248@P@Q0088@P041248@P@Q2482124040001248@PaS
248@Q1S65:D8@Q248@Q243g_>Li6<EJe0V<H0W>L015[FV<HCW=BU36<8@P<H`@Q36<48@Q21248@QS6
8@PHaPaS00848@0824848@@Q1248@P@Q24848@P8@P041248@PQ236<3248336<00`Q236<8@P022485
124010Q21248@PaS0a2400D48@Q212448@Q200<48@88@P848@D8@P051248@P@Q1248@P03124030Q2
36<DYBDY8@PicT8@?NlicRDY7>LHaP<@Q0045:DHaQS65:D248@35:D02AS67>LLiaS65:D@Q1S65:D@
Q00236<011246<HDYABU1Q2400<DYA245:D00Q240PaS0Q240QBU0a240QBU00<HaQBU5:D00aBU1124
0QBU00@HaQBU5:DDY@DHaP<Li`@HaP047>LHaQBU48@25:D011S65:D@Q1240QBU0QS60Q2400<DYA24
5:D0112400<DYAcW6<H00Q2400L<HaBU7>LLiaS65:D@Q0035:D248@25:D00a2436<<H`0236<01A24
36<@Q1BU48@00`aS0a2400<<Ha2436<010aS00<@Q0aS36<00a2400LDYA2448@@Q0aS48@DY@0236<2
48@00`aS48@<H`0448@736<00a2436<<H`0248@:36<01@Q236<<H`Q236<00Q2400@<H`Q236<<H`8@
Q00336<@Q0aS008<H`<@Q0@<H`0000<000@Q12400P@Q00@000@Q1248@P848@08248]Jf]JCW<aS3W>
?NlicP8mk`8icP@mk`0>>Li244YBAS5:DSg_@Q0mkcW>=JdicS6<=JdaS0@YBP@]J`04=JdaS36<<H`4
;F/00c6<>LhicP02>Lh013g_@Q1243g_0SW>00<mkcW>=Jd00SF]00@icSF]<H`aS0<]J`04:DX]Jbe[
<H`2=Jd2>Lh00d8@AS5:DP05BU8014Ha@Q0icS6<0Re[00PYBS6<;F/]JbU:9BTYBRe[0bU:00<]JbU:
:DX01BU:0RDY00@YBS6<<H`aS08]J`DYBP04;F/YBRU::DX29BT2:DX00bDY8@PQ20029BT01R487>LQ
22487>LU:@8YBP059BTQ22DY:DX]J`03:DX022487>LHaQcW8@PLib487>L59BT012e[=JdaS2e[0RDY
0Re[00DYBRe[9BTLib48008Li`8Q20039BTQ224800<Q208U:@<YBP<U:@04:DXU:AcW8@P29BT27>L0
0aS68@PLi`027>L38@P01QcW8@PQ22489BTYBP8U:@04:DX]Jc6<;F/29BT3:DX02BDY8@PLiacW5:D@
Q0aS24848@0224800`aS12448@021242248412401@Q212448@@Q24803P@Q0PQ22@@Q00<8@P@Q1240
0P@Q0`Q20P@Q0PQ200L48@0012448@Q21248@P0212405Q246<HDYA2436<@Q248:DXe[DHaBU9F]E[F
JeY_Nf]JHaQBU5Je>LhaS1BU0`Q200@<H`@Q124HaP8YBP045:D48@@Q248612400`Q212448@022480
10aS2488@P@Q10Q20P@Q0PQ20`aS1PQ200@48@Q22488@P848@06248<HaBU48@<H`Q20`@Q00<8@P@Q
24800`@Q00<8@P@Q12400PQ200<48@Q212400PQ20P@Q00<8@P@Q24800PaS00THaQcW<H`]Jcg_AS4i
cS6<6<H00Q2400@<Ha245:DHaP8DY@0348@DYABU008DY@<HaP055:DHaQS65:D@Q00236<021S65:DD
YABU48@<Ha2436<348@011BU48@@Q1240PaS0Q240QBU0Q2400<DYA2448@00QBU0aS611BU00D@Q1BU
48@@Q1BU00@HaP035:DHaQS600<HaP<DY@8HaP037>LHaQS6008DY@8@Q0075:D@Q1BU5:DHaQBU6<H0
0Q240aBU0a2411BU00H@Q1BU6<HHaQBU6<H35:D348@35:D548@436<748@836<348@00aBU48@DY@02
48@01ABU36<<H`Q236<0112400<<Ha2436<00a240PaS00@@Q0aS36<8@P<<H`8@Q08<H`0448@<H`aS
48@;36<3248236<748@336<00a2436<8@P01124000848@0300048@@Q00D48@070008@RU:F]I242e[
<H`01cW>00Lmkd8@>LhicSg_@Q1:DP02AS42@Q02?Nl013W>?Nle[CW>0SF]136<00<e[Be[;F/00SW>
00LaS2e[:DX]Jc6<;F/aS002=Jd00cW><H`aS002<H`00cF]>LhicP02>Lh4?Nl2<H`00be[:DXYBP05
;F/4<H`013F]>LhmkdHa0Tic00A6<Cg_>Lhmk`<icP03=JdaS36<008YBP03;F/YBRe[00<aS0@]J`07
<H`]Jbe[:DXU:BU:<H`00SF]0c6<0bU:0be[12480bDY0R4800@U:Be[;F/YBP8Li`8Q20DYBP04;F/a
S2e[:DX29BT47>L29BT012489BTQ22480bDY00D]Jc6<=Jde[BU:008U:@8]J`@U:@8Li`036<HQ22DY
00<Q208Li`038@PU:BDY00@U:@048@PU:BU:;F/2:DX02bDY8@PQ22DY:DXU:AcW6<HLib487>L00R48
12DY00P]JbU:;F/e[C6<:DXU:B480RDY00@Q21cW7>L@Q08<H`88@P<48@<8@PT48@88@P848@030004
8@@Q00X48@0424848@Q21242248010@Q24848@Q22`@Q0`Q22P@Q00@HaR489BTDY@8<H`8Li`03:DX]
Jc6<00924004CW=BU48@>Lh2:DX00bDY6<H@Q00236<3248336<424801@@Q2488@P@Q24800P@Q0`Q2
00<48@Q2248010@Q00<8@PaS36<02`Q200<48@Q2124010@Q00D8@PaS48@DYAS6008@Q0031248@P@Q
00<48@<8@P@48@88@P031248@PQ200@48@<8@P0;48@HaQBU>Li:DUkgIcTicRU:6<H<H`045:D02Q24
5:DDYABU48@<Ha245:DHaQcW1QBU0a2400<DYA2448@00PaS0Q2400<<Ha245:D00Q2400<<HaBU48@0
0PaS00@@Q1BU6<HDY@8@Q00536<DYABU5:DHaP025:D01aS65:DDYABU48@DYA2400<DY@046<HDYAS6
6<H35:D36<H00acW6<HHaP037>L011BU6<HLiaS60Q240QBU00@HaQ2448@@Q0@DY@0:48@DYA245:D@
Q0aS48@DYAS65:D248@01ABU6<HHaQBU48@00QBU00DHaQBU5:D@Q1BU00D@Q00336<@Q0aS00D<H`05
48@<H`aS48@<H`0348@2248236<248@236<00a245:D@Q00436<011BU48@@Q0aS0a2400<8@PaS36<0
0Q240PaS00L8@PaS36<<Ha2436<@Q00236<010Q236<@Q1BU0a242@aS00<8@PaS36<01PaS00D@Q0aS
48@<Ha2400<<H`48@P0000H000@Q124000@Q000512401@Q2:DYF]DHa;F/00SF]00LaS3W>>LhmkcW>
=JdicP02?Nl3>Lh014HaBU96<DHa148@00@mkcF]<H`e[@8icP05=JdaS36<<H`]J`02<H`2=Jd01C6<
;F/]Jbe[:DX00S6<0SF]0S6<0Re[00@e[Be[<H`e[@8icP07=Jdmkd8@?Nle[B489BT00RU:00@]Jc6<
<H`YBP8]J`03<H`e[C6<008aS005?Nm244YBBU924006>Lh2<H`012U:;F/YBRU:0Re[00<aS2e[<H`0
0RU:00@aS2e[<H`aS08YBP04;F/YBRe[;F/4<H`00be[:DXYBP02:DX012DY8@PQ22480bDY00dLib48
9BTYBS6<;F/U:B487>LHaRDY:DX]J`029BT01be[<H`aS2U:9BTYBRDY00<Li`049BTQ22DY8@P39BT2
8@P2:DX01SW>=JdaS2e[9BTYBP8]J`039BTQ22DY00<Q20057>LQ22489BTQ20047>L59BT01b487>LU
:BU:;F/aS2DY008Q20049BTYBRU:8@P47>L48@P5:DX0136<=JdaS2e[12DY00<HaQBU48@00Q2400T<
H`Q212448@Q21248@P@Q248020@Q0PQ200<48@0012402@@Q0PQ21`@Q00@8@P@Q24848@88@P848@03
24848@@Q00848@0324848@@Q00848@<8@P848@0324848@@Q00848@8@Q0036<HQ21BU008@Q00@5:DQ
22DY:DXe[CW>BU96<D8@>LhYBRe[8@PLia2436<2248236<00`Q236<8@P0236<224801`@Q24848@@Q
00048@Q200@48@0424848@@Q24821243248336<2248010aS2488@P@Q0PQ200@48@Q21248@P@48@88
@P045:DHaQBU48@324801`@Q2488@PQ21248@P@Q0088@P<48@88@P031248@P@Q00D8@P0;36<@Q0aS
<H`icV<HJeY>Ld8@8@P@Q0025:D01QS65:D@Q1246<HDY@8@Q00536<@Q1S67>LHaP025:D01acW6<H@
Q0aS48@DYA2400@DY@0348@<Ha24008<H`P@Q0036<HDYAS6008@Q08DY@036<H@Q1BU008HaP8DY@03
6<HDYA24008@Q0045:D@Q1245:D26<H35:D00aS65:DDY@026<H00aBU6<HHaP028@P00acW6<HHaP02
5:D00a245:DHaP045:D248@25:D348@25:D248@00`aS48@HaP025:D248@26<H35:D01AS65:DDYAS6
5:D01a2400HDYA24248<H`Q25:D248@236<00`Q236<<H`0248@336<348@01@aS5:D@Q1BU36<00PQ2
00H<Ha2436<@Q1BU48@336<01A2436<<H`aS48@00PaS0PQ200<@Q0aS48@01`aS00D@Q0aS48@<Ha24
008<H`@@Q0<<H`03248<H`aS00T<H`0348@<H`aS0048@P0000<48@0012401@@Q00/8@P@Q000<Hbe[
HaQ6<Be[>LhmkcW>00@aS00;>Lhmkcg_AS5243W>=JdmkdYBDYA>L`03@Q000cg_@Q124003>Lh00cg_
>LhicP02>Lh00cg_>Lhe[@03=Jd00c6<;F/YBP05<H`2;F/012U:;F/]Jc6<0be[00HaS2e[<H`aS2e[
:DX29BT5:DX3<H`01BU:9BTYBRU:;F/00SF]00DaS3F]=JdicSg_008icP8aS08]J`@aS006;F/aS36<
=JdaS3W>0SF]00<icS6<<H`00RU:1BDY00DaS3F]<H`]JbU:00<]J`8U:@8Q20<U:@038@PU:BDY00HU
:@05:DXU:BDY9BTYBP029BT00bU:8@PU:@02;F/01RU:8@PQ22DY:DXU:@8Q20<U:@068@PU:BDY:DX]
Jc6<0Re[0bDY00<Q22DY9BT00RDY0R480bDY00@Q22DY9BTQ208Li`HQ20057>LU:BDY:DXU:@037>L3
9BT48@P27>L00b489BTU:@029BT2:DX4;F/01BU:;F/YBR486<H00`aS0PQ20`@Q00<8@P@Q248010@Q
0PQ200@48@Q212448@@8@PL48@0324848@@Q00848@<8@P031248@PQ20088@P041248@PQ224821240
0`Q21248@P0812401@Q212448@@Q248010@Q0PQ200@DYAS68@PQ208DY@0448@DYAcW7>L26<H38@P0
11cW6<HDYABU0PaS00<8@P@Q24800a2400<8@P@Q24801PQ200<48@Q212401@@Q10Q200D48@Q22488
@P@Q00<8@PP<H`04248<H`Q22483124020Q21248@PaS5:DHaQBU48@3248312400`Q212448@022482
124424800`@Q2488@P03124224802`aS5:DDYCg_DYA_Ng_NAS4e[AcW36<00QBU0Q240`aS0QBU00P@
Q0aS36<@Q1BU48@<Ha240QBU0PaS11240QBU00P<H`Q248@@Q1BU48@8@PaS11240PaS00@@Q1S66<HD
Y@8@Q08HaP8DY@036<HLiaS600<DY@<@Q08HaP055:DHaQcW7>LHaP0348@00aBU6<HDY@055:D01248
9BTU:AcW0Q2400<DYA245:D011BU0Q240QBU00<HaQBU48@00a2411BU00<HaQBU5:D00QBU00@HaQBU
6<HHaP8DY@0348@DYABU00<DY@036<HDYA24008@Q0045:D@Q0aS48@236<01A2436<<H`Q236<00a24
0PaS0Q240PaS0a240PaS0Q2400<<Ha245:D00Q240PaS0Q241@aS00<@Q0aS24800PQ21PaS1A241@aS
00<@Q0aS48@00`aS00<8@PaS36<00`aS00@@Q0aS36<8@P@<H`88@P448@000`@Q010000@Q124000Q2
124000@Q248aS6<HAS4]JcW>?NlicP8e[@05>Lhe[CF]=Jdmk`02AS401T8@?NlicSg_BU9>L`9:DP=2
40LicP04?NlicSW>=Jd4>Lh01CF]<H`aS2e[<H`00be[00<aS3F]<H`00bU:00PaS2e[;F/YBRe[<H`]
JbU:0Re[00<YBRDY9BT00RU:0Re[00@aS2U::DXYBP8]J`09:DX]Jc6<>Lhe[C6<>LhmkcW>008e[@07
>Lhe[C6<;F/aS2e[:DX00Re[00<e[C6<=Jd00S6<13F]00<]Jc6<9BT00RDY00HQ22DY;F/aS3F]<H`3
:DX01Re[:DXU:AcW8@PU:@PQ20059BTYBRU:9BTQ20029BT2:DX49BT2:DX00be[:DXU:@02:DX00bDY
8@PU:@029BT28@P29BT00b48:DX]J`02<H`39BT00b489BTU:@039BT28@P29BT00bU:;F/U:@037>L0
1BDY7>LLiacW9BT00R4800DLib48:DXYBRDY00<Li`8U:@038@PU:BDY008Q208Li`8U:@06:DXU:BDY
9BTYBRe[0RU:00DU:BU:;F/U:AcW008@Q08<H`0324848@@Q00`48@88@P041248@PQ2248212401000
12448@Q21@@Q0PQ200@48@Q224848@<8@P0436<48@@Q124224800`@Q24848@021242248512400`Q2
1248@P04124324801PaS48@LiacW6<HDY@8@Q08DY@056<HLiaS67>LHaP027>L26<H248@2248436<3
248010@Q2488@PQ210@Q00<8@P@Q12400P@Q0PQ20`@Q0PQ20P@Q0PQ200<<H`Q236<020aS0PQ200@4
8@Q21248@P@48@8@Q08DY@0336<8@PQ200<8@P051248@P@Q24848@0224821243248212400`Q21248
@P02124236<020Q2;F]6<G>LMke>LdHa;F/25:D00a245:D@Q00336<348@236<00aBU6<HDY@0236<4
48@011BU48@<H`aS0aBU00<@Q0aS48@00PaS212400H<HaBU5:D@Q0aS48@26<H00aBU48@HaP036<H3
5:D348@25:D011cW6<HHaQBU0QS60QBU00D@Q1BU5:DDYA24008DY@8Li`039BTQ21S600@DY@8@Q003
5:D@Q1BU00@DY@0448@DYABU48@25:D01A245:DHaQBU6<H01QBU00DHaQBU5:DDYA24008DY@8HaP03
48@DYABU008DY@@<H`<@Q0<<H`0348@<H`aS00<<H`8@Q0<<H`0348@DYA24008<H`<@Q0D<H`8@Q08<
H`8@Q00336<8@PQ200T<H`03248<H`aS00D@Q00336<@Q0aS008@Q0T<H`<@Q0D<H`<8@P0000<000@Q
12400P@Q00@000@Q1248@P848@07248e[F]JCW<aS3g_AS401T8@00<mkd8@@Q000Sg_00=244HaBU80
0TYB00A6<CW>>Lhe[@DicP03@Q0mkd8@00@mk`03=JdicSW>00<icP03=JdicSF]00<aS004;F/U:BU:
:DX2;F/00bU:9BTU:@02:DX01Be[:DXYBRU:9BT00RU:1Re[00@aS2e[:DXYBP8]J`@aS007=JdaS3F]
>LhmkcW>=Jd00bU:00@]JcF]<H`]J`8aS08]J`03:DXaS3F]008e[@06<H`YBRe[<H`]JbU:0RDY0Re[
00LYBRDY:DXaS3W><H`YBP02;F/29BT012489BTU:BDY0QcW00<Q22DY9BT00R4800<U:Be[:DX00RDY
00TYBRDY9BTU:BU:9BTQ22DY:DX00S6<00<U:B489BT00RDY00<Q22DY8@P00b4800PYBRe[;F/]JbDY
8@PU:B480bDY0R4800<U:BU::DX01BDY1b480acW0b4800DLiaS67>LLib48008U:@8Li`046<HLib48
7>L28@P2:DX012e[:DXYBRDY0bU:00HLiaS648@DY@aS248312400`Q212448@0912401@Q212448@@Q
24801@@Q0PQ21@@Q1@Q200@48@Q224848@88@P8<H`031248@P@Q00<48@0324848@@Q00@8@P848@88
@P@48@<8@P041248@PaS48@27>L28@P01QcW5:DDY@aS5:D@Q08DY@0536<DYAcW6<H<H`0224801Q24
36<48@@Q24848@88@P031248@PQ200@8@PH48@0324848@@Q00<8@P051248@PaS36<@Q00236<01124
5:DHaQcW0QBU00<@Q0aS36<00`Q200<48@Q2248010@Q00<8@PaS48@00QBU0PaS0P@Q0`Q200@48@Q2
1248@P848@<8@P<48@0424848@Q2124224803@aS48@@Q36<>LiNmfLiCW=:DRU:6<HDY@aS008@Q003
248@Q12400<<H`0348@DYA24008@Q0045:D@Q0aS48@25:D248@01`aS5:DDYAS65:D@Q0aS00<@Q004
5:D@Q12436<648@01ABU48@DYA246<H00QBU00<HaQBU5:D00Q240QS600HDYA2448@HaQcW6<H27>L0
0aS65:DDY@025:D00aS65:D@Q0025:D01QcW5:D@Q1BU6<HLi`8HaPHDY@0548@DYABU6<HDY@0248@2
6<H00aBU48@@Q0045:D36<H01QBU48@HaQS67>LHaP8@Q0035:D@Q1BU00@DY@<@Q08DY@0348@<H`aS
00@@Q00536<@Q0aS48@<H`0348@236<248@010aS48@<Ha240PaS11240PaS00@@Q0aS48@<H`<@Q0L<
H`04248<Ha2448@336<248@236<011BU48@<H`aS0QBU00D@Q0Q236<<Ha2400<<H`03248<Ha24008@
Q00436<8@PQ236<2248136<1248124800005124000@Q1240000312402@Q200048@Q2;F]W>E:D<Ha2
4002AS40148@BU9:DT8@0Sg_0THa00a243g_?Nm6<D8@BU9>LdHa@Q0icSF]>Lh4=Jd2>Lh2?Nl02T8@
?NlmkcW>?NlicSg_@Q0mkcW>0SF]00DicSF]<H`YBS6<00<]J`03:DX]JbU:00@YBP06;F/U:BDY9BTY
BS6<0RU:00P]Jc6<;F/YBS6<=JdicS6<0RU:0S6<0cF]0S6<13W>00D]Jc6<<H`]Jc6<008]J`<aS0<]
J`8aS08e[@8aS0039BTYBRU:00<YBP8]J`8YBP069BTaS3W>>LhaS2480RDY00<Q22DY8@P00R4800DL
iaS67>LLib4800DYBP@U:@068@PU:BDY:DX]JbU:0be[00HYBRDY8@PU:BU:9BT28@P021cW8@PU:B48
:DX]JbU:9BT28@P00bDY8@PQ20029BT00bU:9BTYBP039BT00b489BTU:@029BT00b489BTQ20028@P3
7>L012489BTQ21cW0QS600<Lib488@P00R4800HLib488@PLib489BT2:DX00bDY:DXYBP02;F/2:DX2
7>L248@236<2248<1243248010@Q24848@Q20`@Q00L8@P@Q1248@P@Q24848@0224800`@Q2488@P02
36<5248010@Q2488@PQ20P@Q00<8@P@Q124010@Q10Q21@@Q00<8@P@Q12400P@Q00<8@PaS36<00QBU
00`Q22DY9BTQ21BU48@<Ha245:D@Q0aS6<H29BT011BU1248@PaS0`Q200@<H`Q224848@88@P031248
@PaS0088@PL48@<8@P848@<8@P8<H`<@Q08HaP048@PLiaBU5:D348@00`aS2488@P04124224801`@Q
248<HaBU6<HDYA240088@P0436<8@PQ2248312442483124010Q21248@PQ20P@Q00h8@Q2436<8@R48
=JeF]E:DAS5JeU:D<H`Li`Q21a240`aS0aBU0PaS00D@Q1BU48@@Q1BU008@Q00336<@Q12400<DY@03
48@<H`aS00<DY@<@Q0<DY@8@Q0<DY@0536<@Q1BU5:DHaP0248@02QBU6<HHaQS65:D<Ha245:DLib48
0aS611BU00THaQBU5:DHaQcW6<HDYA245:D00aS60aBU0QS600<DYA2448@00aBU0a2400LHaQBU5:DD
YA245:DHaP025:D00aS67>LDY@0248@26<H01ABU48@HaQS65:D00Q2411BU00D@Q1BU6<HDYA24008<
H`035:D@Q12400<<H`0548@<H`aS48@DY@0248@236<348@436<348@436<0112436<<H`aS112410aS
00<@Q0aS36<00PaS00H@Q0aS36<<H`Q236<348@01`Q248@HaQS65:D<H`Q200<<H`8@Q00336<8@PaS
008@Q0P<H`48@P000P@Q00<000@Q12400`@Q00/8@P@Q1248@SF]MkeJeSW>CW=:DTHa00924004AS52
448@AS43@Q02?Nl2@Q02?Nl00cW>=JdicP02=Jd2<H`012e[<H`icSg_0SW>00<e[CW>?Nl00d8@00<m
kcW>>Lh01SF]00DaS2e[;F/YBRe[008aS08YBP038@PU:BU:008]J`8YBP03;F/aS36<008]J`04<H`]
Jbe[;F/2<H`01SF]<H`aS36<=JdaS08]J`04=JdmkcW>>Lh5<H`00cF]<H`aS003<H`2;F/0136<=Jde
[C6<0Re[0c6<0Re[0RU:0be[00<YBRDY:DX00RDY00<YBRDY;F/00S6<00@e[Be[;F/YBP8U:@048@PL
iacW7>L29BT01BU:;F/]Jbe[9BT00b480RDY0bU:00@aS3W><H`YBP8Q208YBP039BTQ224800<Q2007
7>LU:BU:;F/U:AcW8@P01bU:0RDY0R4800<U:B488@P00RDY0R4800LYBSF]:DXQ21cW8@PU:@028@P3
7>L38@P021S67>LU:BDY:DXU:B489BT2;F/01S6<=Jd]JbU:9BTHaP<DY@0348@8@P@Q00H48@030004
8@@Q00H48@0400048@Q22483124010Q2124000@Q0PQ20P@Q10Q20`aS00@8@PaS36<@Q0<<H`0348@<
H`Q200@48@88@P848@04248<Ha2448@224800`@Q2488@P0312401@Q212448@Q236<00PQ200d<Ha24
:DX]Jc6<AS4e[B4848@48@Q236<8@P0436<01@@Q2488@P@Q24800`@Q0PQ200@48@Q224848@88@P<4
8@0324848@@Q00848@0A24848@Q236<48@0036<Q23W>;F/HaQBU9BU:DU:DE[Dmk`028@P00aS648@<
H`0324801@aS24848@@Q24800P@Q00L<Ha247>LLia245:D<H`0324800`aS24848@03248212432482
124624801`aS48@@Q1cW8@Q:DUJe009BU003=JdQ21S600<<H`@@Q00436<@Q1BU5:D248@00`aS48@<
H`0336<348@01aBU36<<Ha245:DLiaS6008DY@8HaP035:D@Q12400<DY@8@Q00436<@Q1BU6<H25:D0
0a245:DHaP0248@01QBU48@@Q1BU48@DY@<@Q0035:DLiacW00@HaP057>LDYA245:DHaP0248@00aBU
7>LLi`025:D01AS65:DDYA245:D00QS600@DYA2436<<H`<DY@<@Q0036<HDYABU00HDY@<HaP035:DH
aQS600<HaP045:D@Q12436<35:D548@00aBU48@<H`0236<348@010aS48@@Q0aS0aBU00<@Q0aS36<0
0Q241PaS00X8@PaS48@DYA24248<Ha2436<@Q08<H`0548@<H`aS36<@Q00236<01A2436<@Q0aS2480
0PaS0a2400D<H`Q236<@Q1BU00<<H`0348@<Ha2400H<H`8@Q0035:D@Q0aS00D<H`88@P0000<000@Q
12400P@Q00<000@Q12400`@Q00D8@Re[LiaJeSg_009:DP=6<@92408mk`09@Q16<DHa@Q0mkcF]>Li2
43W>008mk`8icP05=JdaS2e[;F/aS002=Jd2>Lh2=Jd2>Lh3@Q001Sg_>LhicSW>=JdaS0<e[@03<H`]
JbU:008YBP03<H`]JbU:008YBP05;F/U:BU:;F/aS009;F/:<H`2=Jd01SW>=Jde[CF]<H`]J`PaS009
;F/aS36<=JdaS2e[<H`]JbU:00H]J`@YBP8U:@@YBP039BT]Jbe[00<aS08U:@038@PLib48008Q2006
7>LU:BU::DX]JbDY124800<U:B48:DX00c6<0Re[0RU:1bDY0b4800@U:BU::DXU:@8Q20049BTYBRU:
9BT2:DX29BT00b489BTQ20058@P012DY:DXU:BU:0bDY00@Q22DY8@PQ20LLi`048@PU:B489BT28@P2
:DX2<H`01Be[<H`]Jb486<H00QBU00<@Q0aS12400`@Q00<8@P@Q12403@@Q0PQ20`@Q00<8@P@Q1240
1P@Q00<8@PaS36<00`aS0a2400<<H`Q224800`aS00D48@Q224848@Q200@48@0448@LiaS636<21240
1@Q212448@@Q24800`@Q0`Q20PaS00<HaQcW;F/00SW>00<aS24836<00PaS00@8@Q2448@<H`L8@P03
1248@PQ20088@P061248@PaS24848@Q21P@Q1`Q200/48@aS6<HU:Be[7>LHaRe[BU9S65Je008e[@05
6<HLiaBU48@<H`022485124224801@aS5:DHaQS65:D00`aS0PQ200<48@Q224801PQ20P@Q00D8@PaS
2488@P@Q0088@P<<H`0?5:DLicF]@Q1BU6LiCW<e[AcW36<DYA2436<@Q1BU00<@Q0035:DHaQ2400<<
H`<@Q0<<H`0948@<Ha2436<DYAS67>LHaQBU00<@Q0<DY@0348@DYABU00<@Q0035:D@Q1BU008DY@8H
aP<DY@0348@DYABU008DY@8@Q0@DY@8Li`046<HDYAS67>L36<H25:D01A245:DDYAS65:D00QS611BU
0QS600DDYA2436<<Ha2400<DY@0548@DYA245:D@Q0045:D011245:DDYAS60aBU00HHaQBU6<HHaQBU
48@236<01Q245:DDYA2436<@Q0<DY@<<H`<@Q0<<H`D@Q0035:D@Q0aS008<H`8@Q0T<H`0348@<H`aS
008@Q08<H`03248<Ha2400D@Q08<H`<@Q00336<@Q124008@Q0P<H`<@Q0P<H`0448@<H`aS48@436<1
24800005124000@Q12400003124020Q2124000Q2<Hag_E[F>Lh2BU800dHa@Q124003@Q0013g_@Q12
448@0Sg_00DicSg_=Jde[C6<00<icP03=JdYBRe[008aS08e[@8aS0@e[@8aS005=JdaS3F]=JdaS003
>Lh013g_>LhicS6<0Re[0RU:00LaS3F]<H`aS2U:;F/aS002;F/00c6<=Jde[@02=Jd00c6<;F/]J`02
:DX00be[:DXaS002=Jd01S6<;F/]Jc6<=JdicP8e[@8aS003=JdaS3F]008aS00;;F/YBRe[<H`YBRe[
<H`e[Cg_>Lh]J`02:DX3<H`00be[<H`e[@02<H`4;F/012U:9BTU:B480RDY00@YBRe[;F/]J`8YBP@U
:@06:DXU:BDY7>LQ22DY0b4800<U:BU::DX012DY0RU:00PU:Be[:DXU:B489BT]JbU:0R4800LU:B48
8@PLib489BTQ20039BT88@P01AcW8@PLiacW6<H00QcW0b4800<U:Be[:DX00bDY2b480RDY00TQ22DY
9BTYBRe[:DX]JbU:9BT00QS600<DY@aS24803@@Q00<8@P0012401@@Q00@8@P@Q24848@88@P@48@07
24848@@Q248<HaBU48@00PaS00@DYAcW6<HHaP<DY@8@Q00624848@Q2124<H`Q20P@Q0PQ200D48ABU
6<HDY@Q200848@88@P848@88@P848@0536<8@PQ21248@P025:D01acW:DXU:BDY6<H@Q0aS0088@P8<
H`88@P<48@L8@P0436<8@PQ212422483124010Q212448@@Q0PQ200P48@Q248@<H`@Q36<@Q2DY0QcW
00H]Jd8@HaQNmfLiHaP2F]H01cW>:DXDYA245:D8@P@Q00@8@P0800048@@Q248LibDY7>LHaP<8@P03
36<8@PQ200848@<8@P<48@<8@P848@04248<H`aS248236<03Q248@PQ23g_CW=BU6<HBU8aS24848@D
YA2436<248@01QBU48@@Q1BU6<HDY@8@Q08DY@8@Q0075:D@Q0Q236<@Q1S65:D00Q240QBU00DHaQBU
6<HHaQBU008@Q0035:D@Q124008@Q00436<@Q12448@26<H27>L26<H011BU48@@Q1BU0QS600@DYA24
48@@Q08DY@8@Q0HDY@8HaP8DY@0448@DYABU6<H35:D00a245:DDY@025:D448@00aBU48@DY@0348@2
5:D0112436<@Q1S60a2400@DYAS66<HHaP@DY@<HaP055:D<H`aS36<@Q0055:D00a2436<<H`0236<4
48@236<0112436<<Ha240PaS00<@Q0Q236<00`aS00<@Q0aS36<01@aS00@8@PaS36<8@P8<H`8@Q0D<
H`<@Q00436<@Q1245:D248@436<448@736<224800`aS248@Q00248@010aS48@@Q1240`aS0PQ20002
12400`0012448@0312402`Q212448@Q2<HacW5Je>Li6<DicAS400T8@00=6<Cg_?Nl00d8@00<mkcW>
>Lh00Sg_0cW>00De[CW>=JdaS2e[00<aS008>Lhe[C6<;F/aS3F]>Lhe[@8aS004=JdaS2e[<H`2>Lh2
=Jd2>Lh01Cg_>LhaS2e[:DX00Re[00<aS3F]=Jd00c6<00<]Jc6<<H`00S6<0cF]0Re[1BU:00<]Jc6<
=Jd00S6<00<]Jc6<<H`00SF]0SW>0SF]0S6<00@]Jc6<;F/]J`8YBP03;F/aS36<008icP8aS08YBP04
<H`]Jc6<<H`2;F/4<H`3;F/49BT3:DX2;F/012U:9BTQ22480bDY0R480bDY12480RDY0b4800<YBRDY
:DX00Re[0bDY00<]JbU:9BT00R4800HU:B488@PU:B489BT28@P01BDY8@PQ22DY8@P00RDY00@Q21cW
7>LLi`8Q20077>LHaR486<HLib489BT012U:0b4812DY00HQ21cW8@PLib489BT38@P012DY:DXYBRU:
0Re[00PYBRDY6<HHaPaS24848@Q220@Q00<000@Q12402@@Q00<8@P@Q12401@@Q00<8@P@Q24800P@Q
00<<Ha2448@00a2400LHaQcW9BTQ21S65:D@Q00336<22483124324801@@Q48@LiacW6<H01@@Q00<8
@P@Q12400PQ20`@Q0PaS00@@Q0aS6<HLi`8U:@058@PDYA2436<8@P0236<01@Q212448@Q236<00PQ2
00@48@Q2248<H`8@Q00324848@@Q00<8@P<48@88@P<48@03248<H`Q200@<H`0B5:D@Q1cW:DXicU:D
F]I[FVLiHaQW>DYB@Q0LiaS648@8@PaS0`Q20P@Q00L8@P@Q124DYAcW9BTLi`0336<00`@Q2488@P02
24821243248212400`Q21248@P0324805PaS248<H`aS48@HaQBU;F/icU:DJeYF]D8@:DXDYAS65:D@
Q1BU48@DYA2411BU0Q240QBU0Q240`aS0a2400LDYA2448@@Q1BU6<HLi`025:D00aS65:DDY@0348@0
11BU48@@Q0aS11240QS600DLiaS65:DDYAS600DDY@8@Q0LDY@8@Q08DY@8HaP8DY@0648@DYAS66<HD
YA240QS611BU00P@Q0aS48@DYAS65:D@Q0aS0Q240QBU00X@Q1BU48@@Q1BU48@DYAS67>LHaP<DY@8H
aP037>LHaQBU008@Q0@<H`8HaP8DY@8<H`0348@<Ha24008<H`<@Q00436<@Q12436<248@010aS48@<
Ha240`aS00<@Q0aS36<030aS00P8@Q2436<@Q0aS248<Ha240QBU00@@Q0aS48@<H`8@Q00436<8@PaS
36<248@336<010Q236<<H`aS0Q241@aS00<@Q0aS36<01@aS0@Q200001@0012448@@Q00000`@Q00T8
@P00124<HcW>LiaBU36<@Q000THa0Sg_13W>0Sg_00PicSg_@Q0mkcW>=JdaS3F]0SW>00A243g_>Lhe
[@@aS08e[@8icP8mk`8icP8aS004=JdaS2U:<H`3>Lh00c6<=Jde[@02<H`3=Jd3<H`02cF]>LhaS3F]
;F/U:Be[>LhmkcW>=Jd00Re[00<YBRDY:DX00Re[0bU:00@]Jc6<=Jde[@<aS08e[@05>Lhe[CF]>Lha
S002:DX012DY;F/aS36<0Re[00<YBRe[<H`00cF]00@aS3F]<H`e[@8aS004;F/YBRU:;F/2<H`9;F/0
12U:9BTU:BDY0RU:00<U:B488@P01RDY00HYBRDY8@PQ22DY:DX29BT3:DX00bDY8@PU:@03:DX012DY
8@PU:B480RDY0R480bDY00<Q22DY9BT00R4800<Lib488@P01AcW00<HaQcW7>L00R4800@Lib489BTU
:@8YBP8U:@HQ20059BTLiacW6<HLi`058@P29BT01B487>LHaQBU36<00P@Q0PQ21@@Q00@000@Q1240
00D48@0400048@@Q248212400`0012448@0212401P001248@PQ21248@P848@0448@Q22U:8@P248@0
1bDYAS5BU5[FAS4]JbU:008DY@0336<8@PQ20088@P@48@<8@P0336<8@PQ200X48@0336<8@P@Q0084
8@@<H`0348@DYABU008<H`H8@P05124<H`Q224848@02248236<524800`@Q24848@0212401@Q21248
@PQ212400PQ200`@Q1BU5:D<Ha245:DLiaS69BTicUJeNmh2Li`026LiLiaoogNmIcTU:A2424821240
1PaS48@@Q0Q212400088@P055:DHaQS65:D<H`0324800`@Q2488@P03248312400`Q212448@092480
2PaS6<HDYCF]@Q1JeVmkF]I6<Be[0QBU0Q240PaS0Q240QS600<DYA2448@00QBU1A240`aS0Q2400PD
YA2448@DYAS65:D@Q1BU0aS600<DYA2448@0112400H<Ha245:DDYAcW6<H55:D26<H35:D00aS648@@
Q00248@00aS65:D@Q00248@010aS5:DDYAS60a240aBU0Q240QBU0QS6112400<HaQ2436<00Q2400<D
YA2436<00Q240`aS0a2400DDYA2448@@Q1BU008HaP8DY@076<HLiacW5:D@Q0aS48@00QBU0Q2400<D
YA2448@00Q241PaS0a2400<8@PaS48@00a2400<<Ha2436<010aS00<@Q0aS24800`aS0PQ20PaS00<8
@PaS36<00`aS00LDY@aS36<<Ha245:D@Q00436<00a2436<<H`0336<0112436<@Q0Q21`aS00<8@PaS
24800Q241@aS0Q240@aS0@Q20@@Q000312401@0012448@0024800`@Q00H8@SF]LiaJeS6<@Q02AS40
0d8@?NlicP04>Lh00cF]>LhicP02?Nl00d8@>Lhmk`02=Jd2>Lh00d8@AS4mk`02=Jd01S6<=Jde[CF]
>Lhmk`924003>Lhe[CW>008aS006;F/aS3F]=JdicSF]0cW>00<e[C6<<H`00SF]0c6<00@e[C6<=Jde
[@8]J`07<H`]JcW>@Q0mkcF]<H`00be[12U:00<U:Be[;F/00S6<00Le[C6<=Jde[CW>?NlicP02=Jd3
;F/4:DX00be[<H`]J`03;F/3=Jd3<H`00cF]<H`aS004:DX01C6<=JdaS2e[:DX00be[0RU:00@]JbU:
9BTU:@<YBP039BTQ22DY008U:@8Q20039BTYBRDY008Q208U:@038@PU:BDY008YBP@Q20DU:@8YBP@Q
2005:DXU:BDY8@PU:@078@P00bDY8@PLi`026<H00acW8@PLi`038@P01RDY:DXYBRU:9BTQ208U:@8Q
20039BTYBR4800@Li`8Q20<U:@068@PU:AcW7>LDY@aS0`Q23P@Q00<8@P@Q12402`@Q00@8@P@Q36<<
H`848@0A248@Q2487>LHaQ247>Le[DHaIcUJeSW>=JdLiaS65:D<H`0824800`@Q2488@P0224800`@Q
24848@0324821242248212400`Q21248@P02248236<011245:D@Q1240PaS0PQ200@48@Q2248<H`<4
8@0324848@Q20088@P0336<8@PaS00L8@P031248@PQ200@8@P0336<8@Q24008HaP0:5:D@Q1248@Pa
S4HaKg]cW7NmKg/2JeX01W_NOomBU2e[24848@D8@P@48@0548@DYAS66<H<H`0324801@aS2488@P@Q
248010@Q2PQ21@aS00TYBSF]E[E_Ne[FE[Dmkb487>L00a2400<DYA2448@00Q241ABU00@HaQBU48@<
H`<@Q08<H`0348@DYA24008@Q08HaP8DY@<HaPL@Q08<H`0448@DYAcW7>L56<H00a245:D@Q0026<H0
1ABU48@DYABU48@011BU0a2400<DYAS65:D00Q241ABU00<@Q1BU5:D00aBU00<HaQBU5:D00Q240QBU
0Q2400H<Ha2448@<Ha2436<648@01PaS5:DHaQcW6<HDY@<HaP037>LDYABU008@Q0055:D@Q1BU6<HD
Y@0548@236<248@236<02PQ236<@Q12436<@Q0aS48@<Ha241@aS00D8@PaS248<H`Q2008<H`05248<
H`aS36<8@P0236<00a2436<@Q00248@020aS48@@Q1BU48@<H`Q236<348@01@aS48@@Q12424801`aS
0Q2400D<H`Q236<<HaBU00D<H`0348@<H`aS0048@P0000<000@Q00000P@Q00`000@Q1248@P@Q000<
HcF]LiaF]CW>BU82CW<0148@?NlicSF]0cW>0SF]00`mkdHaAS5243W>@Q16<Cg_>Lhmkd8@?Nl2>Lh0
0cg_AS56<@02@Q06?Nl00cW>=JdaS002<H`2;F/2<H`01SF]>LhmkcW>=JdaS0<e[@8aS004=JdicSF]
>Lh2;F/0136<=JdicT8@0Sg_00<icRe[;F/00bU:00PU:BU:<H`aS2e[:DX]Jc6<12e[00@icSg_?Nm2
408e[@05;F/YBRU::DXaS003;F/00c6<=JdaS003;F/2=Jd01C6<;F/YBRU:;F/00S6<00<]Jb488@P0
0RDY0be[00DYBRe[:DX]JbU:00<]J`8YBP049BTYBRDY9BT28@P29BT01BU:9BTU:BDY8@P00bU:00<U
:B488@P00bDY0R480RDY00@YBRDY8@PU:@8YBP088@PLib489BTaS2e[9BTQ20DLi`DQ208Li`<HaP03
7>LU:BDY008U:@8Q20@U:@03:DXU:B48008Li`038@PU:B4800<Li`8Q20056<HDYA2436<8@P0<1240
100012448@0010@Q00@000@Q1248@PP48@88@P0?1248@P@Q124@Q2DY;F/LiaS6:DY:DVLiG_MW>F<H
009JeP06>LhaS12448@<H`@Q0PQ20PaS00@8@P@Q1248@P<<H`L48@0324848@Q200<48@0324848@Q2
00<8@PD<H`88@P848@@8@P848@88@P848@H8@P848@<8@P<48@0?248<H`Q2124HaRU:>LhaS1BU48@H
aQ24:DXmke:D009cW00=MkecW6]JIcUkgWooG_L]J`@Q0008@P@Q00000P@Q00@000@Q2488@P8@Q004
36<8@P@Q248236<92482124010Q212448@Q20`@Q0PQ200d<Ha246<H@Q36<AS5S66mkF]IF]DHa:DXL
i`0348@01PaS48@@Q1BU6<HDY@8@Q0035:DHaQ24008<H`0348@<H`aS008<H`035:DHaQBU008@Q004
5:DHaQcW6<H25:D01AS65:DHaQBU48@00QBU0a241ABU0QS600<DYAS65:D00QBU00<HaQBU48@01ABU
0Q2400LDYAS65:D@Q0aS48@DY@0348@75:D36<H00aBU48@@Q00248@00aBU48@<H`025:D00aS648@<
H`0236<25:D01A2436<<Ha245:D00Q2400HDYAS66<HDYA245:D36<H248@00aBU48@@Q00248@01aBU
48@<H`aS48@<Ha2400@<H`0748@<H`aS248<H`Q248@00QBU0Q2400D<Ha2436<<H`Q2008<H`0348@<
H`aS0088@P<<H`<8@PH<H`04248<H`aS48@436<00`Q236<<H`0236<0112436<<H`Q20a240`aS00L8
@PaS48@<Ha245:D<H`03248248@236<148@1248000/48@06248e[GNmF]He[DHa0Tic00E:DTHa@Q0i
cSg_00@e[@<mk`03@Q0mkd8@00Dmk`04@Q0mkcg_>Lh2?Nl00dHa@Q124002@Q000cg_@Q0mk`02>Lh3
=Jd2<H`00be[:DXe[@02?Nl01SW><H`e[CW>=JdaS08]J`05<H`icSW>>LhaS002;F/0236<?NlicSg_
AS5243W><H`4:DX01Be[:DX]Jbe[<H`00be[00LaS2e[:DXaS3W>@Q0icP03=Jd2<H`012e[<H`aS2e[
0c6<00@e[C6<<H`aS0D]J`04<H`YBRU:;F/2<H`00bU:9BTQ2002:DX4;F/00bU:;F/YBP02;F/01BU:
9BTU:BDY:DX01BDY0bU:0bDY0bU:0b4800DU:BU:9BTQ21cW00HU:@08:DXQ21cW7>LYBRe[<H`YBP8Q
20037>LQ21cW008Li`8Q20037>LHaQcW00@Li`056<HQ2248:DXU:@028@P01AcW8@PQ22489BT00RU:
00<U:B487>L00b480acW00@Q21cW6<HDY@8<H`0324848@@Q00D48@0300048@@Q00<48@0300048@@Q
00h48@0324848@@Q00848@0<24848@aS5:DLiaS67>LU:CW>DYAJeW>L0fLi00M:DTHa8@PDY@aS124<
H`0324801`aS12448@@Q248@Q0aS00848@0324848@@Q00<48@0424848@Q21243248212401PQ236<<
Ha2436<8@P<48@88@PD48@@8@P848@05248<H`aS24848@0224800`@Q24848@0624801`aS48@<Hbe[
@Q0icRU:0088@P0>7>L]Jd8@JeYW>GNmLia_Nf<HMkeoog_NF]HHaPX48@03248<H`aS008<H`032484
8@Q200T8@P041248@P@Q12432483124236<0312436<8@RDY=JeJeVLiF]IS65[F?Nl]J`8DY@0<48@<
H`aS36<DYAS67>LDYA245:DHaQBU0`aS00<DYA2436<00Q2400@<Ha245:DLi`<DY@047>LDYA245:D3
7>L248@00aBU48@DY@0348@00aBU6<HDY@046<H00aBU6<HDY@0248@011BU6<HDY@aS0Q2400@DYA24
5:D@Q0<DY@8<H`0448@DYABU48@65:D26<H00aBU48@DY@0948@011BU48@DYA240`aS1A240aBU00@H
aQBU5:DDY@8HaP@DY@8@Q0<DY@0348@<Ha2400<@Q00336<@Q0aS00H<H`D@Q0<<H`<@Q0D<H`03248<
Ha2400<<H`0348@<H`aS00H<H`0448@<Ha2448@236<00`Q236<8@P0:36<02A2436<<H`aS48@<H`Q2
36<DY@0248@236<01A2436<<Ha2436<00@Q200001@00124000@Q00000`@Q00`8@P001248@SF]MkeJ
eSW>BU9>LdYBAS45@Q001Cg_@Q1243W>=Jd00SW>0T8@00DmkcW>>LhmkcW>00<e[@0<>Li2448@@Q16
<D8@AS4mkd8@?Nm243g_0cF]0SW>0SF]00HaS3F]>Lhmkd8@?Nl2>Lh7<H`03CF]<H`]Jc6<=JdicSF]
;F/e[Cg_=JdYBRDY008aS003;F/YBRe[008]J`8YBP<]J`<YBP8aS0<]J`04=JdaS36<<H`2=Jd02SW>
=Jde[CF]<H`e[CW>=JdaS2e[0RU:0RDY00<YBRDY9BT00RDY1RU:00L]JbU:;F/]JbU:;F/YBP029BT0
1BU:9BTU:AcW8@P00bDY0be[00<YBRDY9BT00RU:00DQ22DY8@PQ22DY00@Q20079BTQ22DY9BTYBRe[
:DX00RDY00<Q22U::DX00Re[00HYBRDY8@PQ21cW8@P37>L01BDY8@PQ22487>L00QS600<LibDY9BT0
0QcW0RDY0QcW00<HaRDY:DX00RU:00DU:B488@PQ21cW00@Q208HaP0548@8@PQ21248@P0912400`00
12448@0@12400`0012448@03124424804PaS6<HYBR489BTmke[FMkecW6mkIcUcW7ooMkeW>BU:5:D<
H`848@0436<DYA2424841243248412400`0012448@0224800`@Q2488@P0312400`Q236<8@P032482
36<412401@Q212448@@Q248010@Q00<8@P@Q24800`Q200<48@Q224800P@Q20Q2014Q22DYBU9JeS6<
9BT@Q0aS9BT]Jd8@E[EJeVLiJeYg_G_N009_N`07AS4mkb4848@8@P@Q248010@Q00@8@P@Q1248@P<<
H`04248@Q12448@436<224800`@Q2488@P03124324804@@Q248000@Q248<Ha2436<YBTHaIcUcW5[F
IcUNmd8@<H`00QcW00DDY@aS48@DYAcW00<DY@066<HDYABU36<@Q0aS0Q2400LDYA2448@<Ha246<HD
Y@036<H011BU6<HHaQBU0acW00<HaQBU5:D00aBU00<@Q1BU48@00aBU11S600<DYAS66<H011BU00<@
Q1BU36<00Q240aBU00<@Q1S66<H01ABU00<HaQ245:D00a2400DDYAS66<HDYAS600<DY@0448@<HaBU
48@25:D348@00`aS48@<H`0248@00aBU48@DY@0448@011BU6<HHaQS60QBU00DLiaS65:D@Q1BU00<@
Q0045:D@Q0aS36<448@236<00a2436<<H`0236<00`Q236<<H`0248@236<00a2436<<H`0536<00a24
248<H`0436<01@Q236<<H`aS24800`aS00D8@PaS36<<Ha2400@8@P0336<@Q124008<H`8@Q0D<H`<@
Q0<<H`<@Q0035:D@Q0aS00@<H`0348@<H`aS004<H`001@@Q00<000@Q24800`@Q00H<HcF]MkeJeSW>
BU82CW<00dHaBU924004?Nl2AS401D8@?Nle[CF]?Nl00T8@00PicS6<<H`mkcW>=JdaS3W>0Sg_00=2
44Ha@Q000T8@0cg_00=243W>=Jd00SF]0SW>00TaS3F]=JdaS3W>?NlicSg_=Jd00S6<00@]JcF]<H`]
J`<e[@<aS008>LhaS36<=JdicSF]<H`YBP@]J`03:DX]JbU:00H]J`03:DX]Jbe[008aS08]J`03<H`]
Jc6<008aS004=JdaS3F]=Jd2<H`2=Jd2>Lh2;F/3:DX79BT3:DX2;F/01C6<;F/YBRe[<H`01BU:00DU
:B487>LQ22DY00@YBP8]J`04:DXU:BDY9BT28@P29BT2:DX01b489BTQ22U:9BTQ22DY008YBP039BTQ
22DY00<YBP0<;F/aS2U:8@PLibDY8@PHaQcW8@PU:B480QcW00DU:B487>LLib48008Li`@Q20<Li`04
8@PU:BU:9BT38@P021cW8@PLib489BTLiaS648@236<6124010001248@PQ20P@Q00<000@Q12401@@Q
00<000@Q12402`@Q01T8@P@Q1248@PaS248@Q1BU7>LHaR48<Ha:DVmkLiag_FmkJeY_Ng_NOomBU3F]
36<00003248010aS24848@000P@Q0PQ200<48@Q212401P@Q00@8@P@Q24848@<8@P031248@PQ20088
@P041248@PQ236<324821243248312400`Q212448@02248336<00`Q21248@P0324800`@Q24848@02
24803PaS48@<HcW>F]INmd8@48@<HacW8@PaS4HaCW<2HaP017>LMke_Nf]J0U:D00<icR4848@00P@Q
10Q200D48@Q212448@Q2008<H`0548@<H`aS36<@Q00236<2248336<3124524800`@Q24848@022480
2`aS248LibU:DYAS65[FJeYNme:D@Q000RDY00<DYA2448@00QBU00<HaQBU6<H00QBU3A2400DHaQBU
5:DHaQBU00LHaP@DY@0548@DYABU5:DHaP035:D011S65:DLiaS61ABU00<HaQBU48@00a241ABU00<H
aQBU48@01ABU0Q240QBU00DHaQBU5:DDYAS6008DY@0348@DYA2400D@Q08<H`0348@<Ha2400L@Q003
5:D@Q124008DY@8HaP075:DHaQcW6<HDYA245:D01A2400D<Ha245:DDYA24008<H`8@Q0<<H`D@Q0<<
H`8@Q0<<H`<@Q00536<8@PaS48@<H`0224800`aS48@<H`0236<00`Q236<8@P0436<3248336<01A24
36<@Q0aS24800PaS00<8@PaS36<00PaS0a2400<<Ha2448@00a2400<<Ha2436<011240@Q200000`00
1240000312402P001248@P@Q0008@SF]MkeJeSW>0dYB00A6<D8@AS5240Lmk`04@Q0mkd8@?Nl3>Lh3
=Jd0136<>LhicSg_1SW>00@mkd8@@Q0mk`LicPDe[@8icP03=JdaS36<008aS003>Lhe[CF]008icP03
=JdaS36<008e[@06<H`]Jc6<;F/YBS6<0SF]00D]JbU:<H`e[C6<00<YBP04;F/aS36<<H`2;F/00bU:
;F/YBP02;F/2:DX00be[<H`]J`02:DX01Be[<H`]Jc6<=Jd00SW>00@e[C6<<H`YBP8]J`0:<H`YBRDY
9BTYBRe[:DXU:B489BT3:DX012DY;F/aS3F]0Re[00DaS2U:9BTQ22DY008YBP03;F/YBRU:008YBP8a
S003;F/YBR48008U:@8Q208Li`038@PU:BDY008Q20039BTQ2248008Q208U:@<YBP05<H`]JbU:9BTL
i`038@P00bDY:DXU:@048@P27>L28@P012DY8@PQ22480QcW0QS600<Q21cW8@P00bU:0b480RDY00DQ
21cW5:D@Q0Q200T48@0300048@0001L48@0624848@@Q248DYAS60Q2400HHaRDY7>LYBSg_E[D4Li`0
2fLiJeYkgWooG_L]J`Q21248@P@Q24803P@Q00<000@Q24800`Q200@<H`Q224848@88@P0336<8@P@Q
0088@P031248@PQ200/48@P8@P848@@8@P031248@PaS008<H`086<HDYDHaHaQJeTYB5:D<H`8HaP0?
9BTicSW>CW=:DU:DG_M6<CW>9BT]JbDY6<H<H`@Q00<8@P8<H`@48@88@P0448@<Ha245:D248@00`aS
2488@P0336<224801@@Q2488@P@Q248010@Q00h8@PaS36<<H`Q27>LaS5:DHaQJeV]JHaQ:DSW>0QcW
00HDYA246<HLib486<H248@25:D248@236<010Q248@DYABU112400<DYA2448@00Q2400DDYAS66<HH
aQcW008HaP0;5:DHaQBU5:DHaQBU48@DYAS65:D@Q0025:D01QS65:D@Q1S67>LHaP8@Q00:5:D@Q1BU
5:D@Q1BU48@<Ha245:D248@00aBU6<HHaP035:D248@25:D011S65:D@Q1BU0a2411BU00<<Ha245:D0
0Q2400<DYA2436<00`aS0Q2400<DYA2448@00a240QBU00D@Q1BU5:D@Q1BU00<Li`036<H@Q1BU00H@
Q08<H`0448@DYA2436<2248436<01@Q236<@Q1245:D00`aS00<8@Q2436<00PaS00<@Q0aS36<02@aS
0Q2400D<H`Q236<<Ha2400H<H`<@Q00336<8@PaS008@Q08<H`03248<HaBU008@Q00636<8@PaS36<D
YA240PaS00D8@PaS48@@Q0Q200<<H`0010@Q00h000@Q12448@Q200048@aS>Lig_EJe>Li244ic0TYB
00A6<Cg_?Nm6<@9240<icP0:?Nm2448@@Q16<D8@?NlicSF]>Lh2<H`00cF]>LhicP02>Lh01CF]?Nle
[CW>?Nl00T8@00<mkcW>>Lh00SW>0SF]00DaS3W>>Lhe[C6<00@e[@@aS005=JdaS3W>?Nle[@03<H`2
=Jd4<H`01Be[<H`aS3W>=Jd00S6<1Re[0c6<0Re[00@aS2e[;F/]J`8YBP03;F/YBRU:00@YBP03;F/a
S3F]008aS003=JdaS36<00<aS003;F/YBRDY00HYBP8U:@038@PYBRU:00<]J`<YBP03<H`YBRDY008U
:@03;F/YBRe[00@]J`04:DX]Jbe[:DX29BT00b489BTU:@028@P00bDY:DXU:@038@P01RDY8@PLib48
9BTQ208YBP@]J`8YBP038@PLib48008Q208U:@048@PU:BDY8@P27>L012DY8@PLiacW0b480QS60QcW
00<U:BU:9BT00bDY00LQ22DY9BTQ21cW5:D@Q003248212400`0012448@0B12401`Q212448@@Q0004
8@Q200<48@0324848@@Q00848@0D5:DLiacW6<HDYAS6:DXaS4HaHaQ[FW_NLia[FUkgMkeoogNmE[DD
Y@88@PT48@0324848@@Q00848@0824848@Q2124000Q2124<H`@8@P031248@PQ2008<H`848@L8@PP4
8@T8@P061248@PQ21248@P@Q0PQ20Q2400H<HcF]DYAS65[F8@P25:D011248@P]Jbe[0T8@0UJe00Y:
DT8@:DXYBQcW5:D@Q0Q236<48@@8@P<48@0636<8@PQ236<@Q0aS0a240PaS00<8@PaS24800`Q20P@Q
0`Q210@Q0`Q200`<HaS66<He[E:DHaQ_NekgF]I>Lbe[9BT25:D46<H248@00aS65:DDY@0248@00`aS
48@<H`0948@00aBU48@@Q0025:D46<H00acW6<HHaP026<H01A245:DDYAS65:D00Q240QBU00H@Q1S6
6<HLiaS65:D548@01aBU48@DYA245:D@Q1BU008@Q08DY@8HaP<DY@8HaP0<5:D@Q1BU48@DYA245:D@
Q1BU48@<Ha240QBU1A2400<<Ha2448@00`aS0QBU00D@Q0aS48@DYA2400@DY@8HaP047>LHaQS65:D2
48@011BU48@@Q0aS0aBU00D@Q0aS48@<Ha2400H<H`D@Q08<H`0348@<Ha24008<H`8@Q00336<8@PaS
00L<H`8@Q00636<8@PQ236<@Q0aS0PQ20PaS00`@Q0aS248<HaBU48@<H`Q236<@Q0aS48@836<348@0
0`aS48@DY@0348@236<12480000300048@@Q00848@0400048@@Q248212401@Q2=Jeg_E[F=Jd00dYB
0THa0T8@13g_0T8@00Hmkd8@BU96<D8@?Nl2>Lh2@Q000cg_>Lhe[@03=Jd0136<=Jde[CW>0cF]00Hi
cSg_>LhicSF]<H`2=Jd01SW>=JdaS3F]<H`e[@DaS0@icP8e[@0;>Lhe[CF]=JdaS2e[<H`e[CW>=Jda
S002;F/0236<=JdicSg_=JdaS2e[:DX2<H`2=Jd00c6<=JdicP02=Jd3;F/3:DX00be[:DXYBP029BT0
0bU:;F/]J`03;F/0136<:DXYBRU:0c6<0Re[00DYBRe[;F/aS2U:008U:@048@PU:BU:;F/2:DX01bDY
8@PYBRe[<H`]JbU:008]J`04<H`]Jbe[;F/2:DX01S6<=Jde[C6<:DXU:@<Q20<Li`039BTQ2248008Q
20DU:@8Q208YBP04;F/U:BDY:DX48@P00bDY8@PQ20039BT00b487>LQ20028@P012DY8@PQ22480QcW
00/HaQcW8@PU:B48:DXU:B487>LQ22DY008YBP037>LHaPQ200<48@0324848@@Q00<48@0524848@@Q
1240000:12400`001248@P0312400`0024848@07124236<012DY<H`U:AcW0Q2400<YBSW>AS400Ukg
0V]J00]g_G_NLia_NdYB@Q0U:A2424848@Q200<48@<8@P<48@0300048@@Q00H48@03248<H`Q200H8
@P0336<8@PaS00D8@P<48@0324848@Q200@48@0424848@Q21243248212400`Q236<8@P06248020aS
48@<HcW>CW=JeU:D8@P248@00aBU8@PQ20037>L29BT27>L348@236<324800`@Q24848@03124010Q2
36<8@PaS0a240PaS0a2400<<H`Q224801@Q20P@Q00H8@P@Q12448@Q2124324803AS67>LmkdicG_Mc
W6LiE[E:DR487>LDYA2400<HaP8DY@8HaP8DY@<@Q00336<@Q124008DY@0448@<Ha2448@25:D348@0
0aBU6<HHaP025:D26<H35:D26<H35:D00aS65:DDY@025:D00a245:DLi`027>L548@031BU48@@Q0aS
48@DYAS648@DYA246<H@Q0@DY@0848@DYAS66<HDY@aS5:DHaP<DY@<@Q0045:D@Q12448@236<00aBU
48@DY@0248@00`aS48@@Q0025:D248@236<248@00aBU6<HDY@035:D00acW6<HDY@0248@00aS65:D@
Q00248@011S648@@Q1240QBU00@@Q0aS248<H`8@Q08<H`0448@DYA2448@236<00`Q248@<H`0336<2
48@336<01PQ236<<Ha2436<8@P8<H`035:D<H`aS008<H`03248<H`aS008<H`0348@<H`aS00@<H`88
@P<<H`0448@<H`aS48@536<248@236<248@236<248@136<00004124000@Q000312402`Q212448@00
36<icWNmDY@e[DHaCW<00TYB0THa0Sg_00@icT8@?Nlmk`8icP05@Q1:DTYBAS4mk`02>Lh023g_@Q12
43g_>LhmkcF]>Lh3<H`00be[=Jde[@05>Lh00cF]<H`aS002>Lh02SF]<H`e[CF]>Lhe[Be[:DX]Jc6<
0SF]13W>00TaS3F]=JdaS3F];F/aS3F]>Lh00SF]0Re[00HaS3F]>LhmkcF]<H`2;F/01SF]<H`]Jbe[
=JdicP<e[@03:DX]JbU:00XYBP@]J`8YBP04;F/aS36<;F/3:DX00c6<;F/aS002<H`01Be[9BTLibDY
:DX00Re[0RDY0RU:00<U:BU:;F/00S6<0Re[00HaS2e[<H`]JbU:;F/3<H`2;F/28@P37>L00b487>LQ
20028@P39BT38@P29BT2:DX02R489BTYBRU:9BTQ21cW9BTQ21cW0b4800DU:B489BTQ21cW008Q200:
7>LU:BDY9BTQ21cW6<HQ21cW9BT2:DX012DY8@PQ22480RU:00<Q21cW36<00PQ20P@Q00<000@Q1240
1@@Q00<000@Q124010@Q00<000@Q124010@Q00<8@P@Q12401`@Q0PQ200P48@Q212448AcW>Li242U:
0PaS0RDY00TaS4YBE[E[FVLiLiag_G>LJeX00U:D00HaS1cW36<48@Q2124224800`@Q2488@P022480
0`@Q24848@07124424801PaS2488@PQ236<@Q08<H`04248<H`aS36<22487124524800`@Q2488@P03
24821243248212400`Q236<<H`0236<02bDY:DY:DU[F>LhU:A24248HaQcW6<H00QcW00@Q21cW7>LL
i`8DY@0348@<H`aS008<H`88@P<48@0624848@@Q248<Ha2410aS0a2410aS0PQ200<48@Q212400PQ2
0P@Q00D8@P@Q12448@aS0088@P8@Q004;F]:DUkgLi`2F]H00eJe=JdYBP0248@011S67>LLiacW11BU
00<@Q0aS48@00Q240aBU00@@Q1BU48@@Q08<H`0448@HaQ2436<248@26<H45:D00a246<HDY@025:D0
0a245:DDY@045:D00a245:DHaP027>L35:D348@00aBU48@@Q00348@011BU48@@Q12411BU0Q240QS6
00<DYA2436<00aBU00<@Q0aS48@00Q2400DDYAS65:D@Q0aS008@Q0035:D@Q1BU00<<H`0;48@DYA24
48@<Ha245:D@Q1BU48@DY@026<H248@01ABU7>LLiaBU48@00aBU00<@Q1BU5:D00QBU0Q240PaS00<@
Q0aS36<01A2400L<Ha2448@<H`Q236<8@P0236<0112436<<Ha240PaS00<8@PaS48@02@aS0PQ20`aS
00<8@PaS48@00Q241@aS00<8@PaS36<00Q2400<<Ha2448@010aS00<DYA2436<00`aS00<@Q0aS36<0
0`aS000412401@00124000@Q24800P@Q00`8@SW>NmiJeSW>AS5>LdYB@Q16<D8@?Nl3>Lh01Sg_>Lhi
cSg_@Q16<@924003>LhmkdHa0092408mk`07@Q0mkd8@@Q0mkcW><H`00SF]0c6<00@icS6<<H`aS08e
[@8aS007=JdaS36<<H`]JbU:;F/00S6<0cF]00@icSg_?Nlmk`8icPDaS08e[@06@Q0mkcg_>Lh]Jc6<
13W>0SF]1S6<0SF]00PaS3F]=Jde[C6<;F/YBRe[0RU:00@U:B488@PQ208U:@8YBP039BTYBRDY008U
:@048@PU:B488@P2:DX3<H`01SF]<H`]Jbe[:DX]J`8YBP049BTYBRU:9BT2;F/2?Nl0148@AS5243W>
136<00<]JbU:;F/00RU:0bDY0b4800<U:B488@P01B480RDY00@Q22DY8@PYBPHU:@<Li`8Q20047>LQ
22489BT48@P49BT00acW8@PLi`038@P00acW8@PQ20027>L01bU:;F/YBR4836<@Q0Q200D48@030004
8@Q200<48@88@PX48@0600048@@Q00048@Q210@Q0PQ200@<H`@Q12448@8<H`05124U:DHaCW<e[@02
36<032487>LQ23F]AS5JeTicE[ES64YB>LhU:@8YBP046<H<H`Q2248236<010Q212448@@Q0`Q21P@Q
0`Q200<48@Q2124010aS0`Q210aS20Q210@Q10Q20P@Q0PQ200<<H`Q224800PQ200D<H`Q22488@PaS
0088@P8<H`088@PYBSW>@Q0]JacW5:D8@PD@Q08DY@0;48@<H`aS48@DYAS65:D<H`Q21248@P041240
0`Q21248@P0336<00`Q236<@Q00436<0112436<@Q1240PaS0`Q20`@Q00<8@P@Q12400P@Q0PQ20Q24
00T]JdicHaQcW5[FBU8mkbDY8@P00aBU00@HaQcW5:D@Q0<DY@@@Q0<<H`045:DHaQBU5:D248@45:D3
48@55:D01A245:DDYAS65:D00a240aS600@DY@aS5:DDY@8HaP055:DHaQS66<HDY@0348@00aS65:D@
Q00348@35:D26<H95:D236<35:D0112436<@Q1240aBU00<@Q1BU5:D00Q2400@<Ha2436<<H`8@Q003
5:D@Q124008@Q08<H`0348@DYABU00<DY@8Li`066<HDYABU6<HDYA240PaS11BU0a2400@<Ha2448@<
H`8@Q0@<H`8@Q00836<8@PaS36<@Q0aS248<H`8@Q0P<H`0348@<H`aS008<H`<@Q08<H`<@Q0D<H`88
@PD<H`L@Q00436<@Q12448@736<124800004124000@Q000312402@Q212448@@Q248aS7>LF]HicP02
BU801DHa@Q1244Ha?Nl013W>00DmkcW>>LhicSg_00=2408mk`=240<mk`04@Q0mkcg_@Q02=Jd2<H`2
>Lh01C6<=JdaS3F];F/00S6<00<e[C6<<H`0136<0Re[0S6<0SF]00@icSg_?Nlmk`<icP0;=JdaS36<
<H`]Jc6<>Lhmkd8@?Nle[@03<H`00cW>?Nlmk`02=Jd00c6<=Jde[@09<H`01CF]<H`]JbU:;F/00RU:
0b4800<U:BU::DX01RDY0b4800LU:B48;F/aS3W>=JdaS002;F/2<H`2;F/39BT3:DX2<H`01D8@BU9:
DTHa?Nl00SF]0c6<1BU:0bDY0b4800@U:B487>LLi`HQ208U:@@Q208YBP049BTLiaS67>L28@P27>L0
2B487>LLiacW8@PU:BU:8@PU:@027>L38@P00acW8@PLi`029BT01AcW:DX]JbU:8@P00QBU00@<H`@Q
124000/48@0324848@@Q00L48@0300048@@Q00/48@0E248@Q0Q2000LicF]DYA241S65:DHaQBU9BT]
JcF]AS5:DU:DF]I:DTHa008]J`038@PHaQBU00<<H`88@P0336<8@P@Q00H48@0324848@@Q00848@04
24848@Q2248536<01@Q236<8@PQ236<010Q200L48@Q22488@P@Q24848@0324800`aS24848@022480
0`@Q2488@P03248010@Q2488@PaS0PQ200@48@aS36<8@P8HaP05=Jdmkc6<<H`HaP0248@224800a24
5:D@Q00236<25:D02`Q248@U:Be[7>L48@001248@P@Q24800`@Q0PQ210aS00@8@PaS36<@Q0L<H`88
@P041248@P@Q2485124020Q236<@Q0Q28@PicU[FJeX3F]H02CF]9BT<H`aS6<HLib487>L@Q0025:D:
48@25:D0112436<<Ha240aBU0Q2411BU0PaS0Q240aBU0a2400DDYAcW5:DDYA2400@DY@8HaP047>LD
YABU48@25:D448@25:D26<H25:D00aS65:DDY@026<H00aBU48@@Q00236<45:D00a2436<@Q0025:D0
11S648@DYAS60QBU0PaS00<@Q0aS36<00PaS0Q240aBU00@<Ha2448@DY@8HaP8DY@036<HLiacW00DD
Y@@@Q0<DY@@@Q0@<H`8@Q00536<@Q0aS36<@Q00224801PaS48@@Q0aS248<H`8@Q0@<H`8@Q00336<8
@PQ200P<H`0348@<Ha24008@Q0@<H`0348@<H`aS008<H`0348@<H`aS008@Q00536<DYA245:D@Q003
36<010Q236<@Q1240PaS0@Q200000`0012448@021240400012448@Q2124000aS=Jeg_E[F=JdmkdYB
AS5:DTHa0d8@0Sg_13W>0Sg_1SW>13g_1D8@00PmkcW>>LhicSF]<H`e[Be[0S6<00he[CW>>LhaS2U:
9BTYBSF]<H`]Jc6<=JdaS3F]0S6<0SW>00<mkcW>>Lh00SW>00@e[C6<=Jdmk`A240HicP03=JdicSW>
008icP<aS004=JdaS3F]<H`3=Jd8<H`012e[:DXYBRU:0bDY00<Q22DY9BT00b4800<U:BU::DX00bDY
00<YBRe[<H`00Re[0S6<00De[CW>>Lhe[C6<008]J`8aS08YBP05<H`e[DHaCW=:DP02CW<014YBAS4e
[Be[0bU:00HU:B488@PU:AcW8@P27>L78@P021cW9BTYBRU:;F/YBR487>L48@P00acW8@PU:@028@P0
0bDY8@PQ20037>L012487>LQ21cW124800/U:B489BTQ21cW:DX]Jc6<:DXLiaBU008<H`T48@032484
8@@Q01D48@0724848@Q21248@P@Q24800PaS00d8@R48=Je>LdYB9BTHaQBU36<DYB489BTaS002;F/0
12U:8@PQ21BU0Q240PaS00<48@Q25:D00R4800@<H`@Q124000<48@88@P031248@P@Q00<48@@8@P<<
H`03248<H`Q2008<H`06248<H`Q21248@PaS0PQ200<48@Q236<00PQ20P@Q00<8@PaS24800P@Q0PQ2
00<48@Q224801@aS00@8@PaS24848@88@P0<48@DYB48:DX]Jc6<:DXLia2436<@Q0aS0`Q200L<H`Q2
48@@Q1BU48@<H`0224831248248236<010Q236<8@PQ21@aS00<DYA2448@01@Q200<48@Q212400P@Q
0`Q200d<H`Q27>Lmke[FLiaJeU:D@Q0U:B486<HDY@026<H00aBU48@@Q0025:D0112436<@Q1BU1A24
00DDYA2448@@Q1BU00<HaPHDY@036<HDYA24008<H`0348@DYA2400<@Q08HaP8DY@0448@DYAS65:D2
6<H75:D348@00`aS5:DDY@035:D26<H45:D00aS65:DDY@0248@00aBU48@@Q00348@236<01Q245:DD
YABU48@HaP8DY@8@Q08DY@0348@<Ha24008<H`0448@DYABU48@236<45:D248@00aBU7>LLi`026<H0
11BU6<HDYABU0Q2400HHaQ2448@DYA245:D348@436<00a2436<<H`0236<348@336<248@01PaS248<
Ha245:D@Q0@<H`<8@P0348@<H`aS00L<H`0848@<H`Q2248<Ha2436<8@P<<H`0348@<H`aS008@Q0<<
H`8@Q0D<H`8@Q04<H`48@P0010@Q00`000@Q12448@Q200048@Q2=Jeg_E[F=Jd3AS400d8@AS56<@03
@Q02?Nl3>Lh013g_>LhicSg_0SW>00@e[Cg_?Nlmk`8icP04?Nm243g_?Nl2@Q0014Ha@Q0icSF]0c6<
00De[C6<=Jde[CW>008aS0@]J`DaS004=JdaS3F]>Lh2?Nl2>Lh2=Jd4>Lh2?Nl0248@>LhicSF]>Li2
43g_>Lh2<H`00cW>?NlicP02;F/01cF]>LhaS2e[=JdicSF]008aS009=JdaS36<;F/aS2e[<H`]JbU:
00<U:@048@PU:BDY9BT48@P012DY:DXYBRU:0RDY00<YBRe[<H`0136<0cg_00<e[Be[<H`00be[00PU
:Be[;F/icT8@AS5>LdYB0U:D00<mkcW>:DX00Re[00<YBRDY8@P00b480RDY1acW00DQ22DY:DXYBRDY
008Q20049BTLiacW7>L28@P27>L012489BTQ22480acW0R4800<Lib488@P01B480RDY00XLib487>LQ
236<>LhYBQcW248<H`88@P@48@0300048@@Q00D48@0424848@@Q000>1242248212401@Q21248@PQ2
12400PQ20QBU00Le[E:DAS4]Ja2436<HaP027>L2:DX2;F/01B487>LDYABU48@00PaS0P@Q00HDYB48
8@P@Q0@Q0002124224801@@Q2488@P@Q24800P@Q0`Q200D48@Q22488@PaS0088@P0336<8@PQ200T8
@P8<H`0524848@@Q36<8@P051243248010@Q2488@PQ20`aS0`Q200P48@Q236<<HaBU7>LYBS6<0RDY
00<LiaBU36<00PQ200<<H`Q2248010aS00@DYA2448@8@P<48@<8@P848@88@P8<H`@8@P8<H`0348@<
H`aS00@@Q00336<8@PQ200848@<8@P848@@8@P04124HaR48?Nl2G_L016mkG_Le[BU:0Q240aS600@D
YA2448@DY@8@Q08<H`8@Q0<<H`0648@DYABU48@DYAS60aBU00@HaQBU48@DY@<HaPP@Q0DDY@<@Q004
5:DHaQS66<H35:D011245:D@Q1BU0Q241aBU00<HaQBU5:D00QBU00<HaQBU48@00aBU0a2410aS00<@
Q1BU5:D00a240QBU00<HaQBU48@00aBU112400<DYA2448@0112400<DYA245:D00QBU11S600@DYAS6
5:DDY@8@Q00336<@Q1BU008DY@8@Q0<DY@0448@<Ha2448@236<00`Q236<@Q00248@336<00a2436<<
H`0236<01a245:D@Q12436<@Q0aS00<8@P0336<8@PaS008<H`8@Q0<<H`0348@<H`aS00D<H`03248<
H`aS00<@Q00436<@Q0aS36<348@336<248@00`aS48@<H`012480000400048@@Q000212400`001248
@P0212401PQ2<Hag_Ekg>Li240=:DP03AS5:DTHa0096<@03BU96<DHa00=24003AS4mkcW>008icP03
?Nle[C6<008aS08mk`09>Lhe[CW>?Nm6<Cg_>Lhe[CW>008e[@05<H`YBS6<<H`icP04=Jd2<H`00be[
=JdaS002=Jd01c6<>LhmkcW>=JdaS3F]008aS003;F/aS3W>008e[@04>Lhmkcg_@Q02=Jd2>Lh2@Q04
>Lh02Cg_>LhicSF]>Lhe[C6<;F/YBP03;F/2<H`00be[:DX]J`02;F/00bU:9BTU:@02;F/2<H`2;F/4
9BT00bU:9BTQ20029BT2;F/3:DX00bDY:DX]J`02=Jd2<H`01Be[<H`]Jbe[<H`00be[0SF]13W>00=2
44HaCW<00TYB00E>Ld8@=Jd]JbU:008]J`03:DXQ2248008U:@03:DXQ21cW008Q208Li`068@PYBRU:
:DXQ21cW0RDY00@YBR488@PU:@8Q20037>LQ22DY008U:@038@PLib48008U:@03:DXLiaS6008Li`8U
:@0:8@PLib48<H`e[Cg_<H`HaQBU248E12400`Q212448@021242248;124224801PaS2488@Q2436<a
S09>L`08?NlHaP@Q36<Libe[<H`Q208DY@036<HDY@aS00<8@P0336<8@PQ20088@P0336<8@PQ20088
@PD48@0324848@@Q0088@P@48@88@P0436<8@PQ236<7248536<42485124010Q212448@@Q0`Q20P@Q
0PQ200D48@Q224848@Q200848@8<H`035:DHaQS6008Li`048@PU:AS648@624800`aS248<H`0236<0
0`@Q24848@04248010aS12448@@Q0`aS0PQ200D<H`Q236<<H`Q2008<H`8@Q08<H`<8@P031248@P@Q
00<48@D8@P06124@Q2DYAS5NmeJe0Ukg00DicRU:48@HaQBU00<@Q08DY@0348@DYA2400<@Q00336<@
Q124008@Q00336<@Q1BU008@Q08DY@056<HDYAS66<HDY@0248@011BU6<HDYA240PaS0a2400@DYA24
48@@Q08HaP0348@DYABU008HaP045:D@Q1BU48@35:D248@00`aS48@@Q00348@65:D01a245:DHaQS6
5:D@Q0aS008@Q00336<@Q124008<H`8@Q08DY@0348@DYABU00<@Q0<DY@046<HDYABU5:D336<448@0
0`aS48@<H`0248@00aBU6<HHaP026<H35:D011245:D@Q1BU0a240QBU0a240PaS00<8@PaS36<00a24
00<<H`Q236<00PaS1Q2430aS00<@Q0aS36<00PaS00L@Q0aS48@<Ha2436<8@P0236<00a242488@P06
36<2248236<248@336<448@336<00003124000@Q00D48@0924848@@Q248aS7>LF]He[DHa009:DP03
AS5:DTHa00=6<@03BU96<DHa00924096<@03@Q0mkcW>008mk`05>Lhe[C6<<H`e[@05>Lh2?Nl2>Lh3
=Jd3;F/2=Jd2<H`2>Lh00cF];F/aS003<H`01cF]>LhicSW>=JdicSF]00DaS005;F/aS36<=JdicP03
?Nl3>Lh3@Q000cg_>LhicP03>Lh00cg_=Jde[@02=Jd2<H`00be[<H`]J`03<H`00be[:DXYBP02:DX2
;F/2:DX2;F/01c6<;F/U:B489BT]JbU:00<U:@07:DX]JbU:;F/YBRDY:DX00Re[00Le[C6<<H`]JbU:
;F/aS003;F/00c6<;F/aS004>Lh00cg_@Q1:DP02AS401TicAS56<CW>=JdaS08]J`8YBP@U:@048@PL
iaS66<H27>L00b489BTU:@029BT28@P29BT48@P29BT01b487>LLiacW8@PU:B4800<U:@038@PLib48
00@Q20079BTQ22DY>LhmkbU:7>L00P@Q00<8@P@Q12400P@Q00D000@Q12448@Q200D48@0300048@@Q
01448@0424848@Q2124224802P@Q36<<H`aS8@P]Jd8@BU8aS1S60PaS00HDYBe[:DXQ21S636<248@0
1@aS24848@aS24800`aS10Q20`@Q00<8@P@Q24801P@Q00<8@P@Q12400P@Q0PQ200@<H`Q236<<H`@8
@P031248@PaS008<H`04248<H`Q236<3248812400`Q21248@P08248010@Q2488@PQ20Q240QS611cW
00@HaPaS24848@88@P031248@PaS008<H`88@P031248@P@Q00D8@P031248@P@Q0088@P8<H`88@P8<
H`03248<H`aS008@Q0<<H`<8@PD48@0324848@Q20088@P0:124@Q1249BU:DUJeLiaS648@>Lh26<H0
0aBU48@DY@045:D448@010aS48@@Q0aS1a2400@DYAS66<HHaP8DY@8@Q0086<HDYABU5:D@Q0aS48@<
H`<@Q0035:D@Q1BU008HaP035:D@Q1BU008HaPDDY@0348@DYA24008@Q00336<@Q0aS00<@Q0<DY@8@
Q0LDY@0448@<Ha2436<548@25:D448@45:D00aS65:DDY@0;48@236<01ABU6<HHaQBU48@011BU1124
0PaS00@@Q1BU6<HDY@<@Q00336<@Q0aS008<H`8@Q00336<@Q12400@<H`<@Q0<<H`0348@<H`aS00D<
H`0448@<H`aS248736<224801`aS48@<H`aS48@<Ha2400@<H`0348@<H`aS008<H`8@Q0<<H`<@Q003
36<@Q1240048@P000P@Q00<000@Q00000`@Q00T8@P@Q0008@S6<LiaJeSW>AS401DYB0T8@0THa00=:
DTHaAS400THa0TYB00Y6<Cg_?Nm243F]<H`e[Cg_@Q0mk`8e[@03<H`icSW>00<e[@03>Lhe[C6<008a
S003=JdicSF]008e[@03?NlicSF]008]J`03=JdicSF]00@icP@aS004;F/aS2e[;F/2<H`2=Jd2>Lh0
0cF]>LhicP02?Nl01cW>?Nlmkcg_>Lhe[CW>008e[@08?Nm6<Cg_=Jd]JcF]>LhaS0<]J`8YBP039BTY
BRU:00<YBP04;F/aS36<<H`2;F/00bU:9BTU:@02:DX012e[:DXYBRU:0Re[00TaS2e[:DXU:Be[:DX]
JbU:;F/00RU:00@U:B489BTU:@H]J`8aS004;F/e[CW>>Lh3=Jd00d8@AS5:DP02CW<014Ha@Q0e[CF]
0S6<0RDY124800HU:B488@PQ22DY8@P27>L39BT011cW8@PQ21cW0R4812DY0R4800DLibDY:DXU:B48
008U:@09;F/YBRDY7>LQ22DY:DXU:AcW008@Q00424848@@Q000212400`0012448@0612400`Q21244
8@0912400`0012448@051240100024848@Q20`@Q0PQ200`48@Q236<Lib489BT]Jb486<H@Q0Q236<2
48@236<00`Q236<@Q00224800`@Q2488@P0224800`@Q24848@031243248412400`Q212448@021240
0`Q212448@02124424800`@Q2488@P02248436<010Q236<<H`aS0PQ20P@Q0`Q210@Q0`Q200<48@Q2
24800PQ20P@Q0`Q200<48@Q224801@aS0Q240PaS00<8@PaS24800`Q200<<H`Q236<00PaS00<8@P@Q
12400PQ200<<H`Q224800PQ200H<H`Q236<8@PaS248236<01@Q236<<H`Q236<00PQ200<<H`Q21240
0`@Q00<8@P@Q12400`@Q10Q200/48A2448@YBTHaDYA_Nf<H>LhU:@aS008DY@0436<@Q1BU7>L25:D2
48@00aBU48@@Q00236<348@236<00a2436<@Q0035:D010aS48@HaQS60Q2400@DYAS66<HDY@<<H`03
5:DHaQBU00DDY@0348@DYABU008DY@0348@<Ha24008@Q0045:D@Q12448@35:D248@010aS48@@Q124
0aBU00@@Q1BU48@@Q0@DY@0348@DYA24008<H`045:D@Q0aS36<25:D010aS248@Q1BU0a241QBU00<@
Q1BU5:D00QBU00D@Q0aS48@@Q1BU008<H`0348@DYAcW008DY@<HaP035:D<Ha24008<H`0348@DYABU
00D@Q0<<H`0348@<H`aS008<H`03248<H`Q200<<H`04248<Ha2436<248@536<01A2436<<H`aS2480
0`aS00<@Q0aS24800PaS0Q2400H<H`Q236<<Ha2436<224800`aS48@@Q00248@236<01A2436<<H`Q2
36<01a240@Q200000`0012448@0212403P0012448@Q200048@Q2<Ha_NeJe=Je6<DYBAS43BU8014Ha
@Q1244YB14Ha0dYB00A6<D8@AS52408icP05<H`e[CW>>Lhmk`02>Lh2=Jd00cW>=JdicP02=Jd00cW>
<H`aS002<H`023F]<H`e[Cg_>Lhe[C6<;F/2=Jd00cW>?NlicP02>Lh00cF]>LhaS002<H`01be[<H`a
S3F]<H`]JcF]008icP03=JdaS3W>008icP04?Nm6<D8@>Lh2<H`01CW>=Jde[CW>@Q000Sg_0cW>00@e
[C6<<H`aS08YBP059BTYBRDY8@PYBP05;F/2<H`02Be[9BTU:BU:;F/YBRDY8@PYBP02;F/3:DX01C6<
;F/YBRDY:DX00be[0RDY0R480RU:0Re[00<U:BU:;F/00Re[00<aS3F]=Jd00S6<00@e[Cg_?Nm6<@9:
DP06CW=:DTYB@Q0icSF]0Re[00<YBR488@P00bDY0b480QcW0b480QcW0R4800@U:B489BTU:@<Q200:
:DXQ22488@PYBRDY8@PLib48;F/2:DX012DY8@PQ22DY0R4800@DYA242488@P@48@0324848@@Q00H4
8@0300048@@Q00<48@0500048@@Q1240000712400`0012448@0412401@Q21248@PQ236<00PQ200/@
Q1BU8@P]JbDY8@PHaPaS48@<Ha24008<H`<8@P0436<8@PQ21244248010@Q24848@@Q1@Q21P@Q00@8
@P@Q2488@P@48@D8@P051248@PaS248<H`02248336<324800`@Q24848@0312401PQ212448@Q21248
@P@48@L8@P041248@PQ2248236<00a2436<<H`0536<3248236<424800`aS1248@P02248236<52483
36<424800`aS2488@P0236<01@Q236<48@@Q248010@Q00<8@P@Q12400`@Q0PQ200T<H`@Q6<HicTic
MkeS648@>Lh00QS600<DYA2448@00QBU00<HaQ245:D01A240`aS0a2400@<Ha245:DDY@<@Q0HDY@<H
aP0448@<H`aS6<H348@00aBU7>LHaP035:D011245:D@Q1BU0Q2400D<Ha245:DDYA24008<H`<DY@04
36<@Q12436<348@55:D348@01ABU6<HDYA2436<00a240`aS0a2400<<Ha2448@00QBU00<@Q1BU5:D0
0QBU00D@Q0aS48@HaQBU00@@Q08DY@8@Q00536<DYABU5:DHaP025:D01QS648@@Q12436<@Q08DY@<@
Q0035:D@Q124008<H`0348@<Ha24008@Q00636<@Q0aS36<8@PaS0Q2400<<H`Q236<00a240PaS00<8
@PaS36<00Q2400<<Ha2448@00Q2400D8@PaS248<Ha2400@<H`03248<H`aS00<<H`03248<Ha24008@
Q0<<H`0348@<Ha24008<H`<@Q00336<@Q0aS0048@P0000<48@0012401@@Q00`8@P@Q1248@S6<MkeJ
eSW>AS5>LdHa@Q02AS400dYBAS524002@Q002Sg_AS56<DYBAS5244Ha@Q16<D8@0cg_00=244HaAS40
0T8@0SW>0SF]00HicSF]=JdicSF]<H`2;F/00c6<>Lhe[@03>Lh4=Jd2>Lh01Sg_>Lhmkd8@?NlicP8e
[@09>Lhe[C6<;F/aS2e[=JdaS3F]008icP05=JdaS3F]<H`e[@02>Lh00cF]<H`]J`03<H`2=Jd4>Lh0
1CF]>Lhe[CF]<H`00bU:00<]JbU:8@P00R480be[00@YBRDY:DX]J`8aS08]J`8U:@8YBP8]J`@YBP04
;F/YBRU:;F/2<H`01Be[9BTU:B487>L01BDY0RU:00<U:B48;F/00SF]00@]JbDY<H`icP<e[@09>Li2
44YBCW=:DTicDYA:DT8@008]J`05:DXQ22DY9BTYBP029BT01R489BTQ22487>LQ208Li`038@PLibDY
008U:@068@PU:BDY:DX]JbU:1BDY00<Q22DY9BT00RU:0RDY00HQ21S648@8@PaS248512400`001244
8@0712400`0012448@0712400`0012448@07124010001248@PQ20P@Q0PQ200D48@Q2124<Ha24008D
Y@8HaP0348@<H`Q200<8@P05124<H`Q224848@0424801@@Q24848@Q212400PQ24`@Q0PQ200H48@Q2
2488@P@Q248336<00`Q236<<H`0236<21243248212400`Q21248@P0412401@Q212448@Q212400PQ2
0P@Q0PQ200<<H`@Q12400`Q200<48@Q224801PQ20PaS00<@Q0aS24800`aS00D8@PaS248<H`Q200@<
H`03248<H`aS00@<H`<8@P061248@P@Q248<H`Q210@Q00<8@P@Q12400P@Q0`Q20`@Q00X8@Q2436<D
YC6<@Q1W>E[F?NlaS0@DY@056<HDYABU5:DHaP0348@011BU48@<H`aS0a2400<DYA245:D00a2400DD
YA2448@@Q0aS008DY@036<HDYABU008DY@0548@DYABU5:DHaP045:D00aS65:DDY@0348@45:D248@0
10aS48@@Q1BU0Q2400@DYAS66<H@Q08<H`LDY@8@Q0DDY@0448@<H`aS48@25:D436<448@010aS48@D
YA240QBU00<HaQBU48@00Q2400THaQBU5:D@Q1BU48@DYA2436<00QBU00DHaQ2448@DYAS600<DY@D@
Q08DY@0548@<H`aS48@DY@0348@011BU48@@Q12420aS0a240`aS00@8@PaS36<<H`8@Q0X<H`03248<
H`Q200H<H`04248<H`aS36<248@536<00`Q236<@Q00236<248@236<1248000848@0400048@@Q0005
12401@Q2<HacW5Je>Lh00dYB00=6<D8@AS400THa0T8@00@mkcW>?Nm2409:DP96<@03@Q0mkcg_0092
40<mk`=24003>LhmkcW>00<e[@03>Lhe[CW>00<]J`06<H`e[C6<<H`e[CW>0SF]00@aS3W>>Lhmk`8i
cP05?Nm6<Cg_=JdaS002>Lh2=Jd6<H`4>Lh0236<=Jde[C6<=JdicSF];F/2:DX00c6<>LhaS003>Lh0
1SF]>LhicSg_=JdaS08]J`05<H`]JbU:9BTQ2003:DX00bDY;F/aS003:DX00c6<=JdaS0049BT012U:
9BTU:BDY0RU:00<]JbU::DX00Re[00PaS2e[;F/]JbDY8@PLib4812DY0RU:00@U:Be[;F/aS0<YBP@a
S003=JdmkdHa009:DP9>L`04BU9>Ld8@=Jd2;F/012U:8@PQ22DY0RU:00@U:B488@PLi`8Q208Li`04
8@PU:BDY:DX29BT3:DX39BT01B489BTU:BDY8@P00RU:00<U:B487>L00R4800<HaQ2436<00P@Q00<0
00@Q12402@@Q00<000@Q12402`@Q0PQ20`@Q00<000@Q12401@@Q00<<H`Q212400`@Q00<<H`Q248@0
0aBU0a2400D8@P@Q124<H`Q200848@03248<H`Q200848@0524848@Q21248@P021242248712400`00
1248@P0212400`Q21248@P0412400`aS2488@P06248436<42485124010Q212448@@Q0PQ210@Q0PQ2
10@Q00<8@P@Q12400PQ20P@Q00<8@P@Q24800PQ200<48@Q224800`aS00<8@PaS36<010Q20PaS0`Q2
00<<Ha2436<00`aS00<@Q0aS24801PQ20`@Q0`Q200D48@Q224848@Q200848@0324848@@Q00848@<8
@P0<124DYAcW<HaBU5JeCW<mkb487>LDYA240QBU0QS60QBU0Q2400@<Ha2448@@Q08<H`0448@DYABU
48@236<25:D00aS65:D<H`0236<011245:D@Q1240aBU0Q241QBU0a2400HDYA2448@DYAS65:D=48@0
21BU48@DYABU6<H@Q1BU48@25:D00a245:DDY@025:D248@011BU48@DYA240PaS0a240`aS00@@Q1BU
48@@Q08DY@036<HDYABU00<DY@<@Q0035:D@Q1BU00@@Q0<HaP045:DHaQBU5:D448@236<248@00aBU
48@@Q00236<648@336<248@010aS48@<Ha240PaS00<@Q0aS36<00`aS00@8@PaS36<<H`88@P0336<@
Q12400H<H`03248<H`aS00H<H`0324848@aS008<H`0648@<H`aS48@<H`Q20`aS00<@Q0aS36<010aS
00001@0012448@@Q00000`@Q00`8@P@Q1248@SF]OomS63W>AS5:DTHa@Q03?Nl01DHa@Q12448@AS40
0T8@00<e[CW>>Lh013W>00Pmkd8@AS5244YBCW=:DT8@0SW>13g_0T8@00@mkcF];F/]J`<aS006=Jdi
cSF]>LhaS3F]0SW>00@mkd8@@Q0mk`8icP8e[@<icP05<H`]Jc6<<H`e[@02<H`2=Jd2>Lh3<H`2=Jd2
<H`012U:;F/]Jc6<0be[136<00HicSF]=JdaS2e[<H`5;F/022U:;F/aS36<9BTQ22DY;F/2<H`4;F/0
1BU:;F/YBRU:9BT00RU:0be[00<YBRe[;F/00Re[00DYBRe[:DX]JbDY00<Li`04:DXU:BDY8@P29BT5
:DX012e[:DXYBRU:0S6<00<e[CW>?Nl00Sg_0T8@00a>Le:DAS4mkc6<:DX]Jc6<;F/aS2e[:DX39BT3
8@P01QcW8@PU:BU:;F/U:@8Q20049BTYBRU:9BT38@P29BT37>L28@P00acW5:DDY@04248312400`00
12448@0:12401@0012448@@Q00001@@Q00<000@Q12401@@Q0PQ210@Q0PQ20`@Q00D8@PaS36<<H`Q2
00@<H`88@PL48@0824848@Q21248@P@Q24848@88@P@48@0424848@@Q1242248512400`Q212448@0:
24800`aS248<H`0236<00`Q21248@P0324821243248412422483124324841242248212400`Q21248
@P05248020@Q2488@PaS248<H`Q236<324800`aS248<H`0224800`aS248<H`0236<00`Q236<8@P02
36<01PQ212448@Q236<8@P@48@0324848@@Q00848@0724848@@Q248<Ha2436<00PQ20P@Q00T<H`Q2
48@Libe[F]IF]DYB>Lh00aBU00<@Q1BU6<H011240aBU0Q240PaS00@@Q1BU6<HDY@8<H`075:DHaQcW
5:D@Q0aS48@011BU00<@Q1BU5:D00a240aBU0Q2400DDYAS66<HDYA24008HaP095:D@Q1245:D@Q1BU
48@<Ha2400<DY@@@Q08DY@0748@DYABU6<HDYAS65:D00a2400DDYAcW5:DDYA24008DY@0348@<H`aS
008@Q0035:D@Q1BU00<@Q0035:D@Q12400<@Q0035:D@Q124008@Q0035:DHaQBU008@Q00436<@Q124
36<25:D00aS65:DDY@055:D00a2436<<H`0224800a2436<DY@0:48@00`aS48@<H`0248@236<00`Q2
36<<H`0336<01@Q236<8@PaS24801@aS00@@Q1BU48@<H`88@P0736<@Q0aS36<@Q0aS248010aS00<8
@PaS36<00PaS00@8@PaS36<8@P<<H`8@Q0@<H`4@Q04<H`4<H`000`@Q00<000@Q12400P@Q00P8@P@Q
000<Hcg_OomS63W>0dYB00A6<D8@?Nlmk`924006?Nm2448@AS5243g_1CW>00<mkcF]>Lh00Sg_0TYB
0THa00DmkcW>?NlicT8@008mk`08AS5243g_=JdaS2e[=JdaS08e[@03>Lhe[CF]008aS003>Lhmkd8@
008icP05?NlicSW>>Lhe[@02?Nl2>Lh01CF]<H`aS36<;F/00SF]00@icSF]>Lhe[@8icP04=JdaS2e[
:DX2;F/3<H`2;F/2<H`5=Jd2<H`012e[<H`YBRe[0RU:00@]Jc6<;F/U:@8Q2004;F/aS36<;F/3:DX2
;F/8:DX4;F/01bU:;F/aS3F]<H`YBRDY008Li`038@PU:BDY008Q208U:@03:DXU:BDY00HYBP06;F/a
S3F]=JdmkcW>0T8@00M6<DYBBU9:DSg_>Lhe[@05;F/00bU:8@PU:@029BT27>L01b489BT]JbU:9BTQ
22DY008Q20039BT]JbDY00<Li`8U:@038@PLiacW008Q20067>LHaPaS36<8@P002`@Q00D000@Q1244
8@0001D48@<8@P848@0424848@Q21242248636<2248212401@Q212448@@Q24800`@Q0`Q21@@Q0PQ2
0`@Q00<8@P@Q12401`@Q00<8@P@Q24801@Q200D48@Q2248<H`Q200D<H`L8@P031248@P@Q0088@P03
1248@P@Q00<48@@8@P041248@PQ2248512400`Q212448@0424800`@Q2488@P0636<00`Q236<8@P04
36<224800`@Q2488@P02248236<324801`@Q24848@@Q24848@Q200<48@@8@P0400048@Q2248248@0
0`aS12448@03248236<01acW@Q1>Le[FBU8U:AcW008@Q0066<HDYABU36<@Q0aS0QBU00<@Q1BU48@0
0PaS00@@Q1BU6<HHaP@@Q0035:DHaQBU008@Q00336<@Q12400@DY@0848@DYA2448@DYA245:D@Q08D
Y@0548@DYABU48@DY@026<H00aBU48@DY@025:D348@25:D448@01QS65:DDYA245:DHaP@DY@0448@D
YABU5:D248@00aBU6<HDY@0248@011BU48@<H`aS0QBU0a2411BU00<@Q1BU5:D0112400TDYA245:DD
YAS65:D@Q0aS48@00QBU00<HaQBU6<H00QS600@DYA245:DHaP<<H`8@Q08<H`0448@DYAS66<H248@0
3@aS48@@Q1BU48@<Ha245:D@Q0aS248<Ha2400@<H`8@Q00436<8@PQ2124236<00a2436<<H`0936<0
0`Q236<<H`0636<2248336<010Q236<8@PQ20`aS0PQ200@<Ha2448@<H`48@P0000<000@Q00000`@Q
01<000Q2248000@Q248icWooHaPicTYBCW=:DTHa?Nm243g_@Q0mk`04@Q000cg_>LhicP03?Nl4>Lh0
1S6<=JdicSg_AS52408mk`0;=JdicSW>=Jdmkd8@AS5243g_=Jdmk`03>Lh00d8@?Nlmk`02>Lh3?Nl0
0cF]>Lhe[@02=Jd00c6<=JdicP04>Lh01Sg_@Q1243g_>Lhe[@8icP05=JdaS3W>=JdaS002;F/0136<
;F/aS36<0Re[00<YBS6<<H`00SF]00<aS3F]=Jd00SF]00<icSF]=Jd00c6<0SW>00P]JbU:9BTYBRe[
9BTYBRe[0S6<00<YBRe[;F/00S6<00@YBRDY9BTQ208YBP06;F/aS36<;F/YBRDY0bU:12e[00PYBR48
9BTU:Be[:DXU:B480RDY00@Q22DY9BTU:@8YBP<U:@@YBP8]J`0=<H`icSW>>Lhe[CW>@Q16<DYB@Q0i
cS6<9BT00RU:0RDY0R4812DY00<YBRe[:DX00b480RDY12480bDY00PQ21cW7>LLiaS65:D<H`Q20`@Q
00<000@Q12401@@Q00<000@Q248030@Q00D8@P0012448@Q200<48@0400048@@Q2484124224831240
10Q21248@P@Q1PQ200<48@Q224801@@Q00L8@P@Q12448@Q21248@P07124010Q21248@PQ21@@Q00D8
@P@Q24848@Q200<48@@8@P051248@PQ224848@0224800`aS48@<H`0224800`@Q36<8@P0424821243
248412400`Q212448@021242248010@Q24848@Q220@Q1PQ210aS0PQ200<48@Q236<00`aS0`Q200<4
8@Q212401@Q20P@Q00<8@P@Q12401`@Q00@8@P@Q0008@P8@Q00336<48@Q200<8@P0@124<Ha248@Q:
DU:DE[E241cW8@PDYA245:D@Q1BU48@236<01A245:DHaQBU48@00PaS00@@Q1BU5:DDY@8@Q08DY@03
48@DYABU00L@Q0045:D@Q1BU48@25:D00a2436<@Q0025:D748@00aS65:DDY@025:D0112436<@Q124
0aBU0a240aBU00@HaQBU5:D@Q0@DY@0348@DYABU00<HaP@DY@0348@<H`aS00<DY@0348@<Ha24008H
aP035:D@Q12400D@Q0<DY@D@Q08<H`0648@HaQBU48@<Ha240QBU00@HaQ2448@DY@8@Q0<<H`0348@<
Ha2400<@Q0<<H`8@Q0<<H`0448@DYA2436<324800`aS48@<H`0236<010Q236<<H`Q20`aS0PQ200<<
Ha2436<01PaS00D@Q0aS36<<H`Q200L<H`<8@P8<H`03248<H`aS00@<H`03248<H`aS004<H`0010@Q
00D000@Q12448@Q200848@0736<mkgooG_LicTHaCW<00TYB00=6<D8@?Nl00Sg_00@icSg_@Q1240@i
cP8e[@04?Nm6<D8@?Nl3=Jd01CW>@Q12448@?Nl00cW>00<e[CW>@Q000THa00DmkcW>>LhicSF]00<m
k`04@Q0icSW>@Q02>Lh2?Nl2>Lh0136<=JdaS2e[0SF]00@mkcW>=JdicP=24003?NlicSF]00<aS0<e
[@03;F/YBRe[008aS003;F/YBRe[00<aS004;F/aS3F]>Lh2=Jd01S6<=Jde[CF]>Lhe[@8aS0<]J`03
:DX]JbU:00DaS003:DXU:BU:00<]J`03:DXU:BDY008YBP8]J`8YBP039BTYBRe[00<]J`04:DX]Jbe[
:DX38@P39BT28@P29BT00b489BTU:@02:DX02RDY8@PU:BU:;F/YBRDY:DX]Jc6<0SF]0SW>00Q244Ha
AS5243g_>Lhe[C6<0RU:00@Q22DY7>LLi`8Q20@YBP039BTQ2248008Q20039BTQ224800DQ20057>LQ
22486<HDY@0236<2248312401@0012448@@Q00000P@Q00<000@Q12401@@Q00@000@Q2488@P848@03
00048@@Q00P48@0400048@@Q1242248312400`Q21248@P03248010@Q2488@P@Q0PQ20`@Q00<8@P@Q
12401P@Q00<8@P@Q12400P@Q00@8@P@Q1248@P@48@0324848@@Q00848@88@P031248@P@Q00848@88
@P041248@PQ236<3248010aS2488@PaS0Q2400<<H`Q236<01@Q20PaS0PQ22@@Q00<8@P@Q12400PQ2
3P@Q0PQ21@aS00<8@PaS24800PQ20PaS0PQ20P@Q10Q200@48@Q212448@88@P031248@P@Q00X48@04
248@Q1BU48@324800`@Q24848@0236<02AS6>Li6<EkgDY@aS2U:5:D@Q0035:D248@236<748@35:D3
48@35:D236<01ABU48@<H`aS48@01QBU1A2400@DYA2448@@Q0@DY@8@Q0035:DHaQS6008DY@0448@D
YABU5:D548@00aS67>LHaP0248@45:D011245:D@Q1BU0aS60QBU00<@Q1BU5:D0112400<DYA2448@0
1ABU00DHaQ2448@@Q0aS008DY@@@Q0035:D@Q0aS008<H`D@Q00:5:D@Q12448@DYAS65:D@Q0aS48@4
36<011245:DDYA240PaS0Q241`aS00<8@PaS36<00PaS0Q2400<<H`Q224800PaS00<8@PaS36<00`aS
00X8@PaS36<@Q0aS48@<H`Q236<@Q08<H`04248<H`aS248336<00`Q236<<H`0236<2248010aS2488
@PQ20PaS00@8@PaS36<@Q048@P0000<000@Q12400P@Q00`000@Q1248@P00124<HcF]LiaF]CF]AS42
BU801DHa@Q0mkcW>?Nl00d8@0Sg_00<icSF]=Jd00SF]0cW>0cg_00DicSg_?Nlmkd8@00@aS08mk`04
>Lhmkd8@>Lh2=Jd01SW>@Q12448@BU96<@92408icP=24004?NlicSW>>Lh2?Nl2>Lh00cg_>LhicP02
=Jd2>Lh01cg_@Q16<CW>=JdaS3F]008icP8e[@<aS003=JdaS3F]00<aS005;F/aS2e[;F/aS002=Jd2
>Lh00cF]<H`]J`03<H`3;F/012U:;F/]Jc6<0SF]0S6<0Re[0S6<00L]JbU:9BTU:Be[:DX]J`02:DX0
1RDY:DXU:B489BTYBP8aS08]J`<U:@088@PU:Be[=Jd]JbU:7>LQ20HU:@06:DXQ22487>LQ22DY0b48
0RU:00<]Jc6<<H`00S6<00@e[CW>?Nlmk`924005>LhaS2DY:DXU:@038@P01BU:;F/YBRU:9BT01b48
00@U:B488@PLi`8Q20079BTQ212436<48@Q236<03P@Q00<000@Q124010@Q00<000@Q12401@@Q00H0
00@Q1248@P@Q000;12401@Q212448@@Q24800`@Q00<8@P@Q248010@Q00D8@P@Q12448@Q200P48@05
24848@@Q1248@P04124010Q21248@PQ210@Q00<8@P@Q12400`Q200<48@Q224802PQ200<<H`Q236<0
1@Q20`@Q0`Q210@Q0`Q21P@Q00@8@P@Q2488@PP48@03248<H`Q20088@P0336<@Q0aS00H8@P@48@04
24848@@Q1243248312400`Q212448@0:12400`Q21248@P0212400`Q212448@02248248@02AS6@Q1:
DUkgE[D]Jb4848@DY@027>L25:D00a2436<DY@0448@336<00a245:D@Q00348@01ABU6<HDYA2436<0
1A2400<DYA245:D011BU00@<Ha2448@@Q08DY@0548@DYA245:D@Q0025:D348@75:D448@65:D011S6
5:DDY@aS0a2400<DYA245:D00QBU0a2400<DYA2448@011BU00<@Q1BU6<H00QS60Q2400<<Ha245:D0
0QBU00<HaQBU48@00Q2400<DYA2448@00a240PaS00D@Q0aS36<DYA24008DY@<@Q08<H`<@Q00536<@
Q1245:D@Q00536<00`Q236<@Q00348@010Q236<<H`Q20`aS00<@Q0aS48@01`aS00<8@PaS36<00PaS
00@@Q0aS2488@P8<H`0448@<H`aS248236<00a2436<@Q00236<00`Q236<<H`0436<01@Q236<8@PaS
24800PaS0Q24000312400`0012448@0512401PQ2>Lig_EJe=Je6<@9:DP04AS5243g_>Lh3?Nl0148@
AS4mkcW>0SF]1SW>0Sg_0cW>0Sg_00DicS6<;F/aS3F]008icP03@Q0mkcF]008e[@04>Lhmkcg_?Nl3
@Q02?Nl2@Q001DHa@Q0mkcW>=Jd013g_00HicSg_@Q0mkcW>=Jd3>Lh2@Q02?Nl2=Jd3>Lh2<H`012e[
=JdicSW>0SF]00<]Jc6<=Jd01C6<0SF]0cW>00@aS2e[;F/]J`8aS0<]J`04:DX]Jbe[<H`2>Lh2;F/0
12U:<H`aS36<0RU:00LU:BU:;F/]JbU:9BTYBP029BT00b489BTYBP02:DX01Be[<H`YBRDY8@P00bU:
0Re[0RDY0R4812U:0RDY124800HU:B487>LU:BU:<H`2;F/4<H`013F]>Li243W>0Sg_00DaS2U:9BTQ
22DY00<YBP03;F/U:BU:008Q20039BTQ22DY00<Q20059BTQ21cW7>LQ20029BT00acW48@8@P032480
0`@Q00048@0312400`00124000071240100012448@001@@Q00D8@P@Q00048@Q200D48@0324848@@Q
00<48@0324848@@Q00848@0424848@@Q12432483124010Q212448@Q210@Q00@8@P@Q12448@88@P84
8@0324848@@Q00<48@88@P@48@0324848@@Q00<48@<8@P031248@PQ200L8@P<<H`88@P<<H`032484
8@Q200D8@P@48@0424848@@Q24841242248412400`Q21240000212400`Q212448@021244248010@Q
248<Ha240PaS10Q200<<H`Q212400`@Q00@8@P@Q12448@88@P848@0324848@@Q00848@0324848@@Q
00<48@88@P<48@0324848@Q200848@0324848@@Q0088@P0<5:D]Jcg_IcUS648@=Jd@Q1BU6<HDYAS6
0aBU00H@Q0aS36<@Q1BU48@336<348@00`aS48@@Q0025:D748@00aBU48@@Q0065:D01A2436<<Ha24
5:D00Q240QBU00@@Q0aS36<@Q0<DY@0348@DYA2400<DY@0448@DYABU5:D248@25:D011S65:DDYA24
0aBU00@<Ha2448@DY@8@Q08DY@076<HDY@aS36<@Q1BU6<H00aBU00<HaQBU6<H00aBU0a2411BU00H@
Q0aS36<@Q1BU48@336<248@010aS48@<H`aS0QBU00<HaQBU48@00Q241@aS0a240`aS00<8@PaS36<0
0a2410aS00L8@PaS36<<Ha2436<@Q00236<248@00`aS48@<H`0236<00`Q236<<H`0236<00`Q236<<
H`0636<2248736<2248336<01@Q2124<H`aS48@00`aS0A2400001@@Q00048@@Q00000`@Q00T8@P@Q
124<HcW>MkeJeS6<?Nl00THa0T8@0SW>1Cg_0cW>00@mkcW>>LhicP<mk`05=JdicSg_?NlicP02?Nl0
1CW>=JdaS3F]>Lh00SF]0SW>0cF]00DicS6<<H`e[CW>009240<mk`A2408e[@03>Lhmkd8@00<icPA2
408icP05?NlicSW>?Nm24002?Nl00cF]>LhicP02>Lh2=Jd02Cg_@Q16<D8@?NlicSF]>LhaS003;F/3
<H`3=Jd00c6<;F/]J`02;F/2:DX01Re[<H`icSg_>LhaS0@e[@04<H`]Jc6<<H`3:DX01Be[<H`]Jbe[
:DX00R480RDY00<YBRDY:DX00RDY12U:0RDY0bU:00/]JbDY6<H]JdHaDYA242487>LQ22DY008Q208L
i`048@PU:B489BT4:DX032DY:DXYBRU:9BTYBRe[<H`mkdYB>Lhe[@8U:@8]J`05:DX]JbU::DXU:@03
8@P27>L02RDY:DXU:BDY7>LQ22DY8@PHaPaS0PQ220@Q00<8@P@Q12404P@Q00<8@P@Q12403P@Q00<8
@P@Q12401P@Q00<8@P@Q12400P@Q0PQ21P@Q00D8@P@Q12448@Q200@48@0724848@Q21248@P@Q2480
0P@Q10Q20P@Q00<8@P@Q248020Q20P@Q00@8@PaS36<<H`L8@P0636<8@PQ224848@Q210@Q0PQ200<4
8@Q212400`Q200@48@Q22488@P<48@0324848@@Q00@48@0324848@@Q00L8@P031248@P@Q00<8@P08
36<8@P@Q1248@P@Q24848@88@P<48@0324848@@Q00848@0324848@@Q00@48@0524848@Q21248@P05
12405@Q2124<H`@Q5:DicTicLia[FSW>:DXDYAcW9BTLiaBU6<HDYA2436<@Q0025:D236<248@336<0
0aBU48@@Q00548@00`aS48@@Q0025:D01A245:DHaQS67>L01aBU0QS61QBU00<@Q1BU48@00Q241aBU
0a2411BU0Q2400HDYA245:DDYA245:D348@36<H25:D01A245:D@Q12436<00aBU00<HaQBU6<H00QBU
0Q2400<DYA2448@00QS60QBU00<@Q0aS48@011240PaS112400<DYA2448@00QBU1A240`aS00@@Q0aS
48@DY@<@Q00336<@Q124008<H`0348@<H`aS008<H`0448@8@PaS36<348@336<248@336<00a2436<<
H`0236<010Q236<8@PQ21@aS00D8@Q2448@<Ha2400@<H`03248<H`Q200L<H`<8@P4<H`4@Q0000P@Q
00@000@Q124000848@0:248000@Q248icW_NE[D]Jd8@AS44@Q000cW>=JdicP02?Nl00cF]>Lhmk`02
>Lh00cF]>LhicP02>Lh01CF]>LhicSg_@Q000SW>00<mkcF]=Jd00S6<00<icSF]=Jd013F]0S6<00He
[C6<>Lhe[CW>?Nl3@Q02?Nl00d8@?NlicP02=Jd01Sg_@Q0mkcg_>Lhmk`A24003?NlicSW>00XicP05
<H`e[Cg_AS524002>Lh00d8@AS4mk`02<H`012e[<H`aS2e[0S6<00De[CW><H`aS3F]008]J`059BTQ
22U:;F/e[@03>Lh2<H`2=Jd2;F/2<H`2;F/01bDY;F/]Jc6<;F/YBRDY008Q20@U:@<YBP@U:@8YBP8U
:@05:DXQ21cW;F/icP02BU8013F];F/YBQcW124800<U:B488@P00RDY00`]JbU:9BTU:BU:8@PU:B48
:DX]JbU:>Lh2?Nl00cW>;F/YBP02;F/01C6<:DXU:BDY:DX00RDY00<LiaS68@P00R4800PU:B488@PL
ibDY8@PLiaBU0`Q21`@Q00<000@Q12402@@Q00<000@Q12401@@Q00<8@P@Q12401P@Q00D000@Q1248
@P@Q00@8@P031248@P@Q00<8@P@48@0324848@@Q00L48@88@P848@0324848@Q20088@PL48@042484
8@Q22484124224800`@Q24848@0324800`@Q2488@P0>248010aS2488@P@Q0PQ20P@Q00<8@P@Q1240
0P@Q0PQ22P@Q00<8@P@Q12400P@Q00@8@P@Q24848@88@P848@H8@P041248@PQ21244248212432484
12400`Q212448@0212400`Q212448@0212400`Q21248@P0312401@Q212448@@Q248010@Q00X8@P@Q
36<U:CW>JeYW>DicAS4Q20<Li`048@PLiaS648@236<25:D0112436<DYA240PaS1Q2400@<Ha245:D@
Q0@<H`LDY@0448@HaQBU48@25:D26<H35:D248@25:D248@00aBU48@DY@0348@00aBU48@DY@025:D0
1Q245:D@Q1245:D@Q08DY@H@Q0HDY@036<H@Q124008<H`8@Q0@DY@036<HDYA2400@@Q0045:DHaQcW
6<H348@00`aS48@@Q00248@336<548@25:D248@236<248@011BU36<<H`aS112400@<Ha245:D@Q0<<
H`8@Q0@<H`<@Q0@<H`8@Q00536<8@PaS36<@Q00636<2248436<01@Q236<<H`aS48@01PaS00<8@PaS
48@02PaS0A2400000`0012448@0512402PQ212448@aS>Liooe[F<H`mkdHa148@0Sg_00<icSg_?Nl0
0cW>00@mkcW>?NlicP<mk`DicP05?NlicSW>=JdaS005=Jd01CW>?NlicSW><H`00cF]0SW>0Sg_00Di
cSF]>LhicSg_00<icP06?NlicSW>>Lhmkd8@0Sg_0T8@00A6<D8@>LhicP8mk`9240<aS003=JdmkcW>
008e[@<icP06?Nm2448@AS4mkd8@0cW>0Sg_00@aS2e[:DXaS0<icP03=Jd]Jbe[00<]J`8YBP03<H`e
[CF]00<e[@<aS08e[@06;F/YBS6<=Jd]JbU:12DY12U:00<Q22DY:DX00bDY00DYBRDY9BTU:BU:008a
S0<YBP07;F]245:DBU8icRDY7>L00RDY00<Lib488@P00bDY0RU:00@U:B488@PQ208U:@048@PLibDY
:DX4;F/01CF]@Q0mkcF];F/00RDY00H]Jc6<<H`YBR489BT47>L00b487>LQ20029BT011cW6<H<H`aS
0`@Q00<000@Q124010@Q00<000@Q124010@Q00<8@P@Q12400P@Q00D000@Q12448@Q200@48@88@P<4
8@0324848@@Q00848@0624848@@Q1248@P@Q0`Q200H48@Q21248@P@Q248612400`Q212448@0;1242
248612400`Q21248@P032484124224801@aS2488@P@Q24800`@Q00@8@PaS24848@<8@P0336<8@PQ2
0088@P8<H`88@P041248@PQ2248412400`Q21248@P021244248212400`Q21248@P0412400`Q21248
@P042484124324800`@Q2488@P02248010@Q2488@P@Q0`Q200<<H`Q224800`@Q00<8@P@Q24800`@Q
00@8@P@Q1248@PD48@<8@P031248@P@Q00848@0:36<48@Q2:DY6<G>LIcU6<Cg_8@P37>L26<H248@2
5:D01A245:DDYABU48@00PaS0Q240QBU0a240QBU1Q240aBU0QS60QBU0QS60QBU0Q240QBU00<HaQBU
6<H00QS60QBU0a2400<DYA2448@01A240QBU00<@Q0aS36<00Q2400<DYA245:D00Q240QBU00HHaQBU
48@HaQcW6<H25:D011cW6<HDY@aS0Q2400<DYA2448@00a2400<HaQBU5:D00a240aBU00<@Q1BU48@0
112400@DYA2448@@Q08DY@<<H`8DY@<HaP8@Q08DY@0348@DYA2400L@Q0<<H`0348@<H`aS008@Q0<<
H`0348@<Ha2400`<H`05248<Ha2436<8@P0436<2248336<00a2436<<H`0336<00`Q236<@Q00236<0
212436<<H`Q236<8@PaS248236<1248000<48@0500048@001248@P0212401P0036<e[G_NG_Le[@92
4003?Nm2448@00<mk`06=JdicSW>?Nm243g_13W>0cg_0SW>00@e[CW>@Q0mk`8icP04<H`e[C6<<H`2
=Jd00cg_>LhicP04>Lh01c6<=JdicSW>?NlicSF]00<icP05?NlicSW><H`e[@03>Lh01cg_>LhicSg_
@Q16<D8@00<mk`8icP04?Nm243g_=Jd2<H`5=Jd2>Lh013g_>LhicSF]0d8@00HicSF]>LhicSF]<H`2
:DX013F]>Lhmkc6<12e[0RU:00@]Jc6<=Jde[@<aS006=JdicRe[;F/YBRe[0S6<00D]Jc6<<H`]JbU:
00<U:@04:DX]JbDY9BT3:DX00bDY8@PU:@049BT03RU:;F/]Jbe[:DXQ22e[BU9F]DHa;F/Q22U:9BT6
8@P59BT012U:8@PQ21cW0b4800XU:Be[<H`U:Be[=Je243W>;F/U:@<YBP8aS003:DXU:B48008Q20<L
i`078@PLiacW9BTQ21BU48@02@@Q00<000@Q12401@@Q00<000@Q12401P@Q00D000@Q12448@Q200H4
8@88@P<48@88@P848@88@P0336<48@@Q00<48@0324848@@Q00H48@0324848@@Q00D48@0324848@@Q
00H48@0324848@@Q00<48@@8@P061248@P@Q1248@PaS10Q200D48@Q21248@P@Q00H8@P848@88@P03
1248@P@Q00@8@P@48@0524848@@Q24848@03248010@Q24848@Q210@Q00<8@P@Q24801@@Q0PQ20`@Q
00<8@P@Q24800PQ20P@Q0PQ200<48@Q212400PQ200<48@Q224800`aS0PQ22`@Q00<8@P@Q12400P@Q
00@8@P@Q1248@P<48@0<248<H`Q236<DYAcWDYAJeV<HE[DYBRDY0QcW00<Q21S648@00a2411BU00<H
aQ2448@00PaS0QBU00@@Q1BU48@<H`@@Q00336<@Q1BU008DY@0336<@Q1BU00@DY@057>LHaQBU5:D@
Q0025:D011S65:DHaQS60aBU00<@Q1BU48@01A240QBU00d@Q0aS48@DYA2436<@Q1BU6<HDYA2436<@
Q0025:D00a245:DDY@027>L011S65:DDYABU0Q240QBU00<<Ha2448@00aBU1Q240QBU00H@Q1BU5:D@
Q1BU48@336<01Q245:DDYABU36<@Q08<H`8@Q08HaP<DY@8@Q0<DY@0548@<H`aS48@<H`0448@236<2
48@436<348@236<00`Q236<<H`0736<00a2436<8@P0236<248@2248536<01A2436<<Ha2436<00`Q2
00<<Ha2448@00PaS00<8@PaS36<00PaS1@Q200000`001240000312400`001248@P0212401PQ2>Lic
W5:D<Ha24096<@04@Q16<D8@@Q03?Nl2@Q0014Ha@Q1244Ha0T8@0Sg_00<icSF]=Jd00SF]0Sg_00@i
cSF]:DX]J`8aS008=JdicSW>>Lhe[Cg_@Q0mk`<aS0<mk`924003?NlicSW>008icP04<H`e[CF]>Lh3
=Jd3>Lh01cg_@Q1243g_@Q16<Cg_008icP09?NlicSF]<H`e[CW>=JdicSF]008icP03=JdicSF]008a
S006;F/aS3F]=JdaS3W>0SF]00<aS2e[<H`00SW>00HmkcW><H`e[BU:9BT28@P01BU:;F/]Jc6<;F/0
1c6<00D]Jc6<<H`aS2e[00@YBP039BT]Jc6<008]J`03:DXU:BU:00DU:@068@PU:BDY9BTQ22U:0Re[
00<U:Be[=Jd00T8@00Le[C6<<H`YBRDY8@PLi`029BT00bU:;F/]J`029BT022U:;F/YBRDY8@PU:B48
7>L29BT2:DX29BT6:DX00bDY:DXYBP02:DX00b489BTU:@059BT38@P01A2436<48@@Q00000`@Q00<0
00@Q12400`@Q00<000@Q12400`Q220@Q00@8@P@Q1248@PH48@0324848@@Q00848@0524848@Q22484
8@0524851242248@12400`Q212448@0212400`Q212448@0224800`@Q24848@02124224800`@Q2484
8@0224800`aS2488@P0224801@@Q24848@@Q24800PaS00<8@P@Q12400PQ20P@Q00<8@P@Q24800`Q2
00@48@Q22488@PD48@0724848@@Q1248@P@Q24800P@Q00@8@P@Q24848@<8@P051248@PQ224848@04
24801`@Q2488@PQ21248@P@Q0088@P0336<8@PQ200848@8<H`8@Q0<<H`T48@88@PL48@0524848@@Q
1248@P0412401`aS6<HQ24YBE[EBU4Ha008Li`055:DHaQS67>LDY@0248@00`aS48@DY@0248@01@aS
48@@Q1245:D00Q2400<DYA245:D00QBU0QS600<DYAS648@00a2400<DYA245:D00aBU0Q2400<DYA24
5:D00QBU0aS600HDYA245:DDYAS65:D248@00aBU48@@Q00348@00aBU48@DY@0448@00`aS48@DY@04
48@85:D00aS67>LHaP055:D248@35:D248@01`aS48@@Q0aS48@DYA24008<H`@@Q08<H`8DY@036<HD
YA2400D@Q0055:DLiacW7>LDY@0248@35:D448@010aS248<H`aS0Q241`aS00D8@PaS36<@Q0aS0088
@P0536<@Q0aS36<@Q00236<010@Q248<Ha240`aS00@8@Q2436<<H`88@PH<H`0548@<H`aS36<8@P07
36<3248336<1248000D48@0>00048@@Q24848@0036<aS7NmF]HaS3g_AS5240=6<@924003?NlicSg_
00A24096<@03@Q0mkcg_00<mk`03=JdaS3F]008mk`05=Jd]Jc6<<H`]J`02<H`5>Lh00cF]>Lhe[@02
>Lh00cF]>LhicP02@Q0013g_>LhicSF]0cW>0SF]0c6<00@e[CW>?Nm240@mk`06AS5243g_@Q0mkcW>
1cF]00@icSF]=JdicP8aS003;F/e[CF]00<aS00=>Lhe[CF]:DX]JcF]>LhmkcW>=JdaS2e[:DX00RDY
00<YBRe[;F/012e[1C6<0Re[00@aS3F]<H`aS08YBP8U:@06:DX]Jc6<<H`YBRe[0RU:00@U:B488@PU
:@8YBP049BTQ22489BT4:DX00c6<=JdicP02>Lh02SF];F/YBR489BTQ22DY:DX]JbU:0bDY0RU:00<Q
22DY9BT00b4800DU:BU:9BTU:BU:008]J`<YBPHU:@8YBP049BTQ22DY8@P29BT01B489BTYBQcW48@0
1P@Q0PQ21@@Q00D000@Q12448@0000<48@0300048@@Q00848@0300048@Q200@48@0324848@@Q0084
8@88@PH48@P8@PD48@0324848@Q200848@0424848@@Q124224821242248412400`Q212448@071244
24800`@Q2488@P0424800`@Q24848@03124524801P@Q24848@@Q24848@H8@P071248@P@Q1248@P@Q
24800P@Q00<8@P@Q24800`@Q0PQ20`@Q0`Q200D48@Q21248@P@Q00L8@P@48@0324848@Q20088@P03
36<8@PQ200848@0436<DYA2436<31242248512400`Q21248@P0512400`Q212448@05124224802A24
36<<HcF]AS5W>EJe;F/YBP036<H01A245:D@Q1245:D0112400<DY@aS48@00a240QBU00<@Q1BU48@0
0aBU0QS600@@Q1BU48@@Q08DY@0348@DYAS600@DY@076<H@Q1BU5:DHaQcW6<H00aBU00@HaQBU48@@
Q0@DY@8@Q0035:D@Q1BU00@@Q00336<@Q124008DY@@@Q0045:DHaQS66<H348@03QS67>LHaQ2436<D
YAS648@<Ha246<HDYA2436<348@011BU48@@Q0aS0a2400<<Ha2448@011240QBU0Q240QBU0a240QBU
00<LiaS66<H00aBU00<@Q1BU5:D00Q240PaS00<@Q0aS36<00PaS0a240PaS00L@Q0aS36<8@PaS48@8
@P0336<00a2436<<H`0436<010Q236<<Ha241`aS0PQ200@<Ha2448@<H`88@P0336<@Q12400@<H`07
248<H`aS36<8@PaS24800PaS0@Q20@aS0000100012448@0010@Q00T8@P001248@SF]LiaJeSF]@Q00
0THa1DYB0THa00=244HaAS400T8@00<mkd8@AS400THa00Dmkd8@?NlmkcF]00LaS005;F/aS36<<H`e
[@04>Lh4=Jd5>Lh3?Nl6>Lh3<H`01be[=JdaS3F]>Lhmkd8@008icP04?Nm2448@>Lh2=Jd0136<>Lhe
[CF]0SW>0c6<0SF]136<0Re[136<0Re[00DaS3W>>LhaS2e[008aS0D]J`03<H`]Jbe[008]J`@aS003
;F/aS2U:00HYBP8U:@04;F/aS36<:DX2;F/2=Jd01Re[9BTU:B489BTYBP8Q20@U:@05:DX]JbDY;F/m
k`02BU801SW>:DXYBRDY:DX]J`<U:@<YBP8U:@<Q20059BTYBR487>LQ20029BT00b487>LLi`028@P0
22DY8@PQ22487>LDYB489BT2;F/00b489BTU:@039BT01B489BTQ212436<00`@Q00<000@Q12400P@Q
00<000@Q124020@Q00<8@P@Q12401`@Q0PQ20P@Q00<000@Q24802@@Q00<8@P@Q24800PaS0PQ200<4
8@Q212400`@Q00<8@P@Q12401@@Q00<8@P@Q12400P@Q0PQ20P@Q00<000Q2124010@Q00H8@P@Q2484
8@Q236<224800`@Q248<H`0424800`@Q2488@P022483124011247>LQ21BU0P@Q00D8@PaS36<48@Q2
00848@0336<8@PaS00D8@P041248@P@Q248212400`Q212448@02248612402@Q21248@P@Q24848@Q2
124<H`0224800`@Q2488@P0224801@@Q24848@@Q6<H00RU:00@DY@@Q124<H`H8@P@48@88@P@48@D8
@PD48@88@P848@88@P0>124<H`aS48A245JeJeYF]BDY8@PDYA246<HDY@<@Q08<H`8@Q0045:D@Q124
36<348@01@aS48@DYAS65:D00Q2400@DYAS66<HDY@<@Q0<DY@0448@DYA2448@55:D36<H25:D00aS6
5:DHaP046<H248@00`aS5:DDY@0348@25:D548@25:D021S65:D@Q12436<@Q1BU48@55:D348@25:D2
48@35:D348@436<01QBU48@@Q1245:D@Q08<H`D@Q00936<@Q12448@DYA245:D@Q1S600<Li`<HaP04
48@<Ha2448@25:D00a2436<8@P0248@00aBU36<<H`0348@236<2248436<010Q236<@Q1243`aS0PQ2
0`aS00<@Q0aS36<02@aS00D8@PaS48@DYA24008<H`8@Q04<H`48@P0000<48@00124020@Q00D<HcF]
LiaF]C6<00=6<@03@Q16<DHa00=:DP04AS52448@AS44@Q000cg_@Q124003AS42>Lh00cF]>Lhe[@02
;F/2<H`2;F/0136<>Lhe[C6<13F]0S6<00He[CW>@Q0icSF]>Lh2?Nl00d8@>LhicP03>Lh00cF]<H`a
S004<H`4=Jd2?Nl01CW>?Nlmkcg_>Lh01CF]0SW>13F]00@aS3F]<H`e[@@]J`09=JdaS36<;F/YBS6<
=JdicSF]00@aS004;F/YBRU:;F/3<H`4;F/3<H`00be[9BTU:@04:DX29BT4:DX4;F/2<H`00be[9BTU
:@03:DX29BT00b489BTU:@028@P02BDY;F/]JcF]AS5:DSg_<H`U:@02;F/39BT00bU:;F/YBP029BT4
8@P37>L48@P00acW8@PQ20029BT00b487>LQ20027>L28@P2:DX00bDY:DXU:@069BT00aS648@48@07
12401@Q200048@@Q24800`@Q00<000Q2248030@Q00D8@P@Q12448@0000848@0324848@Q200H48@88
@P0336<8@PQ20088@P<48@<8@P031248@P@Q00848@0324848@Q200<48@0324848@@Q00<48@032484
8@@Q00H48@88@P0336<8@PQ200<8@P031248@PQ20088@P848@080008@P@Q124<HaS67>LDY@848@04
248<H`aS36<312472483124010Q21248@PQ20P@Q00<8@P@Q24801@@Q0`Q20P@Q0PQ200@48@Q22488
@P848@<8@P848@0924848@@Q48@HaR487>L<H`Q200848@@8@PD48@0300048@@Q0088@P031248@PQ2
00@48@0424848@@Q12432482124224802@aS248<Hbe[AS5cW6]J>Lhe[@045:D00a245:D@Q00436<6
48@011BU48@@Q12411BU00H@Q1BU6<HHaQBU48@55:D248@35:D348@01ABU6<HDYA245:D00QS60QBU
00@@Q1BU6<HDY@<@Q0036<HDYABU00HDY@8@Q00336<DYA2400<@Q0<DY@@@Q08DY@<@Q08DY@<@Q003
5:D@Q124008@Q0035:D@Q0aS008<H`8DY@0348@<Ha2400<@Q08<H`8@Q0035:D@Q124008@Q00336<@
Q1BU00<HaP047>LQ21S65:D448@00`aS48@@Q00336<00a2436<<H`0248@00aBU48@<H`0636<01@Q2
36<<H`aS48@00PaS0Q2400@<H`Q22488@P<@Q08<H`0448@<H`aS36<2248336<00a2436<<H`0:36<2
48@636<000848@0500048@0012400002248030@Q0008@SF]NmiNmcF]@Q1:DTHaBU924096<@03BU9>
LdYB009BU09>L`0>AS5:DT8@@Q0mkd8@AS5:DT8@>Lhe[CW>?NlicP<e[@03>Lhe[C6<008aS0De[@03
<H`e[CW>008icP8aS009>Lhmkd8@AS5244YBCW=243W>00TaS006;F/aS3F]=JdicSF]0S6<0SF]00@i
cSg_>LhicP8e[@8icP04=JdicSF]<H`3:DX00cF]<H`e[@02<H`00be[:DX]J`03<H`00be[<H`aS003
<H`3;F/00bU:;F/e[@03=Jd2;F/3:DX2;F/01RU:9BT]Jbe[:DXQ208Li`8Q20<YBP@]J`03:DX]JbU:
008YBP8U:@038@PU:BDY00@Q208YBP07;F]244Ha?NlaS2489BT012U:0RDY0b4800@U:B488@PQ20@L
i`<Q208U:@048@PLiacW8@P29BT28@P00acW8@PU:@02:DX01Be[9BTLiaS65:D00QcW00<DYA2448@0
0PQ20P@Q00L000@Q12448@Q21240000612400`001248@P0212400`0012448@0>12401@Q21248@PQ2
12400PQ200D48A24:DXYBQcW00848@88@P061248@P@Q1248@P@Q0`Q20P@Q00<8@P@Q12400`@Q00D8
@P@Q00048@0000<48@88@P@48@03248<H`Q200<8@P0636<8@PQ21248@P@Q0PQ200<48@Q212400PQ2
0`aS00@8@PaS248DY@8Li`0736<48@@Q36<@Q0aS24800`@Q00@<H`@Q24848@88@P031248@PQ20088
@P@48@0324848@Q200848@<8@P041248@PQ2124424800`@Q2488@P02248212400`Q248@@Q00248@0
0`aS2488@P042484124010Q21248@P@Q0PQ20PaS0P@Q0PQ200<48@Q224800`@Q00<8@P@Q124010@Q
0PQ200L@Q3W>@Q1[FVmk?Nl]J`0248@011cW5:DDYA240QBU0a240`aS1Q2400<DYA245:D00a2400LD
YAS66<HHaQBU48@DY@0348@65:D26<H00aBU48@DY@036<H00aBU48@@Q0045:D00a2436<@Q0025:D0
0a245:DDY@0248@35:D00a245:D@Q0045:D248@00`aS48@DY@0248@00aBU6<HDY@0248@25:D00a24
36<@Q0026<H00aBU6<HDY@0448@35:D348@00aBU48@@Q00236<548@00aBU48@<H`0236<01Q245:DD
YAS65:DHaP8DY@0448@<H`aS48@25:D336<248@00`aS48@DY@025:D236<00`Q236<<H`0436<248@7
36<010Q236<<Ha2410aS00D@Q0aS36<<H`Q2008<H`0348@<H`aS008<H`04248<H`aS36<3248248@3
36<348@136<12480000300048@@Q00D48@08248000@Q36<e[GNmF]He[@=6<@924096<@=:DP07CW=B
U5:DCW=:DTicBU800d8@00=6<D8@@Q000Sg_0SW>13F]00<icSF]=Jd00SF]0c6<0SF]0SW>13F]00@a
S3W>?Nm6<@9240A6<@8icP04<H`]Jbe[;F/2<H`01CF]<H`]Jc6<>Lh00SF]00@aS3F]>Lhe[@DicP0;
?NlicSW>>Lhe[CW>=Jd]JbU:;F/aS002;F/4<H`01be[<H`]Jbe[=JdaS3F]00@aS0<]J`<aS08e[@03
<H`]JbU:00<]J`LYBP039BTQ224800<U:@8YBP03;F/aS2e[00<YBP03;F/aS2e[008U:@038@PU:BDY
00<Q208YBP03;F/aS3F]008mk`08=JdaS2488@PU:BU:;F/YBP8Q20039BTQ2248008Q208Li`036<HQ
224800@Q208U:@8Q208U:@09:DXU:AcW7>LQ22DY:DXU:B48008U:@038@PHaQBU008DY@0348@8@PaS
00D48@0324848@@Q00@48@0324848@@Q00848@0324848@@Q00D48@0524848@@Q1248@P0412400`Q2
12448@02124224802P@Q248000@Q48@LibU:9BT@Q0Q21@@Q00<8@P@Q24800`@Q00<8@P@Q24800P@Q
00@8@P@Q24848@88@P@48@0324848@@Q00848@<8@P031248@PQ200L8@P<48@<8@P041248@PQ22482
36<2248010aS6<HQ21240PQ200@<HaBU36<48@<8@P@48@88@P<48@<8@P<48@<8@P041248@P@Q1242
2483124424801@aS2488@PQ212400`Q20PaS0Q2400<<H`Q2248010Q20`@Q00<8@P@Q24800`@Q00H8
@PaS2488@P@Q248212400`Q21248@P061244248010@Q248U:C6<0V]J00=6<Cg_6<H01ABU0Q2400@D
YA2436<<H`8@Q0<<H`@@Q0055:D<H`aS36<@Q0035:D01AS65:DHaQBU48@01QBU00<@Q1BU5:D00aS6
2QBU00D@Q0aS48@<HaBU008HaP045:D<Ha246<H35:D26<H35:D011245:D@Q0aS0a2400@DYA245:D@
Q0@DY@0448@<Ha2448@25:D01QS65:D@Q1245:D@Q08<H`<@Q08<H`035:D@Q12400D@Q00436<DYA24
48@336<01ABU48@@Q1BU6<H00QcW00<HaQBU48@00a240PaS00X@Q0aS48@<Ha245:D@Q1S65:D@Q0H<
H`03248<H`aS008@Q0X<H`8@Q08<H`05248<Ha2448@<H`032480112436<<H`Q22@aS1Q240@aS0@Q2
00001@@Q00048@@Q00001P@Q00L8@SF]Kg]>Lc6<@Q16<@03?Nl01d8@?Nm243g_@Q1:DTHa009>L`I:
DP07@Q1:DTYBAS4icS6<=Jd00S6<0SF]00HaS3F]=Jde[D8@AS42?Nl01CW>=Jde[CW>=Jd00Sg_00@e
[C6<<H`aS08icP05?Nm2448@AS524002>Lh3<H`00cF]<H`aS002;F/00c6<=Jde[@03@Q0013g_<H`e
[C6<0SF]00LaS3F]=JdicSF]<H`icP02@Q000cW>;F/]J`02<H`00cF]>Lhe[@04;F/2<H`01Be[<H`a
S36<=Jd01S6<00H]JbU:;F/]Jc6<;F/3<H`3:DX0136<;F/]Jbe[0RU:00<U:BU::DX02BU:00@U:Be[
:DXU:@<]J`08:DXQ22DY9BTQ22DY:DXaS08YBP04>Li243g_<H`27>L28@P39BT28@P00acW8@PQ2002
8@P37>L012487>LLiacW0RDY00D]JbU:8@PYBRe[008YBP8Li`8Q2003:DXU:B48008Q208Li`8HaP8@
Q0<8@P848@0300048@@Q00l48@0400048@@Q248:12400`Q212448@03248020aS2488@P@Q248@Q1BU
48@324800`@Q2488@P0212422482124224821242248312400`Q212448@041242248612400`aS2488
@P02248236<01@Q21248@PQ236<00PQ200H48@Q224848@Q236<4248336<01`Q2124@Q1cW6<H@Q000
00@48@<8@P<48@@8@P<48@88@PL48@88@P061248@PQ236<8@P@Q10Q200<48@Q236<00Q240PQ200L<
Ha2448@<H`Q21248@P0512401@Q212448@@Q24800PaS00<8@P@Q12400`Q210@Q0`Q20`@Q0PQ200D<
H`Q236<U:Be[009S6006AS4icQS66<HQ21S611BU112400<<HaBU5:D00Q240PaS0Q240PaS0Q2400H<
Ha2448@DYA245:D448@25:D348@45:D00aS67>LHaP036<H01ABU48@@Q1BU48@021BU00@@Q1BU5:DH
aP8DY@8@Q0065:DHaQBU6<HDYAS60QBU112411BU0Q240aBU00H@Q1BU48@DYA245:D26<H00aBU48@@
Q0025:D248@010aS5:DDYABU0Q2400@<Ha2448@@Q08<H`0348@DYABU00@@Q08DY@0348@DYAS600<@
Q0035:DHaQBU00<DY@<<H`0548@DYA2448@DY@0248@00`aS248<H`0<36<00`Q236<@Q00336<00a24
36<<H`0236<248@236<01@Q236<<H`aS248020aS00@8@PaS48@@Q08<H`03248<Ha24004<H`000P@Q
00<000@Q12400`@Q00/8@P@Q000<HcF]Kg]BU36<@Q16<D8@00Dmk`=2400?AS5:DTYBCW=:DTHaCW=:
DTHaBU96<DYBAS5243W>00@e[@04<H`e[C6<<H`4>Lh3?Nl013W>=Jde[CF]0cW>0S6<0SF]00@icSg_
@Q12408mk`05>Lhe[C6<<H`]J`02<H`01cF];F/]Jbe[<Ha243g_0092408icP04<H`e[CF]=Jd2<H`0
1CF]<H`]JcW>?Nl00T8@00LaS3F]=Jde[CW><H`]J`0:<H`00cF]>LhaS002<H`00be[<H`]J`04;F/0
1RU:;F/e[CF]<H`YBP8]J`06<H`]JbU:;F/U:BU:0RDY00@YBRe[;F/]J`8U:@<YBP079BTQ22DY:DX]
JbU:9BT00RU:0RDY00`Q22DY:DX]JbU:9BTaS3W>@Q0mkbU:9BT27>L01BDY8@PQ22489BT00b4811cW
00LQ21cW8@PQ21cW8@PU:@02:DX00be[:DXYBP029BT37>L012489BTU:B480acW00DHaQcW6<HDYA24
008<H`0324848@@Q00L48@0900048@@Q124000@Q00048@Q200<48@0300048@@Q00<48@0324848@@Q
00D48@0424848@@Q124424801P@Q36<<HaBU48@<H`@8@P<48@@8@P031248@PQ200D48@0424848@Q2
24831242248312422483124;24800`aS2488@P0324800`aS2488@P04248236<2124010aS5:DHaQ24
10@Q0`Q200<48@Q212401@Q200@48@Q212448@H8@P<48@0524848@@Q124<H`07248010@Q36<<HaBU
1PaS00<8@PaS248010Q21@@Q00<8@PaS36<00PaS00<8@P@Q24800PQ21P@Q00<8@P@Q12400P@Q010<
H`Q236<@Q1S6BU9JeUJeBU8Q21cW8@PHaQcW5:DHaP8DY@0348@DYA24008@Q00336<@Q12400<@Q003
36<@Q124008<H`0348@DYABU00<@Q00836<@Q12448@DYA246<HDY@8@Q0055:DHaQS66<HDY@036<H0
1ABU6<HHaQBU48@00aBU0Q240aBU0a240QBU00/HaQBU5:DHaQBU48@DYA246<HLiaS6008DY@0348@D
YA24008@Q0<DY@8@Q0DDY@0336<@Q1BU008HaP045:D@Q12448@45:D00a245:D@Q00248@00aBU48@@
Q00336<00a245:D@Q00548@010aS48@DYABU0QS600<@Q1BU48@00a240aBU0Q240PaS00D@Q1BU5:D@
Q0Q2008<H`03248<H`aS00@<H`0348@<H`aS008<H`0348@<H`Q200<<H`8@Q003248<H`Q200L<H`03
248<H`aS00D<H`88@P0336<@Q0aS00<<H`0348@<H`Q20048@P0000@000@Q124000848@0300048@Q2
00848@0<248mkg_NE[DaS3g_@Q0icSF]>Li243g_0SW>00@mkd8@?Nm240E6<@03BU96<DHa009:DP8m
k`08>Lhmkd8@?NlicSg_=JdaS08e[@04?NlicSW>?Nl2@Q000cg_=JdicP02?Nl013F]<H`aS3F]2SW>
00<e[CW>>Lh00cW>0c6<00DicT8@@Q1243g_00<e[@@aS004;F/aS36<<H`2>Lh013g_>LhicSF]13W>
00@e[C6<=JdaS08e[@07>Lhe[CF]<H`e[C6<:DX00Re[0S6<1BU:0Re[0S6<00@]Jc6<:DXU:@8YBP03
<H`]JbU:00@YBP03;F/YBRU:00<YBP8U:@03:DXU:BDY00<U:@038@PYBRU:008YBP8U:@<]J`<YBP08
<H`e[C6<9BTQ21cW9BTYBP8U:@<Q20@Li`8Q20037>LQ224800@Q2003:DX]JbU:008YBP049BTYBRDY
9BT28@P39BT022U:;F/YBRU:;F/YBR487>L2248212400`Q212448@0812400`0012448@0;12400`Q2
1248@P04124010Q212448@@Q1`Q200@<H`Q212448@88@P0336<8@PaS00@48@88@P<48@<8@P@48@03
24848@@Q00P48@D8@P848@05248<Ha2436<8@P02124011cW:DXU:@aS0PQ20PaS0`Q20PaS0PQ20P@Q
0PQ200<48@Q224800`Q210@Q0PQ200D48@Q22488@P@Q0088@P0436<8@P@Q000212400`Q212448@06
1242248010@Q2488@PQ20`aS0`Q200<<HaBU5:D00QBU0a2410aS0`@Q00<8@P@Q12400P@Q00<8@P@Q
24800PQ20PaS00<8@P@Q12400PQ200<48@Q212400`Q210@Q00`8@Q245:DHaSg_DYANmeJe:DXU:AcW
6<H27>L021S65:DDYA2436<@Q1BU48@336<548@236<01A245:D@Q12436<00Q2400<DYA2448@00Q24
00<DYA2448@00Q2400<DYA246<H00aS600HDYAS66<HLiaS65:D248@00aBU6<HHaP025:D011245:D@
Q1240QBU00@HaQcW7>LHaP8@Q0035:DHaQBU008DY@8HaP045:DHaQS65:D348@011BU48@DYABU1124
0QBU00D@Q1BU48@DYA2400DDY@8@Q0<DY@<@Q0065:D@Q0aS36<@Q0aS0QBU0a2400<<Ha2448@01aBU
0aS600<DYA2448@00Q2400<DYA2448@00aBU00@@Q0aS248@Q0D<H`0348@<H`Q200@<H`03248@Q124
00H<H`03248<H`aS0088@P0336<@Q0aS00<@Q0P<H`0448@<H`aS36<3248136<12481248000@48@0<
00048@@Q1248@P@Q000<HcW>NmiJeS6<0T8@00<mkcW>>Lh01Cg_00E243g_@Q0mkd8@0096<@03BU96
<DHa00=6<@06@Q0mkcW>?Nm244Ha0T8@0SF]00HaS3F]>Lhe[CW>=Jd3>Lh2@Q0013g_>LhaS3F]0S6<
0SF]0SW>00@mkcW>>LhaS0@e[@04>Lhmkd8@@Q02>Lh00c6<=Jdmk`02AS40348@=JdaS36<=JdicS6<
;F/YBRe[:DX]J`8icP03?NlicS6<00<icP8e[@<icP<e[@03<H`e[CF]008e[@8aS003;F/aS36<008]
J`HYBP8aS004=JdaS2U:9BT3:DX2;F/39BT00bU:;F/]J`03:DX012DY:DXU:BDY0RU:0b4812DY00<Q
22DY:DX00Re[00TYBRe[<H`]JbDY<H`icS6<:DX00QcW0RU:0RDY0R480acW00<Q21cW7>L00R480acW
0b480bU:00HU:BU:;F/]JbDY8@P29BT28@P02bDY;F/aS2e[:DX]JbDY7>L@Q0aS248010@Q00<000@Q
12402P@Q00D000@Q12448@Q200X48@88@P031248@P@Q0088@P03124<H`Q200D8@P@48@8<H`062484
8@@Q1248@P@Q1PQ21P@Q0`Q210@Q0PQ200<48@Q212402@Q200P48@Q25:DQ21S636<48@aS0Q2400<<
Ha2436<01PQ20P@Q0`Q200H<H`@Q12448@Q236<2124010Q236<8@P@Q10Q20P@Q00<8@PaS24800PQ2
00@48@Q212448@88@P071248@P@Q1248@P@Q24800PaS10Q20PaS00<@Q1BU5:D00aBU00@@Q0aS36<<
H`<8@P031248@P@Q00D48@88@P0436<@Q0aS36<524800`@Q24848@02124424803P@Q248<H`aS=Jdm
kf<HIcTmkc6<8@PLibDY7>L36<H00aBU48@@Q00448@00`aS48@DY@025:D448@020aS48@@Q1245:D@
Q0aS48@25:D848@25:D011S68@PLiaS60QBU00DLiaS65:DDYA2400<HaP8DY@0448@DYABU5:D248@0
1aS68@PQ21cW48@DYA24008DY@HHaP035:D@Q1BU008DY@0448@DYABU5:D248@00aBU6<H@Q00248@0
0aS65:DDY@0248@45:D00`aS48@DY@025:D248@010aS48@@Q1240PaS00@@Q1BU6<HHaPD@Q0035:D@
Q1BU008HaP8DY@8Li`035:D@Q124008DY@0336<@Q124008DY@0448@DY@aS48@436<01A2436<<H`aS
48@010aS00<@Q0aS36<00`aS0`Q200<<Ha2436<00`Q20Q241PaS00<@Q0aS36<00`aS00<@Q0aS36<0
0PQ20PaS0@Q20@@Q00000`0012400008124020aS>Lig_EJe;F/e[Cg_>Lh2@Q000cg_@Q124002?Nl0
1CW>?Nlmkcg_>Lh00T8@0dHa0T8@00LmkcF]>Lhmkd8@AS5:DP02@Q000cW>?Nm24002?Nl3>Lh00cF]
>LhicP02@Q000cg_@Q0icP02=Jd3<H`013F]?NlicSW>0SF]00TicS6<<H`e[Be[>Lhmkd8@AS400T8@
00@mkcW><H`aS0@e[@0;?NlicSF]<H`]Jc6<=JdaS3W>?Nle[@02<H`01SW>?Nle[C6<=JdicP8aS006
>LhmkcW>=JdaS3W>0Sg_0SW>00<e[C6<<H`00S6<00@]JbU:8@PU:@P]J`04:DX]Jbe[;F/2:DX39BT6
:DX01b489BTU:B489BTYBRDY00@YBP8U:@038@PU:BDY00TYBP089BTYBRe[:DXU:AcW8@PU:@8Q2004
6<HLib488@P27>L00aS67>LQ20048@P29BT2:DX2;F/01RU:;F/YBRDY:DXU:@8YBP05<H`]JbU:<H`]
J`02<H`00a2424848@0?12400`0012448@0;12401@Q212448@Q236<00PQ200H<H`Q236<<H`Q236<6
24800`@Q2488@P032482124324800`@Q248<H`0224800`@Q24848@0224800`@Q24848@0212401@Q2
1248@P@Q00000`@Q1`Q200@<H`Q236<8@P8<H`8@Q08DY@0648@DYABU48@<H`Q20`aS1@Q20P@Q00@8
@P@Q2488@P<48@<8@P<<H`@8@P031248@P@Q00<48@@8@PH48@0324848@Q20088@P8<H`88@P8@Q007
5:DQ22e[>Lhe[B489BT00QS600<@Q0aS36<00`Q210@Q0PQ20P@Q00@<HaBU5:D@Q088@PD48@<8@P0F
1248@P@Q1248@P@Q36<@Q1BU>Li6<F<HJeY243F]8@PLibDY8@PLiaS65:D448@00aBU48@<H`0348@0
11BU48@<Ha240QBU00H<Ha245:DDYA2436<448@35:D00a245:DDY@0?5:D26<H27>L25:D248@>5:D2
6<H95:D01A245:DDYABU6<H00aBU112400<DYA245:D00QBU1a2400LDYA2436<@Q0aS48@<H`0248@0
11BU48@@Q0aS0Q241ABU00<LiaS65:D00a2400<HaQBU48@00QBU0Q240PaS0aBU0Q240PaS0Q2400@D
YA2448@<H`<@Q0<<H`8@Q00336<8@PaS008<H`0348@<H`aS00<<H`<@Q0055:D@Q0aS248<H`0548@0
0`aS48@<H`0436<3248000D48@0400048@@Q248212402PQ2=JekgU[F:DXicSg_>LhmkcW>0Sg_0T8@
0Sg_00=243g_>Lh00SW>14Ha0d8@00@mkcW>=JdicP924005AS5243g_?Nm24004>Lh013F]>LhicSW>
0Sg_00A243g_>LhicP<e[@8aS005=JdicSg_>Lhe[@02<H`01SF]<H`e[CF]>Lhmk`92408mk`8icP8a
S004=JdaS3F]=Jd3>Lh3<H`00cW>?NlicP02=Jd00c6<=JdicP03=Jd00cW>=JdaS002=Jd013W>=Jdi
cSW>0Sg_0cW>00@e[C6<;F/aS08]J`05:DXU:BU::DXaS002;F/012U:;F/]Jc6<0Re[00DYBRe[9BTU
:B4800<U:@<YBP8U:@048@PU:BDY9BT4:DX00bDY:DXYBP02:DX012DY8@PU:BDY12e[0bU:00@U:BU:
9BTU:@8YBP039BTQ2248008Q20036<HLib48008Q20086<HLib487>LQ21cW8@PLi`<U:@04:DX]Jbe[
;F/2:DX012DY8@PU:BU:0be[00PaS2e[<H`aS1cW6<H48@001@@Q00@000@Q124000d48@0300048@@Q
00848@0624848@Q21248@P@Q0`Q210aS00<8@PaS36<00PQ210@Q0`Q20P@Q10Q200<48@Q224800`@Q
1@Q210@Q1@Q20P@Q0`Q200H48@Q21248@P@Q248236<2248236<011245:DHaQBU0QS600<DYA2448@0
0PaS0PQ200@48@Q212448@88@P031248@P@Q00@8@P051248@PQ2248<H`032482124010Q212448@@Q
0`Q200<48@Q224800PQ20`@Q00@8@P@Q24848@88@P0336<8@PQ2008<H`0;48@<HaS67>LaS3g_>Lha
S1cW6<HDY@0236<22482124010Q21248@PQ20P@Q0PQ200@@Q1S65:D<H`848@88@P03124000Q20084
8@@8@P848@<8@P0:;F/icV]JKg]:DT8@:DXQ22U:8@P36<H25:D248@010aS48@@Q1240QBU0a2400@<
Ha2448@@Q08HaP055:D@Q0aS48@DY@0248@236<00a246<HHaP0248@25:D00aS65:DDY@035:D01124
5:DDYABU0Q2400@DYAS66<HHaP8DY@8@Q0@DY@046<HDYA2448@25:D00a245:DHaP026<H75:D01A24
5:DDYABU6<H00aBU00DHaQBU5:D@Q1BU00<@Q0<DY@0536<@Q12448@DY@0448@011BU48@<Ha240`aS
0aBU1Q2400<<HaBU6<H00QcW00<HaQ2448@00Q240QBU00@@Q0aS36<<H`L@Q00336<@Q0aS00H@Q08<
H`04248<Ha2448@336<01A2436<<H`aS48@00PaS00@8@PaS36<<H`8DY@0448@<H`aS36<348@236<2
48@236<524811240000500048@001240000312402PQ200048@aS>Li_Ndic:DXicSg_0SW>0T8@0cg_
00=6<D8@>Lh00SW>00HmkcW>>Lhmkd8@>Lh2?Nl00dHa@Q124002?Nl2@Q02?Nl2>Lh01Cg_=JdicSW>
@Q000Sg_00<icSg_@Q000T8@00A:DTHaAS4mk`8icP07<H`e[CW>?NlicSF]<H`00SF]00<aS2e[;F/0
0S6<00<e[C6<<H`00S6<00<YBRe[=Jd00cW>00@e[CW>?Nlmk`8icP03=Jd]Jc6<008e[@05>Lhe[CW>
>Lhe[@02<H`2=Jd0236<;F/aS3g_=JdaS2e[>Lh2?Nl2>Lh00cF]<H`e[@02<H`2;F/2:DX01C6<=Jde
[C6<9BT00RU:00<U:BU::DX00RU:00PU:B488@PQ22DY:DXQ22DY0Re[0bU:00@]JbDY9BTYBP8]J`03
:DXU:BDY00<U:@8YBP<Q2003:DX]JbDY00<Q208U:@06:DXU:B488@PU:BU:12DY00<YBRDY9BT00b48
00@U:Be[;F/YBP8Q208U:@03:DX]Jbe[008aS003;F/YBRU:008]J`03:DX]Jbe[008aS005;F/aS3F]
7>LDY@0912401@0012448@@Q24800P@Q00<000@Q124010@Q00<000@Q12400PQ200X48@0012448@aS
248<Ha246<HDY@8@Q08DY@0348@<H`aS00<8@P041248@PQ22482124224801PaS24848@@Q24848@@8
@P051248@PQ224848@032482124010Q212448@@Q0PQ20`@Q1@Q20P@Q00/8@PaS48@<HaBU6<HLicW>
@Q0mkcF]008Li`045:D@Q0aS36<424801@@Q2488@PQ212400PQ200@<H`@Q1248@PD@Q08<H`88@P03
1248@PQ20088@P848@0324848@@Q00<48@88@P031248@P@Q0088@P0336<8@PQ20088@P8DY@0?6<Hi
cTHaHaQJeTicE[Dmkc6<7>L@Q0aS248<H`Q200848@<8@P848@0736<@Q1cW8@PLia24248010@Q00@8
@P@Q2488@P<48@<8@P0;36<8@PQ2;F/mkf]JLia6<Cg_7>LHaP028@P27>L02AS65:DDYA2436<DYA24
6<HDY@0248@25:D01A245:DHaQBU48@011BU00<<Ha245:D00a241ABU0a2400DDYAS65:DDYA2400<D
Y@@@Q0035:DHaQS6008HaPDDY@046<HDYAS65:D248@00aBU48@@Q00248@01ABU48@DYABU6<H01ABU
00<@Q1BU5:D00aBU11S600@DYA2448@@Q08DY@/@Q00436<@Q12448@236<00a2436<DY@035:D348@0
1ABU6<HDYA246<H00R4800@Lia2448@@Q08DY@<<H`0348@DYA2400H@Q00436<@Q1BU5:D548@436<2
48@00`aS48@<H`0236<2248010aS48@@Q0Q20PaS00@DYA2448@@Q0@<H`03248<H`aS008@Q0<<H`04
248<H`Q236<1248000P48@0=24848@0036<e[G>LE[D]JcW>?NlicSg_>Lh00d8@0cg_00A243g_?Nlm
k`8icP05?Nm243g_?NlicP03@Q0014Ha@Q0mkcg_0T8@0Sg_0SF]0SW>0Sg_00<icSg_@Q000T8@00U6
<D8@AS5:DT8@?Nle[Be[=Jd00Sg_00=243W><H`00S6<0SF]00@aS2U:<H`aS08e[@<aS004:DXaS36<
>Lh5=Jd4>Lh013F]<H`aS3F]0cW>00HaS3F]<H`aS3F];F/2<H`2=Jd3<H`2>Lh01SF]>Lhe[CF]>Lha
S0<]J`03<H`]Jc6<00<e[@04;F/YBRDY9BT2:DX39BT28@P01RDY:DXYBRU:9BTYBP8]J`HYBP049BTY
BRe[:DX59BT00bU:9BTU:@029BT2:DX022DY8@PU:BDY:DXQ21cW9BT2:DX29BT00b489BTU:@02:DX6
9BT3:DX29BT28@P01BU:;F/aS2e[:DX00Re[00HYBRe[;F/aS2e[:DX2;F/2=Jd01RDY7>L8@PQ21240
00<48@0300048@@Q00848@050008@P@Q1248@P0<12400`Q236<8@P02248336<25:D26<H248@236<3
24800`@Q2488@P0224802P@Q248<H`aS24848@Q21248@P@Q1@Q21`@Q00<8@P@Q248010@Q00<8@P@Q
12401@@Q1PQ200LDYA245:DaS3g_CW=240029BT26<H01A2436<<H`Q236<00PQ20`@Q0`Q200<48@Q2
24800P@Q00<8@PaS48@00Q240`aS0PQ200<48@Q236<00PQ200@48@Q22488@P848@0324848@Q20084
8@<8@P0436<8@PaS248236<03A24:DXe[E[FG_MJeV<HBU92436<7>LDY@aS00@8@P031248@P@Q0084
8@09248<Ha248@PLiaBU24848@Q200@48@<8@P031248@P@Q00848@0=24848@@Q8@P]Jf<HJeY>LdYB
:DXLib486<H00R4800@LiaBU5:D@Q08<H`0548@DYABU48@DY@0448@00`aS5:DDY@026<H35:D648@4
5:D00a2436<@Q0025:D00aS65:DDY@0448@45:D01Q245:DHaQS68@PLi`8DY@0348@DYAS6008DY@05
6<H@Q12448@DY@0348@25:D00a245:D@Q0085:D00aS65:D@Q0025:D26<H45:D948@25:D236<248@0
10aS48@@Q1240PaS00DDYAcW6<H@Q0aS00<@Q0035:D@Q1S6008Li`066<H@Q1246<H@Q1BU0a240PaS
21240PaS00@@Q1BU5:D@Q0P<H`0348@<H`aS00@<H`05248<H`aS36<@Q00236<25:D0212436<<Ha24
36<8@PaS248248@236<01@@Q248<H`aS24800@@Q00002@00124000@Q00048@001248@P0212401`Q2
=JecW5Je<Ha243g_008icP<mk`04=JdicSW>?Nl2>Lh7?Nl01CW>=Jde[Cg_@Q0014ic00=6<DYB@Q00
0SW>00<aS3W>>Lh00Sg_0T8@00=6<DicAS40248@00<icSF]=Jd00SF]0S6<12U:0Re[0c6<00Pe[CW>
=Jde[CW>@Q0icSF]0S6<00DicSF]<H`aS3W>00<e[@03<H`e[C6<008aS005=JdaS36<<H`]J`02<H`0
13F]<H`aS36<0Re[1C6<00<]JbU:;F/00c6<0Re[00/e[C6<?NlmkcW><H`YBRDY:DXU:BU:00DU:@03
:DXU:BDY008U:@8YBP03;F/YBRU:008U:@<]J`03:DXQ22DY00DU:@038@PU:BDY00<YBP8U:@8Q208Y
BP04;F/aS2e[:DX29BT00be[:DXU:@029BT3:DX01be[:DXU:BDY:DX]JbU:008U:@038@PYBRe[008]
J`05:DX]Jbe[;F/YBP02;F/0136<;F/]JbDY0Re[00<HaQBU124010@Q00<000@Q12400`@Q00<000@Q
000040@Q0PQ200T@Q0aS6<HU:C6<?Nle[Be[9BT00QS600<@Q0aS248010Q210@Q00D8@P@Q2488@P@Q
0088@P041248@PQ22483124324851242248312400`Q21248@P0324800`@Q2488@P03248020aS5:D@
Q1S6;F/icUkgF]H2G_L2BU800be[8@PHaP0236<7248010@Q248<Ha240`Q20`aS0Q2400HDYA2436<<
H`Q2124624801`@Q24848@@Q24848@Q200848@88@P8<H`0C248<Ha2448@LibDY;F]F]F<HNmicW6]J
NmicW6mkBU8U:ABU12400`Q20PaS10@Q00P<Ha247>LQ21cW36<8@P@Q0PQ20P@Q0`Q200<48@Q21240
0P@Q00/8@PaS2488@RDY<HaS66LiCW=6<BDY008HaP035:DHaQcW008Q20037>LDYAS6008@Q08DY@@@
Q08DY@036<H@Q0aS008@Q0046<HDYA245:D248@25:D26<H00aBU48@@Q00248@011BU48@DYA2411BU
00<@Q1BU48@00Q2400@DYAS65:D@Q0@DY@<@Q0HDY@0348@<Ha24008DY@0348@DYABU008DY@0448@D
YABU6<H248@26<H348@011BU6<HDYABU0Q2400XHaQBU5:D@Q1BU48@<Ha2436<@Q08DY@<<H`<@Q0<<
H`@DY@0348@DY@aS008<H`DDY@036<HLiaS6008DY@057>LHaQBU48@8@P0436<348@010aS48@<H`aS
11240PaS0Q2400<<Ha2448@00Q240`aS00<8@Q2436<00PaS0a240`aS00<@Q1BU48@00`aS0Q241PaS
0a240PaS0@Q20007124030Q212448@@Q248e[GNmE[DaS48@AS52408icP03?NlicSg_00PicP03?Nm2
448@0092408icP03=JdicTHa00=>L`05AS5:DTYB@Q0icP02=Jd01CW>?NlmkcW>?Nl00THa00=:DT8@
AS400T8@00E6<D8@@Q1243g_00<icP<e[@8aS0@YBP03<H`]Jc6<008aS08e[@8icP8mk`06=JdicS6<
;F/aS3F]0SW>00@aS2e[=JdicP<e[@@aS004=Jd]Jc6<;F/5<H`2;F/5<H`3;F/01cF]<H`e[C6<=Jdi
cSg_008icP03;F/YBRU:00<U:@8YBP8U:@06:DXU:B487>LQ22DY0bU:00@]JbDY9BTYBP8]J`03:DXU
:BU:00@YBPDU:@@YBP088@PU:B488@PYBS6<>LhaS08U:@03:DX]JbU:008U:@<YBP059BTYBRU:;F/Y
BP029BT00bU:9BTYBP029BT2:DX012e[:DXYBRU:0Re[1C6<00D]JbU:6<HDY@aS01448@0300048@@Q
00848@0300048@0000848@0424848@Q2248236<00aBU6<HYBP02?Nl0148@=JdQ21cW0Q2400<<H`Q2
36<00`Q20P@Q1PQ20P@Q0`Q200<48@Q224800`Q200@48@Q212448@88@P041248@PQ2248412422480
1@@Q24848@Q212400`Q200D@Q0aS5:DQ236<009BU009HaQNmeJeG_LmkcF]6<H@Q0aS00D8@P0336<8
@P@Q0088@P8<H`0824848@Q2248<HaBU48@DY@8@Q00436<8@PaS36<224801P@Q2488@PQ21248@P84
8@<8@P031248@PQ2008<H`88@P0736<DYBDY8@PLicW>CW<00WNm00M[FW>LLiaoof]J@Q0Q20022480
0`@Q000<H`0248@02PQ212448@@Q248@Q2487>LDY@aS0P@Q00H8@P@Q12448@Q21244248212402PQ2
1248@QBU7>M:DUkgF]IF]C6<0RDY0QS600LDYAS68@PQ21cW6<HDY@0548@236<348@00aBU48@DY@03
48@25:D01QS648@@Q1245:DHaP8DY@D@Q0DDY@<@Q08DY@0348@DYABU00@DY@8HaP035:D@Q124008D
Y@056<H@Q1245:D@Q00236<00a245:DDY@0248@25:D011245:DHaQBU0a2411BU00@HaQBU48@DY@8H
aP8DY@0348@DYA2400<@Q08DY@H@Q0@<H`035:D@Q1BU00<DY@@@Q00536<@Q1S66<HDY@026<H00acW
6<HDY@026<H02aBU48@<H`aS48@<Ha2436<@Q0aS48@00PaS1A2400<<Ha2448@0112400HDYA2436<<
Ha245:D248@010aS248<Ha240`aS212400<8@PaS48@00PaS00<8@PaS48@00PaS0A240@aS0@Q20000
4P00124000@Q00048@001248@P@Q0008@S6<IcU>Lbe[>Li240<mk`<icP@mk`8icP@mk`=24003AS52
43g_008mk`924003?Nm244Ha0092408mk`03@Q0mkcg_008mk`03@Q16<D8@008mk`03>Li2448@0092
4006?NlicSW>>Lhe[C6<0cF]00<aS3F];F/00S6<0be[0S6<00He[C6<<H`e[CW>@Q03?Nl013W>=Jda
S2e[0c6<00<e[C6<<H`00SF]2c6<00<]Jc6<<H`00SW>1be[0cF]0Re[00PYBSF]>LhicS6<;F/YBRe[
0RU:0S6<00<]JbU:8@P00b4800@U:B488@PU:@<Q208U:@<]J`8YBP8]J`07:DXU:BU:<H`]JbU:9BT0
0bU:00<U:BU:9BT00R4800HLic6<AS5:DT8@:DX27>L39BT28@P00bDY:DX]J`03:DX00bDY:DXYBP02
;F/01BU:8@PQ22DY:DX00Re[00dYBR489BTU:Be[=JdaS2e[:DXQ22DY6<HDY@02248412401@001244
8@@Q00004P@Q0`Q20QBU00@YBT8@DYAS60=JeP03@Q0icQS6008@Q08<H`88@P031248@P@Q00848@88
@P0336<8@PQ200@48@0524848@Q224848@042486124224800`@Q2488@P032482124030Q236<8@PaS
6<HYBRDY:DXmkeJeMkecW09_N`07Mkeoof<HBU8Q212436<00P@Q00X@Q1BU5:D<H`001248@QS68@P@
Q0848@06248<H`Q236<@Q1BU0a240PaS1@Q200H48@Q22488@P@Q248412401@Q236<@Q1S67>L00Q24
00H<HaBU;F/aS5kgJeX2Nmh00f]JHaQ[FP02Ool015[F:DX000Q21`@Q00L000aS48@DYAS65:D8@P02
12400`Q212448@0212406`Q212448@@Q24848@Q2124<H`Q2124LibU:G_MS65:DF]HicRe[7>L@Q1BU
48@DYAcW6<HLi`026<H01QcW5:D@Q0aS48@HaP8@Q00536<@Q12448@<H`035:D00a245:D@Q0025:D3
6<H02QcW48@@Q1245:DLiaS65:DHaQcW0QS600<DYAS648@00Q2400@DYAS65:DDY@<@Q0<DY@H@Q0@D
Y@<@Q0@DY@0348@DYAS6008DY@8@Q0075:D@Q1245:D@Q1S648@00aBU00@HaQBU48@DY@h@Q08<H`8@
Q0065:D@Q0aS48@<Ha240PaS00<@Q1BU5:D00a2400LDYAcW7>LHaQBU48@DY@0348@536<548@010Q2
36<<H`aS0Q2400<DYA2448@00PaS11240`aS0Q2400<<Ha2448@00Q2400H<H`@Q248DYAcW6<H636<2
5:D448@011BU48@@Q0aS0@Q2000812402PQ200048@Q2<Ha_Ndic;F/icSg_13W>00<mkcW>>Lh00cg_
0SW>00<e[CW>>Lh00Sg_00A244Ha@Q1240Lmk`03@Q16<DHa00924004?NlicSg_?Nl5@Q02?Nl2@Q00
1THa@Q0mkcW>?NlicP8e[@<aS003=JdaS36<008aS003;F/aS2e[008]J`<aS003=Jdmkcg_008icP92
4004?NlaS2e[=Jd2<H`00cF]<H`e[@03<H`033F]>Lhe[Be[:DX]JcF]<H`]JbU:;F/aS0<e[@05<H`]
Jbe[;F/aS002;F/01C6<=JdaS2e[:DX00c6<00<]JcF]=Jd00be[0S6<00<]JbU::DX00RU:00TU:B48
7>LLibDY8@PU:B489BT00R4800LYBS6<<H`]JbDY:DX]J`04:DX2;F/3:DX2;F/02bU:9BTYBRDY6<HU
:CW>CW=:DS6<8@P01BDY0b4800LU:BU::DXYBRDY:DX]J`03:DX01BDY:DXU:BDY:DX00Re[00@YBRDY
9BTYBP<aS005:DXU:BDY7>LDY@02248212400`0012448@0212400`0012448@0212400`0012448@03
12400`0012448@06124224802PaS48@@Q248=Je6<F<HF]IS65[F0Tic00<YBR4836<010Q200<<H`Q2
24800`@Q10Q200<48@Q224800`@Q0PQ20`@Q0PQ21@@Q0PQ210@Q10Q20P@Q0PQ200P<Ha246<HHaR48
>Li6<F]J0W>L00Y_Nf]JMkeg_G>L@Q0U:A241248@P8<H`0848@<H`@Q1248@QBU7>L@Q0848@88@P@<
H`D@Q00436<8@PQ236<224831245248010@Q2488@Q240QS600@DYA2436<DY@8Q2004BU9F]G>LMkd2
Kg/01f]JMkekgWNmE[DLi`Q200848@03248<H`Q200<48@0336<8@PaS008HaP0336<48@@Q00@48@04
24848@@Q12432483124224825:D02DHaDYAW>FmkBU8e[B4848@DY@0248@25:D36<H012487>LHaQBU
11240PaS0Q2400@HaQBU48@@Q0<DY@<@Q0035:DHaQBU008DY@@@Q0<DY@@HaP065:D@Q1BU5:D@Q1BU
0Q2400DDYA2448@@Q1BU00<@Q08DY@0<36<DYABU6<H@Q0aS48@DYA245:D@Q1BU0Q240aS600<DYA24
48@00QBU00L@Q1BU48@DYA245:D@Q0036<H00aBU48@DY@0248@00aBU48@@Q00248@436<00aBU48@@
Q00336<348@236<0112436<@Q0aS0Q2400@DYA2448@DY@<HaP8DY@8@Q0@<H`0348@<H`aS008@Q0<<
H`0348@<H`aS00<<H`0348@<Ha24008<H`0348@DYA2400<<H`<@Q0085:D@Q0aS48@<H`Q236<@Q08D
Y@0648@8@PQ2248<Ha240PaS0Q2400@DYA2448@DY@8@Q04<H`0000D000@Q00048@0000<48@0=2484
8@@Q248e[FmkDY@YBSF]>LhmkcW><H`00SF]00Dmkd8@>Lhe[CW>00<e[@8icP8aS003=JdicSg_00@i
cP8mk`03@Q0icSW>00He[@<icP06@Q0mkdHaBU9243g_0SW>00<mkcW>=Jd00cF]0S6<00He[Be[;F/a
S3F]>Lh2;F/00cF]>LhicP03=Jd2;F/2<H`00cW>=Jde[@02>Lh2=Jd2<H`4>Lh01c6<=JdaS36<;F/a
S3F]00<]J`8aS008;F/aS3F]=JdaS2e[<H`e[@<aS0@]J`8YBP8]J`8YBP059BT]Jc6<>LhaS002;F/3
<H`4;F/2:DX00bDY:DXU:@029BT00bU:;F/U:@029BT3:DX29BT02BU:;F/YBRU:9BTYBRe[<H`]J`02
:DX2;F/03BU:9BTQ2248:DXaS3W>AS5243F]:DXLib48008U:@8Q20<Li`058@PU:BU:9BTYBP03;F/0
1BU:9BTU:BDY:DX01RDY0bU:00DU:AcW8@PHaQBU00<8@P848@0300048@@Q00<48@0300048@@Q0084
8@0300048@@Q00D48@0300048@@Q0088@P8<H`07124HaRDYAS5[FVmkMkd00Vmk0WNm00EcW3g_;F/<
H`@Q0088@P<<H`0624848@@Q248@Q0aS0PQ21@@Q00@8@P@Q12448@88@P<48@0300048@@Q00@48@03
24848@@Q0088@P0436<48A2448@25:D02@aS48@Lib48;F]6<E[FMkecW002Kg/026]JKg]g_GooG_L]
J`aS0002124010Q212448@000P@Q00<8@P@Q24800P@Q0PQ21@aS0QS600<DYAS624800PQ200D48@Q2
36<8@PaS0088@P848@<8@P0>36<48AcW?Nm:DSF]6<H8@QBU9BT]JdYBCW=W>@9cW008JeYW>GooOomW
>CW>248<H`848@88@P<48@06248<Ha2436<@Q0aS0PQ20`@Q00@8@P@Q12448@<8@P0A36<8@PaS248<
H`@Q248HaQcWBU9>LeJeJeY>Lc6<7>L@Q0026<H35:D00a245:DHaP036<H00aBU6<HDY@025:D248@2
5:D848@85:D248@45:D011S67>LLiaS60QcW00<DYA245:D00QBU0a2400<HaQ2448@00aBU112400DD
YA2448@@Q1BU008HaP8DY@0348@DYABU00<DY@0348@DYA24008@Q0035:DHaQS6008@Q00336<@Q1BU
008DY@8@Q0055:DHaQ2436<@Q0035:D248@236<00a245:D@Q00336<00aBU48@<H`0336<248@02aBU
48@@Q1245:DHaQBU48@HaQcW5:D00PaS00@DYA2436<8@PH<H`<@Q0<<H`8@Q0@<H`035:D@Q0aS00<<
H`8@Q00336<@Q0aS008@Q08<H`88@P0536<DYAcW7>L@Q004248536<00`Q248@DY@035:D136<000D4
8@0<00048@@Q24848@0036<aS7>LDY@]JcF]13W>0cF]00@icSg_?NlicP8e[@03>Lhe[CF]00<e[@04
>Lhe[CW>=Jd5>Lh2?Nl2>Lh2=Jd3>Lh2=Jd013W>?Nm244Ha0T8@00<icSg_>Lh00SW>13F]2S6<00<e
[CW>>Lh00SF]0c6<1CF]00@icSF]=JdaS0<e[@03>Lhe[CF]008e[@<aS004;F/YBRe[<H`2=Jd01c6<
;F/aS36<=JdaS2e[00@aS005;F/aS36<;F/U:@04;F/2:DX012e[<H`aS36<0Re[0c6<0Re[00<YBRe[
;F/012U:0bDY00DYBRDY8@PU:BU:008]J`@U:@<YBP059BT]Jbe[<H`]J`02:DX00c6<:DXYBP027>L2
:DX01c6<@Q16<Cg_;F/Q22DY008Q20067>LQ21cW6<HLib480RDY00<Q22U::DX00S6<0RU:0RDY00<Y
BRDY9BT01BDY0RU:0RDY00<Q21S65:D00Q2400<<H`Q212401@@Q00<000@Q12401`@Q00@8@P@Q1240
00D48@88@P0?36<DYAcW=JeBU6<HMkecW6mkJeYkgWooG_M241BU008<H`051248@QBU5:D<H`031240
10aS48@@Q0Q20P@Q00<8@P@Q12401@@Q00<000Q212400PQ210@Q0PQ20`@Q1@Q200<<HaBU48@00QBU
00LHaQBU7>Le[DHaKg]cW002Mkd2IcT01GNmOomcW4Ha5:D00P@Q00<8@P@Q24802P@Q1@Q200D<HaS6
6<HHaQBU008<H`0824848@Q21248@P@Q24848@88@P848@0J248<H`Q26<HicTYB?NlLi`Q248@HaQcW
?Nm246<HJeYcW6mkJeYg_G_NLiaF]BDY5:D48@88@P081248@P00248<Ha2436<8@P<<H`X48@@8@P0D
36<8@PQ2248@Q1S6>Li245[FLiaJeTHa9BTDYAS65:D@Q1BU6<HDY@8@Q0045:DLib486<H25:D548@0
1ABU6<HDY@aS48@00PaS00<@Q1BU5:D00aBU00@HaQBU6<H@Q0DDY@0448@DYABU6<H37>L00aBU6<H@
Q0045:D00aS648@<H`0248@01QBU48@<Ha245:DHaP8DY@<@Q0075:DHaQS65:DHaQBU48@011BU00@@
Q1BU48@@Q0<DY@0648@<Ha245:DHaQBU0a2400<DYA2448@00a240QBU00@@Q0aS36<<H`8@Q00436<@
Q12448@236<348@636<011245:DDYABU11S600<DYA2436<00PaS112400D8@PaS36<8@PaS008@Q08<
H`05248@Q12436<8@P0336<00a2436<@Q00536<348@336<010Q236<@Q1BU0Q240PaS0PQ210aS00<8
@PaS48@00Q240ABU0A240A2400000`001240000812401PQ2=JeW>DYB9BTaS0<icP04=JdaS3F]=Jd3
>Lh01Cg_>LhaS36<>Lh00Sg_0cW>00HmkcF]<H`aS2U:;F/3<H`02CF]>LhicSW><H`]Jc6<>Lhe[@02
<H`00cF]>LhicP02>Lh01Cg_>Lhmkcg_>Lh00SF]00HaS3F];F/YBRe[=Jd2<H`01Be[<H`e[CF]<H`0
0cF]00LaS3W>?Nm6<D8@>LhaS002=Jd013W>=JdaS36<0SF]0SW>1CF]0S6<00@]Jc6<<H`e[@8aS003
>LhaS2e[008aS08icP8e[@05<H`]Jbe[;F/aS002:DX012DY;F/YBRU:0RDY00<YBRDY;F/00S6<00D]
JbU::DX]Jc6<00<]J`05:DX]Jbe[<H`]J`029BT3;F/012U:9BTU:BU:1BDY124800DYBRe[;F/]JbU:
00<]J`07:DXQ22DY:DXLibDY>Lh00THa00<icRDY:DX00R4800@U:B488@PLi`8Q20039BTYBRU:008Y
BP8U:@048@PU:BU::DX49BT3:DX29BT00acW8@PLi`027>L00aS648@8@P0212400`Q21240000;1240
0`0012448@07124224801A24248Libe[CW<00Vmk00Ug_G>LJeYNmg_NOomcW5:D48@00`Q200<48@Q2
24801@@Q00H8@P@Q124000@Q2486124224800`@Q24848@0312401@Q212448@@Q24800`@Q00D8@P@Q
124DYB48008aS00D6<HDYA245:DYBSg_BU9S66LiKg]cW6]JKg]g_GooHaPe[AS6248<H`<48@<8@P84
8@0300048@@Q00H8@P0336<8@QBU008DY@0648@8@P@Q1248@PaS10Q200h<H`Q22488@P@Q248@Q0Q2
9BU>Lf<HF]H]Ja240QBU00THaS6<>Li>Le:DE[ES65[FE[D00THa00E242U:7>L8@PaS00848@03248<
HaBU008HaP045:D@Q0Q236<31242248812401PQ21248@PaS248<H`8@Q008<H`icUJeJeY>LcW>7>L@
Q0HDY@0748@DYAS67>LHaQBU48@00QBU00<LiaS65:D00QS60QBU00D@Q0aS48@@Q1BU00<@Q0<DY@<L
i`075:D<Ha245:D@Q1BU48@00aS600PQ21cW7>LHaQBU48@DYA240aS600<DYA245:D00QBU00@@Q0aS
248<H`@@Q08DY@8@Q0055:D@Q1BU48@DY@026<H01ABU48@DYABU48@011BU0Q2400HDYA2436<@Q1BU
6<H348@00aBU48@@Q0025:D248@01PQ236<@Q1245:D@Q08<H`<@Q00536<@Q12448@DY@0548@65:D2
48@336<00a2436<<H`0236<2248236<348@00`aS48@@Q00436<011245:D<H`aS0PQ200D@Q0aS36<<
Ha2400<<H`0748@<H`Q2248@Q1S65:D00`aS00D@Q0aS248<H`Q2008<H`<8@P<<H`48@P000`@Q00<0
00@Q12400P@Q00P8@P@Q1248@Re[IcU:DRU:13F]0SW>0SF]0SW>00<mkcW>=Jd013W>0Sg_0cW>00@m
kcF]<H`]J`8aS004;F/aS36<<H`2>Lh2<H`00be[<H`aS002=Jd00c6<=JdicP02?Nl013W>@Q0mkcW>
0SF]00@icSF]<H`]J`8aS003;F/aS3F]00<aS003;F/aS36<00<e[@8icP92408mk`@aS003>Lhe[CW>
00<aS08icP05=JdaS3W>=JdaS002;F/01C6<;F/aS3F]<H`013F]00<aS3F]=Jd00SW>0S6<00<]Jc6<
<H`00Re[0bU:0RDY00PYBRDY:DXaS3F];F/U:Be[0S6<00<]JbU:;F/00S6<0Re[12U:0be[00<YBRDY
8@P012DY00DQ22DY8@PQ22DY00@YBP<]J`8YBP059BTQ22489BTYBP02;F/2>Lh00c6<:DXQ20039BT4
8@P69BT00b489BTU:@03:DX39BT3:DX012DY8@PU:BDY0R4800@HaQcW5:D<H`<8@P<48@0400048@@Q
000312400`0012448@0212400`0012448@0612405PQ236<8@QS68@PicU[FIcUg_G>LKg][FVmkLiak
gWooBU8Q20@Q0008@P@Q0PQ23`@Q0PQ200<48@Q212402@@Q00@8@P@Q2488@P8<H`0324848B48008i
cP09:DX@Q0aS8@PaS3g_E[EJeVLi009cW008Kg]cW7ooKg]BU2U:48@<H`848@88@P031248@P0000D4
8@88@P8<H`05248<H`aS48@HaP025:D4248236<924806a24248Lic6<AS5S64Ha9BTHaPaS5:D]JbU:
@Q16<EJeG_MF]EkgDYA2436<;F/YBQS648@48@03248021245:DHaQS648@DYA24248412400`Q21244
8@0212400`Q212448@0324803`@Q248<Ha2436<Q22U:DYAW>E[FBU8U:A246<H@Q0025:D01AS65:DD
YA245:D01QS60acW00DDYA245:DHaQBU008@Q0035:DHaQBU008@Q0035:DHaQBU008Li`036<HDYA24
00<@Q0065:D@Q1BU5:DLib480acW00<DYAS65:D00QBU0QS61QBU0Q240PaS00<@Q0aS5:D00aBU00H@
Q0aS48@@Q1BU7>L26<H011BU48@DYABU0Q240aBU212411BU212410aS0Q240PaS00<@Q1BU5:D00`aS
00@DYA2448@<H`8@Q0045:D@Q1BU5:D26<H00aBU48@<H`0236<00a2436<8@P02248436<348@436<5
48@010aS2488@PQ20PaS0a241`aS00<@Q1BU5:D00Q2400<8@PaS248010Q20PaS00@8@PaS36<<H`48
@P0000<000@Q12400P@Q00`000@Q1248@P001248@RU:G_M6<BU:=Jd3>Lh2=Jd01C6<=Jde[CW>@Q00
0cg_1SW>0Sg_00@icSF]<H`]J`<aS003;F/aS2e[008]J`DaS0<]J`8e[@8icP8mk`@icP0:=JdaS36<
;F/aS3F]?NlicSF]<H`2=Jd01cW>=Jde[C6<=JdicSg_008icP8mk`03>Lhe[CF]00<e[@8icP03=Jda
S3W>008mk`05>Lhe[CW>>Lhe[@02<H`00cF]>LhicP02=Jd3;F/00c6<>Lhmk`02?Nl00cW>=Jde[@02
>Lh2<H`7:DX29BT01Be[<H`]Jbe[:DX00Re[00@YBRDY:DX]J`8YBP8]J`09:DX]Jbe[<H`YBRDY:DX]
JbU:008U:@8YBP039BTQ2248008U:@08:DXU:BDY8@PYBRe[<H`YBP8U:@8]J`04:DXU:BDY9BT2;F/0
12U:9BTQ21cW0RDY00@YBR488@PQ20<U:@8YBP04;F/YBRDY9BT28@P29BT38@P00acW9BTU:@02:DX0
0b489BTQ20028@P00aBU48@<H`02248=12400`Q212448@07124224801`aS48@LibU:?NmF]Ekg009c
W009Kg]W>G>LOomg_F<H:DXLi`aS00<48@0424848@@Q124324800`0012448@0612401PQ21248@PQ2
1248@P848@0324848@Q200<48@0524848@Q2248<H`0224800a2436<aS002DY@01SF]5:D8@QcW:DXa
S09:DP07F]IF]E[FIcUF]DHa=Jd00S6<00<Lia24248010Q200<48@Q212400P@Q00D8@PaS48@@Q0aS
0088@P8<H`0348@<H`aS0088@P031248@PQ200848@@8@P0336<8@PQ20088@P8<H`099BTaS4HaG_MB
U36<7>L8@QBU008Q2009;F/YBSF]?Nle[Be[8@PHaQBU008@Q088@P848@88@P0648@HaQS67>L@Q0Q2
0`@Q00<8@P@Q12401P@Q00<8@P@Q12400PQ200<<H`Q224800PaS00LYBS6<DYAW>Dic?NlQ20026<H3
5:D01A245:DLiaS65:D00QS600LLiaBU5:DHaQcW8@PLi`065:D548@02QBU48@@Q1BU48@DYAS67>LH
aQBU0`aS00P@Q1BU48@DYAS67>LHaQ240QBU00DHaQBU6<HHaQcW008HaP045:DHaQBU5:D248@00aBU
48@@Q00248@00`aS48@@Q00348@236<45:D236<248@01QBU48@@Q0aS48@DY@8HaP0<5:D@Q1BU5:DH
aQBU48@<Ha245:D@Q1BU0Q2400@<Ha2436<<H`8@Q00336<@Q12400H@Q08<H`8@Q08DY@@@Q08DY@03
6<HDYABU008@Q08<H`03248<H`Q200D<H`0448@<H`aS36<348@010aS248<H`aS0Q240`aS00@8@PaS
2488@P8<H`@@Q00336<@Q124008@Q08<H`88@P0436<8@PaS248336<3248236<000@48@0300048@@Q
00@48@06248]Jekg@Q0]JcF]0Sg_00@e[C6<<H`aS0/icP8mk`8icP06?Nle[C6<<H`e[C6<0SF]00H]
Jc6<<H`e[C6<;F/3<H`00be[:DX]J`02<H`03CF]<H`icSW>?NlicSF]<H`icSF]>LhaS2e[008aS007
=JdaS36<<H`e[CW>=Jd00S6<00De[CW>?NlicSg_00TicP03=JdicSW>00TicP<aS009=JdmkcW><H`]
JbU:;F/e[CW>009240DicP03=JdaS2e[008]J`8YBP049BTYBRU:;F/2:DX2;F/2:DX3;F/00bU:9BTU
:@03;F/3:DX00c6<;F/]J`06:DX29BT012489BTU:BU:0bDY12U:12e[0RU:0RDY1BU:0bDY00TYBRDY
8@PQ22DY:DX]JbU:9BT00RU:00D]JbU::DXU:B4800@U:@8Q20037>LQ22DY008U:@048@PU:BDY:DX2
6<H324801@@Q248000@Q00000P@Q00<000@Q124010@Q00<000@Q12401P@Q00@8@P@Q36<<H`8HaP03
;F]245:D009_N`09Lia_NfmkKg]g_GooCW<aS0aS00D8@Pd48@0524848@@Q1248@P0512400`Q21244
8@02124010Q212448@@Q0PQ20PaS00X48BDYCW=Nmdic7>L8@QS67>LU:@92400<DYAF]EJeG_MF]Dic
@Q0mkc6<8@PDY@@Q0PQ200@<H`Q224848@88@P848@05248<H`aS36<8@P0336<248@01PaS2488@PQ2
1248@P8<H`03248<H`aS00<8@P0336<8@PaS008<H`036<HLic6<009Nm`04AS4YBPaS5:D27>L2:DX0
22e[<H`aS36<9BTLiaS648@336<424825:D26<H01A2436<8@P@Q24803@@Q10Q200/<H`Q27>LU:Dic
G_M>LdYB;F/HaQcW00@@Q0076<HDYAcW7>LHaQcW6<H00aBU0QS60QcW00@HaQBU5:DDY@<@Q0055:D@
Q1BU48@DY@0248@011BU48@HaQS60QBU0Q2400<DYA2448@00Q2400<DYAS66<H01ABU0aS600@LiaS6
5:DHaP<DY@0348@<Ha2400<@Q0065:D@Q12436<@Q1BU0a2400@DYAS65:D@Q08DY@<@Q00536<@Q124
5:DHaP035:D011245:DDYAS611BU112400<DYA2448@01`aS0a240QBU10aS00<DYA2448@00QBU1124
0QS600DDY@aS248<Ha2400@<H`04248<H`aS36<348@336<448@336<2248010aS248<H`Q20PaS00<@
Q0aS48@00Q240PaS00<@Q1BU48@00PaS0PQ200<<H`Q236<00`aS0`Q20@aS0@Q200000`0012400003
12400`0024848@0212403PQ2;F]W>Dic;F/icSg_>LhmkcW>=JdaS3F]>Lh2@Q000cg_>Lhmk`02=Jd0
136<>Lhmkcg_13W>0c6<00@e[C6<<H`e[@8aS0D]J`03:DX]Jc6<008e[@8aS003=JdicSg_008mk`8e
[@07<H`e[C6<=JdaS2U:<H`00Re[00@aS3F]?Nm2408mk`8icP04?NlicSW>=Jd5>Lh00cF]>LhicP02
>Lh0236<=Jd]Jbe[>Lhmkd8@?Nl2>Lh00cg_>Lhe[@03>Lh00cF]<H`e[@06<H`01cF]>LhicSW>=Jda
S2e[00@YBP@]J`039BTYBRe[00<aS003;F/U:BDY008U:@05;F/aS36<<H`YBP03;F/5:DX01RDY8@PY
BRU:<H`]J`@YBP07;F/U:B487>LQ22e[:DX00S6<0be[0RU:0RDY00<Q22DY9BT00bDY00@Q21cW8@PU
:@@YBP03;F/YBRU:008YBP09<H`e[BU:9BTLib489BTYBRDY008Q208Li`088@PLibU::DXaS3W>8@PD
Y@<8@QT48@0;36<@Q1cW7>LU:CF]BU9JeUJeHaQW>@02G_L02DYBAS4e[C6<7>L<H`Q21248@P0236<4
12400`Q212448@0412432483124010Q212448@@Q0`Q210@Q0`Q201048@Q236<@Q0@Q8@Q>Lf<HBU8H
aPQ25:DHaRU:<H`YBP8aS006>LhaS2U::DXLiaBU0a240PQ200@@Q1S65:D<H`848@0324848@Q20088
@P8@Q00336<8@PQ20088@P0636<8@PQ21248@PaS0`Q200<<H`Q224801@Q200<48@Q224800QBU00DY
BU:DE[E:DS6<0088@P085:DLicW>>LhU:AcW48@<H`8@Q0<<H`D8@P<<H`0424848@@Q1242248<1240
0`Q21248@P0524801b489BU>LfLiDYA:DRU:008HaP<DY@0448@DYABU48@45:D011S67>LDYABU0QS6
00HQ21cW7>LQ21S65:D248@011S65:D@Q1241ABU00@LiaS67>LHaP8@Q00336<@Q1BU00<@Q0035:DH
aQS600DHaP8Li`8HaP085:D@Q12448@DYAS65:DHaP8@Q0@<H`0548@<H`aS36<@Q0035:D248@020aS
5:DDYA2436<@Q0aS48@45:D00a245:DHaP037>L01aS648@@Q1245:D@Q1BU008@Q08DY@@<H`8@Q0@<
H`8@Q00336<@Q1BU008@Q00636<@Q12448@DYA240QS600<LiaBU5:D01`aS00@8@PaS36<<H`8@Q004
36<8@PQ236<548@436<2248536<248@01@aS48@<HaBU6<H00Q2400<<H`Q236<00`aS0PQ20PaS0PQ2
0`aS000312400`0012448@0512403`Q2:DYNmdHa=Je6<D8@?Nle[CW>?Nle[C6<=JdicP02@Q0013g_
=Jde[C6<1SW>00<mkcW>>Lh00c6<00D]JcF]<H`aS3F]008aS0<]J`8YBP03;F/aS3F]008aS005;F/i
cSW>?NlicP02=Jd013W><H`aS36<0SF]1C6<00PicT8@@Q0mkcW>=JdicSg_13W>00<e[CW>>Lh01CW>
00he[C6<<H`aS3F]>LhmkcW>?Nm243g_>Lhe[C6<0SW>00<mkcW>=Jd00c6<00Pe[C6<<H`e[CW>?Nli
cSF]1Be[0RU:00L]Jc6<;F/YBRDY:DX]J`02<H`00bU:9BTYBP02:DX2;F/00c6<;F/aS002;F/012U:
;F/YBRDY0bU:00<U:B489BT00Re[00LYBRDY9BT]Jc6<;F/U:@028@P29BT4<H`00bU:9BTU:@039BT0
1R48:DXU:BU:9BTLi`8Q20037>LU:BU:008]J`06:DX]Jc6<;F/YBRe[0S6<00DYBRDY:DXU:B48008L
i`8Q20059BTLiacW8@PU:@02<H`00b487>L@Q00236<00`Q212448@0212400`0012448@0512400`00
12448@08124324801ABU48@Libe[?Nl00U:D00aNme[FHaQW>Dic@Q0aS3F];F/HaPQ2124236<22483
124224841240100012448@@Q0`Q200<48@Q212401@@Q00@8@P@Q2488@P848@88@P0=36<8@PQ29BT]
Jd8@CW<aS1cW48@DYB48:DX00RDY00H]Jc6<<H`]JbU:7>L25:D248@01PQ2124<Ha246<H@Q0848@06
00048@Q2248<Ha240PaS00<8@PaS36<00PaS0`Q200L48@Q21248@PaS248<H`0624800`aS2488@P02
48@02RDY>Li6<E:D@Q0HaQBU36<8@RU:0SF]00@YBQ2448@DY@8<H`03248<H`aS0088@P031248@PQ2
0088@P031248@PQ200<8@PX48@@8@P<48@<8@P035:DHaT8@009BU006E[DicRDY7>LDYAS60QBU00@@
Q1BU6<HHaP8@Q08DY@8Li`076<H@Q1BU8@PU:Be[9BT00QS60aBU00<@Q1BU48@00Q2411BU0aS60aBU
0Q2400<<Ha245:D00QBU00@HaQBU6<HHaP8DY@8HaP057>LHaQBU48@DY@026<H00a245:DDY@025:D0
1@aS48@<H`aS48@00PaS0a2400<<Ha245:D00QBU0PaS00<@Q1BU5:D00Q2400@<HaBU5:DHaP8@Q007
5:DLiacW7>LDYAS65:D00Q240QBU0QS600@@Q0aS36<<H`8DY@0348@<H`aS008<H`8@Q0@<H`065:D@
Q1BU48@DY@aS0Q2400DDYAS67>LLiaBU008@Q0<<H`0348@<H`Q20088@P8@Q00336<8@PaS008<H`05
5:D@Q1245:D@Q00236<00`Q236<<H`0736<248@010aS48@@Q1240aBU00<<H`Q224800PQ200D<H`Q2
36<<H`Q200@<H`0000D000@Q12448@0000<48@0:248000@Q248aS6<HBU8]JcW>?Nl3@Q001cg_@Q12
43g_>Lhmkd8@008mk`07<H`e[C6<<H`e[C6<>Lh00SF]00HicSg_@Q0mkcW>?Nl2=Jd00cW>=JdicP02
=Jd032e[<H`]Jc6<=JdaS3W>?NlicSF]<H`e[@8icP8e[@8icP03=JdaS36<008aS003;F/aS3F]008e
[@03<H`e[CF]00<icP03=JdicSg_008mk`08>Lhmkcg_@Q0icS6<=JdicPHe[@03?NlicSW>008icP05
?Nm243g_>Lhmk`02>Lh3=Jd00cW><H`aS004<H`3;F/2<H`012e[:DXaS2e[0RU:00<]Jc6<;F/00RU:
0Re[00@aS2U:9BTYBP8]J`8YBP8]J`05<H`]Jc6<<H`]J`02:DX00be[9BTQ20028@P29BT00bU:9BTY
BP02;F/2:DX28@P00bU:;F/aS002<H`4;F/02RU:8@PU:BU:;F/YBR489BTQ21cW124800DU:BU:;F/]
JbU:00X]J`03:DXU:BDY008Q20089BTYBRe[:DXaS3F]:DXLi`<@Q00424848@@Q000412400`001244
8@0412400`0012448@0412400`Q212448@0224800`aS6<HLi`028@P012U:<Ha2448@0SF]00DQ21cW
5:DHaQ24008<H`05248<H`aS36<8@P0:124324831242248212401@001248@PQ212400PQ20P@Q0PQ2
00d<H`Q236<<HaS68@PYBS6<:DXHaQ24248@Q0025:D26<H00aBU48@DY@0248@00`aS2488@P032482
36<2248212401PQ21248@PQ236<8@P<<H`@8@P0336<8@P@Q00D8@P<<H`P8@P0:36<@Q1BU8@PU:Be[
9BTDYA24248248@00aBU36<@Q00336<00a245:D@Q00224800`@Q2488@P0412442485124010Q21244
8@Q210@Q1PQ200H<H`Q2248HaQcWBU82G_L015:D<H`LiacW0QBU0aS611BU0Q2400<HaQcW5:D00aBU
0QcW00@U:Be[7>LHaP8@Q0046<H@Q12448@36<H01QBU48@HaQS67>LHaP8DY@L@Q08DY@056<HDYABU
7>LHaP035:D01QS65:DDYA245:D@Q0DDY@<@Q00436<@Q1245:D348@25:D248@011BU48@DYA2410aS
0a2400<<HaBU48@011S600DDYAS66<HDYA2400@DY@<@Q00536<@Q1BU5:D@Q00236<00a2436<<H`03
36<01A2436<<Ha245:D00Q240PaS00<@Q1S65:D00QcW00<DYA2436<010aS00D@Q0aS36<8@PaS00<@
Q0@<H`035:D@Q1BU008@Q0H<H`04248<H`aS36<248@011BU48@<HaBU0QS600@<H`@Q2488@P<<H`03
248<H`Q20088@P<<H`0000<48@0012400P@Q00<000@Q12400`@Q00D8@Re[JeY>Lbe[008mk`06>Lhm
kd8@@Q16<D8@0SW>0cg_00Xe[CW>>LhicS6<;F/aS3F]>Lhe[@8icP@mk`8icP<e[@8icP04=JdaS2e[
=Jd2<H`3=Jd01C6<=JdicT8@?Nl00cW>13F]136<00@e[C6<<H`e[@<icP8mk`05>LhaS36<=Je24002
?Nl00d8@?NlicP03>Lh00cF]<H`aS003=Jd00c6<>LhicP02?Nl00d8@?NlicP04>Lh2=Jd00cW>=Jde
[@06<H`2;F/012U:<H`aS36<0bU:0be[00@aS2e[:DXYBP8aS004;F/YBR488@P2:DX5;F/00c6<;F/]
J`02;F/2:DX00bDY8@PQ20049BT2:DX01Be[<H`]JbDY:DX00RDY00@YBRe[;F/aS08]J`8YBP04;F/Y
BRDY9BT2:DX012DY8@PQ22480QcW00LQ22DY:DXYBRe[<H`]J`02:DX01be[<H`]JbU:;F/aS2e[00<Y
BP@Q208YBP06;F/aS2U:9BTHaQBU0PaS00<8@P@Q124020@Q00<000@Q00002`@Q00<8@Q2448@00QS6
00DLibDY;F/icSF]008icP039BTQ21BU008DY@0748@8@PQ2248<Ha2436<00`@Q00@8@P@Q12448@<8
@P051248@P@Q1248@P05124324841244248436<248@01bDY<H`aS2U:6<H8@PaS008@Q0036<HDYABU
008DY@046<HDYABU36<3248436<4248212401@Q236<<H`aS24800PaS1PQ200<48@Q224800PaS00<8
@PaS24800PQ200@48@Q22488@P<<H`08248@Q1S69BT]JbDY6<H@Q08<H`0348@<Ha2400<<H`0348@<
H`aS008@Q08<H`<48@88@P<48@0324848@@Q00<8@P<48@0324848@@Q00H48@H8@P0<48@<Hc6<BU9N
mfLi@Q0YBR485:DHaQcW11BU00<@Q1BU48@00QBU00DHaQcW6<H@Q1BU008@Q0048@PYBRe[8@P248@2
5:D348@00aBU48@DY@035:D36<H348@25:D01A2436<<Ha245:D011S600@DYAS65:DDY@8@Q0055:D@
Q1245:D@Q0035:D236<00a245:D@Q00348@011BU48@DYABU0a240QBU00D@Q0aS48@@Q1BU008@Q08<
H`8@Q0035:DHaQBU008DY@<HaP<@Q0035:DHaQ2400P@Q0<<H`0348@<H`aS00@<H`H@Q00636<@Q124
5:DLiaS60QBU20aS00<@Q0aS36<01@aS0Q2400<DYA2436<00PaS00<@Q0aS48@00`aS0PQ200@<Ha24
48@DY@8@Q08HaP035:D@Q0aS008<H`<8@P0348@<H`aS008<H`48@P4<H`4<H`000`@Q00<000@Q1240
0P@Q00T8@P@Q000<HcF]Kg]BU2e[>Lh00d8@0cg_00M244Ha@Q1243W>?Nm24002>Lh0136<;F/aS36<
0SF]00hicSF]=JdicSg_@Q0mkcW>?NlicSF]<H`e[CW>0Sg_00@icS6<<H`aS08e[@03>LhmkdHa0092
408mk`03>Lhmkc6<00<e[@04?NlicSW>=Jd3<H`2;F/0136<>LhicSg_0SW>00<e[CW>>Lh00cW>13g_
0cF]0S6<0SF]13g_0SW>0cg_00@e[CW>=JdicP8e[@DaS08e[@8aS005;F/aS2e[<H`YBP029BT01be[
<H`aS2e[:DX]JbU:00<]J`04:DXU:BDY:DX4;F/2:DX00be[:DX]J`02<H`2;F/3:DX01BDY8@PU:BU:
9BT01BU:0Re[12U:00@]JbU::DX]J`/YBP067>LQ21cW8@PU:B480RDY0RU:00DU:C6<>LhaS2DY008Q
20@]J`05:DXQ22488@PYBP02<H`2;F/022DY8@PLib486<H@Q0Q200031240100012448@001P@Q00<0
00@Q12400P@Q00<000@Q248010Q200@<Ha245:DDY@8@Q0046<HLiacW5:D236<25:D00a2436<<H`03
24800`@Q24848@0312432487124010Q21248@P@Q0PQ20`@Q10Q200<<H`Q212400PQ21@aS00PDYAcW
8@PYBR485:D<H`Q20PaS00<8@PaS48@00QBU00<@Q0aS36<00`Q20`@Q0`Q20`@Q00D8@PaS36<<H`Q2
00<<H`88@P061248@PQ236<8@P@Q1@Q200D<H`Q21248@P@Q0088@P081248@PQ21248@Q245:DLi`8H
aP0448@<Ha2436<2248336<00`Q236<<H`0236<01`@Q24848@@Q24848@Q200<48@0824848@Q21248
@P@Q000<H`8DY@0424848@@Q36<724801PaS24848ABU8@Q>L`9F]@05G_M242U:6<H@Q0026<H35:D0
0a245:DDY@055:D02AS65:DHaQ2436<LibDY:DXU:@035:D00a245:D@Q0045:D348@03QBU6<HDYABU
48@<Ha2436<@Q0aS48@<Ha245:D37>L448@01AS648@@Q1245:D00a2400<DYA245:D01ABU00<@Q1BU
48@00QBU00@@Q1BU6<HHaP8@Q0075:DHaQS65:D<Ha2436<00Q2400<<Ha2448@0112400LDYAS66<HD
YA245:DHaP025:D948@00`aS48@<H`0248@636<448@25:D01Q2436<DYAS67>LHaP8@Q0@<H`0348@<
H`aS008<H`8@Q0035:D@Q0aS008<H`<@Q005248<H`aS36<8@P0236<01a2436<<Ha2436<@Q0aS008@
Q0036<HLiaBU00D<H`<8@P8<H`<8@P8<H`000P@Q00<000@Q12401P@Q00D8@SF]LiaF]C6<008mk`03
>LhmkcW>008mk`=24004?Nm243W>>Lh2?Nl013W>=JdaS2e[0S6<00Te[CW>>LhicSg_>LhmkcW>?Nl0
13W>00<mkcW>>Lh00cF]00DicSF]<H`e[CW>00924005?Nm2448@@Q0mk`02>Lh013F]>LhicSW>0SF]
0c6<00@]Jc6<<H`e[@8mk`<icP08<H`icSF]?Nm243g_@Q0mk`8e[@8icP07=JdaS2e[<H`mkcW>?Nl0
0SW>00<e[CW>?Nl00Sg_00DicSF]>LhicS6<00<e[@HaS008;F/YBRe[<H`]JbU:9BTYBPH]J`8YBP06
;F/YBRDY9BTYBRe[1RU:0Re[00HaS2e[;F/aS2U:;F/69BT02bU:;F/]Jbe[9BT]Jc6<;F/YBR489BT0
0be[00XaS2e[:DXYBRDY:DXU:BU:;F/YBP<U:@@Q208Li`068@PU:BU:9BTYBS6<0Re[00<U:BU::DX0
0RU:0Re[00DU:B489BTU:CF]008aS003:DXU:BDY008Q20035:D<H`Q200d48@0300048@@Q00@48@03
00048@@Q0088@P@<H`0548@DYA246<HLi`026<H548@01QBU48@8@P@Q248<H`88@PD48@88@P@48@88
@P<48@0324848@@Q00848@0324848@@Q00<<H`L8@P8<H`8@Q0066<HLiacW8@PHaPaS0PQ20PaS00D8
@Q246<HLiaBU00848@D8@P081248@P@Q24848@Q21248@P8<H`T8@P848@88@P071248@PQ224848@Q2
36<00PQ200<48@Q224800`Q20`aS00@DYAS65:DHaP8<H`<8@P0336<@Q0aS0088@P8<H`88@PL48@03
24848@@Q00@8@P848@8<H`035:D@Q0@Q00<8@P848@@8@P0336<8@PQ2008<H`08:DY245JeJeY>LcF]
9BTDY@8HaP055:D@Q1245:D@Q0055:D02Q246<HHaQBU48@<HaBU6<HYBRDY0QcW00@DYA245:D@Q0LD
Y@8@Q0045:DHaQBU5:D236<00a2436<<H`0248@36<H35:D00aS65:D@Q00448@03ABU48@DYABU36<8
@PaS48@HaQBU48@DYA2400<DY@0348@DYAS600@DY@8HaP8DY@0548@<Ha2448@<H`0448@00aBU48@@
Q0026<H248@00aBU6<HDY@0236<25:D336<01Q245:D@Q12436<@Q08<H`0348@<Ha24008<H`0348@<
H`aS00@@Q00936<DYABU5:DHaQBU6<HDYA2400<<H`0548@<H`aS48@<H`025:D248@00`aS248<H`02
48@236<624800`aS48@@Q00248@01PaS48@<HaBU6<HDY@8HaP0336<8@PQ2008<H`88@P8<H`@8@P4<
H`0000L000@Q12448@0012400002248020001248@SW>LiaBU36<?Nl2@Q000cW>?Nm24002?Nl3@Q00
0cg_@Q124002?Nl2=Jd3>Lh2=Jd0136<=JdicSW>0Sg_00<icSg_>Lh01CW>00=243g_?Nl00SW>00=2
43g_?Nl00cW>00<mkcW>>Lh00cW>00PaS3W>?Nm243F]<H`e[CW>1c6<00De[CW>=JdicT8@008icP03
=JdicSg_00<icP05=JdaS36<;F/aS002=Jd01cg_AS4mkcW>=JdicSg_00DicP<e[@06<H`e[CF]<H`e
[C6<0cF]0S6<0be[0S6<00@]JbU::DX]J`8YBP049BTYBRU:;F/4:DX2;F/01bU:9BTYBRDY;F/aS3F]
00@aS004;F/YBRDY9BT3:DX29BT00bU:;F/]J`02;F/2<H`012U:9BTU:BU:0Re[1BU:1BDY0RU:0RDY
0R480bDY0b4800<U:BU:9BT012DY0R4800<U:BU:;F/01BU:0be[0RU:00<Q21S648@01`@Q00@000@Q
124000P48@0324848@@Q00<48@03248<Ha24008@Q08<H`04248<H`aS36<248@01PQ2124HaSF]?NlU
:@848@0336<48@@Q00@48@88@P@48@88@P031248@P@Q00@48@0424848@@Q248212400`Q21248@P03
36<524801@@Q248<H`aS48@00QBU0R4800<Lia2424800PQ20PaS00<8@P@Q24800`Q210@Q0PQ200@<
H`Q224848@H8@P0336<8@PQ200X8@P0536<8@PQ224848@032485124436<00`Q236<8@P0236<22480
11246<HHaPaS0P@Q0PaS00<8@P@Q12401@@Q0`Q210@Q00D8@P@Q1248@PaS0088@P@48@<8@P041248
@PQ236<2248248@023W>@Q1F]F]JDY@e[B4848@55:D248@00`aS5:DDY@0448@011BU48@@Q1BU0Q24
00/LibU::DXU:AS65:DHaQ245:D@Q1BU00@@Q0035:D@Q1S6008HaP045:D@Q0aS36<448@35:D00acW
6<HDY@025:D011cW6<HDYABU0Q240PaS00<@Q1BU48@00a240QBU0a2400<HaQBU5:D011241ABU00L@
Q0aS36<<Ha245:D@Q0025:D00aS65:D@Q00248@25:D348@00aBU48@@Q00848@236<00`Q236<@Q002
48@236<00a245:D<H`0236<00aBU48@@Q00448@011BU6<HHaQS60`aS0QBU00d@Q0aS248@Q0aS48@D
YAS65:D@Q0Q236<@Q00236<3248436<00`Q236<<H`0436<01Q247>LQ21cW48@8@P<<H`<8@P8<H`04
24848@Q236<124800004124000@Q000712401`Q2=JecW5Je<H`mkd8@008icP924003?NlicSW>00=2
4003?Nm243g_008mk`<icP8mk`05>Lhe[CF]>Lhmk`05>Lh2?Nl2=Jd013W>?Nm243g_0cW>0Sg_00@i
cSF]?Nm240<icP05?Nle[CF]=JdicP02?Nl2>Lh00c6<=JdaS005<H`00be[=Jde[@03?Nl02CW>=Jdi
cSW>@Q0mkcW>=Jd]J`05<H`013W>?Nm243g_1SW>00<mkcW>=Jd00SF]00DicSF]<H`e[C6<008e[@03
>Lhe[CF]00<aS08]J`04:DX]Jbe[;F/4:DX01Be[:DXYBR489BT00RU:0S6<00@]JbDY8@PYBP<]J`8a
S08e[@03;F/YBRDY00<U:@8YBP039BTYBRe[00D]J`07<H`]JbU:9BT]Jc6<;F/00RDY00<]JbU:8@P0
0RU:00@]JbU:9BTU:@8YBP049BTQ22488@P39BT28@P59BT012489BTU:BU:0be[00@YBRDY9BT]J`8a
S006;F/U:Be[9BTLia240PaS0`@Q00<000@Q124020@Q00H000@Q12448@001242248312401A245:DD
YABU36<00PQ200@<Ha2436<<H`848@0636<U:C6<9BT<H`@Q0PQ20`@Q00<8@P@Q248010@Q0PQ200@4
8@Q21248@P848@88@P@48@0424848@@Q248236<010Q236<<H`aS0`Q200P<H`Q22488@Q2436<@Q1S6
0R4800DHaPaS36<8@P@Q0088@P0436<8@PQ212442482124010Q21248@P@Q10Q20`aS0PQ200@<H`Q2
24848@D8@P0336<8@PQ200<8@P0336<8@PQ200<48@@8@P051248@PaS36<@Q00436<01P@Q248DYAS6
5:D8@P@48@0336<8@P@Q00<48@0524848@@Q1248@P021244248212400`aS24848@03124424800`@Q
248@Q00236<224801b48;F]>LfLiE[E6<C6<00HDY@8@Q0035:D@Q0aS008@Q0036<HDYA2400@@Q005
36<LibDY;F/YBP026<H55:D248@011BU48@DYABU0QS600D@Q1BU5:D@Q1BU00<@Q08DY@0548@HaQBU
7>LHaP035:D27>L01ABU48@@Q1245:D01A240aBU0Q2411BU0Q2400@DYA245:D@Q0<DY@<@Q0035:D@
Q12400H@Q0<DY@<@Q0035:D@Q12400@@Q0<<H`0348@DYA2400<<H`H@Q08<H`0348@<Ha2400<@Q004
36<@Q1245:D36<H:48@00`aS48@DY@0248@236<00a2436<<H`06248336<02PQ236<<H`aS248@Q1BU
7>LHaQ241@aS00P8@PaS248<H`Q236<8@PaS0@@Q000412403`0012448@@Q248000@Q248]Jf]JDY@e
[DHa@Q0mk`02>Lh01Sg_@Q0mkcg_>Lhmk`<icP8mk`8icP0;<H`e[CW>=JdaS3F]>LhmkcW>?Nm24002
?Nl00cW>?NlicP02>Lh01D8@BU9:DT8@>Lh00Sg_00M243W>?NlicSF]>Lhmk`03>Lh5=Jd6>Lh2=Jd2
;F/03C6<>Lhe[CF]<H`e[CW>=JdicT8@AS5243W>00@e[@03<H`]Jbe[008aS005=JdicSW>?Nm:DP02
AS400cg_>LhicP03>Lh00cF]>LhicP04>Lh2=Jd2<H`00cF]<H`aS002;F/01S6<;F/YBRDY8@PU:@DY
BP04;F/YBRe[<H`2;F/3:DX00bDY;F/]J`04;F/2:DX00be[:DXU:@028@P39BT012489BTYBRe[136<
1Be[0bDY00HYBR488@PLibDY:DX29BT00bU:9BTQ20028@P39BT2:DX022487>LLibU:;F/U:AcW8@P8
9BT2:DX00be[:DXU:@029BT01B485:D<H`@Q24801P@Q00<000@Q12400`@Q00D000@Q12448@0000P4
8@0736<DYAS68@PDYA2424800P@Q10Q20`aS0PQ20P@Q0`Q20`@Q00@8@P@Q2488@P<48@0524848@@Q
1248@P07124010Q212448@@Q30Q200H48@Q236<<Ha2436<248@236<212442485124324800`@Q2488
@P08248236<3248336<00`Q236<<H`0236<224801@aS24848@@Q248010@Q0PQ200<48@Q224800`Q2
00@<H`Q22488@P8<H`<8@P0436<8@P@Q248512400`Q21248@P0:1242248512422483124724802B48
:DY:DUkgDYA6<BU:48@HaP0548@25:D00a245:D@Q00248@25:D248@25:D020aS6<HYBS6<;F/HaQBU
6<H25:D248@25:D00a245:D@Q0025:D00a245:DHaP025:D01A2436<<Ha2436<00Q2400@HaQcW7>LL
i`<HaP0448@DYABU5:D26<H25:D248@25:D00a245:DDY@0:48@25:D748@35:D00a245:D@Q0026<H2
5:D01Q2436<DYABU48@DY@@@Q0<<H`8@Q0@<H`0348@DYABU008@Q0<DY@0348@<Ha2400<@Q00636<@
Q0aS48@DYA240QBU0QS600<DYA2448@01@aS00L@Q1BU5:DDYA2436<@Q00336<3248336<00`@Q2488
@P0236<01PQ236<@Q1245:D@Q0<DY@0348@<H`Q200<<H`0348@<H`Q200@8@P000P@Q00<000@Q1240
1P@Q00/8@Re[IcU:DSF]@Q16<D8@?NlicT8@008icP8mk`8icP8e[@04?NlicSW>>Lh2<H`013F]<H`e
[CF]13W>0cg_0SW>00<mkcW>>Lh00d8@00M6<CW>>LhicSg_AS4mk`03=Jd01CW>?NlicSF]<H`00SW>
0SF]0S6<0SF]00DicSF]>Lhe[C6<008]J`08<H`e[C6<<H`e[CW>=Jdmk`924003?NlicS6<00<aS004
=JdaS36<;F/2<H`013W>=Jdmkd8@0THa00E243W>>LhicSg_008icP04=JdicSW>>Lh2=Jd01SW><H`a
S36<>LhaS08]J`03<H`e[C6<008YBP8U:@03:DXU:BDY00<YBP039BT]Jbe[008]J`8U:@8YBP8]J`03
<H`]JbU:00<]J`05:DXU:BU::DXU:@038@P00bDY:DXYBP03:DX3;F/00c6<;F/]J`03:DX012DY8@PQ
22480RDY0RU:0bDY0RU:12DY0RU:0b4800@U:BU:9BTQ208U:@<Q20<U:@8Q208YBP07;F/U:BDY;F/U
:AcW48@00PaS00<8@P@Q12400P@Q00D000@Q00048@0000D48@0500048@@Q1248@P05124224801A24
7>LLiaBU36<00P@Q0PQ200L<H`@Q2488@Q2436<8@P031242248412401PQ21248@PQ21248@P848@@8
@P848@0300048@@Q00<48@0324848@@Q0088@P0536<8@PQ224848@0624800`aS48@<H`0536<42480
0`@Q24848@0324800`@Q2488@P022482124010Q21248@P@Q20Q200<<H`Q224800PQ20`aS0PQ20PaS
0PQ200<48@Q2248020@Q1@Q200<<H`Q224800`Q200@<H`Q22488@P848@0324848@Q200T48@032484
8@@Q00848@<8@P<48@0324848@@Q00848@88@P8<H`0>248<H`Q2248DYAcW=Je:DTHaBU8icR486<H@
Q08DY@8@Q00336<@Q1BU008DY@@@Q0035:D@Q124008@Q0035:D@Q248008]J`039BTDYA24008DY@<@
Q0045:D@Q1BU5:D248@25:D26<H448@01ABU48@@Q1245:D00QcW0QS611BU00<HaQBU5:D00QBU0a24
1QBU11240PaS0a2400<DYA245:D021241ABU00<HaQBU48@00QBU00<@Q1BU48@00Q2400<DYA2436<0
0PaS00@@Q0aS36<<H`D@Q0035:D<H`aS008DY@0348@<Ha24008DY@0448@<H`aS36<448@00aBU6<HH
aP025:D348@436<00a245:D@Q00448@236<00`Q236<8@P0324800`aS2488@P0336<22480212436<<
HaBU6<HDYA24248436<01A2436<<H`Q212400PQ20000100012448@000P@Q00<000Q212400P@Q00P8
@Re[HaQ6<C6<@Q1>LdYB0THa00=243g_?Nl00SW>00Dmkd8@>Lhe[C6<008e[@<aS08e[@8icP06=Jdi
cSg_AS5243g_0SW>0T8@0SW>00Pe[Cg_?Nlmkd8@?Nm6<DYB0T8@0SW>00@mkcW>>Lhe[@8icP<e[@8a
S0<icP05=JdaS36<=Jd]J`05<H`2>Lh2@Q02>Lh00cF]>Lhe[@04<H`013F]>LhaS2e[0RU:00DicT8@
AS5:DTHa009240@icP8e[@03<H`e[CW>00@icP03=JdicSF]008aS004;F/aS36<<H`2;F/2<H`00bU:
9BTU:@02:DX29BT4:DX00bDY;F/]J`02<H`2:DX29BT5:DX39BT2:DX29BT01B489BTYBRU:=Jd00S6<
00D]JbU::DX]Jc6<008]J`05:DXU:BDY8@PU:@02:DX39BT00bU:;F/YBP029BT3:DX29BT3:DX01BDY
8@PLib489BT00RU:00DQ22DY8@PQ22DY008Q208U:@8YBP069BT]Jb486<H<H`Q210@Q00<000@Q1240
2`@Q00<8@P@Q00001P@Q0`Q200<<H`Q224800PQ20`@Q0PQ200H<H`Q22488@P@Q2483124624831243
248412400`Q21248@P09124224801@@Q2488@PaS24800P@Q0PQ200<<H`Q224800`aS10Q200L<H`Q2
2488@P@Q24848@0224800`@Q2488@P022482124224801@@Q2488@P@Q24800`aS0PQ220aS0`Q200<<
H`Q212400P@Q0PQ210@Q00@8@P@Q2488@P<<H`L8@P<48@<8@P@48@88@P031248@P@Q00@48@032484
8@Q200<48@88@P031248@P@Q00<48@P8@P04124DYABU<H`2BU80148@9BTHaQcW0QBU00<@Q1BU5:D0
0a2400<DYA2448@00QBU00D@Q0aS36<DYA24008DY@0548@LibDY:DXQ200248@45:D248@01QBU48@@
Q1BU48@DY@8HaP035:D@Q0aS008@Q00336<DYA2400@DY@<HaP8DY@8@Q0<DY@0348@DYABU00<HaP03
5:D@Q1BU00<DY@0348@DY@aS00<<H`<DY@H@Q0035:D@Q1BU00<@Q0075:DHaQS66<HDYA245:D00aS6
1Q241@aS00@DYA2436<@Q08DY@8@Q0035:D@Q124008<H`H@Q00436<@Q1246<H35:D548@236<348@0
0`aS48@@Q00348@336<010Q236<<Ha240PaS0`Q20PaS00<@Q0aS36<00`aS0Q240PaS0Q2400@<H`Q2
2488@P8<H`<8@P0000<48@0012400P@Q00`000@Q1248@P001248@S6<G_M6<Be[@Q02BU82AS42@Q02
?Nl00d8@>Lhe[@02=Jd2>Lh01CF]<H`aS36<=Jd00SW>0S6<018e[Cg_AS5243W>?NlicSg_@Q0mkcW>
?Nm243g_>Lhmkd8@AS42@Q000dHa?NlicP03>Lh3=Jd2>Lh3<H`2=Jd2>Lh00cF]<H`aS002<H`00be[
<H`aS003=Jd02Cg_@Q0mkcg_<H`e[CW>=JdaS002;F/01S6<=JdaS36<;F/YBP8e[@07@Q16<DYBBU92
43g_=Jd00cW>0SF]00<icSg_?Nl00SW>00<mkcW>>Lh00SF]00<aS2e[;F/00S6<0be[00DaS2e[;F/Y
BRe[00/YBP04;F/aS2U::DX29BT2:DX2;F/02bU:9BTYBRe[:DXU:B487>LU:BU:;F/00c6<00P]JbU:
9BT]Jc6<=JdaS2U:0bDY00@Q22DY9BTU:@8Q2003:DX]JbU:00<U:@<YBP<U:@8YBP048@PLib488@P3
9BT01AcW8@PQ22489BT00R4800PU:BU::DXU:BU:8@PLiaBU0PQ210@Q00<000@Q12400`@Q00@000@Q
124000/48@0324848@Q200<<H`041248@PQ2248312401@aS24848@@Q248010@Q0PQ200<48@Q21240
0PQ20P@Q0`Q22P@Q00<000@Q00000`@Q00<8@P@Q12400`Q20`@Q1PQ20PaS10Q200<<H`Q224800P@Q
0`Q20P@Q10Q200<48@Q236<00`@Q0PQ200L<H`Q2248<H`Q236<8@P0;36<224800`@Q2488@P041240
0`Q212448@021243248010@Q2488@PaS1`Q210@Q00D8@P@Q12448@Q200`48@0324848@Q200L48@05
24848@Q224848@03248248@02bU:>LhicT8@;F/LiaS65:D@Q1S65:D00Q2400D<HaBU5:D@Q0aS00<@
Q00@36<@Q0aS48@DYA2436<HaRDY;F/U:AS648@DYAS65:D448@35:D248@011BU6<HDYA240`aS00@@
Q1BU5:DDY@<@Q0035:DHaQS6008HaP8DY@8@Q0045:DHaQBU48@25:D27>L00aS65:D@Q0035:D336<2
48@25:D648@25:D248@25:D011245:DDYAS60QBU00@@Q1BU5:DHaP8DY@H@Q0@<H`@@Q0035:D@Q1BU
00D@Q08<H`0348@DYAS6008DY@0336<@Q1BU00<DY@037>LHaQ24008<H`<@Q00536<@Q0aS248<H`03
48@336<010Q236<<H`aS0`Q20`aS10Q200<<H`Q236<00a241PaS00<8@PaS36<00PQ20@aS0@Q20003
12400`0012448@0212402PQ2124000Q2<Ha[FTic;F/icT8@0cW>00=243g_@Q00148@0SW>00<aS2e[
<H`01CF]13W>00He[D8@BU9:DT8@>Lh2@Q000cg_=JdicP02?Nl2>Lh00cg_@Q124004@Q0023g_>Lhi
cSg_@Q0icSF]<H`4=Jd00c6<>LhicP02>Lh0136<=Jde[CF]0S6<00D]Jc6<>LhicSg_008e[@<mk`8a
S005;F/e[CF]<H`]J`02:DX00be[<H`e[@03>Lh01cg_@Q0icSW>=JdicSF]008]J`03<H`icSF]00Le
[@03<H`]Jbe[008aS003=JdaS2e[008aS009=JdicSF]<H`]JbU:;F/YBRDY008YBP8aS003;F/YBRDY
00<YBP8U:@04;F/YBRU::DX3;F/2:DX38@P49BT3;F/02RU:;F/aS36<;F/YBR489BTQ22DY0bU:0RDY
00@]JbU:9BTQ208U:@8Q20037>LQ22DY008Q20087>LQ22489BTYBRe[:DXQ20@Li`8Q208U:@038@PL
iacW00<Q20035:D8@PQ200L48@0300048@@Q00P48@0500048@@Q1240000312400`Q212448@051242
24800`@Q24848@032484124724801@@Q2488@PQ2124010Q210@Q00<000@Q12401`@Q10Q200@48@Q2
2488@P<48@88@P0:1248@P@Q24848@Q236<8@PaS124724801@aS24848@@Q248010@Q00@8@P@Q2484
8@<8@P0336<8@PaS00H8@P8<H`88@P0436<8@PQ2248:1242248336<7248010@Q24848@Q21@@Q00<8
@P@Q12403@@Q00<8@P@Q12400`@Q00D8@P@Q24848@Q200848@88@P0:1248@Q2448@]JeJeG_M:DRDY
48@27>L00aS648@@Q00248@45:D448@04QBU36<<Ha245:D@Q0aS5:DQ22e[:DXHaQ245:D@Q1S67>LH
aP8DY@0636<@Q1BU48@DYA241ABU00<@Q1BU48@00Q240QBU0Q2400<HaQcW7>L00Q240QBU112400<D
YAS66<H01AS60QBU00<@Q1BU36<00PaS00<@Q1BU48@00Q2400<DYA245:D00QBU00@@Q0aS36<<H`<D
Y@036<HDYABU00<DY@8HaP057>LHaQBU5:D@Q0025:D248@00`aS48@<H`0236<011245:DDYA240PaS
0aBU0`aS00<@Q1BU6<H011BU0a240aS600HDY@aS36<@Q0aS48@436<348@00aBU48@@Q00336<01PQ2
36<<H`Q236<8@P8<H`88@P0336<8@PaS008<H`055:D@Q0aS248<H`0248@736<2248000848@040004
8@@Q000512401@aS<Ha_Ndic;F/00Sg_0SW>0Sg_00=243g_@Q000d8@00<icSF]=Jd00SF]00<aS3F]
=Jd00cW>0SF]0SW>0d8@00=6<D8@@Q001Cg_0cW>13g_0dHa1Cg_00<icSF]<H`013F]00<icSF]=Jd0
0SF]0cW>136<00/e[C6<=Jde[CW>?NlicSg_>Lhe[C6<00<e[@03<H`]Jbe[008YBP03<H`]JcF]008i
cP8mk`0>@Q0mkcW>=JdaS3F];F/YBRe[=Je243g_=JdaS08e[@05>LhaS36<;F/aS003=Jd2;F/013F]
>LhicS6<0SF]00@aS2e[:DXU:@8YBP8aS004;F/YBRU:9BT2:DX012DY:DXU:BU:0be[00<YBS6<;F/0
0RDY00<Q22DY8@P00R4800@U:BU:;F/]J`8YBP03;F/aS2e[00<YBP<U:@07:DX]JbU::DX]JbU:9BT0
0R480RDY00DQ21cW8@PQ22DY00<Q20<U:@038@PU:BU:00<Li`8U:@8Q208U:@DQ20036<HDY@Q200T4
8@0300048@@Q00<48@0300048@0000D48@0300048@Q200D48@<8@P@48@0324848@@Q00<48@@8@P03
1248@PQ200<8@P031248@P@Q0088@P@48@0324848@@Q00`48@H8@P848@<8@P848@0324848@@Q0088
@P0336<8@PQ20088@P848@<8@P@48@88@P@48@0524848@Q224848@0724800`aS248<H`0236<42480
1PaS2488@PQ21248@P@48@0324848@@Q0088@P0336<8@PaS00<8@P031248@PQ20088@P<48@<8@Pd4
8@88@P031248@P@Q00@48@88@PD48@D8@P0736<8@RU:BU9JeU:D;F/00QcW00@HaQBU5:DDY@@@Q0DD
Y@0548@<H`aS48@<H`0348@25:D02B48:DXU:AcW5:D@Q1BU6<HDY@0248@55:D348@25:D448@25:D3
48@46<H031cW5:D@Q0aS48@DYA245:D@Q1BU6<HLi`@HaP<DY@0348@<Ha2400@@Q00:36<@Q1BU6<HD
YA2436<@Q1S65:D236<00a246<HDY@035:D00a245:DDY@036<H00aBU6<HHaP0548@00`aS248<H`02
48@25:D448@35:D336<01a245:D@Q1S67>LDYA24008<H`055:DHaQS65:D@Q00336<0112436<8@PaS
0Q240PaS00D@Q1BU48@<H`Q200H<H`03248<H`aS00@<H`0448@<H`aS48@25:D00a242488@P0736<1
248112412480000300048@@Q00D48@09248000@Q248e[FmkE[D]JcF]00Dmk`@icP<mk`03>LhaS3W>
00LicP<e[@8icP03?NlicSW>008icP<mk`A2400:>Lhe[CF]>Lhmkd8@?Nm243g_>Lh2?Nl2@Q02>Lh3
=Jd3>Lh2=Jd00cg_@Q0icP02<H`01cF]>Lhmkd8@?NlicSg_00<icP0=<H`e[C6<=Jdmkd8@>LhaS2DY
:DXaS2e[<H`00SF]00<aS3F]=Jd00SF]136<00<]Jc6<<H`00SF]00@aS2e[<H`aS08e[@03<H`]JbU:
008]J`@e[@@icP03=Jd]Jc6<00<]J`05<H`]JbU::DX]J`02<H`00be[9BTYBP029BT01Be[<H`aS36<
;F/00bU:00<]JbDY8@P01R4800@YBRDY:DXYBP8]J`8YBP8U:@03:DXU:BU:00<YBP039BTYBRU:008Y
BP069BTLib488@PU:B481acW00@Q22DY;F/YBP8U:@@Q20077>LU:BDY8@PLiaS67>L00R4800<HaPQ2
24800P@Q00D8@P@Q12448@0000h48@0300048@@Q00@48@0500048@@Q00048@022482124324821242
24851246248212400`Q21248@P081240100012448@002@@Q10Q20P@Q0PQ210@Q10Q20P@Q0PQ21P@Q
10Q210@Q00@8@P@Q24848@<8@P0336<8@P@Q00H8@P031248@PQ2008<H`<8@P031248@P@Q00<8@P06
1248@PQ236<8@PaS0Q242@Q20P@Q00P8@P@Q12448@Q2124000@Q0PQ21`@Q00<8@P@Q12400P@Q00<<
H`Q224800PQ20P@Q00<8@P@Q24800`@Q0`Q200T48ABU7>M246LiF]I6<BU:48@00QBU00<@Q1BU5:D0
1ABU00P@Q0aS48@@Q1BU48@DYA240QBU00L@Q0aS5:DHaQcW8@PLi`025:D00a245:DHaP026<H011BU
48@@Q1BU0QS600<DYA245:D00aBU0Q2411BU0Q240QBU0aS600@DYAS65:D@Q08DY@<@Q0035:DHaQS6
00PDY@0748@<Ha2448@DYAS65:D00Q2400@DYA2448@DY@<@Q00336<@Q1BU00@DY@0348@DYABU008H
aP055:DHaQS65:DHaP025:D548@236<348@336<011245:D@Q1240PaS0a2400HDYAS65:D@Q0aS48@5
5:D436<01a2436<<H`aS248<Ha24008<H`<@Q00336<@Q124008<H`05248<H`aS36<8@P0236<00a24
36<<H`0236<348@01@aS248<Ha245:D00PaS00@8@Q242488@P448@0000D48@0012448@0000<48@08
24848@@Q248e[G>LDY@aS0924003?Nle[CW>00<icP04?NlicSW>>Lh2=Jd:>Lh00cF]>LhicP03>Lh0
2CF]>LhicT8@>LhmkcW>?Nm24003?Nl01SW><H`icSW>@Q16<@8mk`07>Lhmkd8@?NlicSF]>Lh00cF]
0SW>0SF]00@icSg_?NlicP8aS08icP92408mk`@icP04=JdaS36<>Lh2?Nl00cF]:DX]J`02;F/6<H`2
=Jd01c6<=Jde[C6<=JdaS2e[008aS005=JdaS36<<H`e[@02<H`2:DX2;F/00cF]<H`aS002>Lh013F]
>LhicSW>0S6<00D]Jc6<<H`aS2e[00<YBP8aS08]J`8U:@<]J`03:DX]Jbe[008]J`06<H`YBRDY9BTQ
22DY0R480RDY00HQ22DY9BTU:Be[<H`2:DX012DY:DX]JbU:0RDY00<YBRe[;F/012U:0bDY12481QcW
0bDY0RU:00HQ21cW7>LQ22DY8@P39BT022487>LDYAcW8@PLiaS636<412400`0012448@0512400`00
12448@0512400`0012448@0812400`Q212448@04124224801@aS24848@@Q24800P@Q00@000@Q2484
8@<8@P051248@PQ21248@P0212401@Q212448@@Q24803@@Q0PQ200H48@Q21248@P@Q248212400`Q2
12448@0224821245248010@Q2488@PaS10@Q00<8@P@Q12400`@Q00@8@P@Q12448@88@P041248@PaS
36<4248010@Q24848@Q20`aS0PQ200<48@Q212401@Q20`@Q00P8@PaS36<@Q0aS48@<H`Q20P@Q00@8
@PaS2488@PL48@0324848@@Q00848@0324848@Q200L48@0724848@Q21248@P@Q24800P@Q00D8@P@Q
2488@P@Q00<8@P08124@Q124=JeF]E[FDY@]J`8HaP085:D@Q1BU5:DHaQBU48@DY@P@Q00436<@Q124
5:D248@01PaS6<HQ22DY8@PDY@8@Q0@HaP065:D@Q1BU5:DHaQBU0a240QBU0a240QBU00@@Q1BU5:DD
Y@8HaP8@Q0035:DHaQS600D@Q08DY@8HaP8DY@8HaP035:D@Q124008@Q08DY@@@Q0036<HDYA24008D
Y@@@Q0055:D<H`aS5:DHaP025:D248@25:D01QS648@HaQcW6<HDY@8@Q00:5:D@Q12436<@Q0aS48@<
Ha2436<448@00`aS48@<H`0348@00`aS48@DY@025:D248@236<011245:DHaQ240PaS00<8@Q2436<0
0PaS00@8@Q2448@@Q0<<H`0448@<Ha2436<248@636<010Q248@@Q1240PQ200D@Q1BU5:D<H`Q200<<
H`0448@DYA2448@4248000<48@0500048@@Q0008@P0312401@Q2<Ha_NeJe=Jd00d8@00HmkcW>>Lhe
[CW>?Nl3@Q04>Lh013g_@Q0mkcW>0SF]13W>00@mkcW>>Lhe[@8icP03=JdaS3F]00<icP8mk`924004
?NlicSW>>Lh3AS42?Nl01CW>?Nlmkd8@>Lh00cF]0SW>0cF]0SW>0Sg_00HicSF]=JdicT8@AS42@Q00
0cW>=Jdmk`06>Lh3;F/00c6<?Nlmk`02>Lh5<H`2:DX00bDY:DXaS003<H`01Be[<H`aS36<=Jd00SW>
00<aS2e[:DX00be[00<YBRe[<H`00S6<1CF]0c6<0Re[0RDY0RU:0be[00@YBRe[;F/]J`8YBP05;F/a
S36<<H`YBP029BT00bU:9BTU:@029BT00b489BTU:@028@P012DY:DX]JbU:0be[00DYBRe[9BTU:Be[
008aS08YBP03;F/YBR48008Li`<Q20@Li`038@PU:B48008Li`069BTYBR488@PLib480RDY0bU:00X]
Jb487>LLiaS68@P]JbU:6<H<H`H48@0300048@0000@48@0300048@@Q00L48@0400048@@Q00041240
0`0012448@03124224821242248412400`Q212448@0:24800`@Q24848@0?12400`Q212448@081242
2483124224831243248212400`Q21248@P03248412432483124424841245248236<524800`@Q248<
H`022482124224801@aS2488@P@Q24800PaS00@8@P@Q12448@<8@PH48@0424848@@Q248=12401PQ2
12448@Q236<8@PP48@0:36<8@P@Q5:DHaSW>BU96<CF]8@P25:D031245:D@Q0aS48@DYAS65:D@Q0aS
48@<H`8@Q0<DY@8@Q0<DY@8@Q0057>LQ21S648@<H`025:D011S65:D@Q1240aBU0Q2400<DYA2448@0
1ABU00PHaQBU5:DDYA245:D@Q1BU0QS600HLiaS66<HHaQ245:D248@35:D01A245:DHaQcW6<H01ABU
00<@Q1BU6<H00QBU0Q2400DDYAS67>LHaQBU008<H`0548@DYA2436<@Q0045:D448@25:D011S65:DD
YABU0aS600<DYA2448@00Q2400@DYA245:D@Q0@DY@0348@DYA2400<<H`@@Q0035:D@Q12400<<H`03
48@DYA2400@@Q00536<8@PaS36<@Q00436<248@00`aS48@@Q00248@00`aS48@<H`0236<748@021BU
48@@Q0aS248<H`Q236<348@336<112400003124000@Q00848@0=00048@@Q248000@Q36<aS6]JDY@a
S48@AS400Sg_0T8@00De[C6<>LhmkdHa008icP8mk`PicP04=JdicSW>>Lh2?Nl2>Lh3<H`023F]>Lha
S3F]>LhmkdHa@Q02>Lh013F]>Li244Ha0d8@0cW>00@mkd8@?NlicP8e[@8icP<e[@03>Lhmkcg_00@i
cP04@Q1:DTHa@Q05>Lh013g_>LhicSF]0S6<0Re[00<e[CW>?Nl00cW>00<e[C6<<H`00Re[00<aS2e[
:DX00RU:00@]Jc6<=JdaS08]J`06<H`icSW><H`]Jc6<0bU:00D]Jc6<<H`aS2e[008aS003=JdicSF]
00<]J`03<H`]Jbe[008U:@04:DX]Jc6<;F/2:DX2;F/3:DX2<H`012e[:DXU:BDY0bU:0RDY00DQ22DY
9BTQ22DY00<]J`<YBP03;F/aS2U:00<YBP8aS08]J`0;8@PLiacW7>LU:BU:9BTLiaS67>LQ20029BT0
11cW8@PQ22480RDY0QcW00<Q22DY8@P00RDY0bU:00XU:AcW7>LQ22e[:DXQ21241248@PL48@030004
8@@Q00T48@0300048@@Q00@48@0300048@@Q00<48@04248000@Q1242248312400`0012448@021240
0`Q212448@0424801P@Q2488@PQ21248@P848@0324848@@Q00<48@0324848@@Q00D48@0424848@Q2
248412400`Q212448@05124424800`@Q2488@P022483124010Q212448@Q20`@Q0PQ20`@Q00<8@P@Q
12400PQ200<<H`Q224800PQ210@Q1PQ200<48@Q2124020Q20`aS0PQ200<48@Q224800`Q200@<H`Q2
2488@PD48@0324848@@Q00X48@0324848@@Q00@48@88@P031248@PQ200H48@<8@P0:1248@Q24;F]2
43g_>LhU:ABU6<H35:D01A245:DDYA2436<00Q240aBU0Q2400HDYA245:DDYA245:D348@27>L021S6
5:D<Ha246<HDYAS65:D248@45:D248@01ABU48@@Q1BU48@011BU0Q2400<DYAS66<H00aS60R4800<H
aQBU48@00Q240QBU0aS60QBU0QS600DDYA2448@@Q1BU008@Q0035:D@Q1BU00@DY@@@Q0035:D@Q124
008@Q0056<HDYA2448@DY@0448@011BU48@DYAS60QBU00D@Q1BU5:DDYA24008<H`0348@DYA24008@
Q0045:DHaQBU5:D348@336<00a2436<@Q00748@00aBU48@@Q00448@336<00a2436<<H`0224800`aS
48@@Q00248@236<248@236<010Q248@@Q1240`aS0aBU00D<H`Q236<8@P@Q008<H`8DY@0348@<H`aS
0048@P0000<000@Q00001@@Q00P8@P@Q1248@SF]LiaBU36<0T8@00@mkcW>>Lhmk`8icP04?Nm2448@
@Q05?Nl013W>?Nlmkcg_0SW>0S6<13W>0SF]0cW>0S6<0SF]0cW>00<mkcF]=Jd00SW>00E6<DYBBU9>
LdYB0096<@A24009>Lhe[C6<>LhmkcF]<H`e[CW>008e[@8aS00;?Nm243g_>Lhe[Cg_@Q0mkcW>=Jdi
cP02=Jd2?Nl02SF]<H`YBRe[>Lhmkd8@>LhaS3F]0Sg_00DicS6<;F/U:BU:008U:@8YBP03;F/YBRe[
00<aS005;F/aS3F]<H`]J`02:DX00c6<:DX]J`03<H`5;F/3<H`2;F/2:DX00be[:DXYBP029BT00bU:
;F/]J`02;F/01RU:9BTaS3F]<H`]J`8U:@04:DXU:BDY8@P29BT00b489BTYBP039BT2:DX5;F/022U:
<H`e[CF]<H`YBS6<:DX28@P01QcW9BTU:B487>LQ208HaP8Q2006:DXU:BDY9BTQ21S60QcW00LQ21cW
7>LQ22DY;F/YBP059BT012e[9BTHaQ240PQ20`@Q00<000@Q12400`@Q00<000@Q12400`@Q00<000@Q
00001@@Q00<000@Q24800P@Q00<000@Q12400P@Q00H8@P@Q12448@aS248812400`Q21248@P042480
10aS2488@P@Q0PQ220@Q00<8@P@Q12401@@Q00@8@P@Q12448@<8@P031248@PQ200@48@0324848@@Q
00<8@P848@0724848@Q224848@Q2124010Q210@Q00<8@P@Q24800PQ20P@Q0`Q20P@Q0PQ20P@Q1`Q2
00<48@Q224800PaS0Q2400L<H`@Q36<YBSg_<H`@Q00212400`Q21248@P05248712400`Q212448@02
12400`Q212448@0612400`Q212448@0212432486124010Q212448@Q20PaS0Q2400DQ23F]>Lh]JacW
008@Q0035:D@Q12400`@Q0DDY@8@Q00336<DYABU008Li`045:D@Q1BU48@45:D02A245:DDYABU48@D
YA245:D@Q0025:D26<H00aBU48@@Q0035:D021cW6<HDYABU6<HLibDY8@P45:D01QS65:DDYABU6<HL
i`HDY@8@Q0075:D@Q1245:D@Q1BU6<H00QBU00<HaQ2448@00Q241aBU1Q240aBU00L@Q1BU48@DYA24
5:D<H`0248@01aBU48@@Q1245:DHaQBU00<HaP8DY@0448@DYA245:D248@010aS48@@Q1240PaS00@@
Q0aS36<@Q0<DY@8@Q0D<H`0348@<H`aS008<H`<@Q088@P0436<@Q12448@224800a2436<@Q00648@4
36<010Q236<@Q0aS0Q240@aS0@Q2000512400`0012448@0312401@Q2<Ha_Ne:D=Jd00d8@0SW>00@m
kcW>@Q0mk`=24003?Nm6<CW>00@icP03?NlicSW>00<e[@06>Lhmkcg_=JdaS3F]0SW>00<aS3F]>Lh0
0cF]00<icSg_>Lh00cF]00DicT8@AS5:DTic009:DP06AS5243g_@Q1:DT8@0SF]00@icSg_?Nle[@8i
cP04=JdaS36<=Jd5>Lh3?Nl2>Lh3=Jd2>Lh013F]<H`]Jbe[0SW>00E243g_?NlicSF]00<icP03=Jd]
JbU:008U:@04:DXU:BDY:DX3;F/0136<=Jde[C6<0Re[00DaS3F];F/aS2e[00@aS004;F/aS2U:;F/2
<H`01SF]<H`]Jbe[:DX]J`<YBP8U:@04:DX]Jbe[:DX29BT01Re[>Lhmkc6<9BTQ208U:@0;:DXU:BDY
8@PU:BU:;F/YBRDY8@PU:@02;F/00bU:;F/]J`02;F/00c6<=JdaS002;F/0236<;F/YBQcW8@PU:B48
9BT27>L00aS68@PLi`028@P00bDY:DXYBP038@P00acW8@PLi`038@P4:DX59BT011cW6<H<H`aS20@Q
00@000@Q124000T48@0500048@@Q1240000512400`Q21240000212400`Q212448@0412400`Q21248
@P021248248010@Q2488@PQ20`@Q0PQ23@@Q00<8@P@Q12401P@Q00<8@P@Q12400P@Q0`Q200<48@Q2
24800PQ20P@Q00<8@P@Q12400P@Q00D8@P@Q24848@Q200<48@0324848@@Q00848@@8@P<48@<8@P<4
8@@8@P031248@PQ2008<H`055:D@Q0@Q248Li`02<H`00aS61248@P02124010Q21248@P@Q10Q20P@Q
00<000Q2248010@Q00<8@P@Q12400`@Q00<8@P@Q12400P@Q00<8@P@Q12401`@Q00<8@P@Q24800`@Q
00L8@PaS248<H`Q27>L]J`02=Jd01AcW48@@Q1245:D00QS600D@Q1BU48@@Q0aS00<@Q0035:D@Q124
008@Q08DY@8@Q00436<@Q1BU5:D26<H35:D00a2436<DY@035:D011245:DDYABU0a2400<DYA245:D0
0QBU00<HaQ2448@00QBU0QS600@LiaBU5:DHaP8Q20037>LHaQS600PDY@036<HDYABU00<DY@036<H@
Q0aS008@Q0@DY@<HaP8DY@0348@DYABU00<@Q0HDY@0348@<H`aS008@Q0035:D@Q124008@Q0035:D@
Q0aS008<H`8@Q0085:D@Q0aS5:DHaQcW6<HDY@<@Q0035:D@Q1BU008@Q0045:D<Ha2448@436<01124
5:D@Q1BU0a2400<<Ha2424800PaS00<8@Q2448@00Q240`aS0Q2410aS0Q240PaS0Q2400@DYAS65:D@
Q088@PP<H`4@Q04<H`48@P0000@000@Q124000@48@0<248000@Q248]Jf]JDY@aS3g_@Q0icSg_0d8@
00@mkd8@@Q12408mk`8icP03=JdaS3F]008icP06?NlicSW><H`e[Cg_0cW>0SF]0SW>00<mkcW>=Jd0
0SF]13W>0cF]00HaS3W>@Q16<DYBAS43BU82AS42@Q0013g_>Lhmkcg_0cW>0SF]00<aS3F]=Jd00cW>
1Cg_0cW>13F]0S6<00HYBRe[=Jde[D8@AS43@Q001SW>=Jde[CF]<H`]J`8U:@8YBP04;F/U:BU:;F/2
<H`00be[:DXYBP03<H`3:DX00c6<;F/aS003=Jd2<H`5;F/3:DX01Re[=JdaS36<:DXU:@@YBP8U:@04
:DX]JbU::DX29BT2:DX39BT2:DX00be[:DXU:@039BT7:DX01Be[:DXYBRDY;F/00S6<00HYBRDY9BTU
:B487>L38@P00aS68@PQ2002:DX01RDY8@PQ22489BTQ208Li`049BT]JbDY9BT3:DX022DY:DXYBRDY
8@PLiaBU36<3248312400`0012448@0212400`0012448@0;12400`0012448@0612401@Q21248@P@Q
24801P@Q00<8@P@Q12400P@Q2PQ200<48@Q2248010Q22P@Q00<8@P@Q12400P@Q00<8@P@Q124010@Q
10Q20`@Q0`Q200@48@Q22488@P848@88@P848@0924848@Q21248@P@Q24848@Q200@48@H8@P031248
@P@Q0088@P061248@P@Q248@Q0aS0`Q200H<H`Q22488@PaS48@25:D01@aS24848@@Q24800P@Q0`Q2
1@@Q00<8@P@Q12401`@Q00<8@P@Q12400`@Q00@8@P@Q1248@P@48@88@PP48@<8@P0:5:DHaR48:DXU
:AcW6<HDYAS65:D648@336<00aBU48@<H`0548@010aS5:DHaQBU0Q2400@HaQcW7>LHaP8DY@<@Q08H
aP8DY@8HaP035:D@Q124008@Q0HDY@036<H@Q12400@DY@0848@DYAS68@PLiaS65:D@Q0@DY@0548@D
YAS67>LHaP025:D011S65:D@Q12431BU0a2400@DYAS65:D@Q08DY@<@Q08DY@<@Q0045:DHaQ2448@2
36<00aBU48@<H`0348@010aS48@@Q1BU0QS600<DYA2448@011BU112400HDYA2448@<Ha245:D348@4
5:D01PaS48@@Q12436<8@P8@Q088@P0836<@Q12448@<Ha2436<8@P8<H`<@Q0@<H`0448@DYA2448@7
36<0112436<<H`aS0@@Q000020@Q00048@@Q00048@002483124020Q2<Ha[FTic<H`mkdHa?Nl2>Lh6
?Nl0148@?NlmkcW>0SF]00DaS3W>>LhmkcW>008e[@@icP8e[@03>Lhe[CW>008e[@8icP03?NlicSF]
008e[@8icP04=JdaS3F]>Lh4AS43BU801dHa@Q12448@?NlicSF]00924005>Lhe[C6<=JdicP03=Jd2
>Lh01cg_>Lhmkd8@?Nm243W>00<e[@04<H`e[CF]<H`3;F/03Cg_@Q16<DHa@Q0icSg_>Lhmkc6<;F/U
:BU:008U:@03:DX]Jbe[00@]J`03:DX]Jbe[00<aS004:DX]Jbe[;F/4<H`013F]<H`]Jbe[0c6<00<Y
BRDY;F/00c6<00TYBRDY;F/YBRDY:DXU:BU:9BT00RU:0Re[00@U:BU::DXU:@<YBP03;F/YBRU:008Y
BP059BTQ2248:DX]J`05:DX00bDY:DXYBP02:DX012e[:DX]JbU:0RDY0R480RDY11cW00<YBRDY9BT0
0b4800<U:B487>L00R480RDY1BU:00<U:B487>L00b4800<DY@aS12400P@Q00@000@Q124000848@05
00048@@Q1240000212401@0012448@@Q248010@Q00<8@P@Q000010@Q00D8@P@Q12448@Q200P48@06
24848@Q21248@P@Q0`Q200D48@Q21248@P@Q00<8@P8<H`D48@0324848@@Q00848@0324848@@Q0084
8@0424848@@Q12422484124224800`@Q24848@02248212401`Q212448@Q21248@P@Q0088@P@48@05
24848@@Q1248@P03124224821243248010@Q24848@Q20P@Q00D8@P@Q2488@P@Q008<H`<8@P8<H`03
248<Ha24008@Q00636<8@PQ224848@Q20`@Q1@Q210@Q10Q210@Q00<8@P@Q124010@Q00<8@P@Q1240
1@@Q00<8@P@Q12401P@Q00D8@PaS5:D@Q1cW008YBP038@PHaQBU00LDY@0348@<H`aS008@Q08<H`03
248@Q124008@Q0035:D@Q124008DY@076<HDYABU6<HLiaS65:D00Q240QBU0QS600<DYA246<H00QBU
0a2400@DYA245:DDY@8HaP8DY@0548@DYABU6<HDY@0248@01ABU7>LLiacW5:D00Q240aBU0a2400<H
aQcW6<H00QS600<DYA245:D00a2400<DYAS67>L00QBU00D@Q1BU6<HHaQBU00<@Q0055:DHaQS65:D@
Q0035:D548@01QBU6<HDYABU48@<H`<@Q0<<H`8@Q00336<@Q1S6008DY@8<H`0348@DYABU008DY@03
48@DYA24008@Q08DY@8@Q00436<@Q0aS48@25:D248@336<01@Q248@<H`aS48@010aS00<@Q0aS36<0
0PaS00@@Q0aS36<<H`8@Q0085:D@Q12448@<Ha2436<8@P8<H`0348@DY@aS008<H`8@Q04<H`448@00
20@Q00P8@P@Q0008@Re[IcUBU2e[13W>00@e[CW>>Lhmk`924004?NlicSW>?Nl2>Lh5=Jd01C6<=Jde
[CW>?Nl00d8@00@icSF]>LhaS0<icP03?Nle[C6<00@e[@<aS005=Jd]Jc6<=JdicP04?Nl3@Q001Cg_
>Lhe[CW>=Jd00SW>00<e[CW>>Lh01SW>00@e[CW>>Lhmk`=24003?NlicS6<00<e[@@aS003=JdicSW>
008mk`=24005?NlaS2e[9BTYBP02;F/2:DX00be[:DX]J`02;F/0136<;F/YBRU:0RDY00@]JbU:<H`]
J`<YBP8]J`<YBP03;F/aS3F]008aS004:DX]Jbe[:DX2;F/2:DX00be[:DXYBP049BT3:DX03bDY:DXY
BRe[:DX]JbU:9BT]Jc6<;F/YBR48:DX]J`02:DX022489BTU:BDY;F/YBRDY:DX59BT012U:9BTU:BDY
0R480RU:00<Q22DY7>L00R4800@U:BU:9BTU:@<Q20039BTYBRU:00LYBP059BTQ22487>LDY@022483
12400`0012448@0512400`0012448@0312401`Q2124000@Q00048@Q200@48@0500048@@Q1248@P03
12401@Q212448@@Q00001P@Q0`Q21P@Q00`8@P@Q0008@PaS5:D@Q0Q2124000@Q248612400`Q21244
8@0=12400`Q212448@02124424821242248312400`Q21248@P03124324800`@Q24848@0312422480
10@Q24848@@Q0PQ200<<H`Q224800PQ20PaS00@8@P@Q248<H`88@P031248@PQ200<8@P@48@042484
8@Q2248312400`Q21248@P0712400`Q212448@0212400`Q212448@02124010Q212448@Q20`@Q00D8
@P@Q12448@Q200@48@0324848@Q20088@P056<HLiacW8@PHaP035:D26<H00a245:DDY@0248@00`aS
48@DY@0248@00`aS48@<H`0248@35:D26<H01ABU48@DYABU6<H00R4800@HaQBU36<<H`8DY@@HaP03
5:DHaQBU008DY@8<H`8@Q0<Li`036<H@Q124008@Q08DY@DHaP055:DHaQBU48@DY@0248@45:D00a24
5:DDY@036<H348@01@aS5:DHaQS65:D00Q2400DDYAS66<HDY@aS008@Q08Li`036<HDYA24008<H`@@
Q0045:DHaQBU5:D448@236<00a2436<@Q00436<248@011BU48@<H`aS0a240PaS0QBU00@HaQBU48@D
Y@8@Q08<H`8@Q08DY@8HaP8DY@0448@<H`aS248236<00`Q236<8@P0236<248@010aS248<H`aS0a24
00L<Ha2448@@Q0aS48@DY@0248@00`aS248<H`0636<148@136<12480000600048@@Q00048@001@@Q
00P8@Re[IcU>Lbe[>LhmkcW>13F]00<icSg_?Nl00cg_00=243g_>Lh00cW>00<e[C6<>Lh00SW>0SF]
00HicT8@@Q0mkcW><H`3=Jd2>Lh013g_>LhaS36<0SF]00<aS2e[=Jd00S6<00@]Jc6<=JdicPTmk`0:
>Lhe[CF]<H`e[Cg_@Q0mkcW>=Jd3>Lh3=Jd01CW>@Q12448@?Nl00cW>00<e[C6<;F/00c6<0SF]00Xi
cSg_@Q1243g_@Q0mkcW><H`YBP8]J`DYBPH]J`04<H`YBRU:9BT2;F/2:DX01RDY;F/]Jbe[<H`]J`8Y
BPDaS0<]J`05:DXU:BU::DX]J`02<H`012DY8@PQ22U:0Re[00TYBRDY9BTYBRe[<H`]JbU:;F/00S6<
0Re[00<YBRDY:DX00bU:0RDY0bU:00<U:B489BT01BDY00HYBRDY8@PU:BU:9BT38@P29BT38@P49BT0
0acW9BTU:@02:DX00be[:DX]J`02;F/022U:9BTU:BU:8@PDYA241242248412401@001248@P@Q0000
0P@Q00<000@Q12402`@Q00<000Q212400`@Q0`Q21P@Q00<8@P@Q12400`Q210@Q10Q20P@Q0`Q20PaS
0PQ22P@Q0PQ20P@Q00H8@P@Q248000@Q248212432480100012448@Q20P@Q00<8@P@Q124010Q20P@Q
0PQ21P@Q0`Q20`@Q00<8@P@Q124010@Q2@Q200<48@Q248@00PaS1@Q200<48@Q212400PQ200@48@Q2
12448@@8@P848@<8@P031248@PQ200848@0624848@@Q24848@Q21P@Q0PQ220@Q00<000@Q12400P@Q
00/000Q2248<H`Q236<@Q1S68@PLiaS6008@Q0<HaP@DY@8@Q00336<@Q12400D@Q00436<DYABU6<H4
5:D00a245:DLi`029BT00aS648@@Q00248@00aS67>LHaP026<H011BU6<HDYABU112400@HaQBU6<HH
aP<DY@0348@DYA24008DY@DHaP@@Q0035:D@Q12400<HaP035:D@Q1BU008HaP8DY@8@Q0DDY@0?48@D
YABU6<HDYAS648@<HaS67>LQ21S648@<HaBU00<@Q08DY@8@Q08HaP<@Q0035:D@Q0aS008@Q0<<H`05
48@DYA2448@<H`0248@00aBU48@@Q00236<25:D00aS65:D@Q00248@25:D236<00a245:DHaP025:D0
0aS648@@Q00336<0112436<<H`Q20PaS00<@Q0aS36<00`aS00<@Q0aS48@01a2400@<Ha245:D@Q0<<
H`0548@<H`Q236<@Q00236<1248000848@0300048@@Q00<48@0:248000@Q248]Jf<HAS4YBSF]>Lh2
=Jd0136<=Jde[Cg_0SW>00@mkcW>?Nm2408icP03=JdicSg_00<icP0:?NlicS6<=JdicT8@?NlicSg_
=Jd3<H`013F]>LhicSF]0S6<00@e[CW>=JdaS08]J`03<H`e[CF]008e[@8icP@e[@8icP04?NlicSg_
>Lh3=Jd4>Lh3?Nl01SW>=JdicSg_@Q0icP8aS003=JdicSW>008mk`8icP03<H`e[CF]008icPHe[@03
;F/aS36<00<aS08]J`03:DX]Jbe[008]J`05<H`]Jbe[;F/YBP029BT01248:DXU:BU:0bDY1BU:00<]
Jc6<<H`00c6<00<]Jc6<<H`00Re[00LU:B489BTYBRe[:DXU:@02;F/3:DX012e[:DXYBRU:0be[00<Y
BRe[;F/00be[0RU:00@]JbU::DXYBP8U:@<YBP8U:@05:DXU:BDY:DXU:@028@P01acW8@PU:B48:DX]
JbU:00<U:@03:DXU:B48008Li`8Q20<YBP@U:@8YBP079BTQ22e[;F/Lia24248010@Q00D000@Q1244
8@0001/48@88@P@48@0324848@@Q00@48@0424848@Q2124324800`@Q24848@0224800`@Q2488@P07
12400`Q212448@0212401PQ212448@@Q24848@88@PH48@0324848@Q200848@88@P8<H`0324848@Q2
00<8@P848@0524848@Q224848@0424801`@Q2488@P@Q24848@Q200848@<8@P0:1248@QS68@PLia24
248@Q0aS248436<62484124224800`@Q24848@02248020@Q2488@PQ2124000@Q2482124010Q21244
8@Q20`@Q00@8@P@Q1248@PD48@@8@P<48@0524848@@Q24848@0224801`aS5:DLiacW6<HDYA2400<D
Y@046<H@Q1BU5:D348@45:D236<248@00aS65:D@Q0035:D248@25:D56<H01Q245:D@Q1BU6<HDY@<H
aP037>LHaQBU00D@Q08DY@046<HLiaS66<H35:D01AS65:DDYAS648@00aBU00<LiaS65:D00Q240QBU
00<@Q1BU48@00QBU00D@Q1BU6<HHaQBU008@Q0<DY@8@Q00336<@Q1BU00@@Q08DY@8HaP035:D@Q124
00L@Q0@DY@0448@<H`aS36<448@00`aS248<H`0336<248@236<548@25:D348@00aBU48@@Q00548@0
21BU6<HLiacW6<H@Q0aS48@336<324800`aS248<H`0436<348@011BU48@DYAS60QBU11240PaS0Q24
1@aS0@Q20@@Q00000`@Q00048@0212400`0012448@0312401@Q2:DYNmdic:DX01CF]00HaS3W>>Lhi
cSg_>Lh2?Nl01D8@?NlmkcW>=Jd013W>00LmkcF]=JdaS3F]>Lhmk`02>Lh013F]<H`aS36<0cF]00Di
cSF]=Jde[C6<008e[@@aS004;F/e[CW>?Nl2>Lh00cF]>LhicP03=Jd3@Q000cF]<H`e[@02?Nl02CF]
>LhicSg_>Lhe[CW>?Nm24002?Nl00cF]<H`e[@02>Lh0148@?Nlmkcg_0SW>00DaS3F]=JdaS3F]008i
cP06=JdaS36<;F/aS2e[136<00@]JbU:;F/]J`8aS005;F/aS36<;F/YBP028@P49BT00b489BTYBP04
9BT2;F/2>Lh2=Jd2<H`3;F/2:DX49BT3:DX00bDY:DX]J`03;F/2:DX3;F/2:DX2;F/01BU:9BT]Jbe[
:DX00bDY00@YBRDY:DXYBPLU:@048@PU:B488@P29BT00bU:9BTU:@03:DX39BT48@P69BT3:DX28@P2
:DX01RDY6<H8@PQ21248@PT48@0300048@@Q00<48@0300048@@Q00848@0300048@@Q00@48@030004
8@@Q00<48@0624848@Q224848@Q210@Q0`Q200<48@Q212400`Q20`@Q0PQ200<48@Q224801P@Q00D8
@P@Q24848@0000848@0324848@@Q00T48@88@P<48@0324848@@Q00H8@P041248@PQ2248512432480
10aS2488@PQ20P@Q00<8@P@Q124010Q200L48@Q2248<Ha247>LHaP0236<00`Q236<<H`0236<22482
36<224800`@Q2488@P031244248212400`Q21248@P021242248010@Q2488@P@Q1@Q21@@Q00<8@P@Q
12400P@Q0`Q21@@Q10Q200T48@Q2248@Q1S67>LQ21S65:D00Q240aBU0Q2400<DYA2448@00aBU1124
0aBU00@HaQBU5:D@Q0<DY@0348@DYAS6008Li`8DY@0348@DYABU008DY@<HaP035:DHaQ2400<DY@<@
Q0035:DHaQS600@HaP035:D@Q1BU00<DY@0348@DYAS6008HaP<DY@0348@DYA2400<DY@8@Q0056<HD
YABU6<HDY@0348@25:D548@35:D011245:DDYAcW0QS6112400@<Ha2448@<H`8@Q0036<HDYA24008@
Q08<H`8@Q0L<H`8@Q0035:D<Ha24008@Q00436<@Q1BU5:D248@011BU48@DYABU1Q240QS600@LiaS6
5:D@Q0@<H`03248<Ha24008<H`03248<H`aS00<<H`D@Q0055:DHaQBU5:D<H`0348@00`aS48@@Q004
36<1248136<11240000500048@@Q12400003124020Q200048@Q2<HaS64Ha:DX2=Jd2<H`012e[=Jde
[CF]0Sg_00A6<D8@@Q1240<mk`04>Lhe[CF]>Lh4<H`2=Jd4>Lh013F]<H`aS2e[0S6<0SF]0c6<0SF]
00@icSg_=JdicP<e[@07>Lhe[CW>=JdicSF]>Lh00Sg_00<icSF]>Lh01CF]0cW>13g_00@icSg_@Q0m
k`8icP<e[@05<H`icSg_?NlicP02=Jd3?Nl01SW><H`e[CW><H`]J`<YBP8]J`03:DX]Jbe[00<aS08e
[@8]J`04<H`icSF];F/68@P29BT7:DX012e[<H`]Jbe[0RU:00D]Jc6<;F/]JbU:00<U:@<YBP8U:@07
;F/e[CW>=Jd]JbU:<H`00RU:0RDY1RU:00<]JbU::DX00RDY00HQ22DY9BTU:BU:9BT3:DX89BT01B48
9BTU:BDY8@P00RDY00<Q22DY8@P00b4800<U:BU:9BT00RDY00<Q22DY9BT00bDY0RU:00<HaQ242480
0PQ210@Q00@000@Q124000H48@0500048@@Q00048@02248212400`002488@P09124010Q21248@PQ2
0`@Q0PQ200<@Q1BU48@00`Q200D<H`Q22488@PaS0088@P041248@P@Q12442489124010Q21248@PQ2
1`@Q00L8@P@Q1248@P@Q24848@03248010aS2488@P@Q0PQ20P@Q00<8@P@Q12400`Q20P@Q0PQ20PaS
00<48@Q224800`Q20P@Q00@8@PaS48@8@P8<H`8DY@0448@DYA246<H25:D248@01@Q236<<H`aS2480
10@Q0PQ200@48@Q22488@P<48@88@P051248@PQ21248@P021245248;12401PQ21248@PQ21248@P84
8@0424848@Q21242248010aS48@HaQBU0aS60a240QS600@DYA2448@@Q0<DY@0448@DYA2436<348@0
0aBU6<H@Q00348@55:D01R489BTU:AcW36<@Q08<H`<DY@046<HDYAS65:D36<H35:D248@011BU6<HL
iacW1AS60aBU00<@Q1BU6<H00QcW00DDYAS648@<Ha24008DY@8<H`8@Q0046<HDYABU5:D248@236<4
48@01aBU36<<H`aS5:DLiaS600<DY@036<HDYABU008@Q08DY@<@Q08DY@8@Q08<H`0448@DYABU48@2
36<02a2436<<H`Q236<@Q1BU48@<Ha2424800PaS1A240aBU0Q2400PDYA2436<@Q0aS5:DHaQcW0QS6
00<@Q1BU36<00PaS00H@Q1BU36<<H`Q236<324800`aS48@<H`0648@25:D00a245:D@Q00336<00a24
36<<H`0436<12481124000848@0300048@@Q00<48@0;24848@@Q248]Jf<HBU8YBSF]>LhaS002;F/2
<H`3>Lh00cg_@Q124002@Q000cg_>LhicP02>Lh00cF]>LhicP03<H`2>Lh2=Jd01SW>=Jde[C6<;F/a
S0@e[@06<H`e[CF]=JdicSF]0cW>0cF]00@icSF]=JdicP<mk`05>LhmkcW>>Lhe[@03<H`01cW>=Jde
[CW>=Jdmkd8@00<icP924004?Nle[CF]>Lh2<H`2>Lh00cg_>LhicP07>Lh3<H`2:DX01bDY:DXaS36<
;F/aS2e[00DaS003;F/e[C6<008e[@8YBP058@PLib488@PU:@02:DX2;F/3:DX5;F/0136<;F/YBRDY
0RU:00<]JbU:9BT00R480RDY0RU:00@]Jc6<=JdaS08]J`8aS003;F/U:BDY008YBP05;F/U:BDY:DX]
J`02:DX29BT012U:9BTU:BU:0RDY12U:0bDY00XQ22DY8@PLibDY:DXU:B489BTQ208U:@048@PU:B48
8@P49BT28@P29BT2:DX29BT2:DX012485:D<H`aS0`@Q00<000@Q12400`@Q00D000@Q12448@0000T4
8@0300048@@Q00X48@<8@P031248@P@Q00848@08248@Q1S65:D@Q0@Q248<H`@8@P041248@P@Q1242
248236<6124010Q212448@@Q0PQ21`@Q00<8@P@Q12400P@Q00<8@P@Q12401@@Q0`Q200<<H`Q21240
0`@Q0PQ20`@Q1`Q20`@Q0`Q20P@Q0PQ200H<H`Q236<<Ha2436<25:D01AS65:D@Q12436<00Q2400<<
H`Q224800`Q20`@Q00<8@P@Q24800P@Q00<8@P@Q12400PQ20P@Q0PQ200D<H`Q22488@PaS00<8@P03
1248@P@Q00P48@0524848@Q224848@04248312401`Q248@DYABU6<HDYAS6008DY@<@Q0036<HDYABU
00<@Q0056<HDYA2448@<H`0448@011BU48@DYAS60QBU0Q2400XHaQ245:DLib489BTLiaBU48@<H`D@
Q08DY@<HaP<DY@0348@DYABU008DY@056<HQ22486<HDY@0248@45:D36<H00b487>LHaP0348@436<0
1A245:DDYABU48@00aBU1Q2400<DYA2436<00Q240aBU0QS60QBU0Q240aBU0PaS11240QBU0a2400<D
YA2436<00PaS00D@Q0aS36<8@Q24008DY@0448@8@PaS48@436<25:D00a245:D@Q00348@00aBU36<<
H`0248@00aS648@DY@026<H011BU36<<Ha240PaS0Q240PaS0PQ20`aS112400<<Ha2436<00Q2400HD
YA2436<@Q0aS48@736<22480000400048@@Q000212400`0012448@02124030Q2:DYS64ic<H`icSF]
<H`e[C6<>Lhe[@8icP04@Q16<D8@AS42@Q0014Ha?NlmkcF]0SW>00De[CW><H`aS3F]008icP03=Jda
S36<00<e[@03<H`]Jc6<008icP03=JdaS36<008e[@03>Lhe[CF]00<icP8e[@03>LhmkcW>008icP8m
k`=2408icP8mk`03=JdaS3F]008icP03=JdaS3F]008icP8mk`03>LhmkcW>00<aS003=JdicSF]00<e
[@8mk`04>LhaS3F]=Jd2>Lh00c6<;F/YBP02<H`01Be[:DX]Jbe[<H`00Re[00<YBRe[<H`00cF]0cW>
0S6<00@U:B488@PU:@<]J`04:DX]Jbe[;F/3=Jd00c6<:DXYBP029BT5;F/2<H`012e[8@PQ224812U:
0c6<00@e[C6<<H`aS08]J`03:DX]JbU:008]J`069BTYBRe[<H`]JbDY0R4800HU:BU::DXYBR489BT3
:DX29BT3:DX00bDY7>LLi`049BT38@P00acW8@PQ20038@P01bDY:DXYBRDY8@PU:BU:008U:@04:DXU
:B486<H2248412400`0024848@0<12401@0012448@@Q248010@Q00T000@Q12448@Q21248@P@Q2480
0P@Q00@8@P@Q1248@P8<H`8HaP0448@<H`@Q248236<00`Q212448@0324801@@Q48@HaQBU36<01@@Q
00D8@P@Q24848@Q200848@0524848@Q224848@0224800`@Q24848@041243248010@Q24848@@Q10Q2
0P@Q0PQ20`@Q00<8@P@Q12400`@Q0`Q200<48@Q212401PQ200@<H`Q236<<H`<DY@08;F/icT8@=JdQ
22DY7>L@Q0<<H`88@P848@0324848@Q200<8@P@48@0324848@Q200<8@P0336<8@PQ20088@P8<H`<8
@P<48@<8@P@48@88@P031248@PQ200<8@P848@04248@Q0aS5:D27>L011BU36<@Q1S60aBU00<HaQ24
48@00Q2400@DYA2448@DY@@@Q0065:D@Q1245:DHaQBU0Q2400XDYAS65:DDYA245:DLibU:9BTHaP<D
Y@H@Q0035:D@Q1BU00<DY@0448@DYA2448@35:D26<H011cW6<HDYABU0Q2400XDYA246<HHaR486<HL
ib486<HDY@@@Q00436<@Q1BU5:D248@45:D248@01@aS48@@Q1245:D00Q240QBU00D@Q1S67>LQ21cW
008@Q0035:DHaQS6008@Q00336<DYA2400<@Q08DY@0548@<Ha2448@DY@0248@01@aS48@@Q12436<0
1Q240QBU00@@Q0aS36<DY@8@Q08<H`035:D@Q12400D@Q08DY@0348@DYAS6008DY@0336<@Q124008<
H`0348@<Ha24008@Q00436<@Q12448@536<448@236<348@236<3248336<000@48@0400048@@Q2483
12402@Q2;F]S64Ha;F/icSg_>Lhe[@03<H`01CF]?Nlmkcg_@Q000THa00=243g_?Nl00T8@00@icS6<
=JdicP8e[@03<H`e[CW>00He[@@aS005=JdicSF]=JdaS002=Jd4>Lh013F]<H`]JcF]0SW>00<mkcW>
>Lh00Sg_0d8@00dicSF]=Jde[CW>=JdaS3F]>LhmkcW><H`e[@02>Lh2?Nl00cW>=JdaS004<H`02CF]
>LhicSW><H`e[CW><H`e[@02>Lh00c6<;F/]J`07;F/01BU:;F/aS36<=Jd00S6<00PicSF]=Jde[C6<
=Jd]JbDY0R481RU:00P]Jc6<<H`aS3F];F/YBRDY0RU:00@U:BU::DXYBP8aS08YBP048@PU:BU:9BT2
:DX2;F/3<H`2>Lh01C6<;F/U:BDY:DX00RDY00<]Jc6<<H`00bU:00@U:B489BTU:@8YBP@U:@03;F/Y
BRDY008U:@04:DXU:BDY9BT38@P29BT00b487>LLi`027>L012489BTQ22DY0RU:0RDY00<Q22U::DX0
0RDY0R4800<LiaBU48@00PQ20`@Q00@000@Q124000848@0400048@@Q000F12422483124030aS1244
8ABU8@PYBQcW24848@aS248<H`88@P@48@0436<DYAS636<212401PQ212448@@Q24848@88@P@48@03
24848@@Q00848@88@P848@0424848@@Q1243248212442485124010Q212448@@Q1@Q200/48@Q21248
@P@Q24848@Q21248@P@Q0088@P<<H`<@Q0049BTYBT8@>Lh2<H`00acW6<H@Q00236<2248312422483
12422482124010002488@PaS20Q20`aS00@8@P@Q2488@P<48@0424848@@Q248212400`Q21248@P08
248011S67>LLiaS60Q241ABU00<HaQ245:D00aBU0a2400<<Ha2448@01QBU0Q240aBU0a2400@HaQcW
8@PLi`8HaP8DY@8@Q0035:D@Q1BU00@DY@0348@DYABU008@Q0035:D@Q124008DY@046<HLiaS65:D3
48@236<011245:DLib480acW00PDYA2436<<H`Q236<@Q1BU0Q2400<<Ha245:D00QBU0a2400H<Ha24
48@@Q0aS48@35:D011S68@PLiaS61aBU00<@Q0aS48@01A240QBU00@<Ha2448@@Q08<H`@@Q00636<@
Q1245:D@Q1BU0a2400D<HaBU5:DDYA24008<H`0348@DYA24008@Q08<H`0348@<Ha2400@DY@0348@D
Y@aS00<<H`03248<H`aS008@Q08<H`8@Q0@<H`8@Q0045:D@Q0aS248236<248@336<2248236<11240
0003124000@Q00<48@0:00048@Q200048@Q2<HaW>Dic;F/3>Lh013F]>LhicSF]0SW>00DmkdHa@Q16
<DYB00=6<@09BU96<D8@?NlicSg_=JdaS3F]00<icP03<H`icSW>00<aS004>LhaS3F]<H`2=Jd4>Lh0
0c6<=JdicP02=Jd0136<=JdicSg_13W>00@mkd8@?Nm2409:DP04@Q0mkcW>?Nl2>Lh01cg_>LhicSW>
=JdaS3F]00<icP04=Jd]Jc6<:DX3;F/2<H`8=Jd00cg_>Lhe[@02<H`3;F/012U:;F/aS3F]0c6<0SF]
0S6<01@e[CW>>Lhe[C6<:DXU:Be[:DX]Jc6<;F/aS2e[:DX]JbU:;F/aS3F]0Re[0RDY12e[00<YBRDY
:DX00RDY00<Q22DY9BT012DY00dYBS6<:DXU:BU:<H`]JbU:8@PU:BU:9BTYBP02;F/2<H`01Re[:DXY
BRU:;F/YBP8U:@<YBP8U:@048@PU:BU::DX29BT00b489BTU:@039BT01B487>LHaQcW9BT00RU:0bDY
0RU:00<U:B489BT00RDY0RU:00DU:BU::DXDY@aS00L48@0300048@@Q00848@0300048@@Q00<48@03
00048@0000@48@0300048@@Q00X48@0324848@Q200848@8<H`8@Q00336<8@PQ200<<H`041248@P@Q
124224800`@Q2488@P02248312422482124010Q21248@PQ210@Q00@8@P@Q2488@P848@0324848@@Q
0088@P<48@88@P848@<8@P041248@PQ2248212400`Q212448@0212400`Q212448@02124224821242
24801PaS2488@PaS24848@8<H`0<6<HLibU:AS5BU6<HG_M>Le:D>Lh]JaS60Q2400<8@PaS24800PQ2
10@Q00<8@P@Q12400P@Q00<8@P@Q24800PQ200@48@Q22488@P8<H`03248<H`aS00<8@PH48@032484
8@Q200848@03248<H`aS00<<H`0448@<H`aS48@36<H01A2436<DYABU7>L02aBU00<@Q0aS36<00Q24
0QBU1A2411BU0Q2400DDYAcW7>LU:B48008HaP8<H`0348@<HaBU008DY@8HaP0:48@DYABU6<HDYA24
36<@Q1BU36<248@26<H011BU48@@Q1241ABU00@HaQBU6<HQ208HaP8@Q00:5:D@Q12436<@Q1BU6<HD
YA2436<448@00`aS48@DY@035:D236<00a245:DLi`027>L011S648@DYABU1A2400DDY@aS36<@Q1BU
008HaP095:D@Q1BU48@HaQBU36<@Q0aS00<@Q00336<@Q1BU008DY@8<H`8@Q08<H`8@Q08<H`0348@D
YA2400<@Q0<<H`0348@DYA2400@DY@0336<@Q0aS008<H`<@Q0@<H`8@Q0P<H`0448@<H`Q2248436<0
0`Q236<<H`0236<12480000300048@0000848@0=00048@@Q24848@00248]Jf]JCW<aS48@>Lh00cF]
00DicSF]=JdicSg_00=6<@08BU9243g_@Q1:DTicAS4mk`8icP8e[@<icPLe[@07<H`]Jbe[;F/aS3W>
=Jd00SW>0SF]00<aS3F]>Lh00SF]00<aS3F]?Nl00T8@00DmkcW>?Nm243g_00924006AS5:DT8@?Nli
cSF]13W>00<mkcF]=Jd00SF]0cW>00@e[C6<;F/YBP<aS004;F/aS36<>Lh2=Jd0136<=JdaS36<0SW>
00He[C6<;F/]Jc6<;F/4<H`00cF]<H`aS003=Jd00c6<=JdicP02=Jd01Be[:DXYBRU:;F/0136<0be[
00LYBS6<=Jde[C6<:DXU:@02:DX2;F/01bU:;F/]JbDY8@PLib4800DU:@8YBP<]J`03:DX]JbU:008Y
BP049BTQ2248:DX2<H`2;F/5:DX2;F/29BT01B489BTYBRU:9BT00RU:0RDY0R4800DU:B489BTYBRDY
00<Li`038@PYBRDY00HU:@03:DXU:BDY00@U:@04:DXU:AS648@512401@0012448@@Q00001P@Q00<8
@P@Q12402`@Q00<8@P@Q12400`@Q0PQ20`@Q00H000@Q2488@PaS48@236<00`Q236<<H`0224800`@Q
2488@P021246248512401@Q21248@P@Q24800`@Q0`Q20P@Q0`Q200<48@Q212401@@Q1`Q20`@Q0`Q2
00<48@Q212400`@Q00<8@P@Q24800PQ20`@Q1@Q210aS00H@Q1BU7>LmkdHaG_L2E[D01UkgBU8mkbDY
6<H@Q0H8@PT48@88@P031248@PQ20088@P8<H`88@P<<H`L8@P@48@@8@P@<H`<8@P045:D@Q1S66<H2
5:D00a245:DDY@026<H25:D448@35:D00aS65:D@Q00248@35:D010aS48@@Q1BU0QS60QBU00`@Q1BU
5:D@Q1BU8@PYBR486<H<HaBU48@25:D00a245:DDY@026<H55:D00a245:D<H`0448@36<H35:D248@3
5:D00aS65:DHaP027>L00aS65:D@Q00348@020aS5:DDYABU48@<Ha245:D448@011BU6<H@Q1BU0PaS
0Q2400DHaR487>LLiaBU008<H`<DY@<@Q0DDY@<HaP<DY@8@Q00536<@Q12448@<H`0348@35:D336<0
11245:D@Q0aS0a2400<<Ha246<H00Q2400@<Ha2448@@Q08<H`0548@HaQS65:D@Q00336<448@01ABU
48@8@PaS48@00QBU0PaS00<@Q0aS48@00PaS00<8@PaS36<01PaS00@8@PaS36<<H`48@P0010@Q00<0
00@Q124010@Q00D8@Re[HaQ:DS6<008mk`8e[@07<H`e[CF]>Lhe[CW>?Nl00d8@0THa0TYB0THa0Sg_
00A243F]=Jde[@LicP8aS003;F/YBRe[008aS003>Lhe[CF]008e[@04>Lhe[CF]>Lh2=Jd01SW>?Nli
cSW>?Nm24096<@03@Q1:DTHa00=24096<@05@Q16<D8@?Nm24003?Nl4>Lh00cg_>Lhe[@02;F/5<H`3
;F/00c6<=JdicP02>Lh00cF]>LhicP02<H`012U:9BT]Jbe[0SF]0c6<00<e[CW>=Jd00SF]0cW>0SF]
00@]JbU::DXYBP<]J`03:DX]Jc6<00<]J`04<H`e[CF]=Jd2;F/3:DX59BT38@P012DY8@PU:B480RU:
00<]JbU::DX00RU:0bDY12U:12e[00<U:BU:;F/00SF]00@aS2U:;F/aS0@]J`<U:@03;F/YBRDY00@U
:@<Q20036<HLiacW00<Q20049BTYBRDY7>L28@P2:DX39BT48@P00aBU36<48@022488124010001244
8@001@@Q00@000@Q1248@P848@0300048@@Q00P48@88@P848@04248<H`aS248448@236<0312436<<
H`Q21248@PaS24848@Q2124<H`D8@P051248@P@Q24848@032484124324801P@Q24848@Q21248@P<4
8@0624848@Q21248@P@Q0PQ220@Q00<8@P@Q12401`@Q0`Q200l48@aS48@@Q0aS248<HaBU48@HaRe[
@Q1[FW>LMkd00Vmk00moog>LJeXaS1cW48@48@Q248@DYA2424848@0012400PQ21@@Q0PQ200<48@Q2
24800`Q21PaS0PQ20`@Q0PQ20P@Q0PQ200<48@Q2248010aS00D@Q1BU48@DYAS6008DY@8@Q0<DY@03
6<HDYAS6008DY@8@Q0<DY@0348@DYAS600@DY@066<HDYABU48@DYA2411BU00HHaQBU48@@Q1BU7>L2
9BT00acW48@DY@035:D46<H55:D00a245:D@Q0026<H01ABU48@@Q1246<H01ABU00l@Q1S66<HLiaS6
5:D@Q1BU6<HLiaS65:D@Q1BU6<H00aBU0a2400@DYA2448@@Q08DY@0548@<Ha2448@DY@0348@25:D2
6<H011BU48@@Q1240QBU0a241ABU0QcW0QS60aBU0a240aBU0a2400<DYA2448@011240`aS00@@Q1BU
48@@Q0<DY@<<H`0448@<Ha2448@45:D648@236<348@00`aS48@@Q00436<01@Q236<<H`aS5:D00a24
1PaS00<8@PaS36<00@Q2000212400`0012448@0312402`Q212448@Q2;F]W>DYB<Ha243g_>Lh00S6<
00De[C6<=Jde[CW>008mk`924003AS5:DTYB0096<@07@Q16<D8@?NlicSF]>Lh00Sg_13W>0SF]0S6<
12e[0SF]00<icSF]=Jd00cW>00@aS3F]>Lhmk`@icP03?Nm6<D8@00A6<@=24003?Nm6<D8@0096<@03
?Nm243g_008mk`<icP03?NlicSF]00LaS004;F/aS2e[;F/2<H`3=Jd3>Lh01CF];F/YBRU:;F/0136<
23F]0cW>0S6<12U:00<]Jc6<<H`012U:00HaS3F]=Jde[C6<;F/2:DX00be[:DXU:@029BT48@P29BT3
8@P01BDY:DXaS2e[:DX00bDY00P]JbU::DXU:BU:;F/aS2e[0bU:00@]Jc6<=Jde[@8aS0<YBP8aS004
;F/U:BDY9BT2;F/00bU:;F/Q20048@P00bDY8@PQ20028@P00bDY8@PQ20038@P29BT03R489BTQ22DY
8@PLibDY8@PLiaBU36<8@P@Q000412400`0012448@0D12402@Q212448@@Q0008@P@Q24848@032488
48@236<424800`@Q248<H`0224821243248010@Q24848@@Q0`Q200<48@Q236<00PQ20P@Q00@8@P@Q
12448@<8@P<48@0324848@@Q00848@<8@P031248@PQ200<8@P@48@0324848@Q200848@0424848@Q2
248212400`Q236<<H`0224803@aS48@@Q0aS48@LibU:<HaJeVLiNmi_Nf]J00=g_@07CW<e[ABU1248
@P@Q24800PaS00<8@P@Q124010@Q00D000@Q1248@P@Q00@8@P03124<H`aS008<H`03248<H`aS0088
@P848@0324848@@Q0088@P848@<8@P@<H`<@Q0045:DHaQS65:D248@01ABU48@DYABU6<H00aBU00L@
Q1BU48@DYA245:DHaP045:D36<H25:D00a245:DHaP025:D00aS65:D@Q00248@01QS68@PU:BDY7>L@
Q08DY@0448@HaQS66<H85:D348@00aBU48@@Q00248@00aS65:DDY@0448@25:D26<H35:D36<H011BU
48@@Q1BU0QS600@@Q0aS48@HaP@DY@0448@DY@aS36<248@25:D236<01a245:DLiaS648@DYAS6008@
Q00636<@Q1BU5:D@Q1BU0Q240QS60QcW0QS600<DYA2448@00Q2400LDYA245:DDYA245:D@Q0025:D2
36<00a245:D@Q00336<00aBU48@DY@0648@436<01QBU6<HHaQBU48@<H`<@Q0095:D@Q0aS36<8@PaS
48@<Ha24008<H`88@P8<H`0448@<H`aS48@25:D00a2436<8@P0636<12480000600048@@Q00048@00
1@@Q00P8@Re[HaQ242e[?Nm243W>0S6<0cF]00<icSF]?Nl00d8@00<mkd8@?Nl00cg_00M243g_>Lhe
[CW>=JdicP03?Nl4>Lh2=Jd00c6<=JdaS003=Jd3>Lh01Cg_>LhicSF]<H`00SF]00HicS6<<H`aS3F]
@Q02AS400d8@>Li24004@Q001cg_@Q12448@AS4mkd8@008mk`03@Q0mkcg_008icP<]J`07=JdicS6<
<H`e[C6<;F/00c6<1CF]0SW>00Le[BU::DXYBRe[=JdaS004=Jd3<H`013F]<H`e[CF]0SW>00<e[CW>
=Jd00be[00@aS3F]<H`aS0@]J`8aS003=JdaS2e[00H]J`04:DXU:B488@P49BT012489BTQ22DY0RU:
00@U:B489BTYBP@]J`@aS003;F/YBRU:008YBP8]J`@YBP8]J`07<H`]JbU:;F/aS2U:8@P00RDY0RU:
0bDY00DQ22DY8@PLib48008U:@8Q208U:@HQ20069BTYBR488@PHaQBU0PaS0`@Q00<000@Q124010@Q
00@000@Q2488@PH48@0800048@@Q00048@00124000<48@0300048@Q200<48@88@P8<H`045:DLibDY
9BT28@P00aBU6<HDY@0236<2124524800`@Q2488@P0224802@@Q24848@@Q24848@Q21248@P021240
0`Q21248@P0324800`@Q2488@P02248312400`Q212448@02124224800`@Q2488@P04124224831240
0`Q21248@P0212401@Q21248@PQ212400PQ21A2400X<HaBU48@LicF]AS5_Ng>LMkecW09W>@05Mkeo
ofmk?NlDY@0212400`Q21248@P0412400`0012448@0412422483124224800`aS248<H`0336<32483
12422482124624800`aS48@DY@0248@00aBU7>LHaP025:D00a245:DHaP025:D00a245:DDY@035:D2
6<H011BU6<HDYABU0aS60a2400HDYA2436<<Ha246<H65:D236<01AcW9BTYBQcW48@00aS600<@Q1BU
6<H00Q2400X<HaBU5:DHaQBU48@DYAS67>LHaPDDY@047>LHaQcW6<H348@35:D011S65:DDYABU11S6
0aBU00<@Q1BU5:D00QBU00DHaQBU48@DY@aS008@Q0<DY@<@Q00436<@Q1245:D26<H25:D236<248@0
11S65:D@Q0aS0aBU00HHaQBU6<HHaQBU6<H35:D448@25:D348@00aBU6<H@Q0025:D248@236<348@0
0aBU48@<H`0336<00a2436<@Q00348@011BU6<HDYABU1Q240PaS0PQ200<<Ha2448@010aS0PQ200<<
Ha2436<00Q240PaS00<8@Q2436<00`aS0@Q20@aS00000`@Q00048@0512403@Q200048@Q2;F]S64Ha
;F/icT8@>Lhe[C6<008e[@07>Lhe[CF]>Lhmkd8@?Nl00T8@00=6<Cg_>Lh00d8@00<mkcW>=Jd00cW>
00<e[CW>>Lh013W>0cF]0c6<00@icSg_>LhicP8mk`05>Lhe[C6<=JdicP03=Jd2<H`01cg_@Q1:DT8@
?Nm244Ha00924004?Nm2448@@Q02AS400d8@?NlicP03?Nl013W>?NlicS6<0Re[00<aS3F]=Jd0136<
00@]JbU:;F/aS08e[@05<H`e[CW>>Lhe[@02<H`012U:;F/aS2e[0S6<00@e[CW>=Jde[@8aS0De[@<i
cP8aS004:DXaS36<=Jd2<H`2;F/0136<;F/aS3F]0S6<1Re[0RDY00DYBRDY8@PQ22DY008Q20057>LQ
22DY9BTYBP029BT5:DX5;F/2<H`5:DX00be[:DXYBP02:DX3;F/00bU:;F/aS002;F/00bDY:DXYBP02
9BT012489BTU:BDY1B4800<U:B488@P00RDY0R4800HLib488@PU:B489BT27>L00b4848@<H`051240
0`0012448@0212400`Q212448@051240100012448@Q220@Q00D8@P@Q12448@Q200848@<8@P0336<@
Q124008U:@07;F/YBQS66<H@Q0aS48@00PaS1PQ20`@Q0PQ200@48@Q212448@88@P0536<8@PQ22484
8@0224821243248010@Q2488@PQ20`@Q0PQ21@@Q0`Q20`@Q00<8@P@Q24800PQ20`@Q00@8@P@Q1244
8@<8@P848@0=248<Ha245:D@Q0aS48@<HaS6:DXe[F<HIcT00WNm00=[FVLiKg/00Woo00MNmbe[2488
@P001248@P0612400`001240000312400`Q212448@02124324800`aS48@@Q00436<2248010@Q2484
8@000P@Q10Q200L<H`Q236<<Ha246<HDY@026<H00aBU6<HDY@045:D00aS65:DDY@025:D011S65:DD
YA240QBU0Q240aBU0Q240QBU00<@Q1BU48@00a2400<DYA245:D00a2400@HaR489BTLi`8HaP035:D@
Q1S600<DY@0536<@Q1BU5:DHaP055:D00aS65:DDY@025:D00aS65:DHaP026<H01aBU48@@Q1245:DH
aQBU00<@Q0036<HLiacW00<DY@8HaP<@Q0036<HDYABU00@DY@8@Q0@DY@0348@<Ha2400<DY@0648@D
YABU5:D@Q0aS0Q2400HDYA2448@<Ha246<H25:D46<H011BU48@@Q1BU0a2400HDYAS648@@Q1BU6<H2
5:D648@236<00a2436<@Q00348@336<248@01QBU48@DYABU6<HDY@<@Q0<<H`8@Q00336<@Q124008@
Q0<<H`04248<H`Q2248236<248@436<248@336<1248000848@0300048@0000H48@07248aS5kg@Q0Y
BSF]?Nl00SF]00DicSg_?NlmkcF]00<icP<mk`924003?NlicSW>008icP<e[@8icP<mk`03AS52448@
00<e[@03<H`e[CF]008e[@03>Li2448@00924004?Nm2448@@Q02>Lh01Cg_<H`]Jc6<=Jd00Sg_00He
[CW>=JdicSg_@Q03?Nl00cW>?Nm24002?Nl0148@?NlicSg_0T8@00@mkcW>=Jde[@8aS0<e[@03<H`Y
BRe[008]J`05<H`e[CW>?Nle[@02?Nl0236<:DXU:Be[<H`YBRe[<H`2=Jd4<H`01SF]<H`aS36<;F/e
[@<icPDaS006;F/YBRU:;F/aS3F]0S6<0be[0RU:0Re[00DaS2e[:DX]JbU:00DU:@<Q20039BTYBRU:
008YBP039BTQ22DY008YBP05;F/aS3F]<H`e[@02>Lh01C6<;F/U:BU:;F/00RU:00@]JbU::DXU:@8Y
BP049BTYBRU:;F/29BT012489BTaS36<0RU:0R4800<U:B488@P00R4800DYBRDY:DXYBR48008Li`03
8@PYBR4800<Q20049BTQ21S648@4248712401P0012448@00124000@48@0300048@Q200848@030004
8@@Q00P48@88@P04124<Ha246<H2<H`02DicDYAF]E:D=Jd]Jb485:D@Q00236<42482124010Q21248
@PQ20PaS10@Q0`Q210@Q20Q200<48@Q2248010@Q0PQ20P@Q0`Q20`@Q00D8@P@Q24848@Q200<48@88
@PH48@88@P8<H`0348@HaQS6008<H`085:D]Jcg_@Q1>LeJeJeYcW09_N`07LiaoofmkCW<Q20aS2480
0P@Q00<8@P@Q24800P@Q00<8@P@Q12400`@Q0PQ20P@Q0`Q200@48@Q22488@P<<H`H8@P848@88@P03
1248@PQ2008<H`04248@Q1246<H35:D248@00aBU48@DY@025:D26<H01ABU6<HHaQS65:D00Q2400LH
aQBU48@@Q1BU7>LDY@0248@55:D01Q245:D@Q1245:D@Q0<DY@0736<@Q248;F/aS24848@00aBU00<@
Q1BU48@00QBU0Q240QBU00PLiaS648@<Ha247>LQ21cW0a240QBU0QcW11BU00@LiaS66<HDY@8@Q08D
Y@@HaPHDY@0548@DYABU5:DHaP025:D02A245:DDYABU6<H@Q1BU48@DY@046<H00aBU36<<H`0248@0
11BU48@<H`aS112400DDYA245:DDYA24008DY@0348@DYA24008DY@8HaP8DY@0548@DYA246<HDY@03
48@00aBU48@@Q00648@00`aS248<H`0248@010aS248<Ha2411BU11241`aS0Q2420aS0aBU00<@Q0aS
36<00PaS0a240@aS00000`0012448@0212400`001248@P0312401@Q2;F]NmdHa:DX00SW>0SF]00<i
cSg_?Nl00SW>00DmkcW>>LhicSg_00924003?Nm243g_008mk`03=JdicS6<008e[@03>LhmkcF]008m
k`924004?NlicSW><H`3=Jd013W>=Jde[Cg_0T8@13g_0T8@00<mkcW>=Jd00S6<0SW>00DmkcF]=Jdi
cSg_008icP03<H`icT8@00924003?NlicSg_00@mk`03@Q0mkcW>008e[@05<H`e[CF]<H`e[@02<H`0
0be[:DXYBP02<H`3>Lh01cg_>Lhe[Be[:DXU:Be[00TaS0<e[@05;F/aS36<;F/e[@02>Lh023F];F/a
S3F]<H`]JbU:9BT2;F/2<H`00be[<H`]J`03:DX7;F/29BT28@P012DY8@PQ22DY0bU:00@U:B488@PQ
208U:@03:DX]Jc6<008aS006=JdicSF]<H`]JbU:0be[00<YBRDY9BT00RDY00<YBRDY9BT00bU:0bDY
0RU:0Re[0RDY0R4800HYBR488@PQ22DY:DX79BT28@P00bDY8@PQ20027>L236<00`@Q2488@P021240
100012448@000P@Q00<000@Q12400`@Q00<000@Q12401`@Q00@8@P@Q124000<48@0=24848@@Q1248
@PaS5:DQ22U:AS5>LeJeF]H00T8@00@]Jb486<H<H`88@P031248@PQ20088@P041248@PQ224821242
2484124010Q236<8@P@Q0`Q20P@Q1PQ210@Q0PQ200H48@001248@PaS248412400`Q212448@021242
2483124010Q212448@@Q0`Q20PaS01HDYAcW6<H@Q0aS48@Q236<>Li:DTicHaQ_Ng>LJeY_NgooNmiS
63F]6<H@Q088@P061248@P@Q24848@0020@Q00<8@P@Q12400`Q200<48@Q236<00PaS0PQ200@<H`Q2
12448@88@P848@D8@P0736<8@Q2448@DYAcW6<H00aBU00H@Q1BU5:DHaQ245:D26<H27>L26<H02QBU
48@@Q1245:DHaQBU6<HDYA240QBU00<HaQBU48@00PaS1QBU00XHaQ2448@DYB48:DXU:AcW6<H@Q0<D
Y@@@Q0<DY@8HaP8@Q08DY@8Li`<DY@0648@DYAcW7>LHaQBU0Q2400<DYAS66<H00QS600@DYAS65:DD
Y@8HaP045:DHaQBU6<H45:D248@00aBU48@HaP035:D011246<HHaQS60a2400<DYAS65:D00QBU0Q24
00<<Ha2448@00a240PaS1Q240QBU0a2400<DYA245:D00QBU00@HaQBU48@<H`8@Q0035:D@Q12400D@
Q0<<H`<@Q08<H`0348@<H`aS008<H`DDY@D@Q004248<H`aS36<248@336<01`Q236<<H`aS248<H`Q2
00@DY@8<H`<@Q08<H`48@P0000<48@0012400`@Q018000@Q24848@00248aS6]JAS4YBSF]?Nle[CW>
=JdicSg_>Lh2=Jd2>Lh01D8@?NlmkcW>?Nl00d8@00HicSg_?NlicSF]>Lh3?Nl013W>?Nlmkcg_0d8@
00<mkcW>=Jd00SW>00<e[CW>=Jd00Sg_00=243g_>Lh00Sg_00a243g_?NlmkcW>?Nm244Ha@Q0mkcF]
<H`6=Jd2?Nl01CF]@Q16<DHa?Nl02CW>0SF]00<aS3F]<H`00be[00@aS3F]=JdicP8mk`06@Q0icS6<
<H`mkcW>0c6<00<icSF]=Jd00S6<00@icSF]<H`aS08]J`04<H`e[CW>=Jd2<H`00be[:DXaS002;F/4
<H`5;F/02BU:9BTU:BU:9BTQ22DY;F/YBP028@P00bDY:DXU:@028@P00bDY:DXYBP02;F/012DY8@PQ
22DY0RU:00DU:B48:DXU:BU:00<]J`<YBP03;F/YBRU:00@]J`03:DXQ22DY00<YBP<Q20099BT]Jc6<
;F/YBR487>LQ22DY008Q20057>LU:Be[;F/YBP058@P29BT022487>LLiacW6<HDYA2436<224851240
0`0012448@0312400`0012448@0@124224800`@Q248<H`0224801QS6:DY:DTicHaQ[FP9_N`05F]IW
>DHa<H`Li`0236<00`Q236<@Q00236<31244248212400`Q212448@02124424821244248212400`Q2
1248@P0312400`Q21248@P0324821242248212422484124010Q212448@@Q0`Q20P@Q0PQ20PaS00@H
aR488@PDY@8@Q0059BTYBRDY=Je24002DY@015[FHaQF]E:D0Sg_00<aS2485:D01PQ200<48@Q21240
1@@Q0PQ200<48@aS36<00`@Q00<8@PaS24800PQ200<48@Q2124020Q200@<H`@Q36<@Q08HaP045:DH
aQBU5:D348@55:D00aS67>LDY@045:D00a245:D@Q0046<H0112436<@Q1240QS600DDYA2448@@Q1BU
00@@Q0035:DHaQBU008@Q08HaP04:DX]JbDY6<H25:D011S65:DDYA240QBU00<@Q1BU48@00aBU00@@
Q1BU5:DDY@8@Q0035:DHaQS6008DY@<Li`086<HLiaS65:DHaQBU6<HQ208Li`8DY@8HaP035:D@Q0aS
008DY@056<HDYA2448@DY@046<H35:D02AS65:DDYABU7>LQ21S65:D@Q0075:D0112436<<H`aS1Q24
00<<Ha2448@0112400<DYAS66<H00QS600@@Q1BU48@DY@8HaP8DY@@@Q08DY@0348@8@PaS00<<H`T@
Q0035:D@Q124008@Q0035:D@Q0aS00@<H`0348@<H`aS008<H`0548@<H`aS248<H`0448@00aBU48@D
Y@035:D148@136<000848@0300048@0000848@0924848@@Q1248@Re[HaQ:DRe[008icP03=JdicSF]
00@mk`<icP<mk`8icP07@Q0mkd8@?NlicSg_=Jd00cW>00DmkcW>=JdicSg_008icP924004?NlicSW>
>Lh2=Jd3>Lh013g_>Lhmkd8@0Sg_0T8@00@mkcW>>LhicP96<@92408icP8e[@03>Lhe[C6<008icP<m
k`=24006?NlicSW>>LhmkcW>0SF]00LicSg_>LhaS3F]<H`e[@03<H`012e[>LhicSW>0Sg_0SF]00@a
S3F]>Lhe[@8aS0<e[@@aS003=JdaS36<008aS005;F/aS3W>>LhaS004;F/2<H`012e[<H`e[C6<12e[
00HaS2U:9BTU:B489BT4:DX39BT28@P49BT3:DX01RDY8@PU:Be[:DXU:@8Q20059BT]Jc6<<H`YBP02
9BT2;F/2:DX3;F/012U:9BTYBRDY12U:00<U:B489BT01BU:0b4800LU:AcW7>LQ22DY:DX]J`02:DX0
0bDY8@PU:@028@P39BT00b487>LLi`0248@00`aS24848@0912400`0012448@0312400`0012448@03
12400`0012448@0712404PQ212448@@Q36<@Q1S6=Jdmkf<HIcU_Ng>LIcU[FU:D@Q0YBP8@Q088@P8<
H`03248<H`0000848@0536<@Q0aS1240000312400`Q21248@P0424800`@Q2488@P04248212401P00
12448@Q21248@P<48@@8@P848@0536<8@P@Q1248@P0612400`Q21248@P021242248236<011247>LL
iaBU0PaS00<HaQcW9BT00S6<00=6<DYBF]H00e[F00]:DSg_<H`U:AcW36<8@P@Q248<H`Q200T48@<8
@P031248@PQ200@8@P848@0324848@aS00D8@P848@@8@P0436<DYAS65:D248@45:D00a245:DHaP02
5:D26<H011cW6<HDYA240aBU0Q2400<DYAS65:D00Q2400@DYAS65:DHaP<@Q0055:D@Q1245:D@Q002
5:D010aS48@DYAS60QBU00HU:C6<;F/Q21245:D26<H35:D00a246<HDY@0448@85:D021245:DDYABU
7>LHaQcW6<H25:D26<H28@P021cW6<HLiaS65:DHaQcW5:D248@01ABU7>LDYABU48@00QS600<DYAS6
48@00QBU00LHaQ246<HDYAcW6<HDY@027>L01AS65:DHaQS65:D01A2400D<H`Q248@<Ha2400<<H`03
48@DYABU008@Q00336<@Q1BU008DY@036<HDYAS600<@Q0065:DHaQS66<H@Q1BU0Q240PaS1Q2400<<
Ha2448@00QBU0`aS0QBU00<HaQ2448@011242PaS00<@Q0aS36<00`aS0Q2400<<Ha245:D00aBU0A24
0@Q200000`0012448@0212402`0012448@Q200048@Q2<Ha_Ne:D<H`00Sg_0SW>0Sg_0d8@13g_00E6
<Cg_@Q0icSF]008icP03?NlicSW>008e[@05>Lhe[CW>>Lhmk`02>Lh0148@?NlicSW>0cg_00<icSF]
>Lh00SW>13g_13F]00HicSF]=Jde[CW>?Nl2AS42@Q0013g_@Q0mkcg_0SW>0cF]00<aS3W>>Lh014Ha
00LmkcW>>LhicSg_@Q0icP04=Jd013W>=JdaS2e[0cF]0cW>00@e[CW>>Lhe[@8aS003>Lhe[C6<00<a
S003>Lhe[C6<00<]J`06<H`e[Be[;F/YBS6<0SF]00@aS2e[;F/]J`8aS003:DXaS3W>008aS004:DX]
Jbe[:DX49BT3:DX29BT28@P01BDY8@PQ22489BT012U:0RDY12U:0bDY00<Q22DY:DX00RU:0bDY00@Y
BRDY:DXYBP8aS005:DX]Jbe[:DX]J`02:DX49BT4:DX00bDY8@PQ20037>L00aS67>LLi`029BT01R48
9BTU:BDY8@PU:@8Q20<U:@048@PLiaS648@2248212400`001248@P0212400`0012448@0812400`00
12448@03124010001248@PQ21@@Q00P8@PaS248@Q1S6:DYBU5[F0WNm0f]J0Woo00A[FSW>5:D<H`84
8@0436<@Q1BU248=12401PQ212448@@Q24848@D8@P031248@P@Q0088@P<48@88@P8<H`<8@P848@07
24848@Q224848@Q200001P@Q00<8@P@Q24800`@Q00<8@PaS6<H00QcW00<HaQ2436<00Q2400<DYAcW
7>L00RDY00LaS3F];F/YBQcW6<HDY@0248@5248712401PaS12448@Q236<8@P<48@D8@P848@88@P04
36<8@PQ236<4248248@02ABU6<HDYABU48@<Ha2436<@Q0045:D011246<HDYAS60QBU00@HaQ2448@@
Q0@DY@0548@DYABU6<HDY@0248@01ABU48@DYABU48@00aBU0a2400DDYA2448@DYAS6008@Q0097>LY
BS6<;F/LiaS648@DYAS600LDY@<HaP0448@<Ha2448@35:D26<H35:D36<H00a245:DHaP027>L26<H0
11BU6<HDYABU0aS60QBU0aS600@DYAS65:D@Q08DY@046<HDYA2448@45:D01AcW8@PHaQBU48@00QBU
0QS600@DYA245:DDY@8@Q0035:D@Q124008<H`88@P0336<@Q12400@@Q08<H`8@Q0<DY@0448@DYABU
6<H25:D248@00aS65:DDY@0448@00`aS48@<H`0348@236<0212436<DYA245:D@Q1BU48@336<01124
5:D@Q1240PaS1Q2400<DY@aS36<01@aS00@8@PaS48@@Q08DY@4<H`0010@Q00<000@Q124010@Q00D8
@S6<Kg]F]Be[00<icP@mk`04@Q0mkd8@@Q02?Nl013W>@Q1243g_0cW>00DmkcW>>Lhe[CW>00<e[@03
>Lhmkcg_00<mk`<icP03@Q0mkcW>008e[@08>Lhmkcg_>Lhe[CW>?NlicP8e[@<icP04=JdaS3W>>Lh2
AS40148@AS52448@0Sg_0cW>0SF]0S6<00@mkdHaBU96<@<icP07=JdicSg_@Q0mkcF]<H`00cW>00Da
S2e[;F/]JcW>00@mk`03>Lhe[CF]00<aS08e[@8aS004=JdaS36<;F/4<H`3;F/00c6<;F/aS002=Jd0
0c6<;F/aS002=Jd01S6<;F/e[CF]<H`YBP<]J`05:DXU:BDY8@PU:@02:DX29BT38@P00bDY8@PQ2002
9BT01BU:;F/YBRDY8@P00RDY0RU:0bDY00<Q22DY9BT00RU:00<U:B489BT012U:00<]JbU:;F/00be[
0RU:00D]JbU::DXQ22DY008Q2008:DX]Jbe[:DXQ21cW8@PLi`8HaP057>LQ22489BTYBP039BT01R48
9BTU:BDY8@PLi`8Q208HaP8<H`0324848@@Q00T48@0300048@@Q00D48@0400048@@Q0006124010Q2
12448@@Q0PQ2010<Ha246<HicTYBLiag_G>LKg][FVmkMkeooekg<H`DY@848@04248<H`aS36<>1240
0`Q212448@08248212400`Q21248@P02124010Q21248@PaS0Q2400<<H`@Q12400PQ200@<H`Q22484
8@88@P@48@0424848@@Q124224800`@Q248<H`025:D26<H35:D011245:DHaQcW0RDY0be[00@aS1cW
7>LDY@8@Q00336<8@PQ200P8@P848@<8@P051248@P@Q24848@02248010aS24848@@Q2`Q200L<H`Q2
48@HaQcW6<H@Q00236<248@65:D00aS65:DDY@035:D01A245:D@Q1S65:D011S60QBU00@@Q1BU6<HD
Y@8@Q0035:DHaQBU00<DY@<@Q0035:D@Q1BU008@Q0077>LU:Be[;F/Lib486<H00QBU00H@Q1BU6<HL
iaS648@25:D26<H55:D348@02ABU6<HHaQS65:DHaQBU6<HDY@046<H00aBU6<HDY@025:D26<H00acW
6<H@Q0025:D36<H45:D26<H00aBU48@@Q0035:D01AS65:DHaQcW5:D00Q2400<DYAS65:D00QS60aBU
00@@Q0aS36<<H`<@Q0<<H`@@Q0035:DHaQBU00<@Q08DY@0648@DYAS66<HDYA2411BU00<HaQ2436<0
0`aS00<DYA2436<0312400@DYA2448@@Q08<H`8@Q0035:D@Q0aS008<H`0448@<Ha2448@836<00a24
5:D@Q00136<0000300048@0000<48@0=0008@PQ2124000aS=JecW5Je<H`mkd8@>Lh00Sg_00A6<D8@
AS52408mk`A24006AS52448@@Q0icSg_0SW>0cF]00DaS3F]=JdicSF]00<icP8mk`=24003?Nle[C6<
00DicP8mk`8e[@08>LhmkcW>=JdaS2e[<H`e[@8icP8mk`03@Q0mkcg_00=24003>LhaS3F]00@e[@03
>Lhmkd8@008icP03?Nm244Ha00<mk`05>LhmkcW>=Jd]J`03<H`2=Jd01cW>@Q1243W><H`]JcF]008i
cPDaS0<]J`04<H`]JbU::DX3;F/00bU:;F/aS002<H`2:DX01Be[<H`e[C6<=Jd00S6<1Be[0RU:00<U
:BU::DX00Re[1BU:00<U:B488@P00bDY0bU:0RDY00@]JbU::DXU:@8YBP069BTQ22DY:DX]JbU:0RDY
0R480bDY00HYBRDY:DXYBRDY:DX29BT3:DX01BDY8@PU:BDY:DX00bDY00DQ21cW6<HLiaS600<Li`03
9BTQ22U:008YBP04;F/YBRDY8@P27>L38@P00aS636<8@P0412400`001240000712400`0012448@0>
12401@Q236<8@PQ236<00QS600<U:D8@CW<00W>L00U_Ng>LJeY[FWNmOomcW36<36<00P@Q00<8@P@Q
24800`@Q00D8@PaS2488@P0000D48@0424848@@Q2484124324800`aS2488@P041244248010aS48@@
Q1240PQ200@<H`Q224848@<8@P0;1248@P@Q24848@Q21248@P@Q24848@0324801`@Q36<<HaBU7>LH
aQ24008<H`0448@HaQBU6<H25:D01QS65:D@Q12436<@Q08<H`@8@P031248@P@Q00<48@03248<H`Q2
00<48@0324848@Q200848@0324848@@Q0088@P848@<8@P0336<8@PQ20088@P0836<@Q1BU7>LHaQBU
48@<H`<@Q00:5:D@Q1245:D@Q0aS48@HaQcW6<H348@011BU6<HHaQS61ABU0Q2400D<Ha245:DHaQBU
00<@Q0035:DHaQBU00@DY@8@Q08HaP8DY@0:6<HQ236<;F/U:AcW48@DYAS65:D46<H35:D26<H55:D0
0`aS48@@Q0035:D011245:DDYAS62ABU0Q2400@HaQcW7>LLi`8DY@8HaP8Li`056<HDYABU5:DHaP02
48@010aS5:DDYA240QBU0QS600H@Q0aS36<8@PaS5:D26<H00aBU48@@Q00348@336<648@021BU48@<
H`aS48@DYA2436<248@25:D448@01ABU48@DYABU6<H00aBU0Q2400@DYA245:D@Q0<<H`X@Q0035:D@
Q124008<H`L@Q0<<H`0348@<H`aS00@<H`03248<H`aS008<H`48@P000`@Q00<000@Q12401@@Q00D8
@S6<LiaJeS6<009240@mk`924006AS52448@@Q0mkd8@0Sg_148@00<mkcW>>Lh00SW>00<e[CW><H`0
0S6<00<e[CW>>Lh013W>00A243g_>Lhe[@8icP05?NlicSW>>Lhe[@02>Lh01Cg_>LhmkcW>=Jd0136<
0cF]0cW>00<mkd8@AS400T8@1CF]00@aS3W>?Nm240<icP03?Nm6<DHa008mk`<icP05?NlicRe[;F/a
S002>Lh01cF]>Li243W>=Jd]Jc6<008icP8e[@@]J`06<H`]JbU:;F/aS2e[0bU:136<00@e[Be[;F/]
J`@aS003=JdaS36<008aS006=Jd]JbU:9BTYBRDY12U:0Re[00<YBRDY8@P0124800<U:BU:9BT00RDY
0RU:0Re[00DYBRDY9BTQ22DY00@YBP<U:@<Q208U:@DYBP@Q2004:DXU:BDY8@P29BT00bU:9BTQ2002
9BT011cW6<HHaQS60QcW00<Q22DY:DX012U:00HU:B488@PLibU:9BT28@P00`aS48@8@P0<12401@00
12448@@Q00000`@Q00<000@Q00001P@Q00H8@P@Q12448@Q236<25:D02QS6<H`mkf]JKg]cW7NmJeYW
>Fmk0Woo00ABU2DY12448@<8@P<48@04248<H`aS248812401`Q21248@PQ21248@P@Q00<8@P0336<8
@P@Q00848@88@P0636<8@PQ2248<HaBU0PaS00@8@PaS36<<H`88@P848@0324848@Q200<48@<8@PD4
8@88@P0348@DYAcW008HaP0648@<H`aS36<@Q1S60QcW00<HaQBU5:D00Q240`aS00<8@PaS36<00`Q2
0P@Q00<8@P@Q36<010Q20P@Q00<8@P@Q12400P@Q0`Q20P@Q00D8@P@Q248<H`Q2008<H`88@P8<H`8D
Y@036<HDYABU00X@Q0035:D@Q1BU008HaP8DY@<@Q08HaP037>LDYAS6008DY@<@Q0@DY@0448@<HaBU
5:D26<H75:D448@01bU:=Jd]JbDY36<@Q1BU008HaP057>LHaQS66<HDY@056<H00a245:D@Q00348@3
5:D248@26<H27>L011BU48@DYABU0QS600<DYA2448@00QBU0acW0aBU0QcW00<HaQcW5:D00aBU1a24
00@HaQcW5:D@Q0<<H`8@Q08HaP035:D@Q0aS008DY@0348@<H`aS00<@Q08<H`D@Q08<H`<@Q0035:D@
Q124008@Q0046<HDYABU48@35:D00aS67>LDY@0348@00aBU48@@Q00348@436<248@00aBU48@@Q002
48@011BU48@<H`aS112400<<Ha2448@00a240PaS0Q2400<<H`Q224800PaS0Q240@aS0@Q200000`00
12448@021240300012448@Q200048@Q2=Je_Ne:D;F/icP8mk`924003AS5:DTHa0096<@924096<@06
BU96<Cg_@Q0mkd8@0Sg_00<icSg_@Q000THa0T8@0SW>0SF]00DicSF]>LhmkcW>00<mk`05@Q0mkd8@
?Nm24004>Lh2?Nl3>Lh2=Jd2>Lh02CF]<H`aS3F]>Lhe[CW>=Jdmk`02@Q002Cg_>Lhe[C6<=JdicSg_
>Lhe[@03<H`013W>?NlmkdHa0Sg_00I6<CW>>LhaS2e[<H`2=Jd3>Lh013F]<H`aS2e[0S6<00<]Jc6<
<H`02C6<0Re[00<YBRe[;F/00be[00<YBRe[;F/00Re[00<YBRe[<H`00S6<0RU:0be[00DYBRDY;F/Y
BS6<008]J`09:DXU:Be[;F/YBRe[9BTLib48008U:@8YBP8U:@8YBP0:;F/YBRU::DXU:AcW8@PU:BU:
;F/39BT48@P29BT01RU:9BTU:B487>LQ20<U:@038@PU:B4800<Q20<]J`04:DXU:BDY9BT27>L26<H0
2B489BT]Jbe[8@PU:B489BTQ20059BT01b486<HDY@@Q24848@0000/48@0500048@@Q124000091242
248312401`Q248@HaQS67>L]Jcg_009JeP0<IcU_NfmkMke[FV<HBU8icS6<6<H<H`Q20`@Q00@<HacW
9BTLi`88@PH48@T8@P0336<8@PQ200<8@P848@03248<H`Q200<8@P<<H`051248@PQ224848@022480
20aS2488@PaS24848@Q21242248212400`Q21248@P02124224801a24248@Q248:DXQ21BU008<H`H@
Q0<DY@0548@<H`Q236<48@0424821243248212400`Q21248@P05124224821245248010aS2488@PaS
1QBU00<HaQBU36<00a240aBU00D@Q1BU5:DDYAS600<DY@0348@DYA24008DY@0736<DYABU7>LHaQBU
6<H00aBU00<@Q1BU6<H00aBU0a2400TDYAS65:DHaQBU6<HDYAS65:D00aS600LQ22DY8@PLia245:DH
aP055:D00aS65:D@Q0026<H25:D00a245:DDY@0448@25:D01QS65:DHaQcW6<HDY@8@Q0<DY@0448@D
Y@aS48@25:D46<H248@01QBU7>LLiacW6<HDY@8HaP8DY@L@Q0045:D<H`aS248336<00a245:D@Q002
48@00`aS48@@Q00248@011BU36<<H`aS0Q241@aS0Q2400<DYA2436<00PaS1A240PaS00H@Q1S66<HD
YA245:D248@35:D236<248@00`aS48@<H`0248@010aS48@DYA2411BU00LHaQ2436<<Ha246<H@Q004
36<348@00`aS48@<H`0636<1248000@48@0400048@@Q248312403`Q2<Ha_Ne:D;F/icT8@>Lhmkd8@
AS5:DTHa@Q16<@03@Q000dHa@Q16<@03@Q02?Nl2>Lh00cg_@Q124002?Nl00d8@?Nlmk`02=Jd7>Lh3
?Nl4@Q03>Lh2@Q001Cg_>LhicSW>?Nl00SW>00<aS3F]<H`013F]0SW>13g_13F]00DicSg_>LhicSF]
008aS003>Li2448@00924004?NlicSW>=Jd3<H`013W>=Jde[CW>0SF]00<aS2e[;F/00RU:0Re[136<
00<e[C6<=Jd00S6<00/]JbU:;F/YBRe[<H`]JbDY;F/YBSF]008aS003;F/YBRe[008aS003;F/YBRe[
00<]J`8YBP<]J`8YBP8U:@<YBP8U:@8Q20DU:@06:DXU:BU:;F/YBRDY12480RDY00@YBRDY9BTLi`@Q
208U:@03:DXU:BDY008U:@8Q20037>LQ22DY008U:@038@PU:BDY00<]J`03:DXU:B48008Q208HaP03
7>LQ22U:008YBP8U:@067>LU:B488@PU:B480RDY00<LiaS636<01@@Q00<000@Q12402`@Q00@000@Q
124000H48@0R24848@@Q1248@PaS48@DYAS69BT]JdicDYAS66LiJeYg_FmkIcUBU4YB@Q0Q21BU124<
H`Q2124<H`Q26<HLiaS636<512400`Q21248@P02248010@Q2488@PaS1`Q200<48@Q224800P@Q0PQ2
0`aS00<8@PaS24800PQ20P@Q0PQ20PaS0PQ20P@Q1PQ21@@Q00d8@PaS36<DYAcW6<HU:B4848@<H`Q2
36<@Q00236<00a245:DDY@025:D0112436<8@PQ20P@Q0PQ20`@Q0`Q200@48@0012448@88@P031248
@PQ200<48@0424848@Q21245248248@00aS65:DDY@025:D748@01QBU48@@Q1BU48@HaP<DY@046<HD
YABU48@236<01A246<HDYAS65:D00aS600<DYA245:D01QBU0a241aBU0QS60QBU00HLibDY:DXU:ABU
48@35:D011245:DDYAS60QBU0Q2400<HaQBU5:D00QBU0Q241QBU0QS600<LiaS65:D00a240QS600DD
Y@aS36<<Ha2400@HaP8DY@0;6<HDYAcW6<HLiaBU6<HDYAS65:DHaP025:D236<448@336<00`Q236<<
H`0248@336<01a2436<DYABU6<H@Q0aS008@Q0<<H`0348@DYA24008<H`8@Q0045:D<H`aS36<348@0
0`aS48@DY@0248@25:D26<H236<248@26<H00a2436<<H`0248@336<448@01QBU48@@Q1BU6<HDY@<@
Q0096<H@Q0aS36<@Q1BU48@<Ha2400<<H`88@P@<H`48@P0000<000@Q00000`@Q00X000@Q248000@Q
248]JfLiDY@aS0DicP03@Q16<DHa009:DPQ6<@924005AS4mkd8@>Lhmk`02>Lh00cg_>Lhmk`04>Lh2
?Nl2>Lh0136<>LhicSF]0Sg_00=244Ha@Q000dHa00=243g_?Nl00SW>00=243g_@Q000SW>0SF]0SW>
0c6<00Pe[CW>>LhicSg_>Lhe[Cg_0T8@00DmkcW>>LhicSF]00<icP04?NlicSW>@Q02>Lh2<H`00cF]
<H`e[@02=Jd4>Lh01S6<;F/YBRe[<H`e[@@aS08icP8e[@07<H`]Jbe[:DX]Jc6<:DX012e[00TYBRe[
<H`aS2e[:DX]JbU:<H`00Re[00@YBRDY:DXYBP8U:@03:DX]Jc6<00<YBP<]J`039BTQ22DY00@Q208U
:@@YBP<U:@@Q20039BTQ22DY008U:@098@PU:BDY:DXU:B489BTYBRDY008Q2006:DXQ22488@PU:BU:
0bDY12U:00<]JbDY8@P00b4800<HaR489BT00Re[00<U:B488@P00RDY00<]JbU:8@P00QcW0RDY00<Q
212436<01P@Q00<000@Q00004@@Q00<000@Q12400P@Q00<8@Q2436<00PaS00HDYAS67>L]JcF]DY@2
CW<015JeBU8icRU:0QcW00<HaQBU24800`Q20PaS1`Q20P@Q0`Q200D48@Q2248<H`@Q0088@P8<H`07
24848@@Q36<DYAS648@00PQ210aS00<8@PaS24801@Q20`@Q00@<HaBU6<HDY@D8@P848@0324848@Q2
00@8@P8<H`0;48@DYAcW7>LHaQBU24848@Q236<@Q00236<348@3248412400`aS2488@P0224871242
2482124524800`@Q2488@P0224800`aS48@HaP026<H01QcW6<HHaQBU6<HDY@@@Q0055:D@Q1BU48@D
Y@026<H021BU48@@Q1S648@DYA246<H55:D00aS65:D@Q00248@01ABU48@@Q0aS48@011BU00<@Q1BU
48@00a240QS600<LiaS66<H00Q2400@LibU::DXQ208DY@036<HDYABU008@Q0065:DHaQBU48@<Ha24
1aBU0a240aBU1AS60Q240aBU0Q2400<DYA2448@00Q2400HHaQcW6<HDYA245:D36<H00acW5:DHaP02
5:D00a245:D@Q0045:D348@236<01Q2436<@Q12436<@Q0<<H`8DY@056<HDYA2448@<H`0548@00`aS
5:D@Q00548@00`aS248<H`0348@00`aS248<H`0248@011BU48@@Q0aS0Q2411BU00<@Q0aS36<010aS
1A2400<DYAS65:D02A240`aS00@@Q0aS48@@Q08<H`041248@PaS36<2248000<48@0300048@000084
8@0824848@@Q248]Jf<HBU8YBP8mk`03=JdicSF]008mk`03@Q1:DTHa009:DP03@Q16<D8@0096<@03
BU9244Ha00=24004?NlicSg_?Nl4>Lh00cg_>LhicP04?Nl3=Jd00cW>?NlicP02@Q02AS42@Q000dHa
?NlicP03?Nl2>Lh0148@?NlicS6<0SF]0SW>00@aS3F]=JdicP8mk`@icP0@?Nm6<D8@>Lhe[C6<=Jdm
kcW>?Nle[D8@?Nm243g_<H`3;F/00cW>=JdicP02>Lh013F]>LhaS3F]0be[0S6<0Re[0S6<13W>00Da
S2U::DX]JbU:00D]J`03:DX]Jc6<008aS004;F/YBRe[:DX2;F/::DX01BDY:DX]Jc6<;F/00RDY0b48
00<Lib489BT012DY0bU:00DU:AcW8@PLib4800<U:@04:DXU:BDY8@P29BT012489BTU:BU:12DY1248
0bDY0RU:00<U:BU::DX00RU:0R4800<U:B488@P00R4800@U:BU::DXU:@8Q20039BTYBRU:008YBP07
7>LHaQcW9BTQ21BU24800P@Q00<000@Q124020@Q00<000@Q00000P@Q00<8@P@Q124020@Q0PQ200D@
Q0aS36<8@PaS008HaP8]J`07?Nm244icF]I:DT8@;F/00RDY00<HaQ2436<00`aS0`Q200<<H`Q22480
10Q20`@Q0PQ200<48@Q236<00PQ20`aS00<8@P@Q12400PQ210aS00<8@PaS36<00PaS1PQ200@48@Q2
12448@88@P0548@HaQBU48@8@P021244248010@Q24848@@Q0PQ20`aS00HDYAS66<HHaQ2436<22480
0`aS248<H`0248@01@aS2488@PaS24800P@Q0`Q200@48@Q22488@P@48@030008@P@Q00H48@032484
8@Q200<8@P<<H`0348@DYAcW008HaP045:DHaQBU6<H248@25:D248@00`aS48@HaP026<H25:D01124
5:DDYA240aS600<DYA245:D00QS60aBU1A2400@<Ha2448@HaP<DY@8@Q0035:D@Q1BU008Li`048@PH
aQBU48@26<H2:DX00bDY8@PDY@0448@55:D00a245:DDY@045:D248@25:D00a246<HDY@036<H01acW
5:D@Q1245:DHaQBU00<@Q0<<H`045:DHaQS65:D248@01aBU6<HLiacW6<HLiaBU00<@Q0046<HDYA24
48@45:D01a2436<<H`aS248<H`Q200H@Q08DY@D@Q0<<H`0548@DYA2448@<H`0248@00aBU36<8@P02
36<248@00`aS48@@Q00336<011245:D@Q1240PaS00D@Q1BU6<HDYAS6008@Q00336<@Q12400@<H`8@
Q0<DY@D@Q08<H`8@Q0@<H`8@Q00336<8@PaS008<H`03248<H`aS004<H`0000<000@Q124020@Q00D8
@S6<LiaJeS6<008icP03=JdicSW>00=24003?Nm2448@00924096<@06@Q0mkcg_AS5244Ha0TYB00A6
<D8@?Nm240PicP<mk`03>Lhe[CW>008icP03=JdicSg_00924003?NlicSg_00=24006?Nm2448@@Q0m
kcW>0cF]00@icSF]>LhicP8mk`8icP8mk`8icP03?Nm2448@008icP8e[@8icP05?NlicSW>=Jdmk`02
AS400d8@?Nle[@02>Lh023F]<H`e[CW>AS5243g_>Lh2<H`022e[<H`e[C6<;F/aS3F]>Lh2<H`01be[
<H`aS36<;F/aS3F]008aS003;F/YBRU:008]J`03<H`]Jc6<008e[@04<H`YBRe[<H`3:DX00be[:DXU
:@03:DX39BT4;F/022U:8@PU:BDY:DXU:AcW9BT3:DX01b487>LU:B489BTQ22DY008Q20@U:@@Q2003
9BTQ22DY008YBP03;F/YBRU:008YBP<U:@03:DXU:BDY008U:@<]J`<U:@0:8@PLiacW7>LU:B489BTQ
22DY8@P59BT28@P012U:<H`U:AS61@@Q00<8@P0012400P@Q00<000@Q12401P@Q00@000@Q1248@P@4
8@0500048@@Q248<H`0248@01`aS248<H`aS48@HaQcW008Q20047>LQ22486<H348@7248412400`Q2
12448@03124324800`@Q24848@0424800`aS24848@0224800a2436<@Q00548@00aBU36<@Q00436<0
10Q21248@PQ20P@Q00P8@QcW;F/U:@aS1248@P@Q0PQ20`@Q00@8@P@Q24848@@8@P@<H`88@P848@@8
@P0436<8@PQ2248712432484124010Q212448@000`@Q0`Q20P@Q00@8@P@Q2488@P8<H`8HaP047>LH
aQS66<H45:D26<H448@010aS5:DDYABU0Q2400<DYA245:D00Q240aBU0Q240QBU1AS611BU0a2400<D
YA2448@00Q240QS60QBU00<@Q1BU6<H00QS600DDYAS66<H@Q2DY008aS003;F/HaQ24008@Q0045:DH
aQBU5:D26<H25:D00a245:DDY@045:D248@021BU48@@Q1245:DHaQcW6<H25:D848@25:D01QS67>LD
YAS65:D@Q0DDY@0548@DYABU7>LDY@0248@00aBU6<HDY@0248@011BU48@<H`Q210aS0a240PaS0a24
00@DYA2448@@Q08<H`8@Q08DY@0348@DYA24008@Q08<H`0448@<HaBU5:D248@010aS48@@Q1240PaS
1A2400<DYA2448@00Q2400@<HaBU48@@Q08DY@0448@<H`aS48@25:D011245:D<H`aS0Q2400<DYA24
36<00PaS1A2400HDYA2436<8@PaS48@336<000<48@0300048@0000848@0:248000@Q248aS6mkDY@e
[D8@?Nl3=Jd00cW>@Q0mk`03@Q000cg_AS5:DP02AS401Cg_@Q12448@?Nl00THa0TYB00A6<D8@?Nlm
k`@icP05=JdicSW>?Nm24002>Lh01cF]>LhicSF]>Lhmkd8@008mk`03>Li2448@00924003>Lhmkcg_
00924003?NlicSW>008icP03=JdicSW>00DicP04?NlicSg_AS42?Nl3>Lh4=Jd3>Lh01CF]?Nm6<DHa
?Nl00SF]00<icSF]=Jd00SF]00HicSg_@Q0mkc6<=Jd2<H`013F]<H`aS36<0cF]0c6<00Te[Be[:DX]
Jc6<>LhaS2e[9BT00RU:00<]JcF]<H`00be[0S6<00D]JbU::DXYBRe[00<YBP039BTYBRDY008YBP05
9BT]Jc6<<H`]J`029BT012U:9BTQ22480RDY00DQ22DY:DXU:B48008Li`038@PLib4800<U:@038@PU
:BDY00DQ20@U:@09:DX]JcF]<H`U:B487>LQ22U:008U:@048@PU:BDY9BT2;F/01BU:9BTLiacW6<H0
0acW0b4800hLib489BTYBRe[:DXQ21S6:DXicS6<9BT8@P000`@Q00@000@Q124000d48@88@PL48@04
248<Ha2448@236<010Q236<DYAS60acW00@U:B487>LDY@8@Q00336<8@PQ20088@P0336<8@PQ20084
8@0324848@Q20088@P031248@P@Q0088@P848@0636<8@P@Q1248@PaS0PQ200@48@Q236<<H`<@Q005
36<@Q1BU48@DY@0236<3248236<412402@aS248@Q2487>LDY@Q21248@P04124010Q212448@@Q1`Q2
0PaS0`Q200@48@Q236<<H`D8@PD48@88@P031248@PQ200X48@88@P0;1248@PQ21248@P@Q36<8@PaS
48@DY@028@P00aS65:DDY@025:D011S65:DDYABU1A2400<<Ha245:D01A2411BU00<@Q1BU48@00aBU
11S60QBU1a2400DDYA2448@@Q1BU008HaP8DY@0;6<HDYAcW7>LHaQ247>L]JcW>=JdLi`025:D010aS
5:DDYA241aBU00<@Q1BU5:D00a2400<<Ha2448@00aBU0aS600LLiaBU48@DYA245:D@Q00336<248@0
11BU6<HLiaS60aBU0Q2400DDYAS66<H@Q1BU008HaP035:D<H`aS008@Q08DY@0448@<H`aS36<248@3
36<348@00`aS48@@Q0035:D00a2436<@Q00248@236<00a245:D@Q00348@236<01PQ236<@Q1BU6<HD
Y@8<H`0348@<Ha2400D<H`D@Q00636<@Q0aS36<@Q0aS1a240QBU00<@Q1BU48@0112400T<Ha2436<<
Ha2436<@Q1BU48@00PaS00<8@PaS36<00PaS00000`0012448@0312400`002488@P0212401PQ2<Ha_
Ne:D;F/icP@mk`05@Q0mkd8@@Q0mk`03@Q001DHa?NlmkcW>?Nl00d8@00HicSg_>LhicT8@?Nl2@Q04
>Lh02Sg_AS56<Cg_=JdaS3F]>Lhe[Cg_0SW>00<mkcW>>Lh00SW>00@e[CW>?NlicP<mk`96<@8mk`8i
cP03?NlicSW>008icP8e[@8mk`96<@=24004?NlicSF]>Lh2=Jd01SW>?NlicSF]?Nm24096<@04?Nm2
448@?Nl3@Q000cg_>LhicP02>Lh00cg_=JdaS004<H`3=Jd3<H`01CF]<H`]Jc6<=Jd00SW>00@e[C6<
<H`]J`8aS0<e[@@aS08]J`05:DX]Jbe[;F/aS002;F/3:DX00bDY:DXYBP02:DX49BT00bU:9BTU:@02
:DX29BT28@P29BT38@P39BT00bU:9BTU:@03:DX00bDY8@PQ20038@P00bDY:DXYBP03:DX39BT2:DX0
0bDY8@PU:@079BT48@P01QcW6<HLib48;F/YBPDU:@078@PLibU:<H`]Jb4824800P@Q00<000@Q1240
0`@Q00@000@Q1248@P<48@030008@P@Q00L48@0300048@@Q00<48@05248@Q1BU36<8@P0236<248@2
36<548@2248212400`Q21248@P06124010Q212448@@Q0`Q21`@Q0PQ200H<H`Q2248@Q1BU6<H35:D0
2bDY:DX]JbU:7>LHaQBU48@<H`Q236<00PQ20P@Q00@8@P@Q36<<H`H8@P031248@PQ200<48@032484
8@Q200848@L8@P041248@P@Q0004248412401@Q212448@@Q24800P@Q00@8@P@Q2488@P848@040004
8@Q22483124524801P@Q36<<Ha246<HLi`8HaP055:DHaQS67>LHaP027>L00aS65:DDY@035:D448@2
36<548@010aS48@DYABU0aS600HDYAS65:DHaQBU6<H27>L00aS65:D@Q0025:D248@00aS65:D@Q002
48@02AS65:DDYA245:D@Q1BU6<HLi`025:D02aS67>Le[CW>:DXU:ABU48@HaQBU48@00QBU00@HaQcW
5:DDY@8<H`8@Q00;5:D@Q12448@DYA24248@Q1BU7>LHaP0248@011BU6<HHaQS60Q2400D<Ha2448@@
Q0aS008@Q0<DY@036<HDYA2400<@Q08DY@<HaP055:D@Q1BU5:D@Q00236<348@536<348@336<01124
36<@Q0aS0Q241@aS11240QBU00@@Q0aS36<<H`<@Q0P<H`<DY@0448@<Ha2448@336<00a2436<@Q003
48@00`Q236<<H`025:D02A245:D@Q1245:D@Q1BU48@DY@0236<00a2436<<H`0336<00aBU48@@Q002
36<25:D148@000848@0300048@0000D48@0:000<HcF]Kg]BU2e[>LhmkcW>?Nl3>Lh00dHa@Q124002
AS401d8@?NlicSg_@Q0mkcW>00924005?NlicSF]>Lhmk`02@Q001THa?NlmkcW>=Jdmk`924003?Nli
cS6<008aS08e[@@icP03?NlicSW>00DicP03?Nm2448@00924003?NlicSg_00<icP<e[@05?NlicSW>
?Nm24002AS42?Nl2>Lh2=Jd00cW>=JdicP04>Lh3@Q0013g_>LhicSg_0T8@0Sg_0cW>00<mkcW>=Jd0
0S6<00He[C6<=JdaS3W>=Jd3<H`01Be[<H`aS2e[=Jd00cW>00@aS2e[;F/aS0<e[@04<H`e[C6<<H`3
;F/2:DX5;F/2:DX39BT01Re[:DXYBRDY:DXU:@8YBP069BTYBRU::DXQ22DY0RU:00<U:AcW8@P00R48
1BDY0RU:0RDY12480bDY00LYBRDY:DXYBRe[:DXU:@028@P59BT03bU:9BTU:BDY:DXQ21S67>LQ22DY
7>LHaR489BTYBP039BT00bU:;F/U:@028@P2:DX00be[5:D<H`0412400`0012448@0212400`001244
8@0312400`0012448@0412400`Q212448@03124020Q212448@aS48@DY@aS248236<010Q248@@Q124
1@aS1@Q200P48@Q212448@Q21248@P@Q1@Q20P@Q0`Q20`@Q10Q200@48@Q236<DY@8HaP085:DHaRDY
<H`]Jb487>LHaP8@Q006248<H`Q21248@P@Q0PQ20P@Q0PQ200<<H`Q224800`@Q0PQ20P@Q0PQ20P@Q
00<8@PaS24800`@Q0`Q20P@Q0PQ200<48@Q212400PQ200<48@Q212400P@Q00<8@P@Q248010Q200@4
8@Q21248@PD48@@8@P848@04248<H`aS48@25:D26<H00acW6<HLi`066<H00aBU6<H@Q00448@236<7
48@55:D348@00aBU6<HHaP026<H00acW6<HDY@025:D0212436<@Q0aS48@DYA245:D248@25:D00aS6
5:DDY@026<H25:D248@012U:>Lhmkbe[0Q2400@LiaBU48@DY@8Li`045:D@Q12448@236<01A246<H@
Q12436<00a2421BU0Q2400@DYA2448@DY@@@Q0DDY@066<H@Q12448@DYA240QBU00D@Q1S67>LDYA24
008<H`H@Q0@<H`<@Q08<H`0348@<Ha2400@@Q0@<H`0548@<Ha2448@<H`0348@010aS48@@Q1240PaS
00<@Q1BU48@010aS0Q240QBU00<@Q0aS36<00PaS112400D<Ha2448@<Ha24008<H`8@Q0036<H@Q1BU
00P@Q0D<H`<@Q08<H`<@Q04<H`0000<000@Q12400P@Q00@000@Q1248@P848@0>248aS7NmF]He[D8@
AS5:DTHa?NlicSg_@Q16<@924003AS5243g_008icP8mk`924003AS5243g_008e[@06<H`icSg_?Nli
cSF]0SW>00A244HaBU92408mk`04@Q0icSF]<H`4>Lh03cg_@Q0mkcW>=JdmkcW>?Nm244HaBU96<D8@
AS524002>Lh013F]?Nm2448@0SW>00<aS3F]>Lh00cg_00<icSg_>Lh013W>0Sg_00<icSF]>Lh00Sg_
0cF]00A243g_?Nlmk`924004?NlicSW>=Jd3>Lh01cF]<H`aS36<=JdicSF]00<aS08e[@03<H`]JbU:
00<aS004=Jd]Jc6<<H`3>Lh3=Jd2<H`5;F/012U:;F/YBRe[0S6<0RU:00@]JbU::DX]J`8U:@038@PU
:BDY00<U:@<YBP8U:@8Q208U:@0;:DXQ22489BT]JbU:8@PU:BU:<H`YBP029BT00bU:8@PQ20028@P2
9BT38@P49BT012489BTU:BU:0bDY00<YBRe[:DX00RDY00@Q22DY8@PQ208HaP058@PU:BU:<H`]J`04
8@P2:DX012e[=JdU:@aS1@@Q00<000@Q248010@Q00<000@Q12401@@Q00D8@P@Q00048@Q200D48@@8
@P0336<8@PQ200<8@P0336<8@PQ200H8@P031248@PaS00H48@88@P848@0324848@@Q00H48@88@P06
124<H`aS1248@QcW0SW>00<Q21S6:DX00U:D00QJeUkgAS4icRU:7>LHaQ241@Q200H48@Q21248@P@Q
248512400`Q212448@02124424800`@Q2488@P0224800`@Q24848@03248212442483124010Q21248
@P@Q0PQ210@Q0`Q210@Q0PQ20P@Q1@Q200<<HaBU6<H00aS60acW0QBU00@HaQBU6<HDY@8HaP035:DH
aQBU008HaP045:D@Q12448@25:D00a245:DDY@0248@00aBU6<HHaP035:D01A2436<@Q1246<H00acW
00<HaQ2448@00Q240QBU0Q240QBU00@HaQ2436<@Q08DY@0348@DYAS6008HaP075:D<Hb48>Li6<CW>
7>L00aBU00DHaQBU5:D@Q1S6008DY@0348@DYABU00L@Q08DY@036<HDYABU008@Q08DY@046<HDYA24
36<248@25:D00a2436<@Q0035:D01AS65:DDYABU48@01QBU00@HaQcW6<HDY@@@Q0H<H`0548@<Ha24
36<@Q0035:D011245:DHaQBU1A2410aS00HDYA2448@DYAS648@236<00a246<HDY@0436<348@45:D3
36<348@436<248@236<011BU48@<H`aS1A240QBU00D@Q0aS36<<H`Q200<@Q08<H`0348@DYABU00<@
Q048@P000`@Q00<000@Q12400P@Q00`8@P00124<HcF]MkeF]CF]@Q16<DYB@Q03?Nl6@Q001DHa?Nlm
kcW>?Nl00T8@00Pmkd8@@Q0icS6<=JdaS3g_0SW>00@e[CW>=Je240=6<@03@Q0mkcg_008icP8e[@04
>Lhe[CW>>Lh3?Nl3>Lh00cg_AS56<@02AS40148@AS52448@0cW>00De[CW>?NlmkcW>008e[@03>Lhm
kcg_008mk`8icP<mk`04>Lhe[CF]>Lh2?Nl3=Jd013W>?Nm243g_0T8@0Sg_2CW>0cF]00<icSF];F/0
0S6<00<e[Be[;F/00S6<0be[00De[C6<<H`aS3F]008mk`03=JdaS36<00<aS0<]J`8YBPH]J`8YBP03
;F/YBRDY00<U:@04:DXU:B489BT3:DX01RDY:DXU:B487>LQ208U:@038@PU:BDY008U:@8YBP03;F/Y
BRDY008U:@03:DXU:B48008Q208U:@8Q20049BTYBRDY8@P59BT012U:9BTQ22U:0Re[00@U:B488@PQ
20<Li`048@PU:BU:;F/2:DX00bDY7>LLi`029BT01S6<?NlYBQcW124000848@0300048@@Q00H48@03
00048@@Q00<48@0324848@@Q00848@0300048@@Q00H48@H8@P0336<8@PQ200D8@P041248@PQ22483
12401PQ212448@@Q24848@<8@P@48@0=24848@@Q1248@P@Q24848@Q21248@QBU7>L00R4800/Lib48
?Nm6<F<HG_M6<DYB=JdQ21S6008@Q00336<8@PQ20088@PD48@0324848@@Q00@48@0524848@@Q1248
@P02124224801@@Q24848@Q212400`Q200<48@Q224800`Q200P48@Q22488@P@Q24848@Q21@@Q00<8
@P@Q24800`Q20`@Q00<8@P@Q24800PQ20P@Q00<8@PaS48@00QBU00@HaQcW7>LHaP8DY@056<HDYAS6
5:DHaP025:D00aS65:D@Q0045:D00a245:D@Q00248@01QBU6<HDYABU48@DY@<HaP065:D@Q1245:D@
Q1BU0aS60aBU0QS60QBU00@@Q1BU5:DHaP8DY@D@Q08DY@8HaP045:D@Q1cW:DX2>Lh00bDY6<HHaP02
5:D248@011S65:DHaQBU112400@DYA2448@<H`8@Q00536<DYAS66<HDY@0348@01ABU6<H@Q1242480
212400<<HaBU5:D00QS600@DYA2448@DY@8HaPDDY@0348@DYA24008@Q00336<@Q0aS00H<H`06248<
Ha245:D@Q0aS0Q240QBU0Q2400T<Ha2448@@Q0aS48@<Ha245:D01A240`aS0a240`aS1a2400<<Ha24
48@00a241@aS00@DYA245:D@Q08<H`<@Q00336<@Q124008DY@0548@8@PaS248<H`0248@00`aS48@@
Q00348@236<00005124000@Q1240000312402PQ2124000Q2<Ha[FU:D=Je244YB0THa00=244Ha@Q00
0T8@00=6<Cg_?Nl00SW>00A243g_?Nlmk`8icP=24006?NlicSg_AS5243g_0SF]13W>0Sg_0cW>00Xm
kcW>>Lhe[CW>?NlicSg_>Lhmk`8icP09=JdicSW>>Lhe[CW>?Nm243g_00<icP03=JdicSg_00924004
?Nle[CF]=Jd2>Lh3=Jd2@Q03?Nl5=Jd00cW>=Jde[@02<H`3>Lh4?Nl2>Lh00cF]<H`e[@06>Lh2=Jd0
0c6<=Jde[@03=Jd03Re[<H`YBRDY;F/e[CW><H`YBRe[=JdicS6<=Jd3>Lh3;F/00bU:;F/YBP03;F/0
0c6<;F/]J`04:DX29BT2:DX2;F/29BT012U:;F/]JbU:0RDY00<YBRDY9BT00RDY0R4800@Lib489BTQ
20@YBP<U:@037>LQ224800<U:@038@PHaQcW00DQ20039BTQ224800<U:@0:8@PYBRU::DXU:B487>LQ
21cW9BT28@P00acW8@PU:@039BT28@P01acW8@PQ22DY5:D<H`Q200D48@0300048@@Q00X48@030004
8@@Q00<48@0300048@@Q00848@0500048@Q224848@022484124424800`@Q2488@P0612400`001248
@P0212400`Q212448@0612401PQ212448@Q21248@P8DY@0A48@<H`Q248@HaQcW>Li246]JKg]cW7_N
Kg][FUJe>LhU:@0248@00`Q2124<H`0248@010aS12448@Q21`@Q10Q200<48@Q224800PQ200/48@Q2
1248@P@Q24848@Q21248@P@Q00@8@P848@<8@P<48@@8@P<48@0324848@Q200D48@03248<H`Q20088
@P0348@DYABU00<HaP055:DHaQS65:DHaP025:D248@25:D00aS65:DDY@0248@01aS67>LHaQBU48@D
YAS6008DY@0548@DYAS65:DHaP025:D36<H00a245:D@Q0025:D02A245:DHaR487>LDYA245:DHaP09
5:D01AS648@DYA245:D00QS60QBU00`HaQBU7>L]Jc6<:DXHaPaS48@HaQBU6<H25:D00aS65:DDY@05
48@010aS48@@Q1240QBU0QS60QBU00<@Q1BU5:D00Q2400<DYA2448@00`aS00<@Q0aS36<00Q240aBU
00<HaQBU5:D00Q2400@DYAS67>LDY@8HaP037>LDYA2400<@Q0H<H`<@Q00436<@Q1245:D248@01ABU
6<HHaQBU48@010aS0Q240QBU1Q2400@DYAS66<H@Q0<<H`8@Q08<H`@@Q0@<H`0548@<H`aS48@<H`05
48@236<00a245:D@Q00248@010aS48@@Q1241PaS0PQ20PaS0Q2410aS00000`0012448@0212400`00
12448@0312401PQ2;F]W>E:D<Ha240A6<@924096<@924004?NlicT8@?Nl2>Lh3?Nl013W>?Nm2448@
0Sg_00=243g_?Nl00cW>00<e[CW>=Jd013g_0SW>00<mkcW>>Lh00SF]1SW>13F]0SW>0Sg_0SW>0Sg_
0cW>00<mkd8@?Nl00SW>0SF]00<icSF]=Jd00cW>00Dmkd8@?NlicSF]008aS009=JdicSW>=Jd]Jc6<
=JdaS3W>008mk`DicP03=JdaS36<00<mk`8icP03=JdicSF]00De[@8aS004;F/YBRe[<H`2=Jd2;F/0
1SF]>Lhe[CF]<H`e[@8aS005>LhaS2e[9BTYBP02;F/2:DX3;F/4:DX012DY8@PU:BU:0Re[0bU:0be[
00HYBRDY9BTYBRDY:DX28@P021cW8@PQ22DY:DXU:B489BT2:DX29BT48@P00bDY8@PQ20028@P37>L0
1B48:DXU:BDY8@P012DY00<YBRDY:DX00R4800<Lib488@P00QcW12480bDY0R4800HLibDY8@PLiaBU
36<E12400`Q212448@0312401`Q212448@@Q24848@Q200848@0424848@Q2248212401PQ212448@Q2
1248@PD48@0424848@@Q124324831242248212402@001248@P@Q0008@PaS48@DY@0236<041BU6<HH
aS6<>LiNmf]JMkekgV]JKg]NmdYB>LhLiaBU0P@Q0PaS00DDY@aS12448@0000X48@030008@PQ200@8
@P848@<8@P848@0424848@@Q1244248412401PQ21248@P@Q248<H`@48@<8@P848@0424848@Q236<4
248248@45:D00aS67>LHaP026<H00aBU48@DY@026<H00aBU48@@Q0035:D02A245:DDYABU6<HDYA24
5:D@Q0035:D011S648@DYABU0aS600LDYA2448@@Q1BU48@DY@037>L65:D00aS65:DDY@045:D448@0
0aBU6<HDY@026<H021BU48@Libe[=JdaS1cW48@35:D26<H011BU6<HDYAS60aBU1Q2400<HaQBU5:D0
0QS600<DYAS65:D00aBU00<@Q0aS48@00Q240`aS0a2400<<Ha245:D00QS600<DYA245:D00aBU00@H
aQBU6<HDY@8HaP8DY@8@Q00536<8@PaS36<@Q00336<648@00aBU6<HHaP025:D248@01@aS248<H`aS
48@00aBU00@@Q0aS36<@Q08DY@@@Q00636<@Q0aS36<@Q0aS0Q2400<DYA2448@00Q2400@<Ha2436<@
Q0@<H`0348@DYA24008<H`0648@DYA2436<@Q1BU0`aS0Q2400<<Ha2436<010aS11240PaS00021240
0`0012448@0312403@Q200048@Q2<HaS64Ha<H`mkdYBAS5243g_00E24003?Nm243g_008icP04?Nm2
43g_=Jd3>Lh3?Nl3>Lh023F]?NlmkcW>=JdaS3F]>Lh2?Nl4>Lh01T8@?Nlmkcg_>Lhe[@8icP04?Nm2
43g_>Lh3=Jd3?Nl01CW>=Jde[CW><H`00SF]0cW>0SF]00<icSg_>Lh00SF]00<icT8@@Q000Sg_00=2
43g_>Lh00SF]00DaS3F]=JdicSF]00<aS08e[@8icPDaS003=JdaS3F]008icP8e[@03<H`e[CF]00<e
[@8aS0<]J`04:DX]Jbe[=Jd5<H`02be[=JdicSF];F/YBS6<=JdYBRDY:DX00S6<12e[0RU:0RDY00<Q
22DY9BT01RU:0be[00HYBRe[9BTU:B489BT28@P011cW8@PQ22DY0R4800<U:BU:9BT01RDY0RU:0RDY
00DQ21cW7>LLib4800<U:@058@PLib489BTYBP059BT012489BTU:AcW0R4800<U:B488@P00R4800<Y
BRe[:DX00R4800HU:B487>LDYA2436<31240100012448@000P@Q00<000@Q12400P@Q00<000@Q1240
1@@Q00<8@P@Q12400P@Q00<000@Q124010@Q00<8@P@Q12400`@Q00<8@P@Q12406@@Q014000@Q2484
8@aS8@PaS2U:48@8@Q245:DLid8@CW=cW7Nm009_N`07JeYg_GNmMkeJeRDY48@00P@Q00@8@Q2436<8
@PD48@0400048@@Q124224841244248010@Q24848@@Q1PQ20P@Q1@Q200P48@Q22488@P@Q248<H`Q2
0`@Q00<8@P@Q12401@@Q0PQ200L48@Q2248@Q1BU6<HLi`036<H25:D011S67>LHaQBU0Q2400@DYA24
48@DY@<@Q0HDY@8@Q08DY@036<HDYAS6008@Q08DY@056<HDYABU5:DHaP025:D26<H248@011BU7>LL
iaS61QBU00DHaQBU6<HDYAS6008DY@0648@DYABU5:DHaQcW0QS600XDYA246<HLibDY<H`YBQcW5:D<
H`<DY@<Li`036<HDYABU00D@Q0046<HDYABU5:D248@35:D00a2436<DY@025:D00a2436<@Q00248@0
1@aS48@<Ha2436<01A2400@DYA2448@HaP8Li`8DY@046<HQ21cW7>L25:D01A2436<@Q0aS48@01`aS
0Q2400@DYA2448@@Q08DY@0348@<Ha2400@@Q0@DY@076<H@Q0aS48@DYAS648@00PaS00<@Q0aS36<0
0PaS00@8@PaS48@@Q08HaP8@Q088@P0336<@Q12400<<H`0348@DYA24008@Q00336<@Q1BU00<DY@D@
Q08<H`04248<H`aS48@436<00a245:D@Q00124800005124000@Q1240000612401`Q2<HaS64YB:DXe
[DHa00924003AS52448@00924004?Nm6<DHa@Q02>Lh01Cg_@Q0mkcW>=Jd00SW>13g_00A243g_>Lhe
[@8icP03<H`e[CW>008icP04=JdicSg_?Nl2>Lh0148@?NlicSF]0cW>0Sg_00A243g_>LhicP8e[@09
>Lhe[CW>>Li243W><H`]Jc6<008icP03=JdaS3F]008icP8e[@8icP03@Q0mkcg_00@mk`<e[@06<H`i
cSF]>Lhe[C6<0SF]00DaS3F]=JdicSF]008aS005>Lhe[C6<<H`e[@02>Lh00c6<=JdicP02=Jd3<H`0
0cF]<H`aS003:DX01be[<H`aS3F]<H`e[C6<008]J`04=JdaS36<;F/2<H`00bU:9BTYBP02<H`3;F/2
:DX00bDY:DXYBP029BT01B489BTYBRU:;F/00RU:00dU:Be[;F/]JbU:9BTQ22DY8@PU:B489BTLi`03
8@P01BDY:DXQ22DY8@P00RU:0bDY0RU:00<]JbDY9BT00R480acW00DU:BU:9BTQ21cW00<Q20039BTY
BRU:00<U:@8Q208Li`8Q20039BTQ22DY008YBP8U:@098@PU:B489BTHaQ2436<48@Q200D48@030004
8@Q200848@0500048@@Q1240000812400`0012448@0512400`Q212448@0212422486124010Q21244
8@000P@Q0PQ20`@Q0`Q200<48@0012400P@Q00<8@P@Q124010@Q00D8@Q247>LQ21cW008DY@8@Q003
<H`mkfmk009cW008MkeW>F]JLiaoog_N>LhLi`848@0424848@Q236<312401@0012448@@Q00000`@Q
0`Q20`@Q0`Q20`@Q1@Q200<48@Q224800P@Q00<<H`Q224800P@Q00<8@P@Q24800PaS0PQ20P@Q0PQ2
1@@Q1PQ200H@Q1BU6<HLiaS65:D26<H27>L26<H01aBU6<HDYABU48@DYA24008DY@0348@DYABU008H
aP0:5:D@Q12448@DYA245:DHaQBU6<H35:D248@01AS68@PLiaS648@00aBU00<@Q1BU6<H00QS600<D
YAS65:D02aBU0a2400dHaQcW7>LLia245:DHaQBU6<HU:Be[:DXLi`0248@25:D36<H011cW6<HDYABU
0a241ABU00<@Q0aS48@00QBU0QS60QBU00<@Q1BU48@00`aS0Q2410aS0a240QBU0Q2400@DYAS68@PL
i`8HaP087>LQ21cW6<HDY@aS48@<H`<@Q0@<H`0548@<H`aS36<@Q0035:D248@00aS65:D@Q0022482
36<35:D011S65:D@Q1BU0a2400@DYA2448@@Q08<H`03248<H`aS00<DY@0348@DYA2400P@Q08<H`03
48@HaQBU008<H`0348@DYABU00@@Q0045:D@Q0aS248836<248@336<0000300048@@Q00<48@0:0004
8@Q2124000aS<HacW5:D=Jd5@Q001DHa@Q1243g_@Q000SW>0cg_00E243g_?NlmkcW>00Dmk`8icP03
=JdicSW>00Te[@05>Lhe[CF]>Lhe[@05?Nl00cW>?Nlmk`03@Q001THa@Q16<D8@?NlicPHe[@<icP06
?Nle[CF]>Lhe[C6<0SF]00@mkd8@?Nlmk`<icP06=JdaS36<<H`e[CW>136<00<e[CW>=Jd00SF]136<
1CF]00@icSg_?NlicP8aS08YBP03<H`]Jc6<00@aS08]J`8aS004=JdaS36<=Jd6<H`3;F/01bDY:DXY
BRe[<H`]JbU:008U:@03:DX]Jbe[008YBP049BTYBRe[:DX3;F/01RU:9BTU:BU:9BTQ20<Li`8Q2003
9BTQ22DY008U:@048@PU:BDY:DX<9BT00b487>LU:@02:DX00bDY8@PQ20039BT2:DX01bDY8@PLib48
9BTQ22DY008YBP<Q20099BTYBR48;F/aS2e[9BTHaQcW008HaP0336<48@@Q00`48@0824848@Q21240
00@Q0008@P`48@03248000@Q00X48@0424848@@Q0002124010Q212448@@Q1@Q200D48@0012448@Q2
00<48@0424848@aS:DX2>Lh02b4836<DYA246<HicSg_JeYcW6mkLi`00V]J00Ig_GooMkdmkacW1242
248=124324801@@Q2488@PQ212401@Q200<48@Q212400`Q20P@Q0PQ200<48@Q224800PQ200@48@Q2
248<H`88@P041248@P@Q000212400`Q212448@0212400`Q236<8@P0248@35:D00aS67>LLi`036<H0
11cW6<HDYAS60a2411BU00@@Q1BU5:DDY@8HaP8DY@0348@DYABU00<DY@036<HDYABU00@DY@<Li`07
6<HDYABU5:D@Q1BU48@00QBU00<@Q1S65:D00aBU0aS60aBU0QS600<DYAS65:D01ABU0QS600PLiaBU
7>L]JcF]>LhYBQS60aBU1AS60QBU0Q2400<HaQBU5:D00a2400DDYA2448@DYAS600<@Q08HaP065:DH
aQS65:D@Q0aS0Q240`aS00@DY@aS48@DY@8HaP0348@<Ha24008DY@<HaP8Li`046<HDYA2448@25:D3
48@00aBU48@<H`0236<448@00aBU48@@Q00236<348@010aS48@<Ha240QBU00@@Q0aS5:DDY@8Li`08
48@<H`aS48@DYAS65:D@Q0<<H`8@Q0<DY@0448@<Ha2448@436<348@01@aS48@@Q1BU48@00aBU0aS6
11240`aS00<8@PaS36<010aS0Q240@aS000312400`0012400002124020Q200048@Q2<Ha_Ne:D=Jd5
@Q02AS42@Q02?Nl3>Lh0148@?Nm243g_0SW>1Cg_13W>00De[C6<<H`e[CW>00<e[@04>LhaS3F]<H`2
=Jd00cW>?NlicP02?Nl2>Lh3?Nl0148@?Nm6<DYB0T8@00<e[Cg_>Lh00SW>00@e[CW>=Jde[@@icP8e
[@8aS08e[@Dmk`03>LhmkcW>008aS003=JdicSF]008aS004=JdaS3W>=Jd4<H`013F]<H`aS36<0cW>
0SF]0SW>00<mkcW>=Jd00S6<1be[0S6<00D]Jc6<;F/aS3F]00DaS003;F/aS2e[00<]J`8YBP059BT]
Jc6<<H`]J`029BT2:DX00be[:DXYBP05:DX2;F/00bU:9BTU:@038@P00acW8@PLi`028@P011cW9BTU
:BU:0RDY00@Q22DY9BTU:@@YBP8U:@8YBP049BTQ21cW8@P59BT27>L00b489BTYBP029BT012489BTU
:BDY0b480RU:0R4800PU:B488@PYBRe[<H`YBR480QcW00<@Q0aS248010@Q00D000@Q12448@0000<4
8@0500048@@Q1240000912400`0012448@0>12400`Q212448@02124010Q212448@Q210@Q10Q210@Q
00@8@P@Q12448@88@P04124<H`aS7>L2=Jd01RDY6<H8@PaS;F/e[@9W>@05Kg]g_FmkJeYW>@02Ool0
15[F>Lh8@PaS10@Q00<8@P@Q12400P@Q00<000@Q12400P@Q0`Q20P@Q00@8@P@Q2488@P848@032484
8@Q200<48@@8@P031248@PQ20088@P0936<48@@Q1248@PaS24848@Q200@48@0324848@Q200@48@88
@P0348@DYABU008DY@8HaP047>LHaQcW7>L26<H01ABU6<HDYABU48@00QBU0a241QBU00<HaQ2448@0
0Q240QBU0aS60QBU00<HaQ246<H00QcW00<HaQBU5:D00QBU0Q240QBU00<HaQBU5:D00QBU00DHaQBU
5:DDYAS6008DY@8HaP047>LDYABU6<H248@25:D03AS67>LHaQ246<HQ22e[?Nle[BDY8@P<Ha24008D
Y@066<HLiaBU6<HDY@aS0Q240QS600<DYA245:D00aBU0QS600@DYA2448@@Q08DY@096<HDYA245:D@
Q0aS48@<Ha24008<H`8@Q0LDY@8HaP055:DHaR487>LHaP035:D348@336<348@236<248@236<248@0
11S65:D@Q12410aS00<@Q1BU5:D00QBU00@@Q1BU6<HHaP8DY@8<H`@@Q08<H`0648@<H`Q236<@Q1BU
0Q2400@DYA2448@@Q0<<H`8@Q00436<@Q0aS48@25:D00a245:DDY@036<H00aBU48@<H`0636<00`Q2
36<<H`0248@136<12480000300048@0000D48@0924848@@Q248e[GNmF]HaS3g_00924096<@924003
AS52448@008mk`@icP03=JdicSW>00<mk`=24003?NlicSW>008icP04?NlicSW>=Jd4>Lh00cF]<H`e
[@02=Jd00c6<>Li6<@02@Q02>Lh00cg_>LhicP02>Lh2@Q001DHa?NlmkcW>?Nl00cW>0SF]0SW>00Dm
kcW>>Lhe[CW>008e[@0:>Lhe[CW>?NlicSF]<H`e[CW><H`2;F/00c6<=Jde[@06=Jd01SW>=Jde[C6<
;F/aS08e[@<aS003>LhaS3F]00<e[@04<H`]JbU:9BT3:DX3;F/01RDY:DXYBS6<>Lhe[@@aS08icP05
=Jd]JbU::DX]J`02:DX01BDY;F/]Jbe[9BT00R4800@U:BU:9BTYBP@]J`8YBP039BTYBRDY008U:@8Y
BP039BTQ224800<Q20047>LU:BDY9BT4:DX38@P00bDY:DXU:@028@P00bDY8@PQ20028@P2:DX2;F/0
12U:8@PQ22481BDY00<Q22U:9BT00b4800@U:BU::DXYBP<U:@8Li`06:DXaS3F];F/Lib480QS600<@
Q0Q212401P@Q00<000@Q12400`@Q00<000@Q124070@Q00H8@P@Q12448@00248:12400`Q212448@03
12400`Q212448@0212402A245:DU:CW>=JdLia24248@Q002<H`00dicDYAJeP02IcT026mkHaQJeTHa
@Q0icR485:D224800`aS1248@P0224861242248412422482124010Q21248@P@Q10Q20P@Q00<8@P@Q
24800PQ200@48@Q224848@88@P04124<Ha2436<312400`Q212448@022483124010Q236<@Q1S60aBU
00<HaQBU6<H00QS600@DYAS66<HDY@8HaP0448@<Ha245:D26<H011245:DDYAS60QBU00<@Q1BU5:D0
0QBU0Q240aBU0QS600<DYAS648@00QBU00<@Q1BU6<H01AS60a241QBU00@HaQBU5:D@Q0DDY@036<H@
Q124008DY@036<HLiacW00<HaP0;7>LDYAcW=Je6<Cg_9BT@Q1BU6<H@Q0025:D00aS65:DDY@045:D2
48@010aS48@@Q12411S60aBU0QS600<LiaS65:D00Q2400<DYA2436<00a240PaS00<@Q1BU6<H00a24
00<DYA245:D00QS61ABU00<@Q1BU48@00QBU0Q240`aS00@@Q0aS36<<H`8@Q0@<H`0348@<H`aS008<
H`03248<H`aS00H@Q08DY@0548@DYABU6<H@Q00236<448@236<348@236<00a2436<<H`0236<348@2
36<25:D348@00aBU6<HDY@025:D248@00aBU48@<H`0:36<1248000H48@030008@P@Q00848@05248e
[GNmF]HaS007@Q0014HaBU96<Cg_13W>00<mkcW>>Lh00SW>00Pmkd8@?Nm243g_@Q0mkcF]0cW>0Sg_
0cW>0cF]00TicSF]>LhaS2e[>LhmkdHa@Q000SW>0cg_0SW>0Sg_0T8@00<mkd8@?Nl00Sg_00@e[Cg_
>LhicP8mk`8icPDe[@05>Lhmkcg_?NlicP02<H`2=Jd01Be[<H`aS3W>=Jd00S6<0SF]0SW>0SF]00<i
cSF]=Jd00c6<00@e[CW>>LhaS08e[@05<H`e[C6<=Jd]J`03:DX5;F/2:DX01RDY;F/aS3F]>Lhe[@8a
S004=JdaS36<=Jd2;F/2:DX00c6<:DXYBP05:DX29BT3:DX2;F/01C6<:DXU:BU:;F/00RU:0R480RDY
1R4800<LibDY9BT00RU:00HU:BU:9BTQ22DY8@P29BT98@P01BDY:DXYBRU:9BT00R480RDY00@YBRDY
9BTU:@8YBP039BTQ224800<YBP039BTQ2248008Q20089BT]Jc6<;F/U:BU:7>LDY@<<H`D48@040004
8@@Q000512400`001240000412400`Q21240000512400`0012448@0612401`0012448@@Q24848@00
00848@0524848@@Q124000031242248212400`0012448@03124324821242248031BU>Li6<CF]6<H8
@QBU8@PU:D8@AS5JeP9S6004JeYW>EkgDY@2BU800be[7>L8@P062488124624801P@Q2488@PQ21248
@P@48@88@P031248@PaS00L8@P031248@PQ20088@P0336<8@PQ200848@0424848@@Q1243248236<0
0aBU6<HDY@025:D00aS67>LLi`026<H35:D00aS65:DDY@025:D00a245:DDY@026<H00aBU48@DY@02
48@011BU48@DYAS60QBU00H<Ha246<HHaQBU6<H45:D26<H45:D00aS65:DDY@025:D00a245:DDY@07
5:D01A245:DDYABU6<H00aBU0Q240QBU0acW0QS600<@Q1BU<H`00T8@00@]JaBU6<HDY@8HaP055:D@
Q1BU6<HDY@0248@25:D648@011BU7>LLiaS60QBU00L@Q1S66<HHaQBU6<H@Q00236<448@01@aS48@@
Q0aS48@011BU00<@Q1BU5:D00aS60QBU0a240QBU0Q240PaS00D@Q0aS36<<H`Q2008<H`<@Q00336<@
Q0aS00<<H`0548@<H`aS36<@Q0025:D01A2436<@Q1BU6<H00Q240aBU11240PaS00L@Q0aS36<<Ha24
5:D@Q00436<00a2436<@Q00236<00aBU48@@Q00248@00aBU48@DY@025:D36<H248@010aS248<Ha24
0PaS00@8@PaS48@@Q08<H`0000D000@Q00048@0000<48@0A24848@@Q248e[GNmDY@e[DHaDYA>LdHa
CW=:DT8@?Nm24002AS4013g_>LhmkcW>0SF]00@aS3F]>LhicP8mk`03@Q16<DHa00924003?NlicSW>
008icP04@Q0icSW>?Nl2@Q05>Lh01CF]<H`icSW>@Q000SW>00@aS3W>?Nlmk`=24005AS5243g_=Jdi
cP02?Nl3>Lh01D8@?Nm243g_>Lh00cF]0SW>1Cg_0SW>0SF]00<aS3F]<H`01CF]00DaS3F]>LhicSF]
00<aS006>Lhe[CF]<H`e[CW>0cF]00HicSg_>LhaS2e[9BT3:DX3;F/2<H`3:DX01S6<=Jd]Jc6<=Jda
S0De[@04<H`]JbU:9BT7:DX00bDY8@PYBP04:DX59BT00b489BTYBP03;F/012DY8@PU:BU:0RDY0R48
0be[00@U:AcW8@PU:@8Q20037>LQ2248008U:@038@PU:BU:008U:@078@PU:BU::DXU:B487>L00R48
0RDY0RU:0RDY00DQ21cW8@PU:BU:008Q20069BTYBRe[:DXU:B4812U:00DLiaBU36<8@PaS0088@P03
00048@@Q01048@0400048@@Q1242248812400`Q212448@0:12400`Q212448@0=12400`Q21248@P02
24802P@Q36<8@Q24;F/e[BU:5:D8@Q240R480RU:00Le[Cg_AS56<Cg_;F/U:@027>L00a2436<8@P04
24800`aS1248@P091242248612401@Q21248@P@Q24800`@Q1`Q200L48@Q21248@P@Q248<H`062482
12400`Q236<<H`0448@00aBU6<HDY@025:D27>L01R487>LHaQcW6<HDY@<HaP8@Q0035:DLiaS600<H
aP@DY@8HaP8DY@0548@DYAS65:D@Q0045:D011245:D@Q1BU0Q2400<DYAS67>L00QS60QBU00@@Q1BU
5:D@Q0<DY@0548@DYABU6<HDY@0248@00aS65:DDY@0236<248@00aS65:DDY@037>L25:D01aS68@PU
:C6<=JdYBRDY00LDY@0648@DYABU48@DYA240aBU0a240aBU00L@Q1BU5:DHaQcW6<HLi`036<H248@0
0aBU48@DY@0348@35:D26<H25:D248@35:D011S65:DDYABU1Q2400<<Ha2436<01PaS00<@Q0aS36<0
0`aS0a241@aS00@@Q1BU5:DDY@<<H`8@Q0@DY@0448@8@PaS36<248@236<00a245:DDY@0348@22480
1@aS48@DYA2436<00Q240PaS0a240aBU0Q240QBU0Q2400<<H`Q236<00PaS00@@Q1BU48@<H`48@P00
2P@Q00L000aS>LicW5Je<Ha24003CW<014YBAS5244Ha0T8@13g_00HicSF]=JdaS3W>=Jd3?Nl2@Q02
AS43?Nl00d8@?Nlmk`02>Lh01Sg_AS5243g_>Lhmk`924003>LhaS36<00@icP06=JdicSW><H`e[CW>
0T8@00@mkcW>?Nlmk`8icP@mk`06>LhmkcW>=JdicSg_0SW>0SF]0SW>00<mkcW>>Lh00SW>00<e[C6<
=Jd00SF]00<aS2e[<H`00SF]0c6<0SW>00/e[C6<;F/aS3F]<H`e[CW>=JdaS3F]00@icP8aS003:DX]
JbU:008YBP03;F/aS36<008YBP8]J`03<H`]Jbe[008aS003=JdaS2e[00<e[@03<H`]Jbe[008YBP03
9BTYBRU:00HYBP8U:@<]J`039BTQ22DY008YBP<U:@8YBPDU:@038@PU:B4800@YBP<U:@8Q20037>LQ
22DY008U:@8Q208U:@038@PU:BU:008YBP048@PLib488@P49BT3:DX01B487>LQ22489BT00RU:0bDY
0RU:0RDY0bU:0QcW00<DYA24248020@Q00<000@Q12401P@Q00<000@Q12401@@Q00@8@P@Q124000l4
8@0324848@@Q01848@0>24848@Q21248@PaS124@Q2U:=JdaS24836<@Q08HaP09:DXU:C6<>Li244ic
@Q0mkbU:008Q20036<H@Q0Q2008<H`<8@PX48@0324848@@Q00848@0324848@@Q00848@<8@PD48@@8
@P848@0324848@Q200848@88@P0536<8@PQ21248@P031242248236<348@25:D00aS65:DHaP057>L0
1B486<HDYAS67>L00QS60Q2400@DYAS67>LLi`8HaP085:D@Q1245:DHaQcW6<H@Q08DY@<@Q0035:D@
Q12400@DY@8@Q08DY@066<HLiaS67>LHaQBU0Q241aBU00<HaQBU5:D00Q240aBU00T@Q1BU5:DHaQ24
5:DHaQcW6<H00QBU00`LiaS66<H]JcW>=JdU:A245:DHaQ246<H25:D00aS65:D@Q00248@25:D236<0
0a246<HDY@0248@45:D00a246<HLi`027>L25:D26<H00aBU48@@Q00448@00aBU48@DY@026<H011BU
48@@Q1BU0QS61QBU00<@Q0aS36<00`aS00@@Q0aS2488@PH<H`8@Q0<<H`0348@DYA2400D<H`8@Q003
36<@Q12400HDY@8@Q0035:D@Q0aS008<H`@@Q0035:D@Q0aS008@Q0@<H`8@Q00536<@Q12436<@Q003
5:D248@35:D248@736<148@136<12480000600048@@Q00048@000P@Q00T8@P001248@SW>Kg]>Lbe[
@Q000Tic0TYB00A6<D8@AS5:DP96<@@mk`03>LhaS36<008e[@04>Lhe[CF]>Lh2?Nl00cW>?Nm24002
AS42?Nl4>Lh2@Q000cg_@Q124009?Nl013F]>Lhe[CF]0cW>00@e[Cg_?Nm240<icP<mk`<icP8mk`03
>Lhmkd8@0092408mk`06@Q0mkcW>=JdicSF]0S6<13F]0SW>0S6<00D]Jc6<=JdicS6<008]J`04<H`i
cSF]<H`2>Lh01SF]<H`e[CW>?Nm2408icP8YBP8]J`8aS003;F/YBRU:008YBP05;F/YBRe[;F/YBP03
;F/00c6<=JdicP02=Jd00be[<H`e[@02<H`032e[:DXQ22U:;F/aS3F];F/YBRDY8@PU:@8Q20@YBP@U
:@LYBP8U:@07:DX]Jb488@PHaQcW8@P04BDY00@Q21cW7>LQ208U:@03:DX]JbU:00<U:@<YBP0:8@PU
:BDY:DXaS2e[:DXU:B489BT2:DX00b487>LDY@0236<3248612401@0012448@@Q00001@@Q00@8@P@Q
124000X48@0900048@@Q1248@P@Q00048@0000D48@0300048@@Q00<48@0324848@@Q00<48@042484
8@0012432484124010aS48@DYAcW0aS60`aS00HDYAcW6<HDYAS67>L26<H25:D01A2436<<H`aS2480
0P@Q10Q21@@Q00<8@P@Q12400P@Q00@<H`Q22488@P@48@88@P031248@PQ200<48@88@P0336<48@@Q
0088@P0436<8@P@Q1242248312401PQ236<<H`Q2124<H`D@Q0<DY@DHaP8Li`PHaP8DY@0348@HaQBU
008HaP035:DHaQS600<DY@<HaP8DY@0448@DYABU5:D448@25:D00aS648@@Q0025:D37>L26<H01124
5:DDYABU0QS600DDYAS65:DHaQBU008@Q08DY@066<HDYABU5:D@Q1S61QBU00<HaQBU6<H00QBU00@Q
22DY;F/]J`8Li`<DY@086<HDYA245:D@Q1BU48@<H`8@Q0035:D@Q12400<@Q0095:D@Q12436<@Q1BU
6<HLiaS6008DY@8@Q0085:D@Q12448@DYA245:D@Q08DY@8HaP077>LDYABU5:DHaQcW6<H00Q2400@D
YA2448@<H`D@Q0H<H`05248<H`aS48@<H`0348@011BU48@@Q1240`aS112400<DYA2448@00PaS00<@
Q1BU5:D011240QBU00@@Q0aS48@<H`8@Q0055:D@Q12436<@Q00336<548@436<248@25:D00aS67>LH
aP0248@00`aS48@<H`02248010aS48@@Q0aS0@Q2000212400`0012448@0212402PQ212448@@Q36<e
[G>LDY@]JcW>1DYB0THa015244YBAS5243g_>Lhmkd8@?Nle[C6<=JdicSF]>Lhe[Cg_008icP=24003
AS52448@008icP05?NlicSW>>Lhmk`04@Q03>Lh00cg_@Q124003>Lh2=Jd013W>?Nlmkcg_13W>00<e
[CW>?Nl00cg_0cW>00<mkcF]?Nl00THa00E243W>@Q1243g_00<icP05=JdaS3F]<H`e[@02<H`00cF]
<H`e[@02<H`3=Jd01C6<;F/aS36<>Lh01CF]00<icS6<<H`00SW>00Q243W><H`aS2DY8@P]Jc6<0SF]
00H]JbU:;F/YBRe[:DX2;F/3:DX0136<=Jde[CF]12e[0c6<00@YBRDY:DXYBP8aS003;F/YBRDY008Y
BP039BTQ224800<YBP<U:@@YBP039BTYBRe[008YBPDU:@058@PLib488@PU:@028@P39BT48@P69BT2
7>L011S68@PQ224812U:00<U:BU::DX00bDY00LYBRDY8@PYBS6<;F/YBP028@P01BDY:DXYBRDY6<H0
0Q2400<8@PaS124010@Q00<000@Q124010@Q00<000@Q12402P@Q00<8@P@Q12401P@Q0PQ230@Q00<8
@P@Q12400`@Q00<8@P@Q12401@@Q0PQ210@Q0PaS0aBU0QcW00DDY@aS248<HaS600<Li`036<HDYABU
008HaP045:D<H`Q236<3248010@Q248<H`Q22`@Q0`Q20`@Q1@Q200<48@Q212400P@Q1@Q20P@Q0`Q2
0P@Q0`Q200@48@Q224848@88@P0436<@Q1BU5:D348@36<H35:D27>L012487>LHaQBU0aS600<LiaS6
5:D011BU1AS600@DYAS65:DHaP<DY@046<H@Q12448@25:D011245:D@Q1BU0Q2400PDYA245:DDYAcW
8@PLiaS611BU0aS600LDYA2448@DYA245:D@Q0065:D01A245:D@Q1S65:D00QS61ABU0QcW0S6<00@Y
BQcW5:DDY@8HaP055:DHaQBU5:D@Q0025:D01Q245:D@Q12436<@Q0<DY@0636<@Q12448@DYA240QBU
0QS600<DYAS648@00a2400<DYA2448@00Q240QS600<LiaS66<H00QBU11S60Q2400@<Ha2448@<H`@@
Q0X<H`8@Q00336<@Q12400<@Q0@<H`0648@DYA2448@<Ha240`aS1A2400HHaQBU48@@Q1BU48@236<3
5:D348@336<348@010aS48@@Q1240PaS00@@Q0aS48@DY@<HaP8DY@@<H`0348@8@PaS008DY@4<H`00
014000@Q12448@00124000@Q24848@00248aS5kgAS4]JcW>00=:DP03AS5243g_00=24096<@06@Q16
<DHaBU96<D8@0cW>0SF]00@mkd8@BU96<@924003?NlicSF]008e[@8aS003=JdicSW>008icP03?Nli
cSW>008icP03@Q0mkcg_00924005?NlicSg_?Nm24004>Lh01Sg_>LhicSW>=JdicP<mk`DicP05<H`i
cSg_?Nm24003?Nl00d8@>LhicP02>Lh2<H`2;F/2<H`00cF]<H`e[@05<H`01SF]<H`]Jbe[<H`icP8a
S0<icP03=JdicSg_008mk`8aS003:DX]Jbe[00P]J`03<H`]Jbe[008]J`04:DX]Jbe[;F/2<H`2;F/0
12U:;F/aS36<0Re[1BU:0RDY00<Q22U::DX012U:0RDY00<YBRe[:DX00bU:00@]JbU::DXYBP@U:@03
:DXU:B4800<Q20<U:@8Q208YBP03;F/U:B4800@Q2006:DX]JbDY7>LHaR4812U:00HU:B489BTU:BU:
9BT58@P00bDY:DX]J`07:DX01B487>LHaQBU36<00`@Q00<8@P@Q24804`@Q00<000@Q12408@@Q00<8
@P@Q12400P@Q0PaS00@@Q0aS36<8@P8<H`0648@<H`Q2248<Ha240PaS00<@Q0aS36<010aS1@Q200<4
8@Q212402@@Q0`Q210@Q0PQ20`@Q00H8@P@Q2488@P@Q248212401`Q21248@P@Q24848@Q200P48@8<
H`88@P0336<@Q1S6008HaP8DY@0348@DYAS6008HaP<DY@056<HLiaS65:D@Q0025:D26<H011245:DD
YABU1AS600HLiaS65:DHaQBU48@45:D00a246<HDY@045:D011S65:D@Q1BU0Q2400DDYA245:DHaQcW
00<DY@036<HDY@aS008@Q0045:D@Q1BU5:D26<H35:D26<H65:D00a245:D@Q0036<H25:D02QcW5:D@
Q2DY>Lhe[BDY36<DYAcW0QBU00@@Q1BU5:DHaP<DY@076<H@Q0aS48@DYAS65:D00a240QBU00<HaQBU
5:D00Q2400<DYA2448@01A241ABU00D@Q1S67>LHaQBU008@Q0@HaP8@Q00336<@Q124008@Q0D<H`<8
@PH<H`D@Q08DY@0848@<Ha2436<8@PaS48@DY@H@Q08<H`0548@DYAS648@<H`0348@35:D348@00aBU
48@@Q00336<248@010aS48@@Q1S60Q240aBU00@@Q1BU5:D@Q0@<H`0448@<H`aS48@236<1248000<4
8@0300048@@Q00848@09248000@Q248aS6LiBU8]JcW>00E6<@8mk`03@Q16<DHa00=240=:DP0:@Q0i
cSW>>Lhe[CW>?Nm244YBAS42@Q001Sg_@Q0mkcW><H`e[@<icP03=JdicSW>00DicP8mk`07>Lhmkd8@
?Nm243g_@Q000Sg_00<icSg_?Nl01CW>00Le[CW>?NlmkcF]>Lhmk`04=Jd01CW>?Nlmkcg_@Q000SW>
0Sg_0SW>00<aS3F]<H`00c6<0SF]136<0SF]00<aS2e[<H`00c6<00De[CW>=JdicSF]00@icP<e[@03
<H`]Jbe[008]J`8aS004;F/YBRU::DX4;F/2:DX00be[:DX]J`02<H`2;F/01RU:;F/e[CW><H`YBP8U
:@03;F/YBRU:00<YBP03;F/U:B48008U:@03;F/YBRU:008YBP049BTYBRU:;F/3:DX00be[:DXYBP03
9BT2:DX012DY8@PLib4812DY00@Q22DY:DXYBPTU:@038@PLib4800<YBP038@PU:BDY008U:@04:DXU
:B489BT28@P00bU:9BT]J`03:DX39BT012U:9BTQ21S60Q2400<<H`@Q24800PQ200@48@00124000H4
8@88@P0300048@@Q00D48@0324848@@Q00P48@0324848@0000@48@0324848@@Q00H48@0324848@@Q
00H48@88@P848@030008@PaS008@Q0<8@P<@Q00336<8@PaS008<H`<@Q00436<@Q0aS36<624800`@Q
24848@04124010Q212448@@Q0`Q20`@Q0PQ20P@Q00<8@P@Q248010@Q00<8@P@Q248010@Q1@Q200@4
8@Q21248@P848@0324848@@Q00<8@P0448@DYAcW6<H25:D248@01aBU6<HHaQS65:DHaQcW008HaP03
5:DHaQBU00LDY@046<HDYAS65:D26<H27>L011BU48@DYABU0aS60Q2400<HaQBU5:D00QBU112400@D
YAS65:D@Q08DY@056<HLiaS66<HDY@0448@01QS65:DDYA245:D@Q0<HaP045:DHaQBU48@25:D01QS6
5:DHaQBU6<HDY@8@Q00;5:DLiacW48@<Hb48=Jdmkc6<48@DY@026<H25:D00a245:DDY@036<H25:D4
48@25:D00a245:D@Q00248@55:D0112436<<H`aS0Q2400<DYA2448@00QBU0QS600<DYAS66<H01QS6
0QBU112410aS00<@Q0aS36<020aS0a240PaS00<@Q1BU5:D00Q240`aS1A240QBU0Q2400@<HaBU36<<
H`8@Q0066<HDY@aS48@<Ha240aBU0a2400<<Ha245:D00Q240PaS112400<DYA2448@00Q2400LHaQBU
48@<H`Q236<@Q00336<248@236<00003124000@Q00848@0400048@@Q2482124020Q2<HacW5:D<Ha2
44YB@Q03>Lh0148@AS5243g_0SW>0T8@00E6<DYBAS5:DT8@00<icP05?Nm243W>>Lhmk`02>Lh01Sg_
@Q0mkcg_>LhaS08e[@06>Lhe[C6<<H`e[CW>0SF]00<icSF]<H`00S6<00<e[CW>>Lh00SW>00<mkd8@
AS400THa00M:DT8@@Q0mkcF]>Lhe[@03>Lh3<H`2=Jd01C6<=JdicSg_@Q000cg_1CW>00<e[CW>=Jd0
0SW>0cF]00DicSg_>Lhe[Be[008aS004;F/aS36<=Jd2;F/00c6<=JdicP03=Jd2>Lh01CF]<H`aS36<
=Jd00S6<00@]Jc6<<H`e[@<]J`05<H`e[CF]:DX]J`02:DX01Be[:DXYBRe[<H`00be[00<YBRe[;F/0
0RDY00<Q22DY9BT00RDY0RU:00<]JbU::DX01Be[00HYBRe[;F/YBRDY:DX2;F/01RU:;F/]Jbe[:DXU
:@8YBP039BTQ22DY00<Q208U:@8YBP@Q20059BTQ22488@PU:@027>L011S68@PYBRU:0Re[00<YBRDY
9BT00RU:00HU:B487>LQ21cW9BT28@P00acW8@PU:@02:DX01BDY8@PYBRe[9BT00acW00@DYA242488
@PP48@0300048@@Q00848@0424848@@Q000212401@Q212448@@Q000010@Q00L000@Q12448@001248
@P0@12400`Q212400003124020Q212448@@Q36<@Q0aS124224821242248236<00`Q21248@P062480
0`aS2488@P021243248512400`Q21240000612422483124010Q212448@Q20`@Q00@8@P@Q2488@PH4
8@0324848@@Q0088@P@48@0424848@Q2124236<01QS68@PU:B487>LDY@8HaP035:DHaQBU008HaP06
7>LHaQcW6<HDYAS61ABU00<HaQBU5:D00QBU0aS600<DYAS66<H00aS61ABU00<HaQBU5:D00QBU00<@
Q1BU5:D00QBU00L@Q1BU6<HLiaBU48@DY@036<H00aBU48@@Q00248@01ABU48@@Q1245:D00QS600DD
YA245:D@Q1BU008HaP@DY@8HaP8DY@0A6<HDYABU6<HLiaBU36<LibU:=Jd]JaS65:D@Q0aS5:D@Q002
5:D00a245:DDY@025:D448@35:D00a2436<@Q0025:D348@00`aS48@<H`0448@011BU48@DYA241ABU
00HHaQcW6<HDYA245:D46<H25:D0112436<@Q1240QBU00<<H`Q224800PaS00@@Q0aS248<H`@@Q0@<
H`8@Q00336<@Q124008@Q00436<@Q1245:D26<H25:D548@436<00a2436<@Q00248@336<248@25:D2
48@336<01QBU48@@Q1245:D@Q0<DY@D@Q08<H`04248<H`aS36<248@136<0000500048@@Q12400002
12403PQ212448@@Q248e[G>LDY@e[DHaBU9243g_>Lh3?Nl2@Q001cg_>LhicT8@AS5244Ha009:DP04
?NlicSW>@Q05?Nl00cW>?Nm24002?Nl01SF]<H`aS3F]>Lhe[@<aS0@icP04<H`e[C6<<H`2=Jd5>Lh0
1d8@AS56<DHa@Q16<D8@008icP05=JdmkcW>>Lhe[@04<H`3=Jd2>Lh2?Nl2>Lh013F]>LhicSW>0SF]
00<icSF]<H`00SF]0Sg_00@icSF]=JdaS08]J`04<H`e[C6<;F/2<H`012e[<H`aS3F]0SW>00He[CW>
=Jde[C6<=Jd4;F/01c6<=JdaS36<;F/aS2e[008aS003;F/YBRU:008]J`03:DXU:BU:00<aS08]J`8Y
BP059BTQ22489BT]J`029BT00bU:;F/]J`05;F/::DX01be[<H`aS2e[:DXU:BU:00<U:@047>LQ2248
9BT4:DX00b489BTQ20029BT38@P00bDY8@PLi`048@P012U:;F/]JbU:0R4800DYBRDY9BTQ21cW00DQ
20037>LU:BU:008YBP8U:@03:DXQ2248008Q20046<HDY@Q2248412400`0012448@0612401@001244
8@@Q00000`@Q00<000@Q12400P@Q00D8@P@Q12448@0001@48@0300048@Q200<48@0624848@@Q124<
Ha240PQ200<48@Q224801@Q200<48@Q224800PQ20PaS00@8@P@Q248<H`H8@PD48@0300048@@Q00<4
8@88@P<48@<8@P031248@PQ200D48@<8@P<48@<8@P0300048@Q200848@@8@P031248@P@Q0088@P07
36<@Q1S67>LQ21cW6<H00aBU0QS600PLiaS67>LLiaS65:DHaQBU0aS600@@Q1BU5:DDY@8HaP8DY@8H
aP@DY@<HaP@DY@8@Q08DY@046<HDYA2448@25:D248@36<H55:D01a245:D@Q1BU48@DYA24008DY@06
48@DYABU6<HDYA240QBU00<HaQBU5:D01ABU0QS60QBU00`HaQcW6<HDYA245:DLibU:;F/Q21cW48@2
5:D00a2436<@Q0026<H011BU48@DYABU0a2400HDYA245:D@Q1BU48@25:D448@01QBU48@<H`aS48@D
Y@<@Q0045:D@Q0aS48@35:D00a246<HLi`026<H25:D011S65:DHaQS60Q2400@<HaBU5:D@Q08<H`04
48@8@PaS36<248@236<448@01`aS48@<H`aS48@DYA2400<<H`035:D@Q1S6008DY@046<HDYABU48@2
36<00a2436<@Q00636<348@536<448@436<648@25:D348@336<0112436<<H`aS0Q240@aS00021240
3`0012448@@Q00048@Q2124000Q2;F][FU:D<Ha24002BU83AS42?Nl01CW>?Nm244YBAS401D8@1Cg_
0d8@0SW>00<mkcW>>Lh00SF]0cg_1cW>13F]0Re[00<YBS6<<H`00S6<00De[CW>>Li243g_0092408m
k`05>Lhmkd8@?NlicP02?Nl013W>=JdaS3W>0SF]0SW>00<mkcW><H`00SF]0SW>0SF]0c6<00@e[CW>
>Lhe[@8icP924004=JdaS2U:<H`2>Lh2=Jd4;F/00c6<=JdicP04=Jd00cW><H`]J`03<H`00be[<H`a
S002<H`012e[<H`]Jc6<0Re[00DaS3F]>Lhe[Be[008YBP06;F/aS36<:DXU:BU:0RDY12U:00DU:BU:
9BTYBRDY008YBP<]J`03=Jd]JbU:008YBP04<H`]JbU:9BT3;F/2:DX012DY:DXYBRe[0RDY0QcW0b48
1RDY1B4812DY0R480RDY0b4800<U:Be[:DX01B4800@Lib487>LLi`8Q20059BTQ22488@PU:@028@P0
2BDY8@PQ21cW8@PLiaS648@8@P0312400`Q212448@0812400`0012448@0412400`0012448@0;1240
0`0012448@0C124010Q212448@aS0PQ20P@Q00@8@P@Q12448@88@P041248@PQ2124224800`@Q2484
8@02124010Q212448@Q220@Q00<8@P@Q12401@@Q10Q22P@Q0`Q21P@Q00<8@P@Q12401PQ20P@Q0PaS
0QBU21S600<LiaS66<H00aS600<DYAS66<H00QS60aBU0QS611BU00DHaQBU48@DYAS6008DY@8HaP03
7>LHaQBU008DY@8HaP<DY@0348@DYABU008DY@0348@DYABU008HaP035:D@Q1BU00@DY@8HaP@DY@8@
Q08DY@047>LHaQBU5:D248@45:D00a245:DHaP026<H35:D00a246<HLi`027>L26<H012DY:DXYBR48
0QBU00<HaQBU5:D00QBU00<HaQBU5:D00a240QBU11240QBU00<@Q0aS48@00PaS00<@Q0aS48@00Q24
00@<Ha2448@DY@H@Q0035:D@Q1S6008DY@056<HDY@aS48@DY@027>L00aBU36<@Q0035:D248@00aBU
48@@Q00336<748@00aBU48@@Q00448@00`aS48@@Q00236<00a245:DDY@0248@01aBU7>LHaQ2436<@
Q0aS008@Q0<<H`<@Q0<<H`8@Q0@<H`0348@<H`aS00P@Q00336<@Q12400@@Q00336<@Q0aS008<H`4@
Q04DY@48@P0000<48@0012400P@Q00<000@Q24800`@Q00T8@SF]IcU:DS6<?Nm:DTHa@Q000THa0T8@
0Sg_00=243g_AS400T8@00=:DT8@?Nl00SW>00=243g_@Q000T8@0Sg_0cW>00DmkcW>>Lhe[CW>00<m
k`03>LhmkcW>00<e[@04>Lhe[C6<<H`4;F/00cF]<H`aS002=Jd013g_@Q1244Ha0SW>0cg_00A243g_
?Nlmk`8e[@8aS003=JdaS3W>008mk`03>Lhe[C6<008e[@03>Lhe[C6<008aS08e[@03>Lhe[CF]008i
cP03?Nm243W>00<aS003>Lhe[CF]00@aS08YBP03;F/e[CW>008e[@04>Lhe[CF]=Jd2<H`5;F/01c6<
=JdaS36<=Jd]Jc6<008]J`@aS08]J`<YBP04;F/YBRDY8@P29BT00bU:;F/YBP039BT00be[:DXYBP02
:DX01C6<;F/]Jbe[:DX00Re[0S6<00P]JbU:9BTYBRe[:DXaS2e[0RU:12DY00@Q21cW8@PU:@<YBP8Q
20047>LQ22487>L28@P49BT01BU:8@PQ22489BT00RU:1BDY00<Q21cW8@P011cW12480RDY00<Q21cW
7>L01B4800HHaQBU2488@P@Q248712400`0012448@0C12400`Q212448@0B1240100012448@Q20`@Q
00H8@PaS36<000@Q24841242248512422484124010Q212448@Q21@@Q00<8@P@Q12401`@Q0PQ210@Q
00@8@P@Q124000<48@0324848@@Q00<8@PH48@0424848@@Q124224800`@Q2488@P02248011245:DH
aQS60QBU0QS600<DYAS66<H00QcW00@HaQBU5:DDY@<Li`036<HDYABU00DDY@<HaP045:D@Q1BU6<H2
5:D011S67>LQ21cW11BU0QS600@DYA2448@@Q08DY@<@Q0DDY@0348@DYA2400<DY@056<H@Q1BU48@D
Y@0348@35:D01AS65:D@Q1BU48@00aBU0Q240QBU0QS600LDYA245:DHaR487>LHaP025:D01R48:DXY
BRDY5:D@Q0DDY@<@Q0<DY@0448@<Ha2448@35:D0112436<<Ha240`aS1A2411BU1A240QBU0Q2400HD
YAS66<HDYA245:D36<H00aBU48@@Q0025:D0112436<@Q1BU0PaS00<@Q1BU48@00`aS0Q240QBU00@@
Q0aS36<<H`8@Q0035:D@Q12400<@Q08DY@0448@DYA245:D26<H00aBU48@<H`0236<00`Q236<<H`02
48@336<00`Q236<<H`0248@00`Q236<8@P0248@236<0112436<@Q1240QBU00<@Q0aS48@0112400DD
Y@aS36<<Ha24008<H`48@P0000@000@Q124000848@0300048@Q200848@07248]JfLiBU8]Jcg_AS40
0cg_0T8@0THa00=:DTHaBU80248@00<mkd8@?Nl00SW>00LmkcW>?NlmkcW>?NlicP02=Jd01CW>?Nm2
43g_@Q000Sg_00HicSg_?NlicSF]<H`2=Jd00c6<;F/]J`03<H`2=Jd5>Lh2=Jd023W>?Nlmkcg_@Q0m
kcW>=Jd2<H`01cW>@Q12448@>Li243g_008e[@8icP03?Nle[C6<00@aS08e[@8icP8aS003=JdicT8@
008mk`04>Lhe[C6<=Jd2<H`2=Jd2<H`3>Lh00cF]<H`aS002=Jd00c6<=JdaS002<H`5;F/012U:<H`a
S36<0RU:00D]Jc6<;F/YBRDY008YBP05<H`]JbU:9BTYBP02;F/4:DX5;F/2<H`012e[:DXYBRU:0Re[
00LaS2e[;F/]Jc6<;F/YBP02;F/2:DX012DY:DX]JbDY0R4800HU:AcW7>LLib48:DX39BT28@P39BT0
0b489BTU:@03:DX39BT00bU:9BTU:@028@P39BT28@P00acW8@PQ20047>L28@P27>L28@P01acW8@PU
:BU:9BTLiaS6008Li`046<H<H`aS248212400`Q212448@0712400`0012448@0412400`0012448@0B
1240100012448@000`@Q00<8@P@Q12401P@Q0PQ220@Q0`Q20`@Q0PQ200<48@Q224800`@Q00<8@P@Q
12403`@Q1@Q20P@Q0PQ210@Q00@8@P@Q124000<48@0324848@@Q00@48@<8@P8<H`0748@HaQS65:D@
Q1BU7>L00QS60QBU1AS600@DYAS65:DHaP<Li`036<HDYAS6008DY@8HaP057>LHaQBU6<HLi`026<H0
0a245:DDY@035:D36<H45:D348@25:D01AS65:D@Q1245:D00Q2400<DYA245:D00Q240QBU0QS60QBU
00L@Q1BU48@DYAS648@DY@036<H25:D011245:DDYABU11240aBU0a240QBU0QcW0QS600@Lib489BTQ
20<Li`@HaP8DY@0348@DYA2400<DY@0348@<Ha24008DY@8@Q00336<@Q0aS00<<H`8DY@8HaP8DY@04
48@DYABU5:D248@01AS648@<H`aS48@00QBU112400@DY@aS36<DY@8Li`045:D<Ha245:D336<00a24
5:D@Q00348@01PaS5:DHaQS65:D<H`@@Q08<H`8@Q0035:D@Q1BU00<@Q00436<@Q1BU6<H25:D00a24
36<@Q00336<00a2436<<H`0436<348@236<010Q236<@Q0aS1Q2400@<Ha2448@DY@8@Q00336<@Q124
00<@Q08<H`8@Q04<H`0010@Q00<000@Q12400P@Q00/000@Q36<aS6LiBU8]JcW>@Q0mkcW>008mk`06
@Q16<DHaAS5:DTHa0T8@0Sg_1D8@0Sg_0SW>00Dmkd8@?NlicS6<00DicP03?NlicT8@0092408mk`03
>LhmkcW>008e[@8icP05<H`]JbU:<H`]J`02<H`3=Jd4>Lh00cF]>Lhmk`03?Nl00d8@>LhicP02<H`2
>Lh01Sg_@Q0mkcW>?Nle[@<icP<e[@03<H`e[C6<00<aS0@e[@03<H`e[CW>00<mk`8e[@04<H`e[CF]
=Jd4<H`4=Jd2<H`013F]>LhaS2e[0S6<12e[0S6<22e[00@YBRDY:DXYBP8]J``YBP03<H`]Jbe[00D]
J`07:DX]Jbe[;F/aS2e[<H`012e[0S6<00<YBRDY9BT00RU:00DQ21cW7>LQ22DY008Q20<U:@@Q20DU
:@8YBP<U:@<YBP049BTQ22488@P29BT00b487>LQ20057>L48@P00acW8@PQ20038@P02BDY8@PLiacW
6<HDYA2436<8@P0312400`Q212448@09124010Q212448@002`@Q00<000@Q12402@@Q00<000@Q1240
1@@Q00<000@Q12400P@Q0`Q22P@Q0PQ220@Q00H8@P@Q12448@00124224800`0012448@0;1243248;
12400`Q212448@0612422482124324801A245:DHaQBU48@00QBU0aS600@DYAS66<HLi`8HaP037>LH
aQS600DHaP@DY@LHaP@DY@036<HDYABU008DY@<HaP035:DHaQBU008DY@0648@DYABU5:D@Q1BU0Q24
00<DYA2448@00QBU00H@Q1BU48@DYAS65:D26<H248@00aS65:DDY@025:D00a245:DDY@026<H00aBU
48@@Q0025:D011245:D@Q1BU0Q2400@DY@aS48@DY@<HaP0=5:DHaQcW6<HQ22e[:DXU:AS65:DHaQBU
6<H00QBU00@HaQBU5:DDY@8@Q0035:D@Q12400<@Q00336<@Q0aS00@<H`0748@DYAS65:D@Q1BU6<H0
0QBU0Q2400LDYA2448@@Q1BU48@DY@0248@011BU48@<H`aS0Q240aS600<DYA2448@031240aBU00<@
Q0aS48@010aS00DDYA2448@@Q0aS00@@Q00636<@Q1S67>LDYA240PaS0Q2400D<H`Q2248<Ha2400<<
H`8@Q08<H`0348@<H`aS008<H`0448@<H`aS36<348@00`aS48@@Q00248@011BU48@<H`aS11240@aS
0A240@Q200000`001240000512403@Q2124000Q2;F]W>DYB<Ha244Ha?NlicSF]00=24004BU96<DHa
AS49@Q02AS42?Nl00cW>@Q16<@03@Q0013g_>LhaS36<1CF]0Sg_0THa00@mkcW>=Jde[@8icP8e[@04
<H`icSW>=Jd2<H`3>Lh2=Jd01Cg_>LhicSW>?Nl013W>00@e[C6<=Jde[@92408icP8e[@@icP@e[@03
>Lhe[CF]00<aS004;F/aS36<=Jd2>Lh4?Nl6>Lh3=Jd2>Lh02Cg_@Q0icS6<;F/aS3W>=JdaS004;F/0
0c6<;F/aS002<H`2;F/2:DX29BT00bU:;F/aS004;F/2:DX00c6<;F/]J`02:DX012e[:DX]Jc6<0SF]
00<aS2U::DX012e[00<YBRDY9BT00RU:0Re[00<aS2e[:DX012U:00T]JbU::DXQ21cW8@PLib489BT0
0R4800@Lib488@PQ208U:@038@PU:BDY00<YBP<U:@8YBP049BTQ22DY:DX49BT012487>LLib480QcW
00<Q21cW8@P00R4800<Lib487>L00bDY0R4800/LiaS68@P]Jb487>L<H`Q248@8@PaS00H8@PD48@04
00048@@Q248=12401P0012448@001248@PX48@0500048@@Q1248@P0212400`0012448@0312400`Q2
12448@021242248412400`Q21248@P06124010Q212448@000`@Q00<8@P@Q12401@@Q00D000@Q1248
@PaS00848@0324848@Q200848@0300048@@Q00X48@0324848@@Q00848@0936<@Q2e[>LhYBQcW248<
HaS600<Li`036<HDYAS600<HaP057>LHaQcW6<HDY@026<H011cW6<HDYABU0QS600<DYAS67>L00QcW
00DHaQBU6<HDYAS600<DY@0:6<HDYABU5:D@Q1BU48@DYA245:D548@25:D348@01ABU6<HHaQ2436<0
1A2411BU0Q2400HDYAS66<HHaQBU6<H37>L26<H01ABU6<HHaQS65:D00Q2400<DYA2448@00Q240aBU
00<@Q1BU6<H00QBU00HHaR48:DXYBQcW6<H35:D00aS65:DDY@025:D00aS65:DHaP0448@00aBU36<<
H`0236<448@00`aS48@DY@025:D011245:D@Q12411S600<@Q1BU48@01ABU00LHaQ2448@<Ha246<HL
i`025:D836<348@236<248@25:D248@236<248@236<848@00`aS48@@Q0045:D248@010aS48@@Q124
0`aS00<@Q0aS36<010aS00D@Q0aS36<@Q0aS0088@P0336<@Q12400L<H`D@Q08<H`4@Q04<H`4<H`00
1@@Q00<000@Q24800`@Q00H8@S6<IcU:DS6<?Nl2@Q02>Lh3?Nl0148@AS5:DTHa0T8@00<mkd8@?Nl0
0T8@00Dmkd8@@Q16<D8@008mk`9240<mk`<icP8aS006=JdicSW>>Lhe[CW>0d8@00HmkcF]=JdicSF]
>Lh3=Jd2>Lh0136<=Jde[CW>0SF]00@icSF]>LhicP8mk`05>LhmkcF]=JdaS002=Jd013W>?Nlmkd8@
0SW>0cF]00@icSg_>LhicP8e[@07>Lhe[C6<<H`]Jc6<;F/00S6<00@e[CW>>LhicP8mk`06>Lhe[CW>
>LhmkcW>0cF]0SW>0cg_00@icSF]<H`aS0<e[@03<H`]Jbe[008aS0<]J`05<H`]JbU:;F/YBP039BT0
0be[<H`]J`02<H`012e[:DX]JbU:0Re[0RU:00<]JbU:;F/00Re[0S6<0Re[00@YBRe[<H`aS08YBP8U
:@<YBP06;F/YBRe[<H`YBRe[0RDY0RU:0RDY0QcW0b4800LLib487>LQ22DY8@PU:@028@P39BT2:DX2
9BT3:DX00bDY8@PQ20029BT38@P01BDY8@PLiacW8@P00QcW00@HaR488@PQ208Li`088@PU:BDY8@PU
:AcW5:DQ208YBP068@P@Q0aS48@8@PaS0`Q200<<H`@Q00000P@Q0PQ20`@Q00<000@Q12401@@Q00<0
00@Q124050@Q00<8@P@Q12400P@Q00<8@P@Q12400P@Q00<000@Q12400PQ210@Q00<8@P@Q24802@@Q
00<8@P@Q124020@Q00<8@P@Q12400`@Q00H8@P@Q2488@P@Q24831242248412400`Q200048@061240
0`Q212448@0212403@aS24848BDY@Q16<Be[248<HaS65:DHaQcW00<HaP035:DHaQcW008Li`046<HD
YABU7>L36<H01acW6<HHaQBU6<HDYAS6008Li`035:DHaQ2400HDY@036<HDYABU00HDY@@@Q08DY@03
6<H@Q1BU00@DY@036<HDY@aS008<H`8DY@<@Q0055:D@Q1BU48@HaP025:D011S67>LHaQcW0QS600<D
YAS65:D00QS60QBU1A2400<DYA245:D00Q240QBU00HHaQ246<HLibU:9BT36<H25:D36<H35:D00aS6
5:DDY@025:D448@436<248@011BU48@@Q12411BU00<@Q1BU5:D00QS600DDYA2448@@Q1BU00<HaP0:
5:D@Q12448@<HaBU48@HaQBU48@336<348@236<00a245:D@Q00336<00aBU48@DY@0248@010aS48@<
H`aS0a2410aS112400<<Ha245:D00aBU0Q2420aS00<@Q0aS36<010aS00<@Q0aS48@01PaS0Q2410aS
1A2400@<Ha2436<<H`48@P00010000@Q00048@00124000@Q248000@Q248]Jf<HBU8]J`8mk`DicP0;
?Nm2448@AS5:DSg_>Lhmkd8@BU924002?Nl5@Q001DHa@Q12448@?Nl00T8@00A6<Cg_?Nlmk`DicP8e
[@03<H`e[CF]008mk`<icP8e[@8icP8mk`09>Lhmkcg_@Q0icSF]>Lhe[Cg_00@icP8aS0<e[@03<H`i
cSg_008mk`<icP06?NlicSW>?Nle[C6<13W>0Re[0c6<00@e[C6<=JdaS08icP8e[@8icP8e[@03<H`e
[CF]008e[@@icP08=JdaS3F]<H`e[CW>?NlicP<aS009;F/YBRe[<H`icSg_=JdaS2U:00<]J`06:DXU
:BDY;F/aS3W>0S6<00<e[C6<;F/00RU:1Be[0c6<0Re[12U:0RDY00<YBRe[:DX00RU:00D]JbU::DXU
:B48008U:@03:DX]Jbe[008U:@8Q208U:@@Q20059BTQ21cW9BTYBP039BT01BU:9BTU:BDY:DX00Re[
00@YBS6<:DXU:@`Q20037>LQ22DY008U:@038@PLib4800@U:@048@PU:B486<H47>L00aBU6<HLi`02
7>L01a2436<48@@Q24848@Q200848@88@P@48@0324848@@Q00<48@0324848@@Q00L48@0324848@@Q
00@48@0300048@@Q00@48@0300048@@Q00`48@0324848@Q200L48@0324848@@Q00T48@88@PL48@88
@P848@88@P<48@0424848@@Q000;124010Q236<<HbU:0S6<00DYBQBU5:DHaQBU008HaP<Li`<HaP05
5:DHaQcW7>LQ20026<H25:D00aS65:DHaP026<H45:D00aS65:DHaP045:D36<H00aBU48@@Q0026<H3
48@45:D248@25:D26<H25:D011245:DDYABU11240aBU0QS600@@Q1BU48@DY@8@Q0<DY@047>LHaQcW
6<H27>L00b486<HDY@025:D00a245:DDY@035:D248@03QBU48@HaQS65:D@Q1BU7>LU:Be[9BTLiaS6
5:D56<H011BU6<HHaQ240QBU00DHaQBU48@@Q1BU00<@Q00336<@Q1BU008DY@8@Q0035:D@Q1BU008@
Q0@DY@0448@DYABU5:D46<H25:D00a2436<<H`0248@25:D248@2248236<00a245:D<H`0536<248@2
5:D00a2436<<H`0348@336<00aBU48@<H`0336<248@236<248@25:D236<248@00aBU48@@Q00348@2
36<348@236<00`Q236<<H`0336<00a2436<<H`0636<011245:DDYABU1A240@aS0008124020Q21244
8@Q2<Ha_Ne:D;F/5>Lh01Cg_>Lhmkcg_@Q000THa248@00Dmkd8@@Q1243g_00Y24003?NlicSF]008e
[@<icP03=JdicSW>00DicP03=JdicSW>008mk`8icP03?Nm2448@00@icP8mk`8icP<e[@<aS08e[@09
?NlicSW>=JdicSg_@Q0mkcW>008e[@<icP08=JdicSF];F/YBRe[<H`icP@e[@8icP03=JdaS3F]00<i
cP8aS08e[@8mk`8icP04<H`e[CF]<H`2=Jd3>Lh2<H`012e[:DX]JbU:0cW>00<e[C6<:DX00RU:00<]
JbDY:DX00Re[136<0be[1RU:00@aS2e[=JdaS08YBP039BTYBRe[008YBP8U:@8YBP<]J`03:DXQ22DY
008U:@8YBP039BTQ22DY00<U:@038@PU:BDY008Q20037>LQ22DY008Q208U:@09:DXU:BDY:DXU:BU:
;F/YBRe[008YBP8U:@068@PU:AcW8@PLib480QcW124800@Lib489BTQ208Li`038@PU:BDY00<U:@<Q
200;7>LHaQcW7>LQ21S648@Lib487>LDY@021242248212400`Q212448@0312400`Q212448@031240
1@Q212448@@Q00001`@Q00<000@Q12405`@Q00@8@P@Q2488@PD48@0324848@Q200P48@0400048@@Q
24881242248412401@Q212448@@Q248030@Q00h8@P@Q12448@Q28@PaS3W>;F/DYAcW6<HDYAS60QcW
0aS600HLiaS66<HHaQBU6<H27>L011S65:DDYABU0aS600<DYAS66<H00QS600@DYAS65:D@Q08DY@03
6<HLiaS600DDY@0448@DYABU5:D348@011S648@@Q1240QBU00HHaQBU5:DDYAS65:D248@02`aS48@D
YA245:D@Q1BU48@DYA245:D00Q2400HDYA2448@DYAS67>L46<H28@P26<H248@25:D01A245:D@Q124
5:D00a2411BU00P<HacW:DXaS2U:5:D@Q1BU1QS60aBU0QS600TDYA2448@@Q1BU48@<Ha2436<00Q24
0QBU0a2400@DYA2448@HaP8DY@8@Q0DDY@077>LHaQBU48@DYA2436<011BU10aS00<@Q0aS36<020aS
00H@Q0aS36<@Q1BU48@224800`aS48@<H`0348@011BU36<<H`aS0Q240`aS00<@Q1BU48@01A240`aS
00<@Q0aS36<00Q240QBU0PaS0PQ20PaS00<8@PaS36<00Q240PQ20PaS1A240PaS00@DYA2448@<H`48
@P0000D000@Q00048@0000<48@0=24848@00248aS6mkDY@aS3W>@Q0icSg_>Lh00Sg_00Q244HaAS56
<D8@>Lhe[CW>0d8@00@mkd8@AS56<@8mk`8icP@mk`9240=6<@03@Q0mkd8@0092408mk`04>Lhe[CW>
?Nl2>Lh00c6<=Jde[@02=Jd013W>=Jdmkd8@13g_00E243g_>LhicSg_00924004?Nle[C6<=Jd2<H`0
5CF]<H`mkcg_@Q0icSF]>LhmkdHaBU9243g_=JdaS3W>?NlicS6<;F/e[@03>Lh00cF]>Lhe[@02=Jd0
0c6<>LhicP02=Jd2<H`00cF]>LhicP05>Lh00cg_>LhaS002;F/03C6<=JdicT8@?Nle[Be[:DXe[Cg_
>Lh]Jc6<00HYBP05;F/YBRDY:DX]J`03<H`01CF];F/]JbU:;F/00S6<00<e[C6<;F/00bU:0S6<00@]
JbU::DXYBP<U:@<YBP<U:@8YBP<U:@HYBPTU:@05:DXU:B488@PYBP029BT022489BTYBRDY:DXU:BU:
;F/2:DX00bDY8@PQ20048@P37>L48@P00acW9BTQ20039BT00b487>LU:@02:DX00bDY8@PQ20029BT0
1R487>LQ22489BTicP924007=JdHaQBU36<8@PaS24800`@Q00<8@P@Q124030@Q00D000@Q12448@Q2
00L48@03248000@Q00<48@0400048@@Q248612400`Q212448@031243248010@Q00048@Q20P@Q00<0
00@Q12400`@Q0PQ200@000@Q12448@88@QD48@030008@PQ200<48@88@P0?1248@P0036<e[DicHaQ>
Lb487>L@Q1BU7>LDYAS600<Li`036<HDYAS6008Li`8HaP@Li`8DY@056<HDYAS66<HLi`056<H35:D2
6<H01aBU7>LLiaS65:D@Q1BU00@@Q08DY@0348@DYABU00<DY@8HaP<DY@076<HLiaS66<HDYA245:D0
1A240QBU1A240QBU0a240QBU0QS600<DYAS66<H01QBU00<@Q1BU6<H00aBU0Q240QBU00<HaQBU6<H0
0RDY00<Q21S65:D02QBU0QS60QBU00<@Q1BU48@00Q241ABU00@HaQBU48@@Q08DY@8@Q0046<H@Q124
36<:5:D248@00`aS48@@Q00548@00`aS48@<H`0236<00`Q236<<H`0236<248@336<348@010aS48@<
H`aS112410aS0a2400<<Ha245:D00QBU00@@Q0Q236<<H`D@Q0035:D@Q124008<H`8@Q08<H`88@P8<
H`0348@<H`aS00<<H`0548@8@PaS36<@Q0025:D00a2436<@Q00336<000P48@09248000@Q248aS6mk
DY@]JcW>00<mk`<icP03?Nm6<D8@00924004>LhmkcW>>Lh2@Q000dHa@Q124004@Q02?Nl2>Lh2?Nl0
148@BU96<DHa1D8@00<mkd8@>Lh00SW>00De[CW>=JdicSF]00@aS00;=Jdmkd8@AS4mkcW>@Q0mkcW>
?NlicP04?Nl00cW>=JdaS003<H`2=Jd5>Lh01Cg_AS56<DHa?Nl01SW>00DaS2e[<H`e[Cg_008icP03
=JdicSF]00@e[@06<H`e[C6<>Lhe[CW>0cg_0SW>00@e[CW>>Lhe[@<aS008>Lhmkd8@>LhaS2e[<H`e
[@8icP08=JdYBRU::DXU:BU:;F/YBP8]J`8YBP04;F/aS3F]<H`5;F/01CF]<H`aS2e[:DX01Be[1BU:
00HU:BU::DXU:Be[<H`2;F/49BT3:DX012e[:DXYBRU:0b481RDY00@Q22DY8@PU:@8Q20<U:@8Q2003
9BT]Jbe[008YBP@Q208Li`8Q20057>LQ22488@PU:@028@P00acW9BTU:@029BT27>L012DY;F/]JbDY
2B480SF]0Sg_00<Q21S624800PaS1@Q21@@Q00<8@P@Q12404P@Q00D000@Q12448@Q200/48@030004
8@Q200L48@0324848@@Q00T48@0300048@@Q00D48@0324848@@Q00<48@0324848@@Q00/48@88@PH4
8@88@P848@068@PicV]JG_LaS2e[0Q2411cW0aS60QBU0QS60QcW00DHaQcW7>LLiaS600@DY@<HaP0:
5:DHaQcW7>LDYA245:DHaQBU6<H37>L011S648@@Q1240QBU00<<Ha2448@00QS61QBU00@@Q1S66<HL
i`8HaP8DY@8@Q00336<@Q12400<@Q0075:DHaQBU48@<Ha246<H00aBU00<HaQBU5:D00QS600<LiaS6
5:D00Q2400<DYAcW5:D01QBU00HHaQBU5:D@Q1BU6<H25:D01b48:DXQ21S65:DLiaS600LDY@036<HD
YAS600DDY@0336<@Q12400<DY@076<HDYABU5:D@Q1BU6<H00QBU0Q2400@<Ha2448@HaP@DY@046<HD
YA2436<248@01QBU48@<H`aS48@<H`D@Q0@<H`04248<Ha2436<248@00`aS48@<H`0248@236<548@3
36<01A2436<@Q0aS48@00PaS00@@Q1BU6<H@Q0@<H`0348@<Ha2400H@Q0<<H`0548@<H`aS248<H`03
48@010aS48@<H`Q20PaS1A2400<DYA2448@00PaS00000`001240000212400`0012448@0312403`Q2
<Hag_E[F>Li6<DYBAS5244HaBU9>LdYBCW=:DP02AS42?Nl00cF]>LhicP02?Nl5@Q06>Lh00cF]>Lhi
cP02?Nl0148@>Lhmkcg_248@00<mkcW>=Jd00SW>00DmkcF]=Jde[CW>008mk`05>Lhmkcg_>Lhe[@02
>Lh013g_>Lhe[CW>0SF]00<icSF]>Lh00cW>00De[C6<<H`aS3W>00=24003?Nle[CW>008mk`0:=Jda
S3F]>Li244YB@Q0mkcW>=Jd3>Lh00c6<=Jde[@03<H`013F]?Nlmkcg_0cW>0cg_0cW>00<mkcW>=Jd0
0S6<0SF]00LicSF]=Jde[C6<=JdaS002;F/3:DX00be[:DXYBP02;F/00c6<;F/]J`03<H`01Be[:DX]
JbU:<H`012e[0c6<00de[C6<<H`]JbU:;F/YBRe[<H`e[C6<:DX]J`02<H`2:DX3;F/012U:9BTYBRDY
0RU:12DY0RU:0bDY00@YBRDY9BTQ20<U:@8YBP039BTQ224800<U:@048@PLib487>L28@P27>L48@P0
0acW8@PLi`027>L00b489BTQ20028@P012DY:DX]Jbe[0bDY124800<U:BU::DX00RU:00<]JbU:9BT0
0QcW00<DYAS65:D00Q2400<8@PaS24800`Q200<48@Q224800`@Q00<8@P@Q12400`@Q0`Q200<000@Q
12400`@Q00D8@P@Q12448@0000T48@88@P<48@88@PD48@0300048@Q200@48@0300048@@Q00P48@03
24848@@Q00<48@0424848@@Q24841242248412401@0012448@@Q248010@Q0PQ200D@Q1cW8@P]JbU:
008U:@8Q20037>LHaQS6008Li`056<HLiaS67>LHaP025:D26<H00aBU6<HLi`026<H25:D46<H01a24
5:DHaQcW5:DHaQcW00<HaP0648@DYA245:DHaQBU0QS600<DYA245:D00QcW00<HaQ2448@00aBU0QS6
00<DYAS66<H01AS60aBU0a2400@DYA245:D@Q0@DY@<@Q0@DY@0348@DYAS6008HaP055:DHaQS66<H@
Q0035:D36<H01AcW6<HHaQBU6<H00QcW00HDYAS68@PYBRDY5:D248@00aBU48@HaP045:D00a245:DH
aP036<H25:D348@011S65:D@Q1BU0QcW00THaQ2448@DYAS67>LDYA2436<00a240PaS00D@Q1S66<HH
aQ24008<H`0348@DYA2400<<H`8HaP<DY@<<H`0448@<H`aS48@536<648@236<248@00aBU48@<H`02
36<00a2436<@Q00248@010aS48@DYAS60QBU10aS00H8@PaS36<<H`Q236<348@436<01a2436<<H`aS
48@<Ha2400<<H`03248<H`aS00<@Q0<<H`<@Q048@P000`@Q00<000@Q12400P@Q00X8@P@Q1248@S6<
MkeJeSF]AS5:DP96<@924007AS5:DTicCW=6<DYB?Nl00SW>00@e[Cg_>Lhmk`A24003?Nm243g_00<i
cP8e[@06?NlicT8@@Q0mkd8@0Sg_1D8@00@mkd8@@Q16<@8mk`8icP<e[@8icP8mk`HicP0=?NlicSg_
=JdaS3F]>Lhe[CW>=JdicSF]>Lh00SF]00LicSF]=JdicT8@AS524003>Lh2?Nl0136<;F/aS48@0THa
0T8@0SW>0SF]0SW>00@e[C6<;F/aS0<icP8mk`03>Lhe[CW>008mk`8icP8mk`03>Lhe[C6<00<e[@<i
cP03=JdaS36<008aS005;F/YBRU::DX]J`02:DX4;F/00bU:;F/]J`02<H`2:DX01Be[<H`aS2e[:DX0
136<00@e[C6<<H`]J`<YBP03;F/aS3F]008aS005:DXaS36<<H`]J`03:DX00be[:DXYBP04:DX00bDY
:DXU:@029BT01R489BTYBRe[:DXU:@8Q2003:DXU:BU:008YBP@U:@038@PLiacW00@Q20037>LQ2248
00DQ20047>LQ22489BT58@P00bDY;F/YBP03:DX29BT00b489BTU:@029BT01RU:;F/YBRU:9BTQ208L
i`8DY@8@Q08<H`D8@P<48@0424848@@Q248612401@0012448@@Q00000`@Q00@000@Q00048@88@P84
8@0300048@Q200h48@0324848@@Q00@48@0324848@Q200d48@0324848@Q200H48@0324848@@Q00D4
8@0324848@@Q00<48@0824848@@Q248@Q1cW:DXU:@8YBP8U:@<HaP8Li`038@PHaQS6008DY@046<HL
iaS65:D26<H00aBU6<HHaP046<H00acW6<HHaP035:D56<H45:D00aS648@DY@055:D01a245:DHaQS6
5:DHaQ24008DY@8HaP8DY@046<HLiaBU5:D27>L00aBU48@@Q0025:D011245:D@Q1BU0a241QBU00<H
aQBU48@00QBU00<LiaS65:D00QBU0QS600PDYA245:DHaQcW6<HDYAS60QBU00<HaQcW7>L00QS600LL
ib487>LLiaBU6<H@Q0045:D248@01ABU6<H@Q1BU6<H00aBU00D@Q0aS48@@Q1S600LDY@036<HDYABU
008DY@<<H`03248@Q124008@Q0055:D@Q1BU48@DY@0348@00`aS48@@Q0025:D00a245:DDY@0248@5
36<248@336<0112436<<H`aS1A2400<<H`Q248@00Q2400<<H`Q236<00Q2400<<Ha2448@00aBU0Q24
00<<Ha2448@00Q240PaS0a2400<<Ha2436<00`aS0Q242@aS00H@Q0aS48@@Q0aS48@236<00a245:D@
Q0012480000500048@@Q1240000312402`Q200048@Q2=JecW5Je=Je244YB@Q000dHa00E:DTHaBU9:
DTic00=:DP03@Q16<D8@00924007?Nm2448@@Q0mkcW>?Nl00d8@0SW>00<e[CW>>Lh00cW>1cg_1D8@
0Sg_00<icSg_=Jd00cF]00<mkd8@@Q000SW>0T8@00<mkcF];F/00S6<0SW>00Le[CW>=JdicT8@>Lhe
[@02;F/2<H`013F]?Nm243g_0SF]00<icSg_>Lh00c6<00@e[CW>?NlicP8mk`924003>Lhe[CF]008i
cP04=JdaS3F]=Jd2<H`013F]?Nm243g_13F]136<00<icSg_>Lh013W>0SF]1C6<0be[00<YBRe[;F/0
0Re[00dYBRDY;F/e[C6<;F/U:B48:DXaS3F]>Lhe[@03;F/02S6<=Jde[C6<=JdaS2e[<H`]Jc6<12e[
00HaS2e[=JdicT8@AS42=Jd02S6<:DXYBRU:9BTYBRDY:DXU:BU:1BDY0RU:12DY0bU:00<Q22DY8@P0
0RDY0R4812DY00<Q22DY8@P012480RU:00<U:B488@P01B4800<U:B489BT00bU:00HU:B488@PQ22U:
9BT28@P00bDY:DXYBP04:DX012487>LLiacW0aS600<DYA2436<00Q2400<<H`Q224800`Q200<48@Q2
248020@Q00<8@P@Q00004`@Q0PQ27@@Q00<8@P@Q12403@@Q00D000@Q1248@P@Q0088@P8DY@046<HU
:B487>L26<H021cW9BTYBR487>LDYAS68@P27>L36<H01QBU6<HDYAS65:D@Q08DY@8HaP055:D@Q1BU
7>LDY@0248@01QBU6<HDYABU48@DY@D@Q0035:DHaQS600@HaP8DY@036<HDYAS6008DY@@HaP065:D@
Q1BU5:DHaQBU112400<DYA2448@00a2400@<Ha245:DDY@8@Q0045:DHaQS66<H35:D00a246<HDY@03
5:D011S65:DDYABU0aS60QBU00L@Q1S66<HHaQBU48@DY@026<H01acW8@PU:BDY7>LHaQBU00@HaP03
5:D@Q1BU00<DY@8@Q08DY@0548@DYABU48@DY@0348@25:D01AS65:DDYA245:D00QS60QBU0a240PaS
00@@Q1BU5:DDY@<@Q0<DY@0348@<H`aS008@Q08HaP075:D@Q0aS36<@Q0aS24800PaS0a2400HDYA24
48@<Ha245:D248@236<01A2436<<H`aS48@00`aS00<@Q0aS48@00Q240PaS0Q2400<DYA2436<00`aS
112400<<Ha2436<00`aS0Q2400@<Ha2436<@Q088@PD<H`0648@<H`aS36<8@PaS11240@aS00000`@Q
00048@021240100012448@Q20P@Q00H8@SF]MkeJeS6<@Q02BU800dHa@Q16<@02AS45BU83AS42@Q00
0cg_>Li24002@Q001Sg_>Lhmkd8@AS4mk`8icP03=JdicSW>008icP03=JdicSg_00@mk`M2408mk`@i
cP04=Jdmkcg_?Nl3>Lh2@Q0013W>=JdaS36<1CF]1CW>00H]Jc6<;F/e[Cg_@Q02?Nl01CW>?NlicSW>
=Jd00S6<00<e[CW>>Lh00Sg_1SW>0SF]0SW>136<00<e[CW>?Nl00cW>00Pe[CW><H`aS2e[<H`e[CW>
0Sg_0SF]00<icS6<<H`00cF]00<aS2e[:DX00RU:12e[010aS2U:9BT]Jc6<=JdaS2DY8@PYBRe[<H`e
[C6<;F/aS08]J`DaS004=JdaS36<;F/4<H`2;F/2=Jd02cg_@Q0mkcF];F/YBS6<:DXU:B489BT00RU:
0RDY00<Q22DY9BT022DY00HQ22DY:DXU:B489BT48@P29BT012489BTQ22480acW00@U:B488@PLi`<Q
20059BTQ22488@PLi`038@P3:DX012487>LQ22480bU:00@U:B487>LU:@8YBP038@PLiacW008Q2003
7>LHaQBU00<@Q08<H`88@P0436<8@PQ2248712400`Q212448@0:124224800`@Q00048@0712400`Q2
12448@0312400`Q21248@P0<12400`Q21248@P0312400`Q212448@0612400`0012448@06124010Q2
12448@Q210@Q0`Q200<@Q1S68@P00R4800<LiaS67>L00R4800DLiaS66<HLib4800@Li`<DY@036<HL
iaS6008HaP035:DHaQBU008DY@8HaP045:D@Q1246<H25:D01Q245:D@Q1BU48@DY@8@Q0<DY@@Li`8H
aP035:DHaQS600@DY@8HaP045:D@Q1245:D26<H25:D011245:D@Q1BU0Q2400<DYA2448@011241QBU
00<HaQBU5:D00aBU00H@Q1BU5:DHaQBU48@25:D26<H01ABU6<H@Q1BU6<H011BU00PHaQcW7>LHaQcW
9BTLiaS60QBU00DHaQcW5:DDYA2400@DY@0348@DYABU00DDY@8@Q0035:DHaQBU00<@Q08DY@8@Q0<D
Y@8@Q08<H`8@Q0@DY@8@Q0045:D@Q12436<348@25:D00aS65:D<H`0936<248@010aS48@@Q0aS0Q24
00<DYA2424800PaS0Q240`aS0Q240PaS00D@Q0aS48@@Q1BU008@Q08<H`8@Q0075:D@Q0aS36<@Q0aS
48@010aS00<@Q1BU48@00PaS00@8@PaS36<@Q0L<H`03248<H`aS00<@Q048@P000`@Q00D000@Q1240
00Q200848@09000<HcF]MkeJeSF]@Q16<Cg_00924005AS4mkcg_?Nm6<@02BU84AS4014YBAS5:DTHa
0dYB00A243g_>LhicP96<@05@Q0mkcg_?Nm24002?Nl2>Lh2=Jd013W>=JdicSW>1cg_0d8@00LmkcW>
>Lhe[CW>=JdicP02?Nl2>Lh01SF]<H`e[CW>?Nm240DicP0:?NlicSW>=Jd]Jc6<=JdicSg_@Q08>Lh3
=Jd013W>=Jde[CF]0SW>00<e[C6<=Jd00c6<00<e[C6<<H`00SF]00DaS3F]=Jde[CW>00@aS003=Jda
S3F]008icP8mk`8e[@@aS005;F/YBRU::DX]J`02:DX01Re[<H`aS3F];F/YBP8]J`8aS004:DXU:BU:
:DX3<H`01BU:9BTU:BDY:DX00Re[0RU:0Re[00<YBRe[:DX012U:00<]JbU:9BT00Re[00TicSg_?Nlm
kcW><H`]JbU:9BT00RU:00<]JbU:9BT00bDY00DYBRDY9BTQ22DY00@Q208U:@06:DX]JbU::DXU:B48
22DY00HYBR488@PLibDY:DX29BT00b489BTU:@048@P01RDY8@PQ22DY8@PU:@8Q208Li`088@PU:BU:
9BT]JcW>=Jd]J`8Q200;9BTQ21cW7>LQ21cW5:DLibDY8@PHaP0248@00aS648@<H`06248G12401@Q2
12448@@Q24801P@Q00<000@Q12401@@Q00<8@P@Q12402`@Q0PQ210@Q0`Q20`@Q00<8@P@Q124010@Q
10Q200hLibU:?Nm242e[8@PLiaBU8@PU:B489BTYBRDY0acW00@Q21cW7>LHaP8Li`DHaPHDY@<HaP<D
Y@0348@DYA24008<H`035:D@Q1S600@HaP037>LHaQBU008DY@0748@HaQS67>LQ21S65:D00Q240QS6
0aBU00<HaQBU6<H011BU00P@Q1BU48@DYA2436<@Q0aS0Q240aBU00D@Q1BU5:DDYAS600@DY@8HaP06
5:D@Q1BU5:DHaQ240QBU00@@Q1BU48@@Q0<HaP075:D@Q1BU6<HDYAS67>L00RDY00DQ21S66<HHaQcW
008HaP035:D@Q1BU00DDY@046<H@Q1BU48@25:D348@236<01A2436<DYA245:D00aS611BU0a240QBU
00<HaQBU6<H00aBU00<HaQBU5:D0112400DDYA2448@<Ha24008<H`0648@<H`aS36<@Q0aS0a240`aS
00@@Q1BU5:DDY@8@Q0@<H`05248<H`aS48@8@P0236<25:D01A2436<@Q1245:D01A2400P<Ha2436<<
Ha2436<@Q0aS0a240`aS00<@Q0aS24800PaS00<@Q0aS36<00PaS00H@Q0aS36<8@PaS48@236<12480
00848@0300048@@Q00<48@0824848@@Q248aS7_NF]He[@=24007?Nm2448@?Nm243g_@Q000THa0TYB
00M6<DYBAS5:DTHaBU96<@02BU8014Ha?NlicSg_0T8@00<mkd8@?Nl01Sg_0SF]00@aS3F]>Lhmk`8i
cP8mk`04@Q0mkcg_?Nl2@Q001Cg_>LhmkcW>=Jd00SW>0cg_0SW>00HaS3F]=JdicSg_@Q02>Lh02CF]
>Lhmkcg_>Lhe[CW><H`e[@02>Lh2?Nl00cW>=JdicP04>Lh2=Jd013W>=Jde[CW>0SF]00@aS3F]=Jda
S0<e[@03<H`e[C6<008aS08e[@05>Lhe[C6<<H`]J`04<H`2=Jd2>Lh4=Jd00c6<;F/]J`03;F/0336<
;F/U:BDY:DX]JcF]<H`]JbU:9BT]J`8aS004;F/U:BDY:DX3;F/4:DX4;F/3:DX00be[:DXYBP02:DX0
1BDY:DX]Jbe[:DX00Re[0SF]00LicT8@@Q0icRe[9BTYBP02;F/2:DX01BDY:DXU:B489BT00R4800<U
:B488@P00R4800HU:B489BTU:B489BT2:DX29BT00b489BTU:@049BT38@P012DY8@PQ22480bDY1B48
00<U:B489BT0224800LU:BU:9BTYBS6<=JdaS0039BT00b487>LLi`027>L02AS67>LLiaS67>LHaQcW
5:D@Q00236<010Q21248@P@Q0`Q220@Q00<8@P@Q12401`@Q00<8@P@Q12401P@Q00<8@P@Q12405`@Q
00<8@P@Q12401@@Q00@8@P@Q12448@<8@P<48@88@P848@0924848A248@Pe[D8@<H`YBR48008HaP8Q
2004:DXU:B488@P27>L00b487>LLi`027>L00aS67>LDY@025:D011S67>LHaQ240QS600@DYA245:DH
aP8DY@0348@DYABU00@@Q08DY@8@Q0065:DHaQS66<HDYAS60QBU00<HaQcW7>L00QS600@DYAS65:DH
aP@DY@8@Q0@DY@<@Q0035:DHaQ24008<H`8DY@0448@<Ha245:D248@00aBU6<HHaP025:D26<H75:D0
1aS65:DDYABU48@DYA2400DDY@036<HDYAS6008HaP037>LQ21cW008Li`046<HDYAcW7>L26<H248@0
0aBU48@@Q0035:D248@25:D448@00`aS48@DY@025:D248@00aBU6<HHaP025:D00a245:D@Q00248@0
11BU6<HHaQBU0aS600<DYA245:D02a2410aS1A2400@<Ha2436<<H`8@Q0055:D@Q0aS248<H`0248@3
36<248@536<00a245:D@Q00236<348@236<248@010aS48@@Q1240PaS00<@Q1BU48@00a240PaS00<8
@PaS48@00`aS0Q240PaS00<8@PaS36<00`aS00001@0012448@@Q00000`@Q00T8@P@Q1248@SW>OomS
636<?Nl00T8@00=6<D8@?Nl00d8@00<mkdHaAS400TYB00M244HaBU96<DYBAS5:DP02CW<2AS44@Q03
AS42@Q0013g_>LhicSg_0SF]0SW>00@mkcW>>Lhmk`8icP8e[@HicP04?NlicSW>>Lh3?Nl2>Lh00cg_
>Lhe[@06>Lh01Cg_@Q0mkcg_=Jd013W>0Sg_00=243g_>Lh00SW>0Sg_0cW>00<mkcF]=Jd00SF]00<i
cSF]=Jd00cF]00<aS3F]>Lh00S6<00@]Jc6<<H`aS0@e[@05<H`icSW>>Lhe[@04<H`01cW>=Jde[C6<
=JdaS2e[00XYBP03;F/aS2e[008]J`07:DXaS3W>=JdaS2U:9BT00Re[0bU:00<]Jc6<:DX00bDY00@Y
BRDY9BTU:@8YBP<U:@8YBP8U:@068@PU:BU:9BT]Jcg_0T8@00`icRe[<H`aS2e[<H`e[C6<;F/YBRDY
:DX29BT00b489BTQ20038@P01BU:9BTYBRe[:DX00R4800<LibDY9BT01RDY0bU:00@U:B489BTQ20<U
:@048@PU:B487>L28@P012DY7>LQ22480RDY00@Q21cW8@PHaP<Li`04;F/aS36<;F/28@P012DY8@PQ
21cW0R4800<U:B489BT00RDY00DYBRe[:DXU:AcW008DY@0336<8@PaS00<<H`@8@P0536<8@PQ21248
@P0212400`Q21248@P071242248512401@Q212448@@Q24800`@Q00<8@P@Q12403@@Q00<8@P@Q1240
0`@Q0PQ230@Q0PQ200P48A249BUF]F<HBU96<C6<11cW00@U:B488@PU:@8Li`068@PU:BDY9BTLiaBU
0QS60QcW0QS600@DYAS65:DHaP@DY@0448@DYABU6<H25:D00a245:DHaP066<H25:D26<H00acW5:DD
Y@026<H00aBU7>LLi`027>L01AS65:DDYA245:D00QS60QcW11BU00<HaQBU5:D00a2400<DYAS65:D0
0Q2400<<Ha2448@00QBU11S600<DYAS65:D00QBU0aS60Q240QBU00HHaQBU5:D@Q1BU48@35:D248@0
1ABU48@DYAS67>L00R4800<HaQBU5:D00QS600<LiaS648@00QBU0QS600LDYA2448@@Q1BU6<H@Q002
5:D248@01@aS48@@Q1245:D00Q241ABU0aS60Q240aBU00LHaQBU5:DDYA245:DHaP025:D00a2436<<
H`0236<00a2436<DY@025:D248@00`aS48@@Q00248@00aBU48@<H`0236<00a245:DDY@026<H01124
5:D<H`aS0aBU00@@Q0aS36<<H`T@Q0035:DHaQ24008@Q0045:D@Q0aS36<748@236<00a2436<<H`05
36<0112436<<H`Q20`aS00<@Q0aS36<00@aS00001P@Q00048@00124000848@0:24848@0036<mkgoo
G_Le[D8@AS43@Q0014Ha?Nm243g_0T8@00=6<DYB@Q000dHa00E:DTHaAS5:DTic00=:DP03@Q16<D8@
00924004AS5244YB@Q02?Nl013W>?NlicSW>13F]1SW>00<e[CW>?Nl023W>0cg_00I243g_>LhicS6<
=Jd2?Nl01SW>=Jde[Cg_@Q0mk`8icPLmk`HicP<mk`<e[@8icP8e[@03>Lhe[CF]00@e[@<aS003;F/a
S36<008e[@04<H`e[CF]>Lh2=Jd2<H`012e[<H`e[CW>0SF]00d]Jc6<;F/]JbU:9BTYBRDY:DXU:BU:
9BTYBP02;F/01C6<;F/]JbU:<H`00SF]00<aS2U::DX012U:00D]JbU::DXU:BU:00<U:@048@PU:BDY
:DX2;F/2:DX59BT03B489BTU:Be[<H`mkd8@?Nle[C6<:DX]Jc6<008e[@03<H`YBRU:00@U:@8Q2005
9BTQ22DY9BTQ2003:DX012DY8@PLib480bU:00<U:B489BT012U:0bDY0R4800HU:B489BTU:B489BT3
7>L00b489BTQ20038@P00bDY8@PQ20037>L012U:;F/aS2e[224800<Lib488@P00RU:0bDY00@YBRDY
7>LDY@<@Q00336<8@PQ200D8@P@48@88@P@48@88@Pl48@040008@PQ2248212400`Q212448@041242
248412400`Q212448@0;12400`Q212448@0212400`Q21248@P02124248@033g_CW=BU5Je=JdU:AcW
6<HQ22DY7>LQ208U:@8Li`048@PU:B487>L26<H00aBU6<HLi`036<H00aBU6<HHaP026<H25:D348@2
5:D00a245:DDY@045:D00aS65:DHaP025:D66<H011BU6<HHaQS60QcW00<HaQBU48@00Q2400HHaQBU
6<HHaQBU48@25:D00aS65:D@Q0045:D248@25:D448@00aS65:DDY@046<H00aBU6<HHaP065:D01124
5:DHaQBU0QS600<DYA2448@00QBU0a2400LHaQBU6<HQ22DY8@PHaP025:D36<H00acW5:DDY@025:D2
6<H00aBU48@DY@055:D648@00`aS48@@Q0026<H248@00aBU6<HHaP0248@00aBU48@@Q0036<H248@2
5:D348@00`aS48@<H`0236<25:D248@236<348@236<00a245:D@Q00236<00a245:DDY@035:D248@2
36<448@00`aS48@<H`0348@236<248@00aBU6<HDY@0236<00a245:D@Q00236<448@00`aS48@@Q002
48@236<00a2436<@Q00336<00`Q236<<H`0336<348@136<1248000P48@0:248000@Q248e[GNmE[Di
cTYBCW<3BU8014HaBU96<Cg_0T8@0dHa0T8@0THa00I:DTHaAS56<DYB@Q03AS401DYBAS52448@AS40
0d8@00@mkdHa@Q1240<icP04?Nm243W>>Lh2=Jd2>Lh01Cg_>Lhe[C6<=Jd00cW>0SF]00<aS3W>?Nl0
0THa00=243g_>Lh00SF]0SW>00<mkcW>>Lh00cW>0cg_00<icSF]?Nl00T8@00HicSg_?Nlmkd8@>Lh4
?Nl3>Lh2?Nl00cW><H`e[@02=Jd02CW>=Jde[CF]>Lhe[C6<=JdicP02=Jd2<H`2=Jd2>Lh2=Jd2<H`0
1Be[<H`aS36<;F/00RDY0RU:0S6<0Re[0bU:0RDY00LYBRe[<H`]Jc6<;F/aS003;F/01S6<;F/]Jbe[
:DX]J`8aS003;F/YBRDY008U:@03:DXU:BDY008YBP059BTQ22489BTYBP029BT022489BTYBRU:9BTY
BRDY:DX2<H`03SF]<H`aS36<@Q16<DYBCW<icRe[9BTQ22DY:DX39BT00b487>LQ2003:DX28@P29BT3
8@P39BT01B489BTQ22U:;F/00RU:0R4800<U:B489BT01b480QcW0R480acW0RDY00<Q21cW6<H00QcW
0RDY00@Q21S67>LLi`8Q20<Li`8Q2009=JdmkcW><H`U:Be[=Jd]Jb4800<DY@8HaP035:D<H`aS008<
H`0448@DYA2448@536<00`Q212448@02248312400`Q212448@0212400`Q212448@0312400`Q21244
8@0512400`Q212448@0812400`Q212448@0212400`Q212448@04124324800`@Q2488@P04248236<0
0aBU6<HLi`028@P69BT02R486<HLiacW8@PLib489BTYBRDY0QS600DLiaS66<HDYAcW00<HaP8Li`8D
Y@<HaP@DY@0348@DYA2400@HaP@Li`076<HLiacW6<HDYA246<H011cW1QS60QBU00DHaQBU48@@Q1BU
008HaP<DY@8@Q0@DY@0348@HaQBU008DY@0448@DYABU6<H35:D02Q247>LLib486<HDYA245:D@Q1BU
0QS60QcW00<DYA245:D00QBU00<@Q1BU5:D011BU0QS600<LiaS65:D00QBU0QS600@DYA245:D@Q08H
aP<DY@8@Q0035:DHaQS600<DY@0448@<H`aS36<348@01QBU48@@Q12436<@Q0<DY@8@Q0035:DHaQBU
00D@Q08HaP8DY@<@Q00536<@Q1BU6<HLi`035:D348@011BU48@@Q0aS1A2400<<Ha245:D00QS600DD
YA2448@@Q1BU00@@Q0035:D<Ha2400H@Q00336<@Q1BU008@Q00536<@Q12448@<H`0248@01PaS48@@
Q0aS48@<H`8@Q0<<H`88@P0636<@Q12448@<H`Q20PaS0Q240@aS0@Q200021240100012448@001@@Q
00H8@S6<LiaJeSW>AS45BU83AS46@Q02AS400dYBAS5:DP04AS400d8@AS56<@02AS45@Q0013g_@Q12
44Ha0Sg_00<icSg_?Nl00SW>00DmkcF]=Jde[CW>008mk`03>Lhe[CF]00@e[@0:>Lhe[CW>>Lhmkd8@
AS4mkcW>=Jd4>Lh00cg_>Lhe[@03>Lh2?Nl3>Lh00cg_@Q124002>Lh2?Nl00d8@?NlicP03?Nl00cW>
?Nlmk`03>Lh00c6<=JdicP02>Lh01C6<=Jde[CF]>Lh00SF]00<aS3F]=Jd00cF]0SW>00De[C6<<H`a
S3F]00<aS003;F/YBRU:00<YBP03<H`]JbU:00@YBP049BT]Jbe[<H`2:DX2<H`2;F/0136<;F/aS36<
0bU:00<]Jc6<=Jd00RU:0R4800<U:BU::DX00RU:00HU:B489BTYBRe[:DX39BT28@P00bU:;F/YBP02
;F/03c6<=Jde[C6<;F/e[Cg_CW=F]Cg_=JdYBRDY;F/YBP049BT38@P2:DX29BT28@P00bDY8@PQ2002
8@P49BT01BU:;F/YBRU:7>L01B4800DU:B489BTLib4800<Li`048@PLiaS67>L28@P00bDY8@PQ2003
7>L58@P011cW8@PLib480QcW0R4800<]Jc6<=Jd00be[0S6<00<YBR487>L00QBU0a240`aS00@@Q0aS
36<<H`<@Q08<H`0324848@Q20088@P848@88@P041248@P@Q248412400`Q212448@03124224841240
0`Q212448@0C12400`Q21248@P06124010Q248@HaQBU0QcW1BDY00@Q22DY8@PQ20<Li`056<HLib48
9BTQ20027>L26<H01aBU6<HHaQS65:DHaQcW008HaP0448@DYAcW6<H25:D26<H55:D00aS67>LHaP02
7>L02AS67>LHaQcW6<HDYAS65:DHaP037>L56<H01ABU6<HDYAS65:D00a2400<DYAS65:D00aBU00<H
aQBU48@00QBU00<HaQ2448@00QS600@DYA2448@@Q0@DY@046<HLiacW7>L35:D010aS48@HaR480QS6
00L@Q1S65:DDYA245:D@Q0025:D348@01aS67>LQ21cW5:D@Q1BU008HaP035:DHaQ24008DY@<HaP03
5:D@Q124008DY@8Li`065:D@Q0aS36<@Q0aS0a240aBU00/<Ha245:DHaQBU48@DYA2436<@Q1BU008H
aP8@Q0DDY@0648@DYA2436<@Q1BU0aS60a2400@<Ha2436<@Q08DY@D@Q08DY@0748@DYAcW6<H@Q0aS
48@00QBU0Q2400<DYA245:D00PaS112400D<HaBU48@@Q0aS00@@Q00336<@Q12400<@Q08<H`03248<
Ha2400<@Q0@<H`03248<H`aS00L<H`48@P0000D000@Q12448@0000<48@0924848@@Q36<icW_NF]Hi
cTHa00=>L`04BU9>LdYBCW<2BU83AS400dYB@Q124002?Nl2@Q001dHa@Q16<Cg_@Q0icSg_008icP04
?Nm2448@@Q02AS43@Q000cg_@Q0mk`02?Nl01D8@>LhicSF]<H`00SW>13g_0cW>0SF]0S6<00@e[CW>
>LhicP8e[@03>Lhmkcg_00<icP<mk`8icP=2408icP07=Jdmkcg_?Nm244Ha@Q000Sg_00<icSg_?Nl0
0d8@0SF]00PicT8@?NlicS6<=JdicSg_0cF]00DaS3F]<H`e[CW>008e[@06<H`e[CF]=JdicSF]0S6<
2Be[00<YBRe[<H`00SF]00@YBRDY9BTYBP8]J`05<H`]Jbe[:DXU:@02:DX01Be[:DX]Jbe[<H`00be[
00TYBRe[;F/]JbU:9BTQ22U:9BT01bU:0RDY00<Q22DY9BT00bDY0RU:00H]Jc6<<H`aS2e[:DX2;F/0
2RU:=Je2448@<H`U:AcW9BTYBRDY0RU:00<U:B489BT00RU:12DY0b4800@U:BU::DXU:@<Q208U:@<Q
20036<HQ2248008U:@8Q20037>LQ21cW008U:@038@PLiacW008HaP047>LQ22U::DX29BT37>L38@P0
0aS67>LLi`047>L28@P03BDY;F/aS3F];F/U:BU:=JdmkcF]8@PDYAS600<Li`<HaP<DY@8HaP035:D@
Q0aS00<@Q00436<@Q0aS36<32483124224841242248912400`Q212448@0212400`Q212448@031242
248512400`Q212448@02124010Q21248@PaS0PQ200H@Q1cW8@PHaQ246<H67>L28@P00acW8@PQ2002
8@P011cW8@PLiacW0aBU0aS600<DYAS67>L00QS600HDYAS66<HDYAS65:D36<H00aBU48@DY@025:D0
0aS65:DHaP026<H011cW6<HHaQcW0QS60QBU00<HaQBU5:D00QS60QcW0QS600@LiaS66<HHaP<DY@03
48@DYABU00DDY@037>LQ21cW008HaP035:DHaQ24008DY@0348@DYABU008DY@<HaP8@Q0095:DHaQcW
6<H@Q1BU36<@Q1S6008DY@046<HDYAS65:D26<H01QBU48@DYABU6<HDY@8@Q0<HaP037>LHaQS6008H
aP8DY@0448@DYA246<H65:D348@55:D00a245:D@Q00248@45:D236<01A246<HHaQBU48@00PaS00@@
Q1S66<HDY@D@Q0<DY@0448@DYABU48@46<H00aBU48@@Q00548@00aBU48@<H`0348@00aBU48@@Q002
5:D00a2436<@Q00248@01aBU48@DYABU48@DYA2400@<H`065:D@Q1BU5:D@Q0aS0a2400LDY@aS36<<
Ha245:D@Q00336<448@736<00a2436<<H`0248@236<124800004124000@Q0002124030002488@P00
1248@SF]MkeJeSW>AS5:DP=>L`E:DPI6<@03@Q0mkcg_00924003AS52448@008mk`03@Q0mkd8@008i
cP03?Nm244YB0096<@04@Q16<Cg_>Lh2?Nl00d8@>LhicP02?Nl01cW>=JdicSW>@Q0mkcW>008e[@03
>Lhe[CF]008aS005>Lhmkcg_?NlicP02<H`00cF]?Nlmk`02>Lh013g_>LhicT8@0Sg_0T8@00<mkcW>
?Nl00Sg_00DicSg_AS56<D8@008e[@03>Lhmkd8@0092408icP8mk`06@Q0icSF]=JdicSF]0SW>00<e
[C6<<H`00c6<00<icSF]>Lh00S6<00Hmkd8@?Nle[BU:9BT3;F/4<H`2:DX00be[<H`aS002;F/022U:
;F/YBRDY:DX]JbU:;F/3:DX012e[:DXYBRDY0Re[00<aS2e[<H`00S6<00D]JbU::DXU:BU:00@U:@DY
BP@U:@@Q208U:@03:DXaS36<00@aS08YBP05=Jdmkcg_?NlYBP039BT2:DX49BT01B489BTYBRe[9BT0
1B4812DY124800<U:B486<H00QcW00<Q21cW8@P00RDY0b4800HU:B487>LQ21cW6<H27>L00b489BTY
BP029BT37>L011S68@PLib4811cW00@HaQcW8@PQ20<YBP8aS006;F/YBSF]>Lhe[BU:0aS60acW11BU
00@HaQBU6<HHaP8DY@8@Q00336<@Q0aS00<<H`0424848@Q2248612422489124010Q212448@@Q0PQ2
10@Q00<000@Q124010Q210@Q0`Q20P@Q10Q200<@Q1S67>L00QBU11S600@Lib488@PQ20<Li`8Q20@L
i`038@PLiaS6008DY@8HaP035:DHaQS600<Li`8HaP045:DHaQS67>L26<H00aBU6<HDY@025:D00a24
6<HHaP036<H27>L00aS67>LHaP025:D031S65:DDYABU7>LQ21cW6<HLib487>LDY@<HaP8@Q0<DY@04
48@DYABU5:D36<H00acW6<HHaP025:D248@55:D00aS65:DHaP036<H25:D26<H011245:DDYABU0a24
00<HaQcW6<H00QBU00D@Q1BU5:DDYA24008DY@0348@DYAS600<HaP055:DHaQS67>LDY@0248@00aBU
6<HDY@025:D26<H011BU48@DYABU1A2400DDYA245:DDYAS6008DY@<@Q00436<DYABU5:D448@01ABU
48@DYAS65:D00a2411BU00<HaQ2448@00QBU00HHaQBU6<HHaQ245:D248@35:D348@00`aS48@<H`02
48@25:D348@010aS48@@Q1240QBU0Q240PaS00<@Q0aS36<00Q240aBU00<@Q1BU48@00Q2400@<Ha24
48@<H`@@Q08<H`0348@<H`aS00H<H`0448@<H`aS48@636<000P48@0:24848@0036<icWooF]He[DHa
CW<2BU800dHaBU9:DP03BU82AS400d8@AS56<@02AS44@Q000dHa?Nlmk`05>Lh2?Nl3@Q000dHa@Q12
4002?Nl00cW>?Nm24002@Q04>Lh00cg_>Lhmk`02=Jd00c6<=JdicP02>Lh2<H`2>Lh3<H`6=Jd00cW>
=Jde[@04>Lh01Cg_@Q16<DYB@Q0013W>00@mkd8@BU9:DP96<@08@Q0mkcg_>LhmkcF]>Lhe[@<icP8e
[@03<H`e[CF]00De[@05<H`e[CF]=JdaS002=Jd2>Lh2=Jd7<H`3;F/01BU:;F/aS36<;F/00RU:00H]
JbU::DX]JbU:<H`6;F/022U:;F/]JcF]<H`]JbU:;F/2<H`2;F/012DY8@PQ22480RU:00@U:BU::DXY
BP8U:@03:DXU:BDY00<Q208U:@088@PU:BU:<H`mkcW>=Jd]J`8YBP03;F/aS2U:008U:@057>LQ22DY
9BTYBP039BT28@P29BT2:DX00bDY8@PQ20039BT01QcW9BT]JbU:8@PHaP8Li`@Q20037>LQ21cW00@Q
208U:@8Q20057>LQ22DY8@PU:@038@P29BT00b487>LLi`038@P00acW8@PLi`037>L011S67>LQ2248
0RDY00XQ22DY:DX]Jc6<;F/e[C6<;F/U:@<Li`<HaP038@PLib48008Q20059BTQ22DY:DXLi`026<H0
1QcW8@PLiaS65:D@Q08<H`8@Q00536<48@Q236<8@P0412400`Q21248@P091242248912400`Q21244
8@021243248236<02QBU:DX]JdicBU8e[BU:48@DYAcW0QS60QBU00HHaQcW6<HHaQBU7>L46<H011cW
6<HHaQBU0aS600<LiaS67>L011S60QcW0QS60QcW0QS60Q2400DDYAS66<HHaQBU008Li`066<HDYAS6
7>LHaQBU0QS600@LiaS66<HDY@<Li`068@PHaQcW6<HDYAS60aBU00<HaQBU5:D00QBU0QS60acW0R48
0QcW00<HaQBU5:D00QBU1QS60QBU0Q2400DHaQcW6<H@Q1BU00<HaP8DY@046<HDYABU5:D26<H45:D0
1a245:DDYAcW5:D@Q1BU008Li`8HaP8DY@8HaP8DY@<HaP@@Q08DY@<@Q08DY@8HaP8DY@0448@<Ha24
48@25:D00a2436<@Q00248@011BU6<HDYABU0Q2400DHaQBU36<@Q0aS00P@Q0085:D@Q1245:DHaQcW
6<HDY@8@Q0045:D@Q0aS36<248@25:D436<248@00aBU48@<H`0236<248@236<00a245:DDY@0236<2
48@236<248@011BU6<HDYABU0a2400<<Ha2448@00a240PaS0a2400<<H`Q248@00`aS00<@Q0aS36<0
0`aS00@@Q0aS36<<H`48@P000P@Q00@000@Q124000D48@06248e[G_NG_Le[DHa0TYB0dHa14YB00=6
<D8@@Q000dHa00=244Ha@Q000d8@00A6<Cg_>Lhe[@<icP8mk`04@Q0mkd8@@Q02AS40148@>Lhmkcg_
0T8@00<mkcW>?Nl00cW>00DmkcW>=Jde[C6<00@e[@<icP04<H`e[C6<<H`2=Jd3<H`013W>=JdicSF]
13W>00<mkd8@AS400THa00HmkcW>>LhicT8@?Nl2AS4014YBAS52448@0cg_00@icSF]=JdicP<e[@8i
cP03=JdaS36<008e[@03>Lhe[C6<008aS006=JdaS36<=JdicSg_0cF]0S6<00@]JcF]<H`]J`8aS0P]
J`04<H`YBRDY:DX2;F/2:DX012e[<H`aS2e[0RU:00<]Jc6<<H`012e[00HYBRe[;F/YBRDY8@P29BT0
1b489BTU:BU:;F/YBRDY008Q20039BTYBR48008Q208U:@0;:DXU:BU:?Nm:DT8@=JdQ22U:=Jd]J`02
:DX01BDY8@PQ22489BT00RU:0bDY0R4800<U:BU:9BT00b4800DLib489BTU:BU:008U:@06:DXQ2248
8@PLib4811cW1B4800<U:B489BT00b4800@Lib487>LLi`<U:@038@PLiacW00<Li`076<HQ22489BTQ
21cW6<H00acW0R480RDY00/YBRDY;F/YBRe[=JdicS6<;F/LiaS6008DY@HQ20049BTQ21cW8@P29BT0
22486<HHaQcW8@PLiaS65:D336<00a2436<<H`0236<030Q212448@@Q24848@Q21248@P@Q00048@88
@P848@0324848@@Q00848@88@PD48@0600048@@Q1248@P@Q0PQ200/<H`Q236<HaRDYAS5:DSg_<H`D
YAS6008DY@<HaP8Li`<HaP8Li`8DY@8Li`@HaP8DY@8HaP8Li`@HaP@Li`046<HLiacW6<H35:D011S6
48@HaQS60QcW0QBU0QS60QBU00DHaQBU6<HHaQcW00@HaP8Li`046<HDYABU5:D26<H25:D00aS65:DD
Y@0248@27>L012487>LHaQS60acW00@DYA2448@DY@<HaP8DY@036<HDYABU00<DY@8Li`036<HDYABU
008DY@8@Q0045:DHaQS66<H45:D348@00aBU6<HHaP026<H01QBU6<HHaQBU48@DY@8HaP<DY@036<HD
YAS6008DY@0348@DYABU00HDY@036<HLiaBU00<@Q08DY@0448@<Ha2448@95:D248@010aS5:D@Q0aS
0Q240QBU0Q2400@DYA245:DDY@<HaP<DY@/@Q0<<H`8@Q0065:D@Q0aS36<@Q0aS0Q2400@DYA2448@<
H`8@Q00336<@Q124008DY@0448@HaQS648@236<00a245:D@Q00436<01Q2436<<Ha2436<@Q08<H`04
248<H`aS48@336<348@136<124812480000500048@@Q1240000312402@Q212448@Q2<HacW5[F=Jdm
k`02AS400dYBAS56<@02AS401TYBAS5243g_>Lhmk`A24003AS5:DTHa0096<@924004?NlicSg_?Nl2
>Lh2=Jd2?Nl2AS400d8@?Nlmk`03>Lh00cF]?Nlmk`02?Nl3>Lh00cF]>Lhe[@03=Jd3?Nl013W><H`a
S3F]0S6<00@]JcF]>Lhe[@@icP@e[@05>Lhe[CF]?Nm24003?Nl01T8@AS5:DSg_@Q0icPA24004?Nli
cSW>>Lh4?Nl00c6<=JdaS003<H`01CF]<H`aS36<=Jd0136<00DicSF]=Jde[CW>00@aS004=JdaS3F]
=Jd2<H`00be[:DX]J`04;F/00bDY:DXYBP02;F/2<H`00be[<H`aS002;F/2:DX00be[<H`aS002=Jd0
1S6<;F/YBRU:9BTYBP<U:@038@PU:BDY00@YBP03;F/U:BDY008Q208U:@@Q20<YBP05@Q1:DT8@=JdQ
2003:DX49BT2:DX39BT01AcW8@PQ21cW9BT00bU:00<Q21cW9BT01BDY0RU:00@U:AcW7>LQ20<Li`03
8@PLiacW00<Q20047>LQ22489BT28@P00acW9BTU:@039BT28@P47>L012487>LQ21cW0aS60QcW0R48
11cW00@Q22DY9BTQ208Li`079BTYBRe[=JdaS2DY8@P00QcW00<Q21cW8@P00R4800hLib48:DX]JdHa
BU96<D8@9BTQ21cW8@PU:AcW0QS60QcW00DDYA2448@<Ha2400@<H`88@P031248@PQ20088@P<48@88
@P@48@0424848@@Q24841242248412403@aS6<HaS4icDYAS65[FCW=6<BU:9BTHaQBU00<HaP035:DH
aQS6008HaP035:DHaQBU00<DY@046<HLiaS65:D36<H25:D26<H00aBU6<HHaP028@P27>L00aS65:DH
aP035:D00aS67>LHaP035:D021S67>LLib487>LHaQBU6<H25:D:6<H00acW6<HHaP0348@00aBU6<HL
i`035:D26<H27>L28@P26<H00aBU6<HHaP026<H011BU7>LLiaS60aBU00<HaQBU48@00QBU00HHaQcW
5:DDYA245:D26<H00aBU48@HaP036<H45:D00a245:D@Q0025:D011S65:DHaQS60QcW11S600`DYA24
5:DDYAS65:DHaQBU6<HDYAS65:D348@00aBU6<H@Q00248@00aBU48@@Q00248@35:D248@25:D26<H0
0aBU6<HHaP026<H011BU48@<H`aS0Q2400<<Ha245:D00QS60Q2400<DYA2448@00aBU00@@Q0aS5:D@
Q0<<H`0348@DYABU008@Q0@<H`<@Q0<<H`0648@<Ha2448@<Ha240PaS0a240PaS00<@Q1BU5:D00QBU
0a240QBU0PaS0a2400<<Ha2448@00PaS0PQ21PaS112410aS000010@Q00048@0010@Q00T8@P001248
@SF]LiaJeSF]@Q0014Ha00=:DTHaAS400THa00I243g_?Nlmkd8@?Nl3@Q0014HaBU96<DHa1Cg_13W>
00@e[CW>?Nm24096<@8mk`8icP07?NlicSW>>LhmkcW>?Nl00cW>0SF]00DicSF]=JdicSg_008icP06
=JdaS2e[:DX]Jc6<0SF]00<icSF]<H`00cW>00He[C6<>LhicSF]>Lh2?Nl01D8@>LhicSg_AS40148@
0cg_00=6<Cg_?Nl00SW>00<mkcW>?Nl00cW>00@e[C6<<H`]J`8aS003=JdicSF]008e[@<aS0<e[@04
<H`e[CF]<H`5=Jd00be[<H`aS004<H`2;F/4:DX00be[<H`]J`02;F/3<H`3;F/02BU:<H`aS36<=Jda
S2U:;F/YBP079BT01248:DXYBRe[0bU:00HU:B488@PQ22DY8@P49BT03248?Nm>LdYB=JdQ22U:;F/Y
BR489BTYBPDU:@048@PU:BDY9BT38@P2:DX012DY8@PQ22480RDY00DQ22DY:DXYBRDY00@Q20<Li`03
8@PU:B48008Q20037>LQ21cW00DQ20<U:@8Q20069BTQ22DY8@PLiaS60acW00@Q21cW7>LHaP8Li`8Q
20<Li`038@PU:B4800<Q20039BTYBRU:008aS004:DX]JacW7>L26<H28@P39BT022489BTicSg_BU96
<Be[:DX27>L28@P00acW6<HHaP045:D248@436<2248010aS2488@P@Q0PQ21`@Q00L8@P@Q12448@Q2
1248@P0312400`Q212448@0212401`aS248Q23g_DYAW>EJe009>L`06<H`]JaBU6<HDYA240QS600@L
iaS65:DDY@DHaP065:D@Q1BU5:DHaQBU0QS600LLiaS65:DDYAS67>LHaP028@P27>L26<H25:D01AS6
48@DYA245:D01AS60QcW2AS600@LiaS66<HDY@HHaP045:DHaQBU5:D46<H011BU48@HaQS60acW00<Q
21cW6<H00aBU0QS600DDYAcW6<HHaQBU008HaP<@Q0035:DLiaS600@HaP@DY@0448@HaQS66<H55:D3
48@01QBU6<HHaQS67>LHaP8DY@066<HLiacW6<HDYA240QBU00<HaQBU6<H00QBU0QS600@DYA2448@D
Y@8HaP065:D@Q12448@HaQBU1A2400DDYA245:D@Q1BU00@HaP035:D@Q124008@Q004248<Ha245:D3
48@01AS65:D@Q1BU48@011BU0Q2400<<Ha2436<00PaS0aBU0PaS0Q240PaS00@@Q0aS36<<H`8@Q0<<
H`0348@DYA2400@@Q08<H`8@Q0065:D@Q1245:D@Q1BU112400<DYA2448@00`aS00<8@PaS36<00`aS
112400<<Ha2448@00a240@aS0@Q2000412401@0012448@@Q24800P@Q00T8@SW>NmiJeS6<@Q16<D8@
?Nl01D8@0THa00A243g_@Q1240<mk`=24096<@=24003BU96<DHa008mk`924004AS5243g_?Nl2@Q04
>Lh00cg_>Lhe[@02=Jd2>Lh4=Jd3>Lh3?Nl4>Lh3<H`00cF]>LhicP04>Lh013g_>Lhmkcg_0T8@00Lm
kcF]>Lhe[Cg_@Q16<@02?Nl2>Lh014Ha@Q12448@0Sg_23W>0cg_0cW>00<e[C6<<H`00SF]00LaS3F]
>Lhe[C6<;F/aS003=Jd00c6<;F/aS002>Lh5=Jd3<H`6;F/5:DX3;F/2:DX012e[<H`aS3F]0c6<00<]
JbDY9BT00bU:0RDY0R4800LU:BU:9BTYBRe[:DXU:@028@P01bDY8@PQ22489BTYBRe[008U:@06>Li:
DTic@Q0U:Be[0bU:00<Q22DY9BT00bU:0RDY0acW00DU:BU::DXQ21cW00<Q20<YBP049BTQ22488@P2
9BT01B487>LLib486<H00acW00<Q22DY8@P00QcW00<U:BU:9BT00QcW00<U:B489BT00R480acW0aS6
0acW0R480QcW0QS611cW0QS6124800<Lib489BT00R4800HU:Be[<H`YBR487>L28@P29BT02B487>LL
ib489BTmkdHa@Q0mk`029BT012487>LQ22DY0R4800<LiaS66<H01AS600<DYA2436<00PaS0a2400@D
YA24248<H`88@P041248@P@Q24831244248010@Q24848@Q20PaS0Q2400HLib48:DXaS3F]>Lh3<H`0
1BDY8@PHaQS67>L00QS600@Lib487>LLi`8DY@8HaP8DY@0348@DYAS6008HaP057>LHaQBU5:DHaP02
7>L46<H37>L00aS67>LLi`096<H00aBU6<HDY@027>L00b486<HHaP025:D00aS65:DHaP055:D01AS6
5:DHaQS67>L00QS60aBU00<HaQBU5:D01ABU11S611BU0QS600<DYAS66<H00aBU00DLiaBU48@@Q1BU
008Li`036<HLiaS6008HaPDDY@8HaP<DY@036<HDYABU00<DY@0;6<HDYAS66<HLiaBU48@DYAS67>LH
aP085:D00aS65:D@Q0025:D00acW6<HDY@025:D00a245:D<H`0348@25:D00a2436<<H`055:D27>L0
0aS65:DDY@0248@010aS5:D@Q0aS0Q241ABU00@@Q1BU48@DY@@@Q0035:D@Q12400<<H`8@Q0035:D@
Q12400@<H`0448@DYABU5:D236<00a2436<@Q00548@35:D348@35:D00a245:DHaP025:D00a246<HH
aP0548@636<348@336<011245:D@Q1240@aS000212400`0012448@051240200036<e[G_NE[DaS3g_
AS43@Q0013g_@Q12448@0THa0T8@00=6<D8@?Nl00SW>0Sg_0T8@00Y6<Cg_?Nm244HaBU96<Cg_>Lhm
k`E24003?NlicSW>00@mk`05=JdicSF]>Lhe[@04>Lh01cF]<H`mkcg_@Q0mkcW>008mk`04>Lhe[CF]
=Jd3<H`2=Jd2>Lh013g_>LhicSW>0T8@00<mkcW>>Lh00cW>0THa0T8@0SW>0Sg_0THa00=243g_?Nl0
0SF]1CW>0Sg_1SF]136<0SF]136<0SF]00@aS2e[<H`aS0<e[@8aS0<e[@04<H`]JcF]<H`2:DX022DY
:DXaS36<:DXU:BU:;F/2<H`012U:9BT]JbU:1S6<00@]JbU::DXYBP<U:@07:DXQ22489BTYBRe[:DX0
0RDY00@YBRDY8@PLi`8Q208U:@04:DXU:BDY>Lh2BU800cg_;F/aS002;F/39BT012489BTU:BU:0RDY
00<Q22DY8@P00b4800@U:B488@PQ20<U:@03:DXU:BDY00<U:@@Q20HLi`8Q20047>LQ22DY9BT28@P2
7>L01BDY:DXU:AcW6<H00QcW0aS61QcW00<HaQcW7>L00QcW00<HaQcW6<H01AcW124800<U:BU::DX0
0S6<00@U:B487>LLi`8U:@057>LHaQcW7>LQ2002=Jd2AS401S6<;F/LiacW9BTLi`<Q208Li`<HaP8D
Y@8HaP8@Q00336<@Q124008@Q00336<@Q1240088@P031248@PQ200<48@88@P031248@PQ200<8@P06
1248@P@Q36<HaR480QcW00<U:C6<?Nl00SF]00<aS2DY9BT00QcW00@HaQBU6<HLi`8U:@077>LHaQS6
6<HLiaS65:D00Q2400<DYAS66<H00aBU1QS600@DYAS66<HHaP8Li`8DY@036<HLiacW00@HaP<DY@8H
aP047>LU:B487>L25:D36<H25:D248@46<H00aBU6<HLi`026<H011245:DDYABU1AS611BU00@HaQBU
6<HHaP8DY@8HaP047>LDYABU5:D26<H02ABU6<HHaQS65:DHaQBU6<HLi`026<H00aBU6<HHaP025:D0
11245:DDYAS60QBU00<@Q1BU5:D00Q2400<<HaBU7>L00QcW00@HaQBU5:DHaP8Li`086<HDYABU5:D@
Q1BU48@DY@8@Q0035:DHaQBU008DY@0548@HaQS66<HDY@0548@336<01A245:D@Q1BU48@00QBU00@H
aQcW7>LHaP<@Q0045:D@Q0aS36<248@01QS65:D@Q1246<HDY@<@Q0<DY@0548@<H`aS48@<H`0648@3
36<348@010aS48@<HaBU0Q2400@<Ha2436<<H`@@Q08<H`8@Q0045:D@Q1BU48@35:D248@35:D248@0
1PaS48@<Ha2436<@Q0H<H`8@Q0<<H`8@Q048@P0000H000@Q124000@Q000212402@Q212448@aS>Lig
_E[F<Ha24002AS46@Q000cW>?Nm24002@Q000cg_@Q124002@Q02AS40148@?Nlmkcg_1d8@00I6<DYB
AS56<D8@AS42@Q001Sg_@Q0mkcW>=JdaS08e[@03>Lhe[CW>00DicP05?NlicSg_>Lhmk`02=Jd2<H`5
>Lh2?Nl2@Q002cg_>Li6<DYBAS5243F]<H`icSg_>Lh00Sg_00De[C6<<H`aS3F]00HicP04?Nm243g_
?Nl2>Lh2?Nl01cW>=JdaS36<>LhmkcF]00<aS003=JdaS36<008aS004=JdaS36<;F/3<H`2=Jd5<H`3
=Jd4<H`01Re[:DXYBRe[:DX]J`8YBP03;F/YBRU:00<YBP8aS0@]J`<YBP03;F/YBRU:00@U:@09:DXU
:B489BTYBRDY8@PHaQcW008U:@038@PU:BDY008U:@097>LQ23F]?Nm:DSg_<H`e[Be[00DYBP8U:@07
:DXU:B486<HLibDY8@P01BDY00<Lib487>L00bDY0R4800@Lib488@PU:@8Q20PLi`<Q20037>LQ21cW
008Li`058@PU:B487>LHaP027>L011S65:DHaQS61QcW00HHaQcW7>LHaQcW6<H27>L021S67>LLiaS6
8@PLib489BT2:DX29BT3:DX28@P00acW8@PU:@028@P27>L01248:DX]JbU:0b480bDY0b4800<LiaS6
6<H00QS60QcW0aS60QBU00@LiaS66<HQ208Li`045:D<H`aS48@336<00`Q236<<H`03248536<00aBU
6<HQ20037>L01B489BTQ22DY8@P00RDY00<Q21S67>L00acW0QS600DQ21cW7>LLiaS600<DY@<HaP8D
Y@0348@DYABU00<DY@8HaP047>LDYABU5:D26<H25:D011S67>LLiaBU11cW00@DYA245:DHaP<Li`<H
aP047>LHaQBU5:D46<H25:D26<H01ABU6<HHaQS65:D00a2400DHaQ245:DHaQcW00HHaP045:DHaQBU
6<H25:D01a245:DDYAS65:D@Q1BU00@HaP075:DHaQ245:DHaQcW6<H011BU0Q240QBU00HLiaS66<HH
aQ245:D248@00aBU6<HLi`035:D26<H45:D00aS65:DHaP055:D00a245:D@Q0025:D00a246<HLi`02
6<H348@010aS48@@Q1241@aS0Q240QS600DDYA246<HQ21cW00@@Q0<<H`0348@DYABU00DDY@<@Q003
5:D@Q12400<@Q0L<H`0448@<Ha2448@236<248@00aBU6<H@Q00648@25:D248@02PaS48@@Q0aS48@D
YA245:D@Q0aS0Q240aBU00<@Q1BU48@011240PaS00<@Q0aS48@00PaS0Q240`aS0Q240@aS0A240000
0`@Q00048@0312400`0024848@0212401`Q2>LikgU[F<Ha244Ha00E24003AS5243g_008mk`A24003
AS52448@00924004?Nm243g_?Nl3@Q03?Nl0148@AS56<D8@0THa00U:DT8@?Nlmkd8@?NlicSF]>Lh0
1SF]00HicSF]=JdicT8@?Nl2>Lh013g_@Q0mkcW>0S6<00@e[CW>>LhicP8mk`924004?Nm2448@BU82
AS402D8@>LhicSW>?Nm243g_=JdicP02<H`00cF]<H`icP02>Lh013g_>LhicSg_0T8@13W>0Sg_0cW>
00<e[CW><H`00c6<00<icSF]<H`00Re[0c6<0Re[0S6<00H]JcF]<H`icSF]<H`2;F/01S6<>LhaS36<
;F/aS08]J`03:DX]JbU:008YBP<]J`8YBP03;F/YBRe[008aS08]J`8aS003;F/YBRU:008YBP039BTQ
2248008U:@068@PU:BU:9BTQ21cW0R4800<Lib488@P012DY00LQ22e[;F/mkd8@>Lhe[@03;F/2:DX0
1BDY:DXYBRU:9BT0124800@Lib488@PU:@8YBP@Q20<U:@038@PLiacW00<Q20<Li`038@PLiacW008L
i`048@PLiacW8@P57>L00b489BTQ20047>L26<H00aBU6<HHaP047>L36<H77>L26<H37>L38@P012DY
:DXU:BDY12U:00@U:B488@PLi`8Q208Li`039BTYBRDY00<U:@8Q20<U:@8Li`038@PLiaS6008HaP8L
i`<DY@<HaP8Li`038@PHaQBU00D@Q08<H`<8@P<<H`0748@<H`Q2248@Q1BU8@P00acW00@U:B488@PQ
208U:@06:DXLiacW5:DLib480QcW00<Q21cW7>L00QcW1AS600DDYA2448@DYAS600@DY@8@Q0036<HD
YAS600<HaP<DY@@HaP035:DHaQcW00HHaP047>LHaQS65:D56<H00aBU6<HLi`066<H25:D36<H00aBU
6<H@Q0025:D46<H00aBU6<HHaP026<H45:D26<H00aBU48@@Q0035:D46<H011BU48@DYABU1aS60QBU
00<@Q1BU7>L00aS600<DYA2448@01ABU0aS60QBU11S60aBU00<@Q1BU5:D00aBU00<HaQBU5:D01AS6
0QBU00<<Ha245:D00Q240PaS00L@Q0aS48@<Ha245:DHaP0248@01AS67>LLiaBU36<00a240`aS1124
11BU00@@Q0aS48@@Q08DY@0448@<H`Q236<448@236<248@336<00a245:DDY@045:D236<01A2436<@
Q1BU48@00`aS112400<DYA2448@00aBU0Q2400<DYA2448@00Q2400@DYA2436<<H`<@Q0H<H`0348@<
Ha24008@Q048@P000`@Q00<000@Q12400P@Q00P8@P@Q000<HcW>NmiNmcF]0THa00=244Ha@Q000T8@
00<mkd8@AS400T8@0Sg_00E244Ha@Q1243g_00I24003>Lhmkcg_009240=6<@=24003AS52448@00A2
40Dmk`8icP05?NlicSF]=JdicP02=Jd013W>=JdicSg_0SW>00@aS3F]=Jde[@<icP04?Nm2448@@Q02
?Nl2@Q001DHa?NlmkcF]?Nl00SW>0Sg_00M243g_>Lhe[C6<=JdaS002=Jd00c6<=JdaS003=Jd00cW>
=JdicP02?Nl00d8@?NlicP03>Lh00cF]<H`aS003<H`2=Jd6<H`00be[<H`aS002;F/01BU:<H`aS2U:
;F/00S6<00<]JbU:;F/00S6<0Re[0S6<1Be[00<YBRe[;F/00Re[0RDY0Re[0S6<00<YBRe[:DX00RU:
00<U:BU:9BT00bDY0RU:0R480QcW00<Q21cW8@P00R480acW00<U:C6<>Lh00T8@0SW>0RU:0RDY00@Y
BR488@PQ208U:@8Q20037>LQ224800<Q20059BTYBRDY8@PLi`058@P47>L00b487>LLi`026<H021cW
8@PLiaS67>LU:BU:9BT27>L012487>LQ21cW0R4800<U:B488@P00QS600@DYAS66<HLi`8HaP037>LH
aQcW00<HaP047>LHaQS66<H27>L011S67>LLiacW0bDY0b4800@YBRDY9BTU:@<YBP059BTLib488@PL
i`028@P00acW8@PU:@02:DX29BT38@P012DY:DXQ22480acW0QS600DLiaS66<HHaQBU00<Li`048@PL
iacW6<H37>L01aS65:DHaQBU6<HDYA24008<H`DDY@LHaP037>LQ22DY00@Q20@Li`056<HDYABU7>LH
aP037>L00aS65:DDY@046<H45:D26<H35:D00aS67>LHaP045:D00aS65:DHaP046<H02ABU6<HHaQS6
5:DHaQBU6<HLi`036<H011cW6<HHaQBU0aS600<LiaS66<H00QS600<DYAS66<H011S600<@Q1BU5:D0
0QS60aBU00@HaQcW7>LLi`8HaP8DY@046<HDYABU6<H248@25:D36<H02QcW6<H@Q1BU48@DYAS65:DH
aQcW0QS60aBU00<@Q0aS48@00QS600<DYA2448@00QBU0QS60QBU00<@Q1BU5:D00QBU0QS60QcW00<D
YAS65:D01ABU00D@Q1BU5:DHaQBU00<HaP067>LDYA2448@<Ha240`aS0Q2400<DYA2436<00Q2400<D
YAS66<H00aS600<LiaS648@00Q240`aS00@@Q1BU48@@Q0@DY@0436<@Q12448@25:D011246<HDYABU
0Q241@aS11240PaS0Q2400@DYA2448@DY@@@Q0<DY@@@Q00536<@Q1245:D@Q0035:D00a2436<<H`04
5:D00a2436<@Q00648@010aS48@@Q1240PaS0a240@Q200021240100012448@000P@Q00X8@P00124<
HcW>OomNmcF]@Q1:DP=6<@A24003?Nm244Ha00E240<mk`05AS52448@AS524002?Nl2>Lh0148@AS56
<DHa0T8@00Y6<D8@AS56<D8@AS5:DT8@?NlicP924003?NlicSW>00@icP04<H`e[CF]>Lh2=Jd013g_
>LhmkcF]0c6<0SF]00<icT8@@Q000T8@0Sg_0d8@00=6<Cg_?Nl00SW>0Sg_00PicSg_@Q0icSF]<H`]
JcF]0SW>00le[C6<<H`aS3F]>Lhe[C6<=JdmkdHa?Nle[CW>?Nl00SW>00@e[C6<<H`e[@@aS005=Jda
S36<;F/aS003;F/00c6<;F/aS002<H`00be[:DX]J`03;F/01RU:;F/aS36<=JdaS08]J`<aS003;F/Y
BRe[008YBP8]J`06:DX]JbU:;F/aS2U:0S6<0RU:0b481bDY00@Q21cW8@PLi`<Q20@Li`078@PYBRU:
@Q16<D8@=Jd00RU:00<]JbDY8@P012DY00PQ22DY7>LQ21S67>LQ21cW0RDY0RU:0R480QcW0R480acW
124800<LiaS66<H00QS600<Lib488@P00QcW00HU:B487>LLiaS68@P27>L38@P00acW6<HHaP025:D3
6<H011cW8@PLiacW11S60QcW00<HaQcW6<H00QcW00@HaQcW7>LLi`<U:@<Q2003:DX]JbU:008U:@03
8@PU:B48008Li`036<HLiaS600<U:@038@PU:BDY00DU:@038@PLibDY008Q20037>LHaQBU008HaP8L
i`056<HLiacW7>LQ20047>L26<H45:D348@336<011246<HLiaS60QBU00<HaQcW7>L00QS600<U:BU:
9BT00RDY0QcW0QS60QcW1AS60QcW00<HaQcW5:D00QBU0aS600@DYA245:D@Q08HaP035:DHaQS600HH
aP@DY@8HaP045:DHaQcW6<H25:D00a246<HHaP046<H00acW6<HHaP025:D36<H00acW6<HHaP036<H0
11cW6<HHaQS611BU0acW00HDYA245:DHaQcW6<H27>L00aS65:D@Q0026<H35:D248@25:D27>L00aS6
5:D@Q0055:D01aS67>LHaQBU48@DYA24008DY@0348@DYA2400@@Q0<DY@<HaP037>LDYA24008DY@03
7>LHaQBU008DY@0548@DYAS66<HDY@0248@36<H011BU6<HHaQcW0QBU0PaS1A2400@DYA2448@<H`8@
Q0DDY@8HaP8DY@0448@<H`aS36<248@236<011245:DDYAS611240`aS0Q240QBU0Q2420aS00<@Q0aS
36<00Q240aBU0Q2400H<Ha2448@<HaBU48@25:D748@00aBU48@DY@0548@01aBU48@@Q0aS48@<Ha24
008DY@<@Q00536<@Q12436<@Q00436<0000300048@@Q00D48@0924848@@Q248icW>LDY@]Jcg_00A6
<@04BU96<DYBAS44@Q02?Nl01D8@AS56<D8@?Nl00THa00Q:DTHaAS4mkcW>?Nm244Ha148@00A6<D8@
AS5:DP92408mk`9240=6<@03BU96<D8@008mk`924003?NlicSW>00<e[@<aS004=JdicSF]=Jd2<H`0
0cW>=Jde[@02?Nl2@Q001cW>?NlicSW>?NlicSg_008icP03=JdicSW>00<icP@e[@@icP8e[@8aS08e
[@04<H`]Jc6<=Jd4<H`3;F/3<H`00be[<H`aS002;F/4<H`3;F/2:DX00bDY;F/]J`02<H`2;F/2:DX0
1Be[:DXU:BU:;F/00S6<0be[00@YBRDY:DX]J`@YBP07<H`]Jbe[;F/YBRe[:DX00RDY00DQ22DY9BTY
BRDY008Q20039BTQ2248008Q20039BTQ21cW00<Li`0<8@PLiacW:DXaS4YBDYA243W>8@PU:BU:0RDY
1B480acW0bDY00<Q22DY9BT00RU:00<U:AcW8@P00R4800<U:B488@P00R480QcW00XQ22DY8@PLiaBU
6<HLiaS67>LQ208Li`8U:@8Q20047>LQ22488@P77>L00aS65:DHaP087>L011BU6<HHaQ240QS60acW
00<HaQcW7>L012480RDY0b480RDY00DQ21cW7>LLib4800<U:@<YBP@U:@8YBP039BTQ22DY008Q20<H
aP<Li`036<HQ224800@Li`048@PU:B488@P37>L25:D01a245:D@Q1245:DHaR48008Li`056<HDYABU
6<HLi`026<H00acW6<HHaP03:DX00b486<HLi`057>L00aS65:DDY@056<H25:D00aS65:DHaP026<H0
1A245:DHaQS67>L011S600HLiaBU5:D@Q1BU6<H25:D26<H45:D01AS65:DDYABU6<H00acW00<HaQBU
5:D00aS600<DYAS66<H00aS60aBU1AS61ABU00lHaQBU5:DDYA245:DHaQcW6<HDYA246<HDYA245:D0
0QS600<DYA245:D00QS60QBU0aS600<DYAS66<H00QS600HLiaS65:DDYA245:D548@45:D248@011BU
7>LHaQS61ABU00PLiaBU48@<HaBU6<HLiaS60aBU00DHaQBU5:D@Q1BU008HaP8DY@<@Q08<H`8@Q004
6<H@Q1245:D248@00`aS48@@Q0025:D26<H25:D011245:D@Q1240PaS0Q2400<DYA245:D00Q240PaS
0Q2400@DYAS648@@Q08DY@8HaP055:D@Q12436<8@P0236<0112436<<H`aS0Q240`aS0aBU00@@Q0aS
36<<H`8@Q0045:D@Q1BU5:D248@01@aS48@@Q1245:D00QS600@DY@aS48@@Q0<DY@<@Q0@DY@<@Q0<D
Y@0448@<H`aS48@236<00004124000@Q000212404@0024848@@Q000<HcW>LiaF]C6<?Nm6<D8@AS5:
DTHaBU800THa00E:DTHaAS5243g_00924003AS52448@00A6<@9240@mk`05@Q0mkd8@@Q16<@02@Q03
AS400cg_>Lhmk`02@Q04AS43@Q001Sg_@Q0mkcg_>Lhe[@<icP03=JdaS36<008e[@0?>Lhe[CF]<H`i
cSF]<H`icSg_@Q0mkcF]>Li243g_008icP8mk`8icP8e[@8icP8e[@<icP<e[@<icP04=JdaS36<<H`3
=Jd00c6<=Jde[@04<H`2=Jd00c6<;F/YBP02<H`2;F/02S6<=Jde[CF]<H`]JbU:;F/YBRe[0RU:00<a
S3F]<H`00Re[00<YBRe[;F/00bU:136<1BU:0Re[00@YBRDY9BT]J`8aS08]J`8YBP049BTQ22DY9BT2
:DX38@P39BT00bU:7>LLi`027>L02bDY7>LLiaS67>LU:BU:AS5BU4ic@Q001BU:00<U:B488@P01248
0QcW00@Q22U::DXU:@<YBP039BTQ2248008Q20059BTQ21cW8@PLi`028@P57>L26<H27>L01AS68@PQ
22489BT00R4800@LiaS67>LLi`8Q20@Li`8HaP8Li`8HaP@Li`036<HDYAS600<HaP055:DHaQS67>LH
aP027>L28@P00bDY8@PU:@059BT00b489BTQ20067>L29BT00bU:;F/U:@028@P00bDY:DXYBP02:DX5
8@P36<H00acW9BTQ20038@P011cW6<HLiacW0R4800LLib486<HHaQBU6<HDY@0348@011BU6<HLib48
0acW00<HaQBU6<H01AcW0R4800<U:AcW7>L00QS600<Lib486<H00aS60QcW0aS60aBU00<HaQcW6<H0
11BU00<LiaS67>L01AS60aBU00@HaQBU6<HDY@<HaP8DY@8HaP037>LHaQS6008Li`036<H@Q1BU008H
aP035:DHaQS600<HaP047>LHaQS65:D46<H00acW6<HHaP066<H25:D01Q245:DDYABU6<HDY@<HaP03
5:D@Q1BU008DY@8HaP047>LDYABU5:D96<H00acW6<HDY@0248@25:D248@010aS48@DYAS611BU1aS6
00@LiaS65:D@Q08DY@047>LHaQBU48@35:D00aS65:DDY@025:D36<H548@011BU6<HDYABU0`aS00<@
Q1BU48@011BU00@@Q1BU6<HDY@<@Q0035:D@Q0aS00X@Q0<DY@<@Q0056<HDYABU5:DHaP0248@00`aS
48@<H`0336<348@00`aS48@<H`0248@00aBU48@<H`0248@01ABU48@@Q1BU48@00PaS00<@Q1S66<H0
0QBU0a2400<DYA2448@00Q2400PHaQBU48@<Ha246<HDY@aS0Q240QBU00<@Q1BU5:D011240@aS0004
12401@0012448@@Q24800P@Q00H8@SF]MkeJeS6<>Lh7@Q000dHa@Q16<@02AS401DYB@Q1243g_@Q00
0dHa14YB00M6<D8@@Q1243g_@Q0icP03?Nl2@Q03AS400d8@?Nlmk`03?Nl0148@?Nm244Ha0Tic00=6
<D8@@Q000T8@00HmkcW>=JdicSF]>Lh3=Jd012e[<H`]Jbe[0c6<0cF]0cW>00@mkd8@@Q0mk`8e[@03
<H`icSW>008e[@8icP<e[@06>Lhe[CW><H`e[C6<0cF]00DicSg_@Q0icSF]00<aS004;F/YBRe[;F/2
<H`01Be[<H`aS36<;F/00S6<0cF]0S6<0Re[12U:00TaS3F]>Lh]JbDY:DX]Jc6<;F/00RU:0Re[00Le
[C6<:DXYBRDY:DX]J`039BT4:DX2;F/2<H`00be[:DXYBP029BT00bU:9BTQ20029BT01RU:8@PQ2248
9BTLi`8Q208U:@038@PLib48008U:@08AS5BU5:DAS4YBRDY:DXU:@8YBP039BTQ224800<Q20@Li`05
8@PU:BDY9BTYBP059BT4:DX01RDY8@PU:BDY8@PU:@8Q20DLi`046<HLiacW6<H27>L00b487>LLi`04
8@P77>L00aS67>LQ20028@P00acW6<HHaP036<H00aBU6<HHaP027>L00b487>LQ20038@P01acW8@PU
:BDY8@PHaQcW008U:@8Q200=7>LHaQcW8@PYBRe[:DXU:Be[:DXU:B489BT00RU:00<U:B489BT00R48
0QcW00LHaQBU7>LLib489BTLi`028@P27>L01R487>LU:BDY8@PLi`DHaP035:DHaQS6008HaP035:DH
aQcW00<Li`066<HLiacW7>LQ22DY0R4800<LiaS67>L00b4800DHaQBU6<HHaQcW008HaP045:DHaQS6
6<H35:D46<H25:D26<H01acW6<HLiacW6<HDYAS6008Li`046<HDYA246<H27>L01ABU48@DYABU7>L0
11S600DLiaS66<HHaQ24008DY@8HaP065:DHaQS67>LHaQcW0QS600@DYAS67>LLi`8HaP8DY@<HaP8D
Y@056<HDYABU5:DLi`028@P011cW5:DDYABU0QS600@DYA246<HHaP@DY@@HaP8DY@8HaP037>LHaQBU
008HaP045:D@Q1245:D248@01QBU6<HHaQS648@DY@@HaP055:DHaQS66<HDY@046<H35:D00aS67>LH
aP026<H25:D011S648@@Q1240QS600HDYA2448@DYA245:D336<00a246<H@Q0026<H25:D248@25:D0
0aS65:DDY@0448@236<448@236<348@25:D011S65:D@Q1BU0Q2400@DYAS66<HHaPH@Q0<<H`<DY@<@
Q0045:DHaQBU48@236<01A245:D@Q0aS48@011BU00@@Q0aS48@@Q08HaP<DY@8HaPHDY@<@Q00336<@
Q12400<@Q00536<@Q12448@<H`01248000848@0300048@@Q00D48@09000<HcW>MkeF]C6<?Nm243g_
00=24096<@9240=:DP03AS5243g_00924003BU96<DYB0096<@07BU96<DHaAS5244Ha@Q000Sg_00@i
cSg_?Nlmk`924004AS52448@AS42@Q0013W>?NlmkcW>0T8@0dYB0THa0T8@0Sg_00DicSF]>Lhe[CW>
008e[@8aS007;F/aS36<<H`e[C6<=Jd01CW>00Dmkd8@?NlicS6<008e[@8icP09=JdicSW>=JdicSF]
>Lhe[CW>00@e[@04>LhaS3W>?Nl2>Lh3=Jd2<H`3;F/2<H`2;F/4<H`00be[<H`e[@02=Jd4;F/3:DX0
12e[<H`aS36<12e[12U:0Re[0S6<0Re[12U:00HU:B48:DXYBSF];F/2<H`00be[:DXYBP04:DX29BT0
0b48:DXU:@028@P29BT27>L00b489BTYBP038@P01QcW8@PmkdYBDYA>L`8]J`@U:@LQ20<Li`078@PU
:BDY9BTYBRe[:DX00RDY00<Q22DY:DX00Re[0RDY0R480RDY124800<LiaS66<H00QcW0R481acW00@Q
21cW7>LQ20DLi`036<HLib48008Q20037>LHaQS6008HaP055:DHaQS65:DHaP047>L48@P011cW8@PQ
21cW0R4800/U:BU::DXQ21cW6<HLibDY8@PYBRe[008YBP@U:@8Q20039BTYBRU:008U:@8Q20057>LH
aQcW7>LU:@038@P27>L28@P00bDY8@PQ20028@P01QcW6<HHaQS67>LHaP8DY@8HaP055:DHaQS67>LQ
20037>L01AS67>LQ21cW8@P021cW00<HaQcW7>L00QS600@DYAS67>LLi`<DY@046<HDYAS67>L36<H0
0aBU6<HHaP037>L00aS65:DHaP046<H25:D37>L25:D36<H25:D011S67>LLiaS60QBU00<HaQBU6<H0
0aBU0QS60QcW0QS600<DYAS67>L00QcW0aBU0QS600@DYAS65:DHaP<DY@036<HLiacW00DHaP045:D@
Q1BU6<H27>L011S65:DHaQBU11S600@DYAS66<HHaP8DY@8HaP035:D@Q1BU008DY@8@Q0035:DHaQS6
008DY@8HaP047>LHaQS65:D248@01ABU6<HLiaS65:D00Q2400DHaQBU5:DHaQcW008HaP055:D@Q1BU
48@HaP035:D00a245:D@Q00348@011BU48@@Q1241ABU00<@Q1BU48@01ABU0Q2400HDY@aS36<<Ha24
5:D248@336<011245:DDYABU0QS600LDYA2436<@Q1BU7>LHaP0448@01ABU36<<H`aS48@00QBU1A24
0QBU0Q2400<<Ha2448@00PaS0QBU0Q2400<<HaBU48@00a240QS600/LiaBU48@@Q1BU48@DYA245:D@
Q1BU00D@Q0055:D@Q0aS36<@Q0025:D148@136<0000600048@@Q00048@000P@Q00/8@P@Q1248@SF]
MkeJeSF]AS5:DTHa00=2408mk`03>Lhmkcg_00=24009?Nm2448@>Lhmkd8@AS5:DTHa00E240<mk`04
@Q0icSW>=Jd2?Nl00d8@AS524002AS42?Nl2=Jd3>Lh3@Q001cW>?Nlmkd8@?Nm6<DYB0096<@8mk`<i
cP04=JdaS36<=Jd2<H`3;F/02BU:<H`e[CW>?NlicSF]>LhaS002>Lh2?Nl00cF]>Li24002?Nl013F]
>LhicSW>0cF]00@aS3F]=Jde[@<icP08@Q0icSF]=Jdmkd8@?Nle[@8]J`8e[@04<H`]JbU::DX5<H`0
12e[<H`]Jbe[0RDY0Re[00Pe[CW>=Jde[C6<:DX]JbDY0RU:0Re[0bU:0RDY1Be[00HU:BU:9BTU:BU:
;F/4<H`00be[:DXU:@029BT3:DX29BT3:DX38@P29BT28@P02AcW8@PQ21cW>Li:DUJeCW<]J`029BT0
1BU:<H`U:B487>L00RDY11cW00@HaQcW7>LQ20<U:@03:DXU:BDY00<Q20049BTYBRDY;F/3<H`012U:
8@PQ22480bDY0QcW00DDYAS66<HHaQcW00<Q20097>LHaQcW7>LHaQcW6<HLib4800DLi`8Q208U:@05
7>LDYAS66<HLi`025:D01QS67>LLiacW6<HLi`<Q20037>LQ2248008Li`036<HLib48008Q20037>LQ
21cW008Q20039BT]Jbe[008aS004:DXU:B487>L29BT48@P01BDY8@PLiacW8@P00acW0R480QcW0b48
00<Lib488@P00R480acW00<HaQcW7>L00QS60QcW00DQ21S66<HHaQBU008Li`058@PLiacW6<HQ2003
9BT00b487>LLi`047>L36<H35:D00aS67>LLi`026<H00aBU6<HHaP046<H00acW6<HLi`046<H35:D0
1acW6<HHaQcW8@PHaQcW00PHaP<DY@0548@DYABU5:DHaP035:D00aS65:DDY@025:D00acW6<HDY@02
5:D011cW6<HHaQBU0QS60aBU00<HaQBU5:D00QBU00THaQcW8@PQ21cW6<HLib487>L00aS600@LiaS6
5:DDY@8HaP0348@DYAS600<HaP<Li`<HaP8DY@0748@DYAS66<HLiaS65:D011S600HDYAS65:DDYA24
6<H35:D26<H01ABU48@<Ha245:D00QS600@DYAS67>LHaPDDY@8@Q0035:D@Q124008@Q0<DY@0448@D
YABU6<H248@00aBU6<HDY@025:D01aS65:D@Q1BU7>LHaQ24008<H`D@Q00736<@Q12448@DY@aS48@0
0aBU0Q241ABU1A240`aS0aBU00L@Q0aS48@@Q1BU6<HDY@0748@25:D01Q245:D@Q1245:D@Q08DY@03
6<HDYAS600<DY@8@Q0<DY@0348@DYA2400L@Q00436<@Q12448@136<00003124000@Q00<48@0<0008
@P@Q124000aS=Jeg_EJe=Je244YB0THa0T8@0Sg_0SW>0d8@00A6<D8@>LhicPA240A6<@04@Q16<D8@
AS42@Q000cW>?NlicP02>Lh2?Nl0148@AS56<DHa0T8@0SW>00Te[C6<>LhmkdHa@Q0mkcW>?Nl0148@
0THa0T8@00<icSg_>Lh00cF]00DaS3F]<H`]Jc6<008]J`8aS0<icP06?NlicSW>=JdicSg_0SW>00Pe
[Cg_?NlicSF]>LhmkcW>0S6<00De[C6<<H`aS3F]008icP03?NlicSW>008icP924003>Lhe[Be[008]
J`8aS004;F/YBRe[;F/4<H`01Be[<H`]Jbe[:DX00Re[00<YBS6<<H`00SF]0c6<00@YBRe[;F/YBP8]
J`DYBPD]J`05:DXU:BDY:DXU:@02;F/2<H`01Be[:DXYBRDY:DX00RDY0RU:0RDY0bU:01@U:B488@PU
:BU:9BTQ22DY8@PLic6<>Li>Le:D>LhaS2DY8@P]JbU:0R4800<YBRDY8@P00QcW0b4800<Lib487>L0
0R4800<U:BU::DX00b4800<U:BU::DX00RU:00L]Jc6<;F/]JbDY8@PU:@028@P27>L00b487>LLi`02
6<H00acW8@PLi`026<H27>L01QS67>LLib486<HLi`<Q20087>LHaQcW9BTYBRDY7>LDY@8Li`<HaP8L
i`036<HLiacW00@Q20037>LU:B4800<HaP039BTQ2248008Q20049BTQ22DY8@P2:DX0136<=Jd]JbU:
0R4800<U:B489BT00QcW0R480RDY11cW00@HaQcW7>LLi`@Q20077>LQ22489BTQ21S67>L00R4800@L
iaS67>LHaP@Li`DHaP@Li`038@PU:BDY008U:@048@PLiaS67>L28@P011S65:DDYABU0QS600@DYAS6
7>LLi`8HaP8Li`036<HDYABU00HHaP047>LHaQBU5:D46<H02AcW6<HLiaS65:DHaQcW8@PHaP025:D0
0aS67>LDY@045:D00a245:DDY@025:D248@=6<H45:D01AS65:DDYA245:D00QS61AcW0R4800@LiaS6
7>LLi`8HaP045:DHaQBU5:D76<H27>L01QS65:DHaQS65:DHaP@DY@046<HDYAS67>L26<H25:D26<H0
0aBU48@@Q0036<H011BU48@@Q1BU0QS60QBU0aS600<DYA245:D00aBU00<@Q1BU48@01QBU00@@Q1BU
6<HDY@<@Q0036<HDYABU00DDY@0348@DYABU008@Q08<H`<@Q08<H`0348@DYA2400<@Q08HaP8DY@03
48@DYABU008HaP055:D@Q1245:D@Q00236<348@35:D00`aS48@DY@026<H011BU36<@Q0aS1A2400<D
YA2448@00Q2400<DYA2448@00QBU00<HaQBU5:D00QBU00HHaQBU5:DDYAS65:D448@011BU48@@Q0aS
11240@aS000212400`0012448@0312402@Q212448@Q2=JekgUkg>Li6<@02CW<014YBAS56<D8@0THa
00A:DT8@@Q1240<mk`05>Lhe[Cg_?Nm24002AS44?Nl2@Q02?Nl2>Lh00cg_>Lhmk`04>Lh01Sg_>Lhi
cSW>?NlicP@mk`05>Lhmkcg_@Q0mk`04>Lh02D8@?Nlmkcg_@Q16<DYBAS524002>Lh2<H`3=Jd3<H`3
=Jd2<H`2=Jd2>Lh01CF]<H`icSW>?Nl01CW>0Sg_00=243g_>Lh00c6<00Le[CW>=Jde[CW>@Q1>L`02
DY@00dHa=JdicP02=Jd3<H`6;F/2:DX012e[<H`aS2e[0RU:0S6<00<e[C6<;F/00c6<0RU:00L]JbU:
9BTYBS6<=JdaS005:DX39BT022U:9BTU:BDY:DX]JbU:9BT4:DX39BT5:DX3;F/00c6<;F/U:@029BT0
0bU:9BTU:@02<H`01THaCW<mkc6<9BTQ20@YBP8U:@LQ20057>LQ22489BTYBP029BT38@P011cW9BTY
BRU:0bDY00<]JbDY9BT012DY0R4800<Lib487>L00b4800<U:B488@P00acW00LQ21S66<HDYAcW8@PL
i`048@P011cW9BTQ21cW0QS60acW00<HaQcW6<H00QS612480QS600LLib488@PLiaS65:DHaP047>L0
21S67>LLiacW9BTYBS6<;F/2:DX01Be[:DXYBR487>L00R480QcW00<HaQcW7>L00QcW00HHaQcW7>LQ
21cW6<H47>L00b489BTQ20037>L28@P57>L28@P27>L00aS67>LLi`026<H57>L01B489BTU:AcW8@P0
1AS60QcW0QS600<DYAS66<H00QS600<LiaS66<H00aBU0QS60QcW0QBU00@HaQcW6<HDY@8HaP057>LH
aQBU6<HQ20046<H27>L36<H37>L01QS65:DHaQ246<HDY@@HaP037>LHaQS600<DY@0548@DYABU48@D
Y@0248@25:D01A245:DDYAcW6<H00QBU00@HaQBU6<HHaP8Li`045:DHaQcW9BT48@P27>L76<H011cW
6<HLiacW0QBU00@HaQcW7>LHaP8DY@0348@DYABU00DHaP047>LHaQBU5:D26<H01AcW6<HDYA245:D0
0Q2400<<Ha2448@00Q240aBU00@HaQBU5:D@Q08DY@0448@<Ha2448@25:D01A245:D@Q1S65:D00Q24
0QS600DDYA245:DHaQBU008@Q08DY@0348@DYABU008DY@046<HDYABU5:D648@00aBU48@@Q0075:D5
48@010aS48@@Q1240`aS0Q240QBU0Q240PaS00L@Q1S67>LHaQBU48@<H`0248@00aBU48@@Q00548@2
5:D348@45:D248@65:D:48@136<0000D00048@@Q124000@Q00048@Q2124000aS>Lig_Ekg=Je:DTic
BU96<@9:DP09@Q0mkd8@@Q1:DTHa@Q16<CW>008mk`8icP03?Nm2448@00=24004?NlicSW>?Nl2@Q02
>Lh013F]>Lhmkcg_0cW>00Dmkd8@?NlmkcF]008icP03=JdicSg_008mk`8icP04?NlicSW>>Lh2?Nl2
@Q02?Nl2@Q02BU8013g_>Lhe[C6<0SW>00LaS2e[:DXaS3g_>LhaS002=Jd0136<=Jde[C6<0SF]0cW>
00I243g_>LhicS6<>Lh3@Q001CW>=Jde[C6<=Jd00S6<00de[C6<>Li:DU:DE[E>Lcg_=JdaS3F]>Lhe
[@06;F/0136<;F/]JbU:0Re[0bU:0Re[1C6<00@]JbU::DX]J`@YBP05;F/aS36<<H`]J`039BT2:DX0
1B489BTU:BU:;F/01BU:0bDY0RU:0bDY0RU:0be[00PaS2e[9BTU:B489BTQ22DY0RU:00A6<E:DBU8i
cP8Q20@YBP<U:@8Q20047>LQ22487>L28@P29BT01BU:9BTQ22489BT00b4800<U:BU:8@P00RDY00<]
JbU:9BT00RDY00DYBRDY9BTU:B4800<Li`@Q20039BTQ21cW00<Li`8HaP045:DLib488@P37>L28@P0
0bDY8@PHaP026<H01AcW6<HHaQS67>L00aS600DLib487>LLiaS6008Q20047>LHaQBU6<H37>L36<H2
7>L00b489BTU:@08:DX00bDY7>LLi`027>L56<H00acW6<HLi`027>L00b487>LLi`027>L012489BTU
:B480QcW00DQ21S67>LLib4800<Li`046<HLiacW7>L36<H01AcW6<HLiaS67>L00R4800HYBRDY9BTL
iaS67>L26<H00aBU6<HLi`026<H00aBU6<HHaP027>L26<H02AcW6<HHaQS65:DLiaS65:DHaP027>L0
11S65:DHaQBU0QS600<DYAS67>L00acW0QBU0QS600PLiaS65:DDYAS67>LHaQcW0QBU00D@Q1BU5:DH
aQBU008HaP047>LDYABU5:D26<H01QBU48@DYA245:DHaP@DY@0348@DYABU00<HaP035:DHaQcW008L
i`<HaP037>LQ22DY008Q20087>LQ21S66<HDYAcW5:D@Q08HaP048@PLiaBU5:D26<H27>L46<H55:D3
6<H35:D56<H35:D00a245:D@Q0035:D01Q245:DDYABU6<HDY@8HaP045:D@Q0aS36<348@02aBU48@H
aQcW5:D<Ha245:DLiaS648@011BU0Q240aBU00L@Q1BU5:DDYAS65:D@Q00236<01a2436<@Q1BU48@D
YA24008DY@8HaP@@Q0035:DHaQBU00<<H`8DY@0348@<H`aS00<@Q0<<H`0748@DYA245:D@Q1BU48@0
0QBU0Q2400@<Ha2448@HaP8DY@0448@DYA245:D348@35:D248@25:D26<H248@35:D010aS48@@Q1BU
11240@aS00000`@Q00048@0512402PQ212448@Q2=JekgU[F>Li6<Dic1DYB0THa0dYB0THa0T8@0cW>
00@mkd8@@Q1240@mk`DicP04<H`icSW>?Nl2@Q000cg_@Q124004?Nl00cW>?NlicP05?Nl2>Lh3?Nl0
0cW>=JdicP03>Lh3@Q02?Nl02CW>?Nm6<CW>=JdaS3F]?Nm24003?Nl2=Jd00c6<=JdaS002<H`4=Jd0
0cW>?Nle[@02=Jd2>Lh01cg_>LhicSW>=JdicSF]00DicP8mk`96<@0:CW=:DSg_=Jd]Jc6<>LhaS3F]
<H`2=Jd2<H`3;F/00bU:;F/YBP02:DX022e[=Jd]JbU:;F/e[C6<;F/29BT2:DX2;F/012U:;F/]Jbe[
0bU:00<U:B489BT00bDY00<Q22DY:DX01bU:0bDY00@Q22DY:DXU:@8YBP<]J`@U:@05;F/YBS6<:DXi
cP02AS400d8@:DXQ20039BT00bU:9BTQ20049BT01B487>LLiacW8@P00RU:00HU:BU:;F/]JbU:9BT2
8@P012DY8@PQ22480RDY0b4800DU:B488@PU:BU:008U:@DLi`048@PU:BDY8@P37>L28@P00bDY8@PQ
20038@P011cW6<HLiacW11S60acW00<HaQcW6<H00QcW00<Q21cW7>L011cW0R4800@LiaBU5:DDY@TL
i`038@PU:Be[00@YBP059BTQ22488@PLi`036<H37>L76<H00acW8@PQ20028@P37>L01AS67>LLiacW
6<H00QcW00DQ21cW7>LLiaS6008Li`0;6<HLiaS66<HLiaS67>LHaQcW8@PU:@027>L25:D76<H00aBU
6<HLi`027>L00aS648@@Q0025:D46<H00acW6<HDY@066<H00acW8@PLi`026<H45:D01QS65:DHaQBU
6<HDY@8HaP087>LHaQS67>LQ21S648@DY@@HaP8Li`056<HDYAS67>LDY@0248@55:D248@00aBU6<HH
aP025:D011246<HLiacW0RDY00@LiaS67>LLi`@U:@047>LHaQS66<H27>L26<H28@P02AcW5:DDYAS6
5:DHaQcW8@PHaP0248@26<H248@011BU6<HHaQS60QcW11S61QBU00<@Q1BU5:D01ABU00@@Q1BU6<HD
Y@8@Q0035:DHaQBU00<DY@8@Q08DY@056<HDY@aS48@DY@026<H35:D011S65:D@Q1BU0QS600<DYA24
5:D00aS600/DYA245:DDYA245:D@Q1BU48@DYA2400<DY@036<HDYABU008DY@@@Q0086<H@Q1245:D@
Q0aS48@<H`D@Q08<H`0348@DYAS600HDY@8@Q0035:DHaQS6008@Q08DY@0448@<H`aS48@35:D248@2
5:D26<H00a2436<@Q00348@00aBU48@@Q00248@236<000<48@0300048@0000848@0;248000@Q248e
[GNmG_LicTHaBU96<@05BU802THaBU96<DHaBU9>LdHa@Q0icSF]0SW>00<mkdHa@Q000T8@00@icSF]
>LhicP8mk`8icP03=JdicSg_008mk`92408mk`924006?NlicSW>>Li243g_0SW>0cg_1CW>00<aS3F]
=Jd00cg_00Q244Ha?NlmkcW>?NlicSF]0S6<00DicSg_>LhmkcW>00De[@03>Lhe[C6<008aS0<e[@04
?NlicSW>=Jd4>Lh013F]>LhicT8@0SW>0SF]00TmkcW>>Li6<DYBCW=BU3g_>Lh00S6<0SF]136<00@e
[C6<;F/aS08]J`04<H`]JbU::DX9;F/2:DX012e[:DXU:BU:0be[0RU:00@]JbDY9BTQ208U:@038@PU
:BDY00@YBP039BTYBRU:00@YBP8U:@8Q2004:DX]Jbe[;F/2:DX39BT01RU:;F/]JbU:=Jdmk`96<@07
<H`]JbU:8@PU:B487>L00RDY00<YBR488@P00RDY00<Q21cW8@P00bDY12U:0RDY00DQ22DY9BTQ21cW
008Q2003:DXU:BDY008Q20069BTYBRU:9BTQ21cW0RDY00<LiaS66<H0124800<U:B487>L00QcW00@U
:B488@PU:@8Q20037>LHaQcW008HaP035:DHaQcW00<Li`8HaP047>LHaQS67>L38@P37>L00b486<HH
aP025:D26<H01AcW6<HHaQS68@P00acW00HU:BU::DXYBRDY:DX39BT01B487>LQ21cW6<H00QBU0acW
0QS60QcW00DQ21S67>LLibDY008Li`078@PLiacW7>LDYAS67>L00R480QS60acW00HHaQcW7>LHaQcW
6<H57>L39BT00b485:DDY@026<H00acW6<HHaP026<H25:D01AS67>LQ21cW5:D00Q2400DDYAcW6<HH
aQBU008HaP8Li`056<H@Q1S67>LDY@026<H27>L011S65:DHaQBU0QS600@LiaBU5:DDY@<HaP<DY@8H
aP@DY@@HaP8Li`<DY@036<HDYAS6008DY@8@Q0035:D@Q1BU00<DY@036<HDYAS6008DY@076<HQ22DY
8@PLiaS67>L00bDY0R480aS600<LiaS66<H00QcW00<Q21cW6<H00QS600XDYAS67>LLib486<HDYA24
5:D@Q0HDY@036<HLiacW008HaPLDY@0348@DYABU008DY@<@Q0@DY@0448@DYABU6<H25:D248@35:D0
1a2436<<H`aS6<HDYAS600HDY@0448@DYABU48@25:D26<H00aBU6<HDY@0648@00aBU48@DY@0248@2
5:D01AS65:D@Q12436<00a240aBU0PaS0a240PaS0a240`aS00@@Q1BU6<HDY@8@Q08DY@0348@DYABU
008HaP035:D@Q1BU008DY@0648@<Ha245:DHaQBU0PaS00d@Q1BU5:DDYAS65:D@Q0aS48@DYA245:D<
H`0448@0000300048@@Q00D48@0:24848@00248aS7NmF]HicTYBCW<2AS43BU800dicAS5:DP03AS42
BU82AS45@Q001THaBU96<D8@AS4mk`8icP<mk`06=JdaS3F]>Lhmkd8@0Sg_0SW>00DmkcW>>Lhe[Cg_
00=24006?Nm243g_>Lhe[C6<0cF]0c6<00@icTHaAS56<@@icP8aS08e[@<icP8mk`04>Lhmkcg_>Lh2
=Jd3<H`023F]>LhicSF]<H`]Jc6<=Jd2>Lh03CF]<H`aS3F]?NlicSF]<H`e[CW>=JdaS3F]00@icP03
=JdicSW>008e[@@aS005=JdaS36<<H`]J`04:DX4<H`00be[:DXYBP02:DX022e[:DX]Jbe[:DXU:BU:
;F/2<H`2:DX3;F/00bU:8@PU:@029BT02QcW8@PU:BU:9BTQ22DY;F/YBRDY0R4800<LiaS68@P01BDY
0bU:0bDY0RU:0Re[00HaS3W>@Q16<D8@<H`2:DX01b489BTU:BU:9BTQ21cW00<Q208Li`8Q20049BTY
BRU:9BT2:DX012e[:DXU:BDY0bU:00@Q21cW8@PLi`8Q20037>LQ2248008U:@DQ20<Li`038@PU:B48
00<Li`8Q20037>LQ224800<Q208Li`058@PLiacW6<HLi`026<H00acW6<HHaP046<H011cW9BTU:BDY
0R480acW0aS600DDYAS65:DHaQcW00DHaP8Li`DQ20<U:@LLi`036<HLiacW008Li`036<HQ21S6008L
i`<Q208Li`036<HLiaS600@HaP<Q20037>LHaQS6008HaPHLi`068@PLiaS66<HQ21cW0QS60acW00<H
aQBU5:D00QBU0QcW00@Q21cW6<HHaP<DY@8HaP047>LHaQBU5:D36<H00acW6<HDY@025:D01QS68@PL
iacW6<HDY@8HaP035:DHaQS6008DY@0348@HaQS600<DY@036<HDYAS6008DY@<HaP055:DHaQS67>LH
aP027>L02B485:DDYA245:DHaQBU6<H@Q0055:D00a245:DDY@056<H00acW6<HLi`037>L00b487>LL
i`026<H25:D021S65:DHaQBU6<HLib486<H25:D46<H35:D348@00aBU7>LLi`066<H25:D011245:DH
aQS60Q240aS600<DYA245:D00a241ABU0QS600@DYA245:DDY@<HaP@@Q0055:DHaQS66<HDY@0348@0
11BU7>LHaQcW1QBU00@HaQBU48@<H`8@Q0035:D@Q124008@Q08DY@0548@DYAS66<HDY@0248@45:D0
11S648@@Q0aS0Q240PaS00<@Q1BU48@00PaS00D@Q1BU48@DYA24008DY@@@Q08DY@0448@HaQcW6<H3
5:D021cW5:DDYA245:D@Q1BU48@25:D01Q245:D@Q1245:D@Q08<H`0648@DYA2448@DYA240@aS0000
1P@Q00048@00124000D48@05248]Jg>LF]Hmk`03BU82AS45BU84AS42BU8014Ha@Q1243g_0T8@0THa
00A244HaAS4mk`8icP8mk`06>Lhe[C6<<H`icSg_0T8@0cg_1CW>0Sg_0d8@0Sg_0SW>0SF]00TaS3F]
<H`aS3W>?Nm6<DYB@Q000SW>0cF]0c6<0SW>00=243g_?Nl00Sg_0SF]0c6<00@e[CW>>LhaS08e[@<a
S007>Lhe[CF]=JdicSg_>Lh00SF]00@aS3W>>LhicP8e[@LicP8e[@8aS003=JdaS36<00<aS004=Jd]
JbU:9BT3;F/00bU:;F/aS002<H`3:DX00be[<H`YBP029BT2:DX00be[<H`aS002;F/01BU:;F/YBRDY
8@P01BDY0b4812U:0RDY00@Q22DY9BTQ208U:@03:DXU:BU:008YBP049BTQ22489BT2:DX02Re[<H`i
cSF]>Li243g_=JdYBR480bDY00<YBRDY8@P00R480acW0R480bDY0RU:0Re[00DYBRDY9BTYBRDY00HQ
20<U:@038@PLib4800<Q208Li`8Q20037>LQ21cW00<Q208Li`036<HLib48008U:@048@PLiacW8@P2
6<H47>L66<H011cW6<HLiacW0RDY00TLiaS68@PQ21cW6<HDYAS67>L00QS600@DYAS66<HLi`<HaP8L
i`038@PLiacW00<U:@8Q2004:DXQ21cW6<H27>L00aS67>LHaP067>L00aS67>LLi`028@P27>L36<H2
7>L01AS67>LLiacW8@P00QcW0QS61acW0aS600<LiaS68@P00R4811S600HLiaS66<HHaQBU6<H27>L2
6<H25:D56<H35:D011S67>LDYABU11S600<DYAS67>L00QcW00PHaQBU6<HHaQBU6<HDYAS60QBU00<H
aQBU6<H011S600<DYAS65:D00aS60QcW00DQ21cW8@PLiaS6008DY@056<HDYABU48@DY@0348@25:D0
11245:D@Q1S60QBU0aS60QcW00<HaQcW8@P00acW0aS600HDYAS66<HHaQBU6<H37>L86<H25:D01Q24
5:DDYABU6<HDY@8HaP<Li`036<H@Q124008DY@8HaP035:D@Q1BU00<DY@8@Q0035:D@Q124008DY@03
6<H@Q0aS00<DY@8@Q0<DY@<HaP8@Q0035:DHaQS600<DY@0348@DYAS6008Li`055:D@Q1245:D@Q003
6<H25:D00`aS48@@Q00348@25:D248@00aBU48@HaP046<H00aBU48@DY@035:D248@236<00a2436<@
Q00348@236<248@25:D021S648@DYABU48@DYA245:D46<H011BU6<H@Q1BU0a240aBU0a2400<DYA24
5:D00Q2400D<Ha2448@@Q1BU00<@Q04<H`0020@Q00/8@P001248@SF]MkeJeSW>BU9BU4ic00=:DP05
AS5244HaAS5:DP05AS42@Q02?Nl01D8@AS5244YBAS400T8@00@mkd8@@Q1240<icP06=JdicSW>>Lhm
kcF]0SW>00Pe[C6<<H`aS3F]<H`e[CW>148@0Sg_00PicSF]<H`aS3W>?NlicSF]0Sg_0SW>00<e[CW>
>Lh013F]00<aS3F]=Jd00SW>00<aS3F]=Jd013F]13W>00DmkcW>?NlicSg_00<icP03=JdicSW>008e
[@06;F/aS3F]<H`e[C6<13F]00@]Jc6<<H`icP8e[@04>Lhe[CF]<H`2;F/4<H`4:DX3=Jd01C6<;F/]
Jc6<;F/00bU:00<]Jc6<;F/00RU:00@]Jc6<;F/]J`@YBP049BTQ22DY8@P99BT3:DX48@P00acW8@PU
:@02:DX00b489BTYBP029BT2:DX29BT00bU:;F/e[@02<H`01Cg_>Lhe[BU:8@P012DY0RU:00HU:B48
8@PQ21cW9BT28@P022DY:DXYBRU:;F/aS2e[9BT28@P2:DX00bDY8@PQ20027>L38@P47>L36<H00acW
6<HLi`027>L00b487>LLi`047>L00aS67>LLi`057>L48@P01AcW6<HHaQS68@P00QcW00<HaQcW7>L0
0QcW00@HaR488@PQ20@Li`<HaP097>LHaQS66<HLiaBU6<HDYAS600LLi`038@PLiacW008Li`8HaP8L
i`036<HLib48008Q208Li`<HaP037>LQ224800@Q20047>LHaQS68@P35:D011cW8@PLiaS61AcW0QS6
00DLiaS67>LHaQcW00@Q208Li`056<HLiacW6<HLi`036<H00aBU6<HLi`027>L01aBU6<HHaQS67>LH
aQBU00<HaP045:DHaQS66<H35:D01AS67>LQ22487>L00QS600@LiaS66<HHaP<DY@8Li`8HaP8DY@03
6<HDYAS6008DY@<HaP8DY@036<HDYAcW008Li`DHaP@DY@046<HDYA245:D26<H45:D37>L56<H00acW
6<HHaP026<H01QBU6<H@Q1BU48@DY@8Li`036<HLiaS6008HaP055:DHaQS66<HDY@036<H25:D26<H0
1AcW5:DDYABU7>L00QS60QBU00HHaQcW7>LLiaBU48@25:D011S65:DDYA241QBU00DHaQBU48@DYA24
00@DY@036<HDYAS6008@Q08DY@8HaP<DY@056<HDYAS67>LHaP035:D56<H648@01ABU48@@Q1BU48@0
11BU0QS60QBU0Q2400@DYAS67>LHaP<@Q08<H`0448@DYA2448@436<448@00aBU48@@Q00448@01QBU
48@HaQcW6<HDY@8@Q08DY@0548@DYAcW6<HDY@0448@01ABU48@DYABU48@00`aS00<@Q1BU5:D00@aS
00001P@Q00048@00124000848@0;24848@@Q248e[GNmF]He[DHaDYA>L`04BU800dHa@Q16<@07AS42
@Q03?Nl2AS400dYB@Q124002?Nl01D8@?Nlmkd8@>Lh00cF]0Sg_00<icSF]>Lh00SF]00<aS3F]<H`0
0SF]00<icSg_@Q000T8@00@mkcW>>LhicPDe[@8icP06?NlicSW>>LhmkcW>0S6<0SF]00HaS3F]=Jdi
cSF]>Lh6=Jd5>Lh0148@?NlmkcF]0cW>13F]00@icSF]<H`aS0De[@04>LhaS36<<H`5=Jd2>Lh01c6<
:DX]Jbe[<H`e[C6<008YBP08;F/e[C6<;F/YBS6<=JdaS0<]J`04:DX]JbU::DX3;F/00bU:;F/]J`06
:DX00be[9BTQ20029BT00bU:8@PQ20029BT28@P00bDY:DXU:@058@P00acW8@PU:@029BT3:DX29BT2
:DX042DY:DXaS36<;F/aS3g_@Q0icRU:9BTYBRDY8@PYBRDY0RU:0R4800@Lib489BTQ20<U:@04:DXU
:Be[<H`2:DX01R489BTYBRDY8@PU:@<Q20047>LQ21cW8@P47>L012487>LLiaS60QcW0b4811cW00<Q
21cW7>L02AcW00<U:AcW7>L00aS60acW00<HaQcW6<H00QcW00@Q21cW9BTU:@8Q20<HaP065:DHaQS6
7>LHaQBU0QS60QcW00<HaR486<H00aS600<Q21cW6<H011cW00<HaQcW6<H00aS60R4800<Lib488@P0
0QS60QcW0b480QcW00<HaQcW8@P00QcW00<DYAS67>L00QcW00<HaQBU6<H00acW00<DYAS66<H00QS6
11cW0b4800<LiaS67>L00acW0QS600DDYA246<HHaR48008HaP8DY@8HaP035:DHaQBU00<DY@<HaP8D
Y@0348@HaQcW00<Q208Li`<HaP8DY@8HaP045:DHaQcW6<H35:D36<H45:D00aS65:D@Q0025:D28@P0
0acW6<HDY@027>L25:D011S65:D@Q1240QBU00HHaQBU5:DDYA245:D26<H27>L25:D26<H27>L00aS6
5:DDY@025:D01aS65:DDYA245:DHaQcW008HaP035:DHaQS600@HaP8DY@046<HDYABU5:D36<H01QBU
6<HHaQBU6<HDY@8HaP<Li`8DY@0548@DYAS66<H@Q0035:D248@45:D248@00aBU6<HDY@026<H25:D0
0a245:DHaP026<H00aBU6<HHaP026<H00a245:DLi`027>L011S648@DYAS60acW0QBU00P@Q1BU5:D@
Q0Q236<DYAS60a2400<DYA245:D00QS60QBU0Q2400THaQcW6<HDYA246<HDYA2436<00Q240`aS0Q24
0PaS00<@Q1BU48@01Q240aBU00<HaQBU6<H00QBU0a2400<DYAS65:D00QBU00<@Q1BU48@00Q2400@D
YA2448@<H`H@Q04<H`0000<000@Q12401@@Q0148@P@Q124<Hcg_OomNmcF]@Q1BU4icBU9>LdYBAS5:
DTHa00924003AS52448@00E24003?Nm6<D8@00=24096<@07@Q0icSW>>Li243g_>Lh00S6<00HicSg_
@Q0icS6<=Jd4<H`013F]<H`e[CF]0SW>00TmkcW>>LhmkdHa@Q0mkcF]?Nl00SW>00@e[CW>>Lhmk`8i
cP8e[@8icP04=JdaS36<=Jd2>Lh013F]<H`]Jc6<0Re[0S6<0SF]13W>00=243g_@Q000T8@13g_00Hi
cSF]>LhmkcW><H`2;F/01C6<>Lhe[CF]<H`00Re[0S6<00@e[CW><H`aS0@]J`PaS08]J`<aS003;F/U
:BU:008U:@04:DX]JbU::DX4;F/3:DX00b489BTU:@039BT38@P39BT28@P29BT012U:9BTQ21cW0R48
00<LibDY9BT00RDY00<Q22DY9BT00bU:00P]JbU:9BTYBRe[<H`YBS6<0T8@00DicRU:8@PU:B4800<U
:@LQ208U:@06;F/aS2e[;F/YBRDY0Re[0RU:0R4800<U:B489BT012480bDY00HQ21S66<HHaQcW8@P4
7>L38@P00acW8@PQ20037>L00aS67>LQ20028@P01QcW6<HLib487>LQ208Li`8Q208Li`068@PU:AcW
6<HDYAS60b481AcW00<HaQBU6<H00acW0aBU0QcW0R4800@LiaS65:DHaP8Li`8HaP037>LHaQBU008H
aP078@PLiacW8@PLib487>L011S60QcW00@U:BU:8@PQ208Li`036<HLiaS6008HaP045:DHaQS66<H2
7>L26<H67>L00aS68@PQ20037>L00b487>LLi`047>L96<H011BU6<HDYABU0aS600LDYA245:DDYAS6
5:D@Q0035:D011cW8@PQ22480aS60QcW00HHaQBU5:DDYAS65:D26<H37>L29BT01AcW6<HDYABU6<H0
0QBU11S60QBU00DHaQBU6<HDYAS6008Li`8DY@<HaP035:DHaQS6008HaP8DY@047>LQ22486<H25:D2
6<H00aBU6<HHaP036<H01ABU6<HHaQBU48@00QBU00`HaQ245:DLibDY7>LDYA245:DHaQBU6<H25:D0
0aS65:D@Q0035:D46<H00acW6<HDY@025:D26<H35:D00aS65:DDY@035:D248@00aBU7>LQ20027>L0
1QBU48@DYABU48@DY@8HaP<DY@036<HDYABU00<DY@036<H@Q1BU008HaP045:D@Q1246<H28@P01aS6
5:DHaQBU6<HLiaS6008@Q08<H`D@Q00336<@Q124008HaP<DY@0748@DYAS67>LHaQ2436<00a2400<D
YA2448@00`aS00P@Q0aS36<<Ha245:DHaQBU0PaS00H@Q1BU5:D@Q1BU7>L26<H248@01AS65:DDYABU
6<H00QBU0Q240aBU11240`aS00<@Q1BU5:D00@aS000312400`001240000212402@Q200048@Q2?Nmo
oekg=Je6<@04CW<4BU82AS45@Q0014Ha@Q12448@0Sg_0d8@00A:DTHa?Nm240<icP8mk`03=JdaS3W>
008mk`04>Lhe[CF]=Jd3<H`5=Jd2?Nl01d8@?NlicSW>?Nm243g_008icP03=JdicSW>00@icP03=Jdi
cSW>008icP03<H`e[CF]00<icP0:=JdaS2e[;F/e[C6<;F/aS3F]>Lh3?Nl00cW>?Nm24002@Q02?Nl0
1SW>?NlmkcW>=JdicP8e[@04<H`]Jc6<<H`2=Jd01c6<;F/]Jc6<;F/e[C6<008e[@04;F/aS2e[;F/8
<H`013F]<H`]Jbe[0S6<0Re[00<U:BU::DX00Re[00<U:BU:;F/00S6<00<YBRe[:DX00bDY0RU:1bDY
0R481BDY1R4800HU:B489BTU:BU:9BT4:DX03Re[:DXYBRU:;F/e[Cg_>Lhmkc6<;F/YBQcW8@P39BT2
8@P00bDY8@PU:@028@P00bU:9BTYBP02;F/2:DX29BT02Be[:DXU:BU:9BTQ22DY7>LQ20029BT28@P0
0acW8@PQ20026<H27>L012487>LLib4821cW0QS611cW0R480QcW0R4800@Lib488@PU:@<Li`039BTL
iacW008HaP<Q20037>LHaQcW00<Li`8HaP8DY@036<HLiacW008DY@046<HLiacW7>L26<H37>L66<H2
7>L36<H38@P27>L01ABU6<HLib489BT00R4800<U:B487>L00QS600<LiaS66<H01QS61AcW0QS600@L
ib487>LLi`8HaP<Q20047>LHaQcW8@P27>L26<H25:D37>L00aS65:DDY@036<H45:D01QS65:DHaQS6
5:DHaP<DY@036<HLiacW008HaP067>LHaQcW6<HLiaBU0QS600DLiaS66<HDYAS600@Li`8HaP8DY@06
6<HDYABU5:D@Q1BU0QcW0QS60QBU00@HaQBU6<HHaP<DY@8HaP<DY@046<HDYABU6<H27>L00aS65:DD
Y@026<H37>L35:D26<H01aBU48@DYABU6<HDYA24008HaP037>LQ21S600@DY@8HaP095:D@Q1BU5:DH
aQBU6<HDYAS6008DY@036<HLiacW008DY@036<HLiaS6008@Q08DY@0348@HaQBU00<DY@0548@HaQS6
7>LHaP075:D46<H011BU48@DYABU0QS60QBU00<@Q1BU5:D00aS600DDYAS68@PQ21cW008DY@047>LH
aQBU5:D248@00aBU48@@Q00548@25:D26<H35:D00a245:DLi`026<H01A2436<@Q1245:D01A2400@<
Ha2448@@Q08<H`0548@DYA2436<@Q0025:D011245:DDYAS60aBU0Q240aBU00<HaQBU5:D00QBU00<H
aQBU48@00Q2400@DYA2436<<H`<@Q04<H`0000<000@Q12401@@Q00X8@P@Q124<HcW>OomW>CW>CW=B
U0E:DP96<@05BU96<DYBAS5:DP02AS400d8@AS56<@02@Q000cg_@Q124002@Q000dHa@Q0icP02=Jd2
>Lh013g_>Lhe[CW>0T8@0SW>00<mkcF]=Jd00S6<0SF]00DicSg_>Lhmkd8@008mk`05>Lhe[CF]=Jdm
k`02>Lh01Sg_>LhicSg_>Lhmk`8icP04=JdicSW>=Jd3>Lh01Cg_>LhicSF]<H`013F]00LaS3F]>Lhm
kcW>=JdaS005>Lh2?Nl01T8@?Nlmkcg_=JdicP8e[@8aS004=JdaS3F]<H`3;F/2<H`3;F/2<H`3;F/0
136<=Jde[CF]0S6<00<e[C6<;F/00Re[00<aS2e[:DX00RU:0Re[00<YBRDY9BT01RU:00LU:BU:8@PU
:B48:DXU:@028@P29BT28@P39BT022489BTYBRU:9BTYBRe[9BT38@P00bU:9BTU:@028@P012DY:DXU
:B480RDY12U:00DaS3F]>Lhmkc6<008]J`8U:@8Q20039BTYBR4800<Li`<U:@<]J`PYBP049BTQ22DY
9BT38@P01bDY:DXU:BDY8@PLib4800LLi`<Q20DLi`@HaP8Li`8Q20037>LQ2248008Q20<Li`<U:@03
7>LQ2248008Q20077>LQ22489BTQ21cW6<H00QcW00<HaQBU6<H00acW00/DYAS66<HHaRDY:DXU:AcW
6<HLib48008Li`056<HQ21S66<HDY@036<H021cW8@PQ22DY8@PLiaS65:D26<H01QcW8@PQ22DY:DXQ
20LLi`036<HLiaS600@HaP035:DHaQcW00<Li`048@PLiacW7>L28@P00bDY7>LLi`057>L011245:D@
Q1240QS600@Lib486<HHaP8DY@8HaP035:DHaQS6008@Q0035:DHaQS6008DY@0548@DYABU6<HLi`02
6<H011BU6<HHaQS60QBU00<@Q1BU6<H00QS60acW0R4800@LiaS65:DDY@@HaP035:DHaQS6008HaP8D
Y@8@Q08HaP057>LDYAS66<HLi`026<H00aBU6<HHaP026<H00aBU6<HHaP046<H25:D011S65:DLiacW
0QS600DDYA2448@DYA2400<HaP8@Q0055:DHaQS65:D@Q0025:D01QS65:DDYABU48@DY@<Li`036<HD
YABU00DHaP037>LHaQS6008@Q0035:D@Q1BU008DY@0548@DYABU48@DY@036<H01QBU7>LHaQBU6<HD
Y@@HaP8Li`038@PHaQcW008DY@0348@DYABU00<DY@<HaP035:DHaQBU00<DY@<HaP0:7>LHaQS65:D@
Q0aS48@DYA245:D248@01QBU48@DYABU6<HDY@8@Q0055:DHaQBU5:DHaP045:D01a245:D@Q1245:D@
Q1BU00@@Q0@DY@D@Q0055:D@Q1BU48@DY@026<H01QBU48@@Q1245:DHaP8DY@8@Q0@DY@0348@DYA24
008@Q04<H`4@Q04@Q0000`@Q00<000@Q00000P@Q00X8@P@Q1248@SW>OomW>Cg_BU9BU0=:DP04CW=:
DTYBAS42BU82AS42BU800dHa@Q124002AS43@Q03?Nl024Ha?NlmkcF]>Lhmkd8@?Nl3>Lh3?Nl2>Lh0
0cF]>LhicP02<H`00cF]>LhicP02?Nl01CW>?Nlmkcg_>Lh00cF]13W>00DmkcW>?NlmkcF]008icP03
?NlicSW>008aS007>Li2448@?NlaS3F]?Nl00SW>00L]JbU:<H`icSg_>LhaS002=Jd00c6<=JdicP02
?Nl023W>@Q16<D8@?NlicSg_>Lh3<H`00cF]>Lhe[@02<H`3;F/01S6<;F/aS2e[<H`]J`8aS004;F/a
S2e[<H`3=Jd013W>;F/]Jbe[0c6<00<]JbU:;F/01RU:0Re[12U:0bDY00<YBRDY9BT00QcW00<Q22DY
9BT00R482BDY0b4800DU:BU::DXU:B4800@U:@03:DXU:BDY008YBP09;F/YBS6<;F/e[CW>?Nle[BU:
00@Q20059BTQ22488@PLi`028@P00bDY:DXU:@02:DX2;F/5:DX012489BTU:BDY0R481BDY1B480acW
00<Q21cW7>L00QcW00<Q21cW8@P01AcW0QS600@LiaS66<HLi`@Q20057>LQ22488@PLi`058@P011cW
6<HLib480RDY0QcW00<HaQcW7>L00QcW00`DYAS65:DHaQcW6<HLiaS67>LQ22DY8@P47>L011S67>LH
aQcW11S600P@Q1cW8@PYBRDY8@PHaQcW0QS600@LiaS67>LQ208U:@8Q208Li`078@PLiacW5:DHaQcW
6<H00QcW00<HaQcW7>L00QS60QcW00<Q21cW7>L00acW124811cW0QS600DDYA245:DDYAS600<Li`04
6<HDYAS65:D26<H25:D00a245:DHaP026<H00aBU48@DY@026<H00aBU6<HHaP066<H65:D01acW6<HL
iacW9BTQ21cW008HaP047>LHaQS65:D26<H01AcW6<HHaQS65:D00a240aS600DDYAS67>LLiaBU00LH
aP045:DHaQS67>L26<H25:D26<H27>L00aS65:DDY@045:D01QS65:DDYA245:DHaPDDY@0448@HaQS6
6<H25:D27>L00aS648@DY@026<H35:D46<H35:D01Q245:DDYABU6<HDY@@@Q0046<HLiacW6<H25:D4
6<H011BU6<HLib480acW0aBU00@@Q1BU48@HaP8DY@046<HLiaS648@25:D26<H01ABU48@DYABU6<H0
0QBU00D<Ha245:D@Q1S600<DY@<@Q0@DY@8@Q0036<HDYAcW008HaP045:D@Q1245:D248@25:D00a24
36<<H`025:D01a2436<DYABU6<HDY@aS00D@Q0035:DHaQBU008DY@0548@DYA245:D@Q0025:D00a24
5:DDY@035:D548@00`aS48@@Q00124800003124000@Q00D48@0924848@0036<mkgooHaPicTHa009B
U003CW=BU4YB00A:DP03AS5:DTYB00A:DP96<@=:DP04@Q0mkcW>?Nl2@Q000cW>=Jde[@09>Lh00cg_
>LhicP03=Jd00cW>=Jdmk`02>Lh2AS42@Q001cF]>LhicSW>?NlicSF]00<icP8e[@07>LhmkcW>?Nli
cSg_=Jd00SW>0cg_00@icSg_?Nlmk`8icP8e[@<icP04=JdaS36<>Lh5=Jd2>Lh2=Jd00c6<=JdicP02
>Lh2<H`3=Jd00c6<;F/]J`02<H`00be[<H`aS003=Jd3;F/2<H`00cF]<H`aS002<H`00cF]<H`YBP02
:DX01Re[<H`]Jbe[:DX]J`8U:@8YBP8]J`8YBP8U:@05:DXU:BDY9BTYBP048@P59BT38@P29BT2:DX0
0be[:DXQ20059BT2:DX38@P00bDY:DXU:@039BT3:DX01S6<?NlicSF]:DXQ208YBP038@PU:BU:008U
:@8Li`8Q20@YBP069BTYBRe[;F/YBRDY0RU:0RDY00@Q22U:9BTU:@8YBP8U:@8YBP049BTQ21cW7>L3
8@P37>L00b489BTU:@027>L011BU6<HDYABU0QcW00DQ21cW7>LHaQcW008Q208Li`056<HLib489BTQ
20029BT01R487>LLiacW8@PLi`8Q20087>LHaQcW7>LQ21cW6<HDY@8HaP057>LHaQS66<HLi`028@P2
7>L28@P01BDY8@PQ21cW9BT00QcW0QS60QBU00LLibDY:DXU:AcW6<HLi`046<H012487>LU:BDY0RU:
00DU:B486<HDYAS600TLi`036<HLiaS600@Li`036<HLiacW00@Q208HaP0;5:DLib487>LDYA246<HL
iaS67>LHaP037>L26<H65:D26<H65:D00aS65:DLi`056<H25:D011245:DDYAcW0QS600<Lib487>L0
0QBU0QS600@@Q1BU6<HHaP<DY@097>LDYABU6<HLiaS65:D@Q1S600HDY@066<HDYABU5:DHaQ240QBU
00<HaQcW8@P00QcW11BU00@HaQcW7>LLi`@DY@8@Q00436<DYABU6<H75:D00a245:DHaP025:D00aS6
7>LLi`026<H00aBU7>LHaP026<H00acW6<HHaP025:D26<H27>L011BU48@@Q1240QS60aBU00HHaQcW
7>LLiaS65:D26<H00b487>LLi`037>L26<H011BU6<HHaQBU0a2400DDYAcW6<HHaQ2400@DY@0648@D
YABU5:D@Q1BU0QS611BU0Q240QBU0a2400<DYAS65:D00QBU112400<DYA2448@00aBU112411BU0QS6
0QBU00<@Q1S65:D00QS600<DYA2448@00aBU00<@Q1BU5:D00QBU00<@Q1BU5:D00a2400<DYAS648@0
1aBU0PaS0Q240ABU00021240100012448@000P@Q00T8@P@Q1248@SW>OomW>CW>BU800Tic00=BU4ic
CW<01DYB00=6<DYBAS400TYB0THa00=:DTHaBU800THa1Sg_0SW>00He[CW>>LhicSg_=Jd2>Lh2?Nl3
>Lh3=Jd3>Lh01Cg_@Q1244Ha?Nl02CW>00<aS3F]=Jd00cW>0Sg_13W>00DmkcW>>LhicSg_00924003
?NlicSF]00<e[@<icP03=JdaS36<00<e[@@icP04=JdicSW>>Lh6=Jd00c6<;F/]J`06;F/5<H`2;F/2
<H`2=Jd2<H`5;F/2:DX00be[<H`]J`05:DX2;F/2:DX39BT3:DX00bDY8@PU:@028@P49BT58@P29BT0
12e[:DXYBRU:0R4800<U:B489BT01bDY0b480bU:00TU:Be[>Li243W>:DXU:BU:;F/00RU:0bDY00DQ
21cW8@PQ22DY00<YBP039BTYBRe[00DYBP<U:@@YBP039BTYBRDY008YBP8U:@8Li`038@PLib4800@L
i`8U:@8Q20036<HDYAS6008Li`8HaP<Li`036<HLiacW008Li`048@PLib488@P29BT012487>LQ21S6
0QcW0R4800<Lib487>L00acW0QS60acW0aS600<LiaS67>L01AcW0b4800DU:B487>LLiaS6008Li`05
5:DHaQcW8@PU:@027>L02aS65:DHaQS67>LHaQcW8@PU:BU:;F/00RU:00<Q21S66<H01AcW0R4800<L
iaS67>L011cW00<Q21cW6<H00QcW00HQ22DY7>LQ21cW6<H37>L011S67>LHaQS60QBU00DHaR487>LL
iaBU00<Li`035:D@Q124008DY@047>LHaQS66<H25:D01QS65:DDYAS67>LHaP8DY@<HaPDDY@046<HL
ib487>L46<H00aBU6<HDY@025:D36<H00a245:DHaP036<H01ABU6<HDYABU48@01QBU0QS600<DYA24
5:D00QBU0acW00@HaQBU5:DHaP8DY@046<HLiaS66<H25:D548@35:D01Q245:DDYABU48@DY@8HaP8@
Q0035:DLiaS6008Li`<HaP8DY@046<HLiacW6<H35:D46<H35:D00a246<HHaP035:D27>L26<H25:D2
6<H27>L01b487>LHaQS65:DHaQBU008HaP095:D@Q12448@HaQcW6<HDYA24008DY@056<HDYA2448@D
Y@036<H00aBU48@DY@0248@45:D448@01ABU6<HLiaS65:D00Q2411BU0a2400<DYA2448@011BU00<@
Q1BU5:D00QBU0Q2400<DYAS65:D01aBU00<@Q1BU5:D011BU0a2400@DYA2448@@Q0@DY@0348@DYABU
00<@Q04<H`0000D000@Q12448@0000<48@0:248000@Q248icWooHaPicTHaCW<2BU800dicBU9:DP02
BU800dicBU9:DP04AS42BU8024HaBU9:DTYBAS5:DTHa@Q02?Nl013W>?NlicSg_13W>00<mkd8@@Q00
0d8@0SW>00<e[C6<<H`00SF]00<icSg_>Lh00Sg_00A243g_>LhicP<mk`07>LhmkcW>=JdaS3F]?Nl0
0SW>00<aS3W>=Jd00cW>00<mkd8@@Q000d8@1Sg_00De[CW>@Q1243g_008aS003=JdaS3F]008icP8e
[@06<H`]Jc6<<H`e[C6<0Re[00@aS3F]>LhicP<aS003=JdaS2e[008]J`8aS0<]J`8aS08]J`8aS003
;F/YBRU:008YBP09;F/aS36<;F/YBRDY:DXU:BU:00@aS08]J`03:DXU:BDY008U:@<YBP8U:@038@PU
:B4800<U:@078@PU:B488@PU:B48:DX01BDY00<YBRDY9BT00bDY00@YBRDY8@PQ20<YBP099BTYBRDY
7>L]Jcg_BU8mkbU:00@U:@038@PU:B48008Q20047>LU:BU:;F/38@P01BU:;F/YBRU:;F/012U:00<U
:BU::DX00RDY0RU:0Re[0R4800@HaQcW8@PU:@8YBP069BTQ22488@PU:BU:0RDY00<YBR487>L00QS6
00DQ21cW6<HHaQcW008HaP8Li`HQ20047>LHaQS66<H27>L00aS68@PU:@029BT011S67>LLib480QcW
0QS600<Lib487>L00QcW00@HaQcW7>LHaP@Li`8Q20<U:@038@PLiacW00<Li`038@PLib48008Q208L
i`066<HLiacW6<HLiaS60R4800DU:BU:9BTYBRDY008Li`055:DHaQS66<HQ20027>L02AS67>LLibDY
8@PLiaS67>LHaP027>L01AS69BTU:BU:9BT00aS60b4800DHaQ245:DLibDY008aS0039BTQ21S600@H
aP035:DHaQ24008DY@<HaP065:D@Q1BU6<HLiaS60QBU00XHaQBU5:DDYAcW6<HDYA245:DLi`<HaP07
5:D<Ha245:DHaQcW6<H00QcW00@HaQBU5:DDY@<HaP8DY@036<HLib48008Li`@HaP0;48@DYAS68@PL
iaS648@DYA245:D@Q0025:D01aS65:D@Q1BU6<HLib48008Li`DDY@0348@DYABU008HaP035:D@Q124
00<DY@0348@DYA24008DY@8@Q0035:D@Q12400<DY@<Li`045:DHaQcW6<H25:D26<H00aBU48@DY@02
5:D01aS648@@Q1BU6<HLiaS6008DY@8HaP057>LHaQS66<HLi`025:D00aS67>LHaP0248@010aS6<HH
aQcW0QBU00DHaQcW7>LDYA24008DY@0348@DYABU00<@Q0085:D@Q1BU5:D@Q1BU48@<H`8@Q0<DY@03
48@DYABU00HDY@8@Q08DY@8@Q0045:DHaQ2436<248@55:D00aS65:DHaP026<H01AcW6<HHaQBU6<H0
0QBU00<HaQ245:D011S600@@Q1BU48@DY@@@Q0036<HDYABU008@Q0045:D@Q1245:D248@136<000<4
8@0300048@@Q00848@0824848@@Q36<icWooHaPicPa:DP03AS5:DTHa00=6<@9:DP07AS5:DTYBBU96
<D8@AS400Sg_00<e[CW>>Lh01SW>00`mkd8@AS56<Cg_>LhaS3F]>LhaS3F]<H`2>Lh00cg_@Q0mk`02
@Q001CW>=Jde[CW>?Nl013W>0S6<00<e[Cg_?Nl00SF]0SW>00<e[CW>>Lh00T8@00=6<D8@AS400Sg_
00DicSg_=Jde[Cg_00924003>LhaS36<008e[@@icP04=Jd]Jc6<;F/4<H`00be[<H`e[@02>Lh00cF]
<H`e[@07<H`4;F/0136<;F/]Jc6<0Re[00LYBRe[:DXU:Be[:DXaS002;F/29BT00bU:;F/]J`02;F/2
<H`2:DX02BDY:DXU:BDY:DX]JbU:9BTQ20049BT2:DX01BDY8@PLib489BT00RU:0RDY00<YBRDY9BT0
12DY00<Q22DY9BT01RDY0R480RDY00D]JcW>>LhicS6<008YBP059BTQ22DY8@PU:@028@P012DY8@PU
:BDY0bU:00@U:BU::DX]J`8YBP8]J`<YBP039BTYBRU:00<YBP059BTYBRDY8@PHaP027>L39BT01B48
9BTU:BDY8@P012DY0acW00@Q21cW7>LDY@8HaP@Li`038@PU:B4800HLi`<HaP8U:@06:DXQ22487>LQ
21S60QcW00HQ21cW6<HLib487>L26<H27>L28@P01acW6<HDYAcW8@PU:BU:008Q20049BTLiaS66<H2
7>L28@P01AcW8@PQ21cW6<H00QcW00HQ21cW7>LLib489BT2:DX00bDY8@PQ20027>L26<H00acW6<HL
i`077>L01b487>LLiacW6<HLib4800<U:@068@PHaQcW7>LQ21cW11S600HDYBDY;F/]JbDY5:D56<H2
5:D01A245:DHaQcW6<H00aBU0QS60QBU0QS600<DYAS65:D00aBU00<HaQBU5:D011S60aBU0QcW0QBU
00DHaQBU5:D@Q1BU00@HaP047>LHaQcW6<H27>L36<H35:D26<H00acW5:DDY@025:D00a246<HHaP02
6<H011BU48@DYAS60QcW11S60QBU0a2400<DYA2448@01aBU0Q2400<<Ha245:D00QS600@DYA2448@@
Q08HaP045:DHaQcW6<H25:D00aS67>LLi`025:D00aS648@DY@025:D011S65:DDYABU11S600<DYAS6
6<H00aS600<LiaS65:D00aS600@DYA245:DDY@8HaP8DY@036<HLiaS6008@Q0<DY@8@Q08DY@046<H@
Q1BU48@25:D011S648@@Q1240QBU00@@Q0aS48@HaPPDY@8HaP@@Q0055:D@Q12436<@Q0025:D26<H2
5:D248@25:D36<H01AcW6<HHaQBU48@00QBU00@LiaS65:D@Q08DY@L@Q0035:D@Q0aS008@Q08DY@03
48@DYABU004<H`0000<000@Q12400P@Q00l000@Q1248@P@Q0008@SF]OomS63g_BU9>LdYBCW<00TYB
0THa0TYB00=>LdYBBU800dHa0TYB00A6<DYBAS56<@A2408mk`8icP09?NlicSF]>LhmkdHa@Q0icSg_
00924003?NlicSg_008mk`8icP8e[@8icP06?Nle[CF]=JdicSg_0SW>00De[CW>@Q0mkcF]008aS004
=Jdmkcg_>Lh2<H`03CF]?NlicSg_BU9>Ld8@>LhmkdHaBU96<D8@008mk`8icP06@Q0mkcg_=JdaS3g_
0SW>00@mkcW>>Lhe[@8aS004=JdaS36<;F/:<H`01Be[<H`e[CF]>Lh00S6<0Re[00<aS2U::DX00RU:
0S6<00@]JbU:9BTYBP8]J`03:DX]JbU:008U:@05:DX]Jc6<<H`e[@03<H`3;F/5:DX01BDY8@PQ2248
7>L00R480RDY00@Q22DY9BTQ208U:@03:DXU:AcW008Q208YBP8U:@05:DXU:BU:9BTQ20049BT02b48
:DXU:B489BTYBSF]>Lhe[Be[:DX00RDY00<Q22DY9BT00RU:0RDY0RU:0R4800DU:Be[:DXYBRDY00HY
BP8U:@8Q208U:@0;8@PLib48;F/U:AcW6<HQ22e[9BTQ20029BT00b489BTU:@029BT01BU:8@PLib48
:DX00Re[00<Q21S66<H00aS60QcW00<Q22DY:DX00R481AcW2R480QcW00@HaQcW8@PLi`8HaPPLi`05
8@PU:B488@PLi`039BT28@P011S67>LLiacW0R480QcW00DQ21cW7>LLiaS600HLi`8U:@078@PLiaS6
7>LQ22DY8@P00QcW00<HaQBU6<H01AcW00LQ21S66<HDYAS68@PLi`029BT28@P57>L01AS67>LDYABU
<H`00THa00@aS1246<HLi`<DY@056<HDYAS66<HDY@026<H25:D011245:DHaQcW11S600@DYAS66<HD
Y@8@Q0055:DHaQcW7>LHaP025:D26<H248@35:D56<H00a245:DDY@026<H01ABU7>LLib487>L00QS6
00<LiaS66<H00QS600<DYAcW6<H00QS60QBU0aS60QBU0Q2400<DYAS67>L00QS600@DYAS65:DDY@8@
Q0<DY@0448@HaQBU48@25:D01A2436<<Ha245:D01A2400D<Ha2448@DYA24008DY@046<HDYA245:D3
48@45:D00a245:D@Q0025:D00aS65:DHaP025:D86<H011BU48@DYAS60aBU00@HaQBU5:DDY@DHaP@D
Y@8@Q00336<@Q124008@Q08<H`0348@DYAS600<@Q0035:D@Q124008@Q0045:DHaQ2448@25:D26<H3
5:D011245:DHaQS60a240QBU00@@Q1BU5:DDY@<@Q0<DY@036<HLiaS6008HaP037>LHaQS600HDY@8H
aP8DY@0448@DYA2448@25:D348@00aBU36<@Q00248@136<000848@0300048@0000<48@08248000@Q
36<e[G_NG_LicPQ:DP04AS5:DTYBCW<2BU84AS4014YBAS5:DT8@14Ha00=243g_?Nl00Sg_00@icSF]
>Lhmk`924003?NlicT8@00924005?NlicSW>>Lhmk`02>Lh2=Jd3>Lh00c6<=Jde[@05>Lh00cg_>Lhe
[@02<H`013W>?NlmkcW>0SF]0SW>00De[D8@CW=>Ld8@008icP03AS5:DTHa00924004>Lhmkcg_?Nl4
>Lh01C6<=JdicSW>?Nl00SW>0c6<0cF]0Re[00<aS2e[<H`01S6<0SF]00<icSF]<H`00S6<00D]Jc6<
:DX]JbU:008]J`8aS0@YBP049BTYBRU:;F/4:DX2<H`01be[<H`]Jbe[<H`]JbU:00<]J`03:DXQ22DY
00@U:@8Q208U:@03:DXU:BDY00<Q20049BTQ22DY8@P29BT3:DX99BT28@P29BT00bU:9BT]J`02>Lh0
13F]:DXQ22480bDY0R4800DU:BU::DXYBR48008U:@8YBP8U:@03:DX]JbU:008YBP<U:@048@PU:B48
7>L28@P01RDY:DXU:B487>LQ20<U:@@Q20@YBP049BTQ22DY9BT2:DX01BDY7>LLiaBU6<H00QcW1R48
00TLib488@PLib487>LQ21cW8@P00QcW00HU:BU:9BTU:AcW6<H37>L011S67>LLiacW0aS60b480QcW
00<Q21cW7>L00RDY00HYBRDY8@PLiaS67>L38@P012DY8@PQ224811cW00<HaQcW8@P00QcW124800`L
ib487>LLib487>LQ22DY7>LHaQBU6<H28@P57>L26<H01AcW8@PU:BDY8@P00QcW00<HaQcW6<H00QS6
00XLiaBU48@aS4YBCW<icQ245:DLi`@DY@036<HDYAS600<HaP035:D@Q1BU00@DY@8HaP0:7>LHaQS6
6<HDYA245:DHaQcW6<H25:D26<H00aBU48@DY@025:D56<H45:D36<H011BU6<HQ21cW0QS60R4800DL
iaBU5:DHaQcW008HaP8DY@<HaP035:DHaQBU008HaP0348@DYABU008Li`065:DHaQS66<HDYA240QBU
0Q2411BU00<@Q1BU48@00a240aBU00<@Q0aS36<00a240QBU00<HaQBU5:D011BU00<@Q1BU5:D00aBU
00<@Q1BU5:D00a240QS600<DYAS66<H00QcW00DHaQBU6<HDYAS600@DY@066<HDYA245:D@Q1BU1aS6
11BU0Q240`aS00@@Q1BU5:DHaP8@Q0<DY@8@Q0035:D@Q124008@Q08DY@046<HDYAS65:D26<H25:D2
48@35:D248@25:D448@01ABU48@DYA245:D00QS600HQ21cW7>LLiaS65:D248@46<H25:D00aS65:DD
Y@0248@00aS65:D@Q00448@011BU48@@Q1240@aS00000`0012448@021240100012448@Q20P@Q00P8
@SW>OomS63W>AS5:DTHa2DYB00=6<DYBAS4024YB00A6<DYB@Q1240Dmk`06>LhmkdHaAS5243g_0T8@
00@mkcF]=Jdmk`9240LicP8e[@@aS0<e[@8aS003=JdicSF]008e[@<icP8aS08icP07AS5:DTHa@Q0m
kcF]>Lh00cg_00<icSF]>Lh00cW>00PmkcW>=Jde[Cg_@Q16<Cg_0SW>0S6<00<]Jc6<=Jd01cF]0S6<
0be[0c6<00@]JbU::DX]J`<aS0<]J`03<H`]JbU:00<YBP04;F/YBRU:;F/2:DX00bDY:DX]J`05;F/0
1S6<;F/]Jbe[:DX]J`8YBP8]J`04:DXU:AcW7>L38@P00bDY8@PU:@038@P27>L29BT00bU:9BTQ2004
9BT00b489BTQ20029BT00bU:9BTQ20039BT012489BTU:BU:0SW>00<aS2U:7>L00bDY124812U:00@U
:BU::DXYBPDU:@047>LQ22DY7>L28@P29BT78@P00bDY8@PQ20028@P00acW9BTQ20049BT28@P00acW
8@PQ20078@P27>L02R489BT]Jc6<9BTQ21cW6<HLib480acW0b4800DLib489BTU:B48008Li`046<HD
YAcW8@P37>L26<H00acW8@PU:@037>L28@P01QcW6<HLibDY:DXU:@<Li`0:9BTQ22488@PU:B487>LH
aQcW6<H27>L36<H00acW6<HQ2003:DX01QcW6<HLiacW6<HQ20@Li`056<HLiaS67>LQ20027>L26<H2
7>L01AS68@PU:BDY8@P00QS600/LiaS67>LHaR486<H@Q36<CW=BU3g_008DY@046<HDYAS66<H25:D2
6<H00aBU6<HHaP026<H25:D56<H248@011BU6<HHaQS60QBU00@HaR487>LHaP8DY@<HaP@DY@8HaP03
5:DHaQBU00<DY@056<HDYABU6<HDY@027>L46<H01AcW6<HHaQBU6<H00acW0QBU1AS60QBU1AS60QBU
00<@Q1BU48@00Q2400@DYAS65:DDY@<@Q0035:D@Q0aS00@@Q00836<DYA245:D@Q0aS48@<H`8@Q003
5:D@Q1BU00<@Q0055:D@Q12448@<H`0548@26<H35:D26<H25:D01a245:DDYAS65:DHaQBU00<@Q08D
Y@0648@HaQBU48@DYAS60QcW00LDYA246<HHaQBU48@DY@0248@00`aS48@@Q00448@00aBU48@DY@07
48@55:D248@00aBU6<HDY@0248@01ABU6<HHaQBU6<H011BU0aS600<@Q1BU48@00Q2400<DYAcW7>L0
0acW00@DYA245:DDY@8HaP0348@DYAS600@DY@0348@DYABU008HaP035:D@Q1BU008@Q0035:D@Q1BU
004<H`000`@Q00<000@Q12400P@Q00P8@P@Q000<HcF]OomS63W>3DYB00=6<DYBAS4024YB00=6<D8@
@Q000d8@00<mkcW>>Lh00Sg_00=6<D8@?Nl00T8@00DmkcW>>LhicT8@00Hmk`8icP05<H`e[CF]=Jda
S002=Jd2<H`2=Jd01C6<=Jde[CF]?Nl00cW>00daS3F]>LhicT8@BU96<D8@>Lhe[CW>?Nm24003>Lh0
1cF]?NlicSW>?NlicSF]008icP03?Nm243g_008icP06=JdaS36<<H`e[C6<0cF]00<aS3F]<H`00c6<
00<]JbU:;F/00S6<0Re[00<YBRe[<H`00S6<0Re[00<aS2e[<H`00bU:0Re[00PYBRDY:DX]JbU:8@PU
:BU:0Re[00DYBRe[;F/]Jc6<00D]J`DYBP<Q20037>LQ22DY008U:@038@PLiacW008Li`048@PU:BDY
:DX38@P00bDY:DXU:@038@P00bDY8@PU:@02:DX49BT02R48:DXaS3F]<H`]JbDY8@PU:BU:0RDY0R48
0RDY00@YBRDY9BTQ20@U:@<Q2003:DXU:BDY00LQ208U:@038@PU:BDY00<Q20039BTQ22DY00@Q2003
9BTYBRDY00@Li`<U:@8Q20037>LU:B4800<Q2006:DX]JbU:9BTLiaS60QcW00<Q21cW7>L00QcW0R48
00DLib488@PLib4800@Li`076<HLiacW7>LHaQBU7>L00b480QcW00<U:AcW8@P00QcW00DQ22DY8@PU
:AcW00<Q208U:@@Li`8HaP045:DHaQS66<H27>L021S67>LYBRe[9BTLiaS68@P27>L012487>LLiacW
0aS600DLiaS67>LLiaS6008Li`8Q208Li`048@PYBRU:7>L36<H37>L25:D0136<@Q16<CW>0QcW00@H
aQBU6<HDY@8HaP<DY@036<HDYAS600<DY@8HaP037>LHaQBU008DY@8HaP8DY@LHaP8Li`8DY@8@Q004
6<HLiaS66<H45:D00a245:DHaP035:D77>L01AS65:DDYAS67>L00R4800LHaQBU6<HHaQcW6<HDY@02
6<H02A245:DDYAS67>LHaQBU6<HDY@0348@00aBU48@@Q0025:D448@011BU48@<H`aS0Q2400TDYA24
48@<Ha245:D@Q1BU48@00PaS0a2400DDYA2448@@Q0aS008@Q08DY@8@Q0/DY@036<H@Q12400DDY@05
6<HDYABU5:D@Q0035:D01AS67>LHaQBU6<H011BU1a2400@<Ha2448@DY@8@Q0065:D@Q12436<@Q1BU
11240aBU00@@Q1BU5:DHaP<DY@<HaP@@Q0046<HDYABU6<H35:D021245:D@Q1245:DHaR487>L26<H2
5:D021S65:DHaQcW6<HDYA2436<25:D00a245:DHaP026<H45:D00a245:D@Q00136<00005124000@Q
1240000312402`Q200048@Q2>LikgUkg>Li6<DicAS400TYB0Tic0TYB00=6<DicCW<00dic00=BU4ic
CW<00dHa0TYB0THa00=244HaAS400dHa0Sg_0cW>13g_00<icSg_?Nl00Sg_00=243g_>Lh00SW>00@m
kcW>>LhicP8e[@07;F/e[CF]=JdaS2e[<H`00cF]00<aS3F]=Jd01cW>00LmkdYBBU9243W>=JdicP03
?Nl00cW><H`e[@02=Jd3>Lh01Cg_>Lhe[CF]>Lh00Sg_00<icSF]>Lh00SF]00<aS3F]=Jd013F]0Sg_
00@icSF]=Jde[@8aS0<]J`<YBP03;F/YBRe[008]J`8e[@03<H`]JbU:008]J`8YBP069BT]JbU::DXa
S3F]0S6<00<U:BU::DX00RU:0Re[0RU:00<U:BU::DX00RU:2bDY0b482bDY00@Q22DY8@PQ20@YBP8U
:@04:DXQ2248;F/2<H`2:DX0136<;F/U:AcW0b4812DY00@Q22DY8@PU:@8Q208U:@038@PU:BDY00@Q
20<U:@038@PLibDY008U:@8Q208U:@<Q208U:@8Q20039BTQ21cW008Li`8Q20<Li`LQ208Li`8U:@<Q
2005:DXQ21cW7>LQ20077>L00b487>LLi`026<H00b487>LHaP026<H27>L38@P57>L26<H27>L011S6
8@PQ22DY0R480RDY00DYBRDY8@PLiaS600<Li`0=6<HDYAS66<HLiaBU7>LYBS6<;F/Q21S67>L00R48
0QcW00PHaQcW7>LQ21cW6<HLiaS60acW0QS600@DYAS69BTYBP8Q208HaP8Li`096<HLib486<HDYC6<
AS5BU3W>008HaP037>LDYABU00<HaP@DY@036<HDYAS6008DY@DHaP055:DHaQS67>LHaP025:D02AS6
7>LLiacW6<HDYAS67>LHaP035:D76<H00aBU6<HDY@055:D26<H00acW6<HHaP027>L00aS65:DDY@02
6<H01AcW6<HHaQBU6<H00acW0QS60aBU11S61ABU00D@Q1BU5:D@Q1BU008@Q08DY@<@Q0<DY@T@Q003
5:D@Q12400H@Q08<H`<DY@0848@<Ha245:D@Q1BU48@DY@8HaP035:D@Q124008@Q0065:D@Q0aS48@D
YAS61QBU00<<Ha245:D00QcW00DHaQ246<HDYAS600@@Q0045:D<H`aS36<548@01ABU48@@Q1245:D0
0a2400<DYA245:D00QBU00<HaQBU5:D00aBU0Q240QBU0QS60QBU00<HaQBU48@00QBU00<LiaS648@0
0aBU11S600<LiaS65:D00Q2400<DYA245:D00QBU112421BU00<@Q1BU5:D00Q240@aS00000`001244
8@021240100012448@Q20P@Q00T8@SW>NmiF]CW>AS5>LdYBAS4024YB0dic00EBU4icCW=:DTHa009:
DP04AS5244Ha@Q05AS42@Q03>Lh00cg_@Q0icP02>Lh3?Nl013W>?Nlmkcg_0cW>0Sg_00<icSF];F/0
0S6<0cF]0c6<0SF]0S6<0SW>00HmkcF]=JdicSg_>Lh2?Nl3@Q001SW>=JdicSg_>Lhe[@8aS003=Jdi
cSF]008e[@07>Li243g_?Nle[CW>?Nl00cW>1C6<00<icSF]<H`00SF]0cg_00De[C6<<H`]Jc6<008Y
BP8]J`03:DX]JbU:008]J`@aS003=JdaS2U:008YBP8]J`03:DXU:BDY008YBP03<H`]JbU:00@YBP8]
J`03:DX]JbDY00<YBP8U:@038@PU:BDY008U:@048@PU:B48:DX29BT012487>LQ22480bU:0RDY00<Q
22DY9BT00R480RDY00<Q22DY9BT00bDY00<YBRDY8@P00RDY0Re[00DYBRe[;F/YBRDY00<Q20047>LQ
22DY9BT28@P01AcW9BTYBR489BT00R4800@U:B488@PU:@<Q20037>LQ22DY008Q20037>LQ2248008U
:@8Q208U:@HQ20047>LQ21cW6<H27>L38@P27>L48@P27>L00b489BTYBP029BT2:DX01R486<HLib48
9BTQ20LLi`8Q20037>LDYABU008HaP037>LQ21cW008Li`058@PLiacW8@PLi`036<H47>L012489BTQ
22480RDY0R4800@Lib487>LLi`@HaP<Li`035:DLibDY008]J`039BTQ21cW00<Li`056<HLiacW6<HL
i`036<H01QcW6<HLiacW6<HLi`8HaP8Q208U:@047>LHaQS65:D36<H02b487>L]Jbe[>Li242e[9BTH
aQ247>L00QBU0aS600@@Q1BU5:DHaP8DY@<HaP055:DHaQcW7>LDY@036<H00aBU6<HHaP027>L02AS6
7>LHaQBU6<HDYAS65:DHaP045:D00aS65:DHaP026<H35:D011S65:D@Q1BU11S600DLiaS66<HHaQBU
00@HaP@Li`DHaP045:DHaQcW6<H35:D01AS65:D@Q1245:D00a240aBU00<@Q1BU48@00a240QBU00D@
Q0aS36<<HaBU00D@Q0035:D@Q0aS008@Q0035:D@Q12400@@Q0035:D@Q124008<H`8@Q0035:DHaQS6
00<DY@H@Q0035:DHaQBU008DY@8HaP8DY@0548@DYAS66<HLi`026<H35:D448@00aBU36<<H`0248@0
11BU36<<Ha240QBU0Q2400<<Ha2448@0112400<DYA2448@00Q241QBU0aS600<DYA245:D00QBU00<H
aQcW5:D011BU00DHaQBU5:DDYAS6008Li`055:D@Q1BU5:D@Q0025:D26<H248@45:D00a245:DHaP02
5:D36<H15:D148@136<000848@0300048@@Q00<48@0:24848@@Q248e[GNmG_Le[DHaBU83AS43BU80
0dHaBU9:DP02CW<00dYBAS5:DP06BU8014icBU9:DT8@0Sg_0T8@00E6<D8@@Q1243g_00@icP@e[@03
>Lhmkcg_00924006>Lhe[CF]=JdicSg_1CW>136<0cF]0SW>00De[CW><H`aS3W>00924003>Lhe[Cg_
0096<@03?NlicSW>008icP04?NlicSg_?Nl5>Lh00cg_>LhicP04=Jd0136<=Jde[CF]0c6<00DicSF]
=JdaS3F]008icP8mk`06>Lhe[CW>?Nle[C6<0RU:00T]Jc6<;F/]JbU:;F/YBS6<;F/00S6<12e[00Da
S3F]<H`]JbU:008aS003=JdaS2e[00<]J`03:DXU:BDY008YBP03;F/YBRDY00DU:@048@PU:BU:9BT2
8@P01acW:DXYBRU:9BTLibDY00HYBP039BTQ22DY008U:@8YBP<U:@8YBP0;9BTQ22DY:DXU:BU:<H`e
[C6<:DXQ20029BT38@P012DY:DXYBR480QcW00<Q22DY9BT00b4800@Lib487>LQ20@U:@038@PU:B48
008HaP067>LU:BDY8@PU:B480RDY0b480RDY0b480acW00LHaQcW6<HLiaS67>LHaP027>L00aS67>LL
i`038@P022DY8@PQ21cW8@PYBRDY8@P37>L011S67>LLib481AcW00<Q21cW6<H00QS600HQ21cW7>LQ
21cW8@P47>L022487>LLiacW6<HLib489BT28@P39BT38@P27>L28@P36<H27>L26<H01QcW:DXYBRU:
9BTQ20LLi`036<HLiaS6008Li`088@PLiaS65:DHaR487>LQ20@Li`8HaP0<7>LHaQBU6<HDYAS68@PU
:CF]>LhaS2DY0QS600<LiaS66<H00aBU0aS60aBU00<@Q1BU5:D011S600<LiaS65:D01AS600<LiaS6
5:D00QBU00LHaQcW6<HHaQBU6<HDY@026<H27>L00aS65:DHaP047>L45:D00acW6<HHaP026<H35:D0
1aS65:DHaQS67>LHaQBU008HaP8Q208Li`8HaP8DY@@HaPHDY@8@Q08DY@0548@<Ha245:DHaP025:D4
48@35:D01a2436<<H`aS48@DYA24008<H`0348@DYA24008@Q0<DY@0348@8@PaS008@Q0035:D@Q124
008DY@D@Q0045:D@Q0aS48@25:D00a2436<@Q0055:D36<H011BU6<HHaQS60QBU11240PaS0Q240QBU
0a2400<DYAS66<H00Q2400<DYA2448@00QBU00P@Q1BU5:D@Q1S65:DHaQBU0Q2400<DYA245:D011BU
0Q2400DDYAS66<HHaQBU008HaP8DY@0348@HaQcW008HaPDDY@8@Q0035:D<Ha24008DY@056<HDYABU
5:DHaP035:D248@00aBU48@DY@0136<00005124000@Q1240000312402PQ200048@Q2>Liooekg=Je6
<DYB0THa00=244HaAS400dYB0dic0dYB00=6<DYBCW<01TYB00=243g_?Nl0148@00E6<D8@?NlicSF]
008icP<e[@<icP05?NlicSg_>Lhmk`02>Lh00cg_>LhicP02?Nl00d8@?NlaS002;F/01C6<>LhicSW>
=Jd00cW>00<e[C6<>Lh00Sg_0SW>00@mkd8@@Q12408mk`@icP04?NlicSW>?Nl4>Lh0148@>Lhe[C6<
0cF]136<00He[CW>=JdaS3F]<H`4>Lh02Cg_=Jde[CF]?NlicSF]:DXU:@05;F/3:DX2;F/00c6<;F/]
J`02;F/4<H`2;F/3<H`00be[<H`]J`02:DX012DY;F/YBRU:0RDY00DYBRDY:DXU:BU:008U:@8YBP8U
:@058@PU:BDY9BTYBP029BT00b489BTYBP02:DX29BT00bU:9BTQ20029BT00bU:9BTU:@03:DX00bDY
8@PQ20039BT00b48;F/aS002<H`29BT38@P02QcW8@PYBRU:9BTQ21cW8@PU:AcW1B480bDY0b480bDY
0b480QcW00<U:B489BT00bDY0b4800@YBRDY9BTQ208Li`056<HLiaS66<HLi`026<H47>L26<H01R48
7>LU:BDY8@PLi`8Q20<U:@057>LQ21S67>LHaP027>L00b487>LLi`057>L36<H00acW8@PQ20057>L0
1R489BTQ21cW5:DHaP8Li`<Q208YBP8Q20047>LQ22DY8@P27>L46<H01AcW6<HHaQcW9BT00RU:0RDY
00<Lib487>L01AcW00<HaQcW7>L00acW00<HaQcW7>L00acW0R4800LLiaS67>LLiaS67>LDY@026<H0
11cW8@PHaRe[0Sg_00/aS1S66<HLiaS65:DHaQcW6<HDYA2400HDY@0348@DYAS6008HaP045:DHaQS6
6<H25:D00aS67>LLi`036<H35:D36<H00aBU6<HDY@036<H37>L26<H011cW6<HDYABU0QS600<LiaS6
6<H00QcW0aBU0QS600@DYAcW7>LLi`<DY@DLi`DHaP055:D@Q1BU5:DHaP035:D00a245:DDY@025:D3
48@26<H448@01AS65:D@Q1245:D00a2400<<Ha2436<0112400<DYA2448@00Q240aBU0PaS00D@Q1BU
5:D@Q0aS008@Q08DY@8@Q08DY@0448@DYABU48@336<25:D00aS65:DDY@046<H25:D46<H00a245:D@
Q00848@25:D00aS65:D@Q00648@25:D02Q2436<@Q1S67>LHaQBU48@DYA240aBU0QS600@DYA2448@D
Y@@HaP035:D@Q1BU008DY@046<HLiaS66<H25:D00aS65:DHaP0348@85:D00a245:DDY@025:D00a24
5:DDY@0148@0000300048@@Q00<48@0300048@Q200848@07248e[G_NHaPaS48@BU800T8@00=6<DYB
AS400dHa00A:DTicCW=>L`=:DP05AS5:DTicCW=BU003BU8014Ha@Q12448@14Ha0T8@00<mkcW>>Lh0
13W>0cF]00<icSg_>Lh00SW>13g_00<icSF]>Lh00SF]00<icSg_?Nl00d8@1CW>0S6<00@e[Cg_@Q0m
k`8icP=2408icP04=JdicSW>?Nl4>Lh00cg_>LhicP03>Lh00cg_>Lhe[@02=Jd2>Lh2<H`00be[<H`e
[@02<H`2>Lh023F]<H`e[CF]>LhmkcW>=Jd2<H`3;F/012U:;F/]Jc6<0bU:00D]Jc6<;F/YBRe[008Y
BP8U:@8YBP07;F/icSW>?NlicS6<;F/00RU:00<]JbU::DX00Re[00<YBRDY8@P012U:0Re[00<YBRDY
9BT00b480RDY0RU:00HU:B489BTYBRe[:DX29BT012e[9BTU:B480RDY00<Q22U:;F/00S6<0RDY00XQ
21cW8@PQ22DY;F/e[C6<;F/U:@8YBP048@PU:BDY9BT37>L012DY8@PQ21cW0R4800LU:B488@PQ21cW
8@PYBP029BT00b489BTU:@028@P011cW8@PQ22480QcW00<Q21cW7>L00QcW00<Q22DY9BT012480QcW
00HHaQcW7>LHaQcW8@P27>L36<H00acW8@PU:@029BT01R487>LQ22489BTQ20<Li`8Q20047>LHaQS6
7>L28@P27>L00b486<HHaP026<H01B487>LU:B489BT00R4800<Lib488@P01QcW0b4812DY12480acW
0QS60acW0aS612DY00<Q21cW6<H00QS60acW00<Q21cW6<H00QS600@LiaS66<HHaP8Q20036<HLib48
008U:@8HaP067>LHaQS66<HDYAS60R4800DLibU:=JdicRe[008HaP037>LHaQS6008Li`8HaP035:D@
Q1S600<HaP8DY@8HaP048@PLiacW5:D36<H37>L66<H011BU6<HHaQS60aBU00<@Q1S67>L01QcW00@Q
21S65:DDY@<Li`055:DHaQcW6<HLi`066<H00aBU6<HDY@026<H00acW6<HHaP026<H011cW6<HHaQBU
0QS60QBU11S60aBU0Q2400HDYA2448@@Q1BU6<H25:D348@00aBU48@@Q00248@00aBU6<HDY@0348@0
1AS65:D@Q1245:D01A2400@<Ha2448@@Q08<H`0348@DYA24008<H`8@Q0@<H`0648@DYABU48@<Ha24
1ABU00<HaQcW7>L00aBU0QS60a2400@HaQBU5:D@Q08DY@8@Q0045:DHaQBU5:D26<H248@35:D548@0
1ABU6<HLiaS648@00aBU00@@Q1BU5:DDY@8@Q0035:D@Q124008@Q08DY@046<HDYABU5:D26<H01AcW
6<HHaQBU6<H01QBU0aS60aBU00<@Q1BU6<H00QBU0Q240QBU0Q24000312400`001240000212402PQ2
124000aS=Jeooe[F=Je244Ha0T8@00I6<DYBAS56<D8@AS43BU801DicBU9:DTYBAS400TYB0dic0TYB
0THa0T8@00=6<D8@@Q000T8@00@mkd8@?Nlmk`8e[@<icP04<H`e[CW>?Nl4>Lh013g_>LhicSW>0SF]
13W>00<mkd8@@Q0013g_0SF]00DaS3F]>LhicT8@008mk`07>Li2448@AS5243W>=Jd00SW>00@mkcW>
>LhicP8mk`8icP06=JdicSW>>Lhe[C6<0SW>0SF]00<aS3F]=Jd00c6<00@e[C6<=Jde[@@icP@e[@8a
S0D]J`06<H`YBRU::DX]Jc6<0Re[00<aS2e[:DX00RDY00<YBRe[;F/00SF]0SW>0Re[00<YBRe[:DX0
0RU:00`]Jc6<:DXU:B48:DX]JbDY:DX]JbU:;F/39BT27>L28@P00bU:9BTU:@039BT01BU:;F/YBRe[
:DX00RDY00@Q21cW8@PU:@DYBP049BTQ21cW9BT28@P012U:;F/e[Be[0RU:0RDY1R480RDY00<Q21cW
8@P00R4800PU:B487>LLibDY8@PU:B480bDY00HQ21cW7>LLibDY7>L28@P37>L01AS67>LQ21cW9BT0
0RU:00<Q21cW8@P00R4800<LiaS67>L00QcW0QS60acW0QS600HLibDY:DXYBRDY8@P47>L29BT00b48
6<HHaP057>L00b487>LHaP026<H011BU6<HLiacW0R4811cW0b480QcW0QS600<Lib488@P00b480RDY
0b480acW00@Q21cW7>LDY@8Li`8HaP037>LU:BU:008YBP039BTLiacW008HaP037>LQ2248008Li`8H
aP<Li`036<HLiacW00@Li`049BTLiacW7>L26<H03QcW6<HLiaS67>LHaQBU:DXicSg_<H`LiaS68@P4
6<H27>L011BU6<HDYABU0aS600<DYA246<H00QcW1AS60acW0QS600@DYAS66<HHaP<DY@8HaP035:D@
Q1BU008HaP8Li`038@PLiacW008Li`<HaP@Li`046<HLiaS66<H45:D46<H25:D00aS65:DLi`026<H0
0aBU6<HLi`036<H00aBU6<HHaP026<H25:D01aS67>LDYA245:DHaQBU008@Q0<DY@0448@DYABU5:D2
48@00`aS48@DY@025:D011245:D@Q12411BU0Q240aBU0Q240`aS0QBU1A2400D<Ha2448@DYA24008<
H`L@Q0035:DHaQBU00<DY@8HaP035:DHaQBU00@DY@T@Q0<DY@8@Q08DY@036<HDYABU00<DY@0348@D
YAS6008HaP<DY@8@Q0DDY@@@Q0035:DHaQBU008DY@036<HDYABU008DY@@HaP055:DHaQBU48@DY@02
48@26<H011BU48@<Ha240QBU00<HaQBU48@00Q240QBU0A2400000`0012400005124020Q212448@Q2
<HacW5[F>Lh2BU8014Ha@Q1244Ha1D8@00=6<DYBAS400dYB00=6<DYBCW<00Tic1DYB00A6<DYB@Q16
<@Q240<mk`8icPLe[@@icP07=JdicSF]<H`icSg_AS401D8@00<mkcW>=Jd00SW>00<mkcW>>Lh00cW>
00Dmkd8@AS5243W>00<e[@07<H`e[CW>@Q0mkcW>?Nl00SW>00<e[CW>?Nl00SW>00<aS3F]>Lh00cW>
0S6<00De[C6<<H`aS3F]00<aS003;F/e[CW>008icP<]J`03:DX]Jbe[00<]J`<aS08]J`04<H`]Jbe[
:DX49BT2:DX2=Jd02CW>=Jd]JbU:;F/YBS6<;F/aS002;F/00bU:;F/YBP039BT6:DX00bDY8@PU:@02
8@P011cW8@PU:BDY2RU:00@]JbU:9BTU:@8YBP03;F/U:BDY00@Q20049BTYBRU:=Jd2<H`00be[9BTU
:@049BT38@P00acW8@PQ20038@P00acW8@PLi`038@P012DY8@PQ22480RDY0b480QcW00<HaQcW7>L0
0QS600/Lib487>LLib489BTQ21cW6<HLibDY008Q20<Li`036<HLiacW00<Li`036<HQ224800<U:@8Q
20047>LQ21cW7>L38@P012DY8@PQ21cW0QS60QcW00<Q21cW6<H011cW0QS600HLib488@PLib487>L2
6<H00b489BTU:@037>L00b486<HLi`029BT012U:8@PQ22480QcW00<Q21cW6<H00QcW0aS600PQ21cW
8@PYBRDY8@PLiaS60QcW00DHaQcW7>LQ21cW00@HaP047>LQ21cW7>L36<H011cW9BTQ22480QS600<L
iaS66<H00QS60acW00DDYBU:@Q16<CF]008Li`039BTLiaS600@HaP085:D@Q1BU5:DLiaS65:D@Q08H
aP097>LQ22487>LHaR489BTYBRDY00<HaP8Li`8HaP035:DHaQS600<DY@@@Q08HaP057>LHaQcW6<HL
i`046<H27>L28@P46<H011cW8@PLiaS60QBU0QS600@DYA245:DDY@<HaP@DY@036<HDYA24008DY@03
7>LHaQS600<DY@036<HDYABU00@DY@<HaP8DY@<@Q0065:D@Q0aS36<@Q1BU0a240QBU00@HaQBU5:DD
Y@@@Q0035:D@Q12400<@Q0035:D@Q0aS008<H`<@Q08<H`@@Q00536<@Q0aS48@DY@0248@011S67>LL
iaS61QBU0Q240QBU00DHaQBU5:DDYA2400<DY@0548@DYAS66<HDY@0236<35:D348@01QBU48@DYAS6
5:DHaP<DY@036<HDYABU008@Q0<DY@0348@DYA2400<DY@036<HDYABU00<DY@037>LHaQS6008DY@03
48@HaQBU008DY@036<HDYABU008DY@<HaP045:D@Q1245:D248@25:D136<000D48@0<00048@@Q2480
00@Q248aS7>LF]He[D8@0TYB0dHa1T8@00=6<DYBBU800dYB00=6<DYBCW<00dYB00E6<DYBBU9:DTHa
00924003AS52448@00@mk`=24003>LhaS3F]008icP03=JdicSF]00<e[@0:?NlicSW>=JdicSF]<H`e
[CW>?Nl5@Q0013g_>LhmkcW>0SF]1CW>00Q244YBAS5243g_<H`e[C6<0cF]0SW>00<mkcW>>Lh01CW>
00<e[CW>>Lh013W>0SF]00<aS3F]>Lh00S6<00<]JcF]=Jd00c6<0SF]0S6<00H]JbU:;F/YBRe[<H`2
;F/2:DX01Re[<H`]Jbe[<H`]J`8U:@048@PYBRU::DX2<H`2>Lh00c6<;F/YBP04;F/2<H`01Re[:DXU
:BU:9BTYBP8U:@04:DX]Jbe[:DX48@P012DY8@PQ224812DY00<YBRe[;F/01BU:00@U:BU::DXU:@<Y
BP059BTQ22488@PU:@02:DX022DY=JdmkcF];F/Lib48:DX29BT00b489BTU:@028@P00acW8@PLi`05
8@P47>L012489BTU:B480bDY0QcW00@HaQcW7>LLi`8HaP037>LQ224800@Q20087>LQ22488@PLiaS6
7>LQ20<HaP037>LQ21cW008Li`PQ20037>LQ2248008Li`038@PLib48008Q20HLi`HHaP<Li`8Q2003
7>LQ21cW00<Li`048@PLiacW8@P27>L28@P00bU:9BTU:@028@P27>L26<H011cW6<HHaQcW11S600@Q
22DY:DXU:@<Li`<HaP057>LQ21cW6<HDY@026<H27>L26<H01QcW6<HHaQcW8@PU:@8Q20036<HLiaS6
00<Li`096<HLiaS65:D]JcW>?NlicRDY00@Li`076<HDYAS66<HDYA246<H00QcW00DHaQBU5:DHaQcW
008Q20037>LHaQS6008Li`8U:@<Li`056<HLiaS65:DHaP025:D00a245:DDY@025:D248@021BU7>LL
iacW5:DHaQcW6<H25:D00aS68@PQ20037>L01QS67>LLiacW6<HLi`<DY@<HaP@DY@0448@DYABU6<H3
5:D66<H25:D01AS65:DDYA245:D00Q241ABU00<HaQBU5:D01Q2400H<Ha2448@DYAS65:D36<H55:D3
48@25:D336<348@336<00a245:D@Q00636<348@011BU48@HaQS60QcW00<DYA2448@00QS60a240QBU
00H@Q1BU6<HDYAS65:D248@011BU6<HDYABU0Q240QBU112400<DYA245:D00Q241ABU00@HaQBU48@@
Q0<DY@0748@DYA2448@<Ha245:D00Q240QBU0QS60QBU11S600<@Q1BU5:D00QS600HDYA245:DHaQcW
5:D248@65:D248@0000300048@0000D48@0:24848@@Q248e[GNmF]HicTYBCW<6AS44@Q0014Ha@Q12
44Ha14YB0dHa00=244HaAS400THa00=:DTHaAS400T8@00Dmkd8@@Q1:DTHa009240@mk`06>LhmkcW>
<H`e[C6<0SW>00<e[C6<<H`00S6<00<e[CW>>Lh00cW>00<mkd8@@Q001Sg_0T8@0cW>00HmkdHaCW=:
DTHa>Lh2<H`2=Jd00cW>=JdaS005=Jd2>Lh00cg_>LhicP03>Lh2=Jd0136<=Jde[CF]0S6<12e[0RU:
0Re[0SF]0S6<00H]JbU:;F/YBRe[:DX4<H`3=Jd2<H`2;F/01RU:9BTYBRDY:DXe[@8icP09=JdYBRDY
:DXU:BU:9BTYBRe[008aS004:DX]Jc6<;F/29BT01248;F/aS2e[0RDY00HLib488@PQ22DY8@P59BT3
:DX00bDY:DXYBP03:DX01RDY8@PQ22DY:DX]J`8U:@048@PYBRDY9BT28@P01c6<?NlicRe[6<HQ22U:
00<U:@8Q20@U:@068@PU:BDY8@PLiaS60QcW0R480acW0R4800DU:B489BTQ21cW008HaP047>LHaQcW
7>L28@P00acW8@PQ20028@P011cW8@PQ21cW0QS60QcW11S600TQ21cW7>LHaQcW8@PU:BU:8@P00QcW
00DU:B488@PLib4800@Li`DQ208Li`038@PLiaS6008DY@046<HQ22488@P37>L01B487>LLiaS67>L0
0b480QcW00<HaR48:DX00RDY0QcW00TQ21cW6<HLiaS67>LQ21cW6<H00QcW00@Q21cW7>LLi`<U:@03
8@PLiacW00<Li`035:DHaQS600HHaP067>LQ22487>LDYAS60acW00<Q21cW7>L011cW00`Q21S636<Y
BTHaE[E241cW6<HQ21S67>L26<H35:D01A245:DHaQcW6<H00QBU00<HaQcW9BT00RDY0QcW00HQ22DY
9BTQ21cW6<H37>L00aS65:DDY@026<H011BU6<HHaQS60QBU00<@Q1BU6<H00QcW00DHaQBU6<HDYAS6
008DY@8HaP<Li`038@PLib4800<Li`046<HDYAS65:D46<H45:D011S65:DDYABU0QS61QBU00<HaQcW
6<H00QBU00<HaQBU5:D00Q241ABU0Q240QBU1A2400@DYA2448@DY@<@Q0045:D@Q12448@25:D248@0
11BU48@@Q0aS0a240PaS00H@Q0aS36<@Q1BU48@336<00a2436<@Q00248@01@aS5:DDYAS67>L00QS6
11BU00<@Q0aS48@00QBU00@@Q0aS48@HaP8DY@0348@DYA2400<DY@@@Q0035:D@Q12400D@Q08DY@8H
aP037>LDYABU008DY@0348@DYABU008DY@<@Q08DY@0648@DYA245:D@Q1S61ABU0QS600<DYA245:D0
0QBU00PHaQBU5:DHaQBU6<HDYAS60aBU00@@Q1S65:DHaP4<H`000`@Q00D000@Q124000Q200<48@06
248aS7NmF]HicTHa1DYB0THa00E244HaAS5243g_00924096<@=:DP03AS5:DTYB00M6<@06BU92448@
@Q0mkd8@0dHa00=243g_?Nl00d8@00@mkcF]<H`aS0De[@03>Lhe[Be[008e[@@mk`03>Lhmkcg_00Pm
k`06@Q0icSW>>Li6<DYB0THa00E243F]<H`aS3F]00@aS0@e[@@icP03?NlicSW>008icP04=JdicS6<
=Jd4<H`01cF];F/YBRU:;F/aS2e[00@aS0@]J`@aS003;F/aS3F]008e[@03<H`e[Be[00<YBP03;F/Y
BRU:008aS08icP8]J`8U:@08:DXU:BDY:DX]Jc6<;F/YBP<]J`<YBP06;F/YBRU:8@PLibU:124800@U
:BU:9BTQ208U:@TYBP049BTQ22DY9BT2:DX00bDY:DXU:@02:DX28@P0136<>LhicRe[0R4800@YBRDY
9BTQ20@U:@058@PYBRU:9BTQ20057>L00aS68@PLi`028@P00acW8@PQ20028@P47>L26<H00acW6<HL
i`028@P01RDY8@PLib487>LQ20@Li`036<HLiacW008HaP<Li`056<HLiacW:DXU:@038@P47>L00b48
9BTLi`077>L012487>LLiaS611cW00<HaQcW7>L00R480acW00<HaR486<H00QcW00<Q22DY8@P00R48
00@U:B489BTU:@<Q20036<HLiaS6008Li`096<HLiacW7>LQ21cW6<HLib4800<U:@LLi`<HaP<Li`<H
aP@Li`036<HLiacW008Q20<Li`046<HLiacW7>L25:D01R48<Ha244Ha;F/Q20<Li`038@PLiaBU00<D
Y@8HaP045:DHaQS65:D27>L28@P011cW6<HHaR480RDY00@Q21cW7>LLi`8HaP<Li`046<H@Q1245:D3
6<H00a245:DDY@026<H01QcW6<HHaQS65:DHaP8DY@<HaP8Li`036<HLiacW008Q20037>LDYAS6008D
Y@036<HLiaS600<DY@037>LHaQBU008DY@8HaP035:D@Q1BU008HaP0548@DYAS68@PLi`035:D011S6
5:DDYA240QBU00<HaQBU48@00QBU00<@Q0aS48@00Q2400<<Ha2436<00a240QBU0a240QBU0a2400DD
YA2448@@Q1BU00<@Q00436<@Q1245:D548@01@Q236<<H`aS48@00PaS0Q2400LDYA247>LLiaS65:D@
Q0025:D348@00aBU48@DY@0348@35:D01A245:DDYABU48@011BU00D@Q1BU48@@Q0aS00<@Q08DY@@H
aP<DY@036<H@Q1BU008@Q0055:D@Q1245:D@Q0025:D00aS65:D@Q00248@45:D36<H00aBU48@@Q005
5:D36<H00aBU6<HDY@026<H00aBU6<HHaP0136<0000300048@@Q00848@0=00048@@Q24848@00248a
S7NmF]HicTHaBU800dHa0T8@1DHa00A243g_?Nlmk`924005AS52448@?Nm24002?Nl3@Q000dHa@Q12
4005@Q0033g_@Q1244Ha@Q0mkcW>?Nm243g_>Lhmk`8icP8e[@06>Lhe[C6<;F/aS3F]0Sg_00<icSF]
>Lh00Sg_00A243g_?NlicP92408mk`03@Q0icSW>00924003BU96<DHa0096<@05?NlicSF]=JdicP02
<H`023W>=Jde[C6<=JdicSF]>Lh3=Jd00c6<=Jde[@02<H`2=Jd03SW>=JdaS3F]<H`e[C6<;F/YBRe[
:DX]Jc6<;F/3:DX2<H`5;F/2<H`00cF]<H`]J`02<H`02Re[:DX]Jc6<>Lhe[CW>?Nle[Be[0bU:0bDY
00<YBRDY9BT00R480RDY0RU:0RDY00@YBRe[<H`]J`8U:@038@PU:BDY008U:@8YBP8U:@8Q20069BTY
BRU::DXU:B480bDY00<YBRDY9BT012DY00`Q22DY9BTYBRDY8@PaS3W>?Nle[BDY:DX39BT00b489BTU
:@059BT012489BTQ224811cW00HHaQcW7>LLiaS67>L28@P37>L00b487>LLi`027>L26<H011cW9BTU
:B480acW00@HaR488@PQ208Li`035:DHaQcW008Li`8HaP<Li`066<HQ22DY8@PLiaS60QcW00<Q22DY
8@P00RDY00<Lib487>L01AcW00<HaQcW7>L00acW00@HaQcW7>LQ208HaP047>LHaQcW6<H37>L00b48
7>LLi`027>L59BT28@P57>L36<H00b487>LQ20048@P39BT27>L28@P36<H57>L00aS65:DHaP026<H0
0acW6<HHaP057>L03ABU6<HHaQcW8@PU:AS636<U:CF]CW=6<BDY008Q20045:DHaQBU6<H45:D37>L2
6<H25:D011cW8@PLiacW0QS60QcW00<Q21cW7>L00QcW0aS60acW00@DYA245:DDY@<Li`036<HDYABU
008HaP047>LHaQS66<H35:D011245:DHaQBU0QS60acW1AS600DDYAS66<HHaQ24008DY@036<HLiacW
008Li`8HaP8DY@<HaP065:D@Q1S66<HLiaS60QBU0Q2400<DYAS66<H01ABU00<@Q0aS48@01A241ABU
0Q2400<<Ha2448@00a240PaS1A240`aS0a241PaS00D8@PaS48@DYA24008<H`0348@DYABU00<DY@H@
Q0045:D@Q12436<248@011BU48@@Q1BU0a240QBU0a240QBU112400TDYA2436<@Q1BU6<HDYA245:D0
0QS600@DYA2448@DY@8HaP035:D@Q124008DY@8@Q0045:D@Q12448@25:D248@01QBU6<HHaQ246<HD
Y@<@Q0055:DHaQBU5:DHaP025:D248@00aBU48@DY@026<H15:D000<48@0300048@@Q00848@082480
00@Q248aS7>LF]He[@96<@04BU96<DHaAS43@Q03AS42@Q0023g_@Q16<D8@?Nm244Ha@Q02?Nl2@Q00
13g_AS5244Ha148@00<mkd8@@Q000d8@00E6<D8@@Q1243W>00@mk`8e[@03<H`e[C6<008aS009;F/e
[CW>@Q0mkcW>=JdicSg_0092408mk`8icP03?Nm2448@00<mk`03@Q16<DYB00=6<@04@Q0icSF]>Lh3
<H`00cF]>Lhe[@02<H`00cF]>LhicP02=Jd00c6<=Jde[@02=Jd00c6<=Jde[@02=Jd00cW>=Jde[@02
<H`6;F/00bU:;F/aS002;F/00bU:;F/]J`04;F/2<H`3=Jd2<H`02Re[:DX]Jbe[<H`icT8@?NlicRU:
0Re[12DY0RU:22DY00LYBRe[;F/]JbU:9BTYBP059BT00bU:9BTU:@028@P29BT00be[9BTU:@029BT0
1Be[:DXU:B489BT00RU:0R4800@LibDY9BTU:@8Q208]J`8icP8aS08U:@04:DXQ22488@P29BT28@P0
0acW9BTQ20028@P01AcW6<HLiaS68@P00QcW00<HaQcW7>L02AcW00LQ21cW5:DHaR489BTQ20037>L3
8@P47>L00aS67>LLi`027>L25:D26<H00b489BTQ20028@P37>L00b489BTQ20028@P01BDY8@PLiacW
6<H01QcW00<Q21cW7>L00QS621cW0QS600@Lib487>LQ208Li`038@PU:B48008U:@8Q208Li`048@PL
iacW6<H67>L29BT00b489BTU:@028@P;7>L26<H00aBU6<HLi`027>L36<H27>L46<H03AcW8@PQ21S6
5:DHaQcW>Li6<Cg_=JdLiaBU00@HaP055:DHaQS66<HDY@066<H00acW8@PQ20036<H28@P011cW5:DH
aQS60QcW0QS600<LiaS65:D00aBU0acW00DHaQBU6<HHaQBU00<HaP<DY@8HaP045:DHaQS66<H87>L2
6<H35:D00aS65:DDY@025:D011S67>LLiaS60aBU0QS611BU00DLiaS65:DDYAS600<DY@066<HDYABU
5:D@Q1BU1A240aBU112400DDYA2448@@Q1BU00@@Q0045:D@Q12436<448@00`aS48@DY@0336<01124
36<8@PQ20PaS00<@Q0aS48@00PaS00D@Q0aS36<@Q1BU008HaP8DY@8<H`8@Q0036<H@Q12400<@Q003
36<@Q12400@@Q0045:D@Q12448@35:D011245:D@Q0aS0Q2400HDY@aS48@DYAS65:D248@36<H011BU
48@<Ha240QS60QBU0Q2400@DYA2448@@Q08DY@0348@DYA2400DDY@0348@HaQ2400<DY@8@Q08DY@8H
aP0348@DYA24008DY@8HaP4@Q00000D48@0012448@0000<48@0;24848@@Q248e[GNmG_Le[D8@CW=:
DP02CW<2@Q0014Ha@Q0mkdHa0d8@13g_00=243g_?Nl00Sg_0SW>0cg_00=243g_@Q001d8@00A6<D8@
@Q16<@<mk`08>Lhmkd8@@Q16<D8@?NlicP8e[@8icP9240<icP05@Q1:DTHa@Q0mk`02>Lh01Sg_@Q12
448@AS4mk`<icP924003AS52448@00<mk`8icP8e[@<icP03=JdaS3W>00<icP@e[@DaS0<e[@DaS08]
J`8aS0@]J`07<H`]JbU::DX]Jc6<>Lh01c6<00@]JbU:<H`aS0<e[@<icP05=JdYBRe[:DXU:@03:DX2
9BT00b487>LQ20039BT012487>LQ22481BU:00<U:BU:;F/00Re[0RU:0Re[0RDY00@Q22DY:DXYBP<Q
208U:@8Q208U:@048@PLib489BT27>L02B489BTYBRDY<H`icSF];F/YBP02<H`012e[9BTQ22U:0RDY
00TYBRe[8@PQ21cW8@PU:B486<H00acW0b4800<U:B488@P00QcW0R480acW0R4800<U:B489BT00RDY
0QcW00@HaQcW8@PQ20<Li`036<HLib48008Q20036<HLiacW00@Li`038@PLiacW008Li`058@PLib48
8@PLi`048@P00bDY8@PQ20037>L38@P00bDY7>LHaP027>L28@P01AS67>LLiaS67>L00QS60QcW00/Q
21cW8@PQ22DY8@PYBRDY:DXU:B48008Li`078@PU:B487>LDYAS67>L00b4800@Lib489BTU:@@Q208L
i`<Q20077>LQ22487>LQ21S67>L01QS60acW11S600dLiaS68@PU:B486<HLib48<H`icSF];F/Q2004
6<H27>L46<H011cW8@PLiacW0aS600<LiaS67>L00aS60acW0aS600<LiaS65:D01ABU00<@Q1BU5:D0
11S600@LiaS65:DLi`8Q20076<HDYABU7>LHaQBU6<H00QBU11S600@DYAS66<HHaP8DY@036<HDYABU
008DY@<HaP8Li`036<HDYABU00<HaP8DY@056<HLiacW7>LHaP0=5:D011245:DDYABU112400HDYAS6
5:DDYA2436<348@25:D0112436<<H`aS0a2400DDYA2448@@Q0aS00D@Q08<H`0448@<Ha2448@25:D0
0a2436<<H`025:D26<H25:D00a2436<<H`0248@01QBU48@@Q12436<@Q0<<H`0948@DYABU48@DYA24
5:D@Q1BU008@Q0<<H`8@Q0DDY@8HaP8DY@8HaP8DY@0536<@Q12448@DY@026<H00aBU48@@Q0025:D0
0a245:DDY@0348@00aBU6<HHaP026<H00aBU6<H@Q0045:D248@35:D348@35:D136<0000300048@@Q
00848@0<00048@@Q248000@Q248icW_NE[De[D8@1DYB0T8@00<mkd8@@Q000d8@00<mkcW>?Nl00Sg_
0T8@00Dmkd8@>LhmkcW>00<mk`92408mk`I24003AS5243g_008mk`<icP03?Nm2448@00<mk`06=Jda
S3F]>Li243g_0SW>0cg_00M244Ha?NlmkcW>?Nm24003?Nl2>Lh00cg_>Li24004@Q02AS401Cg_>Lha
S36<=Jd00cW>0SF]0cW>00<e[C6<<H`00SF]00HicRe[;F/]Jc6<>Lh4=Jd2<H`00be[:DX]J`02;F/0
0c6<;F/YBP02;F/6<H`01CF]<H`aS36<;F/00c6<00@]JbU::DXaS08e[@06>Lhe[CF]>LhaS2e[0RDY
00<]JbU:9BT00RDY124800LU:B488@PQ22DY8@PU:@09:DX01BDY:DX]JbU:9BT00R4800<YBRDY8@P0
0RDY00@YBRDY8@PU:@8Q20039BTQ21cW00@Q20097>LU:BDY7>L]JcF]>LhaS2DY008]J`03:DXQ22DY
00<YBP049BTQ22DY8@P29BT01b487>LLiaS67>LHaQcW008Q208Li`@Q208Li`8Q20039BTQ21cW008Q
20039BTQ224800DLi`078@PLiacW7>LQ21cW8@P00aS600<Lib487>L00acW0R4800XLiaS66<HQ22DY
8@PU:B487>LQ208Li`059BTQ21cW7>LHaP028@P00bDY7>LHaP036<H00b487>LQ20047>L26<H27>L3
8@P021cW8@PU:BDY:DXU:B489BT47>L28@P27>L01aS67>LLiacW8@PLib48008U:@078@PLiacW8@PU
:B486<H011cW00<Q21cW7>L01aS600<Q21cW8@P00R480aBU00lLib488@PHaQcW6<H@Q2e[?Nm:DSF]
8@PDYB487>L00aS600@LiaS66<HHaP<Li`046<HDYAS67>L26<H25:D26<H37>L26<H00acW6<HHaP02
6<H00acW6<HDY@0248@00aS65:DDY@026<H00acW6<HDY@066<H01acW6<HHaQBU48@DYAS6008Li`<H
aP037>LHaQS600<HaP8DY@046<H@Q1BU6<H37>L26<H45:D66<H00acW6<HDY@025:D00aS648@DY@05
5:D748@011BU48@@Q1240QBU00HHaQ2448@@Q1BU48@236<01a2436<8@PQ236<@Q1BU008@Q0D<H`L@
Q00836<@Q1245:D<Ha2436<@Q08Li`036<HDY@aS00<<H`P@Q0<<H`8@Q0045:D@Q12448@45:D01124
36<<Ha241ABU00<@Q1BU5:D00a240QS60a240QBU00<HaQBU5:D00QBU00D@Q1BU5:DDYA24008<H`09
48@DYABU6<HDYAS65:DHaQ2400HDY@8@Q0@DY@0348@DYABU008@Q0000P@Q00<000@Q12400`@Q00P8
@P@Q1248@SW>OomW>C6<0dHa00A:DTHaAS56<@=24003AS52448@00924006AS52448@@Q0mkd8@0Sg_
0SW>0Sg_00E243g_>Lhmkd8@00<mk`=24096<@9:DP924004>Lhmkd8@@Q02?Nl4>Lh01cg_=JdicSW>
?Nm244Ha00A24008AS4mkcW>>Lhmkd8@>Lhe[@8icP8e[@8icP05?NlicSg_?NlicP03?Nl2>Lh0136<
>LhicSF]0SW>0Sg_0SW>0Sg_00M243W>>LhaS2e[<H`]J`03<H`2=Jd2<H`00be[:DX]J`02;F/00bU:
;F/aS003<H`022e[:DXaS3F]>LhaS3F]>Lh2=Jd012e[:DXaS2e[0SF]00@aS2e[;F/]J`8aS004;F/Y
BRe[;F/6:DX38@P01BDY:DX]JbDY8@P00QcW00<Q22DY:DX00Re[0RU:00<U:BU:;F/00RU:00<]JbU:
:DX00RDY00<YBRDY9BT012U:00<U:B488@P00RDY1R4800XU:B487>LLibe[=JdmkcF]:DXU:@<YBPHU
:@<Q20<U:@DQ20067>LQ22DY;F/U:B480QcW12DY1R480QcW0b480acW11S60b480acW0RDY0b4800<H
aQcW7>L00R4800HHaQcW8@PQ22DY8@P27>L28@P27>L01AS68@PLiacW8@P00bDY0R4800<Lib487>L0
0QcW00<HaQcW6<H00aS60acW00LQ22DY9BTU:BU:;F/YBP068@P00acW6<HLi`037>L00b489BTU:@02
8@P00bDY6<HHaP037>L011S67>LLib480aS600@Lib487>LLi`DHaP<Li`038@PLiaS6008HaP087>LU
:BDY9BTQ21cW6<HYBP8mk`03<H`HaQBU00<Q208Li`046<HLiacW6<H47>L01AS65:DDYAcW8@P00QcW
0QS611cW00HHaQBU6<HDYAS65:D248@25:D248@011BU6<HHaQBU0QS60aBU00PHaR488@PLiaS65:DH
aQcW0QS600<DYAS65:D01AS600@DYAS65:DDY@8HaP8DY@0448@DYAS67>L26<H00aBU6<HHaP026<H2
5:D00acW6<HLi`027>L00aBU6<HDY@035:D248@36<H25:D00a245:DDY@025:D248@45:D00aS65:DD
Y@0348@00aBU48@<H`0336<00a245:D@Q00948@336<948@25:D27>L011S65:D@Q1240PaS00@@Q0aS
48@@Q0@<H`0648@<H`aS36<@Q1BU0Q2400@<Ha245:DDY@D@Q00336<@Q12400<@Q08HaP035:D@Q1BU
00<DY@@@Q08DY@<@Q00336<@Q1BU008DY@046<H@Q12448@25:D248@01QS67>LQ21BU48@DY@<@Q005
36<@Q1BU5:DHaP035:D148@15:D136<00005124000@Q1240000312402PQ2124000aS?Nmooe[F=Je2
44YB0dHa00=:DT8@AS402D8@00<mkd8@?Nl00d8@13W>23g_1D8@00A6<DYBAS52408mk`03>Lhmkd8@
00@mk`0;>Lhe[CW>>LhmkcW>?Nm244Ha@Q0mk`02AS400cg_>LhicP02?Nl5>Lh01cF]>LhicSF]>Lhe
[CW>008mk`03@Q0mkcW>00@icP06=JdicSW>?NlicSg_0SW>0T8@00<icSF];F/00S6<00@]Jc6<<H`e
[@@aS003:DX]JbU:008YBP8]J`03<H`]Jc6<008]J`8aS007=JdaS36<<H`e[CW>=Jd012e[1c6<00<]
Jc6<;F/012e[00@YBRDY:DXU:@@Q208U:@078@PU:AcW7>LQ22DY:DX00Re[00@aS2e[:DXYBP8U:@@Y
BP8U:@04:DXU:BDY9BT3:DX012DY:DXU:BDY1R4800LLiaS67>LQ21cW:DX]J`02>Lh012e[<H`YBRDY
0bU:0RDY0b4800@Lib48:DX]J`<Q20079BTQ21cW7>LQ22DY8@P00RDY0R480bDY0R4800@Lib488@PL
i`<Q20<Li`8Q20@HaP<Li`048@PLib488@P39BT00b486<HLi`046<H28@P011cW8@PQ22480QcW0R48
00<U:B487>L00acW00<Q22DY9BT00R4800DLib488@PQ21cW008HaP037>LHaQS6008DY@036<HLib48
008Q208U:@<YBP<U:@038@PLiacW00LLi`038@PLib4800<Q20036<HLiacW008Li`036<HLiacW00<H
aP038@PLiaS600DHaP8Li`8Q208Li`8HaP8DY@0<7>LQ22DY9BTLia249BU244YB>LhLiaS611cW00<H
aQcW7>L02AcW00<HaQcW7>L00QS600hLib488@PLiaS65:D@Q1BU6<HLiaBU48@<Ha241QBU00<HaQBU
6<H00aS61AcW00@HaQBU5:DDY@<HaP075:DHaQS67>LHaQBU48@00QBU00DHaQBU5:DDYA24008DY@04
6<HLiacW6<H35:D27>L26<H25:D011S68@PLiacW1aBU00<@Q1BU5:D00QS60QBU0a240QBU0a240QS6
00@DYA2448@<H`<@Q0<<H`8@Q00336<@Q12400L@Q08<H`<@Q08<H`0348@DYA24008<H`<@Q0@HaPH<
H`0548@<H`aS36<@Q00:36<01A245:DDYABU48@00`aS0Q2400LDYA2448@DYA245:D@Q0035:D00aS6
5:DDY@0248@25:D348@011BU48@@Q1BU0QS60a2400<DYA245:D00QBU00@HaQcW5:DHaP@DY@@@Q004
5:DHaQBU6<H35:D136<0000300048@@Q00<48@0300048@Q200848@08248icWooHaPicTYBCW=6<@Q2
4096<@03@Q16<DHa00924003?Nm2448@00924003?NlicSg_00E24004?NlicSW>>Lh3?Nl013W>?Nm6
<DHa0TYB0T8@00Hmkd8@@Q0mkcW><H`2>Lh01Cg_@Q0icSg_@Q000Sg_00<icSg_?Nl0148@00@mkcW>
>Lhe[@8icP04=JdicSW>?Nl2>Lh00cF]<H`e[@04>Lh7=Jd00cW>?Nm24002>Lh2=Jd3?Nl3=Jd3>Lh0
1CF]>LhicSF]<H`00Re[00<YBRe[;F/012e[136<00De[Cg_>Lhe[C6<008e[@@aS08e[@03>Lhe[Be[
00@]J`8YBP039BTYBRU:008YBP039BTQ22U:008U:@8Q20<U:@09:DXU:BDY9BTQ22U:;F/aS2e[00HY
BP049BTQ22489BT2:DX29BT2:DX00be[:DXU:@049BT01be[:DXQ21cW8@PYBR48008Li`089BT]JbU:
<H`icSF]<H`U:@8YBP<U:@058@PU:BDY9BTQ20049BT00b489BTQ20048@P01BDY:DXYBRDY8@P00RDY
00HYBR487>LQ21cW8@P79BT012487>LQ21cW0aS611cW0R4800@U:B488@PQ208U:@8Li`046<HLib48
7>L29BT012487>LLiaS60QcW00<Q21S67>L00R480RDY00@YBRDY8@PU:@<Q20<Li`038@PLiaS600LL
i`058@PLib489BTQ20029BT48@P00bDY8@PQ20038@P57>L28@P00acW8@PLi`0?6<H011cW6<HLiaS6
124811cW00hHaQcW7>LQ22DY7>L@Q2U:@Q1BU4Ha8@PHaR4811S600<LiaS66<H00QS611cW00`DYAS6
7>LLibDY8@PHaQcW6<HQ21cW8@P95:D00aS65:D@Q0085:D011S65:DLiacW0QS600DDYAS66<HHaQBU
00<Li`036<HDYAcW008Li`8HaP045:D@Q12448@25:D00aS65:DHaP025:D01aS65:DDYA246<HDYAcW
008HaP035:DHaQS6008HaP<DY@0548@<Ha2448@HaP0248@00aBU6<HDY@0336<01Q245:D@Q12436<@
Q08DY@<@Q0045:D@Q12448@25:D248@636<448@010aS48@8@PaS0Q2400H<Ha2436<@Q0aS48@236<2
48@25:D011S65:DDYA240`aS11240PQ210aS0PQ20`aS0Q240PaS00<8@PaS48@00Q240`aS00@@Q1BU
48@DY@@@Q0@DY@<HaP8@Q08DY@8@Q0035:D<Ha24008@Q08DY@<@Q0035:DHaQS6008DY@0448@DYABU
5:D348@01ABU48@DYA245:D011240@aS000312400`001240000212402`Q2124000aS?Nmooekg>Li:
DTicBU80248@00E6<D8@AS5244Ha00924003?Nm2448@0096<@8mk`04>LhmkdHa@Q04?Nl2@Q03?Nl0
1T8@?Nm6<D8@AS5:DP96<@03@Q0mkd8@00924003>LhaS3F]008mk`03=JdicSW>0092408icP8mk`E2
4004>Lhe[C6<=Jd3>Lh01cg_>LhicSF]<H`icSF]00@icP8e[@<aS08e[@DicP05?NlicSg_?NlicP02
=Jd2>Lh2=Jd3>Lh01C6<;F/]JbU:9BT00RU:0c6<00DYBRe[:DXaS3F]008icP07=JdaS3W>=JdaS2e[
<H`00cF]00DicSF]<H`aS2U:00<]J`03:DX]Jbe[008YBP<U:@04:DXU:BDY7>L28@P012DY:DXU:BDY
0RU:00<Q22DY:DX00Re[00DYBRDY:DXYBRe[00<U:@038@PU:BDY008U:@LYBP8Q20@U:@@Q200:7>LQ
22489BTQ23F]?Nm243F]9BT2:DX29BT012489BTU:BDY0b480RDY00<YBRDY8@P00R4800HU:B488@PU
:Be[:DX29BT2:DX012DY7>LU:BDY0R4800@Lib489BTQ208U:@038@PU:AcW00@Li`096<HLiacW7>LQ
21cW8@PLibDY008Q20039BTQ2248008Li`048@PHaQS68@P29BT01b487>LQ22487>LHaQcW00<Q208U
:@8Q20049BTYBRDY9BT77>L01QS67>LHaQcW6<HDY@8Li`<Q20039BTQ2248008Q208U:@8Q20@Li`04
8@PU:B486<H37>L00b487>LLi`037>L36<H00acW6<HHaP027>L00aS65:DDY@027>L36<H38@P01BDY
8@PLiacW5:D00acW00/U:BU:7>LDYBDY@Q1BU48@8@PLibDY008Li`0D5:DHaQS68@PLiaS67>LHaQcW
8@PU:AS65:DHaR489BTLiaS65:DLi`8Q20047>LHaQBU6<H35:D00a245:DDY@0:5:D56<H00acW6<HH
aP026<H01ABU7>LHaQcW5:D00aS600@LiaS67>LHaP@DY@056<H@Q12448@DY@026<H35:D00aS65:DH
aP025:D00aS67>LLi`036<H01AcW5:DDYA2436<0212400DDYA2436<<Ha24008DY@@@Q0036<HDYABU
00@@Q0<DY@8<H`@@Q0035:D@Q0aS008<H`0348@<H`aS008<H`8@Q00436<@Q0aS48@236<248@35:D2
6<H248@436<248@236<00`Q236<<H`0248@236<00`Q236<@Q00236<348@00`aS48@<H`0236<248@4
5:D348@25:D00aS65:DHaP026<H011BU48@DYABU0PaS0Q2400<DYA2448@00a240aBU00L@Q1BU5:DH
aQcW6<HDY@0348@35:D348@25:D00a245:D@Q00136<0000300048@0000D48@0:24848@@Q248e[G_N
F]He[DHaBU82AS400cg_>LhicP03@Q000dHa@Q124003@Q05AS42@Q02>Lh01Cg_>Lhmkd8@?Nl00SW>
00@mkd8@AS56<@8mk`05<H`icSg_@Q16<@04@Q000dHa@Q0mk`06>Lh01d8@>LhicSF]>LhmkcW>00Dm
k`03>LhmkcW>00<icP05@Q0icSW>>Lhmk`02>Lh00cF]<H`e[@02>Lh2<H`2=Jd2>Lh01C6<=Jde[CW>
@Q000Sg_00<icSF]>Lh013W>0cF]00@icT8@AS56<@8icP05;F/aS36<<H`]J`03:DX3<H`00be[<H`a
S003=Jd013W>@Q0mkcW>0SF]0SW>0S6<00@e[C6<;F/aS08]J`03:DXU:BDY00HYBP039BTYBRDY00TY
BP04;F/YBRU::DX59BT48@P01BDY8@PU:B489BT00RU:00@U:BU::DXYBP8U:@<YBP039BTQ2248008U
:@<Q20<U:@05<H`icSg_?NlYBP029BT01AcW9BTYBRe[:DX00R4800TYBRDY8@PLib489BTQ22DY7>L0
0bDY00@YBRDY:DXYBP8U:@<Q20057>LQ22489BTQ20027>L29BT58@P27>L46<H27>L01B487>LQ21cW
9BT00R4800DLib488@PQ21cW00HQ20<Li`036<HLiaS600<Q20039BTQ21cW008Q208U:@088@PLiacW
8@PHaQcW8@PU:@8Q20037>LHaR48008Q208Li`@Q20<Li`DQ208Li`038@PLiacW008Li`8HaP8Q2006
9BTQ21cW7>LHaQBU0QS600DLiaS66<HDYAcW00<HaP<DY@036<HLiacW008Li`8Q208Li`8HaP0=7>LH
aQcW9BTLia249BU6<E[FAS4U:AS68@P011S600DLiaS66<HHaQBU00<Li`8HaP037>LHaQcW00DLi`04
6<HLiacW7>L25:D01Q245:DDYABU48@DY@8@Q0045:DHaQS66<H25:D011245:DHaQ240QBU00<HaQcW
6<H00QS60QcW1aS60R480QS600@DYA245:DDY@<@Q0035:DHaQS6008DY@036<HDYA24008DY@8HaP8D
Y@<HaP037>LHaQ24008@Q08DY@8<H`0448@DYA2448@25:D0112436<<H`aS0a2400@<Ha2448@DY@@@
Q0<DY@0448@<Ha245:D448@00`aS48@@Q00248@011BU48@<H`Q20PaS00<@Q0aS36<00PaS1A2400@D
YAS66<HDY@8@Q0035:D@Q1BU00@@Q0@<H`<@Q00336<8@PQ200<<H`88@P@@Q00436<@Q12448@25:D0
0aS65:DDY@0348@00aBU48@@Q0025:D00aS67>LDY@0248@25:D01QS65:DDYA245:D@Q08DY@@<H`@@
Q0@DY@H@Q0045:D@Q1BU5:D248@136<000D48@0300048@@Q00<48@06248icWNmF]HicTYB0THa0d8@
0cg_0dHa00E244Ha@Q0mkd8@00=6<@=240@mk`04@Q0mkcW>>Lh2@Q02AS42@Q001Sg_>LhicSW>?Nm2
408mk`03@Q16<DHa00924003?Nle[CW>00PicP8mk`05>Li244Ha@Q0mk`02>Lh013g_>LhmkcW>0Sg_
00=243g_=Jd00Sg_0cF]0SW>0cF]0SW>13F]0SW>0Sg_0cW>00<e[C6<>Lh00Sg_0cF]00Dmkd8@@Q0m
kcF]00<aS003;F/YBRU:008YBP05;F/aS36<<H`]J`02<H`02CF]<H`icSg_@Q0mkcW>?NlicP04<H`0
13W>=JdaS36<0bU:00<U:BU:;F/00RU:00<U:B48:DX00RDY0RU:00<]JbU::DX01bU:00DU:BU:9BTY
BR4800@U:@<Q20067>LU:BDY:DXU:BU:0RDY0be[00@U:B48:DXYBP<Q2004:DXU:AcW7>L29BT01QcW
<H`e[D8@>LhYBP8U:@8Q208U:@@YBP049BTQ22487>L49BT28@P012DY:DXYBRe[0RDY00<YBRDY8@P0
0R4800DU:B487>LQ22DY00@Q20059BTQ22489BTQ20026<H00acW8@PHaP026<H28@P27>L00b489BTU
:@029BT00b487>LQ20027>L00b489BTU:@067>L28@P012DY8@PQ22DY0b480bDY00HQ21cW7>LLib48
7>L28@P01BDY6<HHaQS67>L01B480acW00<Q21cW7>L00bDY00@Q21cW7>LHaP<Q208HaP<Q208U:@03
8@PLiaS6008HaP<Li`HHaP037>LHaQBU008HaP068@PLib488@PLib4811cW00XHaQcW9BTLiaBU9BTm
kdYB@Q0U:@<Li`036<HLiaS600@HaP037>LHaQS600<Li`035:DHaQS600<HaP035:DHaQS600@Li`XD
Y@036<HDYABU008@Q0036<HDYABU008DY@@HaP<Li`036<HDYABU00@HaP<Li`036<HLiaS6008DY@05
48@HaQ245:D@Q0055:D248@011BU48@DYABU0QS600LDYAS66<HHaQBU6<HDY@0348@00`aS48@@Q002
48@011BU48@@Q0aS0Q2400@<Ha2436<<H`8@Q0045:D<Ha245:D248@011BU6<HDYABU1A240`aS00TD
YA2448@<Ha2436<@Q0aS24800`aS00<@Q0aS48@010aS00D@Q1BU6<HLiaS600D@Q08DY@0348@<H`aS
00<<H`0548@<H`aS48@<H`03248010aS48@<H`Q20PaS0a240PaS0QBU0QS60Q2400DDYA2448@<Ha24
008DY@8HaP<DY@8HaP8@Q003248@Q1BU008DY@0548@<HaBU48@<H`0348@25:D26<H00aBU48@@Q002
5:D248@00`aS5:D@Q0035:D136<0000300048@0000D48@0:248000@Q36<e[G>LE[DaS48@AS43@Q00
0cg_@Q16<@04AS400d8@AS524002@Q03BU82AS401DYB@Q0icSW>?Nl01CW>00<mkd8@AS400T8@00@i
cSF]>Lhmk`=240<mk`03@Q0mkcg_00<mk`924004?NlicSg_?Nl2@Q000cg_>LhicP02?Nl2>Lh00cg_
@Q0mk`04>Lh013g_>Li243g_0cW>0Sg_00<icSF]>Lh013W>0SF]00<aS3F]>Lh00SW>00@mkcW>>Lhe
[@8icP05?NlicSW>=JdaS003>Lh3=Jd02C6<:DXaS3F]>LhaS2U:;F/aS002=Jd3<H`00cF]>LhicP03
>Lh3?Nl2=Jd00c6<;F/aS002;F/2<H`01Be[:DXYBRU:;F/00RU:12e[00@YBRDY9BTU:@8YBP03;F/Y
BRU:00HYBP039BTYBR48008U:@05:DXU:B487>LQ20039BT012489BTYBRU:0Re[0RU:0RDY0RU:0Re[
00@U:BU:9BTLi`8Q20059BTQ2248:DXe[@02>Lh01Re[:DX]JbU:;F/YBP<U:@8YBP049BTQ21cW7>L2
8@P49BT01B489BTQ22DY:DX00RDY0R4800<U:B488@P00RDY0b4800<Lib489BT00RDY00@Lib487>LQ
20@Li`046<HQ21cW8@P47>L28@P00acW8@PQ20029BT28@P27>L26<H57>L28@P012DY7>LLib480RDY
00<Q21cW8@P00bDY0R4800<Lib489BT00R4800<HaQcW7>L00R4800PLib488@PQ21cW6<HLib480bDY
00<Lib486<H00QcW0aS600<Q21cW7>L00R4800@U:B487>LQ20@Li`8HaPDLi`036<HDYAS600<HaP8L
i`<Q208Li`035:DHaQBU008HaP0;8@PLia249BTicTYB?NlQ21cW8@PDY@026<H27>L011BU6<HLib48
0acW00<Q21S67>L00QBU0QS600<LiaS66<H00acW0QS60aBU0Q2400<DYAS66<H00QBU00<@Q1S66<H0
0QS600<DYAS66<H01AS60acW00DDYAS65:DDYAS6008DY@LHaP8DY@036<HDYAS600<DY@8HaP035:D@
Q1BU00<HaP8@Q0035:D@Q1BU008DY@8HaP8DY@L@Q0035:D@Q1BU008DY@0648@<H`aS36<@Q1BU0a24
00DDYA2448@@Q1BU00L@Q0035:D@Q12400@@Q0035:D@Q12400<@Q0035:D@Q0aS008@Q0095:D@Q124
48@DYA2436<@Q1BU008@Q00336<@Q124008@Q0035:D@Q124008<H`<@Q08<H`@@Q0H<H`H@Q00736<D
YABU5:DHaQBU48@00PaS0QBU0Q240QBU0Q2400@DYA2448@@Q0<DY@H@Q00336<@Q12400@@Q0@DY@03
6<HDYA2400<DY@<@Q0036<HDYABU004@Q00010@Q00@000@Q0008@P<48@0636<icW_NE[De[D8@0THa
0Sg_00=243g_@Q000dHa1d8@0dHa0TYB0T8@0cW>00<mkcW>=Jd00SW>00]244Ha@Q0mkcW>=JdicSg_
@Q16<D8@00Dmk`04>LhmkcW>?Nl4@Q0013g_>LhicSW>0Sg_00A243W>>LhicP8mk`03@Q0mkcg_008i
cP05?NlicSg_?Nm24003>Lh00cg_>LhicP04>Lh00cF]>Lhe[@02=Jd0136<=Jde[Cg_2CW>00<e[CW>
=Jd00cW>0SF]00@]Jc6<=JdicP8aS003;F/YBRe[00@aS003;F/aS3F]008e[@8icP<mk`05>Lhe[C6<
;F/aS002;F/2<H`2;F/29BT2:DX3;F/3:DX012e[:DXYBRDY0bU:12e[00<YBRDY:DX00bU:0bDY00@Y
BRDY8@PLi`<Q20@U:@8YBP0:9BTYBRDY9BT]Jc6<;F/YBRDY8@P49BT00b489BTQ2002;F/2>Lh013F]
;F/U:B4812U:0bDY0b4800<Lib488@P00RDY0R4800DYBRDY9BTU:BU:008U:@048@PLib488@P39BT0
12489BTQ21cW1b4800<Lib487>L00acW0QS60QcW0b480acW00DQ21cW8@PQ22DY008Q20066<HLiaS6
6<HLiaS60QcW1b480QcW00@Q22DY9BTQ208Li`<Q20037>LQ21cW008Li`8Q208Li`048@PU:B488@P3
7>L00b489BTU:@029BT00b487>LLi`056<H37>L29BT01B487>LHaQcW8@P00QS60QcW0R4800<LiaS6
6<H01AS60QcW00DQ22DY8@PQ21cW00@DY@0;7>LQ21cW6<HLibDY=JdicRe[9BTLi`026<H01AcW8@PH
aQS65:D00QS600@Q21cW6<HDY@HHaP037>LHaQS600<Li`<HaP@DY@046<HDYAS66<H25:D248@00aS6
5:DHaP045:D011S67>LHaQBU0QS600@LiaS65:DHaP8DY@036<HDYAS600<HaP037>LHaQBU008DY@03
6<HDYABU008@Q0065:DHaQS65:D<Ha240QBU0QS600<@Q1BU5:D00Q2400PHaQcW7>L@Q0aS5:D@Q0aS
0Q241ABU0Q240PaS00@8@PaS36<<H`8@Q0035:D@Q1BU008@Q0035:D@Q1BU00D@Q0<DY@8<H`035:DH
aQBU00D@Q0075:D@Q0aS36<@Q1BU48@00PaS0Q2411BU1Q2400@DYA2436<<H`8@Q08<H`04248<Ha24
48@336<00a2436<8@P0236<848@35:D648@25:D011245:D@Q1240aBU1a2400<<Ha245:D00Q2400@<
Ha2448@DY@8@Q0035:DHaQS6008DY@D@Q0<DY@8@Q00000<000@Q12401@@Q00h8@P001248@SW>NmiJ
eSF]@Q1:DSg_@Q0mkdYB14Ha00HmkcW>?Nm244Ha@Q02AS42BU8014HaBU9:DTHa0T8@00A6<D8@>Lhe
[@8icP08=JdicT8@@Q16<D8@>Lhmk`8icP05?NlicSg_@Q0mk`02>Lh013F]>Li2448@0THa00Dmkd8@
?Nm243g_00924004?NlicSg_?Nl5>Lh2=Jd5>Lh013F]>Lhmkd8@0Sg_2CW>00@mkcF]=JdicP8mk`03
>Lhe[CW>008mk`8icP@mk`8icP<e[@04<H`]Jc6<=Jd2>Lh2;F/00c6<;F/e[@02>Lh2@Q000cW>=Jda
S002=Jd00be[=Jdmk`02@Q000c6<;F/]J`02;F/00cF]<H`YBP04:DX3;F/7:DX00bDY:DXYBP049BT0
0bU:;F/YBP02:DX89BT012487>LU:BDY0R4800<U:BU:;F/00RU:1BDY0bU:0bDY0bU:0RDY0RU:00@e
[D8@>Lhe[@8YBP03<H`]JbU:00<U:@8Q20037>LQ22DY008Q208Li`058@PU:BDY8@PLi`039BT00b48
7>LLi`028@P29BT2:DX022DY7>LQ21cW8@PU:BU:9BT28@P011cW9BTLib481QcW00<Q22DY8@P00R48
00DLib486<HDYAcW008Q208Li`078@PLiacW6<HLib489BT00R480acW00@Q21cW9BTLi`8U:@8YBP8U
:@038@PLib4800@Li`<Q20039BTQ2248008Q208Li`<Q20039BTQ224800TLi`036<HLib4800<Q20<L
i`038@PLiacW008Li`046<HLiacW7>L46<H47>L58@P27>L26<H27>L021S65:DQ22U:=JdicRU:7>L2
6<H00b489BTLi`046<H00acW6<HLi`097>L46<H35:D01QS65:DDYABU6<HDY@<HaP8DY@@HaP035:DH
aQS6008HaP8DY@@HaP055:DHaQS65:DHaP025:D011S65:DHaQBU0QS600DLiaS65:DDYAS600<DY@03
6<HDYAS6008DY@036<HDYABU00@DY@0448@DYA246<H35:D448@00`aS48@DY@075:D448@00aBU48@@
Q00448@011BU6<H@Q1BU0a2400<<Ha2448@00Q2400<<Ha245:D00a2400<DYA2448@00a240aBU00L@
Q1BU5:DDYA2436<@Q0026<H01ABU48@8@PaS48@00`aS00@8@PaS36<@Q08<H`0748@<H`aS36<@Q1BU
48@010aS0a2400<<Ha2436<00Q240aBU00<@Q0aS36<00PaS00<@Q0aS5:D00QBU0a240QBU0Q2400<<
Ha245:D00Q240aBU0a2400@DYA2436<<H`8@Q0035:D@Q124008DY@036<H@Q0aS00D@Q0035:DHaQBU
004<H`0000H48@00124000@Q000212402@Q212448@aS>LikgUkg<Ha6<@02@Q000cg_@Q124003AS40
0d8@?Nm24003@Q000dHa@Q16<@03AS42BU82AS42@Q02?Nl013W>?NlicSF]0SW>00A:DTHa@Q0mk`8i
cPDmk`8icP8e[@03>Lhmkd8@0096<@924003?NlicT8@00=2408icP8mk`<icP03=JdicSW>00DicP06
?NlicSW>?Nm243g_2CW>00@e[CW>?Nle[@8icP8mk`07>Lhe[CW>?Nm243W>?Nl00SW>00<mkcW>>Lh0
0SW>0c6<00<e[CW>=Jd00S6<00<]Jc6<=Jd00SF]00Hmkd8@@Q0icS6<=Jd2<H`01CF]>Lhmkcg_=Jd0
0S6<0RU:00L]Jc6<;F/YBR48:DX]J`03:DX2;F/01RU:;F/YBRU:9BTYBP@U:@8YBP8U:@04:DX]Jbe[
9BT48@P39BT38@P032DY8@PQ22489BT]Jc6<;F/U:B489BTYBP<U:@03:DXU:BDY008U:@8YBP8U:@06
:DXU:CF]?Nm243W>0RU:0be[00@YBRDY9BTU:@8Q20037>LQ21cW008Q20047>LQ22DY8@P29BT00b48
9BTQ20048@P01AcW8@PU:BDY:DX00RDY0R4800<LibDY9BT00RU:0R480QcW00@HaQcW6<HQ208Li`8Q
20057>LQ22488@PLi`026<H00b487>LLi`057>L00b487>LHaP027>L28@P01QcW6<HHaQS67>LQ208U
:@8Q20069BTQ22DY8@PLib4811cW00DQ22DY9BTLib48008U:@038@PLiaS6008Li`8U:@038@PLiacW
00`Li`038@PLiacW00<Li`078@PLiacW6<HLib487>L00aS60QBU0QS600@LiaS66<HQ208U:@047>LH
aQS66<H27>L36<H02QcW8@PYBSF]<H`YBQcW5:DLib480QcW00@DYAS66<HLi`8HaP<Li`088@PLiacW
7>LQ21cW6<HDY@DHaPDDY@036<HDYABU00<HaP@DY@8HaP8DY@036<HDYAS6008DY@8HaP037>LDYABU
00<HaP8DY@056<HDYABU5:DLi`026<H35:D26<H25:D46<H00a245:DDY@065:D248@45:D548@00`aS
5:D@Q0055:D0112436<@Q1240`aS00P@Q1BU48@DYAS65:DHaQ240PaS0Q2400@DYA2448@@Q08DY@04
48@<Ha2448@25:D01@aS48@DYABU48@00PaS0Q2400HHaQ2448@<Ha245:D26<H02ABU36<@Q0aS48@<
H`Q236<8@P0236<00a245:D@Q00436<248@00`aS48@@Q00336<01A2436<<H`aS48@00QBU0Q2400TD
YA2448@8@Q2436<@Q1BU48@00PaS0Q240QBU00<@Q0aS48@00Q2400DHaQBU48@@Q0aS008@Q0045:D@
Q0aS48@25:D02A2436<@Q1245:D@Q1BU6<H@Q00236<00a245:D@Q0025:D16<H148@000P48@082484
8@0036<e[GooG_LicPE6<@03BU96<D8@00=24003?Nm2448@00924004AS5244Ha@Q04AS42@Q03AS43
@Q02?Nl2@Q0014YB@Q1243g_13W>0Sg_00<icSg_>Lh00Sg_0T8@00@mkd8@?Nlmk`=24004BU9243g_
?Nl2@Q02>Lh5=Jd2>Lh2=Jd4>Lh2?Nl01T8@?NlicSg_>Li2408icP03<H`e[Cg_00DicP8mk`DicP03
?NlicT8@0092408mk`03>LhmkcW>008e[@06>Lhe[C6<=JdicSg_0SW>13F]0SW>00LaS2e[;F/]JcF]
<H`icP02@Q001cW><H`YBRe[<H`e[BU:008U:@04:DX]Jbe[:DX29BT01248:DXYBRe[0RDY00@Q22DY
:DXU:@8Q20059BTQ22U:;F/aS002:DX00bDY:DXYBP028@P011cW8@PU:BDY0R4800DLib489BTU:Be[
008YBP04;F/YBRe[9BT28@P39BT01B487>LU:BDY:DX00bDY00XQ23F]@Q1:DSg_;F/YBRe[:DXU:@8Q
20037>LQ21cW00<Li`048@PLib488@P39BT28@P00bDY8@PU:@029BT00b487>LLi`029BT01BU:8@PL
iacW8@P00bDY0RU:00@U:B489BTQ208Li`046<HQ21cW6<H27>L01B489BTQ22DY8@P00QcW00<HaQcW
7>L011cW00<Q21cW8@P00QS600@Lib488@PQ208Li`048@PLib488@P29BT28@P022DY;F/YBRU:9BTQ
21cW8@P37>L012487>LLiacW0RDY00<LiaS67>L00RDY0b4800@Lib488@PQ208Li`058@PLiacW7>LQ
20027>L01R487>LQ21cW8@PLi`@HaP038@PLiacW00DLi`8DY@036<HLiacW00<U:@8Q20037>LQ2248
00<Li`0=6<HDYB487>LYBSW><H`]JacW5:DLib486<H00acW0QS60acW00@HaR488@PQ208Li`8Q20<L
i`8HaP8DY@036<HDYA24008DY@<HaP8DY@036<HDYAS600@HaP067>LDYABU6<HDYAS611BU00<HaQBU
6<H00QBU00@HaQBU5:DDY@8HaP@DY@036<HDYA2400<DY@<HaP045:DHaQBU5:D36<H45:D36<H65:D0
11246<H@Q1BU0a2400HHaQBU5:DDY@aS48@45:D00a245:DDY@025:D01Q245:D@Q0aS48@<H`@DY@@@
Q00936<@Q12448@DYA2436<@Q1BU008HaP0448@DYA245:D348@35:D248@236<00`Q236<@Q00248@0
0`aS48@@Q00236<010Q236<@Q1240QBU00<@Q0aS48@00`aS00<@Q0aS36<00a2400<DYAS65:D01a24
00<<Ha2448@01A2400@DYA2448@@Q0@DY@8@Q0075:D@Q0aS36<@Q1BU36<00Q241aBU11240QBU0a24
0@aS00001P@Q00048@00124000D48@09248e[G_NHaPicTHaBU9244Ha009:DP96<@=24006?Nm2448@
@Q16<D8@0THa00=244HaAS400THa0d8@00I6<D8@@Q1243g_>Lh2?Nl2@Q0024Ha@Q1243W>?NlicSF]
>Lh2?Nl013W>=Jde[Cg_0d8@00DmkcW>?Nlmkd8@0096<@924004?Nm243g_?Nl2>Lh01cF]>LhicSW>
=JdaS3F]008icPLmk`03@Q0mkd8@008mk`HicP04=JdaS3W>>Lh2@Q03>Lh00cF]>Lhmk`02?Nl00d8@
?Nlmk`02?Nl3=Jd2>Lh00cF]>LhicP02>Lh3=Jd023W>=JdicSF]<H`]JbU:;F/2=Jd01cW>?NlicSW>
<H`]Jc6<00<]J`8U:@04:DXaS36<:DX39BT01RU:;F/YBRU:9BTQ20@U:@038@PU:B4800<YBP06;F/Y
BRDY9BTQ22DY0b480RDY0b4800HU:B489BTU:BU:;F/2:DX01be[9BTQ22489BT]JbDY008Li`038@PY
BRU:00<U:@067>LYBSF]@Q16<CF]0S6<00<YBRDY9BT00RDY00@Q22DY9BTU:@<Li`DQ208YBP039BTQ
224800LQ20039BTQ2248008Q20079BTQ22488@PU:BU:9BT00R4811cW00HHaQcW7>LQ22DY8@P39BT0
0b487>LLi`037>L26<H37>L26<H38@P27>L00b487>LLi`027>L3:DX29BT01R489BTYBRU:9BTQ208L
i`048@PLib488@P27>L26<H012487>LQ21cW1R4800<Lib488@P00R4800@Lib489BTQ20<Li`048@PL
ib488@P27>L36<H57>L012487>LLiaS60QcW0QS600@Lib488@PU:@8Q20<Li`0>8@PLib487>LQ21cW
6<HU:C6<?NlaS2486<HLi`<HaP<Li`@HaP8Li`098@PLiaS68@PYBR486<HDYAS6008Li`@DY@036<HD
YAS600@DY@036<HDYABU008HaP8DY@<HaP8DY@<HaP055:DHaQS65:DHaP065:D26<H35:D26<H02QBU
48@@Q1S65:DHaQBU6<HDYAS60QBU11S611BU00<@Q1S67>L00QS600<DYAS65:D00a2400LHaQBU5:D@
Q1BU48@DY@0348@011BU48@@Q12421BU00D@Q0aS36<@Q1BU00H@Q00436<@Q0aS36<348@00`aS48@D
Y@026<H35:D348@01QBU48@DYA245:D<H`H@Q00436<@Q0aS48@236<2248010aS48@@Q1BU0Q240PaS
0Q2400D<Ha2448@@Q0aS008@Q0035:DHaQBU00<<H`045:D@Q12436<248@236<00a245:DDY@0248@0
11BU48@@Q1240QBU1A2400D<Ha2448@<Ha24008<H`0948@DYAS66<HDYA245:D@Q1BU00<@Q0035:D@
Q124004<H`0000<000@Q12401@@Q00P8@P001248@SF]MkeJeSW>0TYB00=>LdYBBU801DYB00=6<D8@
@Q00148@00<mkd8@@Q000dHa00=243g_?Nl00T8@00=6<D8@@Q000T8@0Sg_00A243g_@Q1240Dmk`04
=JdaS36<<H`2>Lh0148@AS56<DHa0T8@0THa00=243g_@Q000cg_00<icSg_?Nl00Sg_00HicT8@AS56
<D8@=Jd2>Lh2?Nl00d8@>LhicP06>Lh00cg_>Lhe[@02=Jd5>Lh5?Nl3>Lh00cg_>Lhmk`03?Nl00cW>
=Jdmk`03>Lh013g_>LhicS6<0SF]0cW>0SF]0cW>00<e[CW><H`00S6<0SF]0SW>00He[CW>>LhaS3F]
<H`3;F/0136<;F/]JbU:0RDY0R4800TU:BU::DXU:B489BTYBRe[9BT00R4800<U:BU:;F/00Re[0bU:
00LU:B488@PQ22DY:DXU:@038@P5:DX00be[:DXYBP02:DX00bDY8@PQ20058@P01RU:9BT]Jc6<;F/Y
BP8]J`08?Nm6<DHa>Lh]JbDY:DXU:@@Q20047>LHaR488@P37>L58@P29BT48@P29BT012U:8@PQ21cW
0R4800HLib487>LLiaS68@P29BT01b487>LHaQcW8@PU:B4800<Li`@U:@038@PU:BU:008Q208HaPTL
i`036<HLiacW00@Q208Li`058@PU:BDY9BTQ20029BT00bU:;F/YBP029BT47>L00b487>LQ20028@P2
6<H27>L01R487>LHaQcW9BTQ20DU:@038@PLib48008Q20057>LQ22488@PLi`026<H011cW6<HQ2248
0acW1AS600DDYAS67>LLib48008Li`048@PU:BDY9BT38@P00bDY8@PLi`027>L03AS69BTe[CW>=JdQ
21BU6<HLib487>LHaQBU00<Li`035:DHaQcW00<HaP047>LQ22488@P27>L00b487>LLi`025:D00aS6
5:DHaP086<H65:D00aS65:DHaP027>L26<H01ABU6<HDYABU48@00QS600DLiaBU5:D@Q1BU00@HaP05
5:DHaQS66<HDY@0248@00aBU48@@Q0045:D01A245:DDYABU6<H01ABU0QS600<DYAS66<H00QS600<D
YA245:D01A2400<<Ha2448@00a2400@<Ha2448@DY@<@Q08DY@0348@DYABU008DY@0548@DYA2448@D
Y@0448@25:D00a2436<@Q0025:D01A2436<@Q1S65:D00Q240QBU00@@Q1BU6<HDY@8@Q0<<H`T@Q006
36<8@PQ236<DYA240PaS0Q2410aS00<@Q0aS36<00Q2400DDYA245:D@Q0aS00D@Q00536<@Q1246<HD
Y@0436<00a2436<@Q00248@25:D248@00`aS48@@Q00236<00a2436<<H`0448@00`aS48@DY@0248@0
0`aS48@@Q00348@236<000<48@0500048@001248@P0312403PQ2<Hag_Ekg>Li6<DYBAS5>LdYBCW=:
DTHaBU83AS45@Q02?Nl02D8@AS5:DTHa@Q0icSg_@Q1:DP05@Q001Sg_@Q12448@>Lhmk`924005?Nli
cT8@>Lhe[@02<H`2>Lh013g_AS5:DT8@0Sg_0THa0Sg_00=244Ha@Q000SW>0Sg_00E243g_@Q1244Ha
008mk`04>Lhmkd8@?Nl5>Lh00cg_>LhicP05>Lh4=Jd5>Lh02Cg_>Lhmkcg_>LhmkcW>?NlicP02?Nl2
>Lh01SF]<H`icSg_@Q0icPDe[@DicP@e[@03>LhaS2e[008aS003?NlicSF]008icP8e[@06<H`e[C6<
<H`]JbU:0Re[00DYBRDY9BTQ22DY008YBP@U:@8YBP069BTQ22DY8@PU:Be[0S6<00HYBRDY:DXU:B48
9BT2:DX00bDY8@PQ20028@P39BT3:DX012e[:DXYBR4812DY0R4801<LibDY8@PU:BU:;F/aS2e[:DXU
:C6<@Q1:DSg_;F/U:Be[:DXU:@028@P37>L28@P37>L00b489BTQ20027>L58@P39BT00b489BTQ2003
8@P27>L58@P00bDY8@PQ20048@P47>L29BT012489BTU:BDY0R4811cW00@HaQcW7>LQ20@Li`8HaP8L
i`8Q208Li`058@PU:BDY8@PLi`028@P00bDY:DX]J`02:DX01B487>LQ21cW6<H00acW00LQ21cW7>LL
iaS67>LHaP047>L28@P00acW9BTYBP029BT00b487>LQ20048@P011cW8@PLiacW0QS60acW1aS600<L
iaS66<H00QcW0RDY0R4800DU:AcW7>LLib48008U:@8Li`086<HDYBDY>LhmkcW>9BTHaP8Li`068@PL
iaBU6<HLib480QS600<DYAS67>L00QcW00@HaR488@PQ20<Li`068@PHaQS65:DHaQBU0QS60QcW00<H
aQBU6<H00aS60QBU0QS60QBU00@HaQcW7>LLi`DHaP065:DHaQBU6<HDYAS60aBU0QS600<DYAS65:D0
0aS60QBU0Q2400@DYAS65:D@Q08DY@056<HDYABU5:D@Q0065:D36<H00acW5:DHaP055:D548@00`aS
48@@Q00548@35:D00a245:DHaP025:D011245:D@Q1240QBU00<@Q0aS48@00QBU0Q2400@<Ha2448@<
H`8@Q08DY@@@Q0@DY@8@Q0045:D@Q12436<348@00aBU48@@Q00448@01@aS248@Q1245:D00`aS0Q24
00<<Ha2436<00PaS00<@Q1BU5:D00Q2400@DYA2448@@Q08<H`0348@DYABU008@Q0035:D@Q124008<
H`0348@<Ha24008@Q08<H`<DY@0348@<H`aS00<@Q00336<@Q0aS008<H`D@Q0035:D@Q0aS00@@Q04D
Y@4@Q04<H`0000<000@Q12400`@Q00<000@Q24800P@Q00H8@SF]OomS63W>AS42CW<014YBAS56<DHa
0dYB00=>LdYBCW<00dYB1D8@00I6<D8@@Q0mkcW>?Nl2@Q02?Nl00cW>?Nm24003?Nl02DHa?NlicSW>
?Nm243g_>Lhmk`02>Lh013F]>LhicSg_0d8@0Sg_00M244Ha@Q1243W>?NlicP04?Nl2>Lh2?Nl4@Q02
?Nl2@Q001THa@Q12448@AS4mk`<icP05?NlicSF]>Lhmk`03>Lh2?Nl3@Q02>Lh4?Nl2>Lh01Cg_>Lhm
kcg_@Q000SW>00<aS3W><H`00S6<00P]Jc6<<H`e[C6<=JdaS3W>0SF]0c6<0Re[00<aS3F]<H`00S6<
00@icSg_?NlicP@e[@06<H`]Jc6<<H`]JbU:12DY00<Q21cW:DX00Re[00<YBR48:DX012U:00<]Jc6<
;F/00Re[00@YBRDY9BTQ208U:@078@PLib487>LU:BU:9BT012U:0bDY0RU:00<U:B489BT00RDY00<Q
22DY9BT012U:00/]JbU:=Je6<Dic?Nl]Jb48:DX]JbDY008Q20@Li`8Q208Li`039BTQ21cW008Q208U
:@8Q20039BTQ22U:008U:@8Q208Li`048@PU:B488@P27>L012489BTU:B480QS600HLiaS67>LLiaS6
7>L68@P29BT00b487>LLi`028@P27>L00b487>LLi`026<H27>L012489BTYBRDY124800DLib488@PQ
21cW008Q20049BTYBRU:9BT28@P01AcW8@PQ21cW6<H00QcW00@Q21S67>LHaP8Li`036<HLiacW008Q
20047>LQ2248:DX29BT27>L28@P27>L01B487>LHaQS67>L00b4811cW0QS600<DYAS67>L00QcW0QS6
00<Lib487>L00QcW00DHaR487>LQ21cW008Q200<7>LQ21S65:DQ23F]@Q0aS2485:DLib4811cW00<H
aQcW6<H011S600LLiaBU5:DHaQcW8@PLi`036<H00acW6<HLi`037>L012487>LLiaS611cW0aS61QBU
0aS611BU0QS60acW00<HaQBU6<H011S60aBU0aS611BU00<@Q1BU5:D0112411BU00<HaQBU5:D00QBU
00<HaQcW6<H00aBU00<HaQcW5:D00a240aBU00<@Q1BU5:D01a241ABU00@HaQBU5:D@Q0HDY@036<H@
Q124008@Q08DY@0548@DYA245:D@Q0025:D548@35:D448@236<248@25:D011245:DDYA240PaS0Q24
00HDYA2448@@Q0aS48@336<248@00`aS48@@Q00448@01QBU48@@Q0aS48@DY@8@Q00436<@Q1245:D6
48@00`aS48@<H`0336<248@436<348@336<248@236<248@35:D348@136<148@136<000<48@030004
8@0000848@0824848@0036<e[GooHaPicP9:DP04AS5:DTYBBU83AS45BU800dHaBU924002@Q0013g_
@Q12448@0Sg_00@icSg_@Q12408mk`8icP0:?Nm2448@@Q0mkcW>?NlicSg_@Q02?Nl4>Lh01cF]>Lhm
kdHa@Q0mkcW>00A24003AS5243W>008icP8mk`8icP04?NlicSW>?Nl2@Q02?Nl3@Q0013g_@Q0mkd8@
0cg_00<icSg_>Lh00SW>00<e[CW>>Lh00cW>00@mkd8@@Q12408mk`05>Li243g_?NlicP04?Nl00d8@
?Nlmk`03=Jd2<H`00be[<H`e[@03<H`3=Jd01SW>=Jde[CF]<H`]J`8aS003=JdaS36<008e[@05?Nli
cSW>=JdaS002=Jd4<H`2;F/79BT2:DX012DY:DXYBRe[0RU:00<U:Be[<H`00Re[00<YBRDY:DX00bDY
1R4800<U:BU:;F/00bU:0RDY0bU:1bDY00<Q22DY:DX00Re[0RU:00HaS4HaBU96<C6<9BT2:DX39BT0
1b487>LLiacW9BTQ21cW00PQ20037>LQ224800<Q20<U:@8Q20039BTQ22DY00DQ20037>LQ22DY00HL
i`036<HLib4800@Q208U:@8Q208HaP8Li`@Q20087>LHaQS66<HLiaS67>LU:@8YBP039BTQ224800DQ
20059BTYBRU::DXU:@058@P01QcW8@PQ22486<HLi`8HaP8Li`<Q20047>LHaQS67>L29BT012U:8@PQ
21cW1B4811S600@Q22DY8@PQ20@Li`@HaP075:DHaQcW8@PLiaS67>L00b481AcW00dQ21cW7>LLiaBU
9BTe[Cg_=JdQ21S67>LQ20047>L00b487>LHaP026<H011cW6<HDYAS611cW0aS63acW00<HaQBU5:D0
0aS600HDYAS66<HHaQ245:D26<H25:D00a246<HLi`027>L03AS65:DHaQS65:DHaQcW6<HDYA245:DH
aQcW00<HaP035:DHaQBU00<DY@0336<@Q12400<DY@0848@DYAS65:D@Q1BU6<HLi`LHaP075:D@Q124
48@HaQBU48@00PaS0QBU0a2400<<HaBU48@00a240QBU00P@Q1BU5:D@Q1BU48@DYAS60aBU11240aBU
00<@Q0aS48@00a240PaS0QBU00DHaQ2448@DYA24008<H`0448@DYA245:D27>L00aBU36<@Q00248@0
20aS48@@Q12436<8@PaS5:D248@436<248@00aBU48@<H`0948@00aBU48@DY@0548@236<348@236<0
0a245:D@Q00248@010aS48@<H`Q20PaS00<@Q0aS36<00PaS00@@Q0aS48@@Q08DY@@@Q08<H`0000<4
8@0012401@@Q00T8@P@Q1248@SW>OomNmcF]AS400Tic0TYB00=6<DYBAS400dHa00=:DTHaBU801DYB
0T8@00@mkdHa@Q0mk`924004AS5243g_>Lh3?Nl2>Lh2@Q000cg_>LhicP02?Nl00cF]>Lhmk`04?Nl0
148@?Nm2448@0dHa00@mkcW>?Nlmk`924004>Lhmkcg_=Jd2>Lh3?Nl2>Lh6?Nl01T8@>LhicSW>?Nli
cP8e[@08>Lhmkd8@@Q0mkcW>=Jdmk`<icP8mk`@icP03=JdicSW>00<icP07?NlicS6<<H`]Jc6<=Jd0
0c6<00D]JbU:;F/YBRe[00<aS005;F/aS36<=JdicP02<H`00be[:DX]J`03<H`01Be[<H`e[CW>=Jd0
0S6<00<]Jc6<<H`00Re[00@YBRDY9BT]J`8YBP<U:@<YBP038@PU:BDY008U:@<]J`05:DX]Jbe[:DXU
:@028@P59BT01b489BTYBRU:;F/YBRDY008Q20037>LU:BDY00@U:@05:DXU:BDY8@PU:@04;F/012U:
8@PaS3W>0T8@00@e[BU::DXQ208U:@8Q20057>LQ21cW7>LQ20029BT28@P01BDY8@PQ22487>L00b48
00HU:B488@PU:B489BT37>L78@P012DY7>LLib4811cW00LQ21cW7>LQ21cW8@PLi`038@P00bDY8@PQ
20028@P00bDY7>LLi`077>L01R489BTU:BDY8@PU:@8Q20<YBP049BTLiacW8@P49BT38@P27>L01QS6
7>LQ22487>LQ20<Li`046<HLiacW7>L38@P00bDY8@PU:@02:DX012DY7>LLiaS60acW00@HaQcW8@PQ
20@Li`<HaP037>LHaQcW008HaPDLi`046<HLiacW8@P37>L03aS67>LLiaS67>LHaQBU8@PicT8@>LhQ
21BU7>LQ20027>L26<H27>L26<H01QcW8@PLiaS65:DHaP8Li`035:DHaQS600PHaP037>LQ21cW00@H
aP045:DHaQS66<H25:D00a245:D@Q0025:D26<H65:D011S67>LHaQS611cW00PDYA245:D@Q1S65:DH
aQBU0QS600<LiaBU5:D011BU00DHaQBU48@DYA24008DY@0348@DYABU008DY@0548@DYA245:DHaP04
5:D01QS65:DDYABU48@DY@8@Q0035:D@Q1S6008@Q00336<@Q124008@Q08DY@<@Q0035:DHaQS6008D
Y@036<HDYABU00<DY@0348@DYA2400<DY@8@Q08DY@0336<@Q0Q2008@Q0DDY@0648@<Ha2436<DYAS6
0aBU0a2400@DYA2436<<H`8DY@0448@<H`Q236<248@436<248@436<248@010aS5:DHaQBU0`aS00<D
YA2448@00Q2400<<Ha2448@00aBU112400<DYA2436<00PaS00@8@PaS36<<H`<@Q0<<H`<@Q0045:D@
Q12448@236<248@136<0000300048@0000<48@0<0008@P@Q124000aS>Liooekg>Li:DTic14YB00=6
<DYBAS401TYB0THa00=:DTHa@Q000d8@00Q6<D8@?Nm244Ha@Q0mkdHa0Sg_00LicSg_?NlicSg_>Lhm
k`02@Q04>Lh01cg_>LhmkcW>?Nm243g_00=6<@06@Q0mkcg_>LhmkcW>0Sg_1SW>0Sg_00DicSg_>Lhm
kd8@00@mk`<icP05@Q0mkcW><H`e[@02>Lh2?Nl3>Lh00cF]>Lhmk`02>Lh3?Nl2>Lh4=Jd4>Lh013F]
<H`e[C6<0cF]00@]Jc6<;F/YBPD]J`03<H`]JcF]008e[@07<H`]Jbe[<H`]Jc6<;F/00S6<00@e[CW>
?Nle[@<]J`8aS003;F/YBRU:008YBP06;F/YBRU:9BTYBRDY0RU:00HU:BU:9BTU:BU:;F/2<H`022e[
:DX]Jbe[9BTQ22DY:DX28@P01RDY:DXU:BDY8@PU:@<YBP049BTQ22488@P39BT2:DX01Be[:DXU:B48
9BT00RU:0S6<0RU:010]Jc6<>Li6<Cg_=JdYBRDY:DXU:B487>LQ22DY8@PLi`<Q20<U:@038@PU:B48
008Q20057>LQ22488@PU:@028@P27>L01B487>LQ22489BT00R4800LLib487>LLib487>LQ20047>L2
8@P011cW8@PLiacW0R480RDY00HQ22DY9BTU:B487>L38@P011S67>LHaQcW0R4800<U:BU::DX00RDY
0R4800@YBRe[:DXU:@8Li`039BTQ22DY00<U:@@Li`056<HLib489BTQ20027>L01B487>LLiacW8@P0
11cW0R4800<U:BU:9BT00R4800<Lib487>L01AcW00<HaQcW8@P01AcW1AS600@Lib488@PLi`<HaP<Q
20047>LHaQcW7>L46<H02Q247>LaS3g_>LhQ21S67>LQ21cW0aS60acW00<HaQcW7>L00QcW0aBU00@H
aQcW5:DDY@8HaP075:DHaQS67>LHaQcW6<H011cW0QBU11S600DDYAS65:DDYA2400DDY@0:6<HLiaS6
5:D@Q1BU7>LHaQBU6<H27>L25:D011S65:DDYABU21S61aBU00@@Q1BU5:DHaPhDY@046<HDYA2448@2
5:D348@011BU48@DYABU0Q2400<DY@aS48@00Q2400<DYA246<H00QS600<DYA245:D00aBU0QS60QBU
00<<Ha245:D00QS600D@Q0aS48@@Q1BU00<<H`0348@DYAS600<DY@8@Q00436<@Q12448@45:D348@0
0`aS48@<H`0248@01QBU48@<H`aS248<H`8@Q08<H`<@Q0<<H`0348@<H`aS008<H`035:D@Q1BU008@
Q0045:D@Q1BU5:D448@00aS67>LDY@0336<011BU48@@Q1240PaS00<8@PaS48@00PaS00@8@PaS48@<
H`<@Q0055:D@Q12448@DY@0248@136<1248000@48@0500048@@Q1248@P0212402PQ2>LicW5Je=Je6
<E:DCW=:DTHa0dYB00=>LdYBAS400dHa00=244Ha@Q000d8@00U6<D8@AS5244HaCW=:DTHaBU800T8@
00=6<D8@@Q000T8@00@mkcW>>LhicP8e[@<icP8mk`04>Lhmkcg_AS43@Q02AS44@Q000cg_@Q124002
?Nl2>Lh3?Nl2>Lh2?Nl2@Q0013g_@Q0mkcg_1CW>0SF]13W>00<aS3F]=Jd00cg_00@icSF]>LhicP8e
[@03>Lhe[CF]008aS0<e[@04>LhmkcF]=Jd2<H`2>Lh2<H`00be[:DX]J`06;F/0236<=JdaS36<:DXU
:Be[<H`2=Jd2;F/0136<;F/]Jc6<0cF]0Re[00TaS2e[;F/U:BU:9BTYBRDY:DX00RDY00DYBS6<;F/a
S2DY008YBP0@9BTYBRU:<H`]JbU:9BTYBRe[<H`YBRDY7>LU:BU:8@P29BT3;F/2:DX38@P29BT02248
9BTU:Be[<H`e[BU:9BT28@P02BU:;F/YBRU:9BTQ22U:;F/icP02AS401CF]:DXQ22e[:DX01B480QcW
1R4800HLibDY8@PQ22DY8@P27>L00b489BTQ20028@P29BT78@P00bDY8@PU:@039BT00b489BTU:@02
7>L00aS67>LQ20028@P37>L00bDY8@PQ20029BT00bU:9BTU:@029BT27>L011S68@PQ22480bDY0b48
00@U:BU::DXU:@8Q20LU:@038@PU:AcW008Li`8Q20099BTLiacW7>LHaQcW8@PLib4800@Li`8Q20<U
:@078@PLib487>LHaQcW8@P00QcW00<HaQcW8@P00R4800<Lib487>L01QS600DLib488@PQ21S6008L
i`8Q20047>LHaQS67>L46<H01a248@Pe[Cg_=JdU:AS6008Q20PLi`086<HLiaS67>LHaQBU7>LQ208L
i`045:DHaQcW7>L26<H011BU6<HHaQcW0aS611BU00<HaQBU5:D00aS60QBU0aS611BU11S600@DYAS6
5:D@Q08DY@8HaP8DY@0448@DYABU6<H25:D46<H011BU48@DYAcW0QS60Q241aBU00@HaQBU5:D@Q08D
Y@036<HDYABU008DY@0548@DYABU6<HDY@0348@35:D00a245:D@Q00448@35:D00a245:D@Q00248@7
5:D348@011BU48@@Q1BU0a2400<<Ha2436<00a2400@DYAS66<HHaPD@Q0045:D@Q12448@25:D248@2
36<248@00`aS48@<H`0436<348@236<348@336<448@00`aS48@<H`0248@00`aS48@@Q0025:D01124
36<@Q1240QBU00@@Q0aS36<@Q0<DY@<<H`0348@<H`aS00H<H`035:D@Q0aS008<H`<DY@4@Q04<H`48
@P000P@Q00@000@Q124000848@0;24848@@Q248icW_NF]HaS48@DYA>L`09BU80148@AS56<DHa1D8@
0THa00I244HaAS5:DTicBU83@Q0013g_AS52448@0Sg_0SW>0cF]0SW>00LmkcW>?NlicSg_@Q0mk`02
@Q03AS42@Q001Cg_>Lhmkcg_@Q000Sg_00@e[CW>>LhicP<mk`0;>Lhmkcg_@Q16<D8@?NlicSF]>Lhm
k`02>Lh2=Jd2>Lh2=Jd0136<>LhicSg_0SW>0cF]00@aS3W>>Lhe[@<aS003>Lhe[C6<00<icP8aS006
>Lhe[C6<<H`e[C6<0bU:00@]Jc6<;F/]J`<aS004;F/aS2U::DX2;F/2<H`00be[<H`aS002:DX0236<
=JdicS6<;F/aS2e[<H`2:DX29BT2:DX00bDY8@PU:@02:DX0136<;F/YBRU:0RDY00@YBS6<=Jde[@8]
J`8YBP03;F/U:BDY008Q20@U:@@YBP03;F/U:BDY008Li`8Q20079BTYBRe[=JdaS2e[:DX00R480RU:
00`]JbDY9BTU:Be[:DXaS4HaBU9242e[9BT3:DX39BT00acW8@PLi`048@P00bDY8@PU:@027>L58@P0
11cW8@PQ22DY0R480bDY124800DU:B488@PLib48008U:@038@PLiacW00<Q208Li`<Q20036<HQ2248
008Q20037>LQ22DY008U:@05:DXQ22487>LHaP027>L29BT28@P29BT28@P2:DX01RDY7>LU:BU:9BTQ
20<U:@048@PLib488@P37>L28@P27>L01AS67>LLiacW8@P00QcW00<Q21cW9BT00R480RDY0acW00@Q
21cW7>LHaPDLi`8Q20037>LQ21cW008HaP035:DHaQcW00@Li`8Q20037>LHaQcW008Q200;7>LHaQcW
6<HDYAS67>LHaQBU6<HU:@02=Jd00bDY8@PLi`037>L28@P26<H011cW8@PLiaS60QcW0QS60acW1QS6
00<@Q1BU5:D00QcW0aS600@LiaS66<HHaP8DY@@HaP035:D@Q1BU00<DY@046<HDYAS65:D46<H85:D0
2Q245:DDYA246<HDYAS65:DHaQBU0aS600<DYA245:D00QS600@DYA245:DDY@8HaP8@Q0045:DLiaS6
5:D248@25:D00aS65:D@Q0025:D00aS65:D@Q00548@01QBU48@DYABU6<H@Q08<H`<@Q08DY@036<HD
YABU00<DY@086<H@Q1BU48@DYA245:DHaP<DY@<@Q00336<@Q124008@Q00436<@Q1BU6<H35:D248@0
0aBU36<<H`035:D01Q2436<@Q1245:D@Q0<<H`0448@<H`aS36<348@01@aS248<Ha245:D00`aS00@@
Q0aS48@<H`8@Q00336<@Q1BU00@@Q0035:D@Q1BU00<@Q0<DY@@@Q0055:D@Q12436<@Q00336<22482
36<00`Q236<<H`0448@00aBU48@@Q00336<0000400048@@Q000212403P002488@P00124<HcF]NmiJ
eS6<@Q1>LdYBCW<3BU800dicBU96<@02BU800dicBU924002@Q02?Nl6@Q02BU800dHaBU96<@06AS43
@Q002DHa?Nle[C6<=JdicSF]<H`e[@02?Nl3@Q002dHa@Q16<D8@AS5:DT8@?NlicSg_@Q000Sg_0d8@
0Sg_00I243g_@Q0mkd8@?Nl3>Lh2?Nl013W>?Nlmkcg_0SW>00He[CW>>LhicSF]<H`3=Jd2<H`3=Jd4
<H`00cF]<H`aS003<H`013F]>Lhe[CW>0SF]00<aS2e[<H`01C6<1be[00@aS2e[;F/]J`8aS0@YBP8]
J`8YBP8aS003=JdaS2e[008]J`05:DXU:BDY9BTYBP029BT00b489BTYBP02:DX29BT3:DX2;F/0236<
;F/YBRe[9BTYBRDY8@P39BT00b489BTU:@03;F/2<H`01BDY8@PLib48:DX00bDY0RU:00@]JbDY9BTU
:@PYBP039BT]JcW>008mk`04<H`YBRU::DX29BT28@P39BT01B487>LU:B487>L00R4800<YBRDY8@P0
0R481BDY00<Q22DY9BT00b480RDY0R4800<U:B487>L00QcW00@Q22DY9BTYBP<U:@088@PLiacW7>LQ
21S67>LHaP8Q20037>LQ22DY00LQ20<U:@068@PLiacW8@PYBRDY0QcW1B4800<U:B488@P00bU:0RDY
00HYBRDY7>LLib489BT37>L00bDY7>LLi`027>L00b487>LLi`028@P02RU:9BTQ21cW9BTYBRDY8@PL
iaS60QcW00<Q21cW8@P00R4800@U:AcW7>LQ20HLi`@HaP<Li`8U:@05:DXQ21cW7>LDY@026<H27>L0
21246<H]Jcg_>LhU:AS68@P67>L26<H021cW6<HHaQcW8@PHaQBU6<H27>L25:D011cW8@PLiaS60QcW
00@HaQBU6<HDY@8HaP8DY@0348@DYAS6008DY@036<HLiaBU00<DY@036<HDYABU008DY@8HaP045:DH
aQS67>L26<H01ABU6<HHaQS65:D00a240QBU00P@Q1BU6<HLiaS65:D@Q1BU0aS600P@Q1BU5:DDYAS6
48@DYA243ABU0QS60QBU00<@Q1BU5:D01A2400<DYA245:D00a2400H<Ha245:D@Q1S67>L25:D02PaS
48@@Q1BU48@DYA245:D@Q1BU112400<DYA2436<00PaS0a2400<<Ha245:D00acW212400@DYA2448@@
Q0H<H`8@Q00336<@Q0aS008@Q00436<@Q12436<248@011BU48@<H`aS0a240PaS0aBU10aS0Q2400D8
@PaS36<<Ha24008DY@H@Q0T<H`05248<H`aS36<@Q00236<00a2436<@Q00236<148@136<000031240
00@Q00D48@0924848@@Q248icWooF]HaS48@00I:DP03CW=:DTic009:DP04AS5:DTHa@Q03?Nl2@Q00
1DHa@Q12448@AS401DYB00E6<D8@@Q1244Ha00924004AS5243W>=Jd2<H`00cW>=JdicP03>Lh00d8@
AS524003@Q03AS43@Q02?Nl01DHa@Q1243g_>Lh00T8@23g_0cW>0cg_00<icSg_=Jd01CW>00@e[C6<
=JdaS08e[@06<H`e[CF]=JdicSF]0S6<0SF]0S6<2CF]00<]Jc6<;F/00c6<00L]Jc6<;F/]Jc6<;F/a
S002;F/01bU:;F/aS36<;F/YBRDY00H]J`DaS003;F/YBRDY00<U:@03:DXU:BDY008Q20@YBP8U:@8]
J`03<H`]Jbe[00<]J`05:DXU:BDY8@PU:@02:DX00bDY:DXYBP04;F/01BU:9BTLiacW8@P00bDY00<Q
22U::DX00RU:12DY00<YBRe[:DX00RU:00<U:BU:=Jd00Sg_00<aS2U::DX00RU:0RDY00<Q22DY8@P0
0QcW1B4800@YBRDY8@PQ208U:@8Q20LU:@DQ20039BTYBRDY00<Q20049BTYBR488@P39BT28@P00acW
8@PLi`027>L01aS67>LLibDY8@PLib48008U:@048@PLiacW8@P39BT00b487>LLi`029BT012487>LH
aQcW0RDY0b4800<U:BU:9BT00bDY0RU:0b4800@Lib488@PQ20<Li`048@PLiacW8@P27>L01AS68@PQ
22U:9BT00R4800TU:B488@PLib487>LQ21cW8@P00QcW00@Q21cW9BTQ20HLi`<HaP@Li`<Q208U:@05
7>LHaQS66<HLi`026<H00aBU7>LQ2002;F/00bDY8@PQ20077>L36<H011cW8@PLiacW0QS60QcW11S6
00HLiaS66<HDYAS67>L46<H45:D46<H00aBU6<HLi`045:D00aS65:DHaP046<H01acW6<HHaQS67>LH
aQBU008@Q0<DY@8@Q08DY@DHaP035:DHaQS600DDY@<@Q08HaP<DY@036<HLiaBU008DY@056<HDYABU
6<HLi`025:D01a245:DDYA245:D@Q1BU00D@Q08DY@L@Q0035:DHaQBU008@Q00336<DYABU00<DY@<@
Q08DY@8@Q00336<@Q124008@Q0055:D<H`aS48@DY@027>L25:D348@01ABU48@DYA245:D00a240`aS
0a2400@<Ha2448@<H`@@Q00436<@Q1245:D236<00`Q236<<H`0648@736<0112436<@Q0aS0Q2400<D
YA2448@01Q240PaS00<@Q0aS36<00PQ200<<H`Q236<00`aS00@@Q0aS48@<H`<@Q04<H`000`@Q00<0
00@Q000010@Q00P000aS=Jeg_E[F=Je244Ha0dYB0dHa00=:DTHaAS400THa0dYB00=6<D8@@Q001D8@
00=6<D8@?Nl00cW>0T8@00Q6<D8@@Q0mkdHaBU9243g_148@13W>00Hmkd8@?Nlmkd8@?Nl2@Q03AS42
?Nl2>Lh7?Nl4>Lh02Cg_@Q0mkcg_>Lhe[CW>?Nm24002?Nl00cW>=Jdmk`02?Nl00cW><H`e[@06=Jd0
0c6<;F/aS002<H`2;F/2<H`01SF]<H`e[Be[<H`e[@8icP04=JdaS36<<H`2=Jd02SW><H`e[C6<;F/Y
BRe[=JdicSF]0be[0c6<0bU:0be[00<YBRe[<H`00be[00LaS3F]<H`]JbU:9BTQ20029BT00b489BTL
i`029BT2:DX29BT00bU:9BTU:@02;F/00c6<;F/]J`04:DX29BT2:DX39BT3;F/00c6<;F/U:@028@P3
9BT28@P01BDY:DXYBRU:9BT00RU:0S6<12U:00D]JbDY9BT]JcF]00924003<H`YBR48008YBP0:8@PL
ibDY9BTQ21cW8@P]JbU:7>L28@P01BU:9BTQ21cW8@P00RDY00@Q22DY8@PQ20@U:@038@PU:B48008Q
20<U:@8Li`<Q20059BTQ22488@PLi`038@P37>L28@P01BDY8@PU:B489BT0124812DY0QcW00dQ22DY
7>LLiaS67>LQ21cW8@PU:BU:9BTLi`048@P4:DX00bDY:DXU:@038@P012DY7>LLiacW0R480QcW00@Q
21cW7>LLi`<Q208U:@8Q20039BTQ224800@Li`078@PLiacW9BTQ21cW8@P01acW00<Q21cW6<H00QcW
00LQ22DY8@PU:BU:9BTQ20037>L26<H01QBU6<HU:BU:;F/Q208HaP8Li`069BTQ21S67>LHaQcW11S6
00DLiaS66<HHaQcW008HaP055:DHaR487>LQ20047>L26<H00aBU6<HHaP045:D00a245:D@Q0085:D0
0aS65:DHaP046<H37>L00aS65:DHaP026<H35:D00aS65:DDY@045:D248@26<H00acW5:D@Q0055:D2
48@00aBU6<HDY@036<H011BU48@HaQBU0a2400TDYAS66<HQ22DY6<H@Q0aS48@00QBU0a240QBU0`aS
00<@Q1BU5:D011BU0Q240aBU00<HaQBU5:D00a2400@DYA245:DHaP8@Q0D<H`8@Q0035:D@Q1BU00<D
Y@0348@DYABU008@Q00436<@Q12448@536<0112436<@Q0aS0a240PaS1A240`aS00@@Q1BU48@<H`8@
Q08DY@0448@<Ha2436<448@236<00a2436<<H`0248@01QBU48@@Q12436<@Q0H<H`0448@8@PQ236<2
48@536<548@136<000848@0300048@@Q00<48@0:24848@@Q248e[G_NF]He[D8@BU84AS400dYBAS5:
DP02BU800dHaBU9:DP02BU82@Q002Cg_@Q16<DYBAS5243g_@Q1:DP02@Q000cg_>Lhmk`08@Q0013g_
@Q1243g_13W>1Cg_0T8@0THa0T8@0Sg_00A243g_?NlicP@mk`03@Q0icSW>008icP03@Q0mkcg_008i
cP05=JdicSW>?Nm24004>Lh3?Nl00cF]<H`e[@03<H`02CF]>Lhe[C6<;F/aS3F]>Lhe[@02;F/3=Jd0
0c6<;F/aS003=Jd2<H`3=Jd01CW>=Jde[C6<;F/01C6<00@]JbU:;F/]J`@aS003:DX]Jbe[00<]J`03
<H`]JbU:008]J`8e[@09;F/YBRU:8@PU:AcW8@PLib48008U:@03:DXU:BU:00@YBP039BTYBRU:00<]
J`8YBP8U:@03:DXU:BDY00<U:@08:DX]Jbe[;F/aS2DY8@PLi`DQ2003:DX]JbU:00<U:@06:DXaS36<
;F/YBRDY0Re[00TYBRDY:DXaS4Ha@Q0icS6<8@P00RDY00@Q22DY9BTU:@<Q20LU:@048@PLiacW7>L2
9BT28@P01BDY:DXYBRU:9BT0124800@U:B488@PLi`8Q20039BTQ224800DQ208Li`038@PLib48008L
i`<Q208U:@8Q20047>LQ22DY:DX29BT01R487>LLib487>LQ20<Li`@Q20039BTQ22DY00<Li`098@PY
BRe[:DXU:AcW9BTYBRDY00<Q20047>LQ22487>L28@P47>L28@P01BDY8@PQ21cW9BT00RU:00@U:AcW
7>LLi`8Q208Li`<Q20039BTLiacW00@Li`036<HLiacW008Li`036<HLib48008Q2004:DXU:BDY8@P2
7>L011BU6<HHaQBU0QcW00LQ22U:9BTU:B487>LQ20047>L46<H37>L26<H27>L011S65:DDYAS61AcW
00<HaQcW6<H01AS60QBU00D@Q1BU48@DYAS6008DY@0448@DYABU5:D56<H25:D011246<HLiacW0QS6
00lDYAS66<HHaQBU6<HDYA245:DHaQcW6<HDYA245:D00aS611BU00HHaQBU48@DYA245:D26<H01AcW
6<HDYAS65:D00Q240aBU0Q2400LHaR487>LLiaS648@DY@0448@45:D236<448@011S65:DDYABU0a24
00<DYAS65:D00QBU0a2400<DYA245:D020aS00L@Q0aS36<@Q1BU6<HDY@0448@35:D010aS48@<Ha24
0`aS0Q241@aS00<@Q0aS36<00QBU00<@Q0aS36<00a240PaS00<@Q0aS48@00Q240QBU00D@Q0aS48@@
Q1S6008@Q0@<H`8@Q0035:D@Q124008@Q08<H`<@Q0<<H`88@P8<H`8@Q0H<H`<@Q04<H`0000P000@Q
12448@00124000Q20`@Q00/<HcW>MkeF]C6<?Nm6<D8@BU9>LdYB0096<@04@Q16<DYBBU83AS43BU80
1DHa@Q16<D8@AS40148@00=6<D8@?Nl00cg_00=243g_>Lh00Sg_0SW>0Sg_0T8@0SW>00DmkdHaBU9:
DTHa00924003?Nm2448@00Dmk`03>LhmkcW>00@icP<mk`@icP8mk`05AS5243g_>Lhmk`03@Q04>Lh0
13g_>LhicSW>0SF]136<00<e[C6<;F/00S6<0SF]1C6<00@]Jc6<;F/aS0<icP04=JdaS3F]=Jd2<H`0
0be[=JdaS004;F/4<H`2=Jd01SW><H`]Jbe[:DX]J`8YBP<aS004;F/U:BU:;F/3<H`29BT28@P01QcW
8@PLib489BTYBP<]J`06:DXU:BU:9BTYBRe[0S6<00HYBRDY9BTU:B48:DX2<H`012U:9BTYBRe[0c6<
0be[0RU:1BDY00@YBRe[:DXU:@8]J`04<H`]Jbe[:DX3;F/2:DX01bDY:DY244icAS4aS2DY008]J`09
:DXQ22489BTQ22DY8@PU:B4800<U:@038@PU:B48008Q20049BTQ21cW8@P39BT28@P00bDY8@PQ2002
8@P49BT98@P022DY8@PQ21cW8@PLib487>L38@P59BT01b487>LHaQS68@PU:B48008Li`<Q20@Li`03
9BTYBRDY00DU:@HYBP8Q208U:@037>LQ21cW00HQ20047>LQ22489BT28@P00acW8@PQ20039BT48@P0
12DY8@PLiacW0R4800<U:B488@P00QcW00DQ21cW6<HHaQcW00<Q20047>LHaQcW7>L28@P39BT28@P2
7>L25:D01aS68@P]Jc6<;F/Q21cW008HaP037>LHaQcW00@Li`PHaP035:DHaQS6008DY@046<HLiaS6
6<H47>L00aS65:DHaP026<H01ABU48@@Q1BU48@00QBU00D@Q1BU5:DDYA24008DY@8HaP@DY@8HaP04
7>LHaQBU5:D46<H35:D46<H45:D00aS648@DY@0248@35:D00a245:DDY@027>L01QS65:D@Q1BU6<HD
Y@8@Q08DY@0<48@DYABU6<HQ21cW6<HDYA245:DHaQ240QBU00DHaQBU48@@Q1BU00<@Q00736<@Q1BU
6<H@Q0aS48@00QBU0Q240QBU00<@Q1BU5:D01ABU0PaS0a2400D<Ha2448@@Q0aS00<DY@0848@<Ha24
48@DYA2436<@Q08DY@0648@<H`aS48@DYA2410aS00D@Q0aS36<<Ha24008<H`0448@<H`aS36<22480
0`aS48@@Q00248@36<H01ABU36<<Ha245:D00Q2400D8@PaS36<<Ha24008<H`<DY@0448@<Ha2448@6
36<00a2436<<H`0248@01@aS48@@Q1BU48@00`aS0a24000010@Q00048@0010@Q00T8@P@Q000<Hc6<
LiaF]C6<?Nl00T8@0THa0dYB0T8@0THa00=:DTHaBU800dYB0THa0T8@00A6<D8@@Q1240=6<@8mk`8i
cP04?NlicSW>>Lh2?Nl00cW>?Nm24002@Q001Cg_=Jdmkd8@BU800THa0T8@00<mkd8@@Q000T8@00Hm
kcW>?NlmkcW>=Jd2>Lh043g_@Q0mkcW>=JdicT8@?NlicSF]?Nm244Ha?NlicSg_0d8@00<mkcW>>Lh0
0SW>00@mkcF]>LhicP8e[@<aS005=JdaS36<;F/aS002=Jd0136<=Jd]JcF]136<00H]JcW>>LhicSF]
<H`2=Jd2<H`023W>=JdaS36<;F/YBS6<;F/3<H`00be[=JdaS002<H`3;F/2:DX012e[=JdaS2e[0RU:
00D]Jc6<<H`]JbU:008U:@8Q208Li`8Q2003:DXU:BU:008YBP07;F/YBRDY9BTYBRe[<H`00bU:0RDY
0bU:00@U:BU::DXYBP8aS005;F/YBRU::DX]J`049BT28@P00bDY:DXYBP02:DX00be[<H`]J`04;F/0
2BU:9BTYBRDY<H`mkd8@AS4icP02;F/2:DX00bDY8@PLi`028@P39BT03B489BTU:BDY8@PLib489BTY
BRDY7>LQ21cW00<U:@048@PYBRU:9BT38@P012DY8@PU:BDY124800HU:B487>LQ21cW9BT48@P00bDY
8@PLi`028@P02BDY8@PYBRDY8@PU:B487>LQ20029BT00b487>LLi`047>L00b487>LQ20028@P00bDY
:DXU:@028@P29BT3:DX00bDY8@PU:@039BT01R487>LQ22489BTQ208U:@048@PLiacW8@P29BT38@P3
9BT28@P00bDY8@PLi`028@P00acW8@PLi`048@P67>L26<H28@P00acW8@PLi`027>L28@P29BT28@P0
0acW8@PLi`026<H02ABU8@Pe[CF];F/Lia246<HQ20047>L46<H00acW6<HHaP056<H45:D00aS67>LL
i`027>L46<H27>L35:D00a245:DDY@045:D00a245:DHaP055:D01AS65:DDYABU6<H00QcW00LHaQBU
5:DHaQcW5:DHaP0248@011BU6<HLiaBU0QS600DDYAcW6<HHaQBU008@Q0@DY@0348@DYABU008HaP8D
Y@036<HDYAS6008DY@0548@DYA2448@DY@026<H00acW6<HHaP035:D011246<HDYAS60QBU0PaS0a24
00@<Ha2448@DY@@@Q0LDY@<@Q0<DY@056<H@Q0aS48@<H`0248@010aS48@@Q1240QBU0a2400<DYA24
48@00Q240aBU00<@Q0aS48@00Q240`aS0a240PaS0Q240PaS0Q240`aS00D@Q0aS48@<Ha24008DY@03
6<HDY@aS008<H`0348@DYA2400@<H`0:48@<Ha2448@HaQBU48@<H`Q236<348@236<00a2436<8@P05
36<448@236<148@15:D148@000@48@0500048@@Q1248@P0212401`Q2=Je_Ndic<Ha244Ha00924096
<@=24003AS5:DTHa00=24007AS5:DTHa@Q0mkd8@AS400TYB00E243g_AS5:DTHa00=240@mk`8e[@07
<H`e[Cg_>Lhmkd8@>Lh00Sg_00A244YBBU9240=6<@05@Q0mkcg_>Lhmk`04@Q02?Nl00d8@?NlicP02
=Jd4>Lh01Cg_@Q12448@>Lh01Cg_0SW>13g_00<icSg_?Nl00SW>0S6<00Pe[C6<<H`aS3W>=Jd]Jc6<
0cF]00<aS2e[<H`00be[0S6<0SF]00DaS3F]=JdicSF]008aS006=JdaS2e[:DXaS2U:0be[00@e[CW>
=Jde[@8aS08]J`07:DX]Jc6<>Lhe[C6<;F/00RDY00LYBRe[;F/aS2e[:DX]J`029BT28@P49BT00be[
:DXYBP02:DX28@P012U:;F/]Jbe[0R4800@U:BU::DXYBP<Q20049BT]JbU::DX2;F/0136<;F/YBRe[
0RU:0bDY00<LibDY:DX00Re[00<YBRDY;F/00bU:0Re[00/YBRDY8@PYBSW>?Nm6<D8@;F/YBRDY00<Y
BPDU:@03:DXU:BDY00DQ20059BTQ22488@PLi`028@P00bDY8@PU:@048@P39BT00b487>LLi`028@P0
1bDY8@PLiacW8@PU:B48008Li`038@PU:AcW008Li`04:DXU:BDY8@P29BT01BU:8@PLiacW6<H00R48
00<U:B488@P01QcW0RDY00PYBR489BTYBSF];F/U:B480RU:00PU:BU::DX]JbU:9BTQ22DY0R4811cW
0R4800HU:B488@PLib487>L48@P01acW8@PLiacW6<HQ22DY008Q208Li`038@PLib48008Q208U:@8L
i`036<HLib4800<Li`058@PLiacW7>LQ2002:DX012DY8@PLiacW0QS600@LiaS67>LQ20<U:@8Q2004
7>LDYABU6<H27>L00aS67>LLi`036<H01R487>LHaQcW8@PLi`8HaP8Li`046<HDYAS66<H35:D66<H:
5:D01A2436<@Q1S67>L011BU00D@Q1BU5:DHaQBU00@HaP035:DHaQBU008DY@0548@DYAS66<HDY@02
6<H45:D01AS65:DDYABU48@00aBU00H@Q1BU48@DYA245:D37>L011BU6<HDYABU0Q2400@DYAS66<HH
aP8DY@<HaP055:DHaQBU5:D@Q0025:D00a245:D@Q00248@01@aS48@DYA245:D00Q2400<DYA2448@0
0Q2400@<Ha2448@DY@@@Q08DY@@@Q0045:D@Q0aS48@35:D336<248@336<00a245:D<H`0348@01@aS
48@@Q1BU48@00PaS21240PaS00<@Q0aS36<00PaS00<DYA245:D00aBU00<@Q1BU5:D00Q240PaS00T@
Q0aS36<@Q0aS5:D@Q1S65:D00Q2400@<Ha2448@@Q0P<H`D@Q0035:D@Q1BU008@Q04<H`000P@Q00<0
00@Q12401@@Q00L000Q2<Ha[FTic<H`mk`02AS44@Q02AS400d8@AS5:DP02AS40148@AS56<DHa148@
0THa0d8@00E6<DYBBU9243W>00924003AS4mkcW>008e[@<icP<mk`04>Lhmkd8@AS42BU82AS400d8@
AS524002>Lh3@Q000cg_@Q124004?Nl4>Lh6?Nl0148@?Nm243g_0T8@00<mkcW>?Nl00cW>0cg_00<i
cSF]=Jd00c6<0SF]0S6<00@e[CW>=Jde[@@aS007;F/YBRU:;F/aS3F]<H`00cF]00<icSF]=Jd00SF]
0S6<00<]JbU:;F/00be[0S6<00<e[CW>=Jd00S6<00@]Jc6<;F/]J`<aS00:;F/YBRU:;F/YBRe[<H`e
[C6<:DX38@P29BT28@P49BT2:DX29BT2:DX2;F/012DY8@PQ22DY0RU:00`Q21cW8@PQ22U:;F/YBRe[
=JdaS2e[9BT3;F/00bU:9BTQ20028@P022U:;F/YBRU:9BTYBRe[:DX3;F/2:DX012DY;F/aS36<0T8@
00LicRe[9BTU:Be[:DXU:@038@P39BT01B489BTQ22487>L02B480RDY0R4800<U:B488@P012DY00LQ
21cW7>LLibDY8@PLi`028@P01bDY7>LLib489BTQ21cW00DQ20059BTYBRU:9BTQ20027>L00b487>LQ
20048@P57>L022DY8@PQ2248;F/aS2e[9BT28@P01RU:;F/]Jbe[9BTYBP8U:@<Q20037>LQ21cW008Q
20049BTQ21cW6<H27>L28@P00bDY8@PLi`058@P27>L01R487>LLib487>LQ208Li`DQ208Li`036<HL
iacW00<Li`088@PLib489BTYBRDY8@PLi`8Q20037>LDYAS6008Li`058@PYBRU:9BTQ20046<H37>L3
6<H00acW8@PQ20036<H01AcW8@PLiacW6<H00QBU0QS600DLiaS65:DDYAS600<Li`036<HDYAS600<D
Y@0348@HaQBU008@Q08DY@0748@HaQBU5:DHaQBU48@011BU11S600DDYAS66<HDYAS6008@Q08DY@@H
aP8Li`036<HDYAS6008DY@8@Q08DY@0;6<HDYABU48@DY@aS48@DYAS67>LHaP035:D248@25:D011S6
5:DHaQS60QcW11BU00<HaQBU6<H00Q240aBU0PaS00@@Q1BU48@DY@D@Q0<<H`0748@<Ha2448@DYAS6
5:D01A240PaS00@@Q0aS36<DY@<HaP@<H`0348@<H`aS00@@Q08<H`H@Q0035:D@Q0aS008@Q0@<H`06
48@<Ha2436<@Q0aS0a2400<DYA246<H00aBU1A241PaS00@@Q1BU6<HDY@8@Q08<H`0348@<Ha24008@
Q0H<H`0548@<Ha2448@DY@0248@15:D148@136<0000600048@@Q00048@000P@Q00/8@P@Q1248@SF]
Kg]BU36<?Nm6<D8@00=6<@Dmk`05>Li243g_AS5:DP02@Q02?Nl2AS401D8@>LhmkcW>?Nl01d8@0SW>
00He[CW>=Jde[CW>=Jd6>Lh00d8@?Nm24004?Nl;@Q02?Nl5>Lh2?Nl3@Q000cg_@Q0mk`03>Lh01D8@
?NlicSg_@Q000THa00Lmkd8@?NlmkcW>=JdicP04=Jd01CW>=JdaS3F]>Lh00SF]0S6<00<]Jc6<<H`0
136<00L]Jc6<<H`e[CW>=JdaS003;F/0136<;F/]JbU:0Re[0SF]0SW>00DaS2e[:DXYBS6<008]J`8a
S004=JdaS36<<H`4:DX01Be[<H`aS2U:9BT00R4800@U:BU::DX]J`@U:@03:DXQ22DY00<]J`07:DXU
:BDY9BTQ22DY8@P00RDY00<YBRDY:DX00RU:0c6<00@]JbU::DXYBPPU:@04:DX]JbU:9BT2:DX00be[
:DXU:@02:DX29BT02BU:<Ha2448@>Lh]Jb489BT]J`029BT012489BTU:BDY0R480RDY00<YBRDY9BT0
0RDY00<Q21cW7>L022480RDY0b480bDY0R4800<Lib488@P00QcW00@Q21cW7>LLi`<U:@088@PLib48
7>LQ22DY7>LQ20<U:@8Li`<Q20039BTQ224800<Li`039BTYBRU:00<Q208U:@03:DXU:BU:00DU:@05
8@PYBRDY9BTYBP068@P37>L38@P01AS67>LLib487>L00QS600@Q21cW7>LQ20<U:@037>LQ21cW008L
i`@HaP<Q208Li`078@PLiacW6<HQ22DY8@P00QcW00DQ22DY9BTU:AcW00<Q20037>LHaQS6008Q2004
7>LU:BDY7>L35:D00aS65:DHaP028@P00acW6<HDY@027>L28@P01aS67>LLiaS65:DHaQcW008HaP03
5:DHaQcW00<DY@057>LHaQ2448@DY@026<H25:D00a245:DDY@036<H35:D011245:DHaQS60aBU0QcW
00<HaQBU5:D00QS60QBU0QS60aBU00HHaQBU5:DDYAS65:D26<H00aBU6<HDY@046<H35:D26<H35:D0
11247>LHaQS61QBU00<@Q1BU5:D00QS600<DYAS67>L00R480QS60aBU0QS60QBU2A240QBU0Q240`aS
0a240PaS00D@Q0aS48@@Q1BU008@Q00936<@Q12436<DYAS65:D@Q0aS008@Q0@<H`88@P0436<@Q124
248236<248@336<00a245:DDY@0348@936<248@00`aS48@@Q0025:D248@25:D00a2436<<H`0348@0
1PaS48@@Q0aS48@HaP8DY@0336<@Q1BU008@Q00436<@Q0aS36<348@236<348@436<148@136<00003
124000@Q00D48@0:248000@Q36<aS7>LE[DaS3g_AS45@Q0014Ha?NlmkcW>0T8@00<mkd8@AS400THa
0T8@00Hmkd8@@Q1243g_>Lh7@Q0013W>?NlicSW>13F]00@aS3W>>Lhmk`<icP04?Nm2448@@Q03?Nl3
@Q000cg_@Q16<@04@Q02AS400cg_>LhicP04>Lh2?Nl3@Q001Sg_>LhicSW>?NlicP8mk`=24004AS52
43g_>Lh2=Jd00cW>?Nle[@02<H`023F]>Lhe[CF]<H`e[CW>=Jd2<H`4;F/3<H`00cF]<H`]J`02<H`0
1cW>=JdaS2e[<H`]Jc6<00@]J`<aS003>LhaS2e[008YBP05;F/YBRU:;F/e[@02<H`00be[<H`aS002
;F/00bDY:DX]J`02;F/01RU:8@PU:BDY8@PU:@DYBP8U:@8Q20039BTYBRU:008YBP8Q20039BTYBRU:
00<U:@8YBP07;F/YBRe[<H`e[Be[:DX00RDY00<YBRDY9BT012DY1RU:00<]JbU::DX00Re[0b4800D]
Jd8@AS4mkcF]008U:@04:DXQ22489BT38@P00bDY8@PU:@029BT28@P29BT00b487>LLi`0:8@P00bDY
8@PQ20029BT00bU:8@PQ20048@P27>L012487>LQ21cW0R4800LU:B488@PLib487>LQ20029BT00bU:
9BTLi`037>L29BT00bU:8@PLi`027>L28@P00bDY:DXU:@028@P00bDY:DXYBP029BT2:DX00b489BTY
BP02:DX02bDY8@PU:B489BTLib487>LQ22DY8@P00QcW00<HaQcW7>L01QcW00@HaQcW8@PQ208U:@8Q
208Li`058@PHaQcW6<HLi`048@P011cW6<HLiaS611cW12480RDY124800<LiaS66<H00QcW00DQ22DY
8@PQ21cW00@DY@077>LQ21cW6<HDYAS67>L00R4800<Lib486<H00QS600<LiaS66<H021S600DDYAS6
6<HHaQBU008HaP@DY@096<HDYABU48@DYAS65:DHaQ24008DY@<HaP055:DHaQBU6<HDY@026<H02ABU
6<HDYABU7>LHaQBU48@DY@026<H00aBU6<HDY@026<H25:D00aS65:DHaP046<H45:D011245:DHaQcW
0QS60Q2411BU00L@Q1BU5:DHaQBU7>LQ20027>L25:D46<H25:D01A245:DDYABU48@00PaS0Q240QBU
0Q240`aS1Q2400@<HaBU48@@Q0<<H`@@Q0@DY@<@Q00336<@Q0aS00<<H`0348@<H`aS00@<H`0748@<
H`aS36<@Q1BU6<H00Q242@aS00<@Q0aS36<00a240aBU00D@Q1BU48@@Q0aS008@Q0@<H`8@Q0<DY@8@
Q00836<@Q1245:D@Q0aS248<H`@@Q0<<H`0348@<H`aS008<H`4@Q04<H`000P@Q00D000@Q00048@00
0088@P0:124000Q2=Je[FU:D<Ha244YBAS42BU82AS401T8@>Lhmkcg_>Lhmk`E2408mk`924006?Nm2
44Ha?NlicSg_1T8@00@icSF]=JdicP<e[@05?NlicSF]=JdicP02?Nl2>Lh01Sg_@Q0mkcg_>Lhe[@Di
cP04AS5244HaAS43@Q02>Lh2=Jd5>Lh02T8@?NlicSW>@Q16<Cg_>Lhe[CW>0d8@0Sg_148@00DmkcW>
>LhicSF]008aS006=JdicSF]=JdaS3F]0S6<00@]Jc6<<H`e[@8aS0D]J`<aS003;F/YBRU:00<aS003
;F/YBRU:008aS003=JdaS2e[00@YBP05;F/YBRe[;F/aS002;F/012U:9BTYBRU:0RDY00@YBS6<<H`]
J`8YBP<U:@<YBP<U:@038@PU:Be[008aS003;F/U:BDY00@Q20089BTYBRU:;F/YBRe[:DX]J`<YBP<U
:@8YBP038@PLiacW00<U:@<YBP039BTYBRDY00<U:@8Q20099BTYBRDY9BTicT8@?Nle[B48008YBP03
;F/YBRDY008U:@06:DXU:BDY9BTQ22DY0R4800HU:B487>LQ21cW9BT28@P29BT00acW8@PLi`038@P0
0bDY8@PQ20028@P00bDY8@PU:@028@P27>L012489BTQ22480RDY1R480QcW0RDY00<Q22DY8@P00R48
00<Lib488@P00b4800@Lib489BTU:@8Q20037>LQ22DY008U:@8YBP8U:@@Q20@YBP<Q20037>LU:B48
008Q20@Li`8Q200?7>LDYAS66<HLiaS67>LHaR487>LU:B489BTQ21cW008Q20046<HDYABU7>L38@P0
0acW6<HLi`026<H01248:DXYBRU:0QcW0R4800@LibDY9BTQ208Li`046<HLiacW6<H27>L01AS67>LH
aQcW6<H00aBU00@LibDY9BTLi`8HaP038@PLiaS6008HaP047>LHaQcW6<H57>L86<H00acW6<HDY@02
6<H011BU48@HaQS61ABU0Q240aBU00DHaQcW7>LLiaS6008DY@<HaP8DY@8HaP8DY@8HaP8DY@8@Q0DD
Y@056<HDYAS65:DHaP025:D46<H25:D00a247>LLi`027>L25:D011S65:DDYABU0aS60aBU00<HaQcW
7>L00aS600@LibDY8@PHaP8@Q0<DY@0348@<H`aS00<@Q00336<@Q124008@Q0065:D@Q12448@DYA24
0`aS00@@Q0aS36<<H`D@Q0@DY@<@Q08DY@0348@8@PQ200P<H`<@Q08<H`0548@<Ha2448@<H`0248@2
248236<011BU48@<H`aS0Q2400L<HaBU5:DHaQBU48@DY@0248@436<348@236<248@26<H021BU48@@
Q1245:DHaQ245:D448@00aBU36<@Q002248236<248@236<0000300048@@Q00P48@06248aS6mkDY@a
S3g_14Ha00=:DT8@?Nl00d8@00@mkcW>>Lhmk`9240<mk`04@Q0mkd8@?Nl2>Lh00d8@?Nlmk`03?Nl0
0d8@?NlicP02>Lh00cg_>Lhe[@05=Jd3>Lh01Sg_>Lhmkcg_@Q0mk`8icP05?NlicSF]>Lhmk`02@Q04
AS400d8@?NlicP03<H`2>Lh00cF]>Lhmk`02@Q000cg_>Li24002?Nl01CW>=JdicSg_AS400cg_0d8@
1CW>0S6<0cW>00@aS3F]<H`aS08]J`8aS003=JdaS2e[008]J`03<H`]Jc6<008aS08]J`05:DX]Jbe[
;F/aS008;F/2:DX00bDY;F/YBP05;F/5:DX29BT02BU:;F/aS36<;F/YBRDY8@PU:@02:DX00bDY8@PU
:@039BT2:DX2;F/2:DX48@P29BT2:DX012e[:DX]JbU:0be[00<YBRDY:DX00RU:124800<U:B489BT0
1bU:00DU:B489BTQ22U:008U:@04<H`icT8@>Lh2;F/3:DX00bDY8@PYBP02:DX28@P2:DX012487>LL
ibDY0R480QcW0R4800<Lib488@P00R480QcW0R4800DLib487>LU:AcW008Q20037>LQ21cW008Q208L
i`088@PU:BU:9BTQ21cW9BTQ208Li`<Q20039BTQ2248008U:@068@PLib48:DXU:B480QcW00<Q22DY
8@P00R4800@Lib488@PYBPHU:@<Q20049BTYBRU:9BT88@P77>L36<H57>L00b489BTQ20028@P011cW
8@PLiacW0QS61AcW00/Q21S66<HHaRDY:DXU:AcW8@PU:B48008Li`<U:@046<HLiaS66<H27>L28@P0
11cW6<HDYA240QBU00D@Q1cW8@PU:B48008HaP037>LDYAS600<Li`8HaP8Li`8HaP068@PLiacW6<HD
YAS60acW00<HaQBU5:D00aS600<DYA2448@01aBU00@@Q1BU5:DDY@<HaP067>LHaQS65:DHaQcW0QS6
00HDYAS67>LLiaS65:D248@35:D248@25:D01AS65:DHaQcW6<H01ABU0QcW00HHaQBU48@@Q1BU6<H2
7>L35:D00aS65:D@Q0045:D26<H27>L00aS65:DHaP037>L01QS65:D@Q1BU6<HDY@8@Q08DY@8<H`04
48@DYABU48@236<348@010aS48@@Q1240PaS00<@Q1BU36<00PaS00@@Q1BU48@@Q08DY@056<H@Q0aS
36<@Q0025:D0112436<<H`Q210aS0Q2410aS0a240PaS0a240`aS0Q240`aS00@@Q0aS36<<H`<DY@D@
Q00336<@Q0aS008<H`0548@<H`aS36<@Q0055:D011245:D@Q1BU0a2400@<Ha2448@@Q0<<H`0348@<
H`aS008@Q04<H`0000@48@00124000@48@09248000@Q248aS7>LF]HaS3g_00=6<@03BU96<DHa0092
408mk`03@Q0mkd8@00=24003?NlicSF]008mk`03@Q0mkcg_00@mk`8icP8mk`LicPDmk`8icP03?Nli
cSW>00@icP03=JdicSW>00@icP8mk`07>LhmkcW>>LhmkcW>?Nl00d8@00LmkcW>>Lhe[CW>?NlicP02
?Nl01cW>@Q12448@?NlicT8@00Lmk`03>Lhe[Cg_00924004>LhaS3F]<H`2=Jd01S6<=Jd]Jc6<=Jdi
cP8e[@@]J`8aS005;F/aS36<<H`]J`02:DX012e[<H`]JbU:12e[1bU:0Re[136<0RU:0RDY00`YBRDY
:DXQ22DY;F/aS3F]<H`YBRDY8@P39BT48@P00bU:9BTYBP02=Jd0136<:DXLibDY124800DU:Be[;F/]
JbU:008]J`8YBP8U:@8Q20039BTQ224800<U:@03:DXU:BDY008YBP<U:@048@PU:BDY9BT2:DX29BT0
2RU:;F/e[CW>=Jd]JbDY:DX]JbU:0RDY00DYBR488@PQ22DY008Q208Li`038@PU:B48008Q208Li`8U
:@03:DXU:B48008Q208U:@038@PLiaS6008Li`038@PU:BU:008U:@038@PU:B4800<Li`8U:@038@PU
:BDY00LQ20<U:@HQ20049BTQ22488@P39BT47>L01bDY:DXU:B489BTQ22DY008Q208U:@8YBP8U:@04
8@PU:BDY9BT47>L00b487>LQ20057>L66<H011cW8@PU:BDY0R480QcW00DHaQcW7>LDYAS6008Li`04
9BTQ21cW7>L58@P47>L012DY8@PQ22DY11cW0R480acW0aBU00@HaQcW6<HHaP8Li`038@PLiaS600TH
aP8Li`048@PLiacW7>L66<H37>L00aS67>LHaP036<H25:D248@00aBU48@@Q00248@25:D26<H57>L2
8@P011cW5:DDYABU0aS600DLiaS65:D@Q0aS008@Q08DY@0448@DYABU6<H55:D26<H35:D248@25:D0
0acW6<HHaP025:D26<H00aBU48@DY@026<H25:D00a245:DDY@036<H27>L00aS65:D@Q0055:D01Q24
5:DDY@aS48@<Ha8@Q00536<@Q0aS48@DY@026<H348@25:D348@536<248@236<348@736<348@00`aS
248<H`0548@00`aS248<H`025:D01a2436<@Q1246<H@Q0aS0088@P@<H`8@Q08<H`8@Q08DY@036<HD
YA2400@@Q00336<@Q124008@Q0L<H`48@P0000<000@Q12400`@Q00<000Q212400P@Q00H8@S6<LiaJ
eS6<?Nl2@Q02BU83AS45@Q02?Nl00d8@?Nlmk`03>Lh2?Nl3@Q000cW>?Nm24002?Nl01cW>?Nlmkcg_
>Lhe[Cg_00<icP8mk`8icP03?NlicSW>00<icP8mk`TicP03=JdicSg_0092408icP<mk`03@Q0mkcW>
008e[@DicP@mk`03@Q0mkcg_008mk`05@Q0mkd8@@Q0mk`03>Lh00d8@?Nlmk`04=Jd00c6<=JdaS004
<H`013F]<H`e[CF]0S6<00<]JbU:<H`012e[00<YBRDY:DX00be[00<YBRe[;F/01Be[00DYBRDY:DX]
JbU:008]J`04<H`e[BU::DX29BT01BU:9BTU:B489BT00RU:00@e[CW><H`]J`8Q20DU:@088@PU:BDY
9BTaS3W>=Jd]J`8Q20049BTQ22DY8@P29BT00bU:;F/YBP03;F/012U:8@PQ224812DY00PQ22DY9BTQ
22DY;F/YBRDY0R481BDY00<YBRe[:DX00RU:00DU:CF]?NlicSF]008U:@8YBP039BTQ224800<U:@8Q
20059BTQ21cW8@PLi`029BT00b487>LQ20028@P39BT38@P012DY8@PQ21S60QcW00@Q22DY8@PU:@HQ
20039BTQ2248008Q208U:@038@PLiacW008Q20049BTQ21cW8@P39BT68@P39BT00b489BTQ20048@P5
9BT48@P2:DX01Be[:DXYBR489BT00acW0R480QcW00DHaQcW8@PQ21cW008HaP037>LHaQcW00@Li`04
9BTYBRDY8@P26<H27>L01aS67>LHaQS68@PLiaS6008Li`@Q20089BTLiacW7>LU:B487>LQ208U:@05
7>LHaQcW9BTQ20027>L01AS65:DDYAS65:D011S600@Lib487>LLi`8DY@<HaP035:DHaQS600<HaP04
8@PLiacW7>L26<H00acW5:DDY@026<H00acW6<HHaP036<H55:D248@236<248@35:D36<H011cW5:DH
aQcW0R4800@LiaBU5:DLi`8HaP037>LHaQBU00<@Q0035:DHaQBU00<@Q08HaP045:D@Q1BU5:D36<H2
5:D248@25:D26<H45:D01AS65:DDYABU6<H01ABU00@@Q1BU6<HLi`<HaP045:D@Q1245:D26<H00aBU
48@@Q00248@236<448@010aS48@@Q1240PaS1A2400<DYA2436<00a2400D8@QBU6<HLiaS6008<H`05
5:D@Q1S65:D@Q00236<224801A2436<@Q12436<00Q2400<DYA2436<00PaS00D@Q0aS36<<H`Q2008<
H`<@Q08<H`8@Q00536<8@PaS48@HaP0348@00aS65:D@Q00436<0112436<<H`aS0PQ20PaS0QBU0QS6
00<DYA245:D0112400<DYA2448@00`aS0a240PaS0@Q2000212400`001240000312402@Q212448@Q2
<HacW5Je=Je24002AS40148@?Nlmkcg_0d8@00A6<D8@@Q1240A6<@8mk`03>Lhmkcg_008mk`8icP04
?Nm2448@?Nl3>Lh00cF]<H`e[@03=Jd2>Lh00d8@?NlicP02>Lh01Sg_@Q0mkcW>?Nm2408icP06=Jdi
cSW>=JdaS3F]2CW>0cg_0cW>0T8@0THa00=243g_?Nl01CW>0Sg_0SW>13g_00<icSg_?Nl00Sg_00<i
cSF]=Jd00S6<0SF]0S6<0cF]0SW>00De[C6<;F/YBRe[008aS08e[@04<H`]Jbe[<H`3;F/01bU:;F/]
Jc6<;F/YBRe[00<YBP<U:@04:DXaS36<<H`3:DX00bDY:DXU:@028@P29BT2:DX3<H`01be[9BTU:BDY
8@PU:BU:008]J`<YBP<aS008;F/U:BDY8@PLiaS67>LU:@8YBP04;F/YBRe[<H`2;F/48@P39BT38@P0
0bDY:DXU:@03:DX00bDY8@PLi`038@P01bDY8@PQ2248:DXU:CW>008mk`03=JdU:BDY00HU:@03:DXQ
2248008Li`038@PLib48008U:@048@PLiacW8@P39BT48@P00bDY8@PU:@068@P00acW8@PQ20029BT0
1R489BTU:B489BTLi`LQ20<U:@8Q208U:@8Q20066<HLib488@PYBRDY0R480RDY124800@U:BU::DXY
BP8U:@038@PU:B4800@U:@05:DX]JbU::DXU:@068@P00acW8@PQ20028@P27>L26<H00acW6<HLi`04
7>L28@P67>L26<H57>L29BT37>L01B487>LQ21cW6<H00QcW00<Q21cW7>L00QcW00<Q21cW8@P00QcW
00LHaQcW7>LLiaS65:DHaP037>L00b487>LLi`027>L00b486<HDY@025:D56<H27>L28@P021cW6<HD
YABU6<HLib487>L26<H35:D01AS67>LDYABU48@00aBU00THaQBU5:D@Q1BU6<HLiaS65:D00aS60QcW
21S60QBU00<@Q1BU48@00a240QS60QBU00<@Q1BU5:D00QBU0a2400HDYA245:DDYA245:D36<H45:D5
6<H00aBU6<HDY@036<H01ABU6<H@Q1245:D00Q2400@DYA246<HDY@H@Q00336<@Q124008DY@0648@<
Ha245:DHaQ240PaS0a2400P<Ha2448@@Q1BU48@DYAS60QBU00<@Q0aS48@011240`aS00<8@PaS48@0
0Q240PaS00D@Q0aS48@<Ha24008<H`8@Q00:36<@Q0aS36<@Q0aS48@<H`Q236<748@25:D00a245:D@
Q00236<00`Q248@<H`0636<01A245:DDYA2436<00a2400<DYA2448@00PaS00@@Q0aS36<8@P8<H`88
@P8@Q04<H`0000<48@0012401@@Q00T8@P001248@S6<LiaBU3W>@Q000THa0d8@00@mkd8@@Q0mk`I2
40=6<@8mk`03>Lhmkcg_008mk`03>Lhmkcg_0092408icP8aS0<icP04=JdicSF]?Nl2>Lh2?Nl01D8@
>LhicSW>@Q000Sg_0cW>0SF]00@icSF]=Jde[@DicP03?NlicSW>008icP@mk`03@Q0mkd8@00=240@m
k`8icP03=JdicSW>00Dmk`<icP8mk`05>Lhe[CF]<H`e[@02<H`013F]<H`aS36<1CW>12e[0SF]0S6<
00De[BU:;F/]Jc6<008]J`03:DX]Jbe[008YBP8]J`8YBP048@PU:BDY:DX5;F/00c6<:DXU:@028@P0
0bDY8@PU:@029BT2<H`013F]<H`YBRU:0R480RDY0RU:0bDY00LaS3F]=Jd]JbDY:DXU:@037>L00bDY
:DX]J`06;F/012DY8@PU:B4812DY0b480RDY0RU:0RDY00<Q22DY:DX00R4812DY00<Q22DY<H`00cW>
0bU:00<U:BU:9BT00RDY00<Q22DY8@P00R480QcW00PQ22DY8@PQ22DY8@PU:B480RDY00@Q22DY9BTU
:@<Q20039BTLiacW00@Q20047>LQ22488@P29BT38@P27>L28@P00bDY8@PU:@028@P00bDY8@PQ2005
8@P031cW8@PQ22489BTYBRDY8@PLib48:DXU:@<Q2004:DX]JbU::DX38@P29BT012489BTYBRe[12U:
0R4800@U:B489BTQ20DLi`036<HLiaS600@Li`056<HLiacW8@PU:@028@P37>L46<H27>L00b487>LQ
20028@P00bDY8@PQ20037>L02AS67>LLibDY8@PLiaS67>LQ20057>L46<H01QcW6<HHaQS67>LQ20<L
i`058@PLiaBU6<HLi`045:D46<H27>L00b487>LHaP036<H00acW6<HHaP036<H25:D011S67>LLiaBU
112400<DYAS65:D00QBU0QS60QBU00DHaQcW8@PLiaBU008HaP8Li`8HaP8Li`036<HDYA2400@@Q005
5:DHaQBU5:DHaP0348@25:D26<H011BU48@@Q1BU0Q2400@DYAcW7>LLi`8DY@8HaP@DY@8HaPDDY@03
6<HDYAS6008DY@<@Q08DY@<@Q0035:D@Q12400<@Q08DY@0348@DYABU008@Q00336<DYA24008@Q00<
36<@Q12436<@Q1BU48@<Ha246<HQ21S60`aS00@@Q1BU5:D@Q08<H`88@P0348@DYA2400<<H`P@Q0L<
H`0448@<Ha2436<748@35:D336<248@236<248@336<00a2436<@Q00248@00aBU48@@Q00248@01@aS
48@<H`aS48@01@aS00@8@PaS36<DY@4<H`0000H000@Q124000@Q000212402PQ212448@Q2<HacW5Je
<Ha244Ha0T8@13g_00I244Ha?NlicSg_@Q02BU800dHaBU96<@03AS42@Q000dHa@Q0mk`02@Q000dHa
@Q0icP02>Lh01CF]?Nm243g_>Lh00cF]00<icSF]=Jd00SW>00@mkcW>=JdicP8mk`04>Lhe[C6<=Jd3
>Lh01CF]<H`aS3F]<H`00cF]13W>00<e[CW>>Lh00SF]00<icSg_?Nl00SW>00Dmkd8@?Nlmkd8@00<m
k`<icP04?NlicSg_?Nl2@Q000cg_>LhicP02>Lh2=Jd00c6<=JdaS004<H`2=Jd2<H`012e[<H`e[C6<
0SF]00DicSF]<H`e[CW>008aS08YBP06;F/aS3F]<H`]JbU:0RDY00DYBRDY9BTU:BU:008]J`DYBP03
9BTQ224800DU:@03:DXU:Be[00<aS005:DXQ22DY9BTYBP02;F/2<H`00be[:DXYBP02:DX00bDY7>LL
i`027>L00bDY:DXYBP02;F/012U:9BTU:BU:0RDY0R4800DU:BU:;F/YBRDY008Q20039BTYBRDY00<U
:@03:DXU:BDY00<Q200;9BTQ21cW8@PU:C6<;F/mkd8@>Lhe[@029BT01Be[9BTQ22489BT00R4800<L
ib487>L00QcW00<Q22U:9BT00QcW1R480bDY00@Q22DY9BTU:@8Q20039BTLib48008Q20059BTYBRDY
8@PLi`058@P01BDY8@PQ22489BT012480bDY0R480QcW0R4812DY0R4800LU:BU:;F/aS2e[:DXU:@04
8@P39BT28@P00bDY:DXYBP049BT28@P012DY8@PQ22480QcW0R4800@LiaS66<HHaP@Li`066<HLiacW
7>LQ22DY0R480QcW00<HaQcW7>L00acW00<HaQcW7>L00b480QcW00DHaR487>LHaQcW008Q208HaP03
7>LQ21cW00DHaP8DY@067>LQ21cW6<HDYAS60QcW0R480acW0QBU0QcW0QS600<DYAS67>L01AcW0aS6
00<DYAS66<H00QcW00@HaQcW6<HHaP<DY@056<H@Q1BU5:D@Q0025:D26<H35:D76<H25:D27>L26<H4
5:D011245:D@Q1240QBU0aS600@DYAS65:DHaP@DY@@@Q08DY@066<H@Q1245:DHaQBU0Q2400DDYAS6
5:DDYA24008DY@036<HDYABU008HaP045:DHaQ245:D548@35:D00a245:D@Q00248@25:D348@35:D2
48@00`aS48@@Q00348@01aBU48@@Q0aS48@DYAS6008DY@0536<@Q1BU48@<H`0348@436<248@236<2
5:D336<248@010aS48@@Q12420aS00<@Q0aS48@00Q2400DDYA2448@@Q1BU00@@Q0045:D@Q0aS48@4
36<00`Q236<@Q0045:D011S648@<H`aS0Q240PaS0Q2400<<H`Q2248010aS0A240@aS000212400`00
12448@06124020Q2<Ha_Ne:D=Je244Ha@Q02?Nl00d8@?Nm24003@Q02?Nl00d8@AS5:DP04BU800dHa
@Q124002@Q03?Nl2@Q0014Ha?NlmkcW>0SF]00DmkdHa?Nle[C6<008icP03=JdicSW>008mk`8icP06
=Jdmkd8@?NlicSF]0SW>00Le[CW>>LhicSF]<H`e[@03>Lh2=Jd00cW>?NlicP02=Jd01CW>?NlmkcW>
?Nl00SW>00@mkd8@@Q16<@<mk`8icP03=JdicSW>00@mk`03@Q0mkd8@00<icP06=JdicS6<;F/aS2e[
0S6<0cF]1c6<13F]00LicSF]=JdaS2e[:DX]J`02<H`00cF];F/YBP02:DX49BT5:DX2;F/012U:9BTQ
224812DY00<YBRDY:DX00Re[0S6<00HYBRDY8@PU:Be[:DX2;F/2<H`2;F/00bU:8@PQ20028@P00acW
8@PQ20029BT3;F/39BT01BU:8@PQ21cW8@P00RU:00D]JbDY8@PU:BU:008]J`<U:@05:DXU:B488@PU
:@028@P011cW8@PU:BDY0RU:00`icTHa?NlaS2DY:DXaS2DY8@PLib489BT28@P011cW8@PLib480RDY
00@Q22DY8@PU:@<Q208U:@8Q20@U:@DQ20037>LQ2248008U:@@Q208U:@@Q20049BTQ22487>L48@P0
12DY8@PQ22480acW00<Q22DY9BT00bDY0R4800DU:Be[;F/]JbU:008Q208U:@8Q20<U:@8Q20069BTQ
22U:9BTYBR480RDY00<Q22DY9BT00R482AcW0QS60QcW0b481QcW00<HaQcW6<H00QcW1B483QcW00DQ
21cW6<HHaQBU008HaP8Li`LHaP057>LQ22488@PLi`046<H00acW6<HDY@026<H011cW8@PQ21S60QcW
00@HaQBU5:DDY@<Li`036<HDYABU00<HaP<DY@0448@DYABU6<H25:D:6<H25:D36<H021cW6<HLiaS6
48@<Ha245:D248@25:D01AcW6<HHaQS648@00QBU00D@Q1BU5:DHaQBU008@Q0<DY@0848@DYAS66<HD
YA245:D@Q08DY@8HaPDDY@036<HDYABU008@Q0<DY@8@Q0035:D@Q0aS008@Q0055:D@Q12448@DY@03
48@25:D00a245:D@Q00<48@01@aS6<HHaQS65:D00Q2400@DY@aS48@@Q08DY@<<H`<@Q0<<H`0748@<
H`aS36<DYA2436<00a240`aS00<@Q0aS36<01PaS0a2400<DYA245:D01a2410aS1Q2400HDYAS66<HH
aQ2436<248@00`aS48@<H`0336<3248348@136<000@48@0<00048@@Q1248@P001248@SF]LiaF]C6<
0T8@1cg_00@icT8@@Q1240<mk`92408icP03?Nm244Ha00=6<@924004?NlicSW>?Nl4>Lh3=Jd00cW>
=Jde[@04>Lh2=Jd00c6<=JdicP02=Jd3>Lh00cF]>Lhe[@04=Jd00cW>=JdicP03>Lh2=Jd013W>?Nli
cSg_0SW>0Sg_00<icSF]=Jd00SF]00@icSF]=JdicP=24005?NlicSW>>Lhmk`03>Lh01T8@?NlicSW>
@Q0mk`<e[@8icP03<H`e[CF]008aS08]J`08<H`]Jc6<:DXaS3g_>Lhe[@8]J`0:=JdaS36<:DX]Jc6<
=JdaS2U:9BT2;F/012U:9BTU:BDY1RU:00<U:BU:9BT00b482BDY00DYBRe[;F/aS2U:008U:@8YBP03
;F/YBRe[00<YBP049BTQ22488@P29BT012U:9BTYBRU:0be[00<U:BU:8@P00R4800<Lib489BT00bDY
12U:0R480RDY00DYBRDY9BTU:B4800<Li`8Q208U:@058@PicTYBBU8mk`029BT00bU:9BTU:@038@P0
12DY8@PQ21S60QcW00@Q22DY8@PLi`8Q20047>LQ21cW7>L29BT00bU:8@PQ20039BT012489BTU:BDY
1R4800DU:B488@PLib4800<U:@038@PLib48008U:@068@PU:BU::DXU:B480RDY0R4800<HaQcW8@P0
0bDY00<Lib488@P00R480RU:0RDY00PQ22DY8@PQ22U:;F/YBRDY0QcW12DY00<Q22DY8@P00RDY1B48
00<LiaS66<H021cW00DHaQcW6<HLib4800<Li`8HaP<Li`066<HQ21cW8@PU:B4811cW00<Q21cW6<H0
1AcW0QS60QcW00DU:B487>LLiaS6008DY@036<HLib48008HaP8Li`<HaP037>LQ21cW008Li`HHaP<L
i`036<HLiaS600<Li`PHaP8DY@056<H@Q1BU36<@Q0025:D00aS67>LHaP045:D011245:DDYAS611cW
0QBU0QS60QBU0Q2400@DYA2448@DY@<HaP045:DHaQBU5:D36<H45:D26<H00aBU48@DY@035:D00a24
36<DY@035:D348@45:D36<H011BU48@HaQS60QBU0Q2400<DYA2448@00Q240QBU00@@Q1BU48@DY@@@
Q08DY@8@Q08DY@8@Q08<H`8@Q0055:D@Q12448@DY@0948@01ABU6<H@Q12436<00a240`aS00<@Q0aS
48@01@aS112410aS00<@Q0aS36<00PaS11240PaS0Q240`aS1Q240`aS00@8@PaS48@DY@<@Q0@DY@D@
Q08<H`03248<H`aS00D<H`0000@000@Q124000848@030008@P@Q00848@0536<icWNmF]HaS003@Q02
?Nl0148@>Lhmkcg_0T8@0Sg_00=243g_@Q000Sg_00=243g_@Q000d8@00A6<D8@AS4mk`8icP8mk`8i
cP03=JdicSW>008icP<e[@DicP04=JdicSF]>Lh2=Jd4>Lh013F]>LhicSW>0cF]1CW>0Sg_00@e[CW>
>Lhmk`HicP06=JdicS6<=JdaS3F]0Sg_0T8@13g_0SW>00Dmkd8@?Nlmkd8@008mk`8icP8e[@03<H`e
[CF]00<e[@8aS08]J`05<H`]Jbe[=JdicP02?Nl6<H`012e[<H`aS36<0RU:0S6<0RU:00<U:BU:9BT0
0RU:00D]JbU::DXU:BU:00@U:@038@PU:BDY008U:@068@PU:BDY:DX]JbU:12e[0RDY00@YBRDY:DXY
BP8]J`07:DXQ22DY9BTQ22DY7>L00R4800@YBRe[;F/YBP@U:@8Q20047>LQ22489BT3:DX39BT2:DX2
9BT38@P00bU:8@PLi`027>L00b489BTU:@028@P013F]AS56<CW>0RDY00@]JbU::DXU:@<Q20@Li`05
9BTQ22488@PU:@058@P01QcW8@PLib489BTYBPDU:@03:DXU:BDY008Li`HQ20059BTQ22DY8@PU:@06
8@P00bDY:DXU:@038@P012U:8@PLiacW0b480acW00<Q22DY8@P00RDY0bU:0bDY00DQ22U::DXYBRDY
008Li`058@PU:BU:;F/YBP048@P29BT38@P01AcW8@PLiacW6<H00QcW0R480QcW00<Q21cW6<H00QcW
0R480acW00@Q21cW7>LLi`8HaP8Li`059BTQ22487>LQ20037>L00aS67>LLi`028@P00acW6<HHaP02
7>L00b487>LLi`026<H00aBU7>LHaP046<H27>L011S67>LLiaS611cW0aS600<LiaS67>L00R4800<L
iaS66<H00QcW00@HaQcW6<HDY@8HaP057>LHaQS65:DHaP025:D248@011BU48@DYABU11S600<LiaBU
5:D00aBU0QS60QcW00DHaQBU5:DDYAS600<@Q0055:D@Q1BU48@DY@076<H55:D36<H01aBU6<HDYABU
6<HDYA2400<DY@046<H@Q12448@25:D248@01ABU6<HHaQBU48@00aS60Q2400<<HaBU5:D00a240QBU
0a2400@DYAS65:D<H`@@Q0@DY@<@Q00336<@Q124008@Q0045:D<H`aS48@35:D248@011BU48@DYA24
0aBU112410aS00D@Q0aS48@<Ha2400@<H`0448@DYA2448@336<0112436<<H`aS0Q2400<DYA2448@0
0`aS112400<<Ha2448@00PaS0a240PaS00<@Q1BU5:D00Q240aBU0Q240`aS0a2410aS0Q240PaS0000
0`@Q00048@0512402PQ2124000aS>Liooekg=Je6<D8@0cg_0T8@00<mkd8@@Q000d8@00Q6<D8@>Lhi
cSF]?Nm243g_13W>00DmkcW>>LhicSg_00924004AS4mkcW>>Lh3?Nl00cW><H`aS002=Jd3>Lh3=Jd0
0c6<=JdicP02>Lh00cF]>Lhe[@02=Jd6>Lh2?Nl01SW>=Jde[CW>?Nm2408mk`07>Lhmkcg_>Lhe[C6<
=Jd00S6<0SF]1SW>00E243g_@Q16<D8@00@mk`=2408mk`8icP<e[@05<H`]Jbe[:DX]J`06<H`013F]
<H`e[Be[0S6<00De[C6<;F/]Jc6<008e[@<]J`8aS004;F/YBRDY9BT3:DX01BDY:DXYBRe[:DX00bDY
00<Q22DY8@P00bDY0R480RDY00/YBRe[;F/aS2e[9BTYBRDY:DX]JbU:008U:@<Q200;9BTQ22488@PU
:BU:;F/YBRe[:DXU:@028@P00bDY8@PQ20058@P01bDY:DXYBRU:9BTYBRDY008Q208U:@0A7>LQ21cW
7>LQ22DY8@PU:AcW6<He[D8@CW=242DY8@PYBP029BT00b487>LLi`028@P37>L00b487>LQ20048@P0
0acW8@PLi`027>L88@P59BT00bU:9BTU:@049BT38@P29BT28@P00aS68@PU:@059BT48@P032DY8@PL
ib489BT]JbU:9BTLib489BTYBP<U:@<YBP8U:@<YBP8U:@<Q20<U:@<Q20059BTQ22488@PU:@028@P2
7>L01B487>LLiacW6<H00b480aS60acW00DHaQcW7>LQ21S600HLi`038@PU:B4800@Li`8HaP047>LH
aQS67>L28@P00acW6<HLi`038@P01QcW6<HHaQcW6<HLi`8DY@8HaP8Li`066<HDYABU5:DHaQcW1AS6
1QcW00@Q21S66<HHaP@Li`066<HDYABU5:DHaQBU112400@DYA245:D@Q08HaP8DY@0448@DYAS648@2
5:D27>L01aS67>LLiacW6<HDYAS6008DY@D@Q0046<HLiaS66<H55:D00aS65:DDY@025:D36<H75:D0
11245:D@Q1BU0QS611240QS600HDYA245:DHaQcW6<H95:D00a245:DDY@0348@01ABU6<HDYA245:D0
0Q2400@DYAS65:DDY@8@Q0045:D<H`aS36<248@00`aS48@@Q0025:D348@336<848@336<248@010aS
48@<H`aS1A240PaS1A2400D<Ha2448@@Q0aS00<@Q08<H`0348@<H`aS008@Q0045:D@Q12436<648@2
36<00a2436<@Q0055:D00aS65:D<H`0236<01A2436<@Q0aS48@00PaS0`Q200021240100012448@00
0P@Q00X8@P@Q124<Hcg_OomNmcF]@Q16<@8mk`9240<mk`03@Q16<Cg_00=24003?NlicSW>008icP03
?NlicSW>008icP8mk`06@Q0icSg_?Nm243g_0SW>13g_00<icSF]<H`00S6<00@icSg_>LhicP8aS0@e
[@8icP04<H`e[CF]>Lh2=Jd2>Lh013g_>LhicSg_0cW>00@e[Cg_?Nlmk`<icP8mk`04>Lhe[C6<<H`2
=Jd0136<>LhicSg_0SW>0Sg_1T8@0Sg_00<icSg_?Nl00cg_00HicSF]=JdaS3F]<H`3;F/6<H`00be[
<H`aS005<H`012e[:DXaS36<0be[0S6<0be[0RU:00<U:BU:9BT00RU:00LU:BU::DXYBRDY8@PLi`04
9BT00b489BTU:@039BT00be[<H`aS008:DX01B489BTYBRU:9BT00QcW00<U:B48:DX00bU:00H]JbDY
9BTLib489BT48@P00acW8@PU:@049BT00bU:9BTLi`028@P29BT00acW6<HLi`038@P02BDY8@PLibe[
=Je243g_;F/YBP029BT2:DX01BDY8@PLib486<H00QcW00<Q21cW7>L01R4811cW00<Q21cW8@P00RDY
00@Q22DY8@PQ208U:@03:DXU:B48008Q208U:@048@PLiacW9BT38@P021cW8@PQ22489BTQ22DY8@P6
9BT38@P39BT38@P00bDY:DXYBP039BT3:DX49BT00bU:8@PQ20028@P39BT00bU:9BTU:@098@P37>L0
0aS67>LLi`047>L00b487>LLi`067>L26<H37>L48@P37>L011S67>LHaQS60QcW00<Q21cW7>L00QcW
00<HaQcW7>L00R480QcW1QS60acW00<HaQBU6<H011S60aBU0QS60QcW00<Q21cW8@P00QcW0QS60QcW
00@HaQcW7>LHaPHDY@0348@DYABU008DY@8HaP0348@DYAS6008HaP@DY@@HaP8Li`<HaP8DY@<@Q004
36<@Q1BU5:D26<H35:D26<H25:D011246<HHaQS60QcW00<HaQBU5:D00QBU00HHaQBU5:D@Q1BU6<H4
5:D248@25:D26<H00aBU6<HDY@035:D01AS65:DDYABU48@00QBU00<HaQBU5:D00a2411BU0a2411BU
1Q2400<<Ha2436<011240`aS00D@Q1BU48@@Q0aS00<@Q0055:D@Q0aS36<@Q00336<00a2436<@Q003
36<248@010aS48@@Q1240PaS00@@Q0aS36<<H`<@Q0<<H`8@Q00636<@Q0aS36<@Q0aS0Q2400HDYA24
48@@Q1BU48@336<00a245:DDY@025:D348@00aBU48@DY@0348@236<248@236<1248136<124800005
00048@@Q1240000312402`Q200048@aS?NmoofLi>Li:DTicBU800THa00=244HaAS40148@0THa0T8@
00<mkd8@@Q000Sg_0SF]00@aS3F]=JdicP<e[@<icP<e[@<mk`05>LhaS36<=JdicP02@Q000cW>?Nle
[@03=Jd013W>=Jde[C6<0SF]00<icSF]>Lh00SW>00<mkcW>?Nl00T8@00HmkcW>>LhmkcW>?Nl2=Jd0
1Sg_@Q1243g_=JdaS08e[@@aS003=JdicSW>008icP<mk`92408mk`04>Lhe[CW>>Lh4?Nl3>Lh2<H`0
12e[<H`aS36<0Re[00@YBRe[<H`YBPD]J`03<H`e[C6<00<]J`8aS007;F/aS36<<H`]JbU:;F/012U:
00@]JbU:9BTU:@<YBP039BTQ224800@U:@038@PLibDY00<U:@0:8@PYBS6<>Lhe[BU:9BT]JbU:;F/5
:DX38@P00bDY:DXU:@02:DX29BT012489BTU:BU:0RDY00<Q21S68@P0124800<U:B48:DX00bDY1AcW
0R4800<U:BU:8@P00b480Re[00He[D8@>Lhe[BDY8@P29BT38@P011cW8@PQ22DY0R4800<Lib489BT0
0QcW00<Q22DY9BT00QcW00<U:B488@P00R480RDY00<Q22DY8@P00RDY00<YBRDY:DX00bU:0R480bDY
00<Q21cW7>L00RDY0b4800<U:B489BT00b4800@U:B488@PQ208U:@048@PU:BDY8@P89BT00bU:;F/Y
BP029BT012U:9BTQ22480RDY0R4800<U:BU::DX012DY00DQ21cW7>LQ21cW00@Q20@Li`8Q20@Li`04
6<HLib489BT28@P00aS67>LHaP027>L00aS67>LQ20028@P77>L012487>LQ22480QcW0QS600<LibDY
9BT00R4800@Lib487>LDY@8HaP048@PLiaS67>L26<H011BU6<HLiaS61ABU0QcW00HQ21S66<HHaQcW
6<H27>L36<H011BU6<HHaQcW0QS600<@Q1BU5:D00aBU00@HaQBU48@@Q08DY@0436<@Q1BU6<H348@4
6<H27>L00b487>LHaP035:D348@85:D348@35:D011S67>LHaQS611241ABU00@@Q1S66<HHaP<DY@<H
aP8DY@076<HDYABU5:D@Q1S65:D00a240QBU00<@Q1BU6<H00QBU112400<DYA245:D00QBU00@HaQBU
48@<H`<@Q0055:D@Q0aS36<8@P0336<248@00aBU36<<H`0436<00`Q236<<H`0348@236<010Q236<@
Q12410aS0Q240`aS0Q240PaS0Q2400HDYA2448@@Q1BU48@336<248@336<948@01@aS48@@Q12436<0
11240PaS00D@Q1BU5:DHaQ24008<H`@@Q0H<H`000`@Q00<000@Q12400P@Q00P8@P@Q124<HcW>OomW
>CW>0dYB0dHa248@00M6<D8@?Nm243g_@Q0mk`02>Lh00c6<=JdicP02>Lh3=Jd2?Nl4>Lh00cg_>Lhi
cP04=Jd2>Lh00d8@?Nle[@02<H`013F]>LhicSF]0S6<00@e[CW>>LhicP8e[@03>Lhmkd8@008mk`05
>Lhmkcg_@Q0icP03=Jd3>Lh2?Nl013W><H`]Jc6<0Re[0SF]1SW>0T8@00I6<D8@>LhicT8@?Nl2>Lh0
0cg_@Q0mk`05=Jd01C6<;F/aS36<=Jd012e[00<aS2e[;F/00be[0c6<2Be[0c6<00@]JbU::DX]J`8Y
BP8U:@03:DX]JbU:008U:@058@PYBRDY9BTQ20029BT28@P012DY:DXU:BU:136<0RDY00<YBRe[<H`0
0RDY0RU:00<U:B488@P00RDY00@YBRDY8@PQ208YBPDU:@<Q20067>LU:B489BTQ22DY1R4800@LiaS6
7>LLi`8Q20087>LQ22488@PU:BU:9BTe[@924004?NlYBR489BT28@P29BT012487>LLiacW0RDY00@Q
21cW7>LLi`<Q208Li`079BTQ22DY8@PLib489BT00b480RDY00@Q22DY:DXYBP@U:@04:DXU:BDY9BT3
8@P00acW8@PU:@029BT28@P29BT00b489BTQ20028@P00bDY:DXQ20028@P39BT28@P39BT00b489BTU
:@03:DX00bDY:DXU:@059BT28@P01BDY:DXYBRU:9BT0124800@LiaS67>LHaP<Q20037>LQ2248008L
i`049BTLiacW6<H57>L012487>LHaQS611cW00DHaQcW8@PU:B4800<HaP8Li`8Q20<Li`038@PLiaS6
008Li`8U:@<Li`066<HDYABU5:DLiaS60acW1AS60QBU0QS60QBU0QcW00<Q21cW6<H00aS600<LiaS6
7>L01AS600DDYAS65:D@Q1BU008@Q0036<HDYABU00<DY@0348@DYA24008@Q08DY@086<HDYABU48@H
aQcW9BTLi`8HaP@DY@0:48@<H`aS48@DYAS65:D@Q1BU48@45:D01Q245:DHaQS67>LHaPLDY@0448@D
YABU5:D36<H25:D00a246<HHaP027>L01ABU48@DYA246<H01ABU00H@Q1BU5:DDYAS65:D348@00aS6
5:D@Q00248@55:D00aS648@@Q00236<248@00`aS248<H`0236<25:D011245:D<Ha240PaS00D8@PaS
48@@Q0aS00<@Q0<<H`8@Q0D<H`8@Q08<H`@@Q08<H`055:D@Q1246<HDY@0248@00`Q236<<H`0236<0
1Q2436<<H`aS48@DY@<@Q0035:D@Q12400@<H`<@Q00436<@Q0aS48@25:D00a245:D<H`0236<248@2
36<011245:D@Q0aS0@Q200004@0012448@@Q00048@001248@P@Q000<HcW>OomS63W>AS400dYB00A6
<DYBAS56<@9:DP96<@=:DP03CW=6<D8@00924003?NlicS6<008aS005=JdaS36<=JdicP02=Jd2>Lh2
=Jd00c6<>LhicP03=Jd2>Lh2?Nl00cW>@Q124002?Nl3>Lh00cF]<H`]J`02<H`2>Lh01SF]>Lhe[CF]
>Lhmk`92408mk`04@Q16<DHa@Q02?Nl2AS4013g_=JdaS3F]1C6<0cF]0c6<00De[CW>=JdaS3F]008i
cP8aS009=JdicSW>=JdaS3F]>LhmkcW>00<e[@04>Lhe[Be[<H`2:DX5;F/01BU:;F/]Jbe[<H`00Re[
0S6<12e[00@aS2e[;F/]J`8YBP04;F/YBRe[:DX4;F/012U:9BTQ22481BDY00DQ22DY9BTU:Be[00<Y
BP04;F/aS2e[;F/2:DX01Be[:DXYBRDY;F/00RU:12DY00@YBRe[:DXYBP8U:@8Q208U:@<Q20@U:@04
8@PYBRU::DX58@P00acW8@PQ20027>L012489BTU:BU:0RDY0R4800LicTHaBU8mkbDY8@PYBP02;F/0
12U:8@PHaQcW1B4800DLib488@PQ22DY008Q20079BTQ22DY8@PU:B487>L00bDY00DYBRDY8@PQ22DY
008YBP8Q208U:@@Q208U:@8Q208U:@04:DXU:BDY9BT2:DX00bDY8@PQ20048@P012DY8@PQ22480bDY
00<YBRDY9BT01RDY12U:0RDY00<YBRDY9BT00bDY00<YBRDY9BT00RDY0R4800<Lib488@P00R480acW
00HQ21cW7>LQ21cW6<H37>L38@P39BT27>L011S67>LQ22480QS600<Lib488@P00acW00@Q21cW7>LL
i`8U:@038@PHaQcW008Li`036<HLiacW00<Li`<Q20077>LQ21cW8@PLiaS65:D00QS60QBU00DHaQcW
7>LHaQBU008HaP035:DHaQS6008HaP035:DHaQS6008HaP0:5:DHaQcW7>LHaQBU48@DYAS67>L25:D2
48@00aBU6<HDY@065:D248@00aBU48@@Q00248@26<H27>L36<H011BU48@@Q1BU0Q2400DDYAS66<HH
aQBU00<@Q0035:D@Q12400HDY@D@Q0045:D@Q1BU5:D37>L35:D01QS67>LHaQBU48@DY@8HaPD@Q003
5:DHaQcW00@HaP095:DHaQS65:D@Q0aS48@HaQBU00<@Q0056<HDYABU5:D@Q00236<248@236<348@0
1@aS48@@Q1BU48@01@aS00@8@PaS36<<H`@@Q08<H`@@Q0<<H`0748@<Ha2436<@Q1BU48@00PaS00H@
Q1BU5:DDYA245:D348@00`aS48@DY@0248@236<348@010aS48@<Ha240`aS0Q240PaS0a2400@<Ha24
5:D@Q08DY@<@Q08<H`L@Q04<H`000P@Q00<000@Q12400`@Q00P8@P@Q1248@SW>OomS63F]0dYB00=6
<DYBAS401DHa0TYB00=6<DYBBU800THa0d8@00hmkcW><H`]Jc6<=JdicSF]<H`e[CW>=JdicSF]0SW>
1SF]0cW>00@mkd8@?Nm2408icP04?Nle[CF];F/3<H`2=Jd6>Lh2@Q000cg_@Q0mk`03@Q04?Nl2@Q00
1SF]<H`aS3F]<H`]J`8aS08icP@aS005=JdicSW>?NlicP04=Jd01SW>=Jde[C6<=JdicP8mk`8e[@03
>LhaS36<00<aS0<]J`8aS0H]J`03:DXaS3F]008aS003;F/YBS6<00<aS004;F/YBRDY:DX3;F/2:DX2
;F/2:DX01bDY8@PQ2248:DXU:B48008U:@8YBP039BTYBRU:008YBP@]J`8YBP@U:@8YBP<U:@04:DX]
JbU::DX29BT012U:9BTU:BDY0R4800<Lib489BT00RDY0R480bDY0R480RDY0R4800<Lib487>L00R48
00<U:BU:9BT00bDY00PQ22e[?Nm6<Cg_;F/Q22DY0Re[00@YBR487>LLi`<Q20039BTQ22DY008Q208U
:@058@PU:B488@PU:@028@P27>L28@P2:DX49BT28@P3:DX00bDY8@PQ20078@P29BT00bU:9BTU:@02
9BT2:DX58@P39BT00acW8@PQ20029BT00b489BTYBP029BT00b489BTYBP07:DX012DY8@PQ22480RU:
00@]JbU::DXU:@@Q20039BTQ21cW008Li`@Q20PLi`068@PLib488@PLib483acW0b481QcW0aS60R48
00DLibDY9BTU:B4800<HaP037>LHaQBU00<DY@<Li`036<HDYAS6008HaP045:DHaQS65:D26<H01AcW
6<HDYABU6<H00QcW00DDYA245:DHaQcW008DY@0348@HaQBU00@DY@0:6<HDYA2448@DYAS648@<Ha24
5:D248@00aBU6<HLi`026<H011cW5:DHaQBU0QS60a2400<DYAS65:D011BU0Q2400<DYA245:D00aBU
00<HaQ2448@00PaS0QBU0QS60QBU0QS60QcW11S60QBU00@HaQBU5:D@Q0@DY@0448@DYA2448@36<H0
0aBU48@DY@025:D248@55:D01A245:D@Q1BU48@00`aS00<@Q0aS48@00`aS00H8@Q245:DDYA242485
36<2248236<348@436<00a2436<@Q00248@236<448@00`aS48@<H`0248@00aBU48@DY@0248@00aBU
48@@Q00236<00a2436<<H`0336<00a245:D@Q00548@236<00a2436<<H`0236<348@011BU48@@Q1BU
0a240`aS00<@Q0aS48@00`aS00031240100012448@000PQ200/000@Q248e[GNmG_Le[D8@BU96<DYB
00=6<@9:DP9>L`9:DP03CW=:DTic00=:DP04CW=:DT8@>Lh3<H`2=Jd01CW><H`e[CF]>Lh00SF]00<i
cSF]=Jd00SW>00He[C6<=Jde[Cg_>Lh2?Nl01D8@?Nlmkcg_>Lh00SF]00<icSg_?Nl00SF]00<icSg_
?Nl00S6<00<e[CW>>Lh00SF]00@icSg_?Nm2408icP8mk`92408icP03=JdaS36<008e[@<aS08e[@8a
S00=;F/aS36<=JdaS3F]<H`]Jc6<=JdicSg_=Jd00c6<1CF]00PicSg_?NlicS6<=JdaS3F]0c6<0Re[
00<YBRe[;F/00S6<0Re[00/aS2e[<H`]JbU:;F/YBRe[9BTYBRDY00<YBP03;F/YBRU:008YBP8U:@03
:DXU:BU:00<U:@048@PU:BDY9BT5:DX00bDY:DX]J`03:DX29BT28@P00bDY:DXYBP029BT01B48:DXU
:B489BT00RU:00HQ22DY:DX]JbU:9BT68@P29BT012489BTLiacW0RDY0RU:00<U:B487>L00R4800`U
:B487>LQ22DY8@PaS3W>?Nm6<CW>;F/29BT2:DX00bDY7>LQ20028@P01BDY8@PQ22489BT00acW00TQ
21cW7>LQ22DY8@PLiaS67>L012DY0b4800<U:BU:9BT00R4800DLibDY:DXU:B48008Li`DQ20049BTQ
22U:;F/2:DX29BT012U:8@PQ22480RDY0QcW00<Q22DY9BT00RDY0RU:00HU:B489BTLib489BT2:DX0
0bDY8@PQ2002:DX00bDY:DXU:@028@P01bDY;F/]JbU:9BTYBRDY00<Q208U:@8Li`036<HLiacW008L
i`038@PLib48008Li`036<HLiacW008Q208U:@8Li`8Q20047>LHaQS65:D26<H37>L03aS67>LQ2248
7>LQ22DY8@PHaQBU7>LQ21cW5:DHaP047>L012487>LLiaS60QcW00DHaQBU6<HHaQBU008HaP8Q20<L
i`046<HLib487>L36<H35:D01acW6<H@Q1245:DLiaS600@DY@036<HDYABU008@Q0HDY@046<H@Q124
48@45:D00a246<HHaP045:D00aS65:DDY@025:D348@00aBU6<H@Q0075:D01aS65:DHaQS65:D@Q1BU
008HaP075:D@Q1BU48@<Ha245:D00aS600PDYA247>LLib487>LDYA241aBU0Q240QBU11S60a2400D<
Ha2436<<HaBU00DHaP037>LHaQBU008DY@L@Q00536<DYAS65:D@Q00236<00a2436<<H`02248636<0
0a245:D<H`0336<0112436<<H`Q20PaS00<@Q0aS36<00PQ20Q240aBU1A240`aS00H@Q1BU36<@Q0Q2
36<248@25:D248@00`aS48@@Q00436<448@00aBU48@DY@035:D448@436<248@124800003124000@Q
00848@0400048@@Q248212401@Q2<HakgUkg>Lh00THa00=244HaAS400THa0TYB0dic14YB00M>LdYB
BU9>LdYBAS4mk`03<H`01CF]>LhaS3F]<H`013W>0SF]00@icSF]=JdaS0<e[@<icP=24005?NlicSg_
>Lhe[@03>Lh2=Jd2?Nl2=Jd0136<>LhicSF]13W>00<mkcW>?Nl00SW>00Dmkd8@@Q0mkcW>00<e[@8a
S08e[@8aS08]J`8aS08e[@8aS08e[@8aS08e[@05>Lhe[C6<<H`]J`03=Jd00cW>=JdicP03>Lh2<H`2
=Jd2<H`00be[:DX]J`02:DX2;F/2<H`4;F/012U:;F/]Jbe[0bU:0RDY0bU:00<]JbU::DX00bU:0RDY
00HYBRDY9BTU:AcW8@P39BT3:DX29BT00bU:;F/]J`02;F/38@P011cW9BTU:BU:0bDY00<YBRDY9BT0
0bU:0RDY0bU:00@Q22DY9BTQ208Li`038@PU:B48008U:@8Q208Li`048@PU:BDY7>L38@P29BT28@P0
2QcW8@P]Jbe[>Li6<D8@=JdYBR480RU:00<Q21cW7>L01B4800LU:B488@PLib489BTQ20027>L29BT0
0acW6<HLi`038@P=9BT37>L58@P00bDY8@PU:@03;F/49BT28@P01BDY8@PU:B489BT0124800@U:BU:
9BTU:@8Q208U:@<YBP<U:@07:DX]JbDY8@PLib489BT00RU:0RDY00DYBRDY8@PQ21cW008Q20039BTL
ib4800@Li`056<HLiacW7>LHaP037>L00b489BTU:@038@P67>L26<H27>L01B487>LLiacW9BT00R48
00<U:AcW7>L00acW0QS600@DYAS67>LLi`8U:@078@PLiaS65:DLiaS67>L00aBU00<HaQcW7>L00QcW
00PQ21cW7>LLiaS67>LHaQcW0QS60QBU0QS600@DYAS65:DDY@<HaP035:DHaQBU00/DY@046<HDYABU
5:D348@25:D00a245:DDY@025:D02AS65:DDYABU48@DYA245:D@Q0035:D00aS648@DY@025:D00aS6
5:DDY@0248@25:D00aS65:DDY@0248@01@aS48@@Q1S65:D00aS60QBU00DLib488@PHaQ2400<DY@04
48@<Ha2448@25:D01a245:DDYABU6<HDYAS6008DY@H@Q0055:DHaQS66<HLi`036<H00aBU48@@Q004
36<00a245:D@Q0035:D01A2436<<H`aS48@00PaS00@8@PaS36<@Q08<H`03248@Q124008@Q00436<@
Q12448@:36<00a2436<@Q0025:D011245:D@Q1240`aS0Q2400DDYA2448@@Q0aS008DY@0348@<H`aS
00<@Q0@<H`0348@<Ha2400<@Q0<DY@<@Q0065:D@Q0aS36<8@Q240`aS00000`001240000512402`Q2
00048@Q2=Jeg_Ekg=Je244YB@Q000THa00=:DTHaAS400dYB00E>LdYBCW=6<DYB00E6<@9240<aS005
=JdicSW><H`e[@02<H`2=Jd01CW>?Nlmkd8@?Nl00SW>00<e[CW>>Lh00cg_0cW>0SF]0S6<00P]JcF]
>LhicSg_>Lhe[CW>0c6<00<e[Cg_>Lh013F]0cW>0Sg_0SW>00@e[CW>=Jde[@DaS0<e[@04;F/aS36<
=Jd2<H`00be[=JdaS002<H`012e[=Jde[CF]0S6<0SF]0S6<00@icSg_?NlicP<aS003;F/e[CF]008i
cP03=JdaS2e[008]J`04=JdaS36<=Jd4;F/00c6<;F/YBP02:DX00bDY8@PYBP02:DX29BT00be[=Jda
S003;F/012U:;F/YBRe[0RU:0bDY00@YBRe[:DXU:@8YBP@U:@8]J`05:DXU:B489BTYBP079BT28@P3
9BT5:DX01RDY8@PU:BU:9BTQ208YBP049BTQ22487>L39BT58@P29BT38@P29BT00be[:DXaS002@Q00
0cW>;F/Q20049BT012487>LQ22481RDY0R480acW0b480QS612480RDY0R4800@U:B488@PQ20@U:@8Y
BP049BTQ21cW9BT27>L00aS68@PYBP029BT01B489BTU:BU:9BT00b480bDY0R4800HU:BU::DXU:B48
9BT48@P012DY:DXU:BDY0R480RDY0R4800<U:B489BT00RDY00<]JbU:9BT00RDY00<YBRDY9BT00acW
0b4800DLiaS65:DLiaS600LLi`8HaP047>LQ22489BT28@P57>L00aS67>LHaP027>L01AS68@PU:BDY
8@P011cW0QS611cW00PQ21cW6<HHaQcW6<HLiaBU0QS60QBU00H@Q1S67>LHaQcW8@P37>L01aS67>LQ
22DY7>LDYA2400<HaP075:DHaQBU6<HDYAS65:D00Q2400LDYAS65:DDYA245:DHaP035:D448@35:D0
1Q245:DHaQcW8@PLi`8@Q0035:D@Q1S600<DY@8@Q0086<HDYABU48@DYAS65:DHaPPDY@0348@DYAS6
00<DY@8@Q0<DY@8HaP8DY@0736<@Q1cW8@PYBR485:D00a2400<DYA2448@00aS60aBU0QS600TDYA24
48@DYAS648@DYA245:D00Q2400<DYAS65:D00Q2400@DYA2448@@Q08DY@8@Q0@<H`045:DHaQcW7>L2
48@336<448@336<448@236<00`Q236<@Q00248@00`Q236<<H`0236<2248236<25:D248@236<00a24
36<<H`0448@236<0112436<<H`aS1A240PaS00<@Q0aS48@00`aS00<@Q0aS48@00aBU0PaS0a240PaS
00<@Q0aS24800PaS0@Q2000412400`0012448@0412401PaS=Jeg_E[F=Je240=6<@9:DP05AS5:DTHa
BU9>L`07BU82AS43@Q001CW><H`aS3F]>Lh00SF]00HicSF]<H`e[C6<=Jd2?Nl0148@?NlicSW>0SF]
0SW>00<mkcW>>Lh00Sg_00<icSF]<H`00SF]00HaS3F]>LhicSg_>Lh4=Jd013W>=JdicSW>13F]00<m
kcW>?Nl00SW>0Sg_00@icSF]<H`icP<aS003;F/e[CF]008aS003;F/aS36<008aS004;F/YBRe[;F/3
<H`6=Jd3<H`013W>?NlicSF]0S6<00<]JcF]=Jd00SW>0c6<00DYBRe[<H`aS3W>00@aS003;F/YBRe[
00<]J`8U:@8YBP03;F/U:BDY00HYBP<]J`HYBP039BTYBRe[00<YBP@U:@<]J`03:DXLib48008U:@<Y
BP<Q2003:DXU:B48008U:@03:DXU:BU:008YBP8U:@8Q20<U:@048@PU:BDY9BT88@P00bDY8@PQ2003
8@P29BT00bU:9BT]J`02@Q000cg_;F/Q20039BT28@P27>L29BT3:DX29BT38@P01AcW8@PLiacW6<H0
0QcW00<Q21cW9BT0124800<U:B489BT00bDY0b480bDY124800<Lib488@P00b481BDY00@YBRDY8@PU
:@8YBP039BTQ224800<YBP049BTQ22489BT28@P29BT00bU:9BTQ20029BT00b489BTU:@029BT00b48
9BTU:@03:DX39BT58@P00acW8@PLi`047>L022487>LLiaS67>LHaQcW6<H27>L68@P37>L46<H47>L0
1B487>LU:BDY8@P00acW00DQ21cW6<HDYAS600PLi`8HaP8DY@8HaP<DY@048@PLib488@P46<H00b48
7>LHaP036<H01aBU6<HDYABU48@DYAS600@DY@8HaP/DY@0548@DYABU5:D@Q0026<H00acW6<HHaP04
5:D26<H248@00aBU6<HDY@0248@25:D00aS65:DHaP045:D26<H25:D011S648@DYAS611BU0aS60aBU
0Q2400@HaQcW8@PQ208HaP045:D@Q1BU48@25:D00aS65:DDY@045:D00a245:DDY@045:D448@00aBU
6<HHaP045:D248@00`aS48@@Q00248@336<011BU6<HLiacW0QBU1@aS00<@Q1BU36<00`aS00<@Q0aS
24800`aS0a2410aS00@@Q0aS36<8@P8<H`D@Q08<H`8@Q0<<H`<@Q0<<H`8@Q0035:D@Q0aS00<<H`L@
Q00436<@Q1245:D648@00`aS48@<H`0436<12480000400048@@Q000212402`002488@P@Q0008@SW>
NmiNmc6<@Q000dYB14Ha1Tic00U:DTHa@Q1244HaBU96<D8@>Lh00S6<00@]Jc6<=JdicP<aS0<e[@<i
cP@mk`96<@924005>Lhe[CF]=JdicP02=Jd0136<=JdaS2e[0S6<00TicSF]=Jde[CW>=JdicS6<=Jd0
13W>00<e[CW>=Jd00cF]0SW>0cg_00<icSF]=Jd01C6<00DicSF]<H`aS3F]00@aS003;F/aS2e[00<]
J`05<H`e[CF]>Lhe[@04<H`013F]<H`aS36<0SF]0c6<00@]Jc6<<H`e[@8aS08icP03=JdaS2e[00<a
S004;F/YBRU::DX4;F/01S6<;F/aS2e[9BTaS08mk`04>LhYBR48:DX29BT00bU:9BTU:@04:DX012e[
<H`YBRU:0Re[00<YBRDY:DX00Re[1RU:00<U:BU::DX00RU:0bDY0b480RDY0RU:0b480RU:0bDY1248
2BDY0R480QcW00TQ22U:;F/YBS6<?Nm243g_=Jd00b4800<U:Be[9BT00b4800<U:B489BT01BDY0QcW
0R480RDY124800<Lib488@P0124812DY0b480RDY0b4800@U:B488@PLi`8Q20037>LQ22DY00<U:@04
8@PU:BDY7>L49BT28@P00bDY:DXU:@028@P01AcW8@PU:BDY8@P01BDY00LQ22DY8@PQ22DY8@PU:@02
8@P01BDY:DXYBRDY8@P00RDY0R4800<Lib488@P0124811cW00XQ21cW7>LLiaS67>LHaQcW6<HLi`8Q
20039BTLiaS600DHaP8Li`048@PLib487>L48@P67>L011S67>LLiacW0RDY0QcW1ABU0Q2400HDYAS6
6<HDYAS68@P27>L00aBU6<HLi`037>L00aS65:DDY@025:D46<H248@25:D26<H35:D26<H25:D01A24
5:DDYAS65:D00QS600<@Q1BU48@00QS60QBU00DHaQBU5:DDYAS6008DY@8@Q0@DY@036<HDYA2400@D
Y@0>48@DYAS66<H@Q1BU48@DYA245:D@Q1BU6<HLi`8DY@0748@DYABU5:D@Q1BU48@00QBU00<HaQcW
7>L00QBU00<@Q1BU5:D00a2400<DYAS648@00aBU00H@Q1BU48@HaQBU48@25:D248@00aBU6<HHaP02
48@00aBU48@@Q00248@00`aS48@@Q00648@36<H00acW5:D@Q00236<00aBU48@@Q00348@436<248@0
0aBU48@<H`0236<00aBU48@<H`02248636<348@00`aS48@<H`0336<448@00`aS48@@Q00548@02PaS
48@@Q124248<Ha245:D@Q0aS0Q240PaS0Q240QBU0a2400P<Ha2448@@Q0aS48@<Ha240@Q200000`@Q
00048@0512402@Q200048@aS>Lioof<H=Je24004BU82AS43BU82CW<015:DCW=:DTYB0T8@00I6<DYB
AS5243W>=Jd3<H`00cF]<H`e[@02<H`01CF]>Lhe[CF]>Lh00Sg_00DicSg_?Nm244Ha0092408icP05
=JdicSW>=JdaS002;F/6<H`01SW>=Jde[CF]<H`e[@@icP8e[@03>Lhe[CW>008e[@<icP8mk`8icP04
=JdaS3F]<H`2=Jd3<H`3=Jd01c6<;F/]Jbe[:DX]JbU:008]J`8aS08e[@03>LhaS36<008aS0Le[@04
;F/YBRe[=Jd3<H`00be[>Lhe[@02>Lh00be[<H`]J`02<H`012e[:DXYBRe[0RU:00`aS2e[<H`]JbU:
9BTe[CW>@Q0mkbe[:DX29BT012U:9BTU:BDY1RU:0Re[00DYBRe[:DXYBRe[008YBP05;F/U:B488@PU
:@03:DX29BT01BU:;F/YBRDY8@P00RDY00<Q22DY9BT00RDY0R480RDY0RU:12DY0b4800<U:BU:9BT0
0R4800PU:BU:9BTQ21BU7>LQ22DY0RU:00H]JcF]>Li243F]:DX28@P00bDY;F/U:@028@P00bDY8@PU
:@038@P00bU:9BTQ20048@P00acW8@PQ20048@P01AcW8@PQ22489BT00R480bDY0b480RU:00<U:B48
8@P00RDY0R4800@U:B488@PQ208U:@8Q20039BTYBR48008Q20XU:@038@PU:B4800<Q20<YBPDU:@8Q
20049BTQ22DY9BT2:DX29BT01BU:9BTU:AcW6<H00R4800HU:B487>LHaQcW8@P87>L46<H01B489BTU
:B487>L00QS60QcW0aS600@Lib487>LLi`HQ20LLi`8Q208Li`038@PHaQS6008DY@056<HDYAS66<HL
i`026<H00acW6<HQ20027>L01QBU6<HLib487>LHaP<DY@046<HLib486<H25:D26<H00aBU48@@Q002
6<H35:D46<H248@45:D01Q246<HHaQS65:DHaP<DY@056<HDYABU5:DHaP0248@35:D00a245:DDY@02
6<H00aBU48@DY@025:D011245:DDYAS60QBU00<<Ha2448@00QBU00@HaQBU6<HHaP@DY@8@Q08DY@05
6<HLiaBU5:D@Q0035:D248@011BU48@@Q1BU0QS600<DYA245:D00aBU00@@Q1BU48@@Q0PDY@0336<@
Q1BU00@@Q00636<@Q12436<DYAS60QcW00<DYA2436<00a2420aS00<@Q1BU48@00PaS0a2410aS00D8
@PaS248<Ha2400<<H`8@Q08<H`0348@<H`aS00<@Q0<<H`0648@<Ha2436<@Q0aS112400<<Ha2448@0
0Q240PaS00<DYA245:D00a2400LDYA2448@<Ha245:D@Q00536<1248000<48@0300048@0000848@0:
24848@@Q248e[G_NF]He[DHaBU83AS400dYBAS5:DP02BU84CW<014YBCW=:DTYB0d8@0SW>0cF]136<
0SF]0c6<13W>00DmkcW>>LhicSg_0092408icP8e[@@icP8e[@06<H`e[C6<<H`]Jc6<0SF]23W>00<e
[CW>=Jd00S6<0cW>00Pe[C6<=JdicT8@>Lhe[Be[0S6<0cF]00@aS3F]<H`aS0H]J`8aS0<]J`05<H`]
Jbe[<H`e[@02<H`3;F/0136<=JdaS2e[0cF]00DaS2e[;F/]Jc6<00De[@DaS003;F/YBRe[00@]J`<Y
BP07;F/aS36<;F/YBRDY8@P00RDY00<YBRe[;F/00RDY0R480RDY0RU:0Re[00<YBS6<<H`00S6<0bU:
00D]Jc6<;F/YBRe[00<YBP059BTYBRe[9BTYBP039BT48@P00bDY:DXU:@049BT00bU:8@PU:@03:DX3
9BT00b489BTU:@029BT28@P37>L28@P2:DX01c6<?Nm243W>;F/Q22DY00<YBP039BTLiacW008Q208Y
BP038@PU:BDY00<U:@04:DXU:B488@P29BT68@P39BT78@P69BT38@P01BDY8@PQ22DY:DX01BDY00<Q
21cW8@P00bDY0R480bDY0b481BDY0bU:00<U:B488@P00R4800@Lib488@PQ208U:@<Q20039BTQ2248
00<Q208U:@038@PLiacW00dLi`046<HLiacW8@P27>L00b487>LHaP026<H37>L01QS67>LLiacW8@PU
:@8Q20036<HLiacW008Li`046<HLiaS67>L28@P37>L26<H25:D46<H45:D01AS67>LLiaS65:D011S6
00@@Q1BU5:DDY@<HaPHDY@036<HDYABU008DY@056<HDYAS65:DHaP0348@55:D26<H25:D36<H35:D3
6<H00aBU48@DY@025:D248@25:D00aS648@@Q0025:D248@00`aS48@@Q00348@25:D36<H25:D248@4
6<H248@011BU48@DY@aS0Q2400@DYA2448@@Q08DY@0348@DYABU008DY@8@Q0045:D@Q1BU48@35:D0
0a245:D@Q0025:D02A245:DDYABU36<@Q1BU6<H@Q00236<348@011BU6<HHaQBU0a2400D<Ha2436<@
Q0aS008@Q0<<H`<@Q0<<H`<@Q0D<H`04248<H`aS36<448@236<248@436<348@236<00a245:D@Q003
36<348@010aS248<Ha240PaS0a2400@<Ha2448@@Q0<<H`0348@<Ha2400<@Q0@<H`0000<000@Q0000
1@@Q00T8@P@Q000<HcW>NmiJeSW>AS400TYB0THa00E:DTHaBU96<DYB00A>L`=:DP=6<@03@Q0mkcW>
00<aS003=JdaS36<00<aS007;F/aS3F]>Lhe[C6<=Jd00Sg_0cW>0cg_1SW>00@e[CW>=JdicP8aS004
;F/aS36<<H`2=Jd013W>=JdicSF]13W>0SF]00@aS3F]=Jdmk`<icP09=JdicSW>=JdaS2e[<H`e[C6<
00<e[@DaS08]J`04<H`]Jbe[:DX2;F/00c6<;F/aS004<H`2;F/00c6<=JdaS002<H`00cF]<H`aS002
<H`3;F/2<H`6=Jd00c6<;F/]J`02<H`3;F/2:DX022e[<H`]Jbe[:DX]Jc6<:DX59BT4:DX49BT012e[
<H`aS2U:0be[00@aS2e[;F/YBP@]J`03:DXU:Be[008YBP04;F/YBRDY:DX49BT38@P59BT00b489BTY
BP049BT00bU:9BTU:@02:DX00bDY8@PQ2002:DX01b487>LLib487>LU:B48008U:@05;F/icT8@?Nla
S0029BT3:DX00bDY8@PLi`038@P02RU:;F/YBRDY8@PU:BU:9BTQ22DY0b4800<U:BU:8@P00QcW00@Q
22DY9BTQ208U:@DQ20039BTQ22DY00@U:@8Q208Li`8Q208U:@038@PU:BU:00HU:@048@PLibDY9BT2
:DX01bDY8@PU:BDY8@PYBRDY00<YBP8U:@058@PU:B488@PU:@028@P00bDY8@PQ20029BT00b489BTQ
200<8@P47>L38@P27>L00aS67>LLi`027>L28@P011cW6<HHaQS61AcW00<Q21cW6<H00QcW00<Q21cW
8@P011cW00<HaQcW7>L00b480QcW1AS60aBU0aS60Q240QcW00DQ21cW5:DDYAS6008Li`065:D@Q124
5:DLiaS60QcW00DHaQBU5:D@Q1S600<DY@036<HDYABU00@HaP055:D<H`aS36<HaP045:D36<H85:D2
6<H25:D00a245:D@Q0025:D01QS65:DDY@aS48@DY@D@Q08DY@8@Q08HaP8DY@<HaP8DY@8HaP055:D@
Q1BU48@DY@0348@25:D00a2436<<H`025:D348@01ABU48@@Q1BU48@00QBU0QS600DDYA245:D@Q1S6
008@Q0035:D@Q1BU008@Q00336<@Q124008DY@8@Q00836<@Q1S65:DHaQcW5:D@Q08<H`035:D<H`aS
008@Q0@<H`045:D@Q0aS48@436<00a2436<<H`0236<00a2436<<H`0236<248@336<248@536<011BU
48@DYABU0Q240PaS0Q2400@<Ha2448@@Q0<<H`<@Q00336<@Q0aS008@Q0035:D@Q0aS008<H`0548@<
Ha2448@DY@0336<148@136<000@48@0<00048@@Q1248@P001248@S6<MkeNmcF]0d8@0dHa00<mkd8@
@Q001dYB0dHa0T8@0Sg_00PicSF]>Lhe[CW><H`]Jc6<0Re[00DaS2e[;F/]JcF]008icP04=JdaS3F]
=Jd4?Nl00cW>=JdicP03>Lh01C6<=Jde[CF]<H`00Re[00<aS2e[<H`00SF]00<icSF]>Lh00SW>0cF]
0Re[00@aS3F]=Jde[@<aS0<icP03<H`]Jc6<00@e[@04;F/aS36<;F/3<H`2;F/2:DX2;F/5<H`012e[
<H`]Jbe[0c6<00<]Jc6<=Jd00SF]0c6<0be[0c6<00@]Jc6<<H`aS08icP03=JdaS36<008aS0<]J`05
:DXaS36<<H`YBP029BT3:DX39BT2:DX29BT6:DX49BT2:DX2;F/00bU:;F/YBP03;F/2:DX01S6<=Jde
[Be[:DXU:@8YBP@U:@<Q20039BTQ224800@U:@<Q208U:@<YBP04;F/YBRU::DX39BT00b487>LHaP03
8@P022DY7>LU:CW>BU92436<7>L39BT38@P2:DX38@P2:DX00bDY8@PQ20039BT01B489BTYBRDY8@P0
0QcW0bDY0R480RDY00<YBRDY8@P01B4800HU:BU::DXYBR489BT2:DX00bDY7>LQ20069BT012U:8@PQ
22DY0bU:0R4800<U:B489BT00b4800@U:B488@PYBP8]J`04:DXQ22DY9BT38@P00bDY8@PQ20039BT0
0b489BTQ20029BT38@P00aS68@PLi`028@P00acW8@PQ20038@P27>L00b487>LLi`027>L28@P00aS6
7>LLi`028@P37>L00aBU6<HHaP047>L38@P27>L011S67>LQ21S60acW00<Q21cW7>L01AcW2QS600DD
YAS67>LLib48008HaP<DY@0448@DYAS66<H35:D00a246<HHaP086<H35:D00aS65:DDY@0:5:D46<H3
5:D01Q245:DDYAS65:D@Q0<DY@0436<@Q1BU5:D448@25:D011245:DDYABU11240aBU0QS611BU00@H
aQBU6<HHaP8@Q00436<@Q1BU6<H35:D248@45:D00a246<HDY@0248@35:D248@25:D00aS65:DDY@02
48@00aBU48@<H`0248@00`aS48@@Q0025:D02Q2436<<HaBU7>LHaQ2436<@Q1BU0PaS0a2400<<Ha24
36<01@aS0Q240PaS00L8@PaS48@DYA2436<8@P0436<00a2436<<H`0236<0112436<<Ha240QBU0PaS
0Q240PaS00P@Q1BU48@@Q0Q236<@Q0aS0Q240`aS00<@Q1BU48@00PaS00D@Q0aS36<<H`Q200H<H`05
48@DYA245:D@Q0012480000400048@@Q000212400`0024848@0212401@Q2=Jeg_E[F>Lh00dHa00=2
44HaAS400T8@0THa0dYB00=>LdYBBU800TYB00A244Ha@Q12408mk`03>Lhe[CF]00<aS08]J`@aS08]
J`07=JdicSW>>LhaS3F]?Nl00T8@00<mkcW>=Jd013W>13F]00<aS2e[;F/00Re[00<aS3F]>Lh00SW>
0SF]0SW>00<e[CW>=Jd00S6<00T]JcF]<H`icSF]>Lhe[CW>=Jd00S6<00D]Jc6<>LhicSF]00@aS005
=JdaS2e[;F/YBP02;F/00c6<;F/]J`03<H`012U:;F/aS36<0Re[0S6<00<]Jc6<=Jd00SF]0c6<0Re[
00<YBRe[;F/00c6<0SF]00<aS3F]=Jd00SF]00<]Jc6<;F/0136<00Le[C6<:DXU:BU:;F/U:@028@P2
:DX29BT01B489BTYBRU:9BT012U:0RDY0bU:0be[0RU:1Be[00LYBRe[;F/]Jc6<;F/YBP069BT00b48
9BTQ20029BT00b489BTU:@049BT00b489BTYBP02:DX00bDY8@PU:@03:DX01BDY7>LQ22487>L00b48
00HLib48=Jdmkd8@<H`29BT012489BTQ21cW0R480bDY00@Q22DY8@PQ20<U:@03:DXU:BDY00@U:@04
8@PLib488@P59BT012489BTQ22DY0b4800TLib48:DX]JbU:9BTQ22U:9BT00R4800@LibDY9BTYBPDU
:@068@PU:BDY9BTYBRDY0R4812DY0b4800<U:BU::DX00RU:12DY1B4800<Lib489BT00RDY00@YBRDY
:DXU:@<Q20047>LQ22488@P27>L38@P47>L01R487>LQ22487>LHaP8Li`8Q208Li`036<HLiaS6008L
i`058@PLiaS67>LQ20027>L26<H27>L01AS67>LLiaS67>L00bDY00<LiaBU6<H01QS600<DYAS66<H0
0aBU00<HaQcW7>L00QcW0aBU0QS60QBU00D@Q1BU7>LLiaS600<DY@036<HDYAS600DHaP067>LHaQBU
5:DHaQcW0QBU00HHaQBU5:DDYA245:D248@00aS65:DHaP025:D011S65:DHaQBU0Q2400PDYAS66<H@
Q1BU48@DYA240QBU00<@Q1BU5:D00Q2400L<Ha2448@@Q1BU48@DY@026<H011BU48@@Q1BU0QS600DD
YAS65:DLiaS6008DY@0348@DYA24008@Q0@DY@8@Q08DY@0448@DYABU5:D248@01aBU6<HDYABU48@D
YA2400@DY@8<H`H@Q0075:D@Q12448@<Ha245:D00QS600<DY@aS48@00a2400@<Ha2448@<H`<@Q0<<
H`8@Q00636<@Q0aS48@<Ha241@aS11240PaS00H@Q0aS36<<Ha245:D348@01@aS48@@Q1245:D00a24
10aS0Q240PaS00H8@PaS5:D@Q1BU36<224800`aS48@@Q00536<2248248@25:D148@1248000848@03
00048@@Q00<48@0:24848@@Q248icWNmE[DaS3g_AS42@Q000cg_@Q0mk`02@Q07AS42@Q03AS42BU80
0cg_>LhicP02>Lh00cF];F/aS002<H`00be[<H`aS005<H`00be[<H`aS004>Lh00cF]>LhicP02>Lh0
0cF]>Lhe[@02=Jd5<H`00be[<H`e[@02=Jd3<H`2=Jd2<H`013F]<H`aS2e[0S6<00<e[C6<>Lh00cW>
0cF]0S6<00@e[C6<<H`aS0<]J`03<H`]Jbe[008YBP08;F/aS36<<H`]JbU:;F/YBP@]J`03:DX]Jc6<
008aS003;F/aS3F]008aS006=JdicSW>=Jd]Jc6<0be[00<aS3F]<H`00c6<0Re[12U:00<aS2e[<H`0
0Re[00@aS2e[:DXYBP8U:@<Q20049BTYBRDY9BT38@P00bU:9BTU:@029BT2:DX29BT01R489BTU:BDY
:DX]J`8aS003=JdaS3F]008]J`<YBP049BTQ22489BT2:DX012DY8@PU:BU:12DY0RU:00<U:BU:8@P0
0R481bDY0b4800<U:B488@P00RU:0RDY00HaS3W>?NlicRe[9BT28@P01BDY8@PLib487>L01R4800@U
:BU::DX]J`8YBP049BTYBRDY8@P99BT012487>LLib481BDY00<Q22DY9BT00RU:12DY0b480bDY00@Q
22DY9BTQ208U:@05:DXU:BDY;F/YBP028@P012DY:DXYBRU:0R480RDY0RU:0RDY0R480bDY0R482RDY
0R4800@U:B488@PLi`@Q20<Li`039BTQ21cW008Li`<Q20036<HLiacW008Q20037>LQ21S6008HaP<L
i`066<HLib489BTQ21S60QcW0aS600DQ21cW7>LLib48008Li`036<HDYAS600<HaP055:DHaQcW5:DH
aP045:D00aS67>LLi`046<H248@00aBU6<HHaP025:D36<H00a245:DDY@077>L46<H25:D26<H45:D0
1AS65:DHaQBU48@00QBU0aS600<DYA2448@00Q2400LDYAS65:DDY@aS48@<H`0248@00aBU48@@Q002
48@00aBU48@@Q0025:D36<H00aBU36<@Q00448@55:D348@011BU48@@Q12411BU0Q241aBU112400<<
Ha245:D00QS600@DYA2448@@Q08DY@L@Q0055:D@Q12448@<H`046<H00a2436<<H`0236<448@236<0
0`Q236<<H`0448@25:D0112436<<Ha241@aS00/8@PaS36<@Q0aS248<HaBU48@8@PaS008@Q00636<@
Q1245:DHaQ240QBU00H8@PaS36<<Ha2436<248@436<00aBU48@@Q00336<248@336<2248236<55:D1
24800003124000@Q00848@0=00048@@Q248000@Q248icWNmF]H]Jcg_AS401d8@00A6<D8@?Nm240=:
DP9240=6<@04BU96<DHa?Nl2>Lh013F]>LhaS36<0Re[00@aS2e[;F/]J`@aS08]J`04<H`e[CF]=Jd2
>Lh013F]>Lhe[CW>1cF]0S6<00<]Jc6<;F/013F]00DaS2e[<H`aS3F]00HaS003=JdaS3F]00<e[@<a
S0<icP8aS08e[@DaS003;F/YBRe[00L]J`05:DX]Jbe[;F/e[@03<H`00be[<H`aS002<H`01Be[=Jde
[CW>=Jd0136<0be[136<00D]Jc6<<H`]Jc6<008YBP04;F/aS3F]=Jd3;F/2:DX29BT28@P01BDY:DXY
BRDY8@P00bDY00@Q22DY9BTQ208U:@06:DX]JbDY9BTYBRDY0RU:00HU:Be[<H`aS3F];F/2<H`01Re[
:DXU:BU:9BTQ208U:@04:DXU:BDY8@P29BT00bU:9BTU:@039BT012489BTQ22480RDY12U:00<Q22DY
8@P0124800<LibDY9BT00be[0Sg_00`aS2U:7>LQ22DY8@PU:B489BTQ21cW8@P29BT27>L00bDY:DXU
:@029BT2:DX39BT00b489BTQ20059BT01R489BTU:AcW8@PU:@8YBP058@PU:BDY:DXU:@03:DX00bDY
7>LQ20069BT38@P012DY8@PU:BDY12U:0RDY00<YBRDY9BT00b482RDY00@Q22DY9BTQ20<U:@8Q2004
9BTYBRDY9BT28@P011cW8@PQ224811cW0R480QcW00<Q21cW7>L01AcW00@HaQcW8@PQ20@Li`046<HL
iaBU6<H27>L28@P27>L46<H01AcW8@PLiacW8@P00QcW0QS60QcW00LHaQBU6<HLiaS67>LHaP045:D4
7>L36<H25:D011245:DDYABU0aS60aBU00@LiaS67>LDY@8HaP038@PLiacW008HaP8DY@046<HLiaS6
6<H45:D00aS65:DDY@0248@36<H248@011BU6<H@Q1241ABU0Q240QBU00<@Q1BU5:D00aBU00D@Q1BU
48@@Q1BU008HaP035:D@Q124008@Q08DY@056<HLiaS65:D@Q0025:D01AS65:D@Q1246<H01ABU00LH
aQBU5:DDYA245:DHaP025:D011245:DHaQ240PaS00<DYAS65:D011BU0a2400H<HaBU5:DDYA2436<2
48@45:D26<H248@336<00a2436<<H`0236<0112436<<H`aS0Q240`aS00<@Q0aS36<00PaS0Q240`aS
00<@Q0aS36<00PQ20a2400<<Ha2436<00PaS0Q2400<<Ha2448@00QBU0a240PaS0a241PaS00DDYAS6
48@<H`Q200T<H`8@Q08DY@4@Q048@P0000D000@Q12448@0000848@0;24848@@Q124<HcW>OomJeSF]
@Q16<@03@Q03?Nl2@Q000dHa@Q16<@02AS400d8@?Nm24005@Q03?Nl01CW>=Jde[CF];F/00S6<0SF]
00<aS2e[<H`01C6<00P]Jc6<>LhicSF]<H`e[CW>0SF]00@icSg_?NlicP8e[@03<H`e[C6<008aS08e
[@8icP@e[@04>Lhe[CF]<H`4;F/3<H`013F]>LhicSF]136<0SF]0cW>00<aS2e[;F/00c6<1Be[0c6<
12e[0RU:00<]JbU::DX00RU:00<aS2e[;F/00S6<0SF]00HmkcW>=JdaS2U:;F/4<H`3;F/2:DX4;F/0
12U:9BTYBRU:0be[0bU:00<]JbU:;F/012U:0b4800<U:BU:9BT00R481bDY00LYBRDY9BTU:BU:;F/e
[@02<H`2;F/2:DX38@P01BDY:DXQ22489BT00RU:0b480bU:00<U:B489BT00b4800DU:BU::DXU:B48
00DU:@098@PU:BDY:DXU:B489BTYBSF]00924004<H`YBQS67>L28@P00bDY:DXQ20038@P012U:9BTQ
22DY0RU:0bDY00<YBRe[;F/00bDY00<YBRDY8@P01BDY0R480RDY00<Q22DY:DX00RU:0bDY00<YBRDY
9BT012DY0R4800@U:BU:9BTQ208Li`<U:@038@PU:BDY00<U:@058@PU:BDY9BTQ20039BT00b489BTQ
20028@P00bDY:DXYBP029BT68@P59BT012U:8@PU:B4812DY0b480acW0b480QcW0b4800@Lib487>LL
i`<Q20037>LHaQcW008Li`<HaP049BTYBRU:9BT26<H011cW6<HHaQS611cW0QBU11S600HDYAS66<HL
iaS65:D248@25:D00acW6<HHaP026<H00acW8@PHaP0248@:5:D26<H37>L35:D26<H00acW6<HDY@02
5:D27>L01AS65:DHaQcW6<H00QBU0QS611BU00DHaQBU48@<Ha24008DY@0548@<H`aS48@<H`035:D2
48@336<00a246<HHaP025:D00a245:DDY@045:D46<H00aBU48@<H`0748@35:D0112436<@Q1BU0QS6
00<@Q1BU5:D00Q2400<DYA2448@00Q240aBU0a240QBU2Q240QBU0aS600LDYA245:D@Q0aS48@<H`06
48@436<00a245:DDY@0348@00`aS48@<H`0236<348@236<348@011BU36<@Q0aS0a2400<8@PaS48@0
0aBU00H@Q0aS36<@Q0aS48@236<248@236<2248248@011BU48@8@PQ20`aS0Q240`aS00H8@PaS36<@
Q1BU48@136<000<48@0300048@@Q00848@0=24848@@Q248e[G_NG_LaS48@AS5244Ha@Q000Sg_00@i
cT8@@Q16<@924005BU96<DHa@Q0mk`03@Q02AS42@Q02>Lh2=Jd4<H`2=Jd01C6<=JdaS36<;F/00S6<
0Re[00HaS3F]?NlicSF]<H`2=Jd00cW>?NlicP02>Lh3=Jd00c6<=JdaS002<H`2=Jd013W>=JdaS36<
0SF]00DicS6<<H`]JbU:008]J`07<H`]Jbe[=JdicSg_>Lh0136<0SF]0cW>00He[C6<<H`e[C6<;F/2
:DX01Re[:DXaS3F]<H`]J`8YBPH]J`04:DX]Jbe[;F/2<H`012e[<H`e[Cg_0SW>00<aS3F];F/00Re[
00@YBRe[<H`aS0<]J`03<H`]JbU:00HYBP04;F/aS2e[;F/8:DX00bDY8@PU:@049BT2:DX01BDY8@PU
:B489BT012U:0bDY00@]Jc6<<H`aS0<]J`03:DXU:B48008U:@04:DXQ22489BT2:DX69BT00bU:9BTU
:@028@P49BT28@P39BT28@P29BT2:DX49BT01BU:@Q1243W><H`00QcW0R4800<YBRDY8@P00b4800@U
:B488@PU:@8YBP<U:@04:DX]Jbe[:DX29BT3:DX00bDY8@PQ20049BT012489BTQ22U:0RDY0R4800<U
:BU::DX012DY0b4800HU:BU::DXU:B487>L38@P39BT012489BTU:BU:12DY0RU:00@U:B488@PU:@8Y
BP069BTQ22489BTYBR480acW2BDY12480bDY00<Q21cW7>L00QcW0b480QcW00<HaR488@P00b480acW
0b480acW0aS600DLibDY9BTU:B48008Li`036<HLiacW008HaP048@PLiacW7>L76<H27>L26<H02A24
5:DDYABU6<HQ21cW5:DHaP027>L00aS65:D@Q0026<H45:D248@011BU6<HHaQBU11S600<DYAS65:D0
0QS600@DYAS66<HLi`8HaP035:DHaQS6008HaP8DY@0348@HaQS6008HaP0448@DYABU48@236<248@0
0aBU48@<H`0248@011S65:D@Q1240PaS0Q2411BU00<HaQ2448@00aBU00H@Q1BU6<HHaQcW6<H448@2
5:D348@55:D011245:DDYAS60QBU0Q240QBU0a2400<DYA2448@00Q240QBU0a2400@DYA2448@@Q08D
Y@0;48@<H`aS48@DYA246<HLiaS67>L@Q00236<548@736<01Q2436<<H`aS48@DY@8@Q0<<H`0448@<
H`aS248236<348@010aS48@@Q1BU0Q2400<<Ha2448@00Q2400@DYA245:DDY@@<H`8@Q00536<@Q0aS
36<@Q00236<348@936<00`Q236<<H`0236<25:D136<0000300048@0000<48@0;00048@Q200048@aS
?Nmooekg=Je6<@02BU83AS4013g_@Q0mkd8@14Ha0T8@00<mkd8@@Q000THa0T8@00A6<D8@?Nlmk`8e
[@03;F/aS36<00DaS0@e[@@icP05?NlicSW>=JdaS005>Lh02CF]<H`icSg_>Lhe[Be[<H`e[@02<H`2
>Lh033g_>LhaS36<;F/aS3F]<H`e[CW>=Jd]J`8YBP@aS004=JdaS2e[<H`3=Jd2<H`2=Jd013W>?Nli
cSF]0S6<0SF]0S6<0cF]00HaS3F]=JdaS2e[:DX3;F/2:DX4;F/0236<=JdicT8@?Nle[C6<:DX5;F/2
<H`2;F/2:DX2;F/2:DX00bDY:DX]J`02:DX00bDY:DX]J`02:DX01Re[:DX]Jbe[:DXU:@8YBP05;F/Y
BRU::DXU:@02:DX012DY8@PQ22480RDY0RU:12DY00DYBS6<<H`e[C6<008YBP039BTQ22DY00<YBP<Q
20039BTYBR4800@U:@03:DXU:BDY008Li`8Q20<U:@@Q20DU:@038@PU:B4800<YBP04=JdicSF];F/4
8@P01bDY:DXU:BDY8@PLib48008Li`04;F/aS3W>;F/29BT00be[:DXYBP029BT4:DX012DY:DXYBRU:
12DY0RU:00@U:BU:;F/YBPTU:@<YBP049BTYBR489BT48@P01BDY;F/YBRU:8@P00RDY0b4812DY0RU:
0RDY0bU:00<U:B489BT01B4800<U:B488@P00bDY00<YBRDY9BT00RDY00@YBRDY8@PQ208U:@8Q2003
7>LQ224800@Q20HLi`8HaP@Q20036<HLiaS600<Li`088@PLibDY9BTQ22DY8@PHaP8Li`038@PLiacW
00<HaP<Li`046<HDYAcW6<H27>L00aS65:DDY@025:D00aS65:DDY@026<H00aBU6<HHaP026<H35:D2
6<H45:D00aS65:DHaP026<H35:D00a246<HHaP025:D00a245:DHaP036<H00aBU7>LHaP026<H35:D0
11S65:DDYA2411BU0Q240aBU00P@Q0aS36<@Q1S65:D@Q0aS0QBU0Q2400@<Ha245:DDY@8Q208DY@8@
Q08DY@<HaP0848@DYA2436<@Q1S65:D@Q08<H`035:D@Q12400D@Q08DY@0348@DYABU00<DY@D@Q003
5:D@Q12400@DY@0448@DYABU5:D748@02QS67>LLiaBU48@<HaBU48@DYA240PaS112400<<Ha2448@0
1A240QBU00P@Q0aS36<8@PaS48@<Ha240PaS0Q2400<DYA245:D00a240`aS0Q240aBU10aS00@@Q0aS
36<<H`@@Q00436<@Q0aS48@236<0112436<<H`aS0a2420aS0A240@aS00051240100012448@Q20P@Q
00H8@SF]OomNmcW>AS42BU87@Q04AS40148@AS5243g_0T8@00=:DT8@@Q000cg_00E243W>=JdaS2e[
008aS005>LhaS36<<H`e[@04<H`2=Jd4?Nl013W>=Jde[C6<0SW>00<mkcF]=Jd013W>00@]Jc6<<H`]
J`8e[@<icP8e[@DaS004>LhaS36<;F/2:DX2<H`00cW><H`]J`02<H`3=Jd2<H`2=Jd2>Lh013g_=Jda
S2e[0S6<00<]Jc6<;F/00SF]00@icS6<<H`]J`8aS003;F/YBRU:00@YBP8]J`03<H`e[CW>008icP04
=JdicS6<<H`2:DX00be[<H`aS002;F/2:DX012e[:DX]Jbe[0RU:00<U:BU::DX00RDY1BU:00D]JbU:
;F/YBRe[00DYBP049BTYBRDY:DX49BT00b489BTU:@029BT012489BTQ22DY0Re[0SF]00H]JbDY7>LQ
22DY8@P49BT00bU:9BTU:@029BT00b487>LU:@02:DX01BDY8@PQ22487>L00R480RDY0R481bDY00<Q
22DY:DX00RDY00DaS3F]>Lhe[BU:00<Q208YBP039BTQ224800@Q20049BT]JcF]<H`2:DX29BT2:DX3
9BT012U:9BTU:BDY0RU:12DY1RU:00<U:B489BT00RDY00DYBRDY8@PU:BU:008]J`03:DXU:B48008Q
20DU:@@YBP@U:@088@PU:BU::DXU:B489BTYBP8U:@8Q20059BTQ22488@PU:@048@P02BDY8@PU:BU:
9BTYBR489BTQ20039BT00b487>LLi`029BT28@P011cW8@PQ22DY1acW00<HaQcW8@P00R480aS61QcW
00<Q22DY9BT00R4800<LiaS67>L00QcW0QS600DLiaS67>LHaQcW00<HaP037>LHaQcW008HaP<DY@05
6<HDYAS67>LHaP035:D00acW6<HHaP045:D26<H25:D248@26<H011cW5:D@Q1241aBU0aS600DDYAS6
7>LLiaS600<DY@036<HDYABU00TDY@8@Q0035:D@Q0aS008@Q08DY@@@Q00336<@Q124008@Q0@HaP03
48@DYABU00<HaP8DY@0448@DYABU6<H748@35:D01A2436<@Q1245:D00Q240aBU112411BU00@@Q1BU
6<HHaP<@Q08DY@H@Q00336<DYAcW008HaP8@Q0<DY@<@Q0035:D@Q12400@<H`0448@DYA245:D548@4
36<248@336<248@00aBU48@<H`0248@00aBU48@@Q00648@436<00a2436<@Q00348@336<00a2436<<
H`0436<01124248@Q1240PaS00<8@PaS36<00`aS0Q2400001@00124000@Q00000`@Q00`8@P@Q1248
@SF]NmiNmcW>@Q1:DTHaCW<2BU82AS400d8@BU9:DP02BU800dHa@Q0mk`02?Nl0148@BU96<DHa0cW>
00E243g_>LhicSF]008icP05=JdaS36<<H`]J`03<H`2=Jd0148@?Nm2448@1CW>00DmkcW>?NlmkcW>
008e[@LicP8aS0<icP03=JdaS2e[00<aS003=JdaS36<008]J`04:DX]Jc6<=Jd2<H`2;F/2=Jd01cW>
<H`aS3F]>Lhe[C6<008e[@04>Lhe[C6<<H`5=Jd00cW>=JdicP02>Lh01CF]<H`]Jbe[<H`01be[00Ta
S3F]?NlmkcW>;F/YBRe[<H`01Be[0bU:00<U:BU:9BT00bDY0RU:00<]JbU::DX01BU:00DU:Be[;F/]
JbU:008U:@04:DXU:BU:9BT3:DX012e[:DXU:B480RDY0RU:0bDY00HYBRe[9BTYBRe[<H`2;F/01248
9BTU:BU:12DY1RU:00<]JbU::DX00RDY1acW0R4832DY00<YBRDY:DX00S6<00@YBRDY6<HQ20@U:@<Q
20047>LQ22DY8@P3:DX39BT00bU:9BTYBP02:DX59BT2:DX00bDY:DXYBP05:DX29BT00bU:;F/U:@02
8@P00bDY;F/YBP059BT012489BTU:B480RU:00<]JbU::DX012DY00<Q22DY9BT00RDY00@Lib489BTY
BP8U:@8YBP039BTQ2248008U:@8Q208U:@037>LQ21cW008U:@<YBP8U:@048@PU:BDY9BT38@P00acW
8@PU:@028@P29BT01B489BTQ21cW8@P00QcW00@DYAS66<HHaP8Li`038@PLib48008Li`036<HLib48
008Q20037>LQ224800<Li`<Q208Li`8Q20047>LHaQS66<H27>L01AS67>LLiacW6<H011BU0QS611BU
00<HaQBU6<H00QS60QBU0QS60aBU11S600DDYAS65:D@Q1BU008@Q0045:D@Q1BU6<H25:D00a245:DL
i`037>L011S67>LLiaS60aBU00<HaQBU5:D00a2400DDYA245:DDYA24008DY@036<HDY@aS008@Q007
36<DYABU6<H@Q1BU48@01ABU00DHaQBU6<HDYAS600@DY@<@Q0045:DLiaS65:D648@236<448@00`aS
48@DY@0348@031BU48@DYABU6<H@Q0aS48@DYAS65:D@Q08DY@@@Q00436<@Q12448@25:D26<H248@0
10aS48@HaQ240PaS00<@Q1BU48@00Q240`aS00<@Q1BU48@00a2400@<Ha2436<<H`@@Q08<H`D@Q08<
H`<@Q08<H`0448@DYABU48@636<448@00`aS48@<H`0336<348@236<01@Q236<<H`aS48@010aS00<8
@PaS48@00PaS000812402@Q200048@Q2<HakgUkg=Je6<@04BU84AS401D8@AS5:DTHaBU800T8@0Sg_
0THa00=:DT8@@Q000SW>0Sg_0SW>0SF]00<icSF]=Jd01S6<0SF]00@icSg_?Nm2408icP8e[@04>Lhm
kd8@?Nl4>Lh3=Jd00cW>?NlicP02=Jd2<H`013W>=JdicSF]0S6<0Re[00@aS3W><H`]J`8YBP03;F/e
[C6<00@aS003=JdaS36<008e[@<aS007>Lhe[CW><H`e[C6<=Jd00S6<0SF]00<icSF]>Lh00Sg_0SW>
0be[00DaS2e[;F/]JbDY008YBP03=JdaS3F]008icP8e[@03:DX]JbU:008]J`8YBP05;F/aS2U::DXU
:@02:DX39BT6:DX01Be[9BTYBRDY:DX00S6<0Re[0bDY0RU:0bDY0be[0RDY00<Q22DY9BT00RU:0bDY
0bU:0c6<00<YBRDY:DX012DY1BU:12DY0RU:00@U:B488@PLi`HQ208U:@8YBP8U:@8YBPHU:@06:DXU
:C6<=JdaS2U:0R4800<YBRDY9BT00RDY00LLib487>LQ22DY:DXU:@038@P00bDY;F/YBP02:DX012DY
:DXYBRU:0bDY0bU:0RDY0bU:00DU:B489BTYBRe[00<YBP<U:@8YBPHU:@048@PU:BDY9BT3:DX00bDY
8@PQ20039BT00b489BTQ20029BT012U:9BTQ22DY0RU:0RDY00DQ22DY8@PQ21cW00<Q20037>LQ22DY
008U:@8YBP069BTQ21cW8@PU:B4812DY00PQ21cW7>LQ22DY8@PU:B480RDY00@Q21cW7>LLi`8HaP<L
i`038@PLiacW008HaP037>LHaR48008Q20039BTQ224800@Li`8Q208Li`8Q20057>LHaQS66<HDY@0;
6<H00aBU6<HDY@035:D36<H00aBU6<HHaP045:D00a245:DHaP036<H00aBU6<HDY@0248@45:D26<H3
48@66<H27>L01AS65:DDYABU48@00aBU00@@Q1BU48@@Q0@DY@8@Q0035:D@Q12400@@Q0065:D@Q1BU
48@DYAS60QBU00<@Q1BU5:D00QS60aBU00THaQ2448@@Q1BU6<HDYA245:D0112400<DYA2436<02A24
00`<Ha2448@@Q1BU6<HDYA2436<@Q1BU6<H25:D248@35:D0112436<<H`aS0QBU0QS600<DYA2448@0
0Q2400DDYA2448@<Ha24008DY@0348@<Ha24008@Q00336<@Q12400@@Q0<<H`0448@DY@aS36<248@2
5:D00a2436<<H`0248@336<348@011BU48@@Q1240PaS00@@Q0aS48@@Q08<H`<@Q00836<8@PaS48@D
YA245:D@Q0<<H`0348@<H`aS0088@PD<H`48@P0000D000@Q00048@0000<48@0824848@0036<aS7Nm
F]HicP=6<@924004BU96<DHaAS42BU800dHaBU9:DP03@Q001Sg_@Q16<DHa@Q0mk`<icP07?Nm6<CW>
@Q1:DTHa?Nl00S6<00@e[C6<=Jd]J`8aS003=JdicSF]008icP05?NlicSW>>Li24003?Nl00d8@?Nlm
k`03>Lh00cg_>Lhmk`04=Jd00cW>=Jde[@05<H`012e[<H`aS3F]0S6<0SF]1C6<0be[136<00<e[C6<
<H`00SF]00<icS6<=Jd00cF]1S6<00<e[C6<;F/00S6<00@e[C6<<H`aS0<]J`0:<H`e[CW>=JdicSg_
@Q0mkcF]<H`4:DX29BT3:DX00bDY8@PU:@029BT28@P49BT00bU:;F/]J`03:DX29BT3:DX39BT00be[
:DXU:@03:DX49BT01248:DXYBRU:12DY1BU:00@]Jc6<;F/YBP@U:@<Q20049BTYBRDY:DX29BT2:DX0
1BDY8@PQ22487>L00R4800@U:B488@PU:@8YBP8U:@038@PU:BU:00@U:@07:DXQ22DY>Li:DTHa>Lh0
0QcW0bDY00@Q21cW8@PQ208U:@048@PLib489BT2:DX01RDY8@PU:BDY:DXU:@@YBP039BTYBRU:008U
:@HYBP03;F/YBRU:008YBP<U:@03;F/YBRU:00@U:@8YBP8U:@8YBP049BTYBRU::DX39BT00bU:9BTU
:@028@P49BT012489BTU:BU:1BDY00HQ22DY9BTU:B489BT38@P79BT48@P00acW8@PU:@048@P29BT6
8@P67>L29BT01B486<HLiacW8@P00QcW00@Q21cW7>LHaP@Li`<HaP8Li`8HaPDLi`<HaP037>LQ21S6
008DY@8HaPHDY@046<HLiaS66<H55:D36<H00aBU6<HHaP046<H00aBU6<H@Q0045:D01AS65:DHaQBU
48@00QBU1aS60aBU00<HaQBU5:D00QS600HDYA2448@@Q1BU6<H35:D02A245:D@Q1BU48@DYAS648@D
Y@0348@00`aS48@@Q0045:D011246<HHaQBU0Q2400HDYAS65:D@Q1S65:D248@35:D248@00aBU48@<
H`0236<011245:D@Q1BU1A2400<DYA2448@00Q240QBU00HHaQ2448@<Ha245:D648@01QBU48@DYABU
48@DY@<@Q00336<@Q124008DY@8@Q0035:D@Q124008@Q0065:D@Q1BU5:DHaQ240PaS00<@Q1BU48@0
0a240aBU00T@Q0aS36<@Q1BU48@<H`Q236<0112400@<Ha2436<<H`8@Q0@<H`8@Q0035:D@Q124008D
Y@8HaP035:D<H`aS0088@P8<H`8@Q08<H`88@P<<H`4@Q0002`@Q00D8@S6<LiaJeSW>009:DPI6<@09
BU96<DYBBU96<DYBAS5243g_00=24096<@08?NlicSW>>Li243g_>Lhmk`=6<@8e[@03<H`e[CF]00<a
S00;=JdicSF]>LhmkcW>=JdicSg_@Q0mk`02>Lh00cg_@Q0icP02>Lh3?Nl4>Lh2=Jd3<H`2;F/00cF]
<H`aS004<H`013F]<H`aS3F]1c6<0SF]00DaS3F]<H`]Jc6<008e[@03>Lhe[CF]00<e[@DaS08e[@04
<H`]Jbe[=Jd2<H`00be[<H`aS002:DX01RDY<H`aS3W>?NlicP8mk`03=Jd]JbU:008]J`<YBPHU:@03
:DXU:BDY008Q208U:@05:DX]Jbe[;F/YBP029BT5:DX29BT00bU:9BTYBP04:DX29BT01bU:9BTU:BDY
:DX]JbU:00DU:@8YBP06;F/YBRU:;F/YBRe[0RDY0b481RDY12U:00<Q22DY8@P00R4800<Lib489BT0
0RDY0b4800<U:BU::DX012DY00@Q22DY9BTU:@8icP03?NlicRDY008Q20049BT]Jbe[9BT28@P00acW
8@PQ20028@P49BT28@P89BT00bU:9BTYBP04:DX00bDY:DXU:@02:DX2;F/00bU:9BTYBP04:DX29BT0
12U:9BTU:B480RDY0bU:12DY0b4812DY00HQ22DY9BTU:BU:9BT3:DX29BT01b489BTU:B489BTQ22DY
008Q20047>LU:B489BT38@P59BT78@P00acW9BTQ20029BT28@P00bDY8@PQ20027>L28@P47>L01b48
7>LLiacW8@PLib4800@Li`8Q208Li`8HaPDLi`056<HLiacW6<HLi`046<H00acW6<HHaP026<H01aBU
6<HHaQS65:D@Q1BU008HaP055:DHaQS65:D@Q0025:D00aS65:DHaP036<H00acW6<HHaP025:D00aS6
5:DDY@025:D26<H00aBU48@DY@025:D01AS65:DHaQcW6<H00QcW00@HaQBU5:DDY@8HaP035:D@Q1BU
00HDY@8@Q0085:D@Q1245:DHaQBU48@DY@<@Q08<H`8@Q0@DY@8HaP035:D@Q124008DY@056<HDYABU
5:D@Q0025:D011245:DDYA240aBU0Q2400<<Ha2448@00a2411BU00@@Q1BU5:D@Q08DY@8HaP035:D@
Q0aS008@Q0035:D@Q12400@@Q08HaP045:D@Q1245:D448@01QBU48@<H`aS48@<H`<DY@0448@<Ha24
6<H55:D00a245:D@Q00248@00aBU48@DY@025:D01A2436<<H`aS48@010aS00@@Q1BU5:DDY@@<H`8@
Q00736<8@PaS36<DYA245:D00Q2400@DYAS65:DDY@<<H`04248<Ha245:D336<00a2436<<H`0336<0
000300048@0000848@0400048@@Q248212401PQ2=Jeg_Ekg>Li6<@9:DPA6<@E:DP96<@=24003?Nm2
448@00=6<@0<?NlicSg_?Nm243g_=JdicSg_>LhmkcF]0cW>00Te[Be[:DX]JcF]>LhmkcW>=Jd00cW>
00@aS3F]=JdicP8e[@8icP8mk`<icP<e[@DaS003=JdaS2e[00<aS08e[@8aS0<e[@<aS004=JdaS36<
=Jd2;F/2<H`01cF]<H`aS36<>Lhe[C6<00@e[@<]J`8aS08]J`<aS0<]J`04<H`]JbU:;F/2<H`3=Jd0
0cW>?NlicP02=Jd00cW>?Nlmk`02=Jd00bU:9BTU:@079BT00b489BTYBP029BT01B48:DX]JbU:;F/0
0RU:0bDY00HYBRDY9BTQ22DY:DX39BT00bU:9BTU:@059BT6:DX00bDY:DXU:@04;F/4:DX29BT2:DX0
0bDY8@PQ20029BT38@P012DY8@PQ21cW224800<U:BU:9BT00RU:00<U:B488@P00RU:0RDY0R4800@a
S3W>@Q0mk`8aS005:DXQ22488@PU:@048@P01BDY8@PU:BDY:DX00RDY0bU:00<U:BU::DX00RU:00DQ
22DY8@PQ22U:008]J`8YBP8]J`03<H`YBRU:00<YBP03;F/YBRe[00HYBPDU:@048@PU:BDY8@P29BT2
:DX01BDY8@PU:BDY:DX00RDY00TQ22U::DXU:B487>LU:BU:9BT00b4800<U:B488@P00R480bDY00<L
ib489BT01RDY0R4800<U:B489BT02R4800@U:AcW7>LQ20<Li`HQ208Li`078@PU:AcW6<HDYAS68@P0
1QcW00<HaQcW6<H00QS60QcW00LHaQBU5:DHaQcW8@PHaP025:D02QS65:DDYABU7>LHaQBU48@DYAcW
1QS60aBU0aS600@DYAS66<HHaPHDY@046<HDYA2448@26<H011BU48@@Q1S611BU00@HaQBU5:DHaP@D
Y@@HaP<DY@8@Q0035:D@Q1BU00@DY@0348@DYA2400L@Q00336<@Q12400D@Q0<DY@<@Q08DY@0448@D
YA245:D348@00aBU48@@Q0035:D348@35:D00a245:D@Q00248@00aBU48@@Q00248@011BU6<HHaQBU
0Q2400<DYA2448@011240QS60QBU00@@Q1BU6<HDY@8@Q0035:D@Q12400H@Q0035:D@Q1BU008@Q0@D
Y@D@Q08<H`@@Q0<<H`8@Q0<<H`8@Q00436<@Q0aS48@836<448@01PaS6<HU:BU:8@P@Q0`<H`03248<
H`aS004<H`000`@Q00D000@Q124000Q200848@08000<HcF]OomNmcF]@Q1:DPA6<@03@Q1:DTHa009:
DP03AS5:DTYB00E24003AS5244Ha0092408mk`03@Q0mkcW>00HicP8e[@03>Lhe[C6<008aS005=Jda
S3W>>Lhe[@02>Lh2=Jd3>Lh2=Jd2>Lh01CF]>Li243g_>Lh00SF]00LicSF]<H`YBRe[:DX]J`06<H`0
23F]<H`e[CF]>Lhe[C6<;F/5=Jd2<H`2;F/2<H`023F]<H`icSF]<H`e[CW>=Jd9<H`013F]<H`]JbU:
0Re[1S6<00De[CW>?NlicSg_00<icP0;?NlicSW><H`]JbDY:DXU:Be[:DXU:@028@P39BT012489BTU
:Be[0RU:0Re[00@YBRDY8@PU:@<YBP8U:@8YBP049BTYBRDY:DX49BT00bU:9BTU:@03:DX29BT01BU:
9BTU:BU:;F/00RDY00@YBS6<<H`aS0DU:@@Q20<U:@<Q208U:@058@PLib488@PU:@028@P49BT01248
:DXYBRU:0bDY00XQ22DY8@PYBRe[<H`icSg_>LhaS0<U:@048@PU:BDY9BT48@P00bU:9BTU:@038@P0
0bU:9BTYBP02;F/2:DX49BT2:DX01Be[:DXYBRe[<H`00Re[0bU:00<]JbU::DX00RU:00<]JbU::DX0
0Re[00DYBRDY9BTQ22DY008YBP039BTQ22DY008YBP@U:@<YBP049BTYBR489BT28@P59BT48@P49BT2
8@P01BDY8@PQ21cW8@P01RDY00<Q22DY8@P012480RDY0R4800DLib488@PU:B48008Li`038@PU:B48
008Q20039BTLiacW008Li`048@PLib487>L26<H01AcW8@PQ21cW6<H011cW00<HaQBU6<H00acW1QS6
00HLiaS66<HDYA246<H27>L35:D01QS67>LHaQcW6<HLi`8HaP@DY@<HaP035:DHaQS600<DY@036<HD
YABU008@Q0@DY@0348@<H`aS008DY@036<HDYABU00<HaP@DY@8HaP037>LHaQS600@DY@@@Q0045:DH
aQS65:D248@45:D248@00`aS48@@Q00748@00aBU6<HDY@0248@25:D00a2436<DY@0448@26<H25:D0
11245:DDYABU0a240QBU00@@Q1BU48@DY@<@Q0065:D@Q1S66<HDYAS611240QS60a240QBU0aS61QBU
00H@Q0aS48@@Q1BU48@45:D248@35:D748@236<248@00aBU48@<H`0336<548@010aS48@@Q12410aS
112400D<H`Q236<@Q1BU008@Q0047>LQ21cW6<H248@236<00`Q236<<H`0736<148@1248000050004
8@@Q1240000312402`Q212448@Q2>Liooekg=Je6<DicBU8014Ha00=244HaAS401TYB0d8@00DicSg_
AS5:DT8@00<icP8mk`<icP8mk`@icP8aS004:DXaS3F]>Lh5=Jd0136<=Jde[CW>0SF]00HaS3F]=Jde
[Be[<H`4=Jd;<H`01CF]<H`e[CW>=Jd01C6<00@]Jc6<<H`e[@8aS003;F/aS3F]00@e[@DaS08e[@04
<H`]Jbe[;F/7<H`4:DX2;F/2<H`2;F/00c6<=Jde[@02<H`2;F/01C6<=JdicSW><H`00RU:00<U:BU:
:DX00bU:0bDY00<Q22DY9BT01RU:1BDY00<YBRDY9BT01BDY0RU:00<U:B488@P00RDY0RU:00<Q22DY
9BT00RDY0bU:00DU:BU:9BTYBRDY008YBP8]J`@YBP8U:@078@PU:BDY9BTYBR489BT01b4800DLib48
8@PQ22U:008U:@8Q208U:@048@PU:BDY:DX49BT013W>AS4mkcF]0R481BU:0RDY00DQ21cW8@PU:BU:
00<U:@03:DX]JbU:008YBP8U:@03:DXU:BU:00<YBP049BT]Jbe[<H`3;F/4:DX00be[:DXYBP05:DX2
9BT3:DX2;F/2:DX01bDY8@PQ22DY:DXU:BU:00<U:@03:DXU:BDY008U:@@Q20<U:@058@PU:B488@PU
:@048@P01BDY8@PQ21cW8@P00RDY0RU:12DY00HQ22DY:DXU:B487>L58@P02QcW8@PQ22487>LHaQcW
8@PLib480QcW00<Q21cW7>L00QcW00PQ21cW8@PLiaS67>LQ21cW0aS60QcW0QS600@LiaS67>LLi`8H
aP045:DHaQBU6<H27>L00aS65:D@Q0025:D46<H27>L26<H00a246<HDY@035:D46<H25:D36<H01ABU
48@@Q1BU6<H00QBU00@@Q1BU48@DY@8HaP8DY@8@Q08DY@096<H@Q1S67>LHaQ2436<@Q1S6008DY@03
48@DYABU00<@Q00736<@Q1S66<HDYAS65:D00QS600@DYA245:DDY@8@Q00436<@Q1245:D248@00aBU
48@@Q0035:D236<00a245:DDY@0448@25:D011S648@@Q1BU0QS61QBU00<@Q1BU5:D01QBU00L@Q0aS
48@@Q1BU6<HDY@046<H01QBU6<HHaQS648@HaP8Li`046<HDYABU5:D26<H00aBU48@@Q0025:D00a24
5:DDY@0448@01ABU48@@Q0aS48@00aBU0PaS0a2400<<Ha245:D00Q2410aS0a2400<DYA2448@01PaS
00@@Q0aS36<<H`8@Q08<H`<@Q0045:DLib488@P35:D336<00`Q248@@Q00248@00`Q236<<H`0236<1
248000848@0300048@@Q00<48@0:24848@@Q248icW_NG_LicTHaBU83AS400dYBAS5:DP02AS42BU82
CW<00dYBAS524005@Q0014Ha?NlmkcW>0Sg_0SW>00<mkcW>?Nl01CW>00@e[C6<<H`]J`@e[@03<H`e
[CW>008e[@03<H`e[CF]00<e[@8aS004=JdaS3W>>Lh2=Jd2<H`01CF]<H`aS36<=Jd00c6<00@]Jc6<
=Jde[@HaS004;F/YBRe[<H`2=Jd4<H`3=Jd0136<=JdaS3F]0c6<0SF]00<aS2e[;F/01S6<00@YBRe[
;F/]J`8YBP<]J`07<H`]Jc6<>LhmkcW><H`00Re[0SF]0SW>00HaS2e[:DXU:Be[:DX29BT01bU:8@PQ
21cW9BTYBR48008U:@03:DX]JbU:00<YBP8U:@04:DXU:BDY9BT2:DX39BT012U:9BTYBRDY0R4800<U
:BU:9BT012DY00<YBRDY9BT012U:0RDY1BU:0bDY00@]JbDY9BTQ208YBP8Q20039BTQ21cW008Li`DQ
20049BTQ22488@P2:DX00bDY8@PQ20028@P29BT2:DX01bDY8@Pe[Cg_AS4icR4800<U:@05:DXU:BDY
9BTYBP029BT02AcW8@PU:B489BTYBRe[:DX]J`02:DX39BT2:DX29BT00bU:;F/YBP02:DX012e[<H`]
Jbe[1bU:00<]JbU:;F/00Re[0RU:00HU:BU::DX]JbU:9BT28@P4:DX012DY8@PQ22DY0RU:00DU:B48
8@PU:B48008U:@03:DXU:B4800<U:@DQ20049BTLib488@P29BT00b489BTU:@02:DX29BT28@P00bDY
:DXU:@038@P2:DX00bDY8@PQ20028@P37>L00aS67>LQ20047>L78@P37>L021S67>LLiacW6<HLiaBU
6<H27>L012487>LHaQS60QBU0aS600@LiaS65:DDY@8@Q0036<HDYAS600DHaP035:DHaQS6008DY@03
48@DYAS600<HaP035:DHaQS6008HaP8DY@0348@DYABU00<DY@<@Q0<DY@8@Q0035:DHaQBU008DY@<H
aP8DY@0348@DYAS6008DY@0448@DYABU5:D348@25:D26<H25:D01Q245:DDYABU48@DY@@@Q00436<@
Q12448@45:D248@00aBU48@<H`0248@45:D248@01QBU6<HHaQBU6<HDY@8HaP8DY@@@Q0036<HDYAS6
008HaP<@Q00336<@Q1BU00HDY@0348@DYABU008DY@046<HLiacW6<H55:D00a245:DDY@0648@010aS
48@DYABU0Q240PaS0aBU0Q2400D<Ha2448@DYA2400<<H`<@Q00736<@Q1245:D@Q0aS48@01PaS0Q24
00<<Ha245:D00Q2400<<Ha245:D011BU00@LibDY7>LDY@D<H`<@Q00536<@Q12436<8@P0112400004
00048@@Q000412402@Q200048@Q2>LikgUkg=Je:DP03CW<00e:DCW=:DP02AS43BU801DHaBU9:DTYB
@Q000THa0T8@00=6<D8@@Q001SW>00<aS3F]>Lh00cW>00=6<DYB@Q000SF]0SW>00De[CW>?Nm243g_
008e[@03>LhaS36<008aS0<e[@8aS003=JdaS36<008]J`@aS003;F/aS36<008e[@<aS08icP04=Jda
S2e[<H`2>Lh01S6<;F/YBS6<>Lhe[@@aS0He[@05<H`e[CF]>Lhe[@02<H`00cF];F/aS003=Jd4;F/0
0bU:;F/aS003<H`01BU:;F/e[CF]>Lh00S6<00H]JbU::DX]JbU:;F/2<H`3:DX01Re[:DXYBRU:;F/Y
BP<U:@DYBP05;F/YBRU::DXU:@02:DX39BT2:DX02BDY8@PQ22DY:DXU:B487>LQ20039BT3:DX59BT0
0b489BTYBP03:DX29BT01RU:;F/]Jbe[:DX]J`<YBP069BTQ21cW8@PU:B480bDY0R4800@Lib488@PQ
20@U:@8Q20037>LQ224800<Q20039BTQ2248008U:@04>Li243g_?Nl2:DX00bDY8@PU:@069BT01BU:
9BTU:BDY:DX00Re[0bU:00<]JbU:9BT00RDY0RU:00@U:BU:9BTYBP8]J`04<H`YBRU::DX3;F/00bU:
;F/YBP029BT00bU:;F/]J`02:DX00be[9BTU:@03:DX00b489BTYBP02:DX012DY:DXYBRU:0bDY12U:
0RDY00<Q22DY9BT00RDY00<Q22DY7>L00R480RDY00@Q21cW8@PQ20@U:@038@PU:BDY008U:@04:DXU
:BDY8@P49BT38@P01BDY8@PLiacW8@P01AcW00<HaQcW7>L00QcW00DHaQcW7>LQ21cW008Q20DLi`8H
aP<Li`<HaP037>LHaQS600@HaP035:DHaQBU00<HaP035:D@Q1BU00<HaP8DY@<Li`056<HDYAS65:DH
aP025:D46<H27>L56<H25:D448@00`aS5:DDY@026<H45:D56<H35:D27>L01AS65:D@Q12436<00QBU
00@@Q1BU48@@Q0DDY@046<HDYABU48@35:D448@011BU48@DYA240aBU00DHaQBU6<HHaQBU00D@Q0<D
Y@@@Q0<DY@046<HDYAS66<H35:D00a245:DDY@0248@55:D36<H00aBU6<HHaP027>L26<H35:D46<H2
5:D26<H011cW6<HDYABU1a240QBU0a2400DDYA2436<@Q1BU008@Q08<H`<@Q08<H`<@Q08<H`05248@
Q1BU5:D@Q00236<348@436<348@236<348@01ABU6<HLiaS65:D00a2400<<Ha2448@00`aS0Q2410aS
0@Q200051240100012448@Q20P@Q00L8@SF]NmiJeSW>AS5>L`02BU800dicDYA:DP02AS42BU801DHa
BU9:DTHaBU80148@00=6<D8@@Q000Sg_13W>00De[CW>=JdicSg_008icP05@Q16<D8@>LhaS003=Jd0
13W>?Nlmkcg_0SW>00<e[C6<<H`00Re[0S6<00@e[CW><H`aS08]J`04<H`]Jc6<;F/2<H`00cF]<H`a
S002<H`00cW>=JdaS003=Jd2<H`00be[<H`aS003<H`00be[<H`e[@02=Jd2<H`6=Jd0136<=JdicSF]
1C6<00<]Jc6<=Jd00SF]1Be[00<YBRe[;F/012e[00HaS3W>>LhaS2e[:DX2;F/00bU:;F/aS002<H`2
:DX00be[:DXYBP03:DX29BT3:DX29BT2:DX2;F/012U:9BTU:B480RDY0RU:00<U:B489BT00RDY00<Y
BRDY8@P00R4800<YBRDY:DX00RU:12DY00@Q22DY9BTU:@<YBP8U:@088@PYBRU:;F/aS2e[:DXU:@<Y
BP8U:@<Q208U:@05:DXU:B487>LU:@038@P29BT012489BTYBRU:0R4800<LibDY9BT012DY00LYBS6<
=JdicSg_<H`YBP029BT00bU:9BTU:@039BT28@P49BT3:DX01RDY:DXYBRU:9BTQ208U:@03:DX]JbDY
008YBP03;F/aS2e[008]J`@YBP8]J`039BTYBRU:00@YBP@U:@8YBP<U:@<YBP8U:@<YBP8U:@8Q2003
9BTYBRU:00DU:@<Q208U:@8Q208Li`8Q20<U:@<Q20079BTQ22489BTQ22DY8@P00RDY00<Q22DY8@P0
12480QcW0b4800HLiaS67>LLib487>L26<H37>L011S67>LLibDY0b480acW00@HaQcW7>LLi`8HaP@L
i`8HaP045:DLiaS66<H25:D36<H01ABU48@DYAS67>L00QBU00<HaQcW6<H00QcW00<Q21S66<H00Q24
1AS600DDYAS66<HLiaS6008DY@046<HDYA2448@25:D011245:DHaQS60QBU00<@Q1BU5:D00QS60aBU
00<HaQcW6<H00QBU0QS600@DYA2448@@Q08DY@@@Q0<DY@046<HDYABU5:D248@35:D448@00`aS48@D
Y@035:D00a245:DDY@035:D248@35:D00a2436<@Q00348@25:D01AcW6<HDYABU48@021BU0Q240aBU
0Q2400<DYAS67>L00QS600XDYAS66<HHaQBU6<HLib487>LDY@8HaPDDY@8@Q0045:D@Q12436<:48@0
11BU48@<H`aS0Q240QBU00<@Q0aS48@00`aS00<@Q0aS36<00PaS0a240`aS11240`aS0a2400@<Ha24
5:DHaP8DY@<HaP035:D@Q12400@<H`D@Q08<H`48@P0000D48@0012448@0000D48@08000<HcW>OomN
mcW>BU9BU09>L`03DYA>Ldic00=>L`E:DP06AS5243g_@Q0mkd8@0cg_00=244HaAS400T8@0cW>0SF]
0SW>00Xmkd8@>Lhe[C6<=JdicSF]?Nm24096<@8mk`08>Lhe[CW><H`e[C6<=JdicP<aS08]J`<aS003
;F/YBRU:00<]J`03<H`e[C6<008aS005=JdicS6<<H`YBP02<H`01cF]>LhicSW>@Q0icSF]008aS003
=JdaS36<008aS0<icP8aS08icP03=JdaS36<008aS08e[@05>LhaS36<:DXaS002;F/01S6<=JdaS36<
;F/aS0<e[@8aS003;F/YBRe[008]J`<YBP03;F/YBRU:00<U:@03:DX]JbU:008YBP039BTQ22DY00@Y
BP8]J`<YBP039BTYBRDY00<U:@038@PU:BDY00<YBP<U:@05:DXU:BDY8@PYBP029BT28@P012DY8@PQ
22DY0RU:0RDY00<YBRDY9BT00RDY0RU:00<]JbU:;F/00bU:00<U:B489BT01BDY0bU:00<Q21cW8@P0
0R4800@U:B489BTYBP8U:@037>LQ22DY00<Q20DYBP04<H`e[C6<;F/29BT9:DX28@P29BT00be[:DXY
BP02:DX01bDY8@PU:BDY:DXU:B4800<U:@07:DX]Jc6<;F/YBRDY;F/00bU:0be[1BU:00TU:BU::DX]
JbU:9BTYBRe[:DX02BDY00<YBRDY9BT012U:00HU:B488@PU:BU:9BT28@P39BT01QcW8@PQ22DY8@PU
:@8Q20059BTQ22DY8@PLi`028@P2:DX01BDY8@PQ22489BT00b480RDY00<Q21cW8@P00R480QcW00<H
aQcW7>L00QcW00<HaR487>L00QcW00<Q21cW7>L00QcW0R4800@LiaS66<HDY@8HaP047>LHaQcW5:D3
6<H00acW6<HHaP026<H011BU6<HHaQcW0QS600@DYAS65:DDY@@HaP045:DLiacW6<H25:D26<H00aBU
6<HHaP027>L00aS67>LHaP026<H00aBU6<HDY@025:D021S648@<H`aS5:DLiaS648@25:D00a245:DD
Y@026<H00aBU6<HLi`027>L00aS65:DDY@0548@236<25:D248@01ABU6<HHaQBU48@00QBU00<@Q1S6
5:D00QBU00@@Q0aS36<@Q08DY@DHaP035:D@Q124008@Q08DY@8@Q08HaP@@Q0046<HDYABU48@25:D2
6<H00aBU6<HLi`025:D021245:DDYABU48@DYA245:D26<H01QcW6<HDYAS67>LHaP<DY@@Li`@DY@8@
Q08DY@8HaPD@Q08DY@0448@<H`aS36<248@011BU48@<H`aS3A240PaS0Q240PaS00D@Q0aS248<H`Q2
008@Q0<<H`D@Q00336<@Q1BU00<DY@8@Q08DY@0448@<H`aS36<748@12480000300048@0000D48@0:
24848@@Q248icW_NF]HicTYBCW<2BU801DicDYA>LdicBU800dic00A:DTicAS56<@A240Dmk`A2408i
cP8e[@<icP8mk`8icP04<H`e[CW>>Lh2@Q02AS40148@?NlmkcW>0SF]00TaS3F]=Jde[CW>=JdaS2e[
:DX00Re[0S6<00<]JbU:;F/00be[0S6<00D]Jc6<>LhicSF]00DaS007=Jd]Jcg_?Nm243W><H`00Re[
136<0cW>0SF]0SW>00He[C6<;F/aS2e[<H`3=Jd5;F/4<H`2;F/2<H`00cF]<H`aS002;F/5:DX3;F/2
9BT3:DX2;F/00bU:;F/U:@039BT00bU:9BTYBP03;F/00bU:9BTYBP059BT00b489BTU:@03:DX00bDY
8@PU:@0:9BT38@P00bDY:DXYBP05:DX29BT2:DX4;F/2:DX48@P29BT00bU:9BTU:@029BT38@P49BT0
0bU:9BTQ20038@P2:DX01bDY8@PQ22U:;F/YBRe[008e[@04;F/U:BDY;F/2:DX012DY:DXYBRU:0bDY
00<Q22DY:DX01BU:0bDY0RU:12DY00<YBRe[;F/00bU:00<]JbU::DX00RU:00@]Jc6<:DXU:@@YBP8U
:@05:DX]Jbe[;F/YBP089BT3:DX00b489BTYBP02:DX49BT2:DX29BT00bU:9BTQ20027>L28@P00bDY
8@PU:@078@P39BT012489BTQ22DY0R4800@U:B489BTQ20<Li`039BTQ21cW00LLi`<HaPHLi`HQ20@H
aP8Li`8HaP045:DHaQcW7>L26<H01ABU6<HHaQS67>L00aS61QBU1AcW00@HaQBU48@@Q0<HaP045:DH
aQS66<H27>L01AS65:DHaQBU6<H01QBU00<@Q1BU48@00aBU00@HaQBU5:D@Q08DY@8HaP047>LHaQBU
6<H35:D01A245:D@Q1245:D00a240QBU00<HaQBU5:D00a2400<DYA2448@011BU00@@Q1BU5:DDY@8@
Q0046<HLiaS66<H25:D00a245:DDY@035:D01a245:DHaQ245:D@Q0aS008@Q0XDY@086<HDYABU48@D
YA246<HDY@<HaP035:DHaQS600@HaP035:DHaR48008HaP0348@DYAS600<DY@0448@DYABU5:D248@3
5:D548@010aS48@@Q1BU112400DDYA2436<<Ha2400@<H`035:D@Q124008<H`L@Q08<H`04248@Q0aS
48@336<648@00aS65:D@Q00348@02@aS48@@Q0aS248<Ha245:D@Q00236<148@136<000@48@0=0004
8@@Q1248@P00124<HcF]MkeJeSF]AS4014ic0TYB00E>LdYBCW=>LdYB00M6<@9:DP92408icP8mk`03
@Q0icSg_008mk`03>Lhe[C6<00<icP04=JdaS36<=Jd4>Lh3?Nl4>Lh2<H`01CF]>LhmkcW>=Jd00S6<
00T]Jc6<=JdmkcF];F/YBRe[:DX00Re[00<aS2e[;F/00Re[00<aS2e[<H`00S6<0cF]0cW>00DaS3F]
<H`e[CW>008e[@06<H`e[C6<<H`e[C6<13W>00@e[C6<<H`]J`@aS003;F/aS36<00LaS006;F/aS3W>
>LhmkcF]0S6<00D]JbU::DXYBRe[00<aS003;F/YBRU:00@YBPDU:@8YBP03;F/YBRDY00@YBP049BTY
BRDY9BT28@P00bDY:DXYBP03:DX29BT3:DX00bDY8@PU:@029BT00b489BTU:@029BT00bU:9BTU:@02
8@P00acW8@PQ20029BT00bU:;F/]J`03:DX00be[:DXU:@029BT012U:9BTU:BDY1bU:12DY00DLib48
7>LLib48008U:@058@PU:BDY:DXU:@03:DX013F]?NlmkcF]0RDY00<YBRDY:DX00bU:0Re[0RDY0RU:
0RDY00<YBRe[:DX012U:00<U:B489BT00RDY00<YBRDY:DX01BU:00X]JbU:9BTU:BU:;F/YBRDY8@PU
:@8YBP@U:@04:DXU:BDY9BT3:DX39BT012U:9BTU:BDY0bU:00<U:BU::DX00bU:0RDY00DYBRDY9BTQ
21cW00@U:@<Q208U:@<Q2004:DXQ21cW8@P39BT48@P37>L01R489BTU:B487>LHaP8Q20<Li`046<HL
iacW8@P37>L00b487>LLi`037>L01AS67>LLiacW6<H00aBU0QS600@Lib487>LHaP8DY@076<HLiacW
8@PLiaS67>L01AS60QBU00@HaQcW6<HDY@<HaP<DY@<HaP8DY@@HaP@Li`045:DHaQS67>L26<H348@2
5:D011S65:DDYABU0a242ABU0Q2400@DY@aS36<@Q0<DY@8@Q0055:DHaQBU5:D@Q0045:D01A245:DD
YABU48@00PaS0a2400<HaQcW7>L00QBU00<@Q1S66<H01QBU0QS60Q2400H<HaBU5:D@Q1BU6<H45:D0
1AS648@DYABU6<H011BU00<@Q1BU6<H00aS60QBU00<@Q1BU6<H011BU0acW00DDYA2448@@Q1BU008@
Q0065:D@Q1BU48@DYA240aBU00<@Q1BU5:D00Q2400<<Ha2448@02A240PaS0Q2400@DY@aS36<<H`8@
Q00436<@Q1245:D648@00`aS48@<H`0236<00a245:D@Q00248@01ABU48@@Q1245:D00Q240`aS00<@
Q0aS36<00PaS0Q2400<<Ha2436<00@aS00021240100012448@000P@Q00d8@P@Q1248@SW>NmiNmcW>
AS5>LdYBCW=BU004CW<00dYBCW=:DP02BU80148@AS56<DYB14Ha00I243W>>LhicSg_@Q05?Nl6>Lh2
=Jd2<H`00cF]>LhicP02?Nl6>Lh2=Jd2<H`3=Jd00c6<;F/aS002=Jd00cW>=JdaS002;F/00c6<;F/]
J`02;F/00c6<;F/]J`03<H`3=Jd4>Lh00cF]<H`aS002=Jd2<H`2;F/0136<>LhicS6<13W>00D]JcF]
<H`aS2U:008]J`LaS007>Lhe[C6<;F/YBS6<=Jd00Sg_00<e[Be[;F/00be[00DU:Be[<H`e[Be[008U
:@HYBP04;F/YBRDY:DX2;F/012DY8@PQ22U:1BDY0RU:0RDY00<Q22DY9BT01RDY00<YBRDY8@P00RDY
00<YBR489BT00RDY0b480RDY0R4800DYBRDY8@PQ22DY008]J`HYBP039BTYBRe[00@U:@HYBP059BTY
BRU::DXU:@038@P29BT28@P29BT00bU:9BTU:@039BT01C6<=JdicS6<:DX01RDY00<YBRDY:DX00bU:
12DY1bU:0RDY0R480RDY0RU:00D]JbU::DXYBRe[008YBP8U:@@YBP8U:@04:DXU:BDY9BT2:DX29BT0
0b489BTYBP02:DX59BT00bU:9BTYBP039BT3:DX01Be[:DXU:BDY8@P00bDY00<Q21cW9BT00RDY1248
0RDY00HQ21cW7>LQ22DY8@P29BT012487>LLib480RDY0R4800<U:B488@P01QcW00<HaQcW7>L00QcW
0QS60QcW00<Q21cW7>L00QcW00<HaQcW8@P00QcW0aBU0QS600@Lib487>LHaP@DY@<Li`056<HDYABU
6<HLi`056<H25:D26<H00acW5:DDY@025:D26<H35:D26<H27>L011S67>LHaQcW0aBU00<HaQcW6<H0
0QBU112400DHaQBU48@@Q1BU008@Q08DY@DHaP055:D@Q12448@<H`0348@45:D01A245:DHaQBU48@0
1ABU1Q240PaS00D@Q1BU6<HLiaS6008DY@066<HDYABU48@DYAS60aBU0Q2400<DYA2448@00Q240QBU
00<HaQBU5:D00Q240QBU0QS600LDYA2448@@Q1S65:DHaP025:D26<H35:D26<H35:D36<H01acW48@@
Q1245:DHaQBU008<H`045:DHaQBU5:D248@35:D02`aS48@@Q12436<@Q0aS48@DYA2436<011240PaS
11240PaS0Q2400<8@PaS48@00QBU00@@Q0Q236<8@P8@Q003248<H`aS00<<H`D@Q08DY@8@Q0035:D@
Q0aS00<<H`0348@<H`aS008<H`0348@<H`aS0048@P0000@000@Q124000848@030008@P@Q00848@05
248aS7NmF]He[@02AS42@Q001DHaBU9:DTHaBU800Tic0TYB00I>LdYBBU96<D8@AS43?Nl01T8@?Nli
cT8@BU96<@924096<@07BU9243W>>Lhe[CW><H`00Re[00<e[CW>=Jd00cF]0SW>0Sg_0SW>0c6<00<e
[CW>>Lh00SW>00@e[C6<<H`icP8mk`04=JdaS36<<H`2=Jd5<H`00be[<H`aS004:DX6<H`013F]<H`a
S2e[0S6<0SF]00LicS6<<H`]JcF]>Lhmk`02>Lh012e[:DX]JbU:136<0be[1S6<0SF]00@aS3F]<H`a
S0L]J`03<H`]Jc6<00<]J`03<H`]Jbe[008YBP04;F/U:BDY9BT9:DX29BT00b489BTQ20039BT01248
9BTQ22480bDY00@YBRDY8@PQ20<U:@048@PU:BDY8@P29BT28@P47>L00b489BTYBP02:DX29BT2;F/2
>Lh0136<;F/YBRe[0RU:00<Q22DY9BT012U:0RDY00PQ22DY:DXYBRDY8@PLib480RDY00<YBRDY9BT0
0R4800@YBRDY;F/e[@8icP05<H`]JbDY9BT]J`07:DX01Be[:DX]JbU:9BT01BU:00LU:B489BTU:BU:
9BTYBP02;F/3:DX2;F/00bU:9BTU:@0;9BT2:DX4;F/2:DX29BT2:DX01Re[:DXU:BDY;F/YBP8U:@8Y
BP8U:@03:DX]JbU:008U:@03:DXU:BDY00<U:@03:DXQ22DY008Q208U:@038@PU:BDY00<U:@03:DXU
:BDY00<YBPHQ20037>LHaQS600<Li`036<HLiacW008Li`046<HQ21cW8@P87>L56<H25:D01Q246<HL
iaS67>LQ20LLi`046<HLiaBU5:D37>L26<H01ABU7>LHaQS67>L01AS600@DYA2448@@Q08HaP8Li`06
6<HQ22487>LHaQBU0QS600@DYAS66<HDY@8@Q0035:DHaQBU00<DY@046<H@Q1BU48@35:D348@35:D3
48@00`aS48@<H`095:D01A245:DDYA2436<00Q240aBU0Q2400<DYA245:D00aS60a2400<DYAS65:D0
0Q2400@DYAS66<HHaP8DY@@@Q08DY@056<HLiaS66<HDY@026<H35:D00aS65:D@Q00248@36<H35:D0
1A245:DDYA245:D00Q240acW00LDYA2448@DYA245:D@Q0035:D00aS65:DHaP026<H25:D26<H00a24
36<<H`0336<348@236<448@336<548@020aS48@<H`Q25:DU:Be[8@P936<00a2436<<H`0248@236<0
0a245:DDY@0436<00a2436<<H`0236<248@236<224800003124000@Q00D48@09248000@Q36<icW_N
F]He[D8@0096<@9:DP96<@A:DP07CW=:DTYBAS5:DTHaBU800THa13g_148@00M6<D8@@Q1244Ha@Q0i
cP03=Jd3<H`012e[>LhmkcW>0cF]0T8@0cW>13F]00DicSF]>LhmkcW>00<aS0<icP03<H`e[CF]00<a
S08]J`04:DX]Jbe[;F/4:DX00be[<H`aS002=Jd0136<=Jde[CW>0c6<00<]Jc6<=Jd00SF]00@aS3F]
<H`mk`8icP03=JdaS2e[00<]J`DaS004;F/e[C6<=Jd3<H`00cW>=JdicP02=Jd4;F/2<H`00be[<H`]
J`03;F/2<H`2;F/00bU:;F/YBP029BT012U:9BTYBRDY0RU:00<]JbU::DX00RU:0bDY0R4800DU:BU:
8@PQ21cW008U:@048@PU:BDY:DX39BT01R489BTQ22489BTQ20<U:@067>LQ21S67>LQ21cW0R4800DU
:BU::DXYBRe[008YBP8icP05=Jd]JbU:;F/YBP039BT6:DX69BT012489BTLib480bDY00<YBRDY:DX0
0RDY0Re[00LicSg_=Jd]JbDY8@PU:@02:DX29BT00bU:9BTYBP03;F/00bDY:DX]J`06:DX012DY8@PU
:BDY2RU:00@]JbU:9BTU:@8YBPDU:@04:DXU:BU::DX2;F/7:DX29BT2:DX00bDY:DXYBP03:DX39BT0
2RU:9BTYBRU:9BTQ22DY8@PU:BU:0RDY0b480RDY00<YBRDY9BT0124800@U:BU::DXU:@HQ20@Li`03
8@PLiacW008Li`038@PLiacW00@Li`8Q20037>LHaQcW00<Li`045:DLiacW6<H25:D26<H25:D00aS6
7>LHaP027>L022487>LLib487>LQ21cW48@25:D011S68@PLiaBU0aS611cW00@HaQBU48@DY@<HaP04
5:DHaQcW6<H27>L28@P26<H00aBU6<HDY@026<H25:D348@25:D26<H25:D248@45:D448@25:D448@0
10aS48@@Q1S61aBU00<@Q1BU48@00Q240QBU00<@Q0aS48@00Q240QBU00@HaQcW5:DHaP8@Q08DY@03
6<HDYABU00@DY@8HaP8@Q00336<@Q1BU00<HaP035:DHaQS600@HaP8DY@0348@DYA24008DY@046<HD
YABU48@25:D248@02QBU48@DYABU6<HLiaS65:D@Q0aS0aBU00@@Q0aS48@@Q0@HaPDDY@8@Q0<<H`P@
Q00436<@Q0aS5:D348@03QBU48@@Q0aS48@<H`Q25:DLibDY8@P@Q0aS48@436<248@336<548@01ABU
48@@Q0aS48@00PaS00<8@PaS36<01PaS0@Q2000312400`001240000212403@Q2124000Q2=Jeg_F<H
=Je244YB?Nm244YB009>L`M:DPE6<@A2408mk`I24096<@924006?NlicSW>=JdaS3F]0SW>0cF]00@i
cSg_>LhicP8e[@<icP04=JdaS36<=Jd3>Lh01S6<=JdicTHa@Q0icP@e[@03<H`e[Be[00<]J`<aS08]
J`8aS003=JdaS2e[00P]J`8aS0<e[@04<H`]Jc6<=Jd2>Lh00c6<;F/]J`05;F/00c6<;F/aS005;F/0
1C6<=Jde[CF]<H`00SF]00<icS6<;F/012e[00<aS2e[;F/00RU:00D]Jc6<;F/]Jc6<008]J`@YBP8]
J`08:DXU:BDY;F/e[C6<;F/Q208U:@058@PYBRDY:DXU:@028@P29BT28@P2:DX00bDY7>LQ20059BT2
:DX01RDY8@PQ22489BTQ20<Li`0;8@PU:BDY9BTYBRe[:DX]JbU:;F/e[@02>Lh013F];F/YBRU:0bDY
00PYBRDY9BTU:BU:9BTYBRDY0b4800<LibDY9BT00RDY12480RDY0RU:00Le[D8@>LhaS2DY8@PYBP02
9BT012e[<H`]JbU:0RDY00<YBRe[;F/00Re[1BU:0bDY00<YBRDY:DX012e[00DU:BU::DXaS2e[008U
:@07;F/YBRDY8@PU:BU:9BT00R4800<U:BU:9BT00be[0RU:00H]Jc6<:DXQ22DY;F/3:DX00be[:DXY
BP039BT01bU:9BTYBRDY:DXU:BU:008U:@038@PU:BDY00@Q20039BTYBRDY00<U:@03:DXU:BDY008U
:@@YBP<U:@<Q20@Li`046<HQ21cW8@P27>L38@P02acW6<HLiacW6<HLiaS67>LQ21cW6<H00QcW0R48
00<LiaS66<H00QBU21cW00<HaQcW7>L00QcW00HHaQBU5:DDYAS65:D47>L26<H27>L36<H45:D00aS6
5:DDY@026<H27>L26<H011BU6<HHaQBU0aS60QBU0a240QS600<DYAS66<H00QBU00D@Q1BU5:D@Q0aS
00@@Q08DY@8@Q00436<@Q12448@35:D00a245:DDY@035:D011245:DDYA240aBU00@HaQBU5:DHaPDD
Y@8@Q0065:D@Q0aS36<@Q1S60aBU00<HaQBU5:D00QBU0QS600@LiaS67>LHaP<Li`<HaP037>LHaQBU
008@Q0035:D@Q1BU00<@Q0055:D@Q12448@DY@0448@26<H00a245:D@Q00248@25:D248@01ABU6<HH
aQS65:D00aS60QBU0aS60Q240PaS00DDYA2436<<Ha2400<DY@8<H`8@Q00336<@Q124008@Q00336<@
Q0aS00@@Q08DY@0448@<H`Q236<2248336<0112436<@Q1240PaS00@@Q1BU5:D@Q0@<H`0348@<Ha24
00@<H`4@Q04<H`4<H`0000<000@Q000010@Q00T8@P@Q12448@aS=JekgU[F=Jd00THa00=244HaAS40
0dYB00=6<DYBBU800dYB1DHa0T8@0Sg_0SW>00Dmkd8@AS4mkd8@0096<@04BU9244HaAS42>Lh0136<
=Jde[C6<0cF]1SW>0cF]00@icSF]<H`e[@<icP04<H`e[CW>?Nl3@Q02=Jd01C6<=Jde[CF];F/01c6<
0Re[0S6<0be[00<aS2e[:DX012e[00@aS3F]=Jde[@8aS0<e[@@aS0D]J`@aS0<]J`04<H`]Jbe[<H`2
>Lh01CF]<H`e[C6<=Jd00S6<1Be[00<YBRDY9BT00be[0S6<00<YBRe[:DX00RU:00@]JbU::DXU:@8Y
BP03;F/aS2e[008U:@058@PU:BDY9BT]J`039BT02248:DXQ21cW9BTYBRe[9BT28@P39BT00b489BTU
:@03:DX00b489BTLi`037>L02b487>LQ22489BTYBRe[<H`]Jc6<;F/00cF]00@icRe[<H`YBP8U:@04
8@PU:BDY9BT2:DX01RDY8@PLib489BTQ20@U:@@Q20DU:@07<H`mkd8@=JdYBRDY;F/00RU:12e[1BU:
0Re[0RU:00DU:BU:9BTU:B48008U:@<YBP03;F/YBRe[008YBP@]J`03:DXU:BDY00<U:@03:DXU:BDY
008Q20049BTYBRe[;F/2:DX012DY;F/YBRU:0RDY0bU:00<]JbU::DX00bDY00@YBRDY:DX]J`DYBP04
9BTQ22DY8@P29BT012489BTU:B480RDY00<YBRDY9BT00bDY00<Q22DY:DX00RU:00<Q22DY9BT00b48
00<U:B487>L00acW00DQ21cW7>LLiaS6008Li`8Q20<Li`036<HDYAS600<Li`8Q208Li`8DY@LHaP04
7>LQ21cW7>L26<H37>L00aS65:D@Q0035:D37>L26<H012487>LLiaS61ABU00DHaQBU6<HHaQBU008H
aP047>LHaQS65:D46<H35:D248@00aBU48@DY@0348@01QBU6<HDYA245:D@Q08DY@0436<@Q1245:D6
48@35:D248@00aBU6<H@Q00248@26<H00aBU48@DY@025:D248@35:D00aS65:DDY@025:D348@011BU
48@DYABU0a240aBU00<@Q1BU6<H00QBU0QS60QcW0QS60acW0QS600DDYAS65:D@Q0aS00D@Q0035:D@
Q1BU008DY@@@Q0065:DHaQS66<H@Q0aS0Q240QBU0Q2400<DYAS65:D00aS600@DYAS65:DDY@8HaP03
48@<H`Q200@@Q0<<H`8@Q00336<@Q0aS00P@Q0<<H`035:DHaQBU008<H`0548@8@PQ2248<H`0248@0
0`aS248<H`0248@336<011245:DDYA240PaS00<8@PaS48@00`aS00@8@PaS36<@Q048@P0010@Q00D0
00@Q00048@Q200848@05248e[GooHaPicP02BU800dHa@Q124003BU83CW<014YBAS5:DTYB0THa00=:
DTHaAS401T8@00Lmkd8@@Q0mkd8@?Nm24004?Nl0148@>LhicSW>0Sg_0SW>00<mkcW>>Lh00SF]0cW>
0cg_00<icSF]<H`00SF]00<icSF]=Jd00cF]0cW>00<aS2e[=Jd00Sg_00<aS2U:;F/00c6<0Re[0S6<
00<e[C6<;F/00c6<12e[00DaS2e[;F/]JcF]008icP@e[@<icP05=JdaS2U::DXaS002=Jd00c6<;F/]
J`03<H`00bU:<H`e[@02>Lh4<H`012e[<H`aS36<0be[00DaS2e[;F/]JbU:00<]J`03:DX]JbU:008]
J`06<H`YBRU::DX]JbU:0Re[00<YBRe[;F/01bU:0bDY0RU:0R4800<U:BU:;F/00RDY00<Q21cW9BT0
1bDY12480acW0R4800<U:BU:9BT01RU:0S6<0SF]00@]JbU:9BTQ20<U:@04:DXU:BDY:DX39BT00b48
9BTQ20029BT00bU:9BTU:@028@P29BT2:DX01S6<>LhicSF]:DXU:@8YBP039BTYBRe[008YBP039BTY
BRe[008YBP8]J`8YBP039BTQ22DY008]J`04:DXU:BDY;F/2<H`012e[:DXYBRe[0RU:136<00HU:B48
9BTQ22DY:DX49BT00bU:;F/YBP03;F/5:DX01be[:DXYBRU:;F/YBRDY008YBP8]J`LYBP8U:@048@PU
:BDY9BT28@P29BT01BU:9BTU:B48:DX00RDY00<Q22DY9BT00RDY00P]JbU:8@PQ22DY:DXQ21cW0QS6
00<Lib488@P0124800<U:B487>L01acW00@HaQcW7>LLi`8Q20039BTQ21cW008Li`<HaP055:DQ2248
8@PLi`026<H37>L46<H00aBU6<HHaP056<H27>L00b486<HDY@026<H45:D01AcW6<HHaQBU6<H00QcW
00<HaQBU6<H00aS600<DYAS648@00QBU0Q240QBU0QS600<DYA245:D00QS600<DYA2448@00a240QBU
00@HaQBU5:D@Q08<H`8@Q0<DY@8@Q0055:DHaQBU48@DY@026<H01ABU48@@Q1BU6<H011BU00<HaQBU
5:D01A240QBU0a240aS600LDYAS65:DDYAS65:DHaP057>L36<H35:D011245:DDYABU0Q2400<DYA24
48@00PaS0a2400<DYA246<H00QBU00<HaQBU48@01A2400<<Ha2448@00QBU00<@Q1BU5:D00QS611BU
00HHaQBU5:DDYA245:D248@00aBU36<<H`0248@01QBU48@@Q0aS48@<H`8@Q0075:D@Q12436<8@PaS
48@00QS600@@Q1BU48@<H`<8@P<<H`0348@8@PQ2008<H`8@Q08<H`065:D@Q0aS36<@Q0aS0PQ20`aS
00<8@PaS36<00@Q20000100012448@000`@Q0PQ200L000@Q248e[G_NHaPicP02BU800d8@AS56<@02
AS401DYBCW=>LdicBU800THa00=244HaAS400TYB00=6<D8@?Nl00T8@00<mkd8@AS400T8@00DmkcW>
@Q0mkd8@00@mk`HicP03?NlicSW>008icP09=JdicSF]>Lhmkd8@?NlicS6<00He[@8aS0<icP8e[@08
<H`icSW>>Lhe[C6<;F/aS0@]J`05<H`e[CF]<H`]J`03<H`4;F/5<H`4=Jd2<H`01SF]>LhicSW><H`]
J`<aS003=JdaS36<00<aS0<]J`03<H`icSF]00@aS004;F/aS36<<H`4;F/2<H`012U:;F/YBRU:0be[
00@YBRe[;F/YBP8]J`<YBP8]J`8YBP8]J`03<H`YBRU:00<YBP`U:@8Q20@U:@048@PU:BU:9BT38@P3
7>L38@P29BT6:DX00be[<H`aS003<H`00be[:DXQ20028@P012U:;F/YBRDY0R480bDY0R4800@U:B48
8@PU:@@Q20049BTYBRDY;F/3=Jd00be[9BTYBP029BT3;F/012U:9BTU:BU:12e[00DaS2e[9BTQ22DY
008YBP8U:@03:DX]Jbe[00<]J`@YBP@]J`TU:@XYBP03;F/YBRU:008YBP8]J``YBP05;F/Q21cW8@PU
:@02:DX01bDY8@PU:BDY:DXU:B48008YBP039BTQ2248008U:@058@PU:BU::DXU:@028@P00bDY8@PQ
20028@P011cW8@PLiacW0R4800<U:B488@P011cW11S60R4800<Lib487>L00b480acW0QS600@DYAS6
6<HLi`<Q20037>LHaQS6008Li`8HaP055:DHaQBU5:DHaP047>L02AS67>LHaQcW6<HDYAS65:DHaP02
5:D00aS65:DHaP046<H00aBU6<HHaP026<H031BU6<HHaQS65:D@Q1BU6<HDY@aS48@HaP8DY@8@Q004
5:DHaQBU5:D236<01ABU48@HaQBU6<H00QBU00L<Ha2448@DYAS65:D@Q00A5:D00aS65:DDY@0248@3
5:D448@00aS65:DDY@035:D02QS65:DHaQS67>LHaQcW6<HQ21cW11S600<DYA2448@00QBU0Q2400<D
YA2448@00PaS00@@Q1BU5:DDY@@@Q0055:DHaQS66<HDY@0248@00aBU48@@Q00648@35:D01AS65:DD
YAS65:D00QS600<DYA2448@00Q2400@DYA2448@@Q08<H`8@Q0<<H`8DY@0348@<H`aS008@Q08<H`03
48@DYABU00<@Q08<H`88@P<<H`03248<H`Q200<@Q08<H`8@Q0045:D<H`aS48@324800`aS48@<H`04
36<000848@0700048@@Q124000@Q24800P@Q00L8@SF]OomS63W>BU9>L`02AS400dYBCW=>L`03BU80
14icDYA:DTYB0THa00I:DTHaAS5244Ha@Q03AS44@Q02?Nl3>Lh00cF]>LhicP06?Nl00d8@?Nlmk`02
?Nl0148@?NlicSW>0Sg_00LicSg_?NlmkcW><H`e[@02>Lh4=Jd00cW>=Jde[@02=Jd00cW>=Jde[@06
=Jd022U:<H`aS3W>?Nle[C6<=Jd2<H`013F]<H`aS3F]0S6<13F]0SW>0cF]1CW>136<00Te[CW><H`a
S2U:<H`icSF]>Lh00cF]0S6<00@e[C6<;F/]J`8aS003;F/aS36<008aS004;F/aS2e[<H`2;F/01c6<
;F/YBRDY:DX]Jc6<008]J`03:DX]Jc6<008]J`03:DX]Jc6<00<]J`8YBP03;F/YBRe[00HYBP@U:@05
:DXU:B489BTYBP029BT28@P02BDY8@PU:BDY8@PHaQcW8@PYBP029BT2:DX39BT2:DX00bDY:DXYBP03
;F/3<H`012U:9BTU:B480RDY0RU:00<U:B48:DX00RU:12480bDY00@YBRDY9BTU:@8]J`06<H`icS6<
<H`YBRDY0Re[00@aS2e[;F/YBP8]J`DYBP049BTQ22DY9BT3:DX3;F/2:DX2;F/3:DX2;F/3<H`01BU:
9BTU:BDY:DX00be[00@YBRe[;F/aS0<]J`03:DX]Jbe[008YBP<]J`03:DX]Jbe[008YBP8U:@04;F/Y
BRe[;F/7:DX39BT00b48:DXU:@02:DX39BT012489BTYBRDY0RU:0RDY1BU:12DY00PQ21cW8@PQ22DY
8@PLib480RDY0R480QcW00@HaQcW7>LQ20@Li`056<HLiacW8@PU:@028@P00acW6<HHaP027>L01b48
7>LU:BDY8@PU:AcW008HaP045:DLiacW7>L26<H47>L26<H37>L26<H25:D01AS65:DLiaS65:D011S6
00@DYAS67>LLi`<HaP055:DLiaS66<HLi`025:D248@26<H35:D36<H65:D26<H01QcW6<HHaQS65:D@
Q0DDY@0348@DYA2400<@Q0<DY@8@Q0@DY@036<HDYA24008DY@036<HDYABU00XDY@PHaP<DY@8HaPDD
Y@036<HDYABU008@Q0035:DHaQBU008@Q0045:D<H`aS48@25:D011246<HHaQcW11BU0`aS0a2400<<
Ha245:D00QBU00@HaQBU5:D@Q0@DY@046<HLiaBU36<348@00`aS48@@Q0025:D548@00`aS48@@Q002
48@336<25:D448@00aBU48@@Q00336<348@236<010Q236<<Ha240PaS0Q240QBU0Q240PaS00D8@PaS
36<<Ha24008<H`0000D48@0012448@0000<48@0824848@@Q248e[G_NF]HicP=:DP03AS5:DTic00=:
DP=>L`9:DP04AS5:DTHaBU83AS400dYBAS524003@Q02?Nl2@Q001cg_>LhicSF]>Lhmkd8@008icP05
=JdicT8@?Nm24002?Nl2@Q001Cg_>LhicSW>?Nl00T8@13W>0cF]00<icSF]=Jd00SF]0SW>0SF]00Da
S3W>>LhicS6<008e[@<aS004;F/aS36<>Lh2=Jd01SW><H`aS2e[<H`icP@aS0@e[@03<H`e[CW>00Hi
cP<e[@03<H`e[C6<00<aS003;F/aS36<008e[@05>Lhe[CF]=JdicP02<H`012e[<H`aS36<0Re[00Da
S2e[<H`e[C6<00<]J`07<H`YBRU:9BTYBRe[:DX01Be[0RU:00H]Jc6<;F/]JbDY;F/2:DX01BDY;F/Y
BRU:9BT00be[00<YBR488@P00RDY00TYBRDY9BTQ22DY8@PU:B48:DX00RDY0R4800XLib488@PQ22DY
8@PU:BU:;F/YBP8U:@8YBP<U:@03;F/YBS6<008e[@03;F/YBRDY008U:@048@PU:BU::DX39BT2:DX0
0bDY8@PU:@028@P012DY8@PYBRU:0RDY00PYBRDY<H`icT8@<H`YBR480Re[00DYBRe[;F/]Jc6<00LY
BP038@PU:BU:00HYBP049BT]Jbe[<H`2;F/2:DX2;F/02S6<;F/YBRU:9BTYBRe[:DX]JbU:0Re[0bU:
00HaS2e[;F/]JbU:9BT2:DX2<H`00be[9BTYBP05:DX2;F/00c6<;F/YBP06:DX49BT022U:9BTU:BDY
8@PU:B489BT2:DX012DY8@PQ22DY0RU:00@]JbU:9BTYBP8U:@DQ2003:DXU:BDY00HQ20037>LQ21S6
008Li`038@PLiacW008HaP8Li`<Q208Li`8HaPDLi`<Q208Li`8HaPHLi`046<HLiacW7>L26<H37>L2
5:D01A245:DHaQcW6<H00QBU0QS60QcW0QS600DLiaS66<HHaQcW00<DY@057>LHaQBU48@DY@026<H4
5:D01aS65:DDYABU48@DYA2400<HaP045:DHaQS66<H25:D248@01ABU6<HDYABU48@00QBU0a2400<D
YA2448@00QBU00@HaQ245:DDY@<HaP0448@DYABU6<H25:D00a245:DDY@065:D26<H25:D36<H01ABU
6<HDYAS65:D00QS600@DYA245:D@Q08DY@8@Q0<DY@8@Q00336<@Q124008@Q0<DY@0448@HaQS65:D2
48@010aS48@<Ha240`aS00D@Q1BU48@DYAS600<DY@066<HDYAS65:DHaQBU0Q240aBU00@@Q0aS48@D
Y@@@Q00336<@Q12400<@Q00536<@Q0aS48@<H`0248@00aBU48@DY@0248@224800`aS48@<H`0336<0
2@Q236<<Ha2436<8@PaS48@DY@0348@236<010Q236<<H`Q20PaS0A240@Q200000`0012448@021240
1@0012448@@Q00000`@Q00D000@Q12448@0000<48@0500048@@Q1240000312401@0012448@@Q0000
0`@Q00D000@Q12448@0000<48@0500048@@Q1240000312401@0012448@@Q00000`@Q00D000@Q1244
8@0000<48@0500048@@Q1240000312401@0012448@@Q00000`@Q00D000@Q12448@0000<48@050004
8@@Q1240000312401@0012448@@Q00000`@Q00D000@Q12448@0000<48@0500048@@Q124000031240
1@0012448@@Q00000`@Q00D000@Q12448@0000<48@0500048@@Q1240000312401@0012448@@Q0000
0`@Q00D000@Q12448@0000<48@0500048@@Q1240000312401@0012448@@Q00000`@Q00D000@Q1244
8@0000<48@0500048@@Q1240000312401@0012448@@Q00000`@Q00D000@Q12448@0000<48@050004
8@@Q1240000312401@0012448@@Q00000`@Q00D000@Q12448@0000<48@0500048@@Q124000031240
1@0012448@@Q00000`@Q00D000@Q12448@0000<48@0500048@@Q1240000312401@0012448@@Q0000
0`@Q00D000@Q12448@0000<48@0500048@@Q1240000312401@0012448@@Q00000`@Q00D000@Q1244
8@0000<48@0500048@@Q1240000312401@0012448@@Q00000`@Q00D000@Q12448@0000<48@050004
8@@Q1240000312401@0012448@@Q00000`@Q00D000@Q12448@0000<48@0500048@@Q124000031240
1@0012448@@Q00000`@Q00D000@Q12448@0000<48@0500048@@Q1240000312401@0012448@@Q0000
0`@Q00D000@Q12448@0000<48@0500048@@Q1240000312401@0012448@@Q00000`@Q00D000@Q1244
8@0000<48@0500048@@Q1240000312401@0012448@@Q00000`@Q00D000@Q12448@0000<48@050004
8@@Q1240000312401@0012448@@Q00000`@Q00D000@Q12448@0000<48@0500048@@Q124000031240
1@0012448@@Q00000`@Q00D000@Q12448@0000<48@0500048@@Q1240000312401@0012448@@Q0000
0`@Q00D000@Q12448@0000<48@0500048@@Q1240000312401@0012448@@Q00000`@Q00D000@Q1244
8@0000<48@0500048@@Q1240000312401@0012448@@Q00000`@Q00D000@Q12448@0000<48@050004
8@@Q1240000312401@0012448@@Q00000`@Q00D000@Q12448@0000<48@0500048@@Q124000031240
1@0012448@@Q00000`@Q00D000@Q12448@0000<48@0500048@@Q1240000312401@0012448@@Q0000
0`@Q0@000@@Q0@@Q000312401@0012448@@Q00000`@Q00D000@Q12448@0000<48@0500048@@Q1240
000312401@0012448@@Q00000`@Q00D000@Q12448@0000<48@0500048@@Q1240000312401@001244
8@@Q00000`@Q00D000@Q12448@0000<48@0500048@@Q1240000312401@0012448@@Q00000`@Q00D0
00@Q12448@0000<48@0500048@@Q1240000312401@0012448@@Q00000`@Q00D000@Q12448@0000<4
8@0500048@@Q1240000312401@0012448@@Q00000`@Q00D000@Q12448@0000<48@0500048@@Q1240
000312401@0012448@@Q00000`@Q00D000@Q12448@0000<48@0500048@@Q1240000312401@001244
8@@Q00000`@Q00D000@Q12448@0000<48@0500048@@Q1240000312401@0012448@@Q00000`@Q00D0
00@Q12448@0000<48@0500048@@Q1240000312401@0012448@@Q00000`@Q00D000@Q12448@0000<4
8@0500048@@Q1240000312401@0012448@@Q00000`@Q00D000@Q12448@0000<48@0500048@@Q1240
000312401@0012448@@Q00000`@Q00D000@Q12448@0000<48@0500048@@Q1240000312401@001244
8@@Q00000`@Q00D000@Q12448@0000<48@0500048@@Q1240000312401@0012448@@Q00000`@Q00D0
00@Q12448@0000<48@0500048@@Q1240000312401@0012448@@Q00000`@Q00D000@Q12448@0000<4
8@0500048@@Q1240000312401@0012448@@Q00000`@Q00D000@Q12448@0000<48@0500048@@Q1240
000312401@0012448@@Q00000`@Q00D000@Q12448@0000<48@0500048@@Q1240000312401@001244
8@@Q00000`@Q00D000@Q12448@0000<48@0500048@@Q1240000312401@0012448@@Q00000`@Q00D0
00@Q12448@0000<48@0500048@@Q1240000312401@0012448@@Q00000`@Q00D000@Q12448@0000<4
8@0500048@@Q1240000312401@0012448@@Q00000`@Q00D000@Q12448@0000<48@0500048@@Q1240
000312401@0012448@@Q00000`@Q00D000@Q12448@0000<48@0500048@@Q1240000312401@001244
8@@Q00000`@Q00D000@Q12448@0000<48@0500048@@Q1240000312401@0012448@@Q00000`@Q00D0
00@Q12448@0000<48@0500048@@Q1240000312401@0012448@@Q00000`@Q00D000@Q12448@0000<4
8@0500048@@Q1240000312401@0012448@@Q00000`@Q00D000@Q12448@0000<48@0500048@@Q1240
000312401@0012448@@Q00000`@Q00@000@Q12448@4000000?h000@Q00048@00124000@Q00048@00
124000@Q00048@00124000@Q00048@00124000@Q00048@00124000@Q00048@00124000@Q00048@00
124000@Q00048@00124000@Q00048@00124000@Q00048@00124000@Q00048@00124000@Q00048@00
124000@Q00048@00124000@Q00048@00124000@Q00048@00124000@Q00048@00124000@Q00048@00
124000@Q00048@00124000@Q00048@00124000@Q00048@00124000@Q00048@00124000@Q00048@00
124000@Q00048@00124000@Q00048@00124000@Q00048@00124000@Q00048@00124000@Q00048@00
124000@Q00048@00124000@Q00048@00124000@Q00048@00124000@Q00048@00124000@Q00048@00
124000@Q00048@00124000@Q00048@00124000@Q00048@00124000@Q00048@00124000@Q00048@00
124000@Q00048@00124000@Q00048@00124000@Q00048@00124000@Q00048@00124000@Q00048@00
124000@Q0P000?d48@00124000@Q00048@00124000@Q00048@00124000@Q00048@00124000@Q0004
8@00124000@Q00048@00124000@Q00048@00124000@Q00048@00124000@Q00048@00124000@Q0004
8@00124000@Q00048@00124000@Q00048@00124000@Q00048@00124000@Q00048@00124000@Q0004
8@00124000@Q00048@00124000@Q00048@00124000@Q00048@00124000@Q00048@00124000@Q0004
8@00124000@Q00048@00124000@Q00048@00124000@Q00048@00124000@Q00048@00124000@Q0004
8@00124000@Q00048@00124000@Q00048@00124000@Q00048@00124000@Q00048@00124000@Q0004
8@00124000@Q00048@00124000@Q00048@00124000@Q00048@00124000@Q00048@00124000@Q0004
8@00124000@Q00048@00124000@Q00048@00124000@Q00048@00124000@Q00048@00124000@Q0004
8@00124000@Q00048@00124000@Q00048@00124000@Q00048@020000P0@Q00048@00124000@Q0004
8@00124000@Q00048@00124000@Q00048@00124000@Q00048@00124000@Q00048@00124000@Q0004
8@00124000@Q00048@00124000@Q00048@00124000@Q00048@00124000@Q00048@00124000@Q0004
8@00124000@Q00048@00124000@Q00048@00124000@Q00048@00124000@Q00048@00124000@Q0004
8@00124000@Q00048@00124000@Q00048@00124000@Q00048@00124000@Q00048@00124000@Q0001
12400001\
\>"], "Graphics",
  Evaluatable->False,
  ImageSize->{640, 480},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:00001h1000`40O003
h00O1@@Q00`000@Q1248@P00124<Hcg_Oom[FSg_CW<4F]H3DY@2CW<00e:D
BU9>L`02CW<2DY@3CW<3DY@015JeDYABU4ic0U:D0UJe0Tic00=:DTHaCW<0
0eJe00]BU4icE[EBU4icDYAF]E:DCW=:DTic009F]@03DYA:DTYB009>L`07
E[EJeTic@Q0mkd8@CW<014YB0U:D00=6<D8@>Lh00T8@00]6<DYBAS5:DU:D
F]IF]DicAS5>LdYB009>L`=:DP03AS5:DTic009:DP03AS5:DTYB00A>L`9B
U007E[EBU4icCW=:DTicBU800dic00MBU5JeDYABU4YBCW=BU003CW<015:D
CW=>LeJe0U[F00=BU4icCW<00U:D0UJe00]>LdHaAS56<E:DF]IBU4icDYA>
Le:D00=F]@9Nm`03F]IBU5Je00=JeP9F]@9:DP04CW=BU5[FE[D3CW<2BU82
AS400dYBCW=>L`03CW<00dYBCW=6<@02BU800dHaBU9BU006DY@5CW<00eJe
DYABU003DY@2CW<01E:DE[EF]DicE[D00Tic00=:DTicCW<014ic00QF]E:D
F]INmeJeDYA>Le:D0UJe00ABU4icDYA>L`EBU004E[EBU5:DDY@3E[D3DY@2
E[D015:DCW=BU5:D0Tic00=:DTicDY@01E:D00EF]E[FE[EF]E:D009>L`04
BU9BU5:DE[D2DY@00dicDYABU008E[D4DY@4E[D00e:DCW=>L`02DY@00eJe
DYA:DP02CW<5DY@3E[D2G_L015[FE[EBU5Je0U:D00ENmfLiHaQS65Je009J
eP06E[EJeU[FG_MJeUJe0T8@00E6<E:DG_MJeUJe00=JeP03HaQNmekg009N
m`08HaQW>F<HG_MF]E[FE[EBU0=F]@03F]INmekg009JeP05G_MJeUJeE[EB
U002E[D01e[FE[EBU5JeF]INmeJe009JeP9Nm`03F]INme:D00=F]@05F]IF
]E:DE[EJeP02E[D2F]H00f<HG_MJeP03F]H015kgHaQNmekg0U[F00ANmf<H
G_MJePENm`03F]INme[F00=S60YNm`=S6008G_MJeUkgF]INmf<HG_MS60=W
>@05HaQNmf<HG_MS6003G_L3HaP01EkgHaQNmekgHaP00Ukg16<H0U[F00=F
]E[FE[D00eJe00=Nmf<HHaP00V<H0fLi00=S66LiIcT00fLi0V]J00=W>F<H
HaP00V<H0fLi0V<H00ANme[FHaQS609[FP0:HaQW>FLiHaQW>F<HIcUNme[F
HaP3IcT016<HF]IS66<H16Li00A[FVLiJeYW>@A[FP9W>@03HaQW>FLi009S
609W>@04JeYW>F]JIcT2HaP2IcT2JeX01FLiJeYW>FLiG_L00V<H00=Nmf<H
HaP016Li00=S65kgG_L00VLi00A[FVLiHaQS60AW>@04HaQNmf<HG_L4HaP2
G_L3HaP3G_L00e[FG_MNm`02G_L:F]H2E[D1?Nl0000500048@0012400003
12402PQ212448@aS?Nmoof]J@Q1BU5[F1EJe15:D00EF]E:DDYABU5Je009B
U09:DP05DYAF]EJeE[EJeP04DY@2F]H2CW<2BU801DicDYAF]EJeDY@00UJe
00IJeU:DDYAJeUJeCW<2BU800eJeDYABU004BU82DY@014YB@Q0mkd8@0dYB
00Y>Le:DDYAF]DicBU96<DYBCW=:DP96<@9>L`04DYAJeU[FDY@2BU800dic
E[EF]@02CW<2BU8014icBU9>Ldic0U:D1Dic0U:D00=F]E:DCW<00e:D00=>
LdYBBU800eJe00=BU4YBCW<00Tic00A:DTicCW=>L`=BU09F]@=BU005CW=F
]E[FDYA:DP02AS400dicE[EF]@03DY@00dicDYABU006F]H00eJeF]IF]@03
DY@014icDYABU5:D0eJe00eBU4YBBU9:DTicDYA>LdYBCW=BU5JeDYA>L`06
BU802TicDYABU4icDYA>LeJeDYA>LdYB0Tic00=BU4icCW<015:D0Tic0U:D
00=>Le:DCW<014ic0TYB00E>Le:DE[EBU5Je009BU09F]@03F]IF]EJe00EB
U006E[EBU5:DCW=BU5Je0e:D15Je00=JeU:DDY@01Dic0e:D00=F]E:DDY@0
0U:D0UJe00AJeUkgE[EF]@=>L`03DYAF]EJe009BU0=F]@07F]INme[FF]IF
]E:DE[D00U[F0eJe00EJeUkgF]IBU5Je009BU006CW=F]EJeDYA>LdHa15:D
0UJe00AJeUJeE[EJeP9F]@04DYAF]E:DE[D2F]H016<HG_MNmekg0e[F00AS
65kgE[E>L`924008DYAF]F<HF]IF]EkgHaQW>@9S6004F]INmf<HIcT3HaP2
F]H2E[D5F]H3G_L3F]H00eJeF]IBU002E[D015[FG_MNme[F0UJe00=JeV<H
HaP00ekg00ES65kgF]IJeUJe00MJeP=Nm`04F]INmekgG_L2F]H015kgHaQN
mekg0U[F0Ukg0e[F00UNmf<HG_MF]E[FG_MW>F]JHaP015kg15[F1Ekg00=S
66LiIcT00V<H0fLi00AS66LiHaQS609Nm`03HaQNmekg00=S6003G_MJeUkg
00INm`04F]IF]EJeF]H5G_L3IcT2JeX016LiHaQW>F]J0VLi00IS66LiJeYW
>F<HIcT3JeX2IcT00f<HIcUS6003HaP015kgHaQS66<H0fLi00IS66LiJeY[
FVLiHaP3F]H00ekgHaQW>@02IcT00ekgHaQS6004IcT00f]JIcUW>@02JeX0
0fmkIcUW>@07HaP2IcT00f]JIcUW>@03HaP2IcT3JeX4HaP2IcT3HaP2IcT4
HaP00fLiHaQ[FP04IcT016<HIcU[FVLi1V<H0VLi1F<H0ekg00ES65kgG_MJ
eUkg00=JeP04E[EJeU[FF]H2E[D1G_L1E[D1?Nl000P48@0924848@0036<m
kgooJeXmke:D009JeP9F]@9BU003E[EBU5:D00EBU003E[EBU4ic009:DP9B
U00:E[EJeU[FDYA>Le:DE[EJeUJeDY@2CW<00dYBCW=BU002DY@2E[D04U[F
DYAF]E:DF]IBU4icBU9>Le:DE[EBU4icBU96<DYBCW=BU096<@03?Nm244YB
009:DP9>L`9F]@05CW=6<D8@BU9>L`04BU8024icDYAJeUJeDYA>LdYBCW<3
DY@2CW<00dYBCW=:DP02CW<3DY@2CW<01DYBCW=BU5JeDY@00Tic0e:D00A>
LdYBCW=BU09JeP05DYA:DTicCW=:DP02CW<2DY@01DicDYAF]EJeF]H00U:D
00]>Le:DDYAJeU:DBU96<DYBCW=F]E:D009F]@03CW=BU5:D009F]@9JeP04
G_MJeU[FF]H3E[D01e:DCW=BU5:DCW=BU5Je00=BU0=:DP9>L`03BU9>Ldic
009BU09>L`=:DP05AS5:DTicCW=BU003CW<00e:DE[EBU002CW<00dYBCW=B
U002DY@00dicDYABU003DY@00dicDYABU002CW<01DYBCW=BU4YBCW<00TYB
00=BU5JeE[D00e:D00=JeUJeE[D00UJe15:D0UJe2E:D0UJe00AJeUJeDYAB
U09>L`05DYA>LdicCW=BU002E[D4DY@2E[D2F]H01UJeDYABU4YBCW=BU0=F
]@9BU0=F]@=JeP05DYAF]EJeE[EJeP03E[D3F]H01EJeDYABU4icDY@00UJe
00=>LdYBBU8015:D2EJe00ABU5JeDYAJeP=Nm`9JeP07G_MJeU[FHaQNmeJe
CW<00T8@00UBU5[FG_MNmeJeF]INmfLiHaP00ekg00=S66LiHaP00V<H00MN
me[FE[EF]E[FE[ENm`03F]H2G_L015[FE[EF]E[F15Je0U[F00MNmf<HE[EF
]E[FG_MS6004G_L2F]H01EJeF]IJeU[FE[D00e[F1Ekg00IS65kgF]IJeUkg
HaP2G_L00e[FG_MNm`02G_L00e[FE[ENm`03G_L00e[FE[ES6002IcT00f<H
G_MNm`02G_L4F]H5G_L3HaP016LiHaQS66Li0V<H0VLi0ekg0V<H0Ukg00IS
65kgHaQJeUkgHaP3G_L00e[FG_MNm`02E[D2F]H4G_L2IcT2JeX00fLiHaQW
>@03IcT2HaP2IcT00f<HIcUW>@02JeX01FLiHaQW>F<HIcT00V<H00ENmf<H
HaQNmf<H00MW>@0:JeYS66<HF]IF]E[FG_MS66]JIcT2HaP00ekgIcUS6002
IcT016]JIcUW>FLi16]J00IS66LiHaQW>F<HIcT2HaP3IcT00f]JHaQS6002
HaP3IcT2JeX016LiHaQS66<H0fLi0V<H0VLi1F<H2VLi0V<H00ANmf<HHaQW
>@ES6006IcUS65kgF]INmf<H0Ukg00EJeUkgF]IJeUJe009JeP03G_MF]E[F
009JeP5BU04mk`0000D000@Q00048@0000<48@0;24848@@Q36=6<GooIcTi
cTicG_MJeP05DY@00eJeDYAF]@05DY@2CW<3DY@4E[D00e:DE[EBU003E[D3
DY@00dicBU9>L`02E[D015:DE[EF]E[F0eJe0Tic00E:DTHaBU9:DTic00=:
DP05AS5:DTHaBU96<@02BU82DY@2CW<2DY@02UJeBU96<D8@BU9>LdYBAS5>
Le:D0Tic00=BU5[FF]H00Tic00=BU5JeE[D00U:D00E:DTicDYA>LdYB009>
L`A:DP03DYA>Le:D00IBU0=>L`IBU004CW=:DTicBU83CW<015:DCW=>Le:D
0UJe00=>Le:DDY@00UJe00ABU4icCW=6<@9>L`9BU003E[EBU4ic009>L`9F
]@=JeP9F]@04DYAF]EJeE[D2DY@3CW<015:DE[EF]Dic0TYB00=6<DYBCW<0
0dic0U:D0dic0TYB00=6<DYBBU800e:D00=>LdYBCW<00e:D14YB0dic00EB
U5[FDYA>LdYB009BU0=:DP04DYA>LdicAS42BU800dicDYABU002DY@014ic
DYABU5:D0UJe0U[F00AF]DicCW=>L`9BU003CW=BU5:D009F]@04DYA>Le:D
E[D3G_L01E:DE[EBU4YBCW<00U:D0dic00=BU5JeE[D00U:D00=>Le:DE[D0
0e[F00ABU4YBCW=BU09JeP04E[EBU5JeDY@2E[D3F]H2E[D00e[FE[EF]@06
F]H2E[D2CW<2DY@00e[FE[EBU004CW<5DY@2E[D3DY@3F]H2E[D01EkgHaQS
65[FE[D00Ukg00IJeU:DBU96<DYBDY@3F]H4G_L3HaP01e[FHaQW>F<HF]IN
mf<H009Nm`05E[EJeU[FG_MJeP02E[D3G_L00eJeF]INm`02F]H2DY@015Je
F]INmekg0UJe0e[F00ANmf<HG_MS609Nm`03F]INme[F00=JeP03E[EJeUkg
009Nm`AJeP9F]@9JePAS609JeP05G_MJeU[FF]IF]@02F]H01UkgF]INmf<H
IcUS609Nm`04IcUNme[FDY@5F]H01V<HIcUW>F]JIcUS609Nm`ES609W>@04
HaQNmf<HHaP3G_L4F]H3E[D015kgHaQS66<H0Ukg0V<H1FLi16]J00EW>F<H
HaQW>F<H00MW>@9[FP03IcU[FVLi00AS609W>@06HaQW>F<HHaQW>F<H16Li
0V<H00=Nme[FG_L00Ukg00AW>F]JJeYS609Nm`04HaQW>F]JJeX4IcT3JeX0
16<HIcUS66<H16Li0V<H00=W>F<HHaP00VLi00QS65kgG_MS66LiJeYW>F<H
0VLi00=S66LiJeX00VLi0f<H0VLi1F<H1FLi00IS66LiIcUW>F<HIcT3HaP2
IcT01F<HIcUS66<HIcT015kg00AS65kgG_MNm`AJeP07G_MJeU[FE[EJeUkg
F]H00Cg_000812402@Q212448@aS@Q1oof<H>LiBU002F]H4DY@00eJeDYAF
]@03DY@01EJeCW=BU4YBCW<00e:D1EJe0U:D00IF]E:DE[EBU5JeDY@3CW<0
1E:DE[EBU5:DE[D00U[F0UJe00ABU4YBAS56<@=:DP05CW=:DTHaBU96<@02
BU82AS401TYBCW=BU4icDYA>L`9BU005BU92448@BU9>L`03BU802DicBU9>
LeJeF]IF]E:DCW=BU002E[D2DY@3CW<01DYBCW=>Le:DCW<00dYB00E>Le:D
DYABU4ic00EBU0=>L`EBU003CW=:DTYB00=:DP03CW=BU5:D009BU003E[EB
U5:D009BU09F]@03CW=BU4YB009:DP9>L`9F]@9BU005CW=BU5JeF]IF]@02
F]H6E[D2DY@014icBU9>Le:D0UJe00=BU4YBBU800TYB00I>LdYBCW=BU4ic
DY@4BU8015:DBU96<DYB0e:D00A>LdYBCW=>L`9BU09:DP03CW=:DTic009>
L`05DYAF]E:DDYA>L`02DY@00dYBAS5:DP03CW<024YBAS5:DTicDYAF]Dic
DY@2CW<00eJeDYABU003F]H2DY@2CW<01U:DCW=BU4icDYAF]@9BU09>L`04
F]INmf<HF]H2E[D4CW<00e:DCW=:DP02DY@2E[D3DY@01TicE[EJeU[FG_MB
U09>L`05DYAJeUJeE[EBU004E[D2F]H3E[D015[FE[EF]EJe0e[F00=F]E[F
E[D00U:D00=>Le:DE[D00U[F00=BU4YBDY@00Tic0U:D0UJe00=BU5JeDY@0
0U:D0eJe00EJeUJeF]IJeV<H009Nm`AJeP05E[E6<DYBBU9BU003F]H2G_L0
15[FG_MS66Li0ekg00AW>F<HG_MNm`9S60IJeP06E[EJeU[FG_MJeUJe15[F
00IBU5JeE[EJeUkgF]H2E[D3F]H01V<HG_MS66<HF]INm`EJeP9F]@03F]IN
mekg00IJeP05E[EJeU[FG_MW>@03G_L5F]H015JeF]IJeU[F0Ukg0f<H00EN
mf<HHaQNme[F009F]@05F]IF]E[FG_MS6004IcT2HaP00ekgHaQW>@02G_L0
0f<HIcUS6005HaP2G_L2F]H01UJeF]IF]E:DE[ENm`9S60=Nm`9S6004IcUS
66LiIcT5JeX2IcT2HaP6IcT00f<HJeY[FP02JeX00fLiJeYS6003HaP4IcT0
16<HIcUS66<H1FLi0Ukg0U[F00INmf<HIcU[FVLiHaP2G_L00f<HIcU[FP02
JeX02VLiHaQW>F]JKg][FVLiHaQW>F<H0fLi00=S66LiIcT00V<H00=W>F<H
HaP00Ukg00=S66LiIcT016Li00AS66LiIcUW>@9[FPUS60EW>@03HaQW>FLi
00=W>@03HaQW>F<H00=S609W>@03HaQW>F<H00ANm`04F]INmekgG_L2F]H0
0eJeG_MNm`02F]H2E[D1G_L1F]H1?Nl00006124000@Q00048@000P@Q00X8
@P@Q124<HdHaOom[FSW>BU9F]@A>L`06BU9BU5:DF]INmeJe0e:D00E>Le:D
DYABU4ic009BU005E[EJeU[FE[EJeP03DY@014icE[EF]E:D0dic0U:D00=F
]E:DDY@015:D14ic00=:DTicCW<00e:D00M>LdHaAS56<DYBCW=BU002CW<0
1E:DBU9:DTYBDY@00TYB00M244YBCW=:DTHaBU9>L`02BU800e:DE[EJeP03
DY@02eJeDYABU4icDYA>Le:DCW=BU4icDY@014YB00=BU4icDY@00U:D0UJe
0U:D00E:DU:DDYAJeUJe009BU003F]IBU5:D009:DP04DYA>LdYBCW<2DY@2
CW<00e:DE[EF]@03DY@01DicDYABU5JeCW<00TYB00ABU5JeF]I>L`=:DP04
DYA>Le:DE[D3F]H3DY@01EJeDYAF]DicBU800Tic00UBU5JeDYA>LdYB@Q16
<DYBAS401dic0dYB0dic0UJe00=BU4icCW<00U:D00=F]E:DCW<00TYB0U:D
00Q>Le:DDYABU4icBU9BU4ic0dYB0U:D0TYB0Tic0U:D0UJe00=BU4icDY@0
0dic00ABU5[FF]INm`9F]@9>L`03DYA>Le:D009BU09F]@05DYA>Le:DE[EN
m`03F]H3CW<2DY@2CW<00dYBDYAF]@02E[D3CW<01EJeF]IF]EJeDY@015Je
0e[F00AF]E:DE[EF]@9JeP04E[EJeU[FF]H3E[D00e[FE[EBU004E[D00e:D
CW=>L`02E[D00e[FE[EBU002CW<2DY@014icDYAJeU[F0UJe0e:D00=F]E[F
F]H00eJe0Ukg0U[F0Ukg00=BU4YBBU800e:D0UJe0e[F00=F]E[FG_L00Ukg
0e[F0ekg0U[F0eJe2U[F00=NmeJeE[D00U:D00MJeUkgF]IJeUJeF]INm`04
F]H00ekgHaQJeP03F]H2G_L00e[FE[EJeP02F]H3G_L6F]H2G_L01V<HIcUS
66<HF]INm`EJeP03E[ENmekg00AS6003IcUS66<H00QJeP03G_MS66<H00=W
>@06HaQNmekgF]INmf<H0fLi16<H00=Nme[FF]H01Ekg0U[F00INmfLiIcU[
FVLiJeX4IcT2JeX00fLiJeY[FP03JeX02FLiHaQS66<HIcUS66LiG_MS6007
IcT00f<HIcUS6002IcT2HaP01FLiHaQNmf<HG_L00f<H00AW>F<HHaQW>@9S
6004G_MS66]JIcT2JeX00fLiHaQNm`02HaP016]JIcUW>F]J1VLi0V<H1FLi
0f<H00=W>F<HHaP00ekg00=S66]JJeX016Li00=S66LiJeX00V]J00EW>F<H
HaQS66Li00=S6003G_MS66<H00EW>@04HaQW>F]JJeX8HaP016LiHaQS66<H
1Ekg00AS65kgG_MJePIF]@03F]INme:D004mk`0000<000@Q12400`@Q00`0
00Q2248000@Q48A6<GooJeXicTYBDY@2CW<01DYBCW=>LdicE[D00e[F0U:D
00A>Le:DDYA>L`=BU003E[EJeUJe009JeP04E[EBU5:DCW<2DY@00eJeDYAB
U002BU82E[D00e:DCW=F]@02DY@5CW<014YBCW=:DTic0e:D00I>LdHa@Q16
<DYBDY@2CW<00e:DCW=:DP02BU800e:DCW=6<@02AS47BU8025:DF]IF]EJe
DYAF]E:DE[D2DY@01DicDYABU5:DCW<00U:D0TYB00=6<DicDY@00U:D00=>
Le:DE[D00UJe0Tic0U:D0UJe00I>LeJeE[EF]DicBU82CW<014YBCW=>LeJe
0Tic0U:D00=F]E:DDY@01E:D00=F]DicBU800Tic00=JeUJeCW<00dYB0e:D
00AF]E[FF]IF]@9BU09F]@03DYAF]Dic009>L`9BU004E[EBU4icBU83AS40
1TYBCW=>LdYBCW=:DPA>L`9:DP03CW=BU5:D00=BU004CW=BU5:DE[D2CW<2
BU82CW<3DY@2CW<01dYBDYA>LdYBAS5:DU:D009>L`06BU9>Le:DCW=BU5Je
0U:D0Tic00MBU4YBCW=BU5JeHaQJeP02E[D4CW<00e:DCW=BU002E[D015:D
CW=BU5[F0Ukg00=F]E[FDY@00dic00EF]DicCW=>Le:D009F]@9BU09>L`9F
]@03F]IF]EJe009BU09F]@9JeP9F]@9BU09JeP03E[EJeUJe00MF]@9BU005
F]IF]EJeCW=:DP02DY@2F]H00eJeCW=>L`02CW<015:DCW=BU5Je0U[F15:D
0UJe0U[F00ABU5[FG_MS609JeP07G_MJeU:DCW=:DTicDY@00UJe00AJeUJe
F]INm`9F]@03F]IS65kg00=JeP9Nm`05F]INmeJeF]IF]@02F]H01eJeF]IJ
eUkgE[EJeUJe00=JeP9F]@04DYAF]E[FG_L6F]H00eJeF]INm`02G_L4F]H0
0ekgF]IJeP05F]H01EkgF]IJeU[FE[D00e[F00QNmf<HIcUW>F<HG_MJeUkg
15[F00=F]E[FG_L00f<H00ENmf<HHaQW>F<H009JeP03E[EJeU[F00=JeP03
G_MS66Li009W>@9S6008F]INmekgG_MS66LiJeYW>@AS6004G_MJeU[FF]H3
G_L3F]H00f<HIcU[FP02IcT2JeX5IcT2JeX01FLiKg][FV]JIcT00V<H0fLi
0f<H1VLi00=S66LiIcT00VLi00=S66LiHaP00f<H00ANmf<HHaQW>@AS6003
IcUS65kg009S6003IcU[FVLi009W>@=S609W>@03JeYW>F]J00=W>@03JeYW
>F<H00IW>@AS6008IcUS66<HG_MJeUkgHaQW>@9[FP9W>@06HaQW>FLiJeYW
>F]J1F<H00AW>F<HG_MNm`9S60AW>@03HaQW>FLi00AW>@9S6004IcUS66<H
IcT3HaP01UkgHaQNmekgHaQNm`9S609JePIF]@9JeP5BU04icP000P@Q00<0
00@Q12400`@Q00/8@P@Q000<Hd8@Oom_Nd8@CW=F]E:D00=:DP03AS5:DU:D
00=JeP03DYAF]EJe009BU003CW=BU4ic00=F]@04F]IF]E[FE[D2DY@01Dic
BU9>Le:DE[D00Tic00I:DTicDYABU5JeDY@2E[D01E:DE[EBU5JeDY@014ic
00mBU4icCW=BU4Ha@Q0mkdHaCW=:DTHaBU9>LdYBCW<00U:D0Tic00U:DTic
BU9:DTHaBU9>LdHaBU800Tic00=F]E:DDY@00U:D00=>Le:DE[D00U:D0Tic
0e:D0TYB00=>LdYBCW<00Tic00AF]E:DE[E>L`9BU003CW=BU5:D00ABU009
E[EBU4icBU9>Le:DCW=:DTic009BU09>L`05DYAF]E[FDYA>L`02BU83DY@2
E[D2DY@01DicDYA>LdicBU800U:D0Tic00=BU5JeF]H00e[F0e:D00A>Le:D
CW=BU09>L`05DYAF]DYBAS524003AS400dYBCW=BU002BU802DicDYA:DTHa
BU9>Le:DCW=F]@02F]H2E[D015:DE[EF]EJe0dYB0UJe0e:D00EF]E:DDYA>
LdYB00Q>L`9BU0=F]@03DYA:DTic009BU003E[EBU5:D009BU09JeP03E[EB
U4ic00EBU09F]@04DYA>LdicDY@2E[D4DY@015JeCW=BU4ic0e:D00AF]E:D
DYA>L`=BU09F]@=JeP03DYAF]E:D009F]@06DYAF]EJeF]IF]E[F1UJe00=J
eUJeE[D01UJe00A>Le:DDYAJeP9F]@03DYA>Le:D00=BU004E[EJeU[FF]H3
DY@014icDYABU5:D0U[F0UJe00EJeV<HG_MJeTic009:DP04DYAJeU[FF]H2
DY@3E[D2F]H2G_L00f<HG_MJeP03E[D3F]H00eJeF]IF]@02F]H01EJeG_MN
mekgE[D00e[F00IF]E:DE[EF]E[FE[D6F]H00eJeF]IJeP03G_L4F]H00ekg
F]IJeP02G_L00e[FE[EJeP03G_L00e[FG_MNm`02G_L00e[FHaQS6003IcT3
G_L02E[FG_MNmekgF]INmfLiJeYS6002G_L00fLiHaQS6003G_L00f<HG_MJ
eP03F]H2G_L3IcT01V<HG_MNme[FG_MS609Nm`03HaQNmf<H00EW>@=S6003
IcUS66<H009Nm`=W>@9[FP=W>@=[FP=W>@04HaQ[FVLiIcT5HaP00fLiHaQS
6004HaP3IcT01F<HIcUW>F]JIcT00V<H00M[FV<HG_MNme[FG_MS6002IcT2
HaP01fLiHaQS65kgHaQW>F<H009W>@05JeYS66<HHaQW>@03JeX2IcT00f<H
IcUW>@02IcT016<HG_MS66Li0V]J0V<H0VLi0V<H00ANmf<HG_MS609W>@9[
FP03IcU[FV<H00=W>@=[FP9W>@US6003IcUS66Li009W>@03HaQW>FLi009S
609W>@05HaQW>EkgG_MS6002IcT4HaP2IcT03F<HG_MJeU[FE[EJeUJeF]IF
]E[FE[ENmeJe004mk`0000<48@0012400P@Q00@000@Q1248@P848@0536=2
47ooJeXmk`02DY@024icBU9:DTYBAS5:DU:DE[D2F]H2E[D4DY@00dicDYAF
]@02E[D2F]H01EJeF]IBU5:DCW<00TYB00=F]E:DCW<00TYB00A>Le:DDYAF
]@=BU004E[EBU5:DE[D2DY@00dicBU9>L`04DY@01D8@?Nm244HaDY@01DYB
0dic00ABU4icBU9>L`96<@A:DP04AS5:DU:DE[D3DY@2CW<2DY@00eJeDYA>
L`03DY@014icBU9:DTYB0dic0U:D00IF]E:DDYA>Le:DCW<5DY@2E[D025:D
BU9:DTicDYA>LdYBCW<2DY@2CW<2DY@015[FDYA>LdYB0Tic00=BU5JeDY@0
1E:D00=:DTicCW<00U:D00M>Le:DDYAF]E[FE[EJeP02E[D01E:DCW=BU4ic
DY@00dic00EF]E:DCW=6<D8@009:DP04AS5:DTicCW<2BU801DicDYA:DTHa
BU8015:D00=F]E[FF]H00U:D00AF]E[FE[E>L`9:DP08DYAF]E:DDYAF]E:D
E[EBU09>L`=:DP04DYA>LdicCW<2DY@00dicDYAJeP02DY@01DYBCW=BU5:D
E[D015:D0U[F00UF]E:DCW=BU5JeDYA>Le:DF]H00U:D00=>Le:DE[D00eJe
0U:D00=F]E:DE[D00U:D00A>Le:DDYAF]@EBU09F]@05F]IF]E[FF]IF]@02
DY@3E[D01U:DE[EF]E[FE[EJeP=F]@04F]IF]EJeF]H5E[D01E[FDYA>Ldic
DY@00UJe00ABU4icDYA>L`ABU09F]@04F]IF]DicCW<2DY@4E[D015[FDYAN
mf<H0Ukg00Q>LdHaCW=>LeJeG_MF]E:D0eJe00MJeUJeF]IJeUkgHaQNm`02
E[D00e:DF]IJeP03E[D3F]H015JeF]IJeUkg0U[F00=F]E[FF]H00UJe00=B
U5[FE[D015[F00EF]E[FF]IJeUJe009JeP9Nm`AJeP05G_MJeUkgF]INm`03
F]H015kgHaQJeU[F15kg00IJeUkgIcUW>F]JHaP2G_L00e[FG_MJeP02F]H2
G_L00fLiJeYS6002G_L016<HIcUS65[F1Ekg00AF]E[FF]INm`9S609W>@05
HaQNmekgG_MJeP02G_L016<HG_MS66<H1FLi00=S65kgHaP00f<H00=Nmf<H
HaP00VLi0f]J0VLi00A[FVLiJeYW>@9S609W>@03JeYW>F<H00ES609W>@=S
60IW>@04JeYW>FLiHaP2IcT016<HG_MJeU[F1V<H00=W>F<HHaP00f<H00AW
>F<HIcUW>@AS609W>@9[FP9W>@03HaQW>F]J00AS609[FP07IcUS66<HIcUS
66LiHaP00Ukg0V<H0fLi0f]J00AW>F<HHaQW>@9[FP05HaQW>FLiHaQW>@02
HaP00ekgHaQS6002HaP3IcT2HaP4IcT2HaP2IcT00f<HG_MNm`03HaP00fLi
HaQS6002HaP016LiHaQS65[F0UJe00ABU5[FE[EF]@9JeP5Nm`5BU04mk`00
00@000@Q124000@48@0D24848@@Q36=247ooLia245:DE[E>LdYBAS5>LdYB
CW=BU5JeG_MJeP9F]@04CW=BU5:DCW<2E[D01E[FE[EBU4icDY@014ic0TYB
0Tic00AF]E:DCW=>L`ABU003E[EJeUkg009F]@9>L`=BU00;CW=BU4icCW=B
U5JeBU96<Cg_@Q1:DP03CW<00dYBCW=>L`03DY@014icBU9>Ldic0TYB00QB
U4icBU96<DYBCW=BU4ic1E:D00=F]E:DDY@014ic0U:D0Tic00QBU4icBU9>
Le:DE[E>LdHa0Tic00=BU4icCW<01E:D00E>Le:DDYABU4ic009BU0A>L`03
DYA:DU:D009BU004CW=:DTYBDY@2CW<00eJeF]IF]@02DY@01TicDYABU4ic
BU9>L`9BU09F]@=JeP04G_MJeU[FE[D4DY@3CW<00e:DBU96<@03BU8014Ha
@Q16<DYB0Tic0U:D00A>LdYBBU9BU09>L`9F]@03F]IF]E:D009F]@9BU003
CW=BU5:D00EJeP9F]@=>L`05DYAF]DicBU9>L`03DY@00dicDYABU002E[D0
15:DBU9>Le:D0UJe00=BU4YBDY@00UJe0e:D0U[F00=F]E:DDY@00U:D00UJ
eU:DCW=:DTicDYAF]E:DCW<01e:D00AF]E:DDYAF]@=BU09>L`05E[EJeUkg
G_MF]@02DY@00dicDYABU003DY@8E[D2F]H3E[D2DY@02EJeG_MNmeJeBU9>
LeJeDYAF]@03DY@4E[D3F]H2E[D00e:DCW=BU002E[D00e[FE[EF]@02E[D0
1V<HF]IF]DicBU9BU09F]@9JeP9F]@9BU007E[ENmekgG_MF]E[FG_L00U[F
0UJe00MJeUJeF]INme[FG_MJeP04G_L3F]H00ekgF]IF]@02E[D015[FG_MF
]EJe0U[F00eNme[FF]IBU5JeF]INmf<HG_MF]EkgF]IF]@03F]H01F<HG_MJ
eUJeF]H01ekg00=JeV<HHaP01VLi00=Nme[FF]H00ekg0V<H0VLi00AS66Li
JeYW>@9Nm`03HaQNme[F009F]@06F]IF]E[FF]INmf<H0fLi0e[F00QNmfLi
IcUS66LiHaQW>F<H16]J00IS65kgHaQW>F]JHaP2G_L4IcT00f]JIcUW>@02
IcT2JeX2IcT016<HG_MS66<H0fLi0Ukg00AS66LiHaQS609Nm`9S6005IcUS
66<HHaQW>@04JeX2HaP015[FG_MNmekg1F<H00QW>F<HHaQS65kgHaQW>F<H
0fLi00A[FVLiHaQW>@9[FP04IcU[FV<HIcT2HaP2IcT016<HG_MNmf<H0VLi
0f<H00=W>F<HHaP00VLi0Ukg0V<H00=[FVLiIcT01fLi0f]J00AW>F<HHaQW
>@=S609Nm`03HaQW>FLi009W>@03HaQW>FLi00=W>@9S6007IcUS66<HHaQW
>F]JIcT00V<H0fLi0V<H2E[F0Ekg0E[F0D8@000412400`00124000022480
1`@Q000<Hd8@Oom[FT8@009BU003CW=:DTYB00=:DP04DYAF]E[FF]H2E[D0
0e:DCW=>L`02DY@015JeF]IF]EJe0Tic00ABU4icBU9>L`=:DP=BU003BU9>
Le:D00ABU0=JeP03E[E>Ldic00ABU0=>L`09E[EBU4YBBU8mkdHaBU9>LdYB
009>L`03DYA>Le:D009BU0E>L`07BU9>LdicAS5244HaCW<00U:D00A>Le:D
DYA>L`=F]@04DYA>LdYBCW<3DY@02DicBU9BU4icBU9>LeJeDYA>L`02BU80
15:DCW=>LdYB0U:D00IF]E:DDYA>Le:DCW<2DY@00dicDYA>L`05CW<015:D
E[EBU4ic0TYB0dic0eJe00=BU4icDY@00U:D14ic00AF]E:DF]IF]@9JeP03
G_MJeU[F00ABU0=>L`07DYA>LdYBBU96<DicAS400T8@00A6<DicBU9>L`9B
U003CW=:DTYB00=>L`04DYAJeU[FE[D2DY@2E[D01U:DCW=>LeJeF]INm`=F
]@03F]IF]Dic009>L`9BU004CW=:DTicCW<4DY@01eJeF]IBU5:DBU9>Le:D
009F]@03DYA>Le:D009F]@9BU004E[EJeU[FE[D2DY@01dicE[EF]EJeCW=:
DTic009F]@07DYA>LdicDYAF]E:DE[D015:D00=F]E:DDY@00e:D00=>Le:D
F]H00Ukg00AF]E:DCW=>L`9BU003CW=BU5:D00EF]@04DYAF]E[FG_L2F]H2
E[D2DY@015JeG_MJeUJe0Tic00UBU5JeDYABU4icE[EBU5[FE[D00e[F00=F
]E[FDY@00U:D00]F]E:DE[EF]E[FE[EBU5[FHaQNme[F009:DP9BU0=JeP9F
]@9BU003E[EJeUkg00AJeP=F]@03F]IF]E[F00=JeP04G_MJeU[FF]H2G_L0
2E[FE[EJeUkgF]IF]E:DF]INm`02F]H00eJeF]IJeP03F]H00eJeDYAJeP03
G_L4F]H00eJeF]INm`02G_L00e[FE[EJeP02G_L01E[FG_MNmf<HF]H00Ukg
00=W>F<HIcT00VLi00=S66LiG_L00Ukg00MJeUkgG_MNmfLiJeYW>@02HaP0
1VLiHaQS65kgHaQNm`=F]@EJeP04HaQW>FLiHaP3F]H01ekgHaQS66LiHaQW
>F<H00A[FP07IcUS65kgHaQW>F]JHaP00Ukg1FLi00AS66LiIcUW>@9[FP05
IcUS65kgG_MS6003IcT00f<HG_MS6004HaP2G_L4HaP015kgIcUW>F]J0VLi
00Q[FVLiHaQNme[FG_MS65kg1F<H00=W>F<HHaP01F<H00=W>F]JJeX01FLi
0V]J00=W>F<HHaP00fLi00AS65[FHaQS609W>@IS6003IcUS66<H009Nm`06
IcU[FVLiJeYW>F<H0fLi00AS66LiIcU[FP=W>@AS609Nm`=S609W>@03HaQW
>FLi00=W>@03HaQW>F<H00AS6003IcU[FVLi00=S6004IcUS66<HHaP2F]H0
1EJeF]IJeU[FE[D00U[F0Ekg0EJe0Cg_00000`0012400005124020Q21244
8@aS?NmoogNmAS42DY@2CW<00dYBCW=>L`03DY@3F]H00ekgCW=>L`02AS40
0dicBU9>L`02CW<4DY@015JeDYA>Ldic0TYB00A>LeJeF]IF]@9:DP=BU004
E[EJeU:DDY@2CW<2DY@00e[FE[EBU002DY@01U[FG_MF]DicAS52409:DP06
CW=:DTicCW=BU5Je0U:D0dic0TYB00Q>Le:DCW=>LdYBAS5:DTic15:D0UJe
00=BU4icDY@01Dic0U:D00A>LdYBBU9>L`9BU0A:DP=>L`EBU005CW=BU5:D
E[EBU002CW<00e:DCW=:DP03CW<00dYBCW=BU002DY@01dicDYA>LdHaBU9>
Le:D009F]@=>L`EBU0=F]@09F]INmf<HHaQJeUJeDYAJeUJe00ABU003CW=:
DTYB00=:DP06AS5:DT8@AS5:DTic0U:D00A>Le:DDYABU09>L`03DYAJeU[F
00EF]@03F]IBU5:D009>L`05DYAF]E[FF]IF]@02F]H2DY@014icDYAF]E:D
0Tic0U:D00=>Le:DCW<00U:D00EF]E:DDYABU4ic00ABU0=>L`04DYA>Ldic
DY@3E[D6DY@2CW<5DY@2BU82CW<2E[D2DY@00dicE[EF]@02DY@01TYBCW=J
eU[FG_MJePEBU006CW=BU5:DDYAF]E[F0UJe0U:D00=JeUJeE[D00eJe00UJ
eUJeDYABU5[FG_MJeU:DCW<00U:D00QF]E:DE[E>Le:DE[EJeUkg0e[F00AF
]E[FE[E>L`9BU09F]@03F]IBU5:D00AF]@03DYAF]E[F00=JeP=F]@06DYA>
Le[FF]INme[F0UJe0Ukg0U[F00AF]EkgF]INm`9JeP=Nm`9JeP04HaQNmekg
G_L9F]H015JeF]INme[F0UJe1E[F00=Nmf<HF]H00UJe00AJeV<HHaQS609N
m`=JeP04G_MJeV<HHaP2G_L2HaP00fLiHaQW>@03IcT2HaP2F]H3HaP00ekg
HaQW>@02IcT5G_L2F]H02eJeF]IJeUJeF]IBU5[FHaQW>F]JIcT00V<H0ekg
00=S66]JJeX016Li0f]J00IW>F<HG_MS66LiHaP3G_L2HaP00f]JIcU[FP03
IcT016<HJeYS66<H0Ukg0V<H00A[FVLiIcUS609Nm`]S609W>@04JeYS66<H
G_L2HaP01UkgHaQS66LiHaQNm`MS609W>@03HaQW>FLi00=[FPEW>@03JeYS
66<H00=S6004G_MS66LiHaP2G_L2HaP015kgHaQS66<H0VLi1F<H1VLi00AS
66LiIcUW>@9[FP9W>@04HaQW>FLiIcT5HaP8IcT2JeX3IcT3HaP3IcT2HaP0
0fLiHaQS6002G_L015[FG_MNmekg1E[F0Ekg0E[F0D8@000512402`001244
8@Q200048@aS@Q1oog>L@Q000U:D0Tic00A:DTicBU9>L`9BU005F]INme[F
F]I>L`02BU801THaCW=:DTYBCW=BU09>L`ABU09>L`08BU96<DicE[EJeU:D
CW=:DP=BU007E[EJeUJeE[E>LdYBDY@00eJe0e:D00AJeUkgDYABU0924096
<@A>L`EBU0=:DP=>L`A:DP=>L`=BU007F]IBU5JeDYA>Le:DBU800Tic0e:D
00A>LdYBBU9:DP9BU005CW=:DTYBBU9BU002CW<3DY@015JeDYABU5:D0UJe
00=BU4icCW<00Tic0TYB1Dic00=BU4icCW<00Tic0TYB00ABU5JeF]IBU09>
L`=BU004CW=BU5:DF]H3E[D015kgHaQNme[F1EJe0U:D0dic00=:DTHaBU80
0TYB00=6<D8@AS400TYB0U:D00E>Le:DDYA:DTic009BU003E[EJeUJe00AF
]@9BU004CW=BU5:DDY@2E[D2F]H3E[D014icDYABU5:D0dic00ABU4icCW=>
L`9BU004E[EBU5:DDY@2CW<3DY@3CW<2DY@3CW<00e:DF]IJeP04DY@00eJe
DYA>L`02CW<2E[D014icDYA>LdYB0Tic00AF]E:DE[E>L`9BU003F]IBU5:D
009>L`06E[EJeU[FF]IF]E:D0dic00UBU4icE[EBU5JeF]IBU5JeDY@01UJe
00IJeUJeDYABU5JeG_L2F]H01DicDYABU5:DE[D015:D00EF]EkgF]INmeJe
009JeP08E[EBU5:DCW=F]E:DF]IF]@=BU09JeP9BU004E[ENme[FE[D2F]H0
1EJeDYABU5:DF]H00ekg00=F]E[FG_L00Ukg00=F]E[FF]H00ekg15[F15kg
00=JeUkgG_L00U[F00EF]E[FG_MNmeJe00MJeP03E[EJeUJe009JeP9Nm`04
F]IF]EJeF]H2HaP01EkgF]INme[FG_L00U[F1Ekg00]S66LiIcUS66LiHaQW
>F]JHaQNme[F009Nm`ES6003IcUS66<H00ANm`05F]IF]EJeE[EJeP04E[D0
26<HIcU[FVLiG_MS65kgF]H2HaP01V]JIcUW>F<HIcU[FP9W>@04Kg]S66<H
G_L2IcT00f<HG_MNm`02HaP5IcT00f<HIcUW>@02IcT01V<HG_MNmf<HIcU[
FP9W>@ANm`03IcUS66<H00AS6005G_MS66LiHaQ[FP03IcT015[FG_MS65kg
0V<H00AW>F<HHaQNm`=S6003G_MS66Li00AW>@A[FPEW>@03JeYS66<H00ES
6004G_MS66<HHaP2G_L3HaP00fLiHaQW>@05HaP7IcT2HaP01FLiJeY[FVLi
HaP016Li00=S65kgG_L00V<H0VLi00AS66LiIcUS60=W>@03JeYW>F<H00=S
609W>@03HaQW>F<H00AS60ENm`08F]INme[FG_MJeUJeG_MJeP52400000<0
00@Q00001@@Q00X8@P@Q124<HcW>Oom_NdYBE[EBU09:DP06CW=F]E:DCW=:
DTic0U:D00AJeUJeDYA>L`9:DP=>L`=BU09>L`09DYAF]E:DBU9>LdYBAS5:
DTic00=F]@=>L`ABU005E[EBU4icCW=BU004F]H3E[D2CW<2AS43BU800dic
DYA>L`02DY@015JeCW=:DTYB0e:D1TYB00A>LdYBCW=>L`9BU09F]@=BU00;
CW=:DTYBBU9>Le:DE[EBU4icBU9>L`02DY@014icBU96<DYB0e:D0Tic0e:D
00E:DTicDYAJeUJe00=BU003BU9>Ldic00I>L`9BU006CW=:DTicDYA>Le:D
0UJe0U:D00E>Le:DE[EBU4ic009BU09F]@9JeP9Nm`9JeP9F]@03F]IF]E:D
009BU003CW=:DTYB00I:DP96<@04BU9>LdicCW<3DY@00dYBCW=F]@02F]H0
0eJeDYABU002DY@015JeCW=BU5:D0Tic00UBU5JeE[EF]DicE[EBU5JeDY@0
0UJe00=BU4icCW<00e:D0Tic0U:D0UJe0U:D0Tic0UJe00ABU4icAS5:DP9B
U0=>L`03DYAF]E[F009F]@9BU003CW=BU4ic009BU004E[EBU4icBU84CW<4
DY@00dicDYABU002CW<3DY@01TicE[EF]EJeDYA>L`EBU0=F]@9BU003E[EJ
eUJe00=BU003E[EJeUJe00=F]@09F]IBU5JeE[EJeUJeDYAF]E[F00=BU003
E[EJeUJe009F]@9JeP07DYA>Le:DDYAF]E[FE[D00U:D00A>LdYBCW=F]@9S
60=JeP04E[EJeUJeE[D2DY@01EJeF]IJeU[FE[D01E[F00=F]EkgG_L00Ukg
00=F]E[FF]H00U[F15kg1E[F00EF]E[FG_MNme[F00=F]@9JeP08E[EJeU:D
E[EJeUkgHaQNm`=JeP=Nm`9S609Nm`04F]INme[FG_L3HaP2G_L016<HG_MS
66<H0VLi00=S65kgHaP00UJe00]Nmf<HHaQS65[FG_MS65kgF]IF]E[F009F
]@9JeP9Nm`05F]INmekgF]INm`02HaP036]JIcUNmf<HG_MJeUkgIcU[FVmk
IcU[FPAW>@04HaQW>F<HHaP6G_L2HaP00fLiJeY[FP03IcT2JeX3HaP015[F
G_MNmf<H16Li0ekg00=W>F<HHaP00Ukg00AS66LiHaQNm`QS609W>@AS6003
IcUS65kg009S609W>@9S6003IcU[FV]J00A[FP9W>@03HaQW>FLi009W>@03
HaQNmf<H009S6003IcUS65kg00IS60AW>@04HaQW>F<HIcT2HaP4IcT01f<H
IcUW>FLiJeYW>F]J00IW>@AS6003IcUS66Li00ES60=W>@IS6003IcUS66Li
00=S609Nm`05F]INme[FG_MS6002G_L2F]H2G_L1F]H1@Q0000@48@0A0004
8@@Q1248@P@Q000<Hcg_Oom_NdHaE[EBU4icBU9>L`02DY@01dicBU9>Le:D
E[EJeUJe009>L`=:DP9>L`9BU003CW=:DTic00=BU009BU9>LdYBAS5:DU:D
E[EJeU:D009>L`03DYA>LeJe009F]@9BU09>L`03DYAJeU[F00EF]@04CW=:
DT8@AS43BU800e:DCW=BU003DY@4CW<2DY@00dYBCW=:DP05BU83CW<4E[D2
DY@00dicBU9:DP02BU801UJeF]IBU4YBAS5>L`9F]@07BU96<DHaBU9>Le:D
CW<00U:D00=>LeJeCW<00Tic00=BU5[FE[D00e:D00A:DTicBU9:DP=>L`08
BU9>Le:DCW=BU4icBU9>L`9BU003E[EJeUJe009>L`05DYAF]E:DDYA>L`02
E[D3F]H2G_L00e[FE[EF]@03E[D2DY@2CW<2BU8014icBU96<DHa0TYB0THa
00M:DTicCW=:DU:DE[EBU002CW<015:DF]IF]EJe0U:D0UJe00=BU4icCW<0
0dic00=BU5JeF]H01U:D00AF]E:DDYA>L`ABU09>L`=BU004E[EBU5:DCW<3
DY@02UJeBU9:DTYBDYA>Le:DBU9>Le:D0UJe00=JeUJeDY@00U:D00=>Le:D
DY@015:D00=>LdYBCW<00dic0U:D00=>Le:DDY@00dic0U:D00A>LeJeDYAF
]@9BU003CW=BU5:D00ABU006F]IF]E:DDYAF]E[F0UJe0U:D1EJe00AJeUJe
E[EBU0MF]@03CW=BU5[F00=F]@=JeP07E[EBU5:DDYAF]E[FE[D00U:D00M>
LdYBDYAJeUkgHaQNm`02E[D015:DF]IF]EJe0U:D00EF]E[FF]IJeUJe00IJ
eP=Nm`03F]IF]E[F00EJeP05G_MS65[FF]IF]@05F]H015kgF]IF]E[F0eJe
00AJeUJeE[EF]@ANm`AJeP9Nm`03HaQNmekg009Nm`03F]INmf<H00MS6006
G_MW>F<HIcUS65kg0U[F00IF]E[FHaQS65kgF]H2HaP01ekgF]IBU5[FE[EJ
eUJe009JeP03G_MJeUkg009JeP05G_MS66LiJeYW>@02HaP2F]H00ekgHaQ[
FP02JeX046LiJeYW>FLiHaQW>F<HIcUS65kgF]INmf<HG_MS65kg0VLi00E[
FVLiJeYW>F]J00=W>@03HaQNme[F009Nm`9S609W>@03HaQNmekg009S6005
IcUS65kgHaQW>@03HaP00ekgHaQW>@06HaP00fLiHaQS6005HaP00ekgHaQW
>@02HaP2IcT2JeX00fLiJeY[FP02JeX01V<HIcUW>FLiHaQW>@9S6005G_MS
66LiHaQW>@02HaP00ekgHaQS6002HaP3IcT2HaP00fLiHaQS6003HaP4IcT0
1F<HIcU[FVLiJeX00VLi00=[FVLiIcT00VLi1F<H0fLi0f<H0fLi0f<H00=N
mf<HHaP016<H00ANmf<HG_MS609Nm`03F]INmekg00ANm`9JeP5S605F]@52
400000<000@Q00000P@Q00@000@Q1248@P848@0536<icWooJeY6<@02DY@2
BU83CW<00dYBCW=BU002E[D015[FG_MF]EJe0TYB00=BU4icE[D00UJe0Tic
0TYB0U:D00=F]E:DCW<025:D00M>Le:DCW=>Le:DF]IF]@02DY@01UJeF]IN
me[FE[EJePEBU09>L`=:DPA>L`03DYA>Ldic009>L`03DYA>Ldic00=:DP03
CW=:DTYB00E>L`03DYAF]E:D009BU09>L`03BU9>Le:D009BU003CW=BU4ic
00A:DP9>L`06BU9>LdYBDYA>Le:D14ic00ABU4icDYAJeP9F]@9>L`06BU9>
Le:DCW=:DTic0e:D00=>LdYBCW<015:D00IF]E[FDYABU4YBCW<4E[D2CW<2
DY@01UJeF]IJeU[FE[EBU09F]@06F]IF]DicCW=:DTic0U:D0dHa00EBU4ic
AS5244Ha009:DPIBU09F]@=JePMBU09>L`03DYAF]E:D009>L`03DYAF]E:D
009BU09F]@9>L`9BU09F]@03CW=BU5:D009F]@04DYAF]E:DDY@2E[D2DY@0
14icBU9>Le:D0dic0U:D00=F]E:DDY@00e[F0e:D00=F]E:DCW<00U:D00A>
Le:DBU9>L`ABU003CW=BU5:D009BU006BU9>LdicDYAJeUJe0e:D0eJe0Tic
00=BU5JeF]H00UJe00=BU5JeDY@015:D0eJe00EBU4icCW=>Le:D009JeP9B
U006E[EJeUJeE[EBU4ic0e:D00=F]E:DE[D00eJe0U:D0U[F00IF]E:DAS56
<E:DF]H2HaP015[FG_MNme[F0UJe00=BU5JeE[D00UJe0e[F15Je1E[F00EN
me[FF]IJeUJe00=JeP04G_MJeU[FG_L3F]H2E[D2F]H01UkgF]IBU5JeF]IN
m`9JeP03DYAF]E[F009Nm`05HaQNmekgG_MF]@02F]H2HaP015kgE[EJeU[F
0ekg00AJeV<HHaQNm`9JeP03G_MS66Li009S6003F]INmeJe009F]@03F]IN
me[F009JeP04G_MJeU[FG_L2HaP2G_L00f<HIcUW>@03IcT2HaP2F]H015kg
HaQS66<H0Ukg0fLi00E[FVLiHaQS65kg00=S60=Nm`05F]INmekgHaQW>@03
HaP00fLiHaQW>@02IcT01F]JIcUW>F<HIcT00V<H0Ukg00=S66LiJeX00VLi
0Ukg00ES66LiIcUS65kg00=S609JeP9S6007IcUS66<HHaQW>F<HIcT00f<H
16Li00=Nmf<HHaP00fLi00MS66]JJeY[FVLiJeY_N`02JeX4HaP00fLiJeYS
6003G_L3JeX2IcT2HaP3IcT016]JIcUS66Li16<H00=Nmf<HIcT00fLi0f<H
0VLi0V]J00=W>F]JIcT00VLi00E[FVLiHaQNmf<H00=W>@9S6003G_MS66<H
00US609W>@=S60ENm`07F]INmekgG_MS65[FG_L00U[F0EJe0Cg_00061240
2P002488@P00124<Hd8@Oom[FT8@0U:D0dYB00i>LdYBCW=>Le:DF]IF]E[F
G_MJeU:DCW=:DTic0U:D00=JeUJeCW<00dYB00EBU5JeDYABU4ic00=BU004
CW=BU5JeDY@3CW<01E:DCW=BU5[FE[D00e:D00IJeUkgF]IJeU:DE[D4DY@0
0dicBU9:DP02BU8025:DCW=BU5:DCW=BU4YBCW<3DY@6BU82CW<00e:DCW=>
L`03DY@00eJeDYABU004CW<5DY@2CW<3BU8015:DCW=>LdYB1Dic00=BU4ic
CW<00Tic00EF]E[FF]IJeU:D009>L`03BU9>Ldic009:DP08CW=BU5:DCW=:
DTicDYAF]@9BU008E[EJeUJeDYA:DTicDYAF]@IBU003E[EJeU[F009F]@9B
U004F]IF]E:DDY@2BU83CW<014YBAS5:DTic0TYB00E244HaBU9:DTic009B
U004E[EBU5:DDY@2F]H00eJeF]IF]@04DY@01eJeCW=>LdicDYAF]E:D009>
L`03DYAF]EJe00EBU09>L`9F]@9BU003CW=BU5Je009F]@9BU0AF]@9>L`03
BU9BU4ic009>L`9BU003E[EBU5:D009F]@05G_MF]EJeDYAF]@06DY@4CW<2
DY@3CW<2DY@4CW<015:DE[EF]E:D0Tic00=F]E:DDY@00Tic0U:D00=JeUJe
DY@00eJe15:D00MF]E:DE[E>Le:DCW=BU004E[D025:DE[EF]E[FE[E>Le:D
CW<3DY@03eJeF]IF]EJeDYAF]E:DE[EJeU:DCW=6<D8@E[EJeP02IcT2F]H0
15kgF]IF]E:D0UJe00=BU5JeDY@015[F0UJe25[F00INmeJeF]IF]E[FG_L4
F]H00ekgF]IF]@02E[D3F]H3E[D4F]H02E:DE[EJeUkgHaQNme[FHaQNm`03
F]H2HaP00ekgE[EF]@02F]H016<HG_MNmf<H0Ukg0U[F00AS66LiHaQS609N
m`03F]IF]E:D00=JeP04G_MF]EkgG_L3F]H01UkgHaQS66<HIcUS60AW>@9S
6004F]INmf<HG_L4HaP01EkgHaQW>F]JIcT00V<H00MNmf<HHaQS65kgHaQN
m`02F]H00ekgIcUS6002HaP01VLiHaQW>F<HIcU[FP=W>@=S60=Nm`03HaQW
>F]J009W>@9Nm`0<HaQ[FVLiHaQNmf<HIcUS65kgF]IS66Li0f<H00ANmf<H
IcUW>@=S60=W>@03HaQNmekg009S60=W>@9[FP03IcU[FV]J00=[FP9S60AW
>@03HaQNmekg009S609[FP04IcUS66<HHaP3IcT016]JIcUW>F<H0VLi00=S
66LiHaP00V<H0fLi00=Nmf<HIcT00VLi0V]J0fLi00IS66]JJeYW>F<HG_L2
HaP00f]JIcUS6007HaP00ekgHaQS6002HaP00fLiHaQW>@03HaP4G_L00e[F
G_MJeP05G_L00e[FG_MBU001@Q00000500048@@Q1240000312403@Q21244
8@Q2?NmoofLi?Nm>Le[FE[EBU4ic009BU003E[EJeUJe00=F]@03F]IBU5:D
009:DP03CW=BU5:D009F]@9BU003CW=BU5:D00=BU003CW=F]E:D009BU006
CW=BU5:DDYA>LeJe1U:D00=>Le:DE[D00Ukg0U[F0TYB00Q>Le:DE[EF]Dic
BU9>LdYB14ic00=BU4icDY@015:D0Tic0TYB00=>LdYBBU8014YB0Tic0e:D
00YF]DicBU9>LdYBCW=BU4icDYAF]@9>L`04AS5>LdicCW<2BU800e:DCW=B
U003DY@3CW<02e:DCW=BU5[FE[EBU4icBU9>Le:DCW<00U:D00A>Le:DDYA>
L`EBU008E[EBU5JeE[EBU5[FDYA>L`9BU007F]IF]DicCW=BU4icDY@00e[F
00MF]DicDYABU5[FE[E>L`02BU8014icDYABU4YB0THa00=>LdYBBU800THa
00=:DTHaCW<00Tic00=BU5JeCW<00U:D00]F]E[FE[EF]E[FE[EJeU:DCW=B
U4ic009BU008E[E>LdYBCW=F]E[FE[E>L`9BU008CW=BU4icCW=BU5JeDYA>
L`9:DP04DYAF]E[FF]H4E[D2DY@015JeDYA>Ldic15:D00A>Le:DDYABU0AF
]@=Nm`04E[EBU5:DE[D3CW<2DY@4CW<4DY@2CW<3E[D2DY@00eJeDYABU003
CW<2DY@00eJeDYAF]@02DY@015JeDYAF]EJe15[F00=F]E:DDY@00Tic00=F
]E[FF]H00UJe0U[F00=Nme[FE[D00e:D1EJe00=BU5JeDY@00eJe14YB00AF
]EkgHaQS60=Nm`9JeP03E[EBU5Je009JeP9F]@9JeP9F]@03DYAF]EJe00=J
eP04E[EJeUJeE[D2F]H01ekgF]IJeU[FE[EJeUJe009JeP9F]@AJeP03E[EJ
eU[F009JeP=F]@04F]IF]E[FF]H2G_L00f<HF]IJeP03F]H00ekgF]IJeP02
F]H016<HG_MNme[F0V<H00ENme[FF]IJeUkg00=JeP9F]@9JeP04E[EJeUkg
F]H3HaP00fLiHaQNm`03G_L3IcT2HaP2JeX015kgF]IJeUkg16<H00=Nmf<H
HaP00f<H00=W>F<HG_L015kg0V<H00=Nmf<HHaP01F<H00MW>F<HIcUW>F<H
IcU[FP02IcT01f<HIcUS66<HG_MS66Li009[FP=W>@0:HaQW>FLiIcU[FVLi
HaQNme[FG_L3HaP00fLiHaQW>@04IcT016<HIcUW>FLi0f<H16Li00AS66Li
IcUW>@9S6003IcU[FV]J009W>@9S6003G_MS66Li00ES609W>@=[FP07IcUS
66LiIcU[FVLiHaP00VLi1F<H00=NmfLiIcT00VLi16<H1FLi00=S66LiIcT0
0V]J00=W>F<HHaP016Li1V<H00=W>F<HIcT016<H00=W>F<HHaP00V<H00IN
mf<HG_MNme[FG_L2F]H01ekgF]INmekgE[EJeU:D005240000P@Q00<000@Q
12400`@Q00T8@P@Q000@Q48@OomS63g_CW<00UJe0U:D00=>Le:DF]H00U[F
0eJe00=JeU:DDY@00TYB0Tic0UJe0e:D0Tic0e:D00A>Le:DDYAF]@=BU003
E[EBU4ic00ABU003CW=BU4ic00=BU005E[ENmekgF]IF]@02BU82DY@2E[D0
14YBCW=:DTYB0dic00ABU4icDYA>L`ABU003CW=:DTYB009:DP03CW=:DTic
009:DP05AS5>LdicDYAF]@02DY@044icBU9:DTYBCW=BU4icDYAF]E:DBU96
<DYBDYA>LdYB0dic0e:D0Tic00Q:DTicCW=>LeJeF]IF]E:D0TYB0Tic15:D
0Tic0U:D00=F]E:DDY@00U:D0UJe00=BU5JeE[D00dic00=F]E[FDY@00dic
0U:D00AF]E[FF]IF]@=BU003F]IBU4ic009:DP9BU003CW=:DTHa009:DP03
CW=:DT8@0096<@03BU9BU4ic00IBU005E[EJeU[FE[EJeP04DY@00dicDYAB
U002E[D01dYBAS5>LeJeG_MF]DYB00=BU0=>L`04DYAF]E:DCW<2BU8015:D
E[EJeU[F0eJe00IBU5JeDYABU4icBU82CW<2DY@014icDYAF]E:D0UJe00UB
U5JeE[EJeV<HF]IF]DicE[D00U:D0dic0U:D0dic0e:D14ic0UJe15:D1Dic
0UJe00IBU5JeDYABU5JeDY@3E[D2F]H00eJeF]IBU003CW<02E:DE[EJeUJe
DYAF]E[FG_MJeP04DY@4E[D015:DE[EF]EJe0U:D00=F]DicBU800TYB00AJ
eUkgHaQW>@=Nm`9JeP9BU09F]@03F]IF]EJe00=JeP9BU003E[EJeU[F00EJ
eP9F]@9JeP03G_MJeUJe009F]@03G_MJeUJe009F]@=JeP03E[EJeU[F00=J
eP=F]@9JeP05E[EJeUkgHaQNm`04F]H00ekgF]INm`02F]H3G_L2F]H00f<H
IcUS6002F]H015kgF]INme[F0eJe00=JeUJeF]H00U[F00=Nmf<HHaP016<H
0Ukg0V<H0VLi0V<H0VLi00=S65kgE[D00ekg0f<H00AW>F<HG_MNm`9W>@03
HaQNme[F009Nm`9S609Nm`9S6004G_MS65kgHaP3IcT2HaP4IcT2HaP2IcT0
1F<HG_MNmfLiJeX00fLi00AS66LiIcUW>@9[FP04IcUNme[FF]H3HaP00fLi
HaQS6002IcT016<HIcUW>F<H0fLi16<H00=W>F]JHaP00VLi00A[FVLiHaQS
60=W>@9[FPES6003IcUS66<H009S600;IcU[FV]JIcU[FVLiHaQW>F]JIcU[
FP03HaP01FLiHaQS66<HG_L00V<H00=W>F]JJeX016<H00=W>F]JIcT00VLi
0V<H0f]J00=W>F<HIcT016Li0f<H00MNmf<HIcUS66LiHaQNm`03HaP3IcT0
16<HG_MS66<H0Ukg00=JeUkgG_L00U[F0ekg0U[F0Dic0Cg_00001@@Q0004
8@@Q00000`@Q00`8@P@Q124<Hcg_Oom[FSg_CW=Nme[FE[D2DY@2E[D00e[F
E[EBU003DY@00eJeDYA>L`02CW<2DY@00e[FE[EF]@02DY@00eJeDYAF]@03
DY@00eJeF]IJeP03DY@015JeDYABU5:D0UJe0e:D00=>Le:DBU800U:D00MF
]E[FE[EBU4icBU9>L`04E[D01DicBU9:DTYBDY@00dic00IBU5JeE[EBU5Je
CW<2BU8014HaBU9:DTYB0dic00I:DTHaBU9>LeJeDY@2BU800dHaCW=>L`02
CW<2DY@015JeCW=:DTYB1Tic1U:D00A>LdHaBU9:DPABU005CW=BU5JeDYA>
L`03E[D00e:DCW=>L`03E[D02e:DCW=BU5[FE[E>Le:DE[EJeTicDY@00eJe
00E>LdYBCW=:DU:D009F]@ABU09F]@03DYAF]E:D009BU003CW=:DTic00=>
L`05BU96<DYBBU9>L`02BU8014icDYABU4ic0e:D00=>Le:DDY@00ekg00=F
]DicCW<01E:D0dic00ABU4icDYA>L`9BU004CW=:DTicE[D2DY@01TicDYA:
DTHaBU9>L`9F]@=BU005CW=BU5:DE[EBU003CW<4DY@00dicDYAJeP04E[D2
F]H01ekgF]IJeU[FE[EBU4ic00=BU004CW=:DTYBCW<2E[D035:DCW=BU5:D
E[EBU4icDYAF]EkgF]IBU09:DP03CW=BU4ic00=BU004F]IBU4icCW<3E[D0
15[FG_MNme[F0e:D00=>Le:DE[D015[F0Ukg0e[F15:D0eJe0Tic00ABU5Je
DYA>L`924003CW=BU5kg009Nm`=S60=Nm`03F]IF]EJe009F]@9JeP9F]@9B
U003E[EJeUJe009F]@=JeP=F]@9JeP04G_MJeUJeE[D2F]H00ekgF]IF]@03
F]H4E[D015[FE[EF]EJe0e[F00=F]E:DE[D00Ukg00=JeU:DF]H00U[F00MF
]EkgG_MNme[FE[ENm`02F]H00eJeDYAF]@03F]H01eJeHaQS66LiG_MJeUkg
00AJeP=Nm`03IcUS66Li00QS609Nm`03HaQNme[F009Nm`9S609JeP9S6003
G_MJeU[F009Nm`=S609Nm`9W>@07HaQW>F<HJeYW>F<HG_L00V<H00MW>F<H
HaQS65kgHaQW>@02HaP2IcT2HaP015kgHaQNmf<H0VLi00E[FVLiJeY[FVLi
009S609W>@04HaQNmekgHaP2IcT00f<HIcUS6002HaP4IcT2JeX2HaP2IcT0
1V]JHaQS66LiHaQW>@=S6004G_MS66LiHaP2IcT2HaP2G_L016<HIcUW>FLi
0f<H0VLi00=[FVLiHaP00V<H0VLi00Q[FVLiJeYW>F<HIcUS66Li0V<H1FLi
0V<H0VLi00=[FVLiIcT00f<H16Li00=S66LiIcT016Li00=S66LiIcT00VLi
00=[FVLiHaP00f<H00=Nmf<HG_L00V<H00=W>F<HG_L015kg00=JeUkgF]H0
0ekg00=F]E[FE[D00CW>00031240100012448@000PQ200P000@Q36=6<Goo
IcTmke:D0U[F00AF]E:DDYABU09JeP04E[EBU5:DE[D3DY@4CW<00eJeDYAF
]@02E[D7DY@2F]H01eJeDYABU5JeDYA>Le:D009F]@EBU09>L`9BU0=JeP04
CW=:DTicDY@2E[D3DY@00dicBU9>L`02CW<00dYBCW=>L`02E[D2DY@2CW<5
BU82CW<2BU82AS4014icDYA>Ldic0THa00=>LdYBCW<00e:D00=F]DicBU80
0TYB00ABU4icBU9:DPMBU0A:DP04CW=BU5:DCW<6DY@00eJeDYA>L`03DY@0
2E[FDYA>LdicE[EJeUJeCW=BU002F]H00e:DCW=F]@02E[D014icBU9>LdYB
0e:D00MF]DicDYABU5JeDYAF]@02DY@00eJeCW=>L`02CW<2BU82CW<3BU80
1DicBU9:DTYBCW<015:D00Y>Le:DDYABU5[FHaQJeUJeDYA>L`9BU005E[EB
U4icBU9>L`03DY@2CW<025:DCW=>LdYBCW=BU5JeDY@2CW<00dYBAS5>L`02
DY@00eJeDYAF]@02DY@014icDYABU5:D0dic00ABU5JeDYA>L`9BU0EF]@09
F]INme[FF]IF]E[FE[EBU4ic00ABU09:DP9BU003E[EBU4ic00ABU09>L`9J
eP03E[EBU4Ha009>L`9BU007CW=BU5[FE[EBU4icDY@00UJe00=BU5[FG_L0
0U[F0e:D00=>Le:DE[D00U[F00=F]E[FG_L00Ukg00=F]E[FDY@00e:D0UJe
0U:D00Y>Le:DE[E>LdYB@Q16<DicDYAJeP9Nm`=S609Nm`9JePAF]@05F]IF
]E[FE[EBU003E[D00e[FE[EF]@03F]H015JeDYAF]E[F0V<H00EJeUJeF]IF
]Ekg009JeP06E[EJeU[FF]IF]E[F0UJe00=JeUJeE[D00UJe0U[F00IF]E:D
E[EJeUkgF]H2E[D5F]H00ekgF]IJeP03F]H4E[D01ekgE[EJeUkgIcUS65kg
00IJeP9Nm`9S6003IcUS66<H00US60=Nm`04F]INmf<HHaP2G_L00f<HG_MN
m`02F]H015kgHaQS66<H0ekg00=S66LiIcT00V<H00=[FVLiIcT00Ukg00ES
66LiIcUS65kg009S609W>@03HaQW>FLi009S60=Nm`9S609W>@=[FP=S609W
>@06HaQNme[FHaQW>F<H0VLi0V<H1FLi00=[FVLiIcT00V<H00=[FVLiIcT0
0f<H0VLi00AS65kgHaQW>@9S609W>@9S609Nm`9S609W>@=S6004IcU[FV]J
IcT3HaP016LiJeYW>F]J0fLi0V<H00=W>F<HHaP00V<H00=W>F]JHaP00V<H
00=W>F]JIcT00fLi0V<H00=W>F]JJeX02FLi0V<H0fLi00=S66LiHaP00f<H
0ekg00AW>F<HHaQS60ENm`03F]INmekg009Nm`9JeP5>L`4mk`0000<000@Q
12400P@Q00@000@Q1248@P848@0836=247ooKg/mkdYBE[EBU0IF]@9BU003
CW=BU5Je009BU09>L`IBU004E[EJeUJeE[D3DY@02EJeF]INmeJeDYA>LeJe
DYAF]@02DY@2E[D2F]H014icDYA>LdYB0e:D00]JeUkgDYA:DTicDYANmeJe
DYAF]E:D00=:DPE>L`05DYAF]E:DE[E>L`03BU801TicBU9:DTYBCW=BU0=:
DP03AS5:DTic00A:DP9BU003E[EBU5:D00=BU003CW=BU5:D00=BU0=>L`9:
DP09CW=BU4icAS5244HaDYA>Le:D009F]@9BU003CW=BU5:D009F]@=BU003
E[EBU5:D009>L`03DYAJeU:D009>L`06E[ENmekgE[EBU4ic0U:D0Tic00A:
DU:DDYAF]@9BU003CW=F]EJe009>L`05F]INmeJeCW=:DP04CW<2BU82CW<2
DY@2CW<5DY@2E[D015:DCW=BU5Je0e[F1E:D0Tic00=:DU:DDY@00Tic00A:
DTicDYABU09:DP0=CW=F]EJeDYA>LeJeDYA>LdHaBU9BU4icDY@00UJe00=B
U4icDY@00UJe00=BU4YBDY@00U:D00EF]E:DDYABU4ic009F]@AJeP=BU006
F]INme[FDYA>LeJe0Tic00I6<DYBCW=>Le:DCW<2DY@025JeDYA>LdYBDYAF
]E[FE[D4DY@02TYBCW=BU5:DE[EBU4icBU9>Le:D0eJe0U[F15Je00=BU5Je
DY@00U[F00MNme[FF]IJeUkgHaQNm`03DY@2E[D2F]H2DY@01dicE[E>LdYB
AS5:DUJe00=JeP03G_MS66<H009S60AJeP03E[EJeUJe009JePEF]@03F]IF
]EJe00AJeP03DYAF]EJe009JeP0;G_MJeU[FE[EJeUJeF]IF]E[FE[EJeP02
E[D3F]H2E[D2DY@3E[D00e:DE[EBU002F]H3E[D01e[FE[EF]E:DF]IF]E[F
00=F]@05G_MJeUJeE[EJeP02HaP2G_L00f<HIcUS6002F]H00eJeF]IJeP03
F]H015kgHaQS66<H1Ekg00IJeV<HG_MNme[FE[D2F]H00ekgHaQS6004G_L0
0f<HG_MNm`02G_L00f<HIcU[FP02IcT01F<HIcU[FVLiHaP00fLi1V<H00=N
mf<HHaP00f<H0VLi0V]J1f<H0fLi00I[FVLiHaQJeUkgHaP2G_L2HaP01F]J
IcUW>F]JIcT00V<H00=W>F]JJeX00f]J00=W>F<HIcT00VLi00ENmf<HHaQ[
FVLi009Nm`ES6004IcUS66<HHaP2G_L016<HJeY[FVLi16<H00Q[FVLiJeYW
>F<HIcUS66Li0f]J16Li00MS66LiIcUW>F<HIcU[FP02IcT016<HIcUW>F]J
0V<H00UW>EkgHaQNmf<HIcU[FVLiHaP00VLi0V]J00=_Nf]JIcT00fLi0V<H
00=W>F<HIcT00f<H00=Nmf<HG_L00f<H0ekg00=JeUkgHaP00V<H00ENme[F
F]IJeUJe004icP0000@48@00124000@48@0;24848@@Q36=6<GooKg/mkdYB
E[EBU005E[D8DY@2CW<00e:DCW=BU002DY@4E[D4DY@015JeG_MJeUJe0U:D
0eJe0e:D0eJe00=BU4icCW<00Tic00EBU5JeF]IJeU:D009>L`03E[EJeU[F
00=BU003CW=:DTYB00=>L`04BU9>Le:DDY@2E[D01DicBU9:DTYBCW<00dYB
0dic24YB00M>Le:DDYAF]E:DE[EBU004CW<2DY@00eJeDYABU004CW<2DY@0
14YBAS5244Ha0Tic0UJe0e:D00=>Le:DDY@00U:D00=F]E:DDY@00e:D00Y>
Le:DDYAJeUJeCW=BU5JeF]INm`9BU09>L`9BU00:BU9>LdicDYAF]E:DCW=B
U5JeDY@2CW<01EJeF]IF]DicBU800dic14YB00=>Le:DCW<00U:D00=>LeJe
DY@00U:D0UJe0U:D00=>LeJeF]H00U[F00=F]E:DCW<00U:D00=>LdYBCW<0
0U:D0TYB00=>Le:DDY@00dYB00A>LeJeDYA>L`=BU09:DP9>L`=BU006E[E>
LdicDYAJeUJe0dic00=F]E:DCW<00U:D00=>LeJeDY@00e[F00IF]E[FE[E>
Le:DG_L2F]H00dicDYABU002CW<2BU801DicDYA>Le:DCW<00e:D0dic0U[F
00AF]E:DCW=BU0A>L`03E[EJeU:D009>L`04BU9BU5:DDY@3F]H3E[D3DY@2
E[D015[FG_MNmeJe0U[F0Ukg00AF]E:DE[EBU09JeP09E[EBU4icDYAF]Dic
BU96<DYB009F]@=JeP08HaQW>F<HG_MJeUkgE[EJeP9F]@AJeP9BU003E[EJ
eU[F009F]@AJeP9F]@03F]IF]Ekg00AJeP06E[EJeUJeF]IF]E[F0UJe0U[F
00=Nme[FE[D00U:D0UJe00EBU5JeDYABU5Je009JeP04E[EBU5JeF]H4E[D2
F]H3E[D01EkgF]IF]E:DG_L00V<H0Ukg0f<H1e[F00=F]EkgHaP00V<H00AN
me[FHaQNm`9JeP9S6003G_MJeUJe009JeP=S60ANm`9S6004G_MJeUkgHaP3
IcT00f<HIcUW>@03IcT00f<HIcUS6003HaP2IcT00ekgHaQS6005HaP3JeX3
HaP3G_L00f<HIcUW>@02JeX00fLiHaQNm`02HaP2G_L00f<HIcU[FP05IcT0
16<HIcUW>FLi0f]J0f<H0VLi0V<H0fLi1F<H16Li0V<H0Ukg00MS66LiJeY[
FV<HG_MS6002IcT2JeX01F<HIcUS66<HIcT00f]J00EW>F<HHaQS66]J009W
>@04HaQW>FLiJeX2IcT01F<HIcU[FV]JIcT00V<H0Ukg0V<H1VLi16]J0VLi
00ES66LiIcUW>F<H009W>@9S60=Nm`=S60=Nm`03F]INmekg00=S60AJeP5F
]@4icP0010@Q00`000@Q12448@Q2124000aS?Nmoog>L@Q02DY@01EJeF]IN
meJeDY@00Tic0U:D00AF]E:DCW=>L`YBU0=JeP04E[EBU5JeE[D2F]H02UJe
DYA>Le:DE[EBU5JeCW=F]E:D0U[F0U:D00=>LdHaCW<00Tic00AF]E:DDYA>
L`9BU09F]@03DYAF]Dic00=:DP9BU0A>L`9BU006E[E>Le:DCW=BU5Je0Tic
00I6<DYBCW=>LdYBCW<2BU82CW<025:DCW=:DU:DE[EJeU:DCW<2DY@2CW<0
0dYBCW=>L`04CW<015:DBU9:DTic0U:D00I>LdHa@Q1:DTicDY@2E[D4DY@2
E[D02E:DE[EBU5:DCW=BU5JeDYA>L`02DY@2CW<2DY@2F]H01EJeDYA>Le:D
E[D00U:D00=:DTicDY@00UJe0e:D00Q>LdYBCW=JeV<HF]IBU4ic0e:D00=>
LdYBBU800dYB1Dic0U:D00iF]E:DDYABU4icDYAF]E:DE[ENme[FDYA>LdYB
0U:D0UJe0e:D00A:DU:DCW=:DP9>L`03DYA>LdYB009F]@9JeP9BU09:DP03
DYA>Le:D00=>L`05DYA>LeJeE[EBU003CW<015JeF]IF]E:D0Tic00AF]E[F
F]IF]@9JeP04DYAF]DicBU82DY@2E[D2DY@00eJeDYA>L`02BU86DY@2CW<2
DY@2E[D2DY@015JeCW=BU4ic15:D00A>LdYBBU9>L`9BU005E[EBU5:DE[EB
U002E[D2DY@014icF]IJeUkg0e[F0Ukg011S65JeDYABU5[FG_MF]E:DCW=B
U4icBU9244HaBU9BU09JeP03E[EJeUkg009Nm`03HaQNmekg009JeP03E[EJ
eUJe009JeP9F]@9JeP9F]@9BU003E[EJeUkg009JeP03E[EJeUJe009F]@9J
eP9Nm`03E[EBU5Je00=JeP03DYAF]E[F009JeP03E[EBU4ic00EBU0=F]@9B
U0=JeP04DYAF]E[FG_L2F]H3E[D6F]H2G_L01E[FG_MNmf<HG_L00U[F00AF
]E[FG_MJePAF]@05F]IF]EJeG_MS6002G_L015JeF]INme[F0UJe00MJeUkg
HaQNmf<HG_MW>@02HaP00ekgIcUS6003HaP01FLiJeY[FV]JIcT00V<H00AW
>F<HG_MJeP9Nm`9W>@04HaQJeUkgHaP2IcT00f<HG_MS6002IcT2JeX3IcT2
HaP2G_L01FLiHaQS66<HG_L00V<H00=Nmf<HHaP016<H0f]J00=S66LiHaP0
2FLi0V<H00=Nmf<HHaP00VLi0Ukg1F<H0fLi0V<H00MW>F]JJeYS66LiHaQW
>@04HaP00fLiJeYW>@03HaP00fLiJeY[FP03IcT3JeX01f<HIcUW>FLiHaQW
>F<H009W>@04HaQNmekgF]H5HaP3IcT016]JIcUW>FLi16]J00=S66LiHaP0
0VLi00=[FVLiIcT01F<H00=Nmf<HG_L00f<H0Ukg16<H00ENme[FF]INme:D
004mk`0000@48@00124000@48@0924848@@Q36<mkgooLia6<Dic009F]@04
G_MJeUJeCW<2DY@014icE[EF]E:D0dic00=BU5JeCW<01E:D0UJe00=JeUJe
E[D00U:D00=F]E[FE[D00U:D00A>Le:DDYAF]@=BU09F]@03F]IBU5:D00=:
DP04CW=BU5JeDY@3CW<02E:DF]IF]E:DE[EBU4icBU96<@05CW<5DY@2CW<3
DY@5BU82CW<2BU800dicDYABU002BU8015:DE[EF]EJe0U:D00E>Le:DCW=>
LdYB00=>L`07BU9>LdicCW=:DTicDY@00Tic0T8@0TYB0eJe00EBU4icCW=B
U5Je009BU003E[EBU4ic00=BU003CW=BU5:D009BU005CW=BU5:DE[ENm`02
DY@014icDYAF]E:D0dic0U:D00=F]E:DDY@00U:D00M:DTicF]INme[FDYA>
L`03DY@00dicBU9:DP04BU800dicDYABU002CW<2DY@00eJeDYA>L`04DY@0
1UJeF]IJeUJeCW=:DPABU003E[E>Ldic009>L`04DYA:DTYBBU82CW<2DY@0
0eJeF]IF]@02DY@01DYBCW=BU5:DCW<00U:D0Tic0e:D00=F]DicCW<00U:D
0U[F0Tic0U:D00UF]EkgF]IF]E[FE[EBU4icBU800U:D00=JeUJeDY@00U:D
00I>LdYBCW=>Le:DCW<5DY@00dicDYABU002E[D4DY@3CW<3DY@014icBU9:
DTic0e:D0UJe0U:D00QF]E:DDYA>Le:DE[EJeUkg0e[F00ANmf<HG_MF]@9B
U09JeP0;E[EBU5:DDYA>LdYBAS5244YBDYANm`03F]H3G_L2HaP015kgF]IF
]EJe0e[F00IF]E[FE[EJeUJeF]H4E[D4F]H2E[D00e[FE[EF]@02F]H00ekg
F]IF]@02E[D2F]H3E[D2F]H2E[D4DY@014icDYAF]E:D0UJe00Q>LeJeE[EN
me[FDYAF]Ekg0U[F0UJe00=JeUJeF]H00e[F00MF]E[FHaQNme[FG_MS6002
G_L00e[FE[EJeP02F]H4E[D2F]H2E[D01E[FHaQS65kgE[D00U[F00ENme[F
F]IF]Ekg009S6003G_MS66<H00QS6007IcU[FV]JIcUS66LiHaP00VLi0Ukg
00AJeV<HIcUW>@=Nm`05HaQ[FVLiHaQNm`02HaP2JeX4IcT00f<HG_MNm`05
HaP01ekgHaQNmf<HG_MS66Li009S609W>@03JeYW>FLi00=W>@03HaQW>FLi
00AW>@05HaQW>F<HG_MS6002IcT00f<HG_MS6003HaP2G_L00f<HIcUW>@02
HaP5IcT4HaP00ekgIcUW>@02IcT3HaP01VLiJeY[FVLiJeYW>@=[FPEW>@09
HaQW>F<HIcUS65kgF]INmf<H009W>@=S6005IcU[FVLiIcUS6004JeX4IcT0
1F<HIcU[FVLiJeX00f<H0ekg00ES65kgHaQS65kg00AS6007G_MS65[FG_MJ
eUkgE[D00CW>00000`0012448@021240100012448@Q20P@Q00D8@T8@Oomg
_D8@00ABU009E[EBU4icBU9>Le:DE[EBU4ic009:DP07CW=BU5:DDYA>Le:D
CW<00UJe00EBU5[FF]IF]E[F00=BU003E[ENme[F00ABU0=F]@9BU009E[EB
U5:DDYA>LdYBAS5>Le:D009:DP05CW=BU5[FF]I>L`02DY@2CW<014YBCW=>
Ldic0e:D0TYB00A>LeJeDYABU0A>L`9:DP03CW=:DTYB0096<@=:DP03AS5:
DU:D00=>L`9BU005CW=BU5:DDYA>L`03BU800dicDYA>L`04CW<00dYBDYAB
U002DY@014YBAS56<DHa0e:D0UJe0U:D00=>Le:DDY@00e:D00A>Le:DDYAB
U0M>L`=BU003E[EBU4ic009BU003F]IBU4ic009BU003E[EBU4YB009>L`03
BU9BU5:D009JeP9F]@04DYAF]E:DCW<4BU8014HaBU9:DTic15:D00I>Le:D
DYA>LdYBDY@2CW<01e:DG_MNmeJeCW=6<Dic009BU09F]@9BU0E:DP05DYAF
]DicAS5>L`02F]H01UJeCW=BU5:DCW=:DP=BU005BU9>Le:DDYA>L`03DY@2
CW<01E:DE[EJeU[FE[D00U:D00=F]E:DE[D00UJe0e:D00E:DTicDYAF]E:D
00AF]@04DYA>LdicCW<2E[D01E:DCW=BU5JeDY@00Tic00=BU5JeE[D00U:D
0Tic0U:D00=>Le:DDY@00U:D00=:DTicCW<01E:D15Je0e:D0e[F00=F]E[F
G_L00Ukg00AJeUJeE[EF]@9JeP9F]@05DYA:DTYBAS5:DP05E[D03e[FG_MS
65kgHaQW>F<HG_MF]E[FE[EJeUJeDYAJeP03G_L01UJeDYAF]E:DE[EJeP9F
]@=JeP05DYAF]E:DE[ENm`02F]H3E[D2F]H6E[D01U:DE[EBU5JeDYAF]@9J
eP05G_MJeUJeF]IF]@05F]H01UJeF]IJeU[FE[EBU0=JeP03E[EJeUkg009J
eP05E[EJeU[FF]IS6002G_L01EJeDYAF]EJeF]H00eJe00MBU5[FF]IF]Ekg
F]INm`02F]H2G_L3F]H01EkgF]IS66LiHaP00VLi0f<H00=W>F]JIcT00f<H
0fLi00ES65kgG_MNmf<H00=Nm`=S60=Nm`9S6008IcUS65kgHaQW>F<HIcU[
FP9W>@05HaQNmf<HG_MS6002F]H015kgHaQW>FLi0f<H1FLi0V]J00=W>F<H
HaP01F<H00EW>F]JIcUW>F<H00=Nm`9W>@9S609Nm`06HaQNmekgIcU[FVLi
0f<H0f]J00=W>F<HIcT00VLi00IS65kgHaQS66LiJeX3IcT01V<HIcUW>FLi
JeYW>@9[FP9W>@03JeYW>FLi009S6007G_MS66<HHaQNme[FG_L01F<H00=W
>F<HIcT00V]J00EW>F]JIcUW>F]J009W>@9S60MW>@04HaQW>FLiIcT3HaP0
26LiHaQW>F<HIcUS66LiG_L2HaP3G_L1E[D1?Nl000@48@0<00048@@Q1248
@P00124<Hd8@OomcW4Ha0e:D00AF]E:DDYA:DP9>L`9F]@0=DYA>LdicBU9>
Le:DE[E>Le:DCW=BU5JeDY@015Je00AJeUJeCW=BU0=JeP03DYA>Le:D00=F
]@9BU003E[EBU5Je009BU004CW=6<DYBBU82CW<01dHaCW=BU5kgE[E>Le:D
00E>L`9:DP03DYAF]Dic009:DP03CW=BU5Je00=BU09>L`I:DP03AS5:DTYB
0096<@04BU9>LdicCW<3DY@01EJeDYABU5:DCW<00TYB14ic0TYB00=>LdYB
CW<015:D00A:DT8@AS56<@=BU004E[EBU5:DCW<6DY@014icDYABU5:D0Tic
00=BU4icCW<00Tic0U:D00=F]E:DDY@00Tic00=F]E[FE[D00Tic0UJe00=B
U4icCW<00dic0UJe00=JeUJeE[D00e:D0Tic00U6<DYBBU96<DYBCW=BU4ic
DY@00Tic0U:D14ic00QBU4YBDYAJeUkgF]I:DTHa0Tic00=BU5JeDY@00U:D
00E>LdYBBU9:DTic009BU09:DP05DYAJeU[FDYA>L`02DY@2CW<2DY@014ic
DYA>Ldic15:D0dic00=BU5JeF]H015Je0U:D0UJe0U:D00EF]DYBBU9>Le:D
009F]@09DYAF]EJeE[EBU4icBU9BU5Je00IBU09>L`9BU004E[EBU4icCW<2
DY@00dicDYABU002DY@4CW<4DY@01EJeDYABU5:DE[D00U:D0UJe0U[F00=F
]E[FG_L00V<H0UJe0U:D00EF]E[FE[EF]E:D00=6<@03BU9F]EJe009F]@9J
eP9Nm`06HaQW>FLiHaQNmeJe0U[F00EF]E[FF]IF]E[F009Nm`04F]IF]E:D
DY@2F]H2E[D015[FE[EJeUJe0U:D15[F1EJe00=JeUJeF]H00UJe0e:D1EJe
0U[F00ANmeJeE[EF]@AJeP07E[EJeU[FF]IF]E:DE[D01E[F0Ukg00EJeUJe
E[EJeUkg009S609JeP=F]@03F]IF]EJe00EF]@03F]INmekg00=JeP9Nm`=J
eP03G_MS66<H009S609W>@03G_MS66Li009W>@03HaQNmfLi00=W>@08HaQN
mf<HG_MS65kgF]INm`AS6005F]IS66<HIcUS6002G_L01V<HIcUW>F<HIcU[
FP9S609Nm`9S60=JeP03HaQW>F<H00=S609W>@0:HaQW>FLiIcU[FVLiHaQW
>F<HIcT3HaP3IcT2HaP2G_L2HaP00fLiHaQS6002G_L016<HG_MNmf<H0fLi
0V<H0f]J00AW>F<HHaQW>@ES6003IcU[FV]J009W>@05HaQW>FLiJeYW>@02
JeX00fLiJeYW>@03IcT4HaP016LiHaQJeU[F0Ukg1F<H0VLi0V]J0fLi00M[
FVLiJeYW>F<HIcUS6002IcT016]JIcUW>F<H0VLi00E[FVLiHaQS65kg00=S
60AW>@9S60ANm`5BU04mk`0000@000@Q124000848@030008@PQ200848@07
36<mkgooJeXmke:DE[D00U:D00=F]E:DDY@00Tic0e:D0dic00I:DTicCW=F
]E:DE[D2DY@2E[D4F]H025:DCW=>LeJeG_MJeUJeDY@2E[D00e:DF]IJeP02
DY@00dYBCW=BU002CW<2BU802DicDYA6<DHaBU9F]E[FE[E>L`02DY@2CW<2
BU85CW<2BU801DicDYA:DTYBCW<00e:D0dYB00=>LdYBAS400THa00E:DT8@
AS5:DU:D00=>L`9BU003CW=BU5Je00I>L`=:DP=>L`03AS5>Le:D009BU0A6
<@05CW=:DTicE[EJeP02DY@00dYBCW=BU003DY@00dicDYABU003DY@024ic
DYA>LdicDYA>Le:DCW<:DY@00dicDYA:DP03CW<00e:DBU9BU002F]H00eJe
CW=>L`02DY@014icBU96<DYB0Tic0THa00=>Le:DE[D00Tic00EBU4YBCW=:
DTic009:DP05DYAF]EJeF]IBU004BU84DY@2CW<01DYBCW=BU5:DCW<00TYB
00I>LeJeE[E>Le:DE[D2DY@2CW<00eJeDYABU003DY@00dicDYABU004DY@0
15[FE[EJeU[F0UJe15:D00=F]E:DDY@014ic00AF]E:DDYABU09F]@03G_MJ
eU[F00=BU003CW=BU5:D009BU0=>L`9BU003CW=:DTYB009BU09>L`=BU004
CW=:DTYBCW<2E[D00e:DCW=BU002E[D4DY@00eJeF]IJeP04F]H2G_L2F]H3
DY@2F]H02eJeCW<mkd8@CW=JeUkgF]I>Le:DE[D015[F00=Nmf<HHaP00e[F
0Ukg0UJe00AJeUkgG_MJeP9BU003F]IF]E:D00ABU003E[EBU5:D00AF]@03
F]IF]EJe00=F]@9JeP03G_MJeUJe00=F]@05F]IF]E[FE[EJeP02G_L016<H
G_MJeU[F0UJe00=JeUkgG_L00U[F00=F]E[FE[D00UJe1U[F00AF]E:DDYAF
]@=JeP9Nm`06F]IBU5JeDYAF]E[F0UJe15[F00EF]EkgG_MNme[F00ANm`07
HaQNmekgG_MS66LiJeX00f<H0fLi0V<H0U[F0ekg00=S65kgHaP00ekg16<H
00=Nmf<HHaP00Ukg00IS65kgHaQNmf<HG_L2HaP016LiHaQS65kg16<H0Ukg
00IS66LiJeYW>EkgHaP5IcT2JeX00f<HIcUS6002IcT2HaP3G_L2HaP00fLi
G_MS6002G_L2HaP00fLiHaQS6002HaP01UkgHaQNmekgIcUS609[FP=W>@03
HaQW>FLi009W>@9S60=W>@9[FP9_N`=W>@9[FP06IcU[FVLiHaQW>F<H0VLi
00=S65kgF]H00ekg00AS65[FG_MNm`=S6003IcUS66Li009S6003IcU[FVLi
00AS609W>@9S609W>@03JeYW>FLi009W>@03JeYS66<H009S6006IcUNmekg
G_MS66Li0V<H00=JeUkgHaP00Ukg0E[F0EJe0Cg_00000`@Q00048@051240
2@Q2124000aS@Q1oof]J?Nm>L`02E[D2DY@00eJeCW=>L`04DY@2CW<00dYB
CW=>L`05DY@00eJeDYAF]@04F]H2CW<015:DE[ENme[F0e:D0UJe0U[F0U:D
00m:DTicCW=BU4icBU96<DicDYA:DT8@BU9F]E[FDY@00Tic0U:D00E>LdYB
CW=:DTic009BU0=:DP04DYA>LdicBU83DY@00dicBU9:DP04BU8014HaBU92
44Ha0TYB1Tic0e:D1Tic0TYB0dic0dYB0e:D0TYB0THa0TYB00I>LeJeE[EF
]DicBU82CW<00eJeDYA>L`02CW<2DY@2CW<2DY@5CW<3DY@014icDYAF]EJe
0U:D00=>Le:DDY@00Tic0TYB00M>Le:DBU9BU5JeG_MF]@02CW<2DY@00dic
AS56<@02BU8014icBU96<Dic0e:D0dic1DYB0U:D00AJeUJeDYA>L`9:DP04
CW=BU5:DDY@2CW<01TYBCW=>LdicDYA>L`9:DP05CW=BU5:DDYA>L`02E[D0
0e:DBU9>L`0:DY@2CW<015:DE[EJeUJe0U[F0U:D00=>Le:DE[D00e:D0Tic
00E:DU:DDYABU5Je009BU0AJeP03DYAF]E:D009>L`08DYAF]E:DCW=:DU:D
CW=BU09:DP9>L`9BU005CW=BU5:DDYA>L`02AS401U:DE[EF]E:DCW=BU09F
]@ABU003E[EJeU[F009JeP04E[EJeU[FG_L2F]H00eJeCW=BU002F]H02UJe
CW<mkcg_CW=JeV<HF]I>Le:D0UJe0U[F0Ukg00=S65kgF]H00e[F00ANme[F
E[EJeP9Nm`03F]IBU5:D00=F]@=BU003E[EBU5:D00=BU004E[EJeUJeF]H4
E[D2F]H00eJeF]IJeP05E[D00e[FE[EJeP03G_L00f<HF]IJeP02E[D2F]H0
0ekgF]IF]@03F]H2E[D3F]H015JeF]IJeUJe0U:D00=JeUJeF]H00ekg00AJ
eUJeDYABU0EF]@9JeP04E[EJeU[FG_L2F]H2G_L00f<HG_MNm`03G_L016<H
IcUW>FLi0V<H0VLi00=S66LiG_L00Ukg00=JeUkgHaP00f<H0Ukg00EJeV<H
HaQS65kg00ES60=Nm`03HaQNmf<H009S6003IcUS66<H009Nm`06IcUS66<H
G_MJeV<H0VLi00=S65kgG_L016Li00=[FVLiIcT016Li00=S66LiG_L00ekg
0f<H0ekg0V<H00=W>F<HHaP00V<H0Ukg00=S65kgHaP00V<H0V]J00=W>F]J
HaP00V<H0fLi0V<H0fLi00E[FVmkJeY[FVLi009[FPAW>@03HaQW>FLi009[
FP04IcUNmekgG_L2F]H01f<HG_MNme[FG_MS66Li009S6006IcUS66LiIcU[
FV<H0VLi00=S66LiIcT00VLi0V<H00=W>F]JIcT01FLi0f<H00=W>F<HHaP0
0Ukg00AS66LiHaQS60ANm`9JeP5F]@4mk`000P@Q00<000@Q00000`@Q00T8
@P@Q124<HcW>Oom[FT8@DY@00UJe15:D00A>Le:DDYABU09>L`05DYA>Ldic
BU9>L`03DY@01TicDYABU5:DF]IF]@9JeP07DYA>Le:DDYAJeUkgF]H00U:D
0Tic0Ukg00AF]DicAS56<@9>L`09DYA:DTicCW=BU4YBAS5:DTic009F]@07
BU9>LdYBBU9BU4icBU800U:D0Tic0TYB0dic00=:DTicDY@00U:D00Y>LdYB
CW=:DTicBU96<DYBAS5>L`E:DP03CW=:DTYB009>L`03DYA>Ldic00I>L`9:
DP04CW=BU4icBU82DY@00eJeDYA:DP04BU82CW<2E[D01E:DCW=>LdicDY@0
0Tic1U:D0dic0U:D00=F]E:DCW<00TYB0Tic00IBU4icDYABU4icDY@2CW<0
1E:DCW=>LdYBDY@014ic15:D00A>Le:DDYA>L`9:DP07CW=:DTHaAS5:DTic
BU800THa00=>Le:DCW<00TYB00E>Le:DDYABU4ic009BU004CW=:DTHaBU82
DY@01eJeF]IBU4icBU9>LeJe009BU09>L`07AS5:DU:DDYAJeUJeCW<00e:D
1EJe0e:D00QF]E:DDYA:DTicDYAF]E[F0UJe0U:D0Tic00EBU5JeDYAF]E:D
009>L`05BU9>Le:DDYAF]@02DY@00eJeF]IF]@03E[D3DY@00dicDYABU002
DY@00dicBU9:DP06CW<01EJeDYABU4icBU800Tic15:D0Tic0U:D00=F]E:D
DY@00UJe0e[F0UJe00AJeUkgG_MJeP=BU09F]@0<CW=:DT8@@Q1>Le[FHaQJ
eTicDYAF]E:D0eJe00AJeUkgG_MJeP=Nm`03F]IF]E[F009F]@05CW=BU5:D
DYAF]@02DY@00dicE[EF]@02DY@00eJeF]IF]@03DY@00e[FG_MF]@02DY@0
1U[FG_MNmeJeF]IF]@=Nm`9JeP9F]@03F]INme[F00=Nm`04F]IF]EJeE[D3
F]H015JeF]IJeU[F0UJe0Ukg0e[F00=F]E[FE[D00eJe00=BU5[FHaP00Ukg
00EF]E[FE[EF]E[F009F]@9Nm`=JeP05G_MS66<HG_MJeP02G_L01F<HG_MS
65kgHaP00VLi0f<H00=W>F<HHaP016<H0ekg00=S65kgHaP00ekg1F<H00AN
mf<HHaQS60ANm`03HaQNmekg00=S609Nm`03HaQW>FLi00AS60AW>@AS6003
IcU[FVLi00=W>@9S6003IcUS66Li009S6005G_MS65kgHaQNm`02HaP3G_L0
0fLiJeYW>@02HaP2IcT016<HG_MNmf<H0VLi0V]J00=W>F<HHaP00VLi0f<H
00=W>F]JIcT00VLi00=[FVmkJeX016]J1FLi1F<H00=W>EkgG_L00Ukg00=W
>F<HHaP00V<H0VLi00AS66LiIcUS60AW>@AS609W>@03HaQW>F]J00AW>@9[
FPIS60INm`08HaQNmekgG_MJeUkgHaQJeP52400000<000@Q12400P@Q00l0
00@Q1248@P@Q000<HcW>Oom[FT8@DYAF]E:DE[D00e:D0Tic0U:D0Tic00=B
U4icBU800TYB00A>Le:DDYAF]@9BU09F]@04F]IF]E[FDY@2CW<015:DF]IN
meJe15:D00AJeUkgF]IBU096<@A>L`09BU9>LdicBU96<DYBDYAF]E:D00A:
DPE>L`03DYA>Ldic009:DPA>L`=BU09>L`E:DP96<@03BU9>LdYB009:DP9>
L`9:DP07CW=BU5:DCW=:DTicDY@00dic0dYB00IBU4icCW=:DTicE[D2DY@0
0dHaBU9:DP02BU801DicDYAF]EJeCW<00TYB00=>Le:DDY@00U:D00=>Le:D
DY@00U:D14ic0e:D00=>LdYBBU800Tic0U:D00A>Le:DDYABU0A>L`03BU9>
Le:D00=>L`9BU0=>L`9BU006CW=:DTicBU9>LdYB0THa00=:DU:DCW<00THa
0Tic00MBU4icCW=:DTicDYA>L`03DY@014icBU96<Dic0U:D00EF]E[FDYA>
LdYB009>L`04DYA>LdicCW<2BU8014icE[EF]E:D0Tic0U:D0UJe00MBU5Je
E[EBU4icDYAF]@02DY@2CW<2E[D2F]H00eJeDYA>L`02CW<01UJeDYAF]EJe
CW=BU09:DP9>L`06E[EBU5:DDYAF]E[F0eJe1E:D0dic00ABU4icCW=:DPE>
L`ABU004CW=:DTicCW<4DY@00dicDYA>L`04DY@2E[D3F]H2E[D04E[FHaQJ
eU[FDYA>Le:DF]IF]E:DBU8mkd8@DYAF]EkgF]H00U:D0UJe00=JeUJeE[D0
0U[F1Ekg00AJeUJeF]IF]@9BU007CW=BU5:DE[EBU4icDY@00UJe00A>Le:D
F]IJePABU09JeP9F]@03DYAF]Ekg00EJeP9Nm`03F]IF]EJe009JeP04G_MJ
eUkgG_L2F]H01UJeDYAJeU[FG_MJeP9F]@9JeP06E[EJeU[FG_MJeUJe0e[F
00EF]E:DF]IBU5Je009Nm`05HaQNmeJeE[EJeP03E[D2F]H01EkgF]IF]E[F
G_L00V<H0Ukg00AJeV<HHaQS609Nm`03HaQW>F<H009W>@08HaQW>F<HHaQN
mf<HIcUS60ANm`=S6003F]INmekg00=S609Nm`9S6005G_MS65kgG_MS6003
G_L3HaP00ekgHaQS6002IcT016<HG_MS66<H0VLi0f<H00=W>F<HHaP00VLi
0V]J00=W>F<HHaP00V<H00=W>F<HG_L00ekg00AS65kgHaQNm`9S6003F]IS
66<H009W>@03HaQW>FLi009S6004G_MS66<HHaP4JeX4HaP00fLiHaQS6003
IcT016<HJeY[FVmk0V]J00IW>F]JJeY[FVLiHaP2IcT6HaP3G_L3HaP015kg
HaQW>F<H2VLi16<H00=W>F<HIcT01VLi00=[FVLiHaP00V<H00AW>F<HHaQJ
eP9Nm`05F]INmekgG_MS6002G_L00e[FHaQJeP01@Q000003124000@Q00<4
8@030008@PQ200848@0736=247ooJeXmke:DE[D00e:D00=F]DicDY@00U:D
0Tic00IBU5JeE[EF]E:DCW<2DY@4E[D015:DE[EF]EJe0e:D00YF]E:DDYAJ
eUkgE[E>LdYBCW=F]@=JeP9:DP96<@03CW=BU4ic00=:DP07CW=BU5:DDYAJ
eTicBU800T8@00EBU4icDYA>Le:D009>L`03BU9>LdYB009>L`03BU9BU5:D
00=BU0=:DP05CW=:DTYBAS5:DP02CW<2DY@00dYBCW=:DP03BU82CW<2DY@0
14icBU9>Le:D0Tic00A:DTicDYAF]@9BU003CW=BU5:D009>L`03DYA:DTYB
009:DP04E[EBU5:DCW<2BU82CW<2BU800dicE[EBU005CW<01E:DF]IF]EJe
BU802Dic0U:D0Tic0U:D0dic0U:D00A:DTicCW=F]@9BU008CW=:DU:DDYA>
LdYBDYA:DP=6<@05CW=:DTYBAS5>L`03DY@014icBU9>Le:D0Tic00ABU5[F
E[EBU0A>L`=BU003CW=:DU:D009F]@9BU006CW=6<DHaCW=F]E[F0U:D00=F
]E[FE[D00UJe00AJeUJeE[E>L`EBU09>L`04DYAF]E[FF]H3DY@2CW<015:D
E[EF]EJe0U:D00I>LdYBCW=BU5JeDY@3CW<01E:DE[E>LdYBCW<00eJe0U:D
00=F]E:DCW<00Tic0U:D00=>LdYBAS400Tic00EBU4icDYABU4ic00IBU09>
L`03DYAF]EJe00=BU007E[EJeUkgG_MF]E:DE[D00V<H00IJeU:DE[EF]E:D
CW<2@Q001THaBU9F]EJeDYAF]@ABU09F]@04F]IF]E[FF]H3HaP01U[FG_MN
mf<HF]IF]@9BU09JeP03E[EBU5:D009F]@03F]IF]Dic00=BU003CW=BU5Je
009JeP9F]@04F]INmekgG_L5F]H4G_L2F]H02U:DE[EJeU[FG_MJeUJeDYAF
]E:D0U[F0ekg0eJe0Ukg00IS65[FF]IJeUJeF]H2E[D2F]H4HaP2G_L01UJe
DYABU5JeF]INm`9JeP9F]@03F]INmf<H009Nm`9JeP03HaQJeU[F00AS6004
G_MS66LiHaP3G_L016<HIcUS66Li0f<H0fLi0f<H00MNmf<HIcUW>F<HG_MJ
eP02G_L00f<HG_MJeP02F]H016<HIcUS66<H0Ukg00=S65kgG_L00VLi0V<H
0Ukg0VLi00=[FVLiHaP016<H16Li36<H00AW>F<HHaQS60=[FP03HaQW>F<H
00ES60=W>@9[FP9S6003G_MS66Li00AW>@03HaQW>FLi009[FP06Kg]W>F]J
HaQW>F<H0VLi0V<H00MNme[FG_MS66LiHaQNm`03HaP00fLiHaQW>@02IcT2
JeX2IcT00f<HIcUW>@03HaP2IcT2HaP00fLiHaQW>@05IcT00f]JIcUW>@06
HaP3G_L3F]H015kgHaQNmekg0U[F0F<H0Ekg0D8@000212400`0012400003
12402PQ200048@aS?NmoofLi@Q1>LeJe0U:D00IF]E:DDYABU4icDY@2CW<2
DY@00e[FE[E>L`03DY@00eJeF]IF]@03DY@2E[D00e:DCW=F]@02DY@01eJe
F]IJeUJeDYA6<Dic00=JeP03E[E:DTHa009:DP9>L`A:DP0:CW=BU4icE[EJ
eTicAS5244HaDY@2CW<015:DCW=>Ldic0dYB14ic0U:D00AF]DicBU9:DP9>
L`06BU96<DHaBU9>Le:D0dic14YB0Tic0U:D0dic00=BU4icCW<00dic15:D
00A>Le:DCW=BU0=>L`06AS5:DTicCW=F]E:D0TYB14ic00=:DU:DDY@00e:D
00=>LdYBBU800UJe00MJeU:DCW=>LdYBCW=:DP04CW<2DY@3CW<015:DCW=>
Ldic0U:D14ic00EBU5JeDYA>LdYB00=BU003CW=BU4YB00924004AS5>Ldic
AS42BU8014icDYABU5:D0dic00M:DTicDYAJeUJeDYA:DP02CW<014YBDYAF
]E:D0TYB00i>LeJeE[EBU4icDYA:DTHaCW=F]E[FDYA>Le:D0U[F0UJe00EJ
eUJeDYABU4ic00EBU004CW=BU5JeF]H2E[D3CW<00e:DE[EBU002E[D2DY@3
CW<00eJeDYABU002CW<02e:DE[EBU4icBU9>Le:DF]IF]E:DE[D00U:D0dic
0U:D00A>LdYBBU9:DP9>L`IBU003CW=BU5:D00=>L`9BU09F]@09DYAF]EJe
F]INme[FE[EBU5Je009Nm`03F]IBU5Je009F]@06BU96<DHaAS5>LeJe0U:D
00=F]E:DDY@00U:D00=JeUJeE[D00UJe00=Nmf<HHaP01Ekg00=JeUJeCW<0
0UJe00=JeUJeDY@00U:D00AJeUJeDYA>L`IBU09F]@04F]IF]E[FF]H2G_L2
F]H00eJeF]INm`03F]H00ekgF]IJeP02E[D02E[FG_MJeU[FE[EBU5JeDYAF
]@02F]H015kgF]IF]EJe0U[F0Ukg0U[F00=F]E[FE[D00UJe0U[F16<H0Ukg
00AJeU:DDYAF]@=JeP07E[EJeU[FE[ENmf<HG_L00U[F0ekg00EJeUkgHaQS
65kg00=S6004IcUNmekgG_L2HaP016LiHaQNmf<H16Li0V<H00ANmf<HHaQW
>@9S6004G_MJeUkgHaP2G_L3F]H2HaP01VLiHaQNmekgHaQNm`9S60=W>@=S
60=W>@AS6003IcUS66Li009W>@US6004G_MS66LiIcT3HaP016LiJeYW>FLi
0V<H00IW>F<HHaQS66LiHaP4JeX016LiG_MNmf<H1VLi00AS66LiIcU_N`=[
FP05IcUS66LiIcU[FP02HaP00e[FG_MS6003HaP015kgHaQS66Li0f<H0VLi
00=[FVLiIcT00fLi0f<H0VLi0f<H26Li00=[FVLiJeX01V<H0ekg0e[F0Ukg
00IS65[FE[EJeV<HF]H1AS40000300048@@Q00848@0=00048@@Q24848@00
48A247ooIcTicTicE[D00U:D0dYB1U:D0eJe00=BU4icDY@00U:D0U[F15:D
00EJeUJeE[EJeUJe009>L`04DYAJeUJeCW<2BU8044icDYAJeU[FE[E>LdYB
AS5>Le:DCW=:DT8@AS5>Le[F0UJe00=JeTYBBU800THa00M>Le:DCW=>Le:D
CW=BU003CW<2BU82CW<01DYBCW=>Le:DCW<00TYB0U:D1DYB00=>Le:DCW<0
1TYB0e:D0dic0U:D0Tic0U:D00EF]E:DDYA>LdYB009>L`03DYA>LdYB009:
DP08CW=BU5:DDYA>LdYB@Q16<@9>L`03DYA:DTYB009BU003CW=:DTYB009B
U005E[EJeU:DDYAF]@02DY@2CW<2BU83CW<2DY@3CW<01DYBDYAF]E[FE[D0
0Tic00=BU4icCW<00TYB00=>Le:DDY@00TYB00=>Le:DBU800THa0Tic00AB
U4YBBU9BU09F]@9>L`=BU00<CW=BU5JeHaQNmeJeCW=6<DYBDYA>Le:D0Tic
00=BU5JeDY@00U:D00A>LdYBBU9>L`9F]@9BU09JeP03E[EBU5Je009JeP05
E[E>Le:DCW=BU002E[D3DY@3E[D2CW<015:DBU9:DTic0U:D1dic0U:D00EF
]DicBU9:DTic009BU004CW=:DTicCW<3F]H2DY@01DicDYABU5:DBU800dic
00EBU4icDYABU5Je009BU09F]@9BU09>L`04DYAF]E[FF]H2DY@00dicE[EJ
eP04E[D00e[FE[EF]@02DY@01U[FDYA:DTHa@Q16<@9>L`03F]IF]EJe00AB
U09F]@08F]IF]E:DE[EJeV<HIcUNm`9JeP0:G_MS65[FF]IF]E:DF]IF]E:D
E[D2F]H6E[D4DY@01UJeF]IJeU[FG_MS609Nm`05F]INmekgF]IF]@02F]H2
HaP00ekgE[EBU003E[D2F]H01EJeF]IF]E:DE[D00U[F00QNme[FF]IF]E[F
E[EJeUkg0e[F00=F]E[FF]H00U[F00ENmf<HHaQS66Li009S60AF]@9Nm`IJ
eP9Nm`03HaQNmf<H00=JeP03G_MS66<H009Nm`9S6004IcUNmekgG_L4HaP2
G_L00f<HIcUS6002IcT036]JIcUJeV<HIcU[FVLiG_MJeUkgF]INm`=JeP08
G_MS66LiG_MS65kgF]INm`9S6004JeYW>FLiHaP2G_L026<HIcU[FV]JIcUS
66LiG_L2HaP3IcT3HaP01fLiHaQS66<HG_MS65kg009S609W>@03HaQW>FLi
009[FPMW>@05HaQW>F<HHaQW>@03HaP2G_L00f<HIcU[FP07IcT2JeX00fLi
G_MS6002HaP02UkgHaQS65kgF]INmfLiHaQW>F<H2FLi00=[FVLiIcT00fLi
0V<H0VLi00A[FVLiHaQS60IW>@AS609W>@=S6004G_MS65kgG_L4F]H6G_L1
F]H1@Q0000<48@0400048@@Q1242248212401`aS@Q1oofLi?Nm>LeJe009B
U09>L`03BU9>Le:D00ABU09F]@03F]IBU4ic009>L`03E[EJeU[F009BU007
CW=BU5[FDYAF]E[FE[D00Tic00IBU5[FE[E>LdHaBU82CW<01eJeF]IF]Dic
AS5:DU:D009>L`96<@03BU9>LeJe00=F]@9:DP03AS5:DTic00=>L`03DYA>
Ldic009>L`=:DP06CW=:DTicBU9>Le:D0TYB0Tic00=BU4icAS4014YB00EB
U4icCW=:DTHa00=:DPABU09>L`06DYA>LdicCW=BU5Je0U:D00=F]DicCW<0
14ic00M6<DYBBU9>Le:DE[EBU002CW<2AS400dYBDYABU002BU800dicE[E>
L`02BU801DicE[EJeU[FE[D015:D0Tic0dYB00=>Le:DDY@00Tic00YBU4YB
BU9BU5JeF]IF]DYBCW=BU09>L`9:DP03CW=BU5:D009:DP03DYA>LdHa0096
<@0:BU9BU4icBU96<DicF]IF]E:DCW<5DY@2F]H01UkgE[E>LdHaBU9>L`=B
U09>L`07DYAF]E:DDYA>LdYBAS400U:D00=F]E:DDY@00U[F0UJe00IBU5Je
F]IF]E:DCW<3DY@025JeDYABU5:DE[EBU5JeDY@2CW<2BU8015:DCW=BU5:D
0Tic00=BU4icCW<00Tic00IF]E:DDYA>LdYBCW<2DY@4CW<015JeF]IF]EJe
0Tic0U:D0Tic00=BU4icCW<00dic00=F]E:DDY@01E:D0Tic0UJe0U[F00AF
]E:DDYABU09JeP05E[EBU5JeDYAF]@03DY@01EJeDYA>LdYB@Q000TYB00IB
U5JeE[EBU5JeCW<2DY@015JeF]IF]EJe0U:D00INmf<HHaQNmeJeF]H3G_L0
1e[FDYAF]EJeDYAF]E[F00=F]@=BU003E[EBU5Je00=BU09F]@9JePANm`03
F]INme[F009JeP06E[EJeUkgHaQNmeJe0U:D15Je00=JeUJeE[D00eJe00IJ
eUkgG_MF]E[FE[D5F]H2E[D015[FE[EJeU[F0V<H00=Nmf<HIcT00V<H00AJ
eUJeDYAF]@9Nm`=JeP04E[EJeU[FF]H5G_L2F]H025kgHaQS65kgHaQNmfLi
HaP3G_L00f<HIcUS6005HaP01FLiHaQW>F]JHaP00Ukg00EW>F]JIcUNmeJe
009JeP9Nm`9JeP03G_MS66<H009S6003G_MJeUkg009S609[FP9W>@9Nm`9S
609[FP03HaQW>F<H009Nm`9W>@03JeYS66<H00=S6003IcUS66<H009Nm`=S
6004IcUS66<HIcT3JeX01fLiHaQW>F<HIcUS66Li00ES6003IcUS66<H009N
m`06HaQW>F]JJeYW>F<H0fLi0V]J0VLi0f<H0Ukg00MS65kgG_MJeUkgHaQW
>@02HaP3IcT00f<HIcUW>@04IcT016]JIcUS66Li0V<H0VLi0V]J00=W>F<H
IcT016Li00AS66LiIcUW>@=S609W>@AS609Nm`06E[EJeU[FG_MJeUkg0U[F
00=Nmf<HF]H00D8@0000600012448@@Q00048@001248@P00124<HdHaOomW
>CW>CW=JeUJeDYA>LdYBAS5>L`ABU09F]@9JeP0:E[EBU4YBCW=BU5[FG_MF
]E:DBU83DY@01UJeF]IBU4icAS5>L`=BU008CW=:DTicCW=JeUJeDYAF]@=>
L`0;DYA>LdHaBU96<DYBE[EBU5[FE[E>L`03BU82CW<4BU800e:DCW=>L`02
CW<4BU82CW<2BU82CW<025:DCW=>LdicBU9>LdYBCW<2BU800dicBU9:DP03
BU800dicDYABU003CW<3E[D035:DCW=>Le:DE[EBU4icBU96<DicBU924096
<@04CW=:DTYBBU83CW<0148@?Nm244YB0dic00EF]E:DBU9:DTic00=BU0=J
eP03DYA>Le:D009BU0=>L`04BU9>LdicBU83CW<014YBCW=BU5Je0U:D0dic
00=:DTicBU8014ic0U:D0TYB0THa0dic0U:D0Tic00=BU5JeDY@00e:D00QF
]E:DE[ES65kgF]IBU4Ha0TYB00E>Le:DCW=>Le:D00AF]@04DYA:DU:DCW<2
DY@00dicDYABU003DY@2F]H015JeDYABU5Je1U:D00=>Le:DE[D00UJe0Tic
0TYB00E>Le:DCW=>LdYB00=>L`07DYA:DU:DE[EJeU:DCW<00TYB1Tic00=B
U5JeE[D01E:D00=>Le:DDY@00U:D00I:DTicDYABU5JeDY@2E[D015kgE[EB
U4ic0U:D0UJe00AJeU:DDYAF]@9BU09F]@03F]IF]E[F009F]@08DYAF]EJe
CW=6<D8@AS5BU09JeP9F]@03DYAF]E:D00=BU0=JeP07E[EBU5JeF]INmf<H
G_L00U[F00=F]E[FF]H00e[F00IF]E[FE[EJeUJeDY@3F]H2DY@3F]H2DY@0
0eJeF]IS6002HaP01E[FG_MJeUkgF]H00UJe00=JeV<HG_L00e[F00ABU5Je
E[EF]@=JeP08G_MF]E:DDYAF]EkgF]IF]@MJeP=F]@=JeP9Nm`IS6005F]IF
]EJeE[ENm`02F]H3G_L2F]H01EkgIcUW>F<HG_L01E[F00INmf<HIcUW>F<H
IcT2HaP2G_L4HaP00fLiG_MNm`02HaP2IcT02ekgF]IJeVLiJeYW>EkgF]IN
me[FG_L00U[F00=Nmf<HG_L00Ukg00=JeUkgHaP00V<H00=W>F<HIcT00VLi
00ES65kgG_MS66Li009S60ENm`9S6003IcUS66<H009W>@9S609Nm`04HaQN
mfLiHaP6IcT016]JIcU[FVLi0V<H0VLi00AS65kgG_MNm`9W>@AS60QW>@05
HaQW>FLiIcU[FP04G_L016<HG_MS65kg0f<H00IW>F<HHaQS66LiJeX3IcT0
16<HIcUW>FLi0V]J0VLi00QS66LiIcUW>F]JIcU[FVLi0V<H00=W>F<HHaP0
0V<H00=Nmf<HG_L00f<H0VLi00=S65kgG_L015kg00UJeUkgG_MJeUkgHaQN
mf<HE[D00D8@000312400`0012448@0212402@Q212448@aS@Q1oof<H?Nm>
L`02E[D015:DCW=:DTYB0Tic0e:D0UJe0U[F0U:D00=>LdYBE[D00U[F00AF
]DicCW=>L`=BU003F]IF]E:D009:DP03DYAF]E:D00=:DP03DYAF]E[F00=B
U005CW=BU5:DCW=:DP02AS400dYBDYAF]@02E[D2CW<00dHaBU9>L`04BU80
14icBU9>Ldic1DYB0dic0dYB00Q>Le:DCW=>LdYBCW=:DTic0TYB00=>LdYB
BU800dYB00A>Le:DDYABU09>L`9BU003E[EBU5:D00EBU009CW=:DTYBCW=:
DTHa@Q1:DTic00=:DP=>L`05AS52448@AS5BU002BU82DY@00dicBU9:DP03
DY@01EJeF]IF]E:DBU800U:D1Tic00=:DTicCW<00Tic00=:DTicDY@00UJe
00=:DTicDY@01TYB00UBU4icCW=>LdYBAS5:DTHaBU800Tic00=BU4icDY@0
0U:D00IF]E:DE[E>Le:DE[D2DY@2HaP015JeDYA6<DYB1Dic0U:D00=JeUJe
DY@00dic00=BU4icCW<00e:D00=F]E:DDY@00U[F00EF]E:DDYABU5Je009B
U005E[E>LdicDYA>L`02E[D2DY@00dicBU9:DP04CW<2BU85CW<01EJeF]IF
]DicAS401Tic00=:DU:DDY@00UJe00=BU4icDY@00Tic00IBU5JeDYA>LdYB
CW<3DY@01eJeDYAF]E[FE[EBU4ic009BU09JeP03E[EBU5:D009BU09F]@=J
eP9F]@05DYAF]E:DE[E>L`02@Q000dHaDYAJeP02E[D7DY@2E[D02U[FE[EF
]EJeF]IS65kgF]INmeJe1E[F15Je00EJeUJeE[EBU5[F00AF]@0;F]IF]EJe
CW=F]E[FG_MW>EkgF]INm`04F]H01EJeF]INmekgF]H01eJe0e[F0UJe00=B
U5JeF]H00U[F00EF]E[FF]IJeUJe00=JeP9F]@=JeP04G_MS66<HG_L3HaP0
0fLiF]IF]@02E[D3F]H00ekgHaQNm`02F]H01EkgHaQW>F<HG_L00e[F00=N
me[FG_L00f<H0VLi00AS65kgG_MNm`9S60=W>@9Nm`9S600:IcU[FUkgF]IN
mf<HJeYW>EkgF]H3G_L2F]H2G_L016<HG_MJeU[F0Ukg0f<H00AW>F]JIcUS
60=Nm`9S6004IcUS65kgHaP2G_L2HaP00fLiHaQS6002HaP2IcT2HaP2G_L2
HaP2IcT00f<HIcUW>@04JeX01FLiHaQS66<HIcT00f<H00ANmf<HHaQW>@ES
60UW>@05JeYW>FLiG_MJeP03G_L016<HG_MNmekg1F<H0VLi00A[FVLiHaQW
>@9S6004IcU[FV]JJeX2IcT00f<HIcUW>@02IcT2JeX00fLiHaQS6002HaP0
1FLiHaQS66<HG_L00f<H00AW>F<HHaQS609Nm`9JePANm`07F]INmekgG_MS
65kgE[D00D8@00000`@Q00048@0212403@0012448@Q212400124@Q1oofLi
?Nm>Le[F00ABU0=:DP09CW=BU5:DDYAF]E[FG_MF]E:D009>L`06DYAF]E[F
DYA>LdYB0U:D00=>Le:DDY@00U:D00A>LdHaBU9>L`9BU09>L`04DYAF]E:D
DY@3E[D01DicBU9:DTHaCW<00TYB00I>Le:DDYABU4icBU82CW<01e:DCW=:
DTHaBU96<DYB009>L`04DYA>LdHaAS42BU801TicBU9:DTYBCW=BU09>L`04
DYA>LdicBU83CW<2BU800dicBU9>L`02BU800dicDYABU002DY@01EJeF]IJ
eU[FE[D00Tic1E:D00A>LdYBAS5:DP96<@9:DP96<@04BU9BU5:DBU82@Q00
0dHaCW=BU002DY@00dYBCW=>L`02DY@2CW<025:DF]IF]E:DCW=BU5JeDY@2
CW<00e:DCW=>L`06CW<3DY@2CW<5BU800dHaBU9>L`02BU82CW<2BU801DHa
BU9BU4icDY@00dic0e:D0eJe0e:D00QF]E[FF]IF]DicAS5:DTHa0TYB00I6
<DicDYAJeUkgF]H2E[D2DY@00dicDYABU002DY@01TicDYAF]E[FE[EBU0AF
]@07CW=:DU:DE[EJeUJeCW<00U:D00UJeUJeDYA:DTHaBU9>Le:DCW<00TYB
00Y>Le:DDYABU4icDYAF]E[FE[EBU09:DP9>L`03E[EBU5:D009BU006CW=B
U5:DE[EBU4ic0TYB00=BU5JeE[D01e:D0eJe00=JeUJeE[D00U:D00Q>LeJe
F]IF]E[FDYA>Le:D0U[F00=Nme[FDY@00UJe00EJeUJeDYA6<CW>008mk`05
DYAS66<HHaQJeP06DY@015JeF]IF]E[F0eJe00QJeUkgHaQNme[FE[EJeUkg
0U[F0U:D0U[F0eJe0e[F0UJe0e[F00AF]E:DE[EF]@=Nm`AJeP05DYAF]E:D
E[EJeP02E[D2F]H2E[D2DY@2F]H00ekgHaQJeP02E[D01E:DF]IJeUJeG_L0
1U[F0UJe00=JeUkgF]H00U[F00ANmf<HG_MS609Nm`03HaQNmekg009F]@03
F]IF]Ekg00=Nm`9JeP03G_MW>F<H009Nm`EJeP9S6003IcUS66<H009W>@03
HaQJeUkg00ES600:F]INmf<HHaQW>F<HF]INme[FG_L4HaP2G_L01U[FG_MN
mekgHaQF]@9JeP03G_MS66Li00AS609W>@03JeYS66<H00MNm`05HaQW>F<H
IcUS6003IcT00f<HIcUS6002IcT2HaP2G_L2HaP00f]JIcUS6002HaP3IcT3
HaP00ekgHaQS6002G_L016<HG_MS65kg1F<H00=W>F]JJeX00VLi0f<H00aW
>F]JJeYW>F<HG_MJeV<HG_MW>F]JIcT2HaP01EkgHaQW>F]JHaP00VLi0f]J
00=W>F]JIcT00V]J00AW>F<HIcU[FP9W>@05HaQ[FV]JJeYS6002G_L3HaP0
15kgF]INmekg0V<H00ANmf<HHaQS60ENm`9S6008G_MS65kgHaQNme[FHaQF
]@52400000D000@Q12448@0000<48@0;24848@@Q36=247ooIcTicU:DF]IF
]@02DY@015JeBU9:DTYB0e:D0UJe0U[F00AF]E:DCW=>L`=F]@03DYA>Ldic
00MBU0=:DP0:CW=F]DicCW=:DTicE[E>LeJeF]H2E[D014YBAS5:DTHa0dYB
00ABU4icE[EBU09>L`04BU9>LdicCW<2AS400dYBAS5:DP04CW<00dYBAS56
<@02CW<3BU800dicDYA>L`03CW<00dYBCW=>L`02CW<2BU800dicBU9>L`02
BU82CW<02U:DCW=BU5:DF]INme[FDYA>LdYB1E:D00=:DTicBU800THa0dYB
0dHa00I>Le:DAS56<Cg_@Q04DY@014icBU9>Ldic0U:D00I>LeJeF]IF]E:D
CW<3DY@00dicDYA>L`02BU82CW<015:DBU9>LdYB0U:D00A>Le:DBU9>L`9:
DP96<@9:DP04CW=:DTicBU82CW<02TYBAS5:DTicDYA>Le:DCW=BU4ic0e:D
00=F]E:DDY@00U:D00EF]E[FF]IF]E:D0096<@E:DP03DYAJeU[F00=F]@9B
U0=>L`=BU004CW=BU5JeE[D2DY@3E[D01DicBU9BU5JeF]H00U:D00=>Le:D
E[D00U:D00=:DT8@BU800Tic00ABU4YBAS5:DP9>L`03DYA>Le:D00=JeP03
DYA:DTYB009>L`ABU0=>L`9F]@9>L`07BU9>LeJeDYAF]E:DCW<01E:D00AF
]E[FE[EJeP9F]@03DYA>Le:D009F]@05F]IF]E:DDYAF]@04F]H3E[D01E[F
DYABU48@>Lh00T8@00EBU6<HIcUS65[F009>L`=BU09F]@9JeP08E[EJeU:D
DYAJeUkgHaQNm`9F]@9JeP03G_MF]E:D00=F]@08F]IF]EJeE[EJeUJeF]IF
]@=JeP04E[EBU5:DF]H2G_L00e[FE[ENm`02F]H2DY@2E[D015[FE[EJeUJe
0e[F00ABU5JeE[EJeP9Nm`04F]IF]E:DDY@3F]H01EJeG_MJeU[FE[D00U[F
00AF]E:DF]INm`=JeP04G_MS66<HG_L2HaP00fLiG_MJeP02E[D3F]H2G_L3
F]H3HaP01U[FG_MJeU[FG_MJeP9Nm`05HaQW>F<HHaQW>@02HaP2G_L5HaP0
15kgF]INmfLi0V<H00=Nme[FG_L00Ukg0V<H00=Nmf<HF]H01Ekg00IJeUJe
F]INmf<HIcT2HaP5IcT2HaP01EkgF]INmekgHaP00Ukg0V<H00=W>F<HIcT0
0VLi00IS66LiHaQW>F<HIcT2HaP015kgHaQS66<H0fLi0f<H0fLi16<H00QN
mf<HG_MNmf<HG_MS66Li16<H00EW>F]JIcU[FVLi00AS609[FP05IcUS65[F
F]INm`02HaP00fLiJeYS6002G_L00f<HJeYW>@05IcT2JeX00fLiJeY[FP05
IcT00f]JHaQW>@03JeX02V<HG_MJeV<HIcUS65kgF]INmf<H0ekg0f<H0Ukg
0U[F0ekg00=S65kgHaP015kg0EJe0D8@000212400`0012448@0312403@Q2
12448@aS@Q1oof]J>Li:DUJeCW=BU5Je009BU003CW=:DTic00=BU003E[EJ
eUkg009F]@=:DP04CW=BU5:DDY@4CW<00e:DCW=BU002CW<4BU801E:DCW=B
U5:DCW<00UJe00AJeUJeE[E>L`=6<@07BU9>LdicDYAF]DicDY@00TYB0dic
00QBU4YBCW=:DTHa@Q16<DYB0U:D0TYB00A6<DYBDYABU0A>L`=BU003BU9>
Ldic00=>L`=:DP=>L`03BU9>Ldic009>L`=F]@06F]IF]E:DDYA>Le:D0UJe
0U:D0TYB00E>Le:DDYA>LdHa009:DP96<@04BU9>LdicBU82@Q001THaCW=B
U4icAS5>L`9BU004CW=:DTYBCW<2DY@2BU82DY@01DicBU9>Le:DCW<014YB
0Tic0e:D00=F]E:DDY@01TYB00=>LdYBBU801TYB00Q>Le:DCW=>LdYBCW=:
DTic0TYB0U:D0UJe0Tic00=BU4icCW<00TYB00=>LdYBCW<00TYB00=6<DYB
CW<00UJe00IBU5JeDYABU4icBU84CW<01DYBDYAF]E[FE[D00U:D00AJeUJe
DYABU09>L`9F]@03F]IBU5:D009BU004E[EBU5:DAS42BU83CW<2BU800dic
BU9>L`02DY@00eJeDYABU003CW<014YBCW=BU5Je0U:D0Tic0U:D00AF]Dic
CW=>L`9BU009E[E>Le:DDYA>Le:DCW=BU5Je00=BU004E[ENme[FE[D2DY@2
E[D01U:DE[EBU5:DCW=BU0IF]@08F]I:DTHa?NlicT8@BU9BU0=S6004F]IB
U5:DDY@2E[D2DY@015JeG_MJeUJe0U:D00EF]E[FG_MNmeJe009JeP04E[EJ
eU[FF]H2E[D00e:DE[EF]@02F]H00eJeF]IF]@04F]H01eJeDYAF]E[FE[EJ
eUJe009JeP0?E[E>Le:DE[EJeUJeDYAF]E[FG_MJeUJeDYAF]E[F009Nm`03
E[ENmekg009F]@9BU09F]@03G_MJeU[F00AJeP=F]@04G_MJeU[FF]H2G_L0
2f<HG_MJeUkgIcU[FVLiF]IBU5JeF]H00Ukg0U[F0V<H0U[F0Ukg0U[F00=F
]EkgG_L00V<H0U[F0Ukg0V<H0Ukg0V<H00=W>F<HF]H00ekg00=S65kgG_L0
0Ukg00MS65kgG_MNmf<HIcUS6002G_L00e[FG_MNm`04F]H2G_L016<HIcU[
FV]J1f<H0Ukg00EJeV<HHaQS65kg009S6004IcUS66<HIcT2JeX00f<HIcUS
6003IcT00f<HG_MJeP02G_L01FLiHaQS66<HG_L01V<H0ekg0f<H00AJeUkg
HaQS60IW>@04JeYS66LiHaP2IcT00f<HIcU[FP02IcT5HaP2IcT00f<HG_MN
m`04IcT2JeX00fLiJeYW>@03JeX016LiJeYW>F<H0fLi0V<H00MW>F]JIcUW
>EkgHaQNm`02HaP2G_L2HaP2G_L2HaP01EkgHaQS65kgHaP01Ekg00MS65kg
G_MNme[FHaQF]@01@Q000003124000@Q00848@0<00048@@Q24848@0036=6
<GooJeXicTYB1U:D00E>LdYBCW=>Le:D009F]@9JeP04E[EBU4icBU82CW<2
DY@3CW<015:DCW=BU5:D0dic0dYB00E>Le:DDYABU4ic009BU009E[EJeUJe
E[E:DTHaBU9244Ha009:DP9BU003E[E>LdYB009:DP04CW=BU4icCW<2BU80
148@AS5:DTYB0U:D00E:DTHaAS5:DU:D00A>L`03DYA>Le:D00A>L`9BU0=:
DP03CW=:DTic00A:DP9>L`04DYAJeU[FF]H6DY@01EJeDYABU4icBU800dic
0dYB0dHa00M:DTicCW=:DT8@?Nm:DP02DY@00dYBAS5:DP02DY@01TicBU9>
Le:DE[E>L`9:DP9BU0E>L`9:DP9>L`07BU9>LdicDYAF]E:DE[D00Tic00E:
DTHaBU9:DTic009:DP03AS5:DTYB00A:DP07DYA>LdicCW=:DTicBU800Tic
00E:DU:DF]IF]E:D009>L`9BU003CW=:DTic00=:DP05CW=:DTHaBU9>L`02
E[D3DY@7CW<01dYBCW=BU5[FE[E>Le:D00=F]@04CW=:DU:DDY@2E[D3DY@2
E[D015:DBU9:DTHa0TYB0Tic14YB00A>Le:DE[EF]@=BU09>L`9:DP03CW=B
U5:D009BU09>L`04E[EBU4icBU82CW<015JeDYABU5:D0dic15:D00=>Le:D
E[D00U[F00AF]E:DDYABU0AF]@9>L`04DYAF]E[FDY@3E[D03U[FBU96<Cg_
>Li6<DYBDYAS66LiHaQJeTicDY@2E[D3DY@015JeG_MJeUJe0U:D00=JeUkg
G_L00e[F0UJe0e[F00EF]E:DDYAF]E[F009F]@06F]IF]EJeE[EJeUkg0UJe
00=BU5JeF]H01E[F15:D00AJeUJeDYAF]@=JeP05E[EBU5JeF]INm`02F]H0
1EkgF]IJeUJeDY@00UJe0U[F00ANme[FF]IF]@9JeP03DYAF]E[F009Nm`08
F]IF]E[FHaQNmf<HF]IS60=W>@04F]IF]E:DF]H2G_L00e[FG_MS6002G_L2
F]H2G_L3F]H02EkgHaQNmekgF]IF]F<HIcUS6003G_L2HaP3G_L00e[FG_MS
6004G_L016<HG_MJeUkg0f<H00ENme[FG_MNmf<H009Nm`9JeP9Nm`EW>@IS
6004G_MJeUkgG_L2HaP015kgHaQW>FLi0V<H0VLi00A[FVLiHaQS60=W>@04
HaQNmekgG_L7HaP015kgHaQS66<H0ekg0f<H0Ukg00=JeUkgHaP00VLi00AS
66LiIcU[FP=W>@9S60=W>@05JeYW>FLiHaQNm`02HaP00fLiHaQW>@04HaP3
IcT3JeX00fLiJeYW>@02JeX00fLiJeYS6002IcT016<HIcUW>F<H16Li00AS
65kgG_MS60ENm`03HaQNmekg00=S6004G_MS65kgHaP5G_L00f<HG_MNm`02
G_L1F]H1>Lh0000500048@@Q1240000312402`Q212448@aS?Nmoofmk?Nm>
LeJeDY@00eJe00UBU5JeCW=:DTicDYAF]E:DCW<00e:D0TYB0THa00=>Le:D
DY@00Tic00A:DTicBU9:DP9>L`03DYA>LdYB009:DP04DYAF]E:DDY@2BU82
E[D015[FE[E>Ldic14YB0U:D0Tic0U:D00E>LdYB@Q16<DYB009>L`0;DYA6
<DHaAS5244icDYA>LdYBAS5:DP05DY@00dicDYA>L`04CW<2BU82CW<2BU82
DY@014icBU96<Dic0TYB00=>LdYBCW<01E:D00=>Le:DE[D00dic0U:D00A>
LdYBBU9:DP9>L`04AS52448@AS42BU82AS400d8@AS5:DP03AS400dicBU9:
DP02BU83CW<2BU800dicDYA>L`03BU8014HaBU9:DTHa14ic00ABU5JeF]IF
]@9BU004CW=BU4icCW<2BU82CW<00dYBCW=BU002DY@014icBU9>Le:D0dic
0dYB00=6<DYBCW<00Tic00=:DTicBU801dYB00=>LdYBAS400THa0Tic0e:D
00=:DTicBU8014ic0U:D0UJe0U:D00IF]E[FF]IBU5JeF]H2DY@01dicE[EB
U5:DCW=BU5Je009BU09:DP04CW=BU4icCW<2AS42BU800dicDYABU004CW<0
0e:DCW=:DP03CW<2DY@01DicDYABU4icDY@00Tic0TYB0dic0U:D0Tic00AB
U5[FE[EF]@9BU003E[EBU5:D00AF]@9BU004CW=BU5:DDY@2CW<015:DE[EJ
eU[F0UJe00E:DT8@?NlmkdYB009>L`=F]@05F]IBU5:DDYAF]@03DY@01EJe
F]IJeU[FDY@00eJe0Ukg00IJeUJeE[EBU5JeF]H2E[D00e:DE[EJeP02F]H0
1UJeDYAF]E[FG_MJeP9BU003E[EBU5:D009F]@08F]IF]E[FF]IF]DicDYAF
]@AJeP=Nm`03E[EBU5Je009Nm`9F]@=JeP03E[EBU5:D00=JeP=F]@03F]IF
]EJe009Nm`03HaQJeU[F00EJeP=Nm`04HaQW>FLiG_L3E[D2G_L01U[FG_MS
65kgF]IF]@9Nm`9JeP03E[EJeUkg009Nm`03E[EJeUkg009Nm`05F]INmekg
G_MS6002G_L2F]H5G_L2HaP2G_L00e[FG_MS6002IcT00ekgF]IJeP03F]H2
G_L5HaP016LiHaQS65[F1f<H00=Nmf<HHaP00f<H0VLi00=S66LiIcT026Li
00=S65kgG_L015kg0VLi0V<H00=Nmf<HIcT00V<H0Ukg0f<H00=W>EkgG_L0
0V<H00EW>F]JIcUW>F]J009W>@05HaQW>F]JIcUS6006IcT016<HIcUW>F<H
16Li0V<H0VLi00I[FVLiIcUW>F]JIcT2JeX3IcT3HaP2IcT016<HIcUS66<H
16Li0Ukg00=S65kgHaP00ekg00IS65kgG_MNmf<HG_L2HaP3G_L02F<HG_MS
66<HG_MS65kgHaQF]@01?Nl000<48@0300048@@Q00848@0924848@@Q36=2
47ooKg/mkdYB009BU09F]@03DYAF]Dic009:DP03CW=BU5:D009>L`05E[EB
U5JeCW=24002AS400dicDYABU002CW<01TYBCW=:DTYBCW=BU09>L`03BU96
<Dic00ABU003CW=:DU:D009JeP04E[E>LdYBCW<2BU800dicDYABU002CW<0
0e:DCW=BU004AS401dicDYA>LdYBAS5244Ha00=>L`=:DP03CW=F]E:D009B
U0I>L`=:DP04CW=BU4YBBU82DY@01DicBU96<DHaCW<00TYB0Tic00MBU5Je
DYABU4icDYAF]@02DY@00dYBCW=BU002DY@01DYBCW=>Le:DCW<00d8@00=6
<DicBU800THa00=244HaAS400THa0TYB00M>LdYBBU9:DTicDYA>L`02BU82
CW<00e:DBU9:DP03BU82AS401DYBCW=BU4icDY@00UJe00IJeU:DCW=>LdYB
CW<2BU801DicBU9:DTYBCW<00U:D00U>LdYBCW=BU4icDYA>LdYBCW<00TYB
00=6<DYBCW<00U:D0TYB0Tic1DYB0Tic00M:DTHaAS5:DTicDYA>L`02DY@0
0dicBU9:DP03CW<01E:DCW=BU5JeF]H00e:D00EJeUJeE[EBU5Je009BU003
CW=BU5:D00=BU09F]@03DYA:DTYB00=BU003BU8mkdHa009:DP04CW=BU5:D
DY@2CW<00e:DCW=>L`02BU82CW<00e:DCW=BU004CW<01U:DCW=:DTicBU9>
L`=BU09>L`03E[EJeUJe00=BU0=F]@9BU003F]IF]E:D00ABU0=>L`9F]@9J
eP03DYAF]DHa00924005?Nm:DTYBCW=F]@02F]H015JeDYABU5Je15:D00=F
]E[FF]H015Je0U[F00ANme[FG_MF]@9BU004E[EJeUJeDY@2E[D01EkgF]IB
U5:DE[D00e[F00ABU5JeDYABU0=F]@AJeP9BU003CW=F]E[F00=JeP06G_MJ
eUkgE[EBU5Je0Ukg0UJe00AJeUkgF]IF]@9BU005F]INme[FE[EBU005F]H0
0f<HG_MJeP03F]H01UJeF]INmekgF]INm`=S6006G_MF]EJeE[EJeUkg0U[F
00=S65kgE[D00U[F00MS65kgE[EF]E[FG_MS6003F]H4G_L00e[FG_MS6002
G_L3F]H01UkgHaQNmekgF]INm`9S6006G_MJeUkgHaQ[FV<H0e[F00=Nme[F
F]H00Ukg0V<H00=Nmf<HIcT00VLi00ES65kgG_MS65kg00AS6003G_MS66Li
00=S6003IcUS66Li00=W>@03JeYW>FLi00EW>@9Nm`9JeP=S6004IcUS65kg
G_L2HaP01FLiG_MNmf<HG_L00f<H00ENmf<HG_MS66]J009W>@05JeYW>FLi
HaQW>@03JeX01fLiHaQS66LiJeYW>F<H009W>@04HaQW>FLiIcT4HaP016Li
JeYW>F]J0VLi00Q[FVLiJeYW>F]JIcUS66Li0V<H00AW>F<HIcUW>@9S609W
>@03HaQW>Ekg009Nm`=S60=Nm`04HaQNmekgG_L4HaP01EkgHaQNmekgHaP0
0ekg00=S65kgF]H00CW>00000`001240000312402`002488@P@Q000<Hcg_
OomcW48@CW<00U:D00EF]E[FF]IF]E[F00A>L`03DYA>Ldic00=>L`9:DP03
AS5:DTic009BU004CW=BU5:DDY@4CW<015:DCW=BU4ic0e:D00=F]DicCW<0
0U:D00AF]E:DDYA>L`9:DP03AS5:DTYB00=:DP=>L`0:DYA:DTHa@Q16<Dic
DYA>LdYBCW<3BU801e:DCW=>LdHaBU9>Le:D009F]@=BU0=:DP06DYA>LdYB
AS5:DTic0TYB0Tic00=BU4YBAS400THa0dYB0Tic00=BU5JeDY@00U:D00I>
Le:DCW=:DTicDY@2CW<2AS43BU801D8@AS5244YBAS400dYB00I6<D8@AS56
<DYBCW<3BU82CW<01U:DCW=:DTYBCW=:DP9>L`07BU96<DHa?Nm244HaBU80
0Tic00=BU4icCW<00U:D0Tic00=BU5JeDY@00Tic0U:D00EF]DicCW=6<DYB
00EBU003CW=BU4YB009>L`9BU004BU96<DYBCW<2DY@3BU800dicBU96<@02
AS44BU82AS42BU82CW<2DY@4CW<00e:DCW=BU002CW<4DY@2E[D01e:DF]IJ
eUJeDYA:DTic009F]@07F]IBU4icCW=F]E:DCW<01DYB00E244HaAS5BU5Je
00=BU0A>L`03DYA>Le:D00=BU0A>L`05DYA>LdicBU96<@02CW<2DY@014ic
BU9BU5:D0UJe0e:D00=>Le:DCW<00e:D0UJe0U:D00=F]E:DE[D00dic00=F
]E[FF]H00U:D00E6<CW>>Li244ic009BU09>L`05DYAJeUJeE[E>L`03DY@0
15JeDYABU5Je0U[F00=F]E:DE[D00ekg00=JeU:DDY@015:D0UJe00=JeUJe
DY@00UJe15[F0UJe00YJeU:DCW=F]E[FG_MJeUJeDYAF]@=JeP03E[EJeU[F
00=JeP03E[EJeU[F009F]@09DYAF]EJeF]INme[FE[EBU5[F00=F]@03F]IF
]EJe009F]@9JeP=Nm`AJeP03E[EJeUJe009F]@03F]IS66Li009S6004F]IB
U5JeF]H2G_L2F]H00ekgF]INm`03F]H3G_L3F]H2G_L2F]H015JeF]INme[F
0Ukg00ES65kgG_MJeUkg009JeP9S6003IcUS65kg009Nm`04HaQNmf<HG_L2
F]H015JeF]INmekg0V<H00ANmf<HG_MS60ANm`03IcUS66Li009W>@03HaQW
>F<H009S60=W>@04HaQW>FLiHaP2IcT00f<HIcUS6002IcT4HaP01FLiG_MN
me[FHaP00VLi16<H0fLi1F<H00=W>F<HHaP00V<H00=W>F]JHaP00V<H00=N
mfLiJeX00f]J0fLi00=[FVLiJeX01fLi00=[FVLiHaP00f<H00QW>F]JIcU[
FVLiJeYW>F]J0fLi0Ukg0V<H00=W>F<HHaP00V<H00AW>F<HIcUS60=Nm`9S
6005IcUNme[FHaQNm`02HaP015kgHaQNmf<H0ekg0V<H00MNmf<HG_MNme[F
HaQJeP01?Nl000@48@0500048@@Q1248@P0212401PQ2?NmoogNm@Q1>L`9B
U09JeP03E[EJeUJe009>L`06BU9BU4icCW=:DTic0U:D00=>LdYBBU800TYB
0Tic0U:D1Tic00=BU4icCW<00Tic00=BU5JeDY@015:D00AF]E:DDYA>L`Y:
DP06CW=BU4YB@Q0mkdHa1Dic0THa00A:DU:DDYA>L`96<@05CW=BU5JeF]IB
U003CW<014YBCW=>Ldic0TYB00I6<DicBU9:DTicDY@2CW<0148@AS56<DHa
0dYB0U:D00=F]E:DCW<00U:D0dic00E:DTicDYA:DTHa00=:DP05AS52448@
@Q16<@02BU800dHaBU96<@02@Q000dHaCW=:DP04BU82DY@014icBU9:DTYB
0dic0TYB1DHa00M>Le:DCW=>LdYBDYAF]@02CW<3DY@3CW<015:DE[E>Ldic
0TYB00=>Le:DDY@00Tic00IBU4icCW=:DTicE[D2CW<2AS44CW<2BU82CW<0
1DYBAS5:DTYBAS401DYB00=6<DicCW<00Tic00EBU4icBU9:DTic00QBU0AF
]@03F]IBU4ic009>L`05F]INmeJeDYA>L`03DY@00dicBU9:DP02BU84AS44
DY@00dicBU9>L`05CW<4DY@014icBU9>Le:D0Tic00=6<DYBBU800Tic0U:D
0Tic00=BU5[FE[D00U:D00AF]E:DCW=>L`=BU006E[EBU5:DE[EBU5Je0U:D
00=:DU:DE[D00U[F00=BU5JeAS400SW>00A244icE[EBU09>L`07DYAF]EJe
E[E>Le:DE[D00U:D00=>Le:DF]H00U[F00MF]E:DDYANmf<HG_MJeP04DY@0
1EJeDYABU5JeF]H015Je0e[F00EF]E:DE[EF]Dic009BU003F]INme[F009F
]@06DYAF]E[FE[EJeUJe0U[F00AF]E[FG_MJeP9F]@04DYAF]EJeE[D2F]H6
E[D015[FE[EJeU[F0UJe00AJeUkgHaQNm`9JeP04G_MF]E[FE[D2F]H2E[D0
1e[FG_MW>F<HG_MJeU:D009F]@9Nm`=JeP03G_MJeU[F009JeP9Nm`AJeP9N
m`AJeP0;G_MJeUkgG_MS65[FG_MJeUkgF]INm`04HaP4G_L00f<HG_MNm`03
F]H00eJeF]IS6002HaP4G_L01f<HF]INmekgHaQW>F<H00AW>@04HaQNmf<H
HaP4IcT04F<HIcUW>F<HIcUS66LiHaQW>F<HIcUS66LiHaQNme[FG_L00V<H
00=W>F<HHaP00V<H0fLi16<H0VLi00AS65kgG_MS609[FP03IcUS66<H009S
609[FP03Kg][FV<H00=W>@9[FPAW>@03HaQW>FLi009W>@AS609W>@=[FP9W
>@9[FP9S6003G_MS66<H009S6003IcUS66<H009S6003IcUS66<H009Nm`04
HaQW>F<HHaP4G_L3HaP00ekgHaQNm`02G_L016<HG_MS66<H15kg0F<H0EJe
0Cg_00000`0012448@021240100012448@Q20P@Q00L<Hd8@Oom_Ncg_DYAF
]@02DY@015JeF]INme[F0U:D0Tic00ABU4icCW=>L`I:DP=>L`9BU004E[EB
U4YBBU82AS4014icDYABU5:D0dic1U:D0Tic00E6<D8@AS5244Ha009:DP06
CW=BU4icCW=:DTic0TYB00=6<DYBBU800dic00=BU4icBU801DYB00A6<DYB
DYAF]@ABU003CW=:DTHa009:DP05CW=:DTicBU9>L`02DY@01DicDYABU4ic
BU800T8@00A:DTicDYAF]@9BU003E[EBU5:D00E>L`96<@=:DP96<@03BU96
<DYB00=:DP03@Q16<DYB009:DP04AS5:DTYBAS43BU800e:DCW=BU002CW<4
BU82CW<014YBAS5244Ha0TYB00I>Le:DCW=BU4icDY@2CW<00dYBDYABU003
CW<3DY@4CW<2DY@2CW<2BU800dicBU9:DP02CW<03e:DCW=:DTHaBU9>Le:D
BU96<DicDYA>LdHa@Q16<@02BU8014HaBU9:DTYB0dHa00A:DTicE[EBU09:
DP06CW=BU5:DCW=6<DYB0Tic0e:D0Tic00=BU5JeE[D00U:D00A>LeJeF]IJ
eP=BU008E[EBU5:DCW=:DTicDYA>L`=:DP06CW=BU5:DF]IF]E:D0TYB00=>
Le:DDY@00U:D00=>Le:DCW<00Tic00=BU4icDY@00Tic00=:DTicCW<00U:D
00A>Le:DCW=>L`EBU09F]@=>L`06DYAF]E[FF]IF]E[F0UJe00A>Le:DE[EB
U09F]@9>L`8mk`04@Q16<DicDY@2CW<2DY@00eJeDYABU002CW<01U:DE[EB
U5:DCW=BU09JePEF]@9JeP9F]@05DYAF]EJeF]IF]@02F]H3DY@025[FG_MJ
eU:DE[EJeUJeF]H3E[D00e[FE[EJeP02E[D4F]H00eJeF]IJeP02E[D01U[F
G_MNme[FDYAF]@AJePAF]@0=F]IF]EJeF]IS65kgF]IBU5JeF]IF]E[FG_L0
0V<H00=Nme[FF]H00U[F00UF]E[FE[E>LekgHaQ[FVLiF]H00UJe00=JeUJe
F]H00UJe0U[F0ekg00=S65kgG_L00U[F00EF]E[FF]IF]E[F00=Nm`9JeP04
G_MS66<HHaP3F]H01F<HG_MS66<HG_L00f<H0U[F0Ukg00ES65kgF]IF]E[F
009Nm`=S609Nm`=JeP=S609W>@03HaQW>FLi009W>@07JeYW>F]JJeYW>F]J
HaP01FLi00AS65kgHaQS60AW>@ES6004IcUS66LiIcT4HaP3IcT6HaP00ekg
HaQS6005IcT00f]JIcU[FP03JeX2IcT00f]JIcU[FP03IcT00f<HIcU[FP02
IcT00f]JHaQS6002G_L00f<HIcUW>@02JeX5IcT01f<HF]INmekgIcUS66Li
00AS609Nm`9S60MNm`9S6005G_MS66<HHaQW>@02HaP01UkgHaQS66LiHaQN
m`9JeP9Nm`5JeP52400000@48@00124000@48@09248000@Q36<mkgooLia2
44ic009BU09F]@=JeP03E[E>Ldic009BU0A:DP9>L`=:DP9>L`03BU9BU5Je
009BU09:DP07AS5:DU:DCW=BU4icDY@00Tic15:D00I>Le:DDYA>LdYBAS42
@Q0014HaBU9:DU:D0dic0dYB00=6<DYBAS400dic00=BU4icBU8014YB00M>
LdHa@Q1:DU:DF]IBU002CW<2DY@7BU82CW<02E:DCW=BU5:DE[E>LdHa?Nm2
4002BU87DY@024icBU9>Le:DBU96<D8@AS42CW<5AS400dYBCW=6<@02@Q00
0dHaCW=6<@02AS44BU801dicDYABU4icDYA:DTic00=:DP03CW=:DTYB0092
4003AS5:DTYB00=BU0=>L`05DYA>LdYBCW=F]@03CW<01E:DE[EF]E:DCW<0
0TYB00A>LeJeDYA>L`9:DP9>L`9:DP09DYA>Le:DBU96<DYBCW=BU4ic009:
DP03CW=:DTHa0096<@03BU96<DYB00A:DP03AS5244YB00=BU003CW=:DTYB
009BU00<CW=6<DHaCW=BU4icDYA>Le:DCW=BU5Je0U:D00E>Le:DF]IJeUJe
00ABU00;E[EBU4YBBU9>Le:DCW=:DTHaBU9>L`02DY@2F]H00e:DCW=:DP02
CW<3DY@2CW<00dYBCW=BU005CW<2BU83DY@2CW<015:DCW=>Ldic1U:D00=:
DTicDY@00U[F00IF]E[FF]IF]E:DCW<3DY@015JeF]I>LdHa0Sg_00=:DTHa
CW<00e:D00=>Le:DDY@00U:D0Tic0U:D00EF]E:DDYABU5Je009JeP0:DYAF
]EJeF]IF]E[FE[EBU5JeDY@4E[D015[FDYA>LeJe0e[F1EJe00EBU5JeE[EF
]E[F00AF]@04F]IF]E[FE[D2F]H2E[D01e[FG_MNme[FE[EBU5Je00AJeP0<
DYAF]E:DE[EJeUJeG_MS65kgF]IBU5Je0e[F00=Nmf<HG_L00Ukg0e[F0UJe
0U:D00EJeV<HJeYW>E[F00=F]@9JeP=F]@9JeP03G_MS65kg009Nm`08F]IF
]EJeG_MJeUJeF]IF]@9Nm`9JeP04G_MS66<HHaP3F]H015kgHaQW>Ekg0f<H
00ANme[FF]IJeP9S6004F]IF]E:DF]H2HaP015kgHaQNmf<H0U[F00=Nme[F
HaP00V<H00=W>F<HIcT01FLi0V]J26Li16<H00INmfLiIcUW>F<HIcT5HaP0
1VLiHaQW>F<HIcUS60AW>@IS6005G_MS66LiIcU[FP02IcT2HaP2JeX01Fmk
JeYW>F]JIcT00V]J00=W>F]JIcT00f<H16Li0V<H00INmf<HIcUS66]JIcT2
JeX4IcT00f<HG_MNm`02HaP00fLiHaQS6003HaP01UkgHaQS65kgF]INm`9S
6005G_MJeUkgHaQNm`03HaP01VLiHaQS65kgHaQNm`9S60=Nm`9JeP5S605J
eP52400010@Q00D000@Q12448@Q200848@0836=6<GooKg/mkdicDYA>L`9B
U005E[ENme[FF]IF]@03DY@01TicBU9>LdicBU96<@A:DP03CW=:DU:D00=B
U096<@9:DP04CW=F]E:DCW<3BU82DY@2E[D2DY@00dicDYA>L`02BU8014Ha
BU9>LdYB0e:D00A>LdYBBU9>L`A:DP9>L`9BU0=:DP05DYA>LdYBBU96<@02
BU800dicDYA>L`02DY@01TicBU96<DYBCW=:DP9>L`9BU0=>L`9BU004CW=:
DTHaBU82DY@00dicDYABU003DY@01DicBU9:DTYBCW<014Ha00U>LdYBBU92
44Ha@Q1:DTHa@Q000TYB0Tic0d8@00E6<DicBU9:DTic009BU003CW=BU5:D
009BU0=:DP05CW=BU4YBAS524003BU8024icDYABU4icDYAF]DicBU84CW<0
14YBDYABU5:D0dYB00=BU4icCW<00dYB00=6<DYBDY@01Dic00A:DTHaAS5:
DP9>L`05DYA:DTicCW=:DP02AS4024icBU9:DT8@AS5:DU:DCW<2@Q001TYB
DYAF]DicAS5:DP=>L`03BU96<DYB009:DPA>L`9BU003CW=BU5Je009BU09>
L`9F]@9BU09:DP04CW=BU4icBU82CW<00dYBCW=:DP02CW<015:DE[EBU5:D
0Tic00=:DTicBU8015:D14ic00=BU4icCW<00dYB1Dic00=BU4icCW<00e:D
0dic15:D00=F]E[FF]H00UJe00=BU5JeE[D00UJe0U:D00IF]DicBU9244Ha
DY@2E[D2DY@00dicDYABU002DY@00dYBCW=>L`02E[D2DY@2CW<01EJeF]IJ
eUkgF]H00U:D00IF]E[FG_MJeU:DE[D2F]H00ekgF]IF]@03DY@01EJeF]IF
]EJeF]H00UJe00MBU5JeF]IJeUJeDYAF]@02F]H3E[D00e[FE[EF]@03E[D0
0ekgHaQNm`05F]H2E[D025:DE[EJeUJeF]IBU5JeG_L2HaP00ekgDYAF]@04
F]H2G_L01F<HG_MNme[FG_L00UJe00MBU5JeF]INme[FHaQNm`02F]H00e:D
E[EF]@04F]H3G_L00f<HG_MJeP02F]H3E[D015[FE[EJeU[F15kg0V<H0Ukg
00AJeUkgHaQNm`9S6003G_MS65kg00=Nm`9S6004F]INmf<HG_L3F]H01Ukg
HaQNmf<HF]IF]@9JeP03G_MS66<H009W>@9[FP=W>@E[FP03IcUS66<H009S
609W>@ES60=W>@03HaQW>FLi00IS6004IcUS66<HHaP4IcT7HaP2IcT00f]J
IcUW>@04IcT3JeX01FLiJeYW>FLiJeX00VLi0V<H0fLi00=S66LiHaP00V<H
00IJeV<HIcUW>F]JIcT2HaP2IcT2HaP00ekgHaQS6003IcT016<HG_MS65kg
1F<H0e[F0Ukg00=S65kgHaP00f<H0VLi00=S65kgF]H00Ukg00QS65kgG_MJ
eUkgF]IS65[F0D8@000010@Q00048@000P@Q00`000Q224848@0036=247oo
Kg/mkdicDY@2CW<00e:DF]IJeP02F]H01EJeDYABU4icDY@00dYB00=6<DYB
BU8014YB00M>LeJeDYABU4icBU96<@02BU83DY@014icBU96<Dic0U:D00=F
]E:DDY@00Tic00EBU4icBU9:DTHa009:DP05CW=BU5:DDYA>L`02BU8014ic
BU9>LdYB0dic0U:D00=>LdYBBU800dic00I6<D8@AS5:DTicDY@2CW<00e:D
CW=:DP02BU83CW<3DY@3CW<01e:DE[E>LdHa@Q1:DU:D00=>L`ABU004CW=:
DTYBAS42BU82AS4014YBCW=>LdHa0d8@00Q:DTHa@Q16<DYBCW=:DTHa0T8@
00=6<DicBU800TYB1e:D00M:DTHaBU9:DTicBU924002AS42BU82CW<4DY@6
CW<01TYBDYAF]E:DBU96<@=>L`03BU9>Ldic0096<@08BU9>LdicCW=:DTic
BU9>L`96<@03BU9>Ldic00=:DP03CW=:DTHa00=:DP=6<@0:BU9>LdYBAS52
44HaDYAF]DicAS42BU82CW<014YBAS56<DYB1Dic00QBU4icCW=>Le:DE[EB
U4ic0U:D0UJe0Tic00E:DU:DCW=>LdYB00=>L`=:DP06CW=BU5:DE[EBU4ic
0dYB0Tic00EF]E:DDYA>LdYB009>L`03DYA>LdYB009:DP03CW=:DTYB009>
L`9BU0=>L`9BU09>L`9BU004CW=BU5:DF]H5E[D015:DE[EJeUJe0U:D00=J
eU:DAS400T8@00EBU5JeE[EF]E:D00=>L`04DYA>LdicCW<2DY@00eJeDYA>
L`03DY@4F]H2DY@00eJeF]IJeP02F]H015JeF]IJeU[F0UJe00A>Le:DE[EF
]@9JeP07DYAF]E[FDYAF]E:DF]H00eJe0e[F00=F]E[FE[D00UJe00UJeUJe
DYABU5[FHaQW>EkgE[D015[F0U:D0UJe00UJeUJeE[EBU5kgIcUS65[FDY@0
0e[F0UJe00QNmf<HG_MS65[FG_MJeUJe0e:D00]JeUkgG_MS65kgF]IF]E:D
E[EJeUJe00=JeP03G_MJeV<H009Nm`03F]IF]EJe009F]@03F]IF]E[F00=J
eP=Nm`9S609Nm`9JeP06G_MS66<HHaQNmf<H0Ukg00=JeUkgHaP00Ukg00AJ
eUkgF]INm`9JeP9Nm`03HaQNmekg009F]@03F]INmf<H009S60IW>@A[FP=W
>@03HaQW>F<H009W>@AS60AW>@=S609W>@=S6003IcUS66<H00=S60AW>@9S
609W>@=S6005JeYW>F]JIcUS6002IcT3JeX00fLiJeYW>@02IcT2JeX00fLi
HaQS6003IcT016<HIcUS66<H0Ukg00AS66LiIcUW>@9S60=W>@=S6003G_MS
66Li009W>@05HaQNmf<HHaQNm`04HaP02EkgF]IJeU[FG_MS65kgHaQNm`02
HaP2IcT2G_L2F]H2HaP3G_L2F]H1G_L1F]H1@Q00000300048@@Q00D48@0;
24848@@Q36=6<GooLi`mke:DE[E:DP02CW<00e:DE[EF]@03E[D00e:DE[EJ
eP02DY@01DHaBU9>LdicDY@00dYB1Dic0dYB00I6<DYBE[EJeU:DBU82AS40
14YBCW=F]E[F0U:D0TYB0U:D0Tic0dYB00ABU4icDYABU09>L`06BU9BU5:D
DYA>LdYB0Tic0TYB0dic00I:DTicBU9:DTHaBU83CW<015:DCW=BU5:D0TYB
0T8@00A:DTicDYABU09:DP04CW=F]EJeCW<2BU8014icE[EBU4ic0U:D00MF
]E:DCW=>LdYBCW=:DP0>AS401DYBCW=>LdYB@Q000dHa00E:DTicCW=>LdYB
009>L`ABU007CW=BU4YBBU96<DYBDY@00Tic14YB0U:D0Tic00A6<DicCW=>
L`9:DP=BU006CW=:DTYBCW=BU4YB0THa0dYB0THa00E244HaBU9:DTic009:
DP96<@03BU9>Ldic00=>L`06BU96<DHaBU9>LdYB0dHa00I:DTicBU96<DYB
CW<4BU800dicBU96<@02AS4034YBCW=:DTYBAS5:DTicE[EBU4YBCW=BU09>
L`9:DP=BU0A>L`04DYA>LdYBCW<2DY@5CW<2DY@01UJeF]I>Le:DBU96<@AB
U0I>L`03BU9>Le:D009:DP04AS5:DU:DDY@2CW<2BU801DicDYA>LdicBU80
0U:D0U[F00AF]E[FE[EBU09F]@03F]IBU5:D00ABU007@Q0mkd8@BU9JeUkg
E[D00U:D00=>Le:DE[D00e:D00I:DTicDYABU4icDY@2CW<025:DE[ENmekg
F]IBU4icE[D3G_L3E[D00e[FG_MJeP04DY@00eJeDYAF]@02F]H3E[D2F]H0
15JeDYABU5[F0Ukg00=JeUJeDY@015Je00EBU5JeE[EF]E[F00=Nm`08F]IF
]EJeE[EBU5[FE[EBU0AF]@9JeP03G_MF]EJe009F]@9Nm`07F]IS65kgHaQN
meJeF]H00eJe0U[F00UF]E[FF]IS65kgF]IBU5JeF]H00ekg00ABU5JeF]IJ
eP9Nm`AJeP9Nm`9JeP9F]@04F]INmekgG_L4F]H5G_L00fLiG_MS6002G_L0
0fLiHaQNm`04F]H01V<HF]IJeU[FE[EJeP9Nm`04F]INmekgF]H2G_L01V<H
IcU[FVLiJeYS60=[FPEW>@9S6004G_MS65kgHaP3G_L00f<HIcUW>@02HaP0
0fLiHaQW>@02HaP2G_L2HaP2IcT01f<HG_MS66<HIcUS66Li00=S609W>@9S
6006G_MW>FLiIcU[FVLi0V<H00=W>F]JJeX00fLi0V]J00=W>F<HIcT00VLi
16<H0VLi0V<H00=Nmf<HJeX01VLi00=S66LiHaP00V<H0VLi0f<H0ekg00AS
66LiHaQW>@ANm`=S6003G_MS65kg00=S6004G_MJeU[FF]H2G_L00f<HG_MJ
eP02G_L1HaP1E[D1?Nl000@48@0500048@@Q1248@P0212401`aS@Q1oofmk
?Nm>Le:D009>L`9BU0QF]@06DYA>LdHaBU9>Le:D0Tic0TYB00A>Le:DCW=>
L`A:DP0<AS5>Le:DF]IF]DYB@Q16<DicBU9F]E[F0U:D0TYB00=BU4icCW<0
0Tic0TYB00E>Le:DDYAF]Dic009:DP=BU003BU9>Le:D00A:DP03CW=:DTYB
009:DP96<@9:DP9>L`04DYA>LdicCW<2BU8014Ha@Q1:DTic0U:D00=>LdYB
CW<00e:D0TYB0e:D00=>Le:DDY@00U:D00=>LdYBCW<00TYB0THa00=244Ha
AS400TYB0dHa00A244Ha@Q16<@A:DP=6<@9:DP04CW=:DTYBDY@2CW<3DY@4
CW<00dHaBU9:DP02CW<4BU8014HaCW=F]Dic0TYB00E>Le:DBU96<DYB00=B
U003CW=:DTYB00=>L`03AS5:DTHa009:DPA6<@08BU9>LdYBCW=6<D8@BU96
<@E>L`96<@03BU9>Ldic009:DP05AS5:DTYBBU96<@02BU800dicBU9:DP03
BU8014icBU96<D8@1TYB0U:D00=>LdYBBU800U:D00=>LdYBBU800Tic0U:D
0Tic00EBU4icBU9>Le:D00A>L`03DYA>Ldic009BU00<F]IF]E:DCW=6<DYB
CW=BU5JeDYA>LdYB0dic0dYB00MBU4icBU96<DYBCW=BU003CW<01dYBCW=>
Le:DCW=:DTic009F]@=JePEF]@0@DYAF]E:DDYA>Le:D@Q0mkd8@AS5F]Ekg
DYAF]E:DCW<2DY@01UJeDYA>LdYBCW=BU0=>L`04DYA>LdicF]H2G_L02E[F
CW=>LeJeG_MS65kgF]IF]@02F]H015kgE[EBU5:D0UJe0U:D00=F]E[FF]H0
0eJe0e[F00=BU5JeE[D00Ukg15Je15:D0eJe0ekg0U[F0UJe00EBU5[FDYAB
U5Je009BU003E[EJeU[F00=JeP9F]@=JeP9Nm`9S6003G_MJeUJe00MF]@04
G_MS65kgF]H2E[D00e[FG_MNm`02F]H01eJeF]IJeU[FG_MJeUJe00AJeP05
G_MF]EJeE[EJeP04G_L01eJeF]INmekgHaQNme[F00=S60=Nm`03HaQW>F<H
009JeP03E[ENmekg009Nm`03E[EJeUkg009Nm`9JeP05G_MJeUkgG_MS6002
IcT00f]JIcUW>@04JeX4IcT016<HG_MS65kg0V<H0Ukg0V<H0fLi0V<H00AW
>F<HHaQS60=Nm`03HaQW>F<H00ES6003IcUS66Li009S6005IcUS66<HG_MS
6002IcT016]JIcUW>F<H16Li00A[FVLiJeY[FP=W>@9S609W>@=S609W>@03
HaQNmf<H00AW>@03HaQW>FLi009W>@0;HaQNmf<HHaQW>F<HIcUS65kgHaQN
m`03HaP00fLiHaQNm`03G_L016<HG_MNmf<H0Ukg0f<H00ANme[FF]IJePEN
m`04F]INmf<HF]H1?Nl00003124000@Q00848@0400048@@Q248212401`aS
?NmoogNm@Q1F]E:D009>L`04BU9BU4icE[D3F]H2DY@00e[FE[E>L`02CW<0
1E:DCW=:DTYBDY@00dYB00=>Le:DDY@00dYB00M244YBE[EJeUJeDYA6<@03
BU8014icE[EF]EJe0dic00=BU4icBU800TYB00E>Le:DCW=BU5Je009BU09>
L`03E[EBU4ic00=>L`08BU96<DYBCW=BU4icDYA:DPE>L`07DYA:DTicCW=B
U4icBU800dHa1Tic0e:D0Tic00ABU5JeCW=>L`=BU09>L`05DYA:DTicAS5:
DP03AS400dYBAS56<@02@Q001THa?Nlmkd8@BU9>L`E:DP06CW=:DTicCW=B
U4ic0TYB00=>Le:DDY@00U:D14ic0dYB00=>LdYBBU8014YB0U:D00=>LdHa
BU8014YB00I>Le:DCW=:DTHaBU82CW<2BU802THaBU96<DYBAS5:DT8@?Nm6
<DYB0Tic0dHa0TYB00=>Le:DCW<00TYB00A>LdYBBU96<@=:DP03AS52448@
00A6<@05BU9>Le:DCW=:DP02AS40148@AS56<DYB0dHa0TYB00=>LdYBBU80
0THa0dYB00=6<DYBCW<014ic00A:DTHaBU9:DP9BU003CW=:DTic009>L`05
BU9>LdicDYAF]@02DY@2BU83CW<015:DCW=BU5:D0TYB0THa0dic0dYB00IB
U4YBBU9:DTicBU82CW<3DY@2CW<2DY@2F]H01ekgF]IF]E:DE[EBU4ic009F
]@9>L`0:?Nle[Cg_DYANme[FDYA>Le[FE[D5DY@5CW<2E[D01TicBU9>LeJe
G_MJeP=F]@03F]INmekg009JeP=F]@=JeP05G_MF]E:DDYAF]@02F]H015Je
DYAF]EJe0U[F1EJe0e[F0UJe0e:D0UJe00=BU5JeF]H00VLi00=Nme[FE[D0
1EJe00=JeUJeDY@00U:D00=JeUkgG_L00eJe00ES65kgF]INme[F009Nm`9J
eP06E[EJeU[FF]IF]E:D0UJe00ENmf<HF]IJeUJe00=JeP05G_MBU5:DE[EB
U003F]H2G_L3F]H01EkgF]IF]EJeF]H00Ukg0e[F00AF]EkgG_MS60=Nm`9S
6003G_MJeV<H009Nm`0=F]IF]E[FHaQNmf<HG_MF]E[FE[EJeUkgHaP01Ukg
0V<H0VLi00=[FVLiIcT00VLi00=S66LiIcT016<H00=Nmf<HF]H00U[F00=N
mf<HHaP01F<H00=W>F<HHaP00ekg00AS65kgHaQS609Nm`=S609W>@=S6006
IcUS66<HHaQNmfLi0V]J0VLi00=S66LiIcT00V]J1VLi00=S66LiHaP00VLi
00=S66LiIcT00VLi00AS66LiHaQW>@A[FP04IcUS66<HHaP3IcT00ekgHaQN
m`03HaP3G_L016<HIcUW>FLi0V<H00=Nmf<HG_L00V<H00ENmf<HHaQNme[F
009Nm`AJeP9Nm`9JeP04G_MJeVLiF]H1AS40000400048@@Q000212402P00
2488@P001248@T8@OomcW4Ha0U:D00=>LdYBCW<00e:D00UF]E[FF]IBU5Je
F]IF]E:DBU800dic0TYB0Tic00=:DTicBU800U:D00I:DTicAS56<DYBDY@2
F]H01DicBU9:DTYBAS4015:D14ic00ABU4icCW=:DP9>L`9BU004E[EBU4ic
CW<2DY@01DicBU9>Le:DBU800THa00E:DU:DCW=BU4ic00=:DPE>L`05BU9>
Le:DCW=:DP02AS42BU83CW<024YBDYABU5:DCW=:DU:DE[D2DY@2CW<01EJe
DYA>LdicBU800Tic0TYB0THa00=:DTHaBU800T8@00I6<D8@@Q0mkd8@AS42
BU8014HaBU9:DTic0dYB0dic0TYB00=>LeJeDY@00U:D0dic0dYB00=>LdYB
CW<00dYB00Q6<E:DDYA>LdYBAS5:DTic0dYB00ABU4icBU96<@9:DP9>L`04
BU96<DHaBU84AS401T8@?Nm6<DYBDYA>L`=24004AS5>Le:DCW<3BU8014ic
BU96<DHa0TYB00=>LdHa@Q000T8@00A:DTHaAS5:DP=>L`04AS5:DT8@@Q05
AS40148@AS5>Ldic0TYB00=6<DYBAS401DYB00Q>Le:DCW=:DTicBU96<DYB
0e:D00A:DTicDYA:DP=>L`9F]@9BU09:DP9>L`ABU00;CW=:DTYBBU96<Dic
DYA>LdYBAS5:DP03CW<014YBCW=:DTYB0Tic00ABU4icCW=>L`9BU003E[EN
me[F009F]@ABU09F]@9BU008@Q0e[D8@CW=S65[FCW=BU09JePABU09>L`9B
U09>L`08DYAF]DicBU9>LeJeG_MJeP9F]@=JeP06G_MJeUJeF]IBU5Je15[F
00AF]E:DDYAF]@9JeP03E[EBU5Je009JeP9F]@03DYAF]EJe00=JeP03E[EJ
eU:D009BU09F]@04DYA>LeJeG_L2HaP01E[FG_MF]EJeDY@00UJe00AJeUJe
E[EF]@9BU007E[ENme[FF]IBU5[FG_L00e[F00=Nmf<HHaP00U[F00QF]E[F
E[EJeUJeDYAF]E[F0ekg0UJe0U[F00INme[FDYAF]E:DE[D3F]H2G_L3F]H0
1EkgF]IJeUJeF]H00Ukg00EJeUJeF]IJeUkg009S60ANm`03HaQNmekg009S
6005G_MJeUJeF]INm`02HaP00ekgE[EF]@02F]H5G_L015[FG_MNmf<H0VLi
00QS66LiIcU[FVLiHaQW>F<H0fLi0V<H00=Nmf<HF]H00U[F00ANmf<HIcUS
60=Nm`03HaQW>FLi009Nm`03HaQNmf<H009S6004G_MS65kgG_L2HaP2IcT6
HaP00ekgHaQW>@03JeX026LiHaQW>FLiJeYW>F]JHaP3IcT00f<HIcUS6002
IcT2HaP4IcT00f<HIcUS6002IcT2JeX016LiHaQS66<H0VLi0f<H00=Nmf<H
HaP00f<H00=Nmf<HHaP00VLi16<H0ekg0f<H15kg00=JeUkgE[D00U[F0ekg
0U[F00=Nmf<HF]H00D8@000212400`0012448@0312403PQ212448@aS?Nmo
ofmk@Q1BU5[FE[EBU4icDY@2CW<015:DE[EJeUJe0U:D0UJe00ABU4YBCW=:
DP=BU09>L`03BU9>Ldic00=BU09:DP=>L`03DYAF]Dic009:DPA>L`9BU003
CW=:DU:D009BU09:DP=>L`04DYAF]E:DDY@3CW<014YBDYA>Ldic0TYB0Tic
0U:D2Dic15:D00=:DTicAS400dYB0Tic0U:D00M>Le:DCW=BU5JeCW=BU002
CW<2DY@01DicDYABU4icDY@00dic00A:DTHa@Q16<@=:DP05@Q0mkd8@?Nm2
4003BU800dHa@Q16<@04CW<3BU82CW<01E:DCW=>LdYBCW<00e:D00E:DTic
BU9>LdYB0096<@9BU007E[E:DTYBDYAF]E:DCW<014YB1Dic0TYB00I6<DYB
BU9:DTicBU82AS42BU83@Q03BU801T8@?Nm244HaBU9>L`9:DP07AS5:DTic
E[E>LdHaBU800THa00=244Ha@Q000Sg_00Q244HaCW=>LdYB@Q0mkd8@0THa
00HmkcW>>Lhmkd8@?Nl2>Lh00d8@BU96<@04@Q0014HaBU9:DTYB0THa00M:
DT8@@Q1:DTicDYA>L`02AS49CW<2DY@6CW<014YBCW=>Ldic0TYB00=6<DYB
BU800Tic0TYB00=6<DYBCW<00Tic0U:D0dic2E:D0UJe0U:D00Q>Le:DDYA:
DTHa?Nm244ic15:D15Je00=BU5JeDY@00e:D00=F]E:DCW<00Tic00I:DTic
DYABU5JeF]H3E[D2F]H2G_L015[FDYABU5:D0UJe1U[F0U:D00YF]E[FE[EB
U5JeDYAF]EkgF]IF]@9BU003E[EJeU[F009F]@05DYAF]E[FDYAF]@02DY@2
F]H2G_L01E[FDYAF]E:DE[D00U[F15:D0UJe0U:D0UJe0e[F00=F]EkgG_L0
0Ukg00=JeUJeF]H015Je00=BU5[FF]H00Ukg0U[F0UJe0U[F0eJe00ABU5Je
E[EJePENm`=JeP04G_MJeUkgG_L2HaP015[FG_MJeU[F0Ukg0f<H00=JeUkg
F]H00e[F00=F]E[FG_L00Ukg0U[F00ANme[FF]IJeP9Nm`9S60ENm`9JeP05
HaQW>F<HIcUNm`02HaP00fLiHaQW>@02HaP00fLiHaQS6004G_L015[FHaQW
>F<H0Ukg16<H00MNme[FHaQNmf<HG_MW>@02HaP2G_L3IcT01EkgHaQS66Li
HaP01fLi00=[FVLiIcT00fLi00=[FVLiIcT00V<H00AW>F<HIcUS60AW>@03
HaQW>FLi00=W>@04HaQW>FLiJeX2IcT00f<HIcUW>@02HaP00fLiHaQW>@0:
HaP2IcT00f]JHaQS6002HaP01EkgHaQNmekgF]H00Ukg00=S65kgHaP015kg
15[F0F<H0E[F0D8@00000`0012448@021240100012448@Q20P@Q00L8@T8@
Oom_NdHaDYAF]@02DY@014icDYABU4ic15Je00ABU5JeDYAF]@9>L`03BU9>
Le:D009BU004CW=:DTYBBU82DY@2CW<3BU801DicDYAF]E:DCW<00dYB00=>
LdYBBU800U:D00=>LdYBDY@00U:D0TYB0Tic00I:DU:DDYABU5JeCW<2BU80
1U:DCW=>LdYBAS5:DP9>L`=BU09>L`04BU9>LdicDY@3CW<3DY@2CW<2AS42
BU82CW<01U:DCW=BU4icDYAF]@9BU0=>L`03DYA>Le:D00ABU09>L`=:DP92
409:DP04AS52448@@Q02?Nl01T8@BU9:DTHa@Q16<@=>L`=:DP03CW=:DTYB
00I>L`9BU0A:DP06CW=:DTHaCW=F]E:D0TYB00=BU5JeDY@014YB0dic00A:
DTicBU9>L`I:DP05AS5:DTHaAS5:DP02@Q02AS42BU801Cg_@Q12448@BU80
0Tic00=6<D8@BU800U:D00E>LdHaBU96<DYB00924005?NlicSg_?Nm:DP02
CW<2AS401D8@?Nm244Ha@Q000SW>00<mkdHa@Q000SW>00=244HaAS40148@
00i6<DYBAS56<D8@AS5:DT8@?Nm6<DicDYA>LdHa0dYB00I>Le:DCW=>LdYB
CW<3DY@2CW<014YBCW=>LdYB1Dic00=6<DYBBU800TYB00E>LdYBBU9:DTHa
009:DP03CW=BU5:D00A>L`9BU005CW=BU5:DCW=BU003E[D01e:DCW=BU5:D
E[E:DTHa0092409>L`04E[EBU5:DDY@2F]H2DY@015JeDYA>Le:D0UJe00EB
U4icCW=>LdYB009>L`03DYAJeUJe00AF]@9Nm`9JeP=BU09F]@EJeP03E[EB
U5Je00AF]@03DYAF]EJe009JeP9F]@03DYAF]E[F009JeP=BU09F]@=BU004
F]INmekgG_L2E[D2DY@015[FE[EJeUJe0e:D0eJe0U:D0U[F00ANmeJeF]IJ
ePANm`AF]@05F]IBU5JeE[EJeP03G_L00e[FE[EJeP03E[D00e[FDYABU002
E[D00e[FG_MNm`02G_L6F]H01UkgHaQS65kgF]IF]@9Nm`07F]IS65kgHaQN
me[FG_L01E[F15kg00=JeUkgF]H00Ukg00AJeUkgHaQW>@9Nm`03F]IS65kg
009Nm`05F]IS66<HIcUS6002G_L2HaP00fLiHaQS6003HaP4G_L00e[FHaQS
6003HaP2G_L3HaP00ekgF]INm`02HaP00ekgHaQS6003G_L00f<HIcUS6004
HaP7IcT016]JIcUW>F<H0fLi00=[FVLiHaP00V<H0VLi0V<H2FLi00IS66Li
HaQW>F]JIcT5HaP00fLiHaQW>@02IcT8HaP3IcT00f]JHaQS6002G_L3HaP0
0e[FG_MJeP02G_L01F<HG_MNme[FG_L015[F0Ukg0E[F0D8@00001@@Q0004
8@@Q00000`@Q00T<H`00124@Q4HaOom_Ncg_DY@015[F00MBU4icDYA>Le:D
E[EJeP02DY@00dYBDYA>L`03BU82DY@2CW<015:DCW=>LdYB0U:D00EF]Dic
CW=>LdYB00=>L`03BU96<Dic009BU09:DP03DYAF]EJe00=>L`03DYAF]DYB
0096<@03CW=BU5Je009BU007CW=BU4icBU9>LdHaCW<00TYB0dic00ABU4ic
CW=:DP9>L`04DYA>LdicCW<6DY@00dYBCW=:DP02AS400dYBE[EBU004DY@0
15JeCW=:DTYB0dic00A:DTicCW=BU0E>L`96<@924004AS5:DTHa?Nl2@Q00
0dHaBU96<@02AS43BU800e:DCW=BU002BU85CW<014YBAS5:DTic15:D00Q:
DTHaBU96<DYBCW=BU5Je0Tic0e:D1DYB0THa0TYB00IBU4icCW=:DTHaBU84
AS43CW<03TYBAS4mkd8@>Lhe[D8@AS5:DT8@>Li244YBAS42@Q001THaDYAB
U4icBU96<@9:DP03AS4icSF]008aS004=JdicSg_<H`2;F/00c6<?NlicP05
=Jd02c6<=Je2448@AS5243W>?Nm6<DYBDY@00TYB14Ha00HmkcW>@Q1:DUJe
DY@3BU801DHaBU9:DU:DCW<00TYB00A>Le:DDYABU0=>L`03DYA>LdYB00=:
DP07CW=6<DHa@Q1:DTicDY@00dYB0Tic00=BU4icDY@00dic00=BU4icDY@0
0U:D00A>LdYBCW=BU0=F]@09CW=BU5JeE[EBU3g_>LhmkdHa009BU003CW=B
U5Je009JeP03E[EBU5:D00=BU003CW=BU5Je009BU003CW=BU4ic00=>L`03
DYAF]E[F009F]@9JeP9S6003G_MF]Dic00AF]@05F]INmf<HE[EBU002E[D2
F]H00eJeDYABU002DY@00e[FE[EF]@02E[D00e:DF]IJeP03F]H3E[D00e[F
E[EF]@02DY@3F]H00eJeDYABU002F]H3E[D00e:DE[EBU002E[D015[FE[EJ
eU[F0eJe0e[F00=F]E[FE[D015:D0U[F0eJe0Ukg0U[F0UJe0U[F0Ukg0e[F
0ekg00=JeUkgG_L015[F00=F]EkgG_L00f<H00=Nme[FF]H03E[F0Ukg00IJ
eUkgF]IS65kgF]H7G_L02F<HG_MNme[FG_MS65kgHaQNm`03HaP3G_L01f<H
IcU[FVLiHaQJeUkg009S6003G_MJeUkg009S609Nm`04HaQW>F<HG_L5HaP0
15kgHaQNmekg0f<H0VLi0f<H00=W>F]JIcT00fLi00=S66LiIcT00V<H00AW
>F<HIcUW>@IS609W>@03HaQW>F]J009W>@04HaQ[FVLiIcT4HaP016LiHaQS
66<H0VLi0V<H0fLi16<H0fLi00YS65kgHaQW>F]JIcUS65kgHaQNm`=S609N
m`03F]INmf<H00=S609Nm`03HaQNmekg009JeP5S605F]@5240000P@Q00<0
00@Q12400`@Q01`8@P@Q1248@THaOomcW48@CW=F]E[FE[EJeU:DCW=BU4ic
DYAF]E[FE[E>LdYBDYA>LdYBAS5>L`9BU003CW=:DTic00=>L`ABU004CW=:
DTYBBU82CW<3BU802U:DCW=6<DYBDYAF]E:DCW=:DTic0U:D00E:DTHaAS5>
LeJe00ABU09>L`A:DP9>L`9:DP07CW=BU4icCW=:DTicDY@00dic00=BU4ic
DY@00e:D0Tic00E:DTHaAS5:DTic009BU09>L`=BU003CW=:DTYB009>L`9:
DP03CW=BU5:D00E>L`03AS5243g_00=6<@924004?Nm244Ha@Q03AS400dYB
AS5:DP03CW<4BU83CW<014YBAS5:DTYB0e:D0Tic0TYB00=244HaCW<00U:D
0Tic0e:D0Tic0dHa14YB0Tic0TYB1DHa00E:DTicCW=>LdHa00=2400:?Nli
cSg_AS5:DT8@>Li244YBAS42@Q001TYBCW=BU4icAS52409:DP06AS4icS6<
=JdaS3F]0Sg_00@aS2e[;F/aS08mk`0>>Lhe[C6<<H`icSF]>LhmkdHa@Q0m
kcW>?Nm:DP=>L`05@Q16<DYBBU96<@02>Lh0248@BU9F]E:DAS5>LdYBAS42
BU82CW<2BU800dicDYABU002DY@01DYBDYA>LdYBCW<01DYB00A244HaAS5B
U09>L`03BU96<DYB00=BU0=>L`05DYA>LdicCW=BU003CW<014YBDYABU5[F
0e:D00=F]E:DCW<00SW>00<mkdHaDY@00Tic00=BU5JeF]H00UJe15:D00=>
Le:DE[D00UJe14ic00IBU4icCW=BU5JeF]H3E[D015kgHaQNme[F1E:D0e[F
00ENmeJeE[EBU5Je009JeP9BU004E[EBU5JeE[D2F]H01EJeDYABU5:DE[D0
0U[F0eJe00EJeUJeF]IBU4ic009F]@03G_MJeUJe009BU003E[EJeU[F009F
]@9BU09F]@03DYAF]E[F009JeP=F]@9JeP07E[EJeU[FDYAF]DicDY@01EJe
0U[F00=Nme[FF]H00UJe0U[F00=Nme[FF]H00U[F00ENme[FF]IJeUkg009J
eP=F]@9JeP9S6003IcUNmekg00EJeP03G_MJeUJe009JeP9Nm`=JeP9Nm`9J
eP9Nm`04HaQNme[FF]H5G_L02V<HG_MJeUkgF]INmf<HG_MS65kg0V<H0ekg
00=S66]JJeX00V<H0U[F00=S65kgG_L00ekg00=S65kgG_L00V<H00=W>F<H
F]H00f<H00=Nmf<HHaP00ekg00=S66LiIcT00V<H1FLi00A[FVLiIcUW>@IS
609W>@03HaQW>F<H00ES609W>@03JeYW>FLi00AW>@9S6003IcUS66<H00=S
6004IcUS66<HHaP3IcT4HaP3IcT00f<HG_MS6002IcT016]JHaQNmekg0V<H
0ekg00=JeUkgG_L016<H00AJeUkgG_MNm`9JeP9Nm`5F]@52400000D000@Q
12448@0000<48@0<24848@0048A6<GooLi`mkdicF]IF]E[F0UJe14ic0e:D
00=F]DicBU800TYB0dic00=:DTicDY@015:D00=>Le:DE[D00U:D1Dic0THa
015:DTicCW=:DTHaBU9BU5JeDYA>LdYBDYAF]DicAS5244YB00ABU09:DP96
<@04BU9>LdicBU82AS40148@AS5:DTHa0TYB00=>Le:DDY@00dic15:D00I>
Le:DCW=BU4icAS42BU8<CW<2BU8014icDYA>LdYB0U:D0Tic0THa00A243W>
@Q1240=:DP03AS5:DTHa00=6<@03BU9>Ldic009:DP03CW=BU4ic009:DP=>
L`04BU96<DYBCW<2DY@2CW<2BU800dicBU9>L`02BU89CW<3AS43BU8024Ha
BU9>LdicBU9>LdYBAS42BU82CW<03TYBAS5243g_@Q0icS6<>Li6<DYB?Nle
[D8@BU83@Q001DHaDYA>Le:DCW<00U:D0Tic0T8@0SF]00<aS2DY9BT00RDY
00@YBRe[9BTU:@8Q20@U:@03:DX]Jbe[008]J`05:DXU:Be[<H`e[@02<H`0
0cW>?Nlmk`02>Lh013g_@Q16<Dic0e:D0TYB00A6<DYBBU96<@=:DP9>L`A:
DP9>L`E:DP=24003AS5BU5:D009>L`I:DP03CW=BU4ic00I>L`03DYA>Ldic
00=BU003CW=:DTic009BU005BU8mkd8@BU9BU002CW<01U:DE[EJeU[FDYAF
]@9BU003E[EBU5:D00IBU003E[EBU5:D009>L`05DYAF]EJeF]IF]@02F]H0
25JeG_MNmeJeDYA>Le:DF]H2G_L01E[FDYABU5:DE[D00U[F00=F]E:DDY@0
0U:D00AF]E:DE[EJeP9BU005E[EJeUkgHaQJeP02E[D00e:DF]IF]@02F]H0
1eJeF]IJeUJeDYAF]E:D009F]@=JePAF]@9JeP03E[EJeU[F00EF]@=JeP08
E[EBU5:DDYAF]E[FE[EBU09F]@=JeP03E[EJeU[F00=JeP06G_MS66<HHaQJ
eUkg0f<H0e[F00ENme[FF]IF]Ekg009S6004F]IF]EJeE[D2F]H00eJeDYAJ
eP04F]H00ekgF]IJeP02G_L00e[FG_MS6002HaP00ekgF]IJeP02F]H3G_L2
HaP3G_L00f<HG_MNm`02G_L016<HG_MS65kg16<H0Ukg0f<H00AJeUkgG_MN
m`9S609Nm`9S609W>@MS6003IcUS66<H009S60AW>@9Nm`9S60=W>@03HaQW
>F<H00=W>@=S609W>@=S6003IcUS66Li009S60EW>@03JeYW>F<H009W>@05
HaQW>F<HIcUS6003IcT00f<HIcU[FP02IcT2HaP3IcT4HaP00fLiHaQW>@02
HaP00fLiG_MNm`03HaP00ekgHaQJeP02F]H00ekgHaQNm`06HaP00ekgHaQJ
eP01@Q0000<48@0400048@@Q0002248212401`aSAS5oog>L?Nm>LeJe00=J
eP04DYA>LdicCW<3DY@00eJeDYA>L`03BU86CW<015:DE[EBU4ic0U:D00IF
]E:DDYA>LdYBCW<2BU82AS400dYBDYA:DP02AS4014YBE[EBU5:D0TYB0U:D
00A>LdHaAS5:DPABU09:DP96<@03BU9>Le:D009:DP05@Q16<DHaBU9>L`02
BU800dicDYA>L`03CW<3DY@01DicDYA>Le:DCW<014YB24ic0TYB0Tic00A:
DTicCW=BU0=>L`9BU003BU96<DYB00<mk`04@Q1:DTYBAS42BU801DHa@Q16
<DHaCW<00TYB00=>LdYBDY@01dic00E6<DYBAS5:DUJe009BU004CW=:DTic
CW<2BU801DHaBU9>LdicDY@01Dic0TYB0dHa1TYB00E>LdYBAS56<DYB00=>
L`0>BU9244Ha?Nm6<CW>=JdicTHaBU8mkcW>?Nm6<@=24003BU9>LdYB00=B
U008E[EBU4YBAS4icSF]<H`]J`8YBP8U:@06;F/YBRU::DXU:AcW0R480bU:
0be[0bU:00L]Jc6<=JdaS3F]>Li24002?Nl2>Lh2@Q04DY@3AS43BU800dHa
BU9:DP02DY@014YBAS56<DYB14ic0dYB0d8@00A:DTicDYA>L`M:DP]>L`=B
U0E>L`0=DYA6<D8@@Q16<DicDYA>Le:DE[EJeUJeF]H00U:D00=>Le:DDY@0
0U:D00A>Le:DDYA>L`ABU0=>L`9F]@9JeP9F]@05F]INme[FE[EBU002CW<2
F]H00ekgF]IBU002DY@3F]H015JeDYABU4ic0U:D0UJe00EJeUJeDYABU5[F
009Nm`03F]IF]EJe009F]@04F]IF]EJeF]H4E[D00e:DCW=F]@02E[D2F]H0
15JeF]IF]EJe0U[F00AF]E[FE[EF]@AJeP9F]@03F]IF]E:D009BU003E[EB
U5Je009BU003E[EJeU[F009JeP03E[EJeU[F009JeP9Nm`03HaQNme[F009N
m`03HaQNme[F00AJeP03E[EJeUkg009S6003F]IF]EJe009JePAF]@=JeP03
G_MJeU[F00=JeP03G_MJeUkg009S6003G_MJeU[F00=JePANm`03HaQNmekg
00ENm`=S6003G_MS66<H009S6003G_MS65kg00MNm`04HaQNmf<HG_L3IcT9
HaP016LiHaQS66<H0fLi0Ukg0V<H16Li00AS66LiIcUW>@AS6003IcUS66Li
00=S609W>@AS60=W>@03JeYW>F]J00AS6003IcUS66Li00=W>@03HaQW>F]J
009W>@=S609W>@IS609W>@=S60=Nm`9S6003G_MJeU[F00ANm`=S6006IcUS
65kgG_MS65kg0Cg_00000`0012400005124040Q212448@aSBU9oogNm?Nm:
DUJeCW=F]E[FG_MF]E:D0Tic0e:D00MF]DicCW=244HaBU96<@02BU800dic
DYABU003E[D2CW<2DY@02TicDYABU5JeDYA:DTicDYA>LdHa0T8@0TYB00E>
Le:DDYA>LdYB00A>L`96<@04BU9>Le:DDY@2AS400dYBAS5:DP04BU8014Ha
@Q1243g_0THa00Y>Le:DDYABU4icDYA>Le:DCW=BU09>L`=BU005CW=:DTYB
@Q16<@02BU800dicBU9>L`03CW<3BU82AS401T8@BU9:DTicDYA>L`9:DP04
AS5>LdYBAS42?Nl01DHaBU9>LdicBU8014Ha00=:DTicCW<014YB00A>LdYB
BU9:DP96<@=:DP96<@03BU9BU5Je009BU005CW=:DTicCW=:DP03CW<02dYB
AS5:DTicDYA>LdYB@Q16<DYBCW<00TYB00E6<DYBCW=>Le:D00=>L`9:DP03
CW=:DTHa00Dmk`9240=:DP03CW=BU5Je009BU007E[E>LdicCW=BU5JeF]H0
0U:D00E>LeJeDYA:DSW>008Li`8HaP038@PLib48008Li`038@PLiaS6008H
aP047>LQ22DY7>L26<H00acW8@PHaP026<H37>L01R487>LLiacW8@PYBP<a
S005;F/e[CW>?NlicP02=Jd00cg_@Q1:DP03CW<00e:DBU96<@03AS44BU80
34Ha@Q1244HaBU96<DYBCW=:DTHa@Q16<@=:DP9>L`03DYA>LdYB009>L`03
DYA>Le:D00=>L`9BU09:DP06@Q0mkdHaBU9BU5Je1E:D0U[F0UJe00=>Le:D
DY@00eJe0e:D00AF]E:DDYABU09F]@06DYA>Le:DDYAF]Ekg0U[F00YF]Ekg
G_MF]E:DBU9BU5[FE[EJePAF]@ABU006E[EJeU:DDYA>Le:D0UJe0e:D00AJ
eV<HG_MF]@9JeP9BU003E[EJeUkg00=JeP05E[EJeUJeE[EBU002E[D2F]H0
15kgE[EF]E[F1EJe15[F00IF]E[FF]IJeUJeF]H2E[D2F]H3E[D01U:DE[EF
]EJeG_MS60=JeP03E[ENmf<H00=Nm`04F]INme[FE[D2F]H2G_L01E[FE[EJ
eU[FG_L015Je15[F00AF]EkgF]INm`9JeP=Nm`04F]IF]E[FG_L2HaP2G_L2
F]H015kgF]INmekg0V<H00=Nme[FF]H00Ukg00AS65kgG_MS609Nm`05HaQW
>FLiIcUS6003G_L016LiHaQNme[F16<H00=Nmf<HG_L00V<H0fLi00=S66Li
HaP01F<H00AW>F<HIcUW>@9[FP03IcUS66<H009Nm`9S6006IcU[FVLiHaQW
>F<H0VLi0f<H0VLi1V<H0Ukg00AS66LiIcUS60AW>@=S60aW>@03HaQW>FLi
00AS6008IcUS66<HHaQ[FVLiHaQJeP=Nm`06HaQNme[FF]INme[F15kg1F<H
00=Nmf<HF]H00D8@000412401@0012448@@Q24800P@Q00H<HdHaOomg_CW>
CW<2DY@01UJeG_MJeUJeDYA:DP9BU003CW=BU5Je009>L`04@Q16<DHaAS42
BU801DicDYA>LeJeF]H00U:D0Tic00EF]DicCW=BU5Je00E>L`06AS52448@
BU96<Dic0U:D00=>LdYBBU800Tic00A:DTHaAS5:DP9>L`03DYA:DTHa0096
<@A:DP05AS5244Ha?Nm24002AS42CW<2DY@2CW<3DY@00dicBU9>L`03DY@0
0dYBCW=6<@02AS401TYBCW=>LdYBCW=BU09>L`03AS5:DTYB00=6<@9:DP9>
L`03DYA:DTYB009:DP03AS52448@00924007BU9>LdicBU96<DYBAS4014YB
00E>LdYBCW=:DTic00=:DP04AS5:DTYBBU83AS4014YBE[EBU5:D14ic00A:
DTicBU9>L`9:DP06CW=:DTYBDYA>LdYB0THa00=>LdYBAS400THa0Tic00AB
U4icBU9:DP=>L`9:DP96<@8mk`8icP924096<@03BU9>Le:D00=F]@03DYA>
Ldic009BU00<E[EJeU:DDYA>Le:DCW=6<CF]9BTQ21S611cW00<Q21cW7>L0
0aS60QcW0R4811cW00<HaQcW7>L00acW0b4800@Lib489BTYBPDaS009>Lhm
kcW>=JdicSg_AS5:DU:D009>L`9:DP=6<@03BU96<DYB009:DP03AS5244Ha
00=6<@03BU9>LdYB00924003AS5:DTYB009:DP9BU0A>L`9BU0=>L`9BU09>
L`08BU9243g_@Q1:DUJeDYAF]@9BU004CW=F]EJeF]H2E[D3CW<3E[D2DY@0
0eJeDYABU005DY@2CW<01U:DF]IJeU[FE[EJeP9Nm`04F]I>LdicDY@2E[D2
F]H3E[D2DY@01DicDYAF]EJeDY@00Tic00EBU5[FE[EBU4ic009F]@9Nm`04
F]IF]EJeDY@2E[D4F]H3E[D01E[FDYABU5:DE[D00U[F00EF]E[FE[EF]E[F
00=F]@AJeP03E[EJeU[F009JePAF]@03F]IF]E:D009BU0=F]@9JeP05G_MJ
eU[FE[EJeP02G_L026<HF]IF]E[FG_MJeUJeF]H2G_L00e[FE[EJeP05F]H3
E[D2F]H00eJeF]INm`04F]H3G_L4F]H2HaP00ekgF]IJeP02G_L2F]H01Ekg
HaQNmekgF]H00ekg00ES65kgHaQNmf<H009Nm`=W>@03HaQNmekg00=S60=N
m`9S60=Nm`9S60AW>@06HaQW>F<HHaQNmf<H0VLi0f<H0fLi1V<H16Li0f<H
0VLi0f<H0VLi0V<H00=Nmf<HIcT00ekg0f<H16Li16<H1VLi00=S66LiJeX0
0VLi00IS66LiHaQW>F<HIcT3HaP2G_L3IcT00f<HG_MJeP03G_L00f<HG_MJ
eP02F]H3G_L6HaP00ekgIcUJeP01@Q00000300048@@Q00<48@0>0008@PQ2
124000aSAS5oog>L?Nm:DU:DCW=BU0=Nm`0=DYA>LdicDYA>Le:DE[EBU4ic
BU9244HaBU801Dic0eJe00EBU4icDYABU5Je009BU09F]@0;CW=BU5JeBU92
43g_AS5:DTHaBU9BU002E[D01TicAS5:DTYBDYA:DP96<@03BU9>LdYB0096
<@924006AS5244YBBU9>LdYB14Ha00=:DTHaBU800THa0TYB00E>Le:DDYA:
DTic009:DP05DYA>LdicDYA>L`02BU800d8@AS5>L`02CW<2BU83CW<3BU82
@Q000dHaBU9>L`04BU801E:DAS56<Cg_>Lh00T8@00=:DU:DBU800THa0T8@
00E:DTicDYABU4ic009:DP03AS5:DTHa00924004AS5:DTic@Q02AS401DYB
DYAF]EJeCW<00dYB00ABU4icCW=>L`9:DP03AS5:DTYB009>L`03BU96<DHa
009:DP96<@9:DP04CW=6<DYBBU83CW<014YB@Q12448@1DYB0Tic00EBU5Je
DYAF]E:D00=2400BBU9>Ld8@AS5>LdYB@Q0mkcW>?Nm>LdHa:DXHaPaS48@D
Y@aS0a241@aS0Q240QBU0Q240`aS00<@Q0aS36<00PaS1Q240QBU00<HaQcW
7>L00acW0R480RDY0bU:00@]Jc6<<H`aS08]J`8aS08icP03?Nm2448@0096
<@924005?Nm2448@?NlicP03?Nl00d8@AS5:DP04CW<2BU801DicDYA>Le:D
BU800Tic00AF]E:DDYA>L`<mk`06@Q1BU5JeE[ENmeJe0U:D00=F]EkgF]H0
1e:D00=>Le:DDY@00U[F00EF]E:DDYAF]E:D009>L`03DYAF]E[F009JeP03
E[EJeU[F009F]@IBU00:E[EJeUJeE[EBU4icDYAF]E:DE[D4DY@015[FE[EB
U5:D0e[F0U:D00AF]E:DE[EF]@9JeP=F]@=JeP=BU09F]@9JeP9F]@03F]IF
]EJe009F]@04F]IF]E[FE[D2G_L00e[FE[EJeP03E[D015[FE[EF]EJe0e[F
0UJe1U[F00IF]EkgHaQNmf<HG_L2F]H00e:DE[EF]@03F]H01EJeF]IJeUJe
DY@00UJe15[F00AF]E[FF]IF]@9JeP0;G_MS65kgG_MJeUJeF]INmf<HG_MJ
eP04G_L00e[FG_MNm`05G_L2HaP2G_L016LiHaQS65kg1V<H00=Nme[FG_L0
0V<H00=Nmf<HHaP00f<H0ekg1F<H00IW>F<HG_MNmf<HG_L3HaP4IcT016<H
JeYW>FLi0Ukg0V<H0VLi1F<H0VLi0f<H0fLi26<H00AW>F<HHaQS609W>@9S
609Nm`03HaQW>F]J00AW>@04HaQW>F]JIcT2HaP00ekgHaQW>@02IcT4HaP0
16LiHaQS65[F0ekg00=S65kgHaP00Ukg0U[F0ekg00=S65kgHaP016<H0Ekg
0D8@000212400`001240000312404@Q212448@aSAS5oog>L?Nm:DU:DBU9B
U5[FHaQJeUJeBU800U:D00M>Le:DE[EBU4icAS524002BU802TicBU9>LdYB
DYAF]E[FE[EBU4ic15:D0UJe00MBU4icDYAF]DYBAS4mk`03AS401DYBDYAF
]EJeCW<00dYB00U>LdYBAS5244YBCW=:DT8@AS400T8@00Q6<D8@AS5:DTic
BU96<D8@0THa0dYB0THa00A:DTicCW=BU09>L`9:DP9>L`9BU09>L`03BU96
<DHa009:DP=>L`04BU9>LdicCW<2BU82AS40148@AS5>Ldic0dYB00Q>LdYB
AS5:DSg_>Li244Ha0dic0THa00A243g_CW=>L`9BU09:DP07AS5:DTYB@Q16
<D8@AS400TYB00A6<D8@AS56<@9F]@9BU003CW=:DTic00A>L`05AS5:DTHa
AS5:DP02CW<02DYBAS56<DicAS5244HaBU9>L`02BU8024HaCW=>Le:DCW=:
DTHa@Q02AS4014YBAS5:DTYB0Tic15Je00A>LdHa@Q16<@9>L`96<@0;CW=:
DTYB?NlicSg_CW=6<C6<7>L<H`0248@01ABU48@@Q0aS48@01@aS0aBU00<@
Q0aS48@00Q240PaS00<@Q0aS48@01Q2400<DYA247>L01AcW00@U:B488@PQ
208U:@05:DX]Jc6<<H`e[@04<H`00cF]>Li24003@Q001DHa@Q12448@AS40
0Sg_00<icSg_?Nl00d8@00=6<DicDY@00Tic0TYB0dic00=:DTicBU800U:D
00UF]E:DCW<mkcW>?Nm245JeDY@00e[F0U:D0e[F00=BU4icCW<015:D0Tic
00EBU5[FF]IF]Dic00=BU09>L`05DYAF]EJeF]IF]@04F]H3DY@00dicDYAB
U002E[D015[FE[EF]Dic15:D00AF]E:DE[EBU09F]@=BU09JeP9F]@9BU09F
]@9JeP9F]@05DYAF]E[FF]IF]@02DY@014icE[EJeU[F0UJe0U[F0UJe00IB
U5JeE[EJeUJeF]H2G_L01U[FE[EF]E:DE[EJePAF]@03F]INmeJe00=F]@06
F]INme[FF]IF]E[F0ekg00IS65[FF]IJeU:DE[D7F]H00eJeDYAF]@03F]H0
0eJeF]IJeP02F]H01UJeF]IJeUkgHaQNm`9JeP07E[EJeUkgG_MS65kgF]H0
0ekg0e[F0ekg00=JeUkgHaP00ekg00IW>F<HHaQNmf<HIcT2HaP00ekgHaQN
m`02G_L00f<HG_MS6002G_L3HaP2G_L02F<HIcUS66<HG_MS65kgHaQNm`03
HaP00ekgHaQS6005IcT00f]JIcUS6003G_L00f<HIcUW>@04HaP2IcT016<H
G_MS66<H0fLi0f<H00=Nmf<HG_L00V<H00AW>F<HHaQNm`9W>@04HaQNme[F
HaP4IcT00f<HIcUS6003IcT00f<HIcUS6002HaP4IcT3G_L01FLiHaQNmekg
F]H01Ekg00EJeUkgF]INme[F009S6003G_MS65kg00=S605W>@5JeP524000
00<000@Q12400P@Q00@000@Q1248@P848@0536<mkgooJeXmk`02DY@01DYB
CW=BU5[FG_L00U:D00A>Le:DCW=BU09>L`07DYA:DTYBBU9>Le:DCW<00dYB
15:D00A>Le:DDYABU0=F]@05F]IF]DYBAS524002AS40148@AS5244YB0e:D
00=:DTHaBU800TYB00M6<D8@AS56<DicDYA:DP02AS4013g_@Q1244Ha0TYB
0Tic0dHa00=:DTicBU800dHa00=:DTicDY@00U:D00E>LdYBBU9>LdYB00=B
U004CW=:DTHaAS42BU8014icBU9:DTYB0Tic0U:D00E>LdHaAS5244YB009>
L`9:DP05AS5:DTYBBU96<@02?Nl00d8@AS5:DP04AS43BU83CW<3BU82AS42
@Q0014HaBU9:DTHa0T8@00M:DU:DE[EBU4icBU96<@02BU801TicBU9:DTYB
AS5:DP9>L`=:DP03CW=:DTHa00I6<@A>L`03BU96<D8@0096<@06@Q16<DYB
AS5>Le:D0THa0S6<00@]JbU::DXQ20@Li`8HaP087>LDYABU36<@Q1BU48@<
H`@8@P0436<8@P@Q2482124010Q21248@P@Q0PQ20PaS00<8@P@Q24800`Q2
00<48@Q2248020Q200D<H`Q22488@PaS008@Q08<H`0348@DYABU008Li`03
8@PLib4800<Li`058@PU:BU::DXU:@02:DX3<H`00be[:DXU:@029BT01be[
:DXe[CF]>LhmkcW>009240=6<@9>L`04DYA>LdicDY@2CW<4DY@013W>=Jdi
cTHa0U[F00=BU5JeE[D00UJe0U[F0UJe00=>Le:DDY@00e:D00AF]E:DDYAB
U0IF]@9BU005CW=BU5JeE[EJeP03E[D015[FG_MJeUJe0Tic0U:D0U[F0eJe
00=BU5JeCW<00U:D0U[F00=F]E:DE[D00UJe0U:D00AF]E[FE[EF]@9BU005
E[EJeU[FG_MJeP03E[D2F]H2E[D015:DE[EBU5Je0U[F00AF]E[FE[EJeP=F
]@08DYAF]EkgHaQNme[FDYAJeP9F]@03CW=BU5:D00AJeP07G_MJeU[FF]IF
]E:DE[D00e[F00AF]E[FHaQS609Nm`9JeP03E[EJeU[F00=F]@=JeP04E[EJ
eUkgG_L3F]H2G_L00e[FG_MJeP04G_L015[FE[EJeU[F0Ukg0U[F00=Nmf<H
F]H00e[F0ekg16<H00ANme[FG_MS609W>@03G_MS65kg00INm`03HaQNmf<H
00=S60=Nm`YS60=Nm`=S6005IcUS66<HIcUS6002IcT2HaP00e[FG_MNm`02
HaP016LiHaQS66<H15kg1FLi0V]J0V<H00ANmf<HHaQS60=W>@9S60=W>@=N
m`9S60=W>@06HaQW>F<HIcU[FVLi0V<H00INmf<HHaQW>F]JIcT4HaP2IcT0
15kgF]IJeU[F0ekg15[F0Ukg0V<H00=Nmf<HG_L00f<H0E[F0D8@00031240
0`0012448@0212403PQ212448@aS@Q1oof]J?Nm>Le:DBU9>Le:DF]H2E[D0
0dicDYA>L`04DY@01TicBU9:DTYBCW=BU09>L`9:DPABU004BU9>Le:DDY@5
E[D2BU83@Q000dHa@Q124002CW<01EJeDYA:DTYBAS400TYB00A6<D8@AS5:
DP9>L`06AS5:DT8@@Q0mkd8@0THa1DYB00=6<DYBBU800THa00A244YBAS5:
DP9BU09>L`04AS5:DTYBCW<2DY@2CW<014YBAS5:DTHa0dYB00=6<DYBCW<0
0e:D00E:DTHaAS56<DYB009>L`9:DP04AS5:DTYBCW<2@Q000cg_@Q1:DP02
BU82AS40148@AS5:DTYB0dic00A:DTHaAS5:DP=24003AS5:DTYB00=6<@05
BU9>LeJeDYA>L`08BU800dHaBU9:DP02CW<4BU85AS45BU801DicBU96<DHa
@Q0014Ha00M:DTicCW=:DTHa=JdaS003:DX28@P37>L01ABU6<HLiaS65:D0
0a240`aS00P8@PaS2488@P@Q24848@Q20P@Q0PQ200<48@Q224801@Q20P@Q
00D8@PaS2488@P@Q00H8@P<<H`07248<H`aS48@<Ha2436<00QBU0QS60QcW
00<Q21cW7>L00QcW00<Q22DY:DX00bU:00<]JcF]<H`00Re[12DY00DYBRe[
<H`icSg_008icP07?Nm6<DHa@Q16<DicDY@014ic00]BU4icDYA>Le:DCW<m
kcW>?Nm6<E[F00EF]@9JeP04G_MF]E:DCW<8DY@2E[D01e:DE[EF]E[FDYAF
]Dic00=BU09JeP9F]@AJeP03DYA>Ldic009BU0AF]@06DYAF]E:DDYA>LeJe
0U[F15Je0U:D0UJe00AJeUJeDYAF]@9BU0AJeP=F]@06F]IF]E[FE[EBU5Je
0U:D00=JeUJeF]H00e[F00MBU5JeDYABU5JeG_MS6002F]H3E[D3DY@2E[D0
0e[FG_MJeP04F]H00e:DE[EF]@02F]H2E[D015[FHaQNmekg0U[F0UJe00=J
eUJeF]H00UJe0U[F0UJe00AJeUkgF]INm`9JeP08G_MJeUkgF]INme[FG_MS
609JeP9F]@9Nm`=JeP=Nm`03F]IF]E[F009Nm`09HaQNmf<HG_MS65kgF]IN
mfLi009S6003G_MS66Li009Nm`03F]INmekg009Nm`=S6003G_MS65[F00=N
m`AS6004G_MS66<HHaP4G_L5HaP01VLiHaQW>F<HIcUS609Nm`04F]IS66<H
IcT4HaP3G_L2HaP01VLiJeYW>F<HJeYW>@]S6003IcUS66Li009Nm`03HaQN
mf<H00AW>@03HaQW>FLi00=W>@03HaQNmf<H00AW>@03HaQNmf<H009S6006
IcUNmekgE[EJeUkg1U[F00=Nmf<HG_L00ekg16<H0E[F0D8@00001@@Q0004
8@@Q00000`@Q00P8@P@Q000<HcW>Oom[FSg_0Tic00IBU4icDYA>Le:DCW<3
DY@2CW<01U:DCW=BU4YBAS5:DP=BU003BU96<DHa009>L`9BU09>L`03BU9B
U5Je009BU008E[EJeUJeCW=:DU:DBU92408mk`08BU9>LdicCW=6<DYBCW=2
40<mk`03BU96<Dic009>L`09DYA6<D8@?Nm244HaBU9244YB009>L`03BU96
<Dic009>L`05AS52448@@Q16<@03CW<3BU85DY@2CW<00dYBCW=:DP04BU80
0dHaBU9>L`02DY@00dicDYA>L`02AS42BU82CW<01TYBAS56<DYBCW=6<@92
4003AS5:DTYB009:DP96<@9:DP04CW=BU4icCW<3BU8014Ha@Q0icSg_0T8@
0THa0TYB00=6<D8@AS400TYB0THa00E244HaAS5:DTHa009:DP9>L`Q:DP04
CW=BU4icCW<2BU801e:DE[EBU4YB?Nle[C6<008YBP048@PLiacW6<H25:D3
48@236<2248010@Q248<H`aS1PQ20P@Q00<8@P@Q12402`@Q00<8@P@Q0000
1P@Q00<8@P@Q12400P@Q00D8@P@Q12448@Q200@48@0424848@Q212422480
10@Q2488@PQ20PaS00@8@PaS36<@Q0<<H`046<HQ22DY9BT28@P4:DX00bDY
8@PLi`067>L012489BT]JcF]0SW>00A244HaAS5BU09>L`=:DP0>CW=BU4ic
BU96<CW><Ha244icF]IF]DYBCW=BU09F]@9JeP04DYAF]DicDY@2CW<01E:D
E[EBU5JeCW<00U:D00=F]E:DDY@015:D00=>LeJeE[D00UJe0Tic00EF]Ekg
G_MJeUJe009>L`ABU0AF]@9BU003E[EBU5Je00=BU0=JeP03E[EBU5:D00=J
eP06E[EBU5JeE[EJeUkg0U[F0UJe00ABU5JeF]IJeP9F]@9BU007E[EJeU[F
F]IF]EkgE[D00Tic00EBU5[FF]IJeUJe009BU09JeP03E[EBU5Je009JeP03
E[EJeU[F009JeP9BU09F]@06F]IF]E:DDYAF]E[F0Ukg0e[F0UJe00ABU5Je
DYAJeP9F]@9JeP=Nm`03F]IF]EJe009JeP04G_MJeU[FF]H3G_L00e[FE[EJ
eP06F]H2G_L4F]H00ekgF]IJeP02G_L00fLiHaQNm`03F]H016LiHaQS66Li
0ekg0U[F00=Nmf<HHaP00ekg0V<H00ANme[FF]INm`AS6003IcUS66<H00QS
60=W>@03HaQW>F<H009S6003IcUNmekg009Nm`=W>@9S609Nm`9S609W>@03
HaQW>F]J009[FP03IcUS65kg009S6005IcUS66<HHaQW>@04HaP016LiHaQN
mekg0V<H0VLi00MS66LiIcUW>F]JHaQW>@02HaP00fLiHaQW>@02IcT00f<H
IcUNm`03HaP016LiG_MNme[F0ekg00=JeUkgF]H00Ukg1F<H00ENmf<HHaQW
>Ekg0056<@0000<000@Q12400P@Q00<000@Q12400`@Q00`<Hcg_OomW>Cg_
CW=BU4icDYA>Le:DCW<5DY@01DicDYABU5:DCW<00TYB00E>Le:DCW=>LdHa
009:DP05CW=BU5:DCW=:DP02CW<045JeDYABU5JeF]IBU4icBU9BU4Ha@Q0i
cSg_BU9BU4ic14YB0T8@00Hmkd8@AS5:DU:DE[D2BU801D8@?Nm2448@BU80
0THa00A:DTicBU96<@9:DP9>L`05AS52448@@Q16<@02CW<3BU801DicDYAB
U4icE[D00Tic00A:DTicBU9>L`A:DP04AS5:DTicE[D2DY@2CW<014HaBU9:
DTYB0Tic00=6<D8@AS400TYB00A6<D8@@Q16<@=:DP96<@=:DP=>L`9:DP9>
L`03AS5243W>00<mk`03AS5:DTYB00=6<@9:DP=6<@04@Q16<DHaAS42BU80
14icBU9:DTYB0Tic14YB00A>Le:DDYA>L`=:DP9BU09>L`05@Q0icS6<9BTY
BP029BT01QS65:D@Q1245:D@Q0D<H`@8@P0336<8@PQ20088@P<48@032484
8@Q200D48@0324848@@Q00<48@0300048@Q200X48@0324848@@Q00D48@88
@P061248@P@Q1248@P@Q1PQ21@aS00H@Q0aS6<HLibU:9BT28@P01BDY:DXY
BRU:9BT00QcW00<Q21cW8@P00QcW00@HaR48:DX]J`8e[@8mk`06AS5:DTic
DYA:DTic0TYB0dic0THa00LaS3F]@Q1>LekgF]I:DP02DY@2E[D00e[FE[EB
U007DY@00eJeDYABU003DY@00eJeDYABU003DY@014icDYAF]E[F15:D00EJ
eV<HG_MF]Dic00EBU09F]@04DYAF]EJeE[D2DY@035JeDYABU5JeF]INme[F
E[EBU5JeF]INm`9F]@9BU0=JeP04G_MJeUJeDY@2E[D3F]H00e:DCW=F]@02
E[D01E[FE[EF]E[FE[D00U:D00E>LeJeG_MJeUJe009BU003E[EJeUJe00AF
]@04G_MJeU[FF]H8E[D00e:DE[EJeP02G_L3F]H2E[D01U:DE[EF]E:DF]IF
]@9JeP04G_MJeU[FE[D4F]H00ekgF]IJeP03G_L7F]H00eJeF]IJeP02G_L0
0e[FG_MJeP02G_L00eJeF]INm`03HaP01E[FG_MJeUkgHaP00VLi0V<H00EJ
eUkgG_MJeUkg009S6003G_MJeV<H009S6003F]INme[F009Nm`05HaQNmf<H
HaQW>@03HaP00ekgHaQS6003HaP2IcT00f<HIcUS6002IcT2HaP3G_L00fLi
HaQW>@03HaP2G_L2HaP5IcT2JeX00fLiHaQNm`02IcT4HaP01FLiHaQNmf<H
IcT00f<H00=Nmf<HHaP026Li00=S66LiIcT016<H0VLi0V<H00=Nmf<HIcT0
0V<H0U[F0Ukg00IJeUkgF]INme[FG_L3HaP015kgHaQS65kg0V<H0E[F0DHa
000212400`0012448@0312402`Q212448@Q2>Lioof]J@Q1BU5JeDY@00dic
0e:D00AF]E:DE[EBU09>L`0;DYA>LdYBBU9>Le:DBU96<DYBCW=:DP02AS40
1U:DCW=:DTHaCW=BU09F]@9BU09:DP=BU003BU92448@0096<@9BU003CW=B
U4ic00924003>Li244Ha0096<@05BU9>LdYBCW=:DP03AS42BU82CW<03TYB
@Q1244HaDYAF]DYBAS4mkcF]@Q16<DicBU82AS401dicF]IJeUJeDYA>LdYB
009>L`0:DYA>LdicBU9>LdYBAS5:DTHaDY@2F]H00eJeBU96<@02BU83CW<0
1DYBDYA:DTHa@Q000THa0d8@00I6<DYBBU9:DTHaCW<2DY@2CW<015:DCW=:
DTHa0TYB00A6<Cg_?Nm24096<@04@Q0mkcW>?Nl2@Q03BU8034icBU9:DTHa
BU9>Le:DCW=:DTHaCW=BU09F]@04DYA>LdYBBU83AS4025:DE[E:DTYB;F/L
iaBU36<248@00`aS2488@P0424800`@Q2488@P0412422485124324851240
0`Q212448@0A12400`Q212448@0412400`Q212448@0412400`Q212448@06
12432482124010Q21248@P@Q0PQ20PaS0QBU00HHaQBU5:DDYAcW6<H27>L0
0aS67>LHaP026<H03ABU6<HDYAcW6<HQ22U:;F]6<D8@AS5:DTHa009>L`=6
<@07BU96<Cg_=JdaS4HaDY@00U[F00M:DU:DE[E>Le:DCW=BU003F]H00eJe
CW=BU003E[D5DY@00dicDYABU005DY@01eJeF]IJeU:DCW=BU5Je009JeP06
E[EBU5JeDYA>Le:D0eJe00ABU4icDYABU0EF]@9BU004E[EJeUJeF]H3E[D2
F]H3E[D01U[FG_MNme[FE[EBU0AF]@03DYAF]EJe00=BU005E[EJeUJeF]IB
U002BU800e:DF]IF]@05E[D00e:DF]IJeP08F]H025:DE[EF]E[FE[EJeU:D
E[D3F]H3E[D00e[FDYAF]@02DY@4E[D01E[FG_MNmekgF]H00UJe0U[F00=N
me[FE[D00U[F00=Nme[FG_L00U[F00IF]E[FE[EBU5JeF]H3G_L00e[FG_MJ
eP02F]H015JeF]IJeUkg15[F00IF]E[FG_MNmf<HIcT2G_L2F]H6G_L2F]H0
0ekgHaQNm`02G_L00f<HG_MS6003HaP2IcT4HaP00ekgHaQS6003IcT2HaP0
0ekgHaQS6005G_L5HaP00ekgHaQS6002JeX2IcT016]JIcU[FV]J0fLi16<H
00EW>F<HIcUNmf<H009Nm`9S609Nm`03HaQW>FLi00QW>@9S6003IcUS66<H
009S609Nm`9JeP04HaQ[FVLiIcT3G_L2HaP2G_L015[FG_MS66<H0VLi00MS
65kgG_MNmf<HIcUJeP01AS400003124000@Q00848@0;00048@Q2248000@Q
36<e[GooIcU6<@03DY@2CW<025:DCW=>LeJeDYAF]E:DCW<3DY@024icBU9:
DTicDYA>LdYBAS42BU8014HaBU9>Ldic0TYB00=>LeJeE[D00e:D00]>LdYB
CW=F]DicBU9243g_BU96<Dic00=BU005CW=243g_?Nm24003AS42BU801Dic
BU96<DYBAS4014YB00U>LdHaAS5244HaDYAF]DicAS400SW>00E244YBBU9:
DTHa009:DP06E[EJeU:DE[E>LdYB0Tic00=BU4icCW<00dYB0THa00I:DU:D
E[EJeUJeCW<2AS400dYBCW=BU003CW<00dYBAS524005@Q02AS4014YBAS5:
DTYB0e:D00E:DU:DDYA:DTHa009:DP04@Q0mkcW>@Q02BU801Cg_>LhicSW>
@Q000THa00M:DTHaBU9>LdHa@Q1:DP02DY@014icAS5:DTic0U:D00AF]Dic
BU9>L`96<@04BU96<E:DDY@2CW<01C6<8@PDY@aS48@00`aS1PQ20P@Q00<8
@P@Q24800`@Q00<8@P@Q12400PQ25@@Q00<000@Q124010@Q00<000@Q1240
2P@Q00<8@P@Q12400`@Q00<8@P@Q12400`@Q00<8@P@Q124010@Q00@8@PaS
36<<H`<DY@036<HDYAS600<Li`<HaP0;7>LHaQBU6<HLiaS67>LHaQcW:DXa
S002@Q03AS4024icBU9:DT8@AS5:DT8@?Nl2=Jd01DHaDYAJeU:DCW<015:D
00A>Le:DF]IJeP9F]@03CW=BU5Je00=F]@=BU004CW=BU4icDY@2E[D2DY@2
E[D02E[FE[EBU4icDYAF]E[FG_MF]@02DY@2CW<015:DE[EF]E[F15:D15Je
0U:D0UJe00=JeUJeE[D00eJe00=JeUJeF]H00UJe00UJeUkgF]IJeUJeDYAF
]E[FE[D00U:D00AF]E:DE[EF]@9BU004E[EJeU[FCW<2BU800e:DE[EJeP02
DY@00e[FDYABU002E[D3F]H00eJeF]IJeP02F]H2E[D015:DE[EF]E[F0eJe
15[F15Je15:D00EJeUJeE[EF]Ekg009S6005F]IF]E[FE[EJeP02E[D2F]H0
0ekgF]INm`04F]H025:DE[EF]EJeF]INmf<HF]H3G_L00e[FE[EF]@02F]H3
G_L01EJeF]IJeUJeF]H00V<H00=W>EkgF]H00U[F0Ukg00EJeUkgG_MS65[F
00MNm`9S6007IcUS66LiIcUS66LiG_L01F<H00=W>F<HIcT01V<H0Ukg00=S
65kgG_L016<H0Ukg0VLi00A[FVLiIcUW>@9[FP=W>@03HaQW>F<H009S609W
>@9S609Nm`9S60=Nm`05HaQW>F]JIcU[FP04IcT016<HIcUW>FLi1V<H0ekg
00AS66LiIcUW>@9Nm`03HaQNmf<H00ANm`=S6008IcUS65kgG_MS65kgIcUN
m`52400000@000@Q124000848@0;00048@Q2124000Q2=Jeoof<H@Q1F]@02
DY@2CW<3DY@00dicDYA>L`02DY@3CW<015:DCW=>LdYB0Tic0TYB0dHa00A:
DTHaBU9:DP9>L`03DYAF]EJe009>L`06BU9BU5:DCW=:DTic14Ha0TYB0e:D
00A>LdYB?Nlmk`9:DP9BU0=6<@08CW=BU4icBU96<DYBDYA>L`96<@06@Q0m
kdHaDYA>LdHa0SW>0cg_00=244HaBU800TYB00A>Le:DDYABU09:DP06AS5>
LdicCW=:DTic0dYB00E6<E:DE[EF]E:D009:DP07CW=:DTYBCW=BU4icBU80
1DHa00@mkcW>@Q16<@=:DP03AS5>Le:D009BU003BU96<DHa0096<@9:DP0:
AS5244HaAS4mkcF]>Li244Ha@Q02?Nl02D8@AS56<DYBDYA>LdHaBU9BU002
E[D2DY@03UJeDYAF]E:DCW=:DTHa=Jd]Jb489BTLiaS648@336<2248<1242
248=12400`Q212448@0412400`Q212448@0a12400`Q21248@P0212422485
36<348@35:D27>L36<H27>L01AS69BTYBSW>?Nl0148@00E6<Cg_>Lhe[CW>
0096<@08DYAF]E:DE[E>LdYBCW=:DP9BU003E[ENme[F009JeP=F]@ABU09>
L`=BU09>L`06DYAF]EJeDYAJeUJe0e:D0e[F0UJe0U:D00=F]E:DE[D00e:D
0Tic0U:D0UJe00=JeUJeDY@00U:D0U[F0UJe00=BU5JeF]H015Je00=JeUJe
E[D00U[F0UJe00=BU5JeE[D00eJe00=BU4icE[D00UJe00=BU4YBBU8014ic
0U:D00=F]E[FE[D00UJe0U[F00=F]E[FE[D015[F00AF]E[FF]IJeP9F]@03
DYAF]EJe00AF]@03F]IF]EJe00AF]@04DYAF]E:DF]H2HaP00e[FE[EJeP02
G_L2F]H00eJeF]IJeP02F]H00eJeF]IJeP02F]H2E[D00e[FG_MNm`02F]H0
0ekgF]IJeP02F]H2E[D015[FG_MJeUkg0e[F0UJe0U[F00=Nme[FG_L00Ukg
0V<H00=Nme[FF]H00V<H00=Nme[FHaP00VLi0Ukg0V<H00AW>EkgG_MNm`=S
60=Nm`9S6006IcUS66LiHaQW>F<H0ekg00=S66LiHaP00Ukg0V<H0fLi00AS
66LiHaQW>@9[FP04HaQW>FLiIcT2JeX016LiHaQS66<H0VLi0f<H00ANmf<H
G_MNm`MS6004JeYW>FLiIcT2HaP016LiHaQW>F]J0VLi00IS65kgG_MJeUkg
F]H3G_L00fLiHaQS6006HaP3G_L00f<HIcUW>@02HaP01EkgF]INmf<HF]H0
0D8@00041240100012448@Q20`@Q00P<Hc6<OomS64HaDYAF]E:D0Tic00EB
U4icDYABU4ic00ABU0M>L`9:DP03AS5:DTHa0096<@A:DP05CW=BU5[FE[EB
U002BU800dicDYABU002CW<01TYBAS52448@BU9>L`=BU00@BU96<D8@@Q16
<DYBDYA>LdYB@Q16<DYBDYA>LdHaBU83CW<2AS401T8@?Nm6<E:DCW=6<@8e
[@04?Nm2448@@Q03AS401DYBCW=BU5:DCW<00dYB0Tic14YB00A6<DYBBU9B
U09F]@03DYA:DTYB009:DPE>L`05BU96<D8@AS524003?Nl2AS42BU801DHa
CW=BU5:DCW<00TYB0THa00=:DTHaAS400THa00=244Ha>Lh00SW>00<mkdHa
?Nl00Sg_0T8@00=6<DicDY@00dYB00M>Le:DE[EBU5JeDYAF]@02DY@2BU80
0d8@>LhaS0029BT01AcW6<HDYA2436<00PQ200D48@Q212448@Q200@48@04
00048@Q2248=12400`0012448@0712400`0012448@0:12400`0012448@06
12400`Q212448@03124010Q212448@Q24P@Q0PQ20`@Q0PQ20PaS00<8@PaS
48@00Q2400<<Ha245:D00QBU1QS60QcW00@YBRe[>Lhmk`924004?Nm2448@
>Lh2=Jd013W>AS5:DU:D0UJe0U:D0Tic00=:DTicE[D00U[F00MNme[FF]IB
U5JeDYAF]@03DY@2CW<6DY@00eJeDYAF]@02E[D2DY@2E[D2F]H00eJeF]I>
L`03DY@01UJeDYABU4icDYA>L`9BU09F]@03F]IBU5:D009BU09JeP05E[EB
U5JeDYAJeP04E[D3F]H5E[D2DY@3E[D3DY@2E[D015:DBU9:DTYB14ic00=B
U5[FF]H00UJe0e[F0UJe15[F0UJe0e[F0UJe00=BU5JeE[D01UJe0U:D00QF
]E[FE[EF]E:DE[EJeV<H0Ukg0UJe00IJeUkgG_MF]E[FE[D3F]H00eJeF]IF
]@02F]H01EJeF]IF]E[FG_L01e[F0UJe0U[F00=Nme[FF]H00U[F0eJe0ekg
00=JeUkgG_L00V<H00=JeUJeF]H00V<H00EJeUkgHaQW>F<H00=Nm`=S6003
G_MS66<H009W>@ANm`05IcUS66LiHaQW>@02HaP3G_L3HaP3G_L026<HIcUW
>F<HIcUS66LiHaP3JeX00fLiHaQW>@04IcT2HaP3IcT00f<HG_MS6002G_L4
HaP01EkgHaQS66LiJeX00fLi0f<H16Li0V<H00MJeUkgF]IJeUkgF]INm`02
HaP016LiHaQS65kg16<H0ekg0V<H00=W>F<HHaP00ekg0F<H0E[F0D8@0000
0`001240000212402`0012448@Q2124000aS>Lioof<H?Nl00UJe00=BU4ic
CW<00e:D00I>LeJeDYAF]E:DCW<3DY@6CW<3AS402dicBU9:DTHaBU9>LdYB
CW=BU5JeCW<00TYB00=>Le:DCW<00Tic0THa00A:DTHaBU9:DP9BU007CW=B
U4icAS4mkdHaCW<00U:D00A243g_@Q1:DP9>L`96<@03CW=BU5:D009>L`05
@Q0mkcg_?Nm6<@02?Nl01CF]?Nlmkd8@AS400dYB0THa1DYB0THa0TYB00AB
U4icBU9:DP96<@04CW=BU5:DDY@2BU800dicBU96<@03CW<00e:D@Q0mk`02
?Nl01dHa?Nlmkcg_AS5:DTHa00924004AS5:DTicDY@2BU87@Q02?Nl2<H`0
13g_BU9>LdYB0SW>0T8@00A:DUJeE[EJeP9BU0AF]@08DYA6<D8@=JdU:B48
6<HDY@8@Q08<H`<8@P<48@0324848@@Q00/48@0324848@@Q01448@030004
8@@Q00848@0300048@@Q00848@0300048@@Q00D48@0300048@@Q01L48@03
00048@@Q00848@0300048@@Q00@48@0324848@@Q00<48@<8@P041248@PQ2
248236<348@25:D66<H27>L012489BT]Jc6<0SF]00@aS3W>AS5:DP96<@07
CW=BU5:DAS5:DU:DBU800Tic00=BU5[FE[D00U[F00=F]E[FF]H00UJe00U>
Le:DBU9BU4icDYA>LdYBDY@00UJe00=BU4icDY@00U[F00AF]E:DE[EF]@9J
eP03DYAF]EJe009JeP9BU004CW=BU5JeDY@3CW<015JeF]IF]EJe0Tic0U:D
00=F]E:DCW<015Je15:D00=F]E[FF]H01UJe00=BU5JeDY@00e:D1Tic00E:
DTHaBU9>LeJe009JePAF]@AJeP=F]@9JeP=F]@9JeP04E[EBU5JeE[D2F]H0
0ekgF]IJeP03F]H3E[D00e:DE[EJeP03F]H3G_L2F]H01EkgF]IF]E[FE[D0
1E[F00=Nme[FG_L00e[F0Ukg0U[F0UJe1E[F00=Nme[FF]H00UJe1e[F00=N
mf<HG_L00Ukg00=JeUkgG_L00Ukg00AS65kgHaQS609Nm`05HaQW>FLiHaQJ
eP02G_L2HaP00ekgF]INm`03HaP01fLiHaQS66LiG_MJeUkg00AS609Nm`9S
60=W>@04JeYW>FLiIcT3JeX00f<HIcU[FP02JeX2IcT00f<HIcUS6002HaP0
0fLiHaQW>@02HaP3IcT2HaP2G_L016LiJeYW>FLi16<H0fLi0V<H00=Nme[F
G_L00ekg0U[F16<H00ENme[FHaQS66Li009S609Nm`05IcUS66<HIcUNm`02
F]H1G_L1F]H1AS4000P48@0;24848@@Q248icWooG_M245:DE[EBU002CW<2
DY@024icDYA>LeJeDYA>Le:DCW<2DY@014icBU9:DTic0dYB00=6<DYBBU80
0TYB0THa0TYB00A>LeJeDYA>L`9:DP03CW=BU5:D009>L`05AS5:DTHa@Q1:
DP02CW<2DY@2CW<2@Q02BU800e:DCW=6<@02@Q000dYBDYA:DP02BU801Tic
E[EBU4YBCW=2408mk`=24003>Lhe[CW>00924004BU96<DYBBU82AS45BU83
AS400dYBCW=>L`02BU800dHaBU9:DP03DY@2BU801DicAS5:DTYBCW<00U:D
00E243g_>Li244Ha00<mk`96<@=24004BU96<DicCW<2BU803d8@?Nm243g_
@Q0mkcW>?Nm243W><H`mkdHaDYA6<@02>Lh2@Q001DHaDYAF]E[FE[D00U:D
0U[F00MBU5JeBU9243F]9BTQ20026<H248@01`Q236<8@PQ21248@P@Q0088
@P<48@0300048@@Q01H48@0300048@@Q00X48@0300048@@Q00/48@032484
8@@Q00L48@0324848@@Q01L48@0324848@@Q00<8@P<48@03248<H`aS008<
H`8@Q0<DY@8HaP035:DHaQS6008Li`038@PU:Be[008e[@0:<H`e[Cg_AS5:
DT8@BU9>LeJeCW<2BU8024icBU9>LdicDYAJeUkgF]H4E[D015[FDYA>LdYB
0Tic00AF]E:DDYA>L`9BU003E[EBU4ic009F]@06F]IF]E:DDYAF]E[F0UJe
00=BU5JeE[D00U:D00A>Le:DDYABU0=>L`03DYAJeUJe009F]@9>L`9BU004
E[EBU5:DDY@2E[D01U:DCW=BU5JeDYAF]@=JeP04E[EBU5JeDY@2E[D4DY@2
CW<00dYBCW=BU002CW<3BU801dicDYAJeU[FE[EJeU:D009F]@=JeP=F]@=J
ePAF]@06F]IF]EJeE[EJeUkg15[F00=Nme[FE[D00e:D0e[F00=F]E[FG_L0
0Ukg1E[F00EF]E[FF]IJeUJe00=JeP03G_MJeU[F009JeP9Nm`IJeP05E[EJ
eUkgF]INm`02E[D8F]H2G_L01V<HG_MJeU[FG_MS609Nm`AS609Nm`05HaQW
>F<HG_MJeP03HaP5G_L2HaP016LiHaQW>F<H0U[F00ANmf<HIcUS609Nm`9S
6005IcU[FVLiIcUS6002IcT4JeX3IcT016]JIcUW>FLi16<H0VLi1F<H00QW
>F]JHaQS65kgHaQW>F]J0VLi00ENmf<HIcUW>F<H00=W>@09HaQJeU[FG_MS
65[FG_MJeUkg00AS6005F]INmf<HIcUS6003G_L2HaP016LiHaQW>Ekg0U[F
0Ekg0E[F0D8@000010@Q00048@000P@Q00d000@Q248000@Q36<mkgooHaPi
cTicE[E>L`02BU82CW<2DY@2E[D00e[FE[EBU003CW<2DY@5CW<01E:DBU9:
DTHa@Q000TYB0dHa00E:DU:DCW=>LdYB009>L`9BU003CW=:DTYB00A:DPAB
U003CW=6<DYB009:DP04CW=BU4icBU82@Q0014YBCW=:DTYB0dHa0Tic00A6
<Cg_>Lhmk`96<@<mk`06@Q1:DTHaAS5244Ha14YB0THa00=:DTHaBU800Tic
00EBU4YBAS5>LdYB0096<@03BU9>Ldic0096<@03BU96<DYB009>L`9:DP96
<@04@Q0mkcW>?Nl3@Q02AS42BU82AS4014YBDYA>LdYB0d8@00<mkcW>=Jd0
1CF]00LaS3F]=Jde[Cg_@Q1>L`02DY@01UJeDYAF]EJeBU92408YBP038@PH
aQS6008@Q00536<8@PQ236<8@P0212400`Q21248@P0212400`Q212448@0[
124010Q212448@004@@Q00<8@P@Q12402@@Q00<000@Q12402`@Q00<000@Q
12400P@Q00<8@P@Q124010@Q00<8@P@Q12400PQ20PaS0Q240QBU00<HaQBU
6<H00QS60QBU00XHaRDY9BTU:CF]?Nm6<CW>?Nm:DP9>L`03BU9>LdYB00=:
DP04CW=F]EJeE[D2DY@025JeF]IJeUJeDYA:DTicDY@3CW<2DY@00eJeCW=>
L`02CW<3E[D3DY@2E[D015[FE[EF]EJe0U:D00AF]E:DDYABU09>L`9BU09F
]@05DYAF]DicDYA>L`0:DY@01DicDYAF]E[FE[D00U:D0U[F01AF]E:DDYAF
]E:DE[E:DTHa@Q1:DU:DE[E>LdHa@Q0mkdYBCW=:DU:D0eJe0e[F00=NmeJe
E[D00UJe0U[F0UJe0U:D1UJe25[F0UJe0U:D00=JeUJeF]H00e[F1Ekg00=J
eUJeE[D00ekg00=F]E[FF]H00Ukg00UJeUJeE[EJeUkgHaQNme[FE[D00Ukg
0U[F00UF]E[FF]IJeUkgF]IF]E[FE[D01U[F0ekg00AS65kgF]INm`=S60AN
m`04F]IS66LiIcT3G_L026<HG_MJeUkgHaQNmf<HG_L3HaP015kgHaQNmekg
0U[F00ANmf<HHaQW>@AS6009JeYW>FLiIcUS66LiJeYW>F]J009W>@03HaQW
>FLi009S6003G_MS66Li00=W>@9[FP9W>@=S6003G_MS66<H009S609W>@=S
609Nm`AS609Nm`05F]INmekgHaQNm`02F]H2HaP4G_L00f<HG_MS600:HaP0
0e[FG_MJeP01AS40000300048@@Q00848@0400048@@Q2482124020aS>Lio
oekg?Nm>LeJeCW<2BU82CW<00e:DE[EBU002E[D3DY@3CW<00e:DCW=>L`02
CW<2DY@00dicBU96<@02AS42BU82AS4014YBCW=>Ldic0TYB00Q>Le:DDYAB
U4YBCW=:DTHa0TYB0U:D00EF]DicCW=:DTHa009:DP04CW=BU4icAS42@Q03
BU801dHaBU96<DHaBU9BU48@008icP06?Nm:DSg_?NlicT8@1THa00=:DTHa
BU800dYB0dHa00=>Le:DCW<00TYB00E>LdYBAS5244YB009>L`05BU96<DHa
BU96<@03CW<014YB@Q16<D8@13g_0T8@00M6<DYBAS56<DYB@Q1:DP02DY@0
0dYB@Q124002@Q02>Lh01SF]>LhicSW>=JdaS0<e[@03?Nm244ic009BU00;
E[EBU5:DE[E:DTHa;F/YBR487>LDY@0248@524800`@Q24848@0324831240
10Q212448@002`@Q00<000@Q24801@@Q0PQ200<48@00124010@Q00<8@P@Q
124020@Q00<8@P@Q12401P@Q00<000@Q12402P@Q00<8@P@Q12403P@Q00<0
00@Q124020@Q00D000@Q12448@Q200H48@@8@P0336<@Q12400@DY@8HaP8D
Y@0948@HaQcW9BTYBRDY=Je244Ha008mk`03AS5BU5:D009:DP05CW=:DTYB
BU9>L`02E[D3DY@3F]H01eJeDYA>LdYBCW=BU4ic00ABU0A>L`9F]@03F]IB
U5:D009BU004F]IF]E[FE[D4DY@025JeDYABU4icDYA>Le:DE[D4DY@3CW<3
DY@3CW<00eJeDYABU002DY@01eJeF]IF]EJeDYAF]E[F00ABU003E[EBU4YB
00=6<@04DYAF]DicAS42@Q03BU800eJeDYAJeP02E[D015[FG_MJeU[F0UJe
00EJeUJeF]IJeUJe00=BU003E[EJeUJe00=F]@03F]INme[F009JeP03E[EN
meJe009BU003E[EJeU[F00AJePENm`05F]IF]E[FG_MS6003F]H3G_L2F]H0
1UJeF]INmf<HF]IF]@9JeP05G_MJeU[FF]IF]@06F]H00eJeF]IJeP05F]H0
2UkgHaQNmekgF]INmf<HG_MS65kg0V<H0U[F00=S66LiIcT01Ukg00AS65kg
HaQNm`ES6004G_MJeUkgF]H2G_L6HaP4IcT01F<HIcUW>FLiJeX01VLi00AS
65kgHaQS60=W>@=[FP03IcUS66<H00IS609W>@03HaQW>F<H009S609Nm`07
HaQW>F<HHaQJeUkgF]H00ekg00EJeUkgG_MNmf<H009JeP9Nm`9S6003G_MS
66<H00AS609W>@9Nm`9JeP5240000P@Q00<000@Q12400`@Q00`8@P@Q1248
@SW>OomW>Cg_BU9>LdYBCW<3BU82CW<00e:DE[EJeP02E[D00dicBU9>L`02
DY@2CW<2DY@2E[D00dicBU924002BU83AS401TYB@Q1:DTicE[E>L`9:DP0:
CW=BU4icBU9>LdYBAS5244HaBU82DY@014icBU96<Dic0TYB00]6<DYBBU96
<DYBAS5:DTicDYAF]Dic00=:DP03CW=:DSg_008mk`03@Q16<Cg_0092408m
k`9240=:DP96<@05BU9>Le:DDYA:DP02AS401DYBCW=:DTYBCW<014YB00=6
<DYBAS400Sg_00E244icCW=:DTHa009>L`0:BU92448@@Q0mkd8@AS5:DTHa
@Q04BU82@Q02AS401T8@?NlicSW>AS5240<mk`07=JdaS2U:9BTaS2e[@Q00
0TYB00Q>LdYBAS5243W><H`Q21S60PaS0PQ20P@Q00<8@P@Q12407@@Q00<0
00@Q12401@@Q00<8@P@Q12401`@Q00<000@Q12400P@Q00<000@Q248050@Q
00<8@P@Q12402P@Q00<000@Q124070@Q00<8@P@Q24800PQ200@<H`Q236<@
Q08DY@0348@DYABU008HaP045:DHaQS67>L28@P2>Lh01dicDYA>LdYBAS4m
kdHa009:DP=BU004E[E>LdicDY@3E[D2DY@01DicBU9>LdicE[D00U:D00=>
Le:DDY@00Tic0U:D0U[F0e:D0e[F00E>Le:DDYABU5Je00ABU003E[EBU4ic
00ABU005CW=:DTicCW=F]@02DY@2CW<4DY@00eJeF]IF]@04E[D2F]H00eJe
DYAF]@02E[D015:DBU96<DHa0Tic0U:D00I>LdYBAS5244YBCW<3E[D01E:D
E[EJeU[FE[D00U[F00=F]E[FE[D015Je00MJeUJeE[EF]E[FG_MJeP02E[D0
15kgF]IJeUJe0U:D00=F]E[FE[D00U[F0Ukg15[F00MNme[FG_MJeUJeF]IN
m`02HaP00e[FG_MNm`02F]H3E[D2G_L8F]H02eJeF]IJeUJeF]INme[FG_MF
]E:DE[D00e[F00=F]EkgG_L00V<H00=Nme[FF]H00Ukg00MJeUkgG_MS65kg
HaQNm`02HaP016LiHaQNme[F15kg00EJeV<HG_MS65kg00=S6006G_MS65kg
F]INmf<H0fLi1V<H00=W>F<HHaP00f<H0fLi0V<H00=NmfLiG_L00V<H0VLi
00=[FVLiIcT00VLi00=S65kgG_L00Ukg00=S65kgG_L00ekg0V<H15kg1F<H
00=Nme[FF]H00f<H0ekg0V<H0Ukg00=JeUkgHaP00f<H00ANmf<HHaQW>@9S
6003F]INme[F0052400000D48@0012448@0000<48@09248000@Q36<icWoo
IcTmkdic00I:DP07CW=BU5:DF]IF]E[FDY@00dic0U:D00Q>LdYBCW=BU5Je
DYA>LdYB1dHa00=244YBCW<00U:D00E6<DYBDYABU4ic00=:DP96<@03@Q1:
DU:D009BU007BU96<DicCW=6<D8@AS400TYB00A6<D8@BU9>L`9BU00:CW=:
DTYBBU9>LdHa@Q0icSg_AS42@Q02?Nl3@Q000cg_AS5:DP02BU800d8@AS5>
L`02DY@01DYBAS56<DYBCW<00TYB00=>LdYBCW<01DHa00E243g_AS5>Le:D
009:DP03CW=:DTYB00A24096<@04BU96<D8@AS42CW<00dYB?Nm6<@02BU80
0dHa@Q0icP02?Nl2@Q02?Nl02SF]<H`YBRDY<H`e[D8@AS5:DTic0TYB00E2
43W>=JdQ21cW00<<H`<8@P848@0324848@@Q00@48@0324848@@Q02h48@03
0008@PQ200D48@0300048@@Q00X48@88@P<48@88@QL48@0300048@@Q00T4
8@0324848@Q200@8@P8<H`@@Q0045:DHaQBU6<H25:D021S68@PYBRDY<H`m
kdicDY@2BU82@Q000dHaBU9:DP07DY@2E[D015[FDYA>Le:D0TYB15:D00A>
Le:DCW=BU09>L`03DYAF]E[F00=BU09JeP04E[EBU4icDY@3E[D014icDYAB
U4ic0U:D00M>Le:DDYA>Le:DCW=:DP02DY@015JeCW=:DTic1E:D0U[F00AB
U5JeDYAF]@9JeP09E[EBU5:DE[EJeTicBU96<DYB009>L`9BU005CW=6<DHa
@Q16<@02DY@2E[D02E:DF]IJeUJeF]IF]E[FG_MJeP02E[D2DY@5E[D2F]H2
E[D4F]H01UJeDYABU5:DF]IF]@=JeP06G_MJeU[FF]INme[F0Ukg0e[F00=N
mf<HG_L00U[F00=Nme[FF]H00UJe00=JeUkgG_L035[F0ekg00=JeU:DE[D0
0UJe00AJeUJeE[EJeP=S6003G_MJeU[F00ANm`03HaQNmekg009Nm`ES609J
eP=Nm`03HaQNmf<H00IS6004G_MJeUkgG_L2HaP016]JIcUS65kg0V<H0VLi
1F<H16Li1V<H00=W>F<HJeX00VLi00M[FVLiIcUS65kgHaQJeP02G_L2HaP3
G_L2HaP4G_L3HaP015kgHaQNme[F1ekg00=S65kgG_L00ekg1f<H0VLi00AS
65[FHaQJeP52400000<000@Q12400P@Q00`000@Q1248@P@Q000<HcF]OomW
>Cg_CW<2DY@3BU8014HaBU9:DTic0e:D00=F]E:DDY@00Tic00=BU4YBCW<0
15:D0Tic00=:DT8@AS400dYB00I243g_@Q1:DU:DCW<2BU82CW<00dYBAS5:
DP02AS43@Q000dYBCW=>L`02BU82DY@2BU801e:DCW=>LdYBAS5:DTic00=B
U008CW=:DTYBCW=6<D8@?Nm240=6<@A24003AS52448@00=:DP=>L`04DYA>
LdicBU83AS42BU8024icDYABU4icBU96<D8@AS42@Q0014Ha@Q16<DHa0dYB
00a6<D8@?Nm244HaBU9>LdYBCW=:DTHaBU82AS44@Q002Cg_=JdicT8@AS52
43g_=JdaS004:DX00be[9BT]J`02<H`01Re[8@PHaQS648@<H`@8@P031248
@P@Q01448@0324848@@Q00<48@0324848@Q200T48@0424848@@Q24881240
0`Q212448@0512400`0012448@02248912401@0012448@@Q000030@Q00<8
@P@Q12405`@Q00<000@Q124020@Q00<8@P@Q12400`Q200<48@Q236<010aS
0a2400<<HaBU6<H00aS60QcW00@mkdYBCW=:DP8mk`03@Q1:DTYB00=:DPE>
L`04DYAF]EJeDY@3CW<00eJeDYABU002DY@00dicDYA>L`08DY@2E[D00e:D
CW=BU002DY@3E[D4DY@00dicDYABU002DY@4CW<00e:DCW=F]@02DY@00dic
DYABU002F]H01UJeF]IF]EJeF]IF]@9JeP04G_MF]E:DE[D2G_L015JeAS5:
DTYB0dic00E:DTHaAS5:DTic00ABU003E[EJeU[F00=F]@=JeP05E[EBU5Je
E[EJeP03E[D2F]H2E[D00e:DE[EJeP02F]H3E[D015[FE[EF]EJe0ekg0UJe
1E[F25kg00EJeUJeE[EJeUkg009JeP=F]@03G_MJeU[F009F]@=JePANm`03
F]INme[F00EF]@05F]INmekgIcUS6003G_L00e[FG_MNm`05F]H2G_L026<H
G_MNme[FG_MS65kgF]H2G_L2HaP3G_L00fLiHaQS6003G_L2HaP4IcT4HaP0
16]JIcUS65[F0Ukg00QS66LiHaQW>F<HIcUS66Li0f<H0fLi00=S66LiHaP0
0f<H1Ekg0U[F0ekg0f<H0Ukg0V<H00AW>F<HHaQJeP9Nm`03HaQW>F<H009N
m`=S60ANm`YS6003G_MS65Je005240000`@Q00<000@Q12400P@Q00X8@P@Q
1248@SW>OomS63g_CW=BU09>L`I:DP09DYAF]E:DE[E>Le:DCW=BU4ic009:
DP06CW=F]EJeDYA>Le:D0THa00A244YBAS56<@8mk`06@Q1>Le:DDYA:DTHa
0Tic0dHa00I:DTHa@Q0mkd8@BU82CW<01DHaBU9BU4icBU800Tic00IBU4ic
AS5244YBCW<3DY@3BU801dicAS4mkcW>?Nm:DTHa00A24005AS52448@BU96
<@02BU800dicBU9>L`02DY@00dYBAS524002BU801DHaBU9>LdicDY@00TYB
00I6<DYBAS5244Ha@Q02AS402D8@AS5>LdYBAS4icSg_@Q16<@02CW<00dYB
AS56<@03BU85@Q0013g_>LhicSg_0T8@00Hmkc6<<H`]JbU:9BT3:DX01be[
<H`e[Be[9BTLiaBU008@Q00336<8@P@Q00P48@0300048@@Q00P48@88@P@4
8@0324848@Q200`48@88@P031248@P@Q00848@0400048@@Q248>1242248B
12400`Q212448@0212400`Q212448@0212400`Q212448@0G12400`001244
8@0212400`Q212448@021246248236<248@00aBU48@@Q00248@26<H011BU
7>LQ23g_0Tic00=:DSg_>Lh00THa14YB00U>Le:DCW=>Le:DE[EBU5JeDY@0
0Tic0U:D00IF]E:DDYA>Le:DCW<2DY@00dicDYABU004DY@015JeDYAF]Dic
0U:D0eJe2e:D00]:DTicDYA>Le:DCW=F]DicDYA>Le:D00=F]@03F]IF]EJe
009F]@=JeP0=E[EBU5[FG_MJeUJeBU96<DYBCW=BU4icBU800THa00=:DTic
DY@00U:D0UJe00IJeUJeE[EF]E[FG_L2F]H00eJeDYABU005E[D2F]H015Je
DYAF]EJe0U[F00ENmeJeDYAF]E[F00=F]@03G_MS65[F009F]@EJePMNm`9J
eP03E[EJeU[F00=JeP9F]@AJeP9F]@AJeP=Nm`9JeP03E[EJeUJe00=F]@9J
ePAS6007G_MF]EkgF]INme[FG_L015[F00=S65kgG_L00ekg00IS65kgG_MJ
eUkgHaP3G_L5HaP2G_L2HaP00fLiJeYW>@02IcT015kgHaQW>FLi0V<H00AJ
eUkgHaQS609W>@=S609W>@9S6003G_MS66Li00=W>@=S60INm`=JeP04G_MS
66<HG_L2HaP01UkgHaQW>F<HIcUS60=Nm`9S609Nm`AS60ANm`AS60=Nm`AS
605Nm`5JeP4mk`0000T000@Q12448@00124000@Q24800P@Q00/8@SF]NmiN
mcg_DYAF]E:DBU9>Le:D009:DP05AS5:DU:DCW=F]@05DY@00dicBU9>L`03
CW<014YBCW=BU4YB0T8@00M6<DicDYA>Ld8@?Nm24002DY@00dYB@Q1:DP08
@Q03BU82CW<01E:DCW=>LdicBU800Tic0U:D00=>LdYBBU800dic00QBU4YB
CW=>LdHaBU9243g_0T8@00=6<DYBAS4014Ha00=244HaBU8014YB00M6<DYB
BU9:DTHa@Q1:DP02CW<2AS4014YBDYABU4YB1dHa0dYB00M6<D8@?NlmkdHa
BU9BU004CW<00dYBAS4mk`02@Q0033W>?Nm6<DHa?Nle[C6<>Lhe[Be[:DXU
:@<Q20037>LHaQBU00<@Q08<H`<8@P051248@PQ21248@P0A124010Q21244
8@@Q0PQ200<48@0012401@Q20`@Q0PQ20P@Q0PQ200@48@Q22488@P<48@@8
@PX48@88@P848@88@Q448@0324848@@Q00`48@0300048@@Q01P48@052484
8@@Q124000031242248010@Q2488@PaS0PQ200<<Ha2448@00Q240aS600<L
ib48:DX00Re[00He[CW>?Nm244HaBU82CW<2BU82CW<4DY@014icE[EF]EJe
0Tic15:D0Tic0U:D00AF]E:DDYABU0=F]@EBU003CW=BU5:D009F]@=BU003
E[EBU5:D009>L`03DYA>Ldic00EBU005CW=BU5JeF]IF]@02DY@02eJeF]IJ
eU[FE[ENmf<HG_MJeUJeF]H00Ukg00A>LdYBBU9>L`9BU0A:DP03DYAF]E:D
00AF]@9JeP=F]@03DYAF]EJe00=F]@=BU003F]IF]E:D009BU0=F]@05F]IF
]E[FF]IBU004E[D01UkgF]INme[FE[EJeP9F]@0=F]IF]E[FG_MJeUkgF]IN
me[FG_MJeUkgF]H00Ukg00IJeUJeE[EJeUkgF]H2G_L00eJeF]IJeP05F]H0
1EkgF]INme[FG_L00eJe0U[F00ANme[FG_MNm`9S6005G_MF]EJeF]INm`04
F]H3G_L2F]H3G_L2F]H00ekgHaQS6002HaP00fLiHaQS6003HaP3G_L016<H
IcUW>FLi0f<H00=Nmf<HG_L00V<H0Ukg00ES66LiHaQW>F<H009W>@=S609W
>@AS6004IcUS66LiG_L2HaP2G_L2HaP4F]H4IcT4HaP01FLiHaQNmekgHaP0
0VLi00ANmf<HG_MNm`=S609Nm`=S60=Nm`9S6004G_MS65kgG_L2HaP1F]H1
@Q0000848@0300048@@Q00<48@0;24848@0036<e[GNmF]Hmke:DE[EBU003
CW<2BU800dHaBU9>L`02DY@00eJeDYABU002CW<01DYBCW=>LdicDY@014ic
00e:DT8@@Q1244icDYA>Ld8@?Nm244icDYA:DP02AS46@Q03AS4014YBCW=B
U5:D0dic0dYB00A>Le:DDYA>L`9:DPM>L`03BU96<Cg_00=240=6<@03BU96
<DHa00924096<@=:DP06AS5:DTYBAS5>LdHa0TYB00M>LdYBBU96<DYBDYA>
L`02BU801DHaBU96<DHa@Q000THa0TYB0T8@0Sg_00A:DTicCW=>L`9:DP03
CW=:DTHa00924003?NlicSg_0096<@03?NlaS3F]008e[@03<H`YBRU:00<L
i`068@PHaQS648@<Ha240PaS0PQ200@48@Q22488@QD48@<8@P<48@H8@PD4
8@0424848@@Q1243248512400`aS2488@P0<1242248:12400`Q212448@08
12400`Q212448@0212400`Q212448@0<12401PQ212448@001248@Q<48@07
24848@Q224848@Q212400`Q200<<Ha2448@00a2400<DYAS67>L00R480Re[
00<aS3W>>Lh00T8@00=6<DYBCW<014YB00A>Le:DDYABU09>L`05DYAF]E:D
DYA>L`02DY@00eJeCW=>L`02CW<00eJeDYAF]@02DY@3E[D3DY@015JeCW=B
U5:D0eJe0e:D00=F]DicDY@00dic00UBU4icDYA>Le:DE[EBU4icDY@00eJe
0U:D1E[F00=Nmf<HG_L00UJe00AJeUkgF]I>L`9:DP04CW=BU5:DCW<2AS40
1DYBDYAF]EJeDY@01EJe00=JeUJeE[D01EJe0e:D0UJe00EBU5JeDYAF]E:D
009F]@=JePEF]@AJePAF]@03F]IF]EJe009JeP9Nm`AJeP06G_MJeU[FF]IN
me[F0UJe0U[F0Ukg25[F00ENme[FG_MJeUkg009JeP9F]@9JeP03G_MJeU[F
009Nm`03HaQJeU[F00QJeP9Nm`=JePANm`03F]INmfLi00MS60ANm`03HaQW
>FLi009W>@04HaQNmf<HG_L2HaP2G_L00f<HG_MS6002IcT3HaP016LiHaQS
66Li16<H0VLi0f<H00ANmf<HG_MS609Nm`AJeP03HaQW>FLi009S6005G_MS
66LiIcUS6002G_L5HaP00ekgHaQS6002HaP00ekgHaQNm`03HaP6G_L01F<H
G_MNmf<HE[D00Cg_00001@@Q00048@@Q00000`@Q00P8@P00124<Hc6<OomS
648@0U:D0Tic0e:D00=>LdYBBU800TYB00=>Le:DE[D00U:D00E>Le:DDYAB
U4ic0096<@0@BU9BU5:DAS5:DSg_@Q1:DUJeDYA:DSg_@Q1>LdYBAS42@Q04
CW<2@Q001dHaBU9>LdicBU96<DYB00=>L`05BU96<DHaCW=F]@02DY@2AS40
0dYBDYA>L`02CW<2BU801dicDYA:DT8@?Nm244YB009>L`A:DP03@Q0mkdHa
0096<@=2409:DP03AS5:DTHa009>L`06BU96<DHaBU9>LdHa0TYB00EBU4ic
CW=6<DYB0096<@A24096<@9240A:DP=6<@924004>Lhe[CW>@Q02?Nl00c6<
:DXYBP028@P011cW6<HHaQBU0Q2400<<H`@Q12400`Q20P@Q0PQ200@48@Q2
1248@PH48@0300048@@Q00/48@04248<Ha24248312400`Q212448@022482
12400`Q236<8@P07248212400`Q21248@P0@12400`Q21248@P031243248I
12400`0012448@0Y1242248436<01A245:DHaQS65:D00aS600<Q22e[<H`0
0T8@00E6<DYBAS5:DTHa009:DP=>L`08DYA>Le:DE[EJeUJeDYA>L`EBU004
CW=BU5JeE[D4DY@2F]H4DY@5E[D00e:DCW=:DP04DY@4CW<00e:DE[EBU003
DY@00eJeF]IJeP04DY@00eJeF]INm`02G_L00eJeDYAF]@02E[D01E[FDYAB
U4icBU800Tic00UBU4YBCW=>Le:DE[EBU5JeF]H00UJe00ABU5[FF]IF]@=B
U09F]@9BU003CW=F]EJe00ABU0=F]@07DYAF]EJeG_MJeUJeDY@00UJe1e[F
0U:D00EF]E[FG_MJeUJe009JeP03G_MJeU[F00IJeP03G_MJeU[F00=JeP9N
m`9JeP04E[EJeU[FF]H2E[D3G_L01V<HG_MJeU[FE[ENm`AJeP05G_MS65[F
F]IF]@02F]H2G_L00e[FG_MNm`03G_L015[FG_MNme[F0Ukg00=S65kgG_L0
0V<H00QNmf<HHaQNmf<HIcUS66Li0f<H0VLi00=S65kgF]H015kg00=S65kg
G_L00f<H00E[FVLiIcUS65kg009S609W>@=S6003IcU[FV<H00ES6004G_MJ
eUkgG_L3F]H016<HIcUW>F]J16<H00IW>F<HHaQNmf<HIcT5HaP01UkgF]IN
me[FG_MS60UNm`05F]IS65kgHaQJeP01AS4000<48@0300048@@Q00848@08
24848@@Q248icWooG_M240=BU006CW=BU5JeCW=:DTHa0dYB00A>LeJeDYAF
]@9>L`0:DYAF]E:DBU96<DYBCW=BU4icBU82@Q001Cg_CW=BU5:DAS400T8@
00I:DTHa@Q0mkd8@BU83CW<014Ha@Q16<DYB0Tic0dYB0Tic0TYB0THa00U>
LeJeE[E>LdYBAS5:DTicDY@00Tic0TYB00A>Le:DBU92408mk`9>L`9:DP=6
<@03@Q16<Cg_0096<@924096<@9:DP96<@05BU9BU4YBBU924003BU8014Ha
CW=BU5:D0TYB00=6<DYBBU80148@00A6<D8@AS524096<@06CW=:DTYB@Q16
<Cg_0SW>00HaS3g_@Q1243W>;F/2:DX012DY7>LLiacW0QBU0Q240PaS00<8
@P@Q124010Q20`@Q00<8@P@Q12402P@Q00@000Q21248@P<48@0524848@Q2
248<H`0224841243248212462484124224801@@Q24848@@Q248030@Q00<8
@P@Q12400PQ200<<H`@Q24801P@Q0PQ22`@Q0PQ25P@Q00<8@P@Q124050@Q
00<8@P@Q12400P@Q10Q200<<Ha2436<00QBU0QS600TDYA246<HLibDY;F/a
S3g_@Q000dHa14YB0Tic00ABU4icDYABU09F]@04DYAF]DicCW<8DY@01EJe
DYABU5JeF]H00UJe00=>Le:DDY@00UJe0U[F0U:D00=>Le:DCW<00e:D0dic
15:D00=>Le:DDY@00e[F0UJe0U:D00EF]E[FF]IS65kg009F]@04DYAF]E[F
F]H2DY@2BU802dicDYA>LdicBU9>Le:DE[EBU5JeF]H00UJe00=BU5JeF]H0
15:D0UJe0U:D00=>Le:DDY@015:D00UJeUJeE[EBU5JeF]IF]E[FDY@00UJe
0U[F00=F]E[FF]H00U[F00=F]E:DCW<00U[F00=Nme[FE[D04E[F0Ukg0U[F
0UJe1U[F0V<H0U[F00=F]E[FG_L015[F0Ukg0U[F00MF]E[FG_MNme[FG_MJ
eP02G_L01E[FG_MJeUkgF]H00Ukg0V<H15kg00=S66LiG_L00f<H0VLi0f<H
00AW>F<HHaQS609Nm`03F]INmf<H009S609Nm`03HaQW>F<H00=W>@=S6005
JeYW>F<HG_MS6003IcT3HaP00fLiG_MS6002G_L3F]H01EkgHaQW>FLiJeX0
16<H0VLi00=S65kgHaP01F<H1Ukg00=S65kgG_L01ekg00ES65kgG_MS65[F
0052400000<000@Q12400P@Q00@000@Q1248@P848@0736<e[GooHaPmkdic
DY@00Tic0U:D0UJe0Tic00A6<DYBBU9:DPABU005CW=BU5:DBU9>L`03AS40
0dYB?Nm24002>Lh01DHaCW=BU5JeBU800dic00E:DT8@@Q1244Ha00A>L`03
@Q16<DYB00924004AS5:DTicCW<2AS400d8@AS5:DP02DY@00dicAS4mk`03
BU84DY@3BU800d8@AS5>L`02CW<2BU802e:DCW=:DTHa@Q16<D8@AS5:DTHa
@Q000THa0Tic00I:DTHaAS5:DTHaBU82CW<3BU800dicDYA>L`02BU800dHa
CW=6<@02?Nl024HaBU9>Ld8@?NlicSF]>Lh2@Q0014YB@Q0mkcg_0SW>0S6<
0Re[00DU:AcW7>L@Q1BU00<@Q00336<8@P@Q00`48@0324848@Q200X48@04
24848@Q2124324800`@Q2488@P0924821242248010@Q24848@@Q0`Q200<4
8@Q224800`aS00<8@P@Q12401`@Q00H000@Q1248@P@Q00021245248010@Q
2488@PQ220@Q00<8@P@Q12400P@Q0PQ210@Q00<8@P@Q12400P@Q00<000@Q
12400P@Q00<000@Q124010@Q00<8@P@Q12400`@Q00<8@P@Q24802P@Q00<0
00@Q124030@Q0PQ200H48@Q2248@Q0aS48@25:D01QS65:DDYAS65:DHaP8L
i`8YBP0=?Nm244icCW=6<DYBCW=:DTicBU9>Le:DCW<00U:D00=F]E[FCW<0
2E:D00=>LeJeE[D00U[F0U:D00=F]E:DF]H015Je00=>LdYBDY@00U[F00AF
]DicBU9>L`ABU09>L`03E[EBU5[F009F]@ABU006E[EJeU[FF]IF]E:D0UJe
00=JeUJeDY@00U:D0Tic00M:DU:DDYABU4icBU9BU005E[D2F]H2E[D00e:D
E[EJeP02E[D2CW<2DY@2E[D2DY@2E[D00e[FE[EF]@03E[D00e:DE[EBU006
E[D00e[FE[EJeP03E[D015kgF]IF]E:D0U[F0eJe0U[F00EF]E[FF]IJeUkg
009JeP05E[EJeUkgF]IF]@03DY@015JeF]IJeUJe0U[F00IS65kgF]IJeUJe
F]H2G_L026<HG_MJeUkgF]INme[FG_L2F]H01EJeF]INmekgHaP01ekg00ES
65kgHaQNmf<H009Nm`0<HaQNme[FG_MJeUkgHaQNmf<HG_MS65kg0VLi00AS
65[FG_MNm`9JeP04G_MS66LiIcT3G_L3HaP00ekgHaQW>@03IcT2HaP5IcT4
HaP3G_L3F]H015kgIcUW>F]J0VLi00=S66LiHaP00V<H00ANmf<HHaQS609N
m`=S6003G_MJeU[F009Nm`9S60INm`03HaQNme[F009Nm`5S605Nm`524000
00D48@0012448@0000<48@0;248000@Q36<icWooHaPmkdicDYA:DP02DY@2
E[D00e:DBU9>L`02AS42CW<4DY@01dicDYA>LdicBU96<DYB0096<@09@Q0m
kcW>=Je6<DicE[EBU4YB00=>L`03BU92448@0096<@03CW=BU4YB00Q6<@9>
L`=6<@05@Q1>LeJeDYA:DP02@Q000dHaBU9>L`03DY@02DicBU9:DTHa@Q16
<DYBDYA>L`02BU800dicBU96<@03@Q0014HaBU96<DHa0T8@00E:DTicBU9:
DTHa009:DP09AS5:DTicCW=:DTHaBU9>Le:D009>L`04AS5:DTYBAS43@Q00
14YBAS5243g_0SW>00@mkdHaAS56<@8mk`09@Q0icSF]<H`e[Be[:DXU:B48
008HaP8@Q08<H`0348@8@PQ200T48@0324848@Q200<48@0300048@@Q00/4
8@0524848@Q224848@02248010@Q248<H`aS0`Q20P@Q0`Q20`@Q00@8@P@Q
2488@P848@03248<H`aS00<8@P<48@0300048@@Q00/48@05248<H`aS36<8
@P021242248312400`Q212448@0224800`@Q00048@0O1242248=124010Q2
12448@000`@Q00L000@Q1248@P@Q24848@03248236<55:D01QS65:DDYAS6
7>LU:@8YBP07>Li244icBU96<DYBCW<00TYB00E>Le:DCW=:DU:D009F]@AB
U003CW=F]E:D00=BU003CW=BU5:D009F]@04F]IF]EJeDY@2E[D025[FE[EB
U5JeDYA:DU:DE[D2F]H01TYBCW=>LdicE[EBU09>L`03DYAF]EJe009F]@04
DYAF]E:DDY@2E[D00e[FE[EJeP03E[D2F]H00eJeDYAF]@02CW<01DYBCW=B
U4icDY@00dic00=BU5[FE[D00UJe0e[F00=BU5JeE[D00U[F00=F]E:DCW<0
0U:D00=F]E:DDY@01UJe00=BU5JeE[D025Je15[F00=F]E:DE[D00U[F0eJe
0U[F0UJe00=JeUJeF]H00U[F0Ukg00=F]E[FF]H00e[F0UJe0U:D00EF]E[F
E[EJeUJe009Nm`9S6003E[EJeU[F00ENm`=JeP03G_MJeU[F009F]@03F]IN
mf<H00=Nm`03F]INmf<H009Nm`04HaQNmf<HHaP6G_L00e[FG_MS6004HaP0
0ekgHaQW>@02HaP01EkgF]INme[FE[D00V<H00AW>F<HG_MNm`IS6003IcU[
FV]J009S6006IcUS66LiJeYS66Li0V<H00EW>F<HG_MJeUkg00AJeP04HaQ[
FV]JJeX5HaP3G_L6HaP00ekgF]IJeP02G_L01F<HG_MNmekgHaP00ekg00QS
65kgG_MNme[FG_MW>E[F0DHa000212401`0012448@@Q00048@Q200848@06
248icWooHaPmkdic1E:D00AJeUJeE[E>L`9:DP04AS5:DTicCW<2DY@01dYB
@Q12448@BU9243g_00924004BU96<D8@BU82AS401dYBDYAF]E:DBU96<Dic
009:DP8mk`04@Q1:DU:DBU83@Q0014HaBU9244Ha0T8@0dYB00=6<DYBCW<0
0Tic00=6<D8@AS400THa0U:D00UF]E:DBU96<DYBCW=BU4icBU800THa00A>
Le:DCW=:DP96<@9>L`06BU9>LdHa@Q16<Dic0U:D00=:DTHaBU802DYB00E>
LdYBAS5:DTHa009:DP06AS52448@AS5:DT8@0SW>00@aS3W>?Nm24096<@07
?NlicSF]>LhaS2U:8@P00QcW0QBU0PaS00D8@P@Q24848@Q200X48@030004
8@@Q00<48@0324848@@Q00D48@0924848@@Q248<HaS65:D<H`Q200@48@88
@P041248@PQ236<324800`@Q24848@02248312400`Q212448@02124010Q2
36<<H`Q220@Q00<000@Q12400PQ20`@Q00<000@Q24801PQ20P@Q00L8@P@Q
00048@aS48@<H`041242248412400`Q212448@0E1242248C12400`001244
8@0712401`Q21248@PQ236<8@PaS00@DY@0348@DYAS6008HaP065:DQ22DY
>LhmkdHa1TYB0dic00E:DU:DF]IJeUJe00A>L`=BU004E[EBU5:DDY@2F]H0
15kgF]IF]Dic0UJe0U[F00=F]DicCW<00U:D00EJeUJeDYA>Le:D009>L`04
DYAF]EJeE[D3DY@01EJeDYAF]E:DCW<00U:D0e[F00=Nme[FF]H00U:D00EJ
eUJeDYABU4ic009BU09F]@03DYA:DTYB009BU0AF]@04F]INme[FE[D2DY@5
E[D3DY@01UJeF]IF]EJeDYAF]@=BU09F]@EJePAF]@9JeP03E[EBU5Je009F
]@08DYAF]E:DF]IF]E:DE[EBU0=F]@EJeP9F]@=JeP9BU0AF]@AJeP03G_MJ
eU[F009JeP06G_MJeUkgG_MS65kg0U[F0Ukg00=S65[FF]H00U[F00AS65kg
F]IJePENm`04HaQNmf<HG_L4HaP00ekgF]INm`05G_L01f<HG_MS65kgF]IN
me[F00ANm`03F]INmf<H009S6003G_MJeUkg00ES6008IcUS66LiHaQW>F<H
IcUS60=W>@=S609Nm`EJeP03G_MS66<H00AW>@9S60ENm`08HaQNmf<HHaQN
mf<HG_MJeP=Nm`05IcUS66<HG_MJeP02G_L3HaP3F]H1HaP1G_L1@Q000005
00048@@Q1240000312402@Q2124000aS>Lioof<H?Nm>L`05DY@2E[D00e:D
CW=:DP02BU800dHaCW=BU002DY@00dYBAS56<@02AS43?Nl5AS401TYBAS5:
DU:DF]I>L`A:DP07AS4mkcW>AS5:DTicBU800T8@14Ha00=244Ha@Q000dYB
00M6<DYBCW=>LdYBAS524003AS401e:DE[EBU5JeBU96<DYB00=>L`03BU96
<DYB00=>L`04BU9244YBBU83CW<014YB?Nm6<DYB0U:D00A:DT8@AS5>L`9:
DP06CW=:DTHaAS5:DTic0dYB00A6<DYBBU96<@=24004AS5:DT8@>Lh2<H`0
0cW>@Q124002AS4033W>=Jde[CW>=Jd]JacW6<HLiaS65:D<H`<8@P031248
@P@Q01T48@0400048@aS48@25:D2248212401PQ212448@@Q248<H`@8@P03
1248@PQ20088@P<48@0324848@@Q00848@<8@P05124<H`Q2248000041240
100012448@@Q0PQ210@Q20Q21@@Q00@8@PaS5:D<H`L48@0324848@@Q01<4
8@0300048@@Q00h48@0300048@0000`48@0424848@@Q2482124324800`aS
48@@Q0025:D011245:DDYABU0aS600HU:Be[?NlicSg_AS42CW<2BU82CW<3
BU82E[D00e[FDYA>L`04CW<00e:DE[EBU003DY@2F]H00ekgF]IBU002DY@0
15JeF]IJeUJe0Tic00IBU5JeE[EF]DicDY@2CW<3DY@2E[D00e:DE[EBU007
DY@4F]H015kgE[EF]E:D0eJe0Tic00IBU5JeDYABU4icBU82CW<015:DF]IB
U5Je0e[F1UJe0U:D0UJe00=BU5JeE[D00UJe1e:D15[F0eJe00ABU5JeF]IJ
eP9F]@03DYAF]EJe009F]@07DYAF]E[FE[EBU4icDY@00eJe0e[F00ANme[F
E[EF]@9JeP9F]@03DYAF]E:D009F]@9JeP03G_MJeU[F00IJeP03G_MS66<H
00=JeP03G_MS66<H009JeP05E[EJeUkgG_MJeP07G_L00f<HG_MS6004HaP2
G_L00e[FG_MJeP02G_L3HaP3G_L00e[FG_MNm`02G_L00e[FG_MS6003HaP0
15[FG_MNmekg1F<H00=W>F<HHaP01fLi0V<H0Ukg0U[F00=Nme[FG_L00U[F
00IS66LiIcUW>F<HIcT2HaP2G_L00f<HG_MJeP02G_L3HaP2G_L2F]H01Ukg
HaQS66<HG_MS609Nm`04HaQNmf<HG_L2F]H00ekgHaQJeP01AS4000031240
00@Q00848@0400048@@Q248212403@aS?Nmoof<H?Nm>Le[FDYA:DTicDYAF
]E[F009BU003BU9>LdYB00=6<@9:DP9>L`=:DP924096<@=:DP05DYA:DTHa
BU9>L`02E[D03DicBU9:DTHaBU9243W>@Q1:DUJeDYA243g_00=24096<@92
4096<@ABU003CW=:DTic009:DP03AS5:DTic009BU006BU9244HaBU9>Le:D
0Tic00I6<DYBCW=BU4icBU82AS401DicDYA>LdicAS400T8@00=:DTicBU80
0dHa0TYB0dHa00=:DTicBU801dYB0THa00<mkcW>>Lh00SW>0SF]00PaS3W>
@Q1244Ha?Nle[CW>0Re[00DQ21cW5:DDYA24008<H`0524848@@Q1248@P08
1240100012448@000`@Q00<000@Q12401@@Q0`Q20`@Q00@<Ha2448@<H`H4
8@88@P051248@PQ236<8@P0536<010Q212448@Q210@Q00T8@P@Q12448@Q2
1248@P@Q248020@Q0`Q200<48@Q212400PaS00L@Q1cW7>LDY@aS1248@P04
12401PQ248@DYA2424848@@8@P031248@PQ20088@PL48@0300048@@Q00H4
8@0400048@Q2248G12400`0012448@0512400`Q212448@0512401@Q236<8
@PaS24800Q2401@HaQBU48@@Q1BU6<HDYB489BTicTYBCW=BU4icBU9>LdYB
CW=:DTic0e:D00=F]E:DDY@01U:D0UJe0U:D0e[F15Je0e[F00AF]E:DDYAB
U0=F]@9BU006BU9>LdicE[EJeU:D0UJe00=BU5JeCW<00e:D00A>Le:DDYAF
]@MJePMF]@03DYAF]Dic009>L`9BU003E[EJeU[F009JeP9F]@04F]IF]EJe
DY@3E[D015:DE[EBU5:D0eJe0e:D0UJe00=BU5[FF]H00U[F00=F]E[FE[D0
0eJe00=BU5JeDY@015Je00=BU5JeDY@00UJe00=JeUJeDY@00U:D15[F0eJe
0e[F00=F]E:DF]H00e[F0UJe0e[F00=Nme[FF]H01E[F0ekg0e[F15kg1U[F
1Ekg0V<H00=W>F<HHaP00V<H0ekg00AW>EkgF]IJeP9Nm`=S6006G_MJeUkg
F]INmf<H1Ekg0V<H00EW>F<HHaQNmf<H009W>@AS609W>@9S6004G_MS66<H
IcT3HaP5G_L01U[FG_MJeUkgF]INm`9S6004IcUS65kgF]H5G_L3HaP2G_L2
F]H015kgF]IJeUkg0f<H0ekg00=S65kgG_L00e[F0F<H0E[F0DHa00031240
0`0012448@0212403PQ212448@aS@Q1oof<H>LiBU5JeDYA>LdYBCW<3E[D0
15:DBU9>LdYB0THa1dYB00I6<D8@@Q1244YBCW<2BU8024icBU96<DHaDYAF
]E[FCW<2BU8024HaBU9243W>@Q1:DUJeCW<3@Q0013g_AS5244Ha0d8@00=6
<E:DDY@00U:D00=:DTicBU800THa00A:DTHaDYABU09>L`04AS5244YBBU82
DY@2BU801dHaBU9BU4icBU9244YB00A>L`=6<@05BU9>LdYBBU924002AS40
14YBAS56<DHa0TYB00A>LdYBAS5:DP96<@04CW=:DTHaAS43>Lh00cF]>Lhe
[@03=Jd0148@AS56<CW>0SF]00DaS2e[8@PLiaS6008@Q00436<8@PQ22484
12400`Q212448@0512400`0012448@0>12402@Q212448@Q236<@Q0aS1248
@P061243248336<010Q236<<H`aS0PQ20P@Q00<8@P@Q24800P@Q0`Q200@4
8@Q21248@PX48@@8@P061248@PaS5:DLiaBU0PaS0PQ21@@Q00<@Q1BU48@0
0`@Q00P8@P@Q2488@P@Q24848@Q20`@Q00<000@Q12403@@Q00<000@Q1240
7P@Q00<8@P@Q124010@Q0PQ210aS0QBU00<HaQ2448@00aBU00HLibDY?Nm:
DTicE[D2BU82CW<3BU800e:DE[EF]@05DY@01EJeCW=BU5:DE[D00e:D00AF
]E[FF]IBU09F]@9JeP04G_MJeUJeDY@2CW<2E[D01U:DE[E>LdYBCW=BU09F
]@04DYAF]EJeE[D3DY@2CW<01U:DCW=BU5JeF]INm`=JeP05E[EJeUJeE[EB
U004E[D2DY@2CW<2DY@3E[D2G_L2E[D00e:DF]IF]@02DY@4E[D2DY@01EJe
DYABU5:DE[D00U:D0eJe15[F0eJe00=JeUJeE[D00e:D2EJe00AJeUJeDYAB
U09F]@03F]INmeJe00=F]@03F]INme[F00=F]@04G_MJeUJeE[D3F]H00ekg
F]IJeP06F]H2G_L4F]H5G_L5F]H2G_L00e[FG_MNm`07HaP2G_L3HaP00ekg
F]IJeP04HaP7G_L00e[FG_MNm`06HaP015kgHaQS66Li16<H0VLi2F<H0Ukg
00MJeUkgG_MNme[FG_MJeP02G_L01F<HIcUW>F<HF]H00ekg00=S65kgG_L0
0f<H0Ukg00AJeUkgG_MJeP9Nm`9S60=Nm`=S6006G_MJeU[FF]INme[F0D8@
00001@0012448@@Q00000`@Q00T8@P00124<Hcg_OomNmcW>BU800U:D00=>
LdYBBU800TYB00A>LdYBDYABU09>L`9:DP9BU09>L`=:DP04AS5:DTYBBU84
CW<02DYBAS56<DHaCW=BU5JeDYA>L`02AS42?Nl01T8@BU9BU5:DBU92408i
cP03@Q1:DTYB00=:DP03AS5:DU:D009>L`07BU9>Le:DCW=:DTHaCW<00dYB
00M>LdYB@Q1244YBCW=BU002BU800dicBU9:DP03CW<3AS400dYBAS56<@02
@Q02AS42BU8024Ha@Q16<DicDYA6<D8@BU82CW<2BU82AS401D8@AS5:DSg_
>Lh00S6<00LicT8@@Q0icRe[<H`mk`02AS40148@?Nl]JbU:0R4800<HaQBU
36<01PQ200L<H`Q236<8@P@Q00048@02248>12400`001248@P0224831240
0`Q212448@0212401@Q2124000@Q24800`@Q00@8@P@Q1248@P<@Q00436<@
Q0aS36<224800`@Q2488@P05248312452484124324800`@Q248<H`0248@0
2AS648@HaQBU7>MBU6<HBU8U:@0212401@Q21248@PaS48@00PQ200D48@Q2
1248@P@Q0088@P@48@0300048@@Q00H48@0324848@@Q00H48@0524848@@Q
1240000Q124224800`@Q24848@0424801a2436<@Q1BU6<HLiaS6008DY@07
8@P]JcW>BU9>LeJeF]H00U:D1dic0e:D00=>LeJeDY@00UJe00ABU4icDYAB
U0=JeP08E[EJeU:DE[EJeUkgF]IBU09>L`03E[EJeU[F009BU09>L`05DYAF
]EJeDYAJeP02E[D2DY@00dicDYABU002CW<2DY@01E[FG_MNmekgHaP00U[F
00=BU5JeF]H00U[F00IBU4icDYAF]E:DE[D2DY@01UJeDYAJeU[FG_MJePIF
]@=BU0=>L`03DYAF]EJe009BU003E[EBU5:D00EF]@04F]IF]E[FDY@2E[D0
15:DE[EF]E[F0UJe00IBU5[FF]IF]E:DE[D3F]H2E[D00dicE[EF]@02F]H2
E[D5F]H3E[D2F]H00ekgF]IJeP03F]H015kgF]IJeUJe0U[F0Ukg00=S65kg
F]H00e[F00=F]E[FHaP00Ukg0UJe00ANme[FG_MS609Nm`04HaQNmekgG_L5
HaP00ekgHaQS6002G_L2E[D2G_L2HaP2G_L00e[FG_MNm`03G_L2HaP00e[F
G_MW>@02HaP00e[FG_MS6003IcT7HaP00fLiHaQS6003G_L01F<HG_MNmekg
F]H015kg00=F]E[FG_L00ekg0f<H15kg00=S65kgG_L015kg0U[F0Ukg00=J
eUkgHaP00V<H0Ukg0V<H0Ukg00AJeUkgHaQJeP56<@0000@48@00124000@4
8@0=24848@0036<mkgooF]HicTYBE[EBU4YBAS400TYB14ic0U:D00=>LdYB
BU800Tic00ABU4icBU96<@9:DP0=AS5:DTYBBU9>LdYBCW=6<D8@AS5:DTic
E[D00U:D00=>Ld8@AS400SW>00]244HaCW=F]DHa@Q0mkcW>@Q1:DTic009:
DP05AS5:DTicDYA>L`02BU83CW<00dYBAS5:DP02CW<014YBCW=6<D8@0THa
00=BU4icBU800TYB00E6<DYBCW=>LdYB0096<@=:DP06@Q16<D8@?Nm244Ha
0TYB00=6<DYBCW<00TYB0THa00E>LdYBBU96<DYB0096<@92400<?NlicS6<
;F/icSg_@Q0e[C6<=JdicTHa0T8@00Lmkbe[9BTLib487>LDY@0236<22480
0`@Q2488@P04248H12401@Q212448@@Q24800P@Q00@8@P@Q2488@P@48@04
24848@Q21242248248@436<224800`aS1248@P0424851243248812422480
30aS48@DYABU48@DYAS67>M>Lf<HAS4U:@848@0336<48@aS00<<H`<48@03
24848@@Q00<8@PP48@0400048@@Q248912400`0012448@0J12400`001244
8@0412400`Q212448@041243248236<348@26<H02QcW5:DDYBDY:DY244ic
BU9JeUJe0U:D00I:DU:DCW=>LdYBCW<6DY@01eJeDYAF]DicDYA>Le:D009J
eP03E[EJeUJe009F]@04G_MJeU[FE[D2CW<2E[D2F]H00dicBU9BU002DY@3
E[D00e[FE[EF]@04CW<01e:DCW=BU5:DF]INme[F009S609JeP=F]@9JeP03
DYA>Le:D009F]@06DYA>Le:DE[EBU5Je0e[F0UJe00EJeUJeE[EBU5Je009B
U09>L`9BU004E[EBU5:DDY@5E[D2F]H:E[D015[FE[EBU5:D1UJe0U[F00AF
]E:DDYABU09JeP=F]@06F]INme[FF]IF]E[F0UJe1e[F00=Nme[FF]H01E[F
15kg1E[F0ekg00=F]E[FF]H00Ukg00=JeUkgG_L015kg0V<H00=W>F<HG_L0
0Ukg00=S65kgG_L00UJe0Ukg0V<H00=Nme[FG_L015kg0V<H0ekg0V<H0ekg
00AS66]JIcUW>@=S6009G_MS66<HHaQW>F<HG_MS65kg00=S6004G_MJeUkg
F]H3G_L3F]H015kgHaQS65kg0V<H1Ekg00=S65kgF]H00ekg00=JeUkgF]H0
15kg0f<H00=Nmf<HG_L00Ukg0U[F0Ekg0E[F0D8@00051240100012448@Q2
0P@Q00P<Hcg_OomS63F]AS5:DTHa0TYB00A>LdYBCW=>L`=BU0A>L`03BU9>
LdYB00E:DP9>L`05BU9BU5:DDYA>L`03AS401T8@BU9BU5JeDYA:DP=6<@03
@Q0mkd8@009240=6<@04?Nm2448@AS45BU800dicDYA>L`02CW<3DY@02dic
BU96<DHaBU9>LdYBAS5244HaBU800Tic0dYB00=6<DicCW<00Tic0THa0TYB
00A6<D8@@Q12409:DP96<@924006AS5:DTHaAS5244Ha0TYB00I>LdHa@Q0m
kcW>=Jd2>Lh2=Jd2<H`3=Jd02cW>@Q1243W><H`YBQcW8@PDYA2436<00PQ2
00@48@Q21248@P8@Q0046<H@Q0Q22486124010Q212448@Q20PaS0`Q20`@Q
00<000@Q24800`Q20P@Q00<8@P@Q24801@@Q00<8@P@Q12400`@Q00H8@P@Q
1248@PaS5:D248@010aS2488@PQ20P@Q0PQ20`aS00L8@P@Q1248@P@Q2484
8@03248010aS24848@@Q0PQ20`aS00H@Q1S68@PYBSF]<H`2:DX01R486<I:
DVmkCW<YBP848@8<H`0348@8@P@Q00@48@0424848@Q2248612401@001244
8@Q212400PQ2<@@Q00H8@P@Q12448@Q21243248248@25:D36<H011247>LY
BT8@1Tic00A:DTicBU9:DP=>L`04DYAF]E:DE[D4DY@2E[D3F]H2E[D01U:D
E[EF]EkgF]IF]@9BU0IF]@EBU003F]IF]EJe009BU003CW=BU4ic00=BU004
E[EJeU[FG_L2HaP00ekgE[EF]@02G_L00e[FDYA>L`02E[D2F]H015JeDYA>
LeJe0e[F00AF]E[FG_MJePEF]@9BU003CW=BU5:D00=BU0=F]@04DYAF]E:D
E[D2DY@9E[D2F]H01E:DE[EBU5JeF]H00UJe0e[F0UJe00=BU5JeF]H015Je
0U[F0eJe0U[F00=BU5JeDY@00U[F00ENme[FF]IJeUJe00AJeP04E[EJeUkg
G_L7F]H2G_L2HaP2G_L2F]H015kgHaQNmf<H0Ukg00IJeV<HG_MW>F<HIcT2
HaP00ekgHaQS6002F]H015JeF]INme[F0Ukg00=S65kgF]H00U[F00=S65kg
HaP00U[F0V<H00=W>F<HF]H00ekg00=W>F<HHaP00f<H00MNmf<HIcUS66Li
G_MJeP02G_L4HaP015kgHaQNme[F0Ukg0U[F00=Nmf<HHaP00Ukg0V<H0Ukg
0V<H00QNme[FG_MJeUkgF]INme[F15kg16<H0ekg00IS65kgG_MJeV<HF]H1
@Q00000500048@001240000312402PQ212448@aS?Nmooekg<Ha244Ha0TYB
00E>LdYBBU9:DTic00=BU09>L`=:DP03CW=:DTYB00=:DP09CW=:DTicBU9>
LeJeDYA>Ld8@00=6<@08BU9>LeJeDYA:DTHaBU92408mk`03@Q16<DHa00I2
40I:DP=>L`05BU9>Le:DDYA>L`02BU8024HaBU9:DTicBU96<D8@BU82CW<3
BU82AS401TYBDYABU4YB@Q16<@9:DP06AS4mkcg_@Q16<DYB2dHa00I:DTic
BU9243g_=Jd2>Lh3=Jd0436<=Jde[C6<=Jdmkd8@AS4icRe[:DXQ21cW5:D@
Q0aS0PQ20`@Q00<<Ha2448@00QBU0PQ21P@Q00@8@P@Q1248@P8<H`032484
8@Q200@48@0324848@Q200<8@P848@0324848@@Q00P48@<8@P848@8<H`8D
Y@<<H`88@P041248@P@Q248236<224800`@Q24848@021242248336<22482
12400`Q236<<H`0248@27>L00bDY<H`aS0029BT27>L01U:DKg]>LbU:0004
8@<<H`88@P0400048@@Q124424891240100012448@@Q0PQ200D48@001244
8@Q200T48@0324848@@Q01X48@0324848@Q200@48@88@P848@03248<Ha24
008@Q08DY@8HaP065:DQ22e[?NmBU4YB1Dic00A:DTicBU9:DP9>L`9BU004
E[EBU5:DCW<2DY@015JeDYAF]EJe0U[F00=F]E:DCW<00e[F00EF]DicE[EF
]E[F009F]@MBU00:F]IF]E:DDYA>Le:DCW=BU4icDY@3E[D2G_L2HaP01U[F
E[EBU5[FG_MJeP=BU09JeP9F]@9BU09F]@9JeP03E[EJeU[F009F]@04DYAF
]EJeE[D2DY@00dicDYABU002DY@00eJeDYAF]@02E[D6DY@00eJeF]IF]@04
E[D3F]H01EJeDYABU5:DF]H00UJe00AJeUJeF]IJeP9F]@03DYAF]EJe00=F
]@AJeP05DYAJeU[FE[EBU002F]H015kgF]IJeU[F0UJe0e[F00EF]E[FF]IJ
eUkg00MJePENm`03F]INme[F009Nm`04HaQNmekgF]H2G_L2HaP016]JHaQS
65[F0V<H0Ukg00EF]E[FF]IJeV<H00ANm`9JeP03G_MJeV<H00ANm`=S6003
G_MJeUkg00AS6003G_MS65kg00AS6004IcUNmekgG_L4HaP00ekgHaQNm`03
G_L3F]H00ekgHaQS6002HaP016LiG_MNmf<H0Ukg00=S65[FG_L00ekg00=J
eUkgF]H00Ukg0V<H00=Nmf<HHaP015kg00ES65kgF]INmeJe005240001P@Q
00h000@Q24848@0036<icW_NF]He[D8@CW=:DU:D0Tic00E:DTHaCW=BU4ic
009:DP03CW=BU4ic00=:DP9>L`=:DP03CW=BU4ic00=BU006CW=6<DHaBU92
44Ha0U:D00=F]DicAS400dYB00A243W>>LhicP96<@05@Q16<DYBAS524002
BU801DicBU9:DU:DCW<00dYB00U>LdYBCW=:DTHaBU96<DYBCW<00THa0T8@
00E:DTicCW=>LdYB00A6<@9>L`09AS4mkcg_AS5>LdYBAS5244YB0096<@07
BU9>LdHa@Q0mkd8@BU800T8@0TYB00i6<Cg_>LhmkcW><H`icT8@=JdYBRDY
:DXicSg_0SW>00<aS2U:9BT00QBU00@<Ha2436<8@P@48@0524848@@Q2484
8@0436<00`@Q24848@04124224821244248010@Q2488@P@Q20Q20`@Q00<0
00@Q12401`@Q0PQ20P@Q00<8@Q2448@00PaS00<8@P@Q124010@Q00H<Ha24
7>LDY@aS24841242248010aS24848@@Q1@Q20QcW00De[DYBE[ES65Je009J
eP0:<H`U:AcW8@Q6<Ekg>LhHaP00124236<00`Q212448@03124236<00`Q2
12448@021240100012448@000`@Q10Q200<48@Q212400`@Q00D8@P@Q1244
8@0002/48@0424848@Q2124236<348@35:D01AS6:DXaS4Ha?Nl00THa00=>
Le:DCW<00TYB00A6<DicBU9BU09F]@9JeP04E[EBU5:DE[D2F]H025JeF]IF
]EJeDYA>LeJeF]H4E[D3DY@015[FE[EBU4ic0U:D00AF]E:DE[EBU0AF]@9B
U005CW=BU5JeE[EJeP03G_L2E[D4F]H015JeDYAF]E:D15Je00=JeUJeE[D0
0UJe00QNme[FF]IF]E:DE[EJeUJe0e:D0UJe0e:D00=F]E[FE[D00UJe00=J
eUJeE[D00U:D00IF]E:DE[EJeUJeF]H2E[D015[FE[EF]E:D0e[F00=F]E[F
E[D00UJe0e:D00IF]E[FE[EJeU:DF]H3E[D2DY@5E[D00e:DF]IJeP02E[D0
0e[FE[EJeP03F]H4G_L2F]H2E[D00e[FE[ENm`02G_L00f<HG_MNm`03G_L0
0eJeF]IS6002IcT01UkgF]INmekgHaQNm`9S6004G_MS65[FG_L2F]H00ekg
F]IJeP02F]H3G_L01U[FG_MNmekgHaQNm`9S6006G_MS66<HHaQW>F<H0ekg
1F<H00=W>F<HHaP016<H0ekg2F<H00ENmf<HG_MJeUkg009S6003IcUNmekg
009Nm`03IcUS65kg00=JeP9Nm`0;F]INmekgG_MJeUkgHaQW>F<HG_MJeP02
G_L00f<HG_MS6002G_L1F]H1@Q000006124000@Q00048@000P@Q00T8@P00
124<HcW>NmiF]C6<@Q000Tic0U:D00A:DTHaBU9>L`9BU003AS5:DTic009B
U09:DP=>L`=:DP07CW=BU5:DDYAF]DicBU800dHa00I244YBCW=JeU:DCW<3
AS401DYB@Q0mkcW>?Nl00T8@0dHa00=244HaAS400Tic0TYB0dic0THa0dic
14Ha0TYB14Ha0dYB0Tic0dHa00=:DTicDY@00T8@00Hmkd8@BU9:DTHa@Q02
AS43BU8014Ha@Q12448@0dHa0dYB00`mkcW>?Nle[C6<=JdmkcF];F/U:BU:
>Lh2?Nl01SW><H`U:B486<HDY@8@Q088@P848@0424848@@Q1242248336<5
248312400`Q212448@03248512400`Q236<8@P08248512400`Q21248@P07
124010Q236<DYA240PaS00D8@P@Q12448@Q200848@06248@Q1cW7>L@Q0Q2
10@Q0`Q20`@Q10Q200/<HaS67>LicTYBE[ENmeJeF]IF]C6<008Q20059BUB
U5[F;F/DY@0212400a2436<48@0312400`002488@P022483124010001244
8@0010@Q10Q20P@Q00<8@P@Q248010@Q00<8@P@Q12400P@Q00<8@P@Q1240
0P@Q00<8@P@Q12401`@Q00<8@P@Q12401`@Q00<8@P@Q00000`@Q00<8@P@Q
12400`@Q0PQ20P@Q00<8@PaS24800PaS0aBU0Q2400@DYAcW;F/e[@924007
AS5:DTicDYA:DTicAS400TYB00=>Le:DE[D00eJe00=BU5JeDY@00UJe00AJ
eUJeF]IF]@ABU0AF]@9BU005CW=F]EJeE[EBU002CW<2DY@00eJeDYABU002
E[D03E[FDYABU5:DCW=F]E:DE[EJeUkgHaQNme[F009F]@=JeP9F]@9BU003
E[EBU5Je009JeP9F]@05DYAJeU[FG_MF]@03DY@3E[D00e:DE[EBU002DY@0
1TicDYAF]EJeF]IF]@9JeP04E[EBU4icCW<2E[D3F]H015JeF]IJeU[F0eJe
0e[F00AF]E[FDYAF]@=BU0=F]@05F]IF]EJeE[EJeP02E[D2DY@2E[D00e[F
E[EF]@03E[D2F]H00eJeF]IJeP02F]H01UkgF]IJeU[FG_MJeP9F]@04F]IF
]E[FF]H5G_L00e[FG_MJeP02F]H01EkgIcUW>EkgF]H00V<H0Ukg00=S65kg
HaP015kg1U[F15kg00AJeUkgG_MS60=Nm`05HaQNmf<HHaQW>@04G_L9HaP0
1EkgHaQS66<HG_L026<H00=Nmf<HHaP00Ukg00AJeUkgG_MW>@9S6003G_MS
66<H00=S60EJePINm`=S609Nm`04F]IS65kgHaP2G_L1HaP1E[D1?Nl00003
00048@@Q00D48@0:24848@@Q36<mkgooIcTicTHaCW<3BU8014icBU9:DTYB
0Tic0TYB00ABU4icBU9:DP9BU004E[E>LdHaAS42BU82CW<2BU800dHaBU96
<@02BU82@Q002dYBCW=F]E:DCW=:DTHaBU96<D8@>Lh00T8@00@mkd8@?Nm2
40=6<@03@Q16<DHa009BU006BU96<D8@@Q1:DTic0dYB00M6<DYBAS5:DTHa
CW=6<@02@Q000dHaBU9:DP02BU802THa?NlmkdHaCW=:DT8@>LhmkdHa0TYB
00A6<Cg_@Q16<@9BU007BU96<Cg_?Nm243g_@Q000THa0cW>00Q243g_=Jde
[Cg_=JdaS2e[0SW>00@aS2DY7>LHaP8@Q08<H`031248@P@Q00T48@05248H
aRDY8@P@Q00212422485124324831244248236<00`Q212448@0212422484
12400`Q236<8@P041242248212401@Q236<@Q0aS24801@aS00H@Q0aS36<<
H`Q248@336<524800`@Q2488@P0412401PQ236<8@R48<HaF]@9_N`0>Nmic
W7_NMkeJeUJe6<H48AcWCW=W>C6<00048@88@PH48@03248@Q0aS00848@03
00048@@Q00<48@0700048@@Q1248@PaS24800`@Q00@8@P@Q124001X48@03
0008@P@Q00<48@0500048@@Q1248@P0;124010Q21248@P@Q0PQ20PaS0QBU
00P@Q1BU48@HaRe[=Je:DT8@0THa00=:DTHaBU8014YB00A>Le:DF]IJeP=F
]@AJeP03E[EJeU:D009BU09F]@03F]IBU5:D009BU005E[EBU5JeDYAF]@03
DY@02TicDYABU5JeDYAF]E[FG_MJeUJe0U:D0UJe2U[F00=Nme[FE[D00Tic
00=BU5JeF]H00eJe00=JeUJeE[D00UJe00UBU5JeE[EJeU:DE[EBU5JeF]H0
0UJe25[F1E:D1EJe0e[F00=F]E[FE[D00U[F00EF]E[FE[EJeUJe00ABU0=J
eP04E[EJeUJeE[D3F]H025JeDYABU5JeF]IF]E[FE[D4F]H015JeF]IF]E[F
0Ukg00MJeUkgG_MF]E[FDYAF]@02G_L01f<HG_MNmekgHaQNmf<H009Nm`9J
eP=S609Nm`=S60ANm`05F]INme[FG_MS6004F]H02F<HG_MS66<HG_MS65kg
HaQNm`02HaP02EkgHaQNme[FG_MS66LiG_MJeP03G_L3HaP015kgHaQNmekg
0f<H0ekg16<H00=W>F<HHaP00f<H00=W>EkgG_L00ekg0f<H00ANmf<HG_MN
m`AJeP04E[EJeUkgHaP3G_L015[FG_MNmf<H0ekg00AJeUkgG_MS609Nm`5J
eP4mk`0010@Q00h000@Q12448@Q2124000aS@Q1oofLi=Je6<Dic1TYB00A>
Le:DBU9:DP=>L`9:DP05DYAF]E:DBU96<@03BU800e:DCW=>L`02BU800dHa
BU9:DP02AS401D8@BU9>LeJeDY@00TYB0THa00M243g_?Nlmkd8@?NlicP02
@Q02AS400d8@BU96<@02BU800e:DCW=6<@02@Q04BU801DHaBU96<DYBAS40
0dYB0dHa00]:DTicBU9:DTHa@Q0mkdHaBU96<D8@008mk`=:DP04AS52448@
BU82DY@014YBAS4icSg_0d8@00U6<D8@>Lhe[CW>AS5243F]<H`00SW>0S6<
00Te[CW><H`YBQcW6<HDYA2436<00PQ22`@Q00H8@QS67>LLia2412432485
12401`Q212448@Q21248@P@Q00@8@P0436<8@PQ2248212400`Q21248@P03
2484124010Q212448@Q20`@Q00T8@PaS48@<H`Q236<@Q0aS24800PaS00<@
Q0aS36<00`aS00<@Q0aS24801@Q210@Q0`Q200D<H`Q28@PaS5kg009_N`0<
Nmig_GNmLiaF]E:D5:D48B48E[ES62e[0P@Q00<<H`Q224800P@Q00H000@Q
2488@Q2424871240100012448@@Q0PQ200<48@Q212403@@Q00L8@P@Q1244
8@001248@P0;12400`0012448@0C124010Q212448@@Q0`Q200<<Ha2448@0
0Q240QBU00HLic6<>Li:DTHa@Q02AS401DYBAS5:DTicBU800Tic00=BU5Je
F]H00eJe00AJeUkgF]IF]@9JeP04DYA>Le:DDY@2F]H00eJeDYABU002DY@0
0eJeDYABU002DY@01EJeDYA>LdicE[D00U:D0UJe0U[F00EF]E:DE[EBU5Je
00=JeP06E[EJeUkgG_MJeUJe0e[F00IF]E:DDYABU5JeF]H2E[D015:DE[EF
]E[F0UJe0U:D0eJe0U:D00IJeUJeF]IBU5JeF]H3E[D3F]H015:DE[E>Le:D
0eJe00=BU5JeE[D015[F00MF]E[FF]IF]E[FE[EJeP02E[D4DY@00eJeF]IF
]@02F]H2E[D3F]H01EJeDYAF]E:DE[D00U[F00=F]E[FF]H00U[F0UJe0e[F
0ekg00AJeUJeE[EBU09JePANm`03HaQNmf<H00=Nm`03F]INmekg00=S6004
G_MS65kgHaP3G_L00e[FG_MJeP02F]H2G_L3F]H015kgHaQNmf<H0Ukg00=S
65kgG_L016<H0ekg0f<H00ANme[FG_MNm`ES6003G_MS66<H009S6003G_MJ
eUkg00AS6003IcUS66<H00AS6004G_MJeUkgG_L3HaP00ekgHaQNm`03G_L4
F]H5G_L01U[FG_MJeV<HG_MS60=JePANm`5S605JeP4mk`0000<48@001240
0P@Q00@000@Q1248@P848@0836<icWooJeXmkdicBU96<@9:DP03DYA:DTYB
0096<@05CW=:DTicDYA:DP02AS400dicDYABU002CW<00dYB@Q124002@Q03
AS42BU800e:DAS524002@Q002TicF]INmeJeBU96<DYBAS5243g_0T8@0cg_
00E244YBAS56<Cg_0096<@9BU008BU96<D8@@Q16<DYBCW=BU0A:DP08AS5:
DTYBBU96<D8@?Nm6<@=:DP04AS5243g_@Q02AS400cg_@Q16<@03BU801DHa
BU92448@AS400TYB00Q6<Cg_?NlmkcW>@Q0mkd8@0THa00e243g_?Nlmkd8@
?NlicSF]<H`]JbDY8@PDY@0436<00`Q212448@0212400`Q212448@021240
0`0012448@02124011S68@PU:AcW0PaS0PQ200<48@0012400P@Q1@Q200<4
8@Q212400`aS0PQ200<48@Q212400P@Q0PQ200T48@aS48@DY@aS1248@PaS
24800P@Q00<8@P@Q12400PaS0QBU10aS0Q240QBU00DHaPaS36<8@PaS008@
Q08<H`03248<H`aS0088@P@48@08248<Ha2436<U:C6<E[E_N`9cW00;JeYo
ogooMke[FR4848@<HaBU8@PDY@0212400`Q212448@0312401P00248<Ha24
5:D8@P<48@0300048@@Q00@48@0424848@Q236<2248712400`Q21248@P02
24801@@Q2488@P@Q24800P@Q00<8@P@Q24801@@Q00<8@P@Q12403`@Q00<0
00@Q24801@@Q00/8@P@Q1248@P@Q24848@Q236<@Q0aS00<@Q08Li`07;F/e
[CW>?NlicSg_BU800U:D00A>LdYBAS5:DP9F]@9JeP04E[ENme[FF]H2E[D0
35[FDYABU5:DE[EJeUJeDYAF]DicDYA>L`9BU004E[EBU5JeE[D4CW<015[F
E[EF]EJe1E:D00=F]E[FF]H00e[F0Ukg0U[F00IF]E[FE[EJeUJeDY@2E[D0
2E[FE[EF]E:DF]IF]E[FE[EJeP03E[D2DY@2E[D00e[FE[EF]@02F]H01EJe
F]IJeU[FG_L00U[F00AF]E:DDYAF]@9BU0AF]@05F]IF]EJeE[EBU002E[D0
0e[FE[EBU002E[D2F]H3E[D00e:DF]IF]@02F]H2G_L00eJeF]IJeP02F]H0
25JeDYAF]E:DF]IF]E[FE[D2F]H3E[D6F]H00ekgF]IF]@02E[D3G_L01E[F
G_MNmf<HIcT00V<H00=Nme[FG_L02V<H00ANme[FF]IJeP9Nm`03HaQNme[F
00=Nm`AS6003IcUS65kg009Nm`9S609Nm`05F]INmf<HG_MS6003F]H01Ekg
HaQS65kgF]H00ekg0f<H0ekg1f<H0VLi0V<H00=Nmf<HG_L00Ukg00=S66Li
HaP01ekg00IJeUJeF]INmf<HIcT3G_L00f<HG_MNm`03G_L00e[FG_MNm`02
G_L1HaP1E[D1?Nl0000400048@@Q0004124020Q212448@aS>Lioof]J?Nl2
BU800dHaBU9>L`02CW<2AS401TYBCW=>LdicDYA:DP96<@04CW=BU5JeCW<2
BU82@Q0013g_AS52448@0THa00E>LdYBBU9244Ha009:DP9JeP04DYA>Ld8@
BU82@Q0013g_AS52448@0Sg_0T8@00=6<D8@@Q000THa0U:D00E:DTHa@Q12
44Ha00A>L`03AS5:DTHa0096<@03BU96<D8@008mk`08AS5:DTicBU96<Cg_
>Li24096<@03@Q0mkdHa009>L`=6<@03@Q16<DHa009:DP05AS4mkd8@?Nli
cP02?Nl3AS403T8@>LhicSg_@Q0mkcF]>Lh]Jc6<9BTLiaS648@236<52485
12400`0012448@0312401ABU9BTYBQS612400PaS1@@Q00L8@P@Q1248@P@Q
24848@02248436<32482124224800`aS248<H`0436<42482124324801A24
5:D@Q0aS24800PaS00<@Q1BU5:D00QS600@@Q0Q2248<H`8@Q00536<8@PQ2
248<H`022483124324801@aS248U:C6<F]H00Vmk00ag_FmkNmioogNmIcTQ
20aS248HaR485:D2124010Q212448@000`@Q0PaS00<DYA2412400P@Q00D0
00@Q12448@Q200D48@0336<8@P@Q00H48@0424848@@Q12442484124010Q2
1248@PQ22`@Q00D8@P@Q12448@0001448@0324848@@Q00848@0<248<H`aS
36<@Q1BU48@DYAS67>LaS3F]13g_00A:DU:DDYA>L`96<@03CW=F]E:D00EJ
eP9F]@03F]IF]EJe009BU004E[EJeUJeE[D2DY@014icDYABU5Je0U:D00=F
]E:DDY@00Tic00ABU5JeE[EF]@IBU003E[EJeU[F00AJeP9Nm`04F]IF]EJe
F]H2E[D2DY@6E[D2F]H5E[D2DY@015JeF]IF]E[F15Je15[F00ENmeJeF]IB
U5Je00ABU003E[EBU5Je00=F]@04DYAF]EJeF]H6E[D015[FE[EBU5:D0UJe
0U[F00=Nme[FF]H00U[F00=Nme[FE[D00U:D1EJe0e[F00EF]E:DE[EJeUJe
009JeP06E[ENme[FF]IF]E:D0e[F15kg00IS66LiIcUS65kgF]H2G_L4HaP0
1VLiHaQS65kgHaQNm`=JeP03G_MS65kg009Nm`07F]INmf<HHaQNmf<HIcT0
0V<H0ekg0f<H0U[F0Ukg00AS65kgF]IF]@9Nm`9S60ANm`06HaQNmf<HHaQN
me[F0V<H00AW>F<HHaQNm`=S6004IcUS66<HHaP3G_L5HaP5G_L4F]H00ekg
HaQNm`06G_L00f<HF]INm`02F]H3G_L1HaP1E[D1@Q0000848@0>00048@@Q
124000@Q24848@0036<mkgooKg/mk`9>L`96<@06BU9BU4icCW=6<DYB0THa
00=>Le:DBU800THa00A:DTicBU9:DPA240M:DP0:CW=:DTYBAS5244YBCW=B
U5kgF]H2CW<0348@?Nm243g_@Q0mkd8@?Nm244HaBU96<@924005AS5>Ldic
BU96<@02@Q000dYBAS5:DP02BU800dHaBU8mk`02>Lh01Cg_BU96<DHa@Q00
0THa00]:DTicBU96<D8@AS5:DTicBU9243g_009240A6<@924003AS52448@
00=2408mk`924003AS5243W>008icP05?Nm6<DHa=Jd]J`037>L011BU48@8
@PQ20P@Q00<8@P@Q12400`@Q0PQ20`@Q00H000@Q12448@Q212425:D011cW
8@P@Q0Q21@@Q0PQ20`@Q0`Q200H<Ha2448@@Q0aS2484124524801A245:DH
aQS648@00PaS00@8@PaS2488@P8@Q0046<HLia2436<224800aBU48@<H`02
36<424800a245:DDY@0236<01ABU48@@Q0Q212400PQ200<@Q0aS36<00PaS
00/LibDY?Nm>Le[FKg][FWNmJeY>Ld8@008HaP0436<8@PaS248236<00`Q2
12448@0212401@Q21248@P@Q36<00Q2400@8@P@Q1248@P<48@88@P031248
@PQ200@8@PH48@03248<H`aS00<<H`0424848@@Q248212400`Q212448@07
12401@Q21248@P@Q000010@Q00H000@Q124000@Q00031240100012448@Q2
10@Q0PQ210@Q00@8@P@Q248<H`<@Q08DY@8HaP8YBP03@Q16<DHa009:DP05
CW=BU5:DDYA>L`02DY@2E[D2F]H015JeDYABU5Je0U:D00=F]E:DDY@00UJe
00=JeU:DE[D015:D00E>Le:DE[EBU5Je00ABU09F]@03DYAF]EJe00=BU0=F
]@=JeP9F]@AJeP03E[EJeU[F00=F]@06DYAF]E[FF]IF]E[F2EJe00EJeU:D
E[EF]E:D00AF]@03G_MJeU[F009BU003E[EBU5:D00=BU0AF]@04DYAF]E[F
F]H4E[D4F]H015JeF]IF]EJe0U[F00=F]E[FF]H00e[F00ENme[FF]IBU4ic
009BU005E[ENme[FG_MJeP03DY@2F]H015JeDYAF]E[F0Ukg0U[F00ABU5Je
F]IF]@9JeP03G_MS66<H009S6004IcUNme[FF]H2G_L01F<HIcUS65kgHaP0
0VLi00AS65[FG_MNm`9JeP06E[ENmekgG_MJeUkg0U[F0Ukg00=S66LiHaP0
0V<H00=Nme[FG_L01Ekg00=JeUkgG_L00e[F0f<H15kg00=S65kgG_L00V<H
0ekg0f<H00=Nmf<HHaP00Ukg00=S65kgHaP00ekg0V<H0ekg0f<H0Ukg0U[F
0Ukg1F<H00=Nme[FG_L00V<H0Ukg0U[F0Ukg0F<H0E[F0D8@00000`001244
8@021240100012448@Q20P@Q00D8@Sg_Oom[FSg_009>L`03AS5:DTYB009>
L`03BU96<DHa009:DP9>L`9:DP96<@03BU9>LdHa00924005?Nm244HaAS5>
L`03BU800dicBU9:DP02AS40148@BU9BU5Je0U[F00A>LdYB?Nm2408mk`05
@Q0mkd8@@Q0mk`02BU8014Ha@Q1244YB0Tic00E6<DYB@Q1244Ha00E:DP05
AS4icSW>>Li24002AS42@Q000dHaBU9:DP02BU82@Q0014HaBU9>Ldic0T8@
00<mkd8@AS400TYB00E6<D8@@Q1244Ha00924003AS4mkcW>008mk`05@Q16
<D8@?Nle[@02?Nl014YB@Q0aS2e[0QcW00<HaQBU36<00PQ200<48@Q21240
20@Q00@000@Q124000<48@03248@Q1BU008Li`0448@<H`@Q000312401@Q2
1248@PQ212400`Q200@<Ha2448@@Q088@P848@L8@P0648@DYABU6<H@Q0aS
0PQ20PaS00<8@Q2448@00QS600@@Q0aS36<<H`8@Q00336<8@PQ20088@P05
36<8@QBU5:D@Q00236<011246<H<H`Q20P@Q00<<H`Q236<00`aS00dQ22DY
?Nm>Le[FLia_NgNmKg]>Ld8@7>LDY@0236<324800`aS48@48@03124020Q2
12448@Q248@DY@aS2482124020Q212448@@Q248<H`@Q248236<224861240
0`Q21248@P0336<010Q236<8@PQ210@Q00<8@P@Q124020@Q00<000@Q1240
50@Q00<8@P@Q12400`@Q0PQ200<48@Q224800Q2400<DYA245:D00QS600PU
:Be[?Nm6<DYBAS5:DTic0U:D0Tic00AF]E:DDYAF]@9JeP03E[EBU5:D009B
U09F]@03DYAF]EJe009F]@EBU005CW=BU5:DDYAF]@08DY@015JeDYABU5Je
0U:D00EF]E[FF]IJeUJe00=JeP03E[EJeUJe009JeP03E[EJeUJe009BU003
E[EJeU[F00EF]@03F]IF]E:D009BU003F]IF]EJe009BU0EF]@=JeP9BU09F
]@03DYA>Le:D009F]@03DYAF]E:D00MF]@03F]IF]E[F009JePAF]@04F]IF
]E[FE[D3F]H2G_L2F]H015:DCW=BU5:D1E[F0U:D0eJe00ABU5JeDYAJeP=N
m`03F]IF]EJe00=JeP=Nm`03HaQW>FLi009S6006F]INme[FG_MS66Li0V<H
00MNmf<HHaQS65kgF]INm`02E[D015[FG_MNme[F0Ukg00=JeUkgF]H01V<H
0Ukg00=JeUkgG_L00Ukg00AJeUkgG_MNm`=JeP03G_MS65kg009Nm`03F]IN
mekg009S609Nm`03F]IS66<H00MS6003G_MS66<H009Nm`03F]IS65kg009S
60=Nm`03HaQW>Ekg00=JeP9Nm`ES6007G_MJeUkgG_MS65kgF]H015kg0F<H
0E[F0Cg_00001@@Q00048@@Q00000`@Q00P8@P@Q124<Hcg_Oom_NcW>1TYB
00=>Le:DCW<01dYB0THa0d8@0dYB00=6<DYBBU800Tic00A:DTHa@Q1>L`9B
U00:BU96<DHaAS5:DU[FG_MJeTic@Q02AS400d8@?Nm24002@Q02AS46BU80
14Ha@Q16<DYB0d8@00M6<DYB@Q1244Ha@Q0mk`02>Lh01d8@CW=BU4ic@Q16
<Dic009BU003BU96<DHa00=>L`05AS5243g_@Q16<@03@Q02AS47@Q000cg_
>LhicP02@Q001Sg_>Lhe[Cg_=JdaS08Q20046<HDY@aS248212400`Q21244
8@0212400`Q212448@0:12401PQ21248@PQ236<@Q08<H`0524848@@Q0004
8@042483124324801A246<HHaQ2424800P@Q00H8@P@Q248<H`Q236<22480
1aS6<H`mkcF]7>LDYAcW008HaP<@Q08DY@0348@<H`Q200/8@P8@Q08DY@04
48@<H`aS36<348@236<02A246<HQ21BU;F]:DVLiJeYBU002BU802RU:6<HL
ic6<:DXDY@@Q248@Q0aS0PQ20P@Q00D8@P@Q2488@P@Q0088@P0336<8@PQ2
00<8@PD<H`88@P0336<8@PQ20088@P848@04248<HaBU5:D26<H25:D248@2
2482124010Q212448@000P@Q00D000@Q12448@Q200<48@0300048@@Q00`4
8@0324848@@Q00l48@03248<H`aS00<@Q00:5:DHaQBU:DXe[DYBCW=244Ha
CW<2DY@2CW<3DY@2E[D01E[FE[EBU5JeDY@00eJe0U:D0UJe00AJeUJeDYA>
L`=BU003CW=BU5:D009F]@07CW=:DU:DDYAF]E:DCW<015:D00AF]E:DF]IJ
ePEF]@05F]IF]E[FF]IF]@02F]H2DY@015JeF]IJeU[F0eJe00AJeUJeE[EJ
eP=F]@06DYAF]E:DE[EJeUJe0U:D00A>Le[FF]IJeP9F]@04DYAF]E:DE[D3
DY@3E[D00e:DE[EF]@02F]H01EJeF]IF]EJeF]H00UJe0U[F0U:D00AF]E[F
E[EJeP9F]@9JeP03G_MJeU[F009JeP9F]@04DYAF]E[FF]H5E[D015[FE[EF
]E:D0U[F00=Nme[FF]H00e[F00AF]E[FF]IJeP=Nm`03HaQNmekg009JeP0;
G_MJeU[FG_MJeV<HG_MS66LiHaQW>@03G_L2F]H00eJeF]INm`02G_L3F]H0
1F<HG_MS66<HG_L00V<H0Ukg00=JeUkgHaP00Ukg1E[F00=F]E[FF]H016<H
15kg0V<H00INmf<HG_MS65kgHaP3G_L00e[FG_MNm`02G_L00f<HG_MNm`0;
G_L00e[FG_MNm`02G_L2HaP00ekgHaQNm`03G_L015[FG_MNmekg0e[F0Ekg
0EJe0D8@000212400`0012448@0312402@Q2124000aS>Lioof]J?Nm6<@05
BU84CW<2AS42BU801TicBU9244Ha@Q0mk`96<@=:DP05AS5:DTicDYA:DP02
AS4014YBCW=BU4YB0T8@00M6<DYBF]INme:DCW=24002AS40148@?NlmkdHa
0T8@00=6<DYBCW<00THa00A>LdHaAS524096<@04@Q0mkd8@BU82AS42@Q02
?Nl2>Lh014HaBU9BU4YB0THa0dic00I:DTHaBU9:DTicBU83@Q001Cg_@Q12
44Ha@Q000dHa00A243g_@Q16<@924003?NlicSg_00924006>Lhe[CW>>Lhe
[C6<0R4800<DYA2436<010Q21`@Q00@8@P@Q124000848@0300048@@Q00@4
8@03248@Q1BU008<H`H48@<8@P@48@0636<@Q1246<HDY@aS0P@Q1`Q200P<
H`Q27>LaS3g_<H`HaQBU0QcW00<DYA2448@00aBU00<@Q0Q224802PQ200<<
Ha2448@00aBU0`Q200h@Q1BU48@8@PaS48@Lib486<HYBTHaHaQ_Ne:D0TYB
00PYBQS67>L]JbU:5:D48@Q20PaS0PQ20`@Q00<8@P@Q24800PQ20`aS0PQ2
0PaS00<8@PaS24800PaS0PQ200<48@Q224800PQ200@48@Q21248@P8@Q08H
aP8DY@8<H`0424848@Q2248:12400`0012448@0:12400`Q212448@071240
0`001248@P0:1242248236<348@01ABU6<HDYBe[>Lh00TYB0THa00=>Le:D
DY@00dic0U:D0UJe00=JeUJeDY@00U:D00=F]E:DDY@00U:D00EF]E[FE[EF
]Dic00EBU004CW=F]EJeDY@3CW<01E:DCW=BU5:DCW<00U:D00AF]E:DE[EF
]@AJeP=F]@03F]IF]E[F00=JeP9BU005E[EJeUkgF]IBU003E[D00e[FE[EF
]@02E[D00e:DE[EBU003E[D4DY@2E[D00e[FE[EBU002DY@015JeDYA>Le:D
0eJe0U:D00=F]E[FF]H00UJe00=JeUJeE[D00UJe15[F1UJe00=BU5JeF]H0
0Ukg0e[F00AF]E:DDYAF]@AJeP9BU0=F]@03DYAF]EJe009JeP05G_MJeU[F
F]IF]@04F]H4G_L00f<HG_MJeP02F]H5G_L01E[FHaQS66LiHaP00ekg0U[F
0UJe00INmf<HG_MNmeJeF]H2G_L00f<HG_MS6002HaP00ekgF]INm`03G_L2
F]H01eJeF]INme[FE[EJeUkg00=S60ANm`=S60ANm`03HaQNmekg00=Nm`9J
ePQNm`03HaQNmekg009Nm`08HaQNme[FG_MJeUkgF]INm`AS60INm`03F]IN
mekg009JeP5Nm`5F]@52400000D000@Q12448@0000<48@0924848@@Q36<i
cWooF]HicTHa009>L`=:DP03AS5:DTYB009>L`=6<@=24005?Nm:DTYBCW=B
U002BU82CW<3BU82AS401DYBCW=BU4YBAS400d8@00=6<E:DCW<00UJe00=:
DTic@Q000T8@0dHa00a244HaAS5>Le:DBU96<D8@?Nm244YBAS43@Q000dYB
AS56<@02AS42@Q02>Lh01Cg_@Q1:DTYBAS4014YB00=6<DYBBU800TYB00A>
LdHaAS4mk`<icP03@Q16<DHa009240<mk`924005?NlicSW>>Lhe[@02>Lh0
1CF]>LhicRU:8@P00a2400<<H`Q212400P@Q0PQ20`@Q0`Q22`@Q00L8@P@Q
1248@PaS48@<H`0712401PQ236<8@PQ21248@P8<H`0548@DYA2448@<H`02
248010@Q248<H`Q20Q2400/HaQBU7>LHaRU:@Q1>LfmkIcTmkbe[008<H`8D
Y@0348@<H`Q200<48@05248<H`aS36<8@P021242248236<25:D248@536<3
24802PaS6<H<HbDYF]Ig_F]J=JdHaR480QS60QBU0PaS00<8@PaS48@00PaS
00<8@PaS24800`Q20`aS00<8@P@Q248010Q210aS2`Q200<@Q1BU7>L00SF]
00ABU5[F;F/Li`88@P0348@8@PQ200/48@0300048@@Q00d48@0324848@@Q
00P48@0400048@@Q0003124224803@@Q2488@PaS48@<HaBU6<HLib48:DXe
[Cg_0096<@08@Q16<DYBBU9BU4icDYA>L`9F]@03F]IBU5Je009F]@9BU09>
L`AJeP0:CW=BU5:DCW=BU4icE[EBU5JeDY@3CW<00e:DE[EBU003DY@01UJe
DYABU5:DE[EJeP9F]@=JeP9F]@9JeP9Nm`9JeP04E[EJeU[FG_L4F]H2E[D2
DY@3E[D01E:DE[EBU5[FG_L00U[F00MBU5JeE[EF]E:DE[EJeP08DY@8E[D0
25[FE[EF]E:DE[EJeUkgF]H3E[D3F]H01EJeF]IJeU[FG_L00UJe0U[F00=F
]E:DDY@00U[F15Je00IBU5[FG_MNme[FDY@2E[D015:DE[EJeU[F0eJe00=J
eUkgF]H01Ekg00=S65kgG_L015[F0Ukg00=S65kgHaP00Ukg00AS65kgHaQN
m`9JeP=Nm`03HaQNmekg009S609Nm`03HaQW>F<H00AS609Nm`9JeP03G_MS
66<H00=JeP03E[ENmf<H00ES6004G_MJeU[FF]H3G_L2F]H3G_L02e[FG_MN
mekgHaQNme[FG_MJeUkgF]H015kg00=S65[FG_L00ekg0e[F0ekg0f<H0Ukg
00AJeUkgG_MS609Nm`04F]IF]EkgE[D1@Q0000<48@0300048@@Q00D48@07
36<icWooG_Le[DHaDY@014YB0THa0Tic0TYB00A244YB@Q12408mk`04AS5>
Le:DCW<3BU800dicBU9>L`02BU82AS42CW<00dYBAS4mk`02@Q001DHaCW=B
U5JeDY@00TYB0T8@0dHa00I244Ha@Q1:DTicDY@2AS42?Nl00dHaBU96<@02
?Nl0148@AS5:DTHa0d8@00E6<Cg_>LhicT8@009:DP96<@I:DP06CW=:DTYB
@Q16<Cg_0cW>00=244HaAS400T8@00@icSg_?Nlmk`924003>Lhe[CW>00<i
cP05=JdicSF]:DXQ200248@00`aS2488@P0412422483124324800`@Q0004
8@0512401@0012448@Q212400PaS0`Q210@Q00<8@P@Q24800PQ200<48@Q2
12400PaS00<@Q1BU48@00Q2400@8@P@Q12448@<<H`<DY@8HaP0<:DY244ic
JeYW>Cg_:DX<Ha245:D@Q0aS0PQ200L48@Q22488@PaS248<H`0424800`@Q
36<DY@025:D01A2436<<H`aS48@00PaS0PQ20PaS00hHaPaS9BUJeWNmJeXi
cQcW8@PLiaS648@DYA241`aS0`Q210aS10Q200<<H`Q224800PQ20PaS20Q2
00L48@Q236<8@PaS48@HaP02>Lh2DY@01Be[8@P48@Q236<00PQ280@Q00<8
@P@Q12402`@Q00L8@P@Q1248@PaS5:D@Q0025:D28@P00be[=JdicP04AS42
BU82CW<3DY@00eJeDYAF]@02DY@01UJeDYABU4icDYAF]@9JeP03E[EBU4ic
00IBU006E[E>LdicBU9BU5Je0U:D00U>Le:DDYAJeU:DCW=BU5JeF]H00UJe
00=JeUJeE[D00UJe0U[F0ekg0UJe0U[F0Ukg0U[F0UJe0U:D00IF]E:DE[EB
U5JeDY@2E[D00ekgE[EF]@02DY@00e[FDYAF]@02E[D4DY@01EJeDYABU5Je
DY@01EJe00EBU5[FF]IJeUJe009BU006F]INme[FE[EBU5Je0e[F0eJe00AN
me[FF]IF]@9JeP03E[E>Le:D00=JeP09DYAF]EJeE[EJeUkgE[EJeU:D00EF
]@06F]IF]EJeF]IF]E[F0ekg00MJeUkgHaQNmf<HF]INm`02F]H015kgF]IN
mekg0V<H0ekg00=S65kgF]H00e[F00=Nmf<HG_L00Ukg00AS65kgG_MNm`9S
6003IcUS65kg00=S60=JeP9Nm`03HaQNme[F009JeP03G_MS66<H009S6003
G_MS65kg009JePANm`9JeP=Nm`9JeP03G_MS66<H009Nm`EJeP9Nm`03HaQN
mekg009JeP9Nm`AJeP04G_MS66<HHaP2G_L2F]H2G_L2HaP3F]H1G_L1E[D1
@Q00000300048@0000848@0400048@@Q248212401PQ2>LicW5[F=Je6<@9>
L`9:DP=6<@9:DP04CW=:DTHa@Q02?Nl2AS400dicDYABU002CW<01TYBDYA>
LdicBU9>L`9:DP96<@03BU9>LdYB0096<@09?Nm244Ha@Q1F]E[FE[EBU48@
00=6<@=24004AS5244YBAS42BU82@Q02>Lh3@Q000dHaBU9:DP02AS401dYB
AS56<Cg_@Q0mkcW>00924009CW=BU4icCW=:DT8@AS5:DTHa00=:DP03AS52
43F]008icP04@Q1:DT8@@Q02?Nl3@Q003Sg_>LhmkdHa@Q0mkcF];F/YBSF]
<H`U:ABU248236<71242248010@Q248<H`Q230@Q10Q20PaS0PQ210@Q00D8
@PaS36<8@PaS0088@P0648@DYAS66<H@Q0Q20P@Q00D8@PaS248<Ha24008L
i`05<H`e[CF]?Nle[@028@P02cg_CW=cW6Li:DXLi`Q248@DYA24248010aS
00<8@PaS12400`@Q0PQ20Q2400PDYA242488@PaS24848@Q20PaS0PQ200L<
Ha2436<HaRU:<H`YBP026<H27>L00aBU36<<H`0236<01a245:DHaQBU48@<
Ha2400@8@P8DY@0348@<H`Q200L8@P051248@PQ21248@P021242248248@0
0aBU6<HLi`02:DX2;F/022DY7>M246<HE[D]J`Q2124236<A12400`Q21244
8@0:12400`Q212448@0=12402@Q21248@PQ236<8@Q245:DHaP025:D011S6
8@PYBS6<0Sg_00=244YBCW<014ic00=BU5JeF]H00UJe0U:D00A>Le:DDYAB
U0=F]@03DYAF]Dic009>L`03DYA>Le:D00ABU09>L`05DYAF]E:DDYAF]@04
DY@01e[FE[EBU5:DF]INme[F009F]@9JeP9Nm`05HaQJeU[FF]IF]@04F]H0
1EJeDYAF]EJeDY@00UJe00=BU5JeF]H00U[F15Je00MJeU:DDYABU5JeF]IF
]@02CW<3E[D015:DE[EF]E[F2eJe00=JeUJeF]H00e[F00=F]E:DF]H00e[F
0UJe00IJeUJeF]IJeUJeF]H2E[D02U[FE[EJeU[FE[EBU5JeF]IS65kg0UJe
0U:D00IF]E[FF]INme[FE[D2F]H2G_L4F]H3G_L2F]H00ekgF]IJeP02HaP0
25kgHaQJeU[FG_MJeV<HG_L3F]H2G_L2HaP02EkgHaQS65kgF]IS66LiHaQN
m`02HaP015kgF]IF]EJe0U[F00ANme[FE[EBU0=JeP06G_MS66LiIcUS65kg
15[F00ENme[FF]IJeUkg009JePQNm`9JeP9Nm`9JePENm`05F]INmekgG_MJ
eP08G_L3F]H3G_L3F]H1HaP1F]H1?Nl000H48@0<00048@Q2124000aS=Jeg
_EJe>Li6<E:D0dYB0dHa0TYB00A>LdYB@Q12408mk`06@Q16<DYBDYAF]Dic
0TYB0Tic0TYB00=>LdYBBU800THa0dYB0THa00/mkd8@AS56<E:DF]IF]Dic
@Q16<DYB00E240E6<@08@Q0mkcW>>Li243g_@Q16<@=:DP04AS5:DTHa@Q03
?Nl01SW>@Q16<DYBDYA>L`9:DPA6<@9:DP04AS5:DSg_=Jd2>Lh3AS400cg_
@Q0mk`02?Nl2@Q02?Nl2@Q002cg_=JdYBRU:<H`e[BDY7>L8@PaS24801@@Q
0`Q200@48@Q22488@P`48@88@P041248@PQ236<248@010Q212448@@Q0PQ2
00<<H`Q224800PQ200L<Ha245:DDYAS636<8@P0212400`Q236<<H`0248@2
7>L04Be[<H`e[CW><H`Lib48?NmF]FmkG_LU:AS6248<HaBU36<00PQ200<<
H`Q236<00PaS0PQ20P@Q0PQ200@<HaBU5:DDY@X8@P0936<@Q0aS7>LYBS6<
:DXHaQBU008Li`035:D<H`aS008<H`0448@DYABU6<H248@00`aS248<H`02
248010aS5:D@Q0aS1PQ20P@Q00L8@P@Q2488@P@Q24848@0224803`aS48@D
YAS68@PYBS6<;F/YBRDY8@Q246<HCW<aS00212400`aS2488@P0712401000
12448@004`@Q00<8@P@Q12401P@Q00<000@Q12400P@Q00D8@P@Q12448@Q2
008<H`0448@DYABU5:D26<H00bDY:DXaS002>Lh2AS4014icDYA>LdYB0Tic
00IJeUJeE[EBU5JeCW<5DY@3E[D00e:DCW=>L`02CW<2DY@014icDYABU5:D
0Tic00=F]E:DDY@01U:D00AJeUJeDYABU0=JeP9F]@04F]INmekgHaP2G_L0
2EJeF]IJeU[FG_MF]E[FDYAF]@02DY@01EJeDYABU5JeDY@00e[F0UJe00IB
U5JeE[EF]E:DCW<2F]H01EJeCW=>Le:DF]H00U:D00=F]E[FF]H00eJe00=B
U5JeDY@01EJe0U[F00IF]E[FF]IF]E:DE[D2F]H00ekgF]IJeP03E[D015[F
E[EJeUJe0U[F0eJe00AJeUJeDYAJeP=Nm`05E[EJeU:DDYAF]@04F]H00eJe
F]IJeP02G_L3F]H5G_L2F]H00ekgF]IS6002HaP015kgF]INme[F0V<H00EJ
eUkgE[EJeUkg00=S6008G_MS66<HG_MJeV<HIcUS609Nm`06HaQNmekgE[EB
U5[F0Ukg00=JeUJeE[D00e[F0f<H00=W>F<HG_L015[F00QNme[FF]IJeUkg
F]INme[F0Ukg00IS65kgHaQNme[FE[D3F]H01UkgF]IJeUkgHaQNm`=JeP]N
m`=JeP=Nm`05F]IF]E[FG_MJeP01@Q00000500048@0012400003124030Q2
00048@aS>Lig_E:D<Ha245:DCW=:DP9>L`96<@06@Q16<DHaBU96<DYB0THa
00A>LdYBCW=>L`9:DP03CW=:DTic00=:DP03CW=BU5:D0096<@9:DP9>L`06
BU92448@@Q16<E:D0eJe0Tic00M:DT8@?Nlmkd8@AS524002AS42BU82AS42
>Lh2?Nl01D8@?Nm2448@AS400Tic0TYB00E243g_?Nm244Ha00=:DP07AS5:
DTYBBU96<D8@BU800THa00A244HaAS4mk`8icP924004?NlicSW>?Nl2@Q00
1cg_>Lhmkcg_>LhaS2U:008U:@058@PHaQS648@<H`04248612401@Q236<8
@PaS48@00PaS10@Q00D000@Q12448@Q200848@0424848@@Q248236<01124
5:D@Q0aS0PQ21@aS0Q2400HHaR486<H@Q0Q21243248236<04ABU6<Hmkd8@
G_MW>E[FIcUJeTYB?NlLiaBUAS5_Nf<H<H`00P@Q00<@Q0Q236<00PaS0Q24
00@<H`Q22488@P@48@8<H`0548@<H`Q21248@P021243248636<00aBU6<HD
Y@0248@25:D01Q2436<8@Q245:DLi`<DY@0:7>LHaQBU36<8@P@Q248<H`Q2
48@336<010@Q2488@P@Q0`Q20`@Q10Q200P<HaBU5:DU:CF]@Q1F]DYB0UJe
00XicRe[9BTU:D8@CW<icR4824848@8<H`0324848@@Q00<48@0324848@@Q
00P48@0324848@@Q01D48@0324848@0000848@0624848@Q21248@PaS0a24
00LDYAS67>LU:Cg_@Q16<@02@Q0014YBCW=>Ldic0U:D0UJe00=BU4icDY@0
0e:D00A>Le:DCW=F]@=BU006CW=BU4icCW=:DTic0e:D0dic0UJe15:D0U[F
00ABU5JeE[EJeP9F]@=JeP04G_MJeU[FG_L2HaP01ekgDYABU5JeG_MS65[F
009F]@03F]IBU5:D009BU004E[EJeU[FE[D2F]H015JeF]IF]E[F0eJe00=B
U5JeDY@00U:D00AF]E:DE[EF]@9JeP9F]@9JeP=F]@9BU004E[EBU5JeE[D5
F]H2E[D2F]H01EkgF]IJeUJeF]H00eJe00IJeUkgF]IF]E:DE[D2F]H2E[D0
1E:DE[EJeUkgF]H00UJe00EBU5JeF]IJeUkg009JeP0;E[EJeUJeF]INme[F
E[EJeUkgHaQNm`04F]H4G_L01f<HG_MJeU[FE[EJeUkg00AJeP05G_MS66<H
G_MJeP03G_L00f<HIcUS6004G_L5F]H3E[D3F]H2G_L00f<HIcUS6002G_L4
F]H00eJeF]IJeP02G_L3F]H2G_L01E[FG_MNmekgHaP00ekg00AJeUkgG_MJ
ePANm`9JePANm`9JeP06G_MJeUkgG_MJeUkg1U[F00ANme[FG_MJeP4mk`00
2`@Q00H<HcW>LiaF]C6<AS42CW<3BU8014Ha@Q12448@0dYB0T8@00=6<DYB
BU800dic0TYB00Q>Le:DCW=6<DYBCW=BU4ic0TYB00M6<DYBBU9>LdYB@Q0m
k`02@Q02E[D025[FE[E:DTYBAS5243g_@Q03AS42@Q0014HaCW=6<Cg_0SW>
0T8@00E6<D8@?Nm244Ha00=>L`07BU92448@@Q0icSg_AS400TYB00E6<DYB
BU96<D8@0096<@08BU96<D8@AS5243g_>Lhmk`924004?NlicSW>?Nl2@Q02
?Nl00d8@?NlicP02:DX01Re[9BTQ21S65:D@Q08<H`88@PL48@88@P0336<@
Q124008<H`848@0400048@@Q248212400`001248@P02124224801A2436<@
Q1BU48@00PQ200H48@aS48@<H`Q236<248@01QcW8@PHaQ24124000@8@P0B
36<DYAS6>Li6<EkgIcUJeVLiE[E243W>6<HDYDYBKg]JeS6<0P@Q1PaS00<@
Q0aS36<00`Q200<48@Q2248010aS00@8@P@Q12448@<8@P8<H`0548@<H`aS
36<DY@026<H02a2436<DYABU6<HDY@aS248<HaBU7>L00QBU00@HaQcW6<H@
Q0D8@P8<H`0348@<H`Q200D8@P848@88@P041248@P@Q124236<04aBU6<HQ
23F]?NmBU4icDYAJeSF]:DXU:BU:AS5>Lc6<7>L8@P@Q008<H`0324848@@Q
00/48@0500048@@Q1248@P0;12400`Q212448@0412400`001248@P071240
0`Q21248@P0236<248@01QBU48@HaQcW:DXicP96<@8mk`04BU9BU4icCW<2
DY@2E[D5DY@00dicDYA>L`04DY@5CW<014YBCW=BU5:D0dic15:D00=>Le:D
E[D00UJe0U:D00=F]E[FF]H00eJe0Ukg0U[F00MNmf<HG_MNmeJeDYAF]@02
G_L00e[FDYAF]@02F]H3DY@00eJeF]IJeP02F]H2E[D3F]H3E[D00e:DE[EB
U003DY@5E[D00e[FE[EJeP06E[D00e:DE[EF]@03E[D00ekgF]IJeP02E[D0
0e[FG_MJeP02F]H015JeF]IJeUJe15[F0eJe0U[F0eJe1E[F00EF]E:DF]IF
]Ekg009JeP04E[EJeU[FF]H2G_L3F]H01UkgHaQNmekgE[EJeP9Nm`04HaQN
mekgG_L6F]H01UkgF]IJeU[FG_MS60ENm`=S60ENm`03F]IF]E[F00AJeP9F
]@04F]INme[FG_L3HaP2G_L00e[FG_MNm`03F]H2G_L3F]H2G_L01E[FG_MN
mekgHaP01Ekg00=S65kgF]H00Ukg15[F00ANmf<HG_MNm`=JeP06G_MJeUkg
G_MJeUkg15[F00ENme[FF]INmeJe004mk`0000@000@Q124000@48@0>2484
8@0036<icW_NF]HicTHaDYA>LdYBCW=:DPE6<@924096<@9:DP9>L`A:DP03
CW=:DTYB00A>L`03DYA:DTYB00=6<@06CW=:DTYBBU9244Ha0TYB00QF]E[F
E[EF]D8@>LhmkcW>1dHa00<mkd8@>Lh00SW>00<mkd8@?Nl00T8@00U6<DYB
BU96<DYBAS5243g_@Q000THa14YB00I>LdHaAS5244YB@Q03?Nl2BU802D8@
?NlmkcF]>LhmkcW>?Nm24002>Lh01C6<=JdaS2U:9BT00QcW00DDYA2448@D
Y@aS00P8@P@48@0636<8@Q245:D@Q0Q20P@Q00D8@P@Q24848@Q200@48@@8
@P0636<@Q12448@DYA240`aS00X8@PaS36<8@QcW9BTYBRDY36<8@P<48@0@
248<H`Q2248HaQcWCW=NmgNmNmi_NgooLia_Ne[F;F/28@P00bU:;F/U:@02
36<02@@Q248<H`Q236<@Q1BU48@<H`03248312401@Q236<<H`aS24800P@Q
00<8@PaS36<00`aS0Q2400T<H`@Q248U:CW>:DX<H`@Q48@00PaS00@@Q1S6
7>LLi`8DY@8@Q0055:DHaQS648@<H`02248348@01`aS2488@PQ21248@P@Q
0088@P031248@P@Q00<8@P8<H`07248HaR48@Q1JeVLiNmh00W>L00U_NeJe
E[DU:@Q26<I6<E[F;F/00P@Q0Q240PQ20P@Q00<000@Q12400P@Q00<000@Q
124020@Q00<8@P@Q124010@Q00<000@Q12402P@Q00<8@P@Q12400`@Q00D8
@P@Q1248@P@Q0088@P0336<@Q124008@Q08HaP097>Le[Cg_CW=6<D8@AS5>
LdYB00ABU003CW=BU5Je009BU003BU9>Le:D00EBU003CW=:DTYB00I>L`05
DYAF]E:DDYA>L`02DY@2F]H3DY@4E[D01U[FG_MNmekgF]IF]@=S6003F]IB
U5Je00=JeP03E[EBU5Je009F]@03F]IBU5Je00AF]@03DYAF]EJe00=JePAF
]@=BU0=F]@07DYAF]EJeF]IF]E[FE[D00e[F0e:D00MJeUJeDYAF]E[FG_MJ
eP04E[D2F]H025kgF]IJeU[FE[EBU5JeF]H2G_L01e[FE[EF]EJeF]INme[F
00=F]@03F]INme[F00MJeP04G_MJeUJeE[D2F]H2G_L2F]H00ekgHaQNm`07
F]H2G_L016<HG_MJeUJe15[F00AF]EkgG_MS60=Nm`EJeP04G_MS65kgHaP2
F]H4G_L00e[FG_MNm`02G_L00e[FHaQS6002HaP00ekgF]IS6003G_L5F]H0
0eJeF]INm`06G_L00e[FG_MNm`02HaP4G_L4HaP00e[FG_MNm`03HaP3F]H2
G_L015[FG_MNmekg0U[F0UJe0e[F0Ekg0EJe0D8@00000`@Q00048@021240
3@0012448@Q200048@aS>LikgU[F>Li:DTic009:DP9>L`96<@04@Q16<DHa
AS42@Q02AS4014YBCW=>Ldic0THa0dic0TYB0Tic0U:D00A:DTHaBU92409:
DP9>L`03AS5244Ha009:DP05E[EJeUJeE[E24003>Lh2AS401d8@AS56<DYB
AS5243W>008e[@06?Nm2448@@Q0icSg_0TYB00=6<D8@BU800d8@00<mkd8@
BU801TYB00A6<D8@AS56<@8mk`07@Q16<DYB@Q0mkcW>=Jd00Sg_00<icT8@
?Nl00SW>0S6<0Re[00<U:B487>L00QBU0Q2400<<H`Q224800`Q200@48@Q2
2488@P848@88@P0536<DYABU48@<H`0512422484124010Q21248@PQ20PaS
00<@Q1BU48@00`aS0Q240PaS00L8@QcW8@PU:BU:48@8@P02124324802@@Q
36<Lib48DYAS67NmNmi_N`02Mkd02F]JE[DYBQcW8@P]JcF]9BT<H`022480
10@Q48@@Q0aS0QBU00@@Q0aS2488@P@48@03248<H`aS0088@P848@03248<
Ha240088@P8<H`0>48@8@P@Q36<U:CW>:DX<H`@Q36<@Q0aS48@HaP8Li`8D
Y@0448@DYAS66<H248@236<010Q236<<Ha240PaS1PQ200<48@Q224800`Q2
01X<H`Q236<<HaS69BTmke[FHaQkgWNmKg][FU:DF]HYBPQ26<I6<Ekg;F/0
00@Q48@DY@aS1P@Q00<000@Q12405@@Q00@000@Q1248@P`48@88@P031248
@P@Q0088@P<@Q08DY@047>LQ23F]@Q02BU82AS400dYBCW=BU002DY@01Tic
DYABU5JeDYA>L`9:DPEBU003CW=BU4ic00=:DP04CW=BU4icCW<4DY@01Dic
DYABU5JeF]H00e:D1EJe00=JeUkgG_L00U[F00ANmf<HHaQJeP=F]@05G_MJ
eU[FE[EBU004E[D00e:DE[EJeP02E[D00e:DE[EF]@03F]H3E[D3DY@025Je
DYAF]EJeDYAF]E[FE[D3F]H00eJeF]IF]@02DY@00eJeF]IBU002DY@2F]H0
0ekgE[EF]@02E[D00e[FG_MJeP03F]H3E[D01U[FG_MNme[FE[EBU0AJeP=F
]@=JeP03G_MJeU[F00IJeP9F]@03F]INmekg00=JeP=Nm`9JeP04E[ENmekg
G_L2F]H01F<HG_MNme[FE[D00U[F00QNme[FF]IJeUkgHaQNme[F0Ukg15[F
0Ukg00=S65kgG_L00U[F0ekg15[F0ekg0V<H1Ekg00=S65[FF]H015[F00=N
me[FF]H00ekg00=S65[FF]H00Ukg00ES65kgG_MNmf<H00=Nm`=S6003G_MJ
eV<H009S6006G_MJeU[FG_MJeUkg0e[F00ANme[FF]IF]@AJeP5Nm`5F]@52
40000P@Q00<000@Q00000`@Q00/8@P@Q124<HcW>NmiF]Cg_CW=F]E:D00E:
DPI6<@9:DP03DYA>Ldic009>L`=:DP03CW=BU4YB009:DP06CW=BU4YBAS4i
cT8@0TYB00a6<DYBCW=:DTHa@Q0mkdicE[EJeUJe@Q02?Nl0148@?Nm243g_
0d8@00@mkcW>@Q12408icP0=@Q16<DYBAS5243g_AS5:DTicAS5243g_AS40
0TYB0dHa0Tic00M:DTHaBU9244Ha@Q16<@03@Q02AS400cg_>LhicP02@Q00
0cW><H`aS002<H`2;F/29BT011cW5:D@Q0Q21@aS0PQ200<<H`Q236<00`aS
00<8@P@Q24800PQ200<<H`Q236<00PaS00<8@P@Q24801`@Q00@@Q1S68@PQ
208DY@0348@<H`aS00D@Q0095:DQ2248:DX]JacW5:D8@P0000848@88@P<<
H`086<HQ24icE[E_Ng>LKg]oo`9g_@05F]Hmkbe[5:D@Q00236<01A245:DD
YABU36<00`Q20Q240PaS00@8@P@Q24848@88@P0<1248@PQ2248000@Q7>LY
BS6<7>L<Ha240PQ200@<H`@Q248<H`<DY@046<HLiaBU48@25:D01QS65:DQ
22U:9BTHaP8@Q0046<HDY@aS248336<25:D00a2436<<H`0336<01PQ236<<
H`Q2124@Q08HaP0:48@48@Q28@PYBTYBJeYcW7_NKg/2Mkd2Nmh01c6<7>L8
@Q247>LDY@Q200848@0736<@Q0Q2124000@Q00005`@Q00<000@Q124010@Q
00<000@Q124030@Q1@Q200X<Ha245:D@Q1S65:DHaRe[=Je>L`=:DP04CW=B
U5JeE[D6DY@01eJeCW=:DTYBDYAF]E:D009:DP03DYA>Ldic00A:DPABU004
CW=BU5JeE[D5DY@00eJeDYAF]@02F]H01UkgF]IJeU[FG_MS609JeP03DYAF
]E[F009F]@03F]IF]EJe009BU09F]@05F]IF]E:DCW=F]@02DY@2E[D4F]H0
0eJeDYABU002DY@01UJeDYABU5[FE[EBU09F]@04G_MJeU[FF]H6E[D00e:D
E[EJeP02G_L2F]H2E[D5F]H015JeF]IJeUJe0U[F0eJe15[F00=F]E[FF]H0
0eJe00EJeUkgG_MJeUJe00=JeP=F]@9JeP03G_MJeU[F00=JeP05G_MJeU[F
F]INm`02F]H2E[D2F]H2G_L00e[FG_MJeP02G_L01E[FG_MJeUkgHaP00Ukg
0U[F00=Nme[FF]H00U[F00ANme[FF]IF]@9JeP03G_MJeUkg00=Nm`04F]IN
mekgHaP7G_L4F]H00ekgF]INm`04F]H7G_L3HaP2G_L00e[FG_MS6004HaP0
16LiHaQS65kg0V<H00ANme[FF]IJeP9Nm`9JePIF]@03F]INmeJe00524000
00<000@Q12401`@Q00H000aS=JekgU[F?Nl3DY@00dYBCW=>L`02BU82@Q05
AS400dYBDYA>L`03CW<3BU83CW<2BU801dicE[E:DT8@>LhmkdHa009:DP9>
L`96<@03?Nm244ic009JeP05DYA243W>?NlicP05@Q02?Nl00cW>@Q0mk`02
>Lh01T8@BU96<D8@?Nm240A:DP08@Q0mkd8@AS5:DTHa@Q16<@=>L`=6<@A2
400:?Nm244YBBU8icSF]>Lhmkd8@>Lh5<H`01Re[9BTQ22486<HDY@<<H`88
@P0836<8@PaS248<H`Q248@<H`<8@P041248@PQ2248336<2248912401124
6<HQ21cW1A2400<<Ha2436<00a2400TLib48;F/]JaS648@8@P@Q24800P@Q
0148@PaS248<HacW8@Q>Le[FKg]g_FmkOomkgW>LF]Hmkc6<008@Q08<H`05
5:D@Q1BU5:D@Q00336<010Q248@@Q0aS0PQ200@48@Q212448@@8@P061248
@QS69BTaS2480Q240PQ20P@Q00<<Ha245:D00Q2400<HaR486<H00Q2400LH
aR486<HLibDY8@PLi`0248@01ABU48@<H`aS24800Q2400@DYA2448@@Q0L<
H`88@P0436<HaQBU48@224802248;F]6<FLiLiakgVmkMkd2Nmh03G>L<H`H
aPQ25:DQ212424848@Q248@<H`Q200H48@0300048@@Q00L48@0324848@@Q
00848@0300048@@Q01<48@0300048@@Q0088@P071248@P@Q1248@PaS48@0
11BU00DHaQcW<H`icTHa009:DP9>L`07DYAF]E:DDYA>Le:DCW<00e:D00=>
LdYBCW<00e:D0TYB1Dic0TYB00U>Le:DE[EBU4icDYAF]E:DE[D00e:D0UJe
00=BU5JeE[D00ekg00IF]EkgG_MS65kgF]H2DY@015[FE[EJeU[F0UJe0U:D
00=F]E[FE[D01U:D0UJe0U[F00=F]EkgE[D00U:D00E>LeJeE[EBU5Je009B
U09F]@04F]IF]E[FF]H2E[D015:DE[EBU5[F0U:D00QF]E[FHaQNme[FE[EJ
eUJe0U[F00INme[FF]IF]E[FE[D4F]H3E[D2F]H00eJeF]IJeP02F]H2E[D0
0e[FG_MNm`04F]H02EJeF]IF]EJeF]INme[FG_MF]@02F]H2G_L00eJeF]IJ
eP02F]H2E[D3F]H3G_L00e[FG_MJeP02G_L00e[FG_MNm`02G_L7F]H2G_L4
F]H00ekgF]INm`03G_L00e[FG_MJeP03HaP00ekgF]INm`04G_L4F]H2G_L2
F]H2G_L00e[FG_MJeP05G_L01V<HG_MNme[FG_MS609Nm`9S6003IcUS66<H
00AS6003F]INmeJe00ANm`03F]IBU5Je009F]@05F]IF]E[FG_MJeP01@Q00
0007124000@Q124000@Q00000PQ2010000@Q36<icWNmF]HmkdicF]IBU4ic
DYA>LdYBAS5240=6<@=:DP04CW=:DTYBAS43CW<02dYBAS5>LdYBAS5:DTHa
CW=BU4icBU800T8@00=6<DYBBU800TYB00A>LdYBAS4mk`96<@07DYAF]Dic
BU9243g_@Q000Sg_0d8@00<mkd8@@Q000cW>00DmkdYBAS5:DT8@0096<@=:
DP08@Q16<DicDYA>LdHa@Q16<@9:DP03AS5:DTYB009:DP07?Nm243g_?Nli
cSF]>Lh00Sg_00A6<D8@>Lhe[@8]J`8YBP099BTYBRDY6<H@Q0Q236<8@P@Q
0088@P0348@<H`aS00@8@P031248@PQ20088@P0336<8@PQ2008<H`0348@<
H`aS00D8@P@48@05000@Q1cW=JdicP028@P25:D00b487>LLi`047>L26<H2
5:D010aS48@8@PQ20P@Q0PQ20PaS00D@Q1S66<He[Cg_009S6009G_M_Nf<H
E[E242487>LDYA24008<H`075:DHaQBU6<H@Q1BU48@00PaS00<8@PaS36<0
0PQ200@<H`Q224848@88@P<48@0436<DYAcW8@P27>L00b4848@<H`021242
48@01aS68@PLiacW5:D@Q0aS008@Q08Li`089BTYBRU:8@PLiaBU6<HDY@@<
H`0448@DYABU5:D348@00aBU6<HDY@0248@00`Q2124<H`0536<28@P03CW>
CW=JeW>LJeYkgWooIcUNmbe[8@P<H`@Q0088@P@<H`0548@<H`Q212400005
12400`Q21248@P0412400`Q212448@0512400`0012448@0J124010Q21248
@PaS0QBU00LHaQ246<HHaQcW=Jdmk`02BU800dHaCW=>L`02DY@024icBU9B
U5:DE[EBU4icBU83DY@00dicBU9:DP04CW<3DY@3CW<00e:DE[EBU003E[D0
1U:DE[EBU5:DE[EBU0AJeP03E[ES65kg009JeP9BU0=F]@07DYAF]E[FF]IB
U4icDY@00UJe00EJeU:DDYABU4ic00=BU09F]@9JeP04E[EJeU[FE[D2F]H0
15JeDYAF]Ekg0UJe00IBU5JeG_MF]E:DE[D2F]H3E[D00e:DE[EF]@02F]H0
0ekgF]INm`02F]H015JeF]IJeU[F0UJe0U[F0eJe00=JeUJeE[D00eJe0U[F
00=NmeJeE[D00UJe15[F00AF]EkgG_MJeP=F]@03G_MJeUkg00EJeP03E[EJ
eU[F00=Nm`=JeP9F]@04F]INmf<HG_L2F]H015kgHaQS66<H0ekg15[F0Ukg
00EJeU:DDYABU5Je009Nm`04HaQNme[FG_L3F]H00eJeG_MNm`06G_L00f<H
G_MNm`02F]H00ekgF]IJeP02G_L01U[FE[EJeU[FG_MS609Nm`06E[EJeV<H
HaQNme[F0ekg00=S65kgHaP00V<H00Y[FV<HHaQNmf<HIcUS65[FG_MJeP9N
m`EJeP9F]@04DYAF]E[FE[D1@Q0000848@0300048@@Q00H48@0E36<mkg_N
E[DicU:DG_MBU4YBDYA>LdYBAS4mkdHaBU96<DYBAS5:DTic00=:DP03CW=B
U4ic00E:DP08AS5:DTicDYA>LdHa@Q0mk`96<@03BU9>Ldic009:DP924096
<@04CW=BU4YBAS43?Nl4@Q001Cg_@Q0mkd8@?Nl00SW>00A244HaBU96<@92
40=:DP=6<@04BU9>LdicBU82@Q0014YBCW=:DTYB14Ha00=243g_?Nl013W>
0T8@00<mkcW>=Jd00be[00HYBRDY:DXQ21S648@236<3248236<00`Q236<<
H`0624800`aS248<H`02248436<224800`aS2488@P0612402QBU7>LaS3F]
9BTQ21BU6<HLiaS60acW00@Q21cW7>LHaP8DY@0348@<H`Q200<48@0536<8
@PQ236<@Q0026<H02c6<@Q1S66LiHaQ_NfLiE[DmkbDY7>L011240QBU00DH
aQ2448@@Q1BU00@<H`0348@<H`Q200D8@P081248@PQ2248<HaBU7>LU:@8H
aP038@P@Q0aS00848@8@Q0056<HQ22488@PLi`0248@020aS6<HLiaS68@P]
JbU:9BT36<H248@436<01Q245:DHaQS65:D@Q0@DY@0436<8@PQ2248336<0
4a2436<Lib48?NmBU5kgLia_Ng_NMke[FV<H:DXQ20Q21248@PaS008@Q0<<
H`0324848@@Q00848@0400048@@Q1242248512400`Q212448@0Q12432482
36<00a245:DDY@025:D011S67>Le[Cg_0TYB00=6<DYBDY@00U:D0dic00=B
U5JeDY@00Tic00=:DU:DDY@00TYB14ic15:D0Tic00=BU4icDY@00UJe00=J
eUJeE[D00U:D15Je0e[F0ekg0U[F00=BU5JeDY@00UJe0U:D0U[F00=F]E:D
CW<00UJe0e:D00=>Le:DDY@00U:D1eJe00=JeUJeE[D015Je00=JeUJeDY@0
0U[F0eJe0U[F1eJe15kg00=JeUJeE[D00e[F00=F]E[FF]H00U[F0eJe00AJ
eUJeE[EF]@AJePAF]@EJeP03G_MJeU[F009F]@QJeP03E[EJeUJe009JeP=N
m`AF]@04G_MS65kgG_L2F]H015kgHaQS66<H0ekg1e[F0UJe00QBU5JeG_MN
me[FG_MJeUkg0U[F00=F]E[FF]H00ekg00=JeUkgF]H00f<H00=Nme[FG_L0
15[F00ENme[FG_MF]E[F00=Nm`9JePENm`03F]INmf<H00=Nm`08HaQW>FLi
HaQNmf<HG_MS609Nm`04F]INmekgG_L2F]H00eJeF]IJeP04E[D1G_L1E[D1
?Nl0000500048@@Q1240000312402@Q200048@aS?Nmooekg>Li>L`02E[D0
14icDYABU4YB0T8@00e6<DYBBU9:DTicBU9>LdYB@Q16<DYBDYA>L`02BU80
14icBU9:DTHa0TYB0Tic00UBU4YB@Q0mkdHaCW=:DT8@AS400TYB0d8@00M>
LeJeE[E:DT8@>Li6<@03@Q04AS401dYB?NlicSW>?Nm6<DYB0096<@04@Q16
<DYBBU82@Q000dYBCW=:DP04AS42@Q002DHaBU9:DT8@?NlicT8@?Nle[@02
>Lh00dHa@Q0mk`02>Lh2<H`01be[:DXYBRU:8@PLiaBU008<H`031248@PQ2
008<H`03248<H`aS008<H`0424848@@Q1243248236<02124248@Q12436<8
@P@Q248236<22485124236<2:DX00c6<;F/YBP02:DX00bDY7>LDY@025:D0
0a2436<@Q00248@25:D0112424848@@Q0`Q200dDYBDY7>L<HbDY?Nm_Ng>L
DYA:DSW>:DXU:@025:D736<01A245:DHaQBU48@00PaS00<@Q0aS248020Q2
0P@Q00<8@PaS36<00QBU00P@Q0aS24848@Q21248@Q240QBU0Q2400<DYA24
48@00QBU0QcW00TQ22DY;F/aS2U:9BTHaQ2436<00`Q200<<Ha2448@00a24
00H<Ha246<HLiaBU36<3248236<02PQ236<HaRU:7>LU:CW>E[EW>EJe0U[F
00DmkcF]6<HHaQ240088@P0336<HaQS6008@Q0<<H`88@P<48@@8@P<48@88
@RL48@<8@P0336<@Q1BU00<DY@039BTYBSW>00924004AS5:DU:DCW<2BU80
1DicDYABU5:DBU800U:D0Tic0U:D0dYB00=>Le:DDY@00e:D0Tic00=BU5Je
DY@00U:D0eJe0e:D0U[F0UJe0U[F0Ukg00=JeUJeE[D00UJe00=BU4icCW<0
0UJe0U[F00=F]E[FF]H00UJe25:D0UJe00=BU5JeE[D025[F00EBU5JeF]IJ
eUkg009F]@AJeP04E[EJeUJeF]H2DY@00eJeF]IJeP02F]H00eJeF]IJeP02
F]H2E[D2F]H00e:DE[EF]@03F]H01E:DE[EF]EJeG_L00U[F0UJe25[F00=F
]E[FE[D01U[F0UJe0U[F0UJe0U[F0Ukg0e[F00AF]E[FF]INm`AJeP06G_MS
66<HHaQNmf<H0U[F00=F]E[FF]H00UJe0U:D00=F]E[FG_L00U[F00=F]E[F
F]H015[F00ANme[FG_MS60=Nm`03E[ENme[F009Nm`9JePENm`9JeP04E[EN
mf<HHaP3F]H00ekgHaQNm`07G_L3HaP00ekgHaQNm`02HaP5G_L2F]H015Je
F]IJeU[F0UJe00ABU5JeF]IBU05240000`@Q00<000@Q12400P@Q00`8@P@Q
124<Hcg_OomNmcW>CW=JeU:DCW<2DY@2AS42@Q02BU82CW<01TYBCW=6<D8@
AS5:DP9BU0A:DP=6<@=>L`03DYA6<Cg_00924005BU9>LdHaAS5:DP02AS42
@Q002DYBE[EBU4ic?NlicT8@?Nm24002AS402TYBAS56<DYB@Q0icSF]>Li6
<DYB14Ha00E:DTHa?Nm6<DYB009>L`=6<@03@Q16<DHa00A6<@<mk`04>Lhe
[CW>?Nl2@Q03>Lh00cF]<H`]J`03:DX28@P248@00`aS2488@P0212400`Q2
36<<H`0236<00a242488@P021243248336<0112436<@Q0aS0PQ20`aS0`Q2
10@Q00@@Q1BU9BT]J`8aS007:DX]JbU:9BTQ21S65:D01Q240QBU00D@Q0Q2
12448@aS0088@P065:DU:B4848@U:D8@0W>L0Tic00<e[BDY7>L00QBU0Q24
00@8@PaS36<8@P8@Q0066<HLiaS648@<H`Q20`aS00D8@PaS2488@P@Q00@8
@P061248@PaS48@HaQBU0PaS0`Q200@48@aS36<DY@8@Q0<DY@8@Q0035:DQ
21cW008U:@07:DXaS2e[8@PDY@aS48@00`Q200@<Ha2448@<H`8@Q00:36<@
Q1S67>L@Q0aS1248@PaS48@224800`aS7>LYBP028@P013W>E[EW>EJe0U[F
00E2436<6<HHaQ240088@P0436<DYA245:D348@01`aS12448@001248@P@Q
00@8@P041248@PQ22484124010Q212448@001P@Q00<8@P@Q124010@Q00<8
@P@Q12403@@Q0PQ20P@Q0PaS00<@Q1BU6<H00QS600TQ22e[?NlicSg_AS5:
DTicDY@00dYB00=>Le:DDY@00Tic0U:D00M>Le:DCW=>LdHaBU9>L`03DY@0
1EJeCW=>LdicDY@00UJe00=BU5JeE[D00UJe0U:D0eJe15[F0Ukg00AJeUJe
E[EF]@EBU003F]IF]E[F00AF]@9BU09>L`ABU0=F]@03DYAF]EJe00MJePAF
]@03G_MJeU[F009F]@=JePAF]@05DYAF]EJeF]INm`03F]H01EJeF]IJeU[F
E[D00U[F0UJe00QBU5JeF]IF]E[FE[EBU5Je0e[F00=F]E[FE[D025[F00AF
]E[FF]IJeP9F]@AJeP03E[EJeU[F009F]@9JeP07G_MJeU[FF]IF]E[FE[D0
15[F00AF]EkgHaQNm`9S6005G_MS65[FF]IF]@03F]H00e:DCW=BU002F]H0
0ekgF]IJeP04F]H01EJeF]IF]EkgHaP015kg15[F15kg0U[F00QS65kgG_MJ
eUJeF]INmf<H0Ukg00=F]E[FHaP00Ukg0U[F1Ukg1V<H00EW>EkgG_MJeUkg
00IJeP03E[EJeUJe009BU05JeP5F]@52400000<000@Q00000`@Q00<000@Q
24800P@Q00H<Hcg_OomW>CW>CW<4E[D00dicBU96<@02@Q02AS401TYBCW=:
DTYBAS524096<@04BU96<DYBCW<2DY@00dicBU9:DP04CW<014YB@Q12448@
14Ha0dYB00Q243g_AS5:DTicDYA:DT8@0Sg_0dHa00Y:DTHaBU9BU4Ha@Q0i
cSF]?Nm240=:DP03@Q0mkcg_00924003AS52448@00=6<@03@Q0mkd8@0096
<@03@Q0icT8@008icP05=JdaS3F]>Li24002?Nl2>Lh02Cg_>Lh]Jbe[8@PL
iaS65:D@Q00236<324800`aS248<H`02248236<4124224800`aS48@<H`03
36<3248010aS248<H`Q20PaS0PQ200<48@Q224800PaS00<DYA246<H011S6
0Q240`aS00d@Q0aS48@@Q0aS6<H]JbU:5:D48@Q248@<H`022480312436<4
8BU:BU9_Nf<H;F/Q21cW5:DHaP8Q20045:D<H`Q2248236<224801PaS5:DH
aQS648@8@P8<H`07248<H`Q224848@Q212400`Q20P@Q00@8@PaS48@<H`88
@P848@<8@P8<H`8@Q00336<@Q12400@HaP087>L]Jc6<=JdaS2U:8@PHaP8@
Q00324848@Q20088@P8<H`03248<H`aS00@<H`<8@P8<H`0L48@<H`aS5:DH
aPaS6<HmkfLiOomJeS6<;F/HaQcW6<HLia24124<Hbe[DYA:DQcW5:DHaQ24
36<324821245248236<2248212400`Q212448@0O124010Q212448@Q20`@Q
0`aS0Q240QS600HQ22DY<H`aS3g_BU82CW<01DHaBU9BU5:DE[D00U:D1Tic
00=BU4YBBU800U:D00=JeUJeDY@00dic15:D0UJe00=BU5JeE[D00e:D00AF
]E[FG_MNm`9JeP03E[EJeUJe00IBU003CW=JeU[F009JeP05E[EBU5JeDYAF
]@05DY@01DicE[EBU5JeDY@00UJe15[F00UNme[FF]IBU5JeF]IF]E[FE[D0
15[F00AF]E[FE[EJeP=F]@AJeP03E[EJeU[F00=F]@03F]IF]E[F00=F]@=J
eP9BU09F]@03F]INmekg009JePAF]@03F]INmekg00=JeP03E[EJeU[F00=J
eP9Nm`9JeP06E[EJeUJeF]IF]E[F0Ukg0U[F00AF]E:DE[EF]@9JeP03E[EJ
eUJe009JeP=S6003G_MF]EJe00=F]@9JeP=F]@YJeP9Nm`04F]INmekgHaP2
G_L3F]H3G_L4F]H00f<HG_MNm`04F]H2HaP2G_L3F]H2G_L025[FG_MNmekg
F]INme[FG_L2HaP015kgHaQNmekg0e[F15kg1U[F00=F]E[FF]H00DHa0005
1240300012448@Q200048@aS?Nmoof<H>Li:DP9F]@05DYAF]E:DBU96<@02
@Q02AS44BU84AS42BU801THaBU9BU5:DCW=:DP9>L`9:DP09CW=:DT8@@Q0m
kdYBAS5244Ha009:DP03AS5243g_009:DP07DYA>LdHa?Nm243g_AS400TYB
0THa00U:DTicAS5243W>=Jdmkd8@AS400TYB0T8@0Sg_0T8@00=6<D8@?Nl0
0THa00=243g_?Nl00THa0d8@0Sg_00@e[C6<>LhicP8mk`8icP07=JdicSF]
<H`YBQcW8@P00QBU0`aS10Q200@<H`Q236<<H`<8@P848@050008@PQ236<@
Q00336<00`Q236<8@P02248336<324800`@Q2488@P0336<011245:DHaQcW
0QS600<DYA2448@010aS00P@Q0aS36<<HacW:DXU:ABU0P@Q00h@Q0aS2488
@Q2436<48BU:BU9_Nf<H;F/U:B480QS600DQ21cW5:D@Q0Q2008<H`88@P08
124<HaS67>LHaPaS248<H`88@P031248@PaS0088@P041248@P@Q24821242
36<01A2436<8@PQ212400`Q20`aS00<@Q0aS48@00a240QS600@Q21cW:DXa
S08e[@059BTQ21cW48@<H`04248010aS248<Ha240`aS00@8@PaS248<H`<8
@P@<H`0J48@HaPaS6<I6<F<HOomNmc6<;F/HaQcW6<HLi`aS124<Hc6<E[E6
<AcW36<DYA2436<48@@8@P041248@P@Q248336<00`Q21248@P0<124010Q2
12448@@Q0PQ21@@Q00<000@Q124010@Q00<000@Q248010@Q00@8@P@Q1244
8@88@P8<H`0448@DYABU6<H28@P01be[=Je244YBCW=:DTHa009>L`04E[EB
U4icDY@4CW<00e:DCW=>L`02CW<015:DE[EF]EJe14ic0U:D0UJe0U:D00=F
]E:DE[D00U:D0UJe0U[F00=Nme[FE[D00U[F00AF]E:DE[EF]@9BU003CW=B
U5Je009Nm`9F]@03DYAF]E:D00EBU004CW=F]E:DE[D2DY@00eJeF]IF]@03
F]H00ekgF]IF]@03E[D00e[FE[EJeP02F]H01ekgE[EJeUJeF]IF]E[F00=F
]@=JeP=F]@05F]IF]E[FE[EJeP04E[D3F]H01UJeDYABU5JeF]INm`=JePAF
]@03F]INme[F00IJeP04E[EJeUJeG_L2F]H00eJeF]IJeP02E[D2F]H2G_L0
0e[FE[EBU003E[D00e[FE[EF]@02E[D2F]H01UkgHaQNmekgE[EJeP=F]@=J
eP03DYAF]E[F00=JeP03G_MJeU[F00=JeP04G_MJeUkgF]H3G_L3F]H4G_L0
1E[FE[EJeU[FG_L00V<H00ANme[FF]IJeP9S6004G_MJeUJeF]H4G_L2F]H2
G_L015[FG_MNmf<H0Ukg00=S65kgF]H00U[F0ekg00=JeUkgF]H015[F0UJe
0Ekg0EJe0DHa00001@00124000@Q00000`@Q00X8@P@Q000<Hd8@OomW>CF]
@Q1BU09F]@06DYA>LdicCW=6<DYB0T8@0THa00=>LdYBAS400dHa00E:DT8@
AS56<Dic009BU003CW=:DTYB009>L`03BU9243g_00A24096<@08CW=:DTic
@Q16<D8@?Nm2409>L`05AS4mkcg_@Q1:DP02AS401T8@BU9>LdicBU8mk`8i
cP04?Nm6<DYBAS42?Nl01T8@BU9:DT8@?Nm240=6<@8mk`92400;AS4mkcW>
>Lhmkd8@?NlicS6<=Jdmk`03@Q001CW>BU9JeTYB>Lh00Q2400<<H`Q236<0
0Q2400<<H`Q212401@Q20PaS00<48@Q212400PQ20PaS0Q2400L<H`Q22488
@PaS248<H`02248236<0112436<<H`Q20P@Q0PaS00@@Q0aS36<<H`@@Q0@<
H`0348@<H`aS008@Q0067>L]JbDY5:D8@PaS0QcW00<<H`@Q24800PaS00DH
aR488@PQ21BU008HaP045:DHaQ2448@336<00`Q236<@Q00248@00`aS2488
@P0436<424801`@Q24848@Q21248@P@Q0088@P031248@PQ200<8@P848@<8
@P8<H`09248<H`@Q124@Q1BU8@PHaQBU008Li`066<HQ22DY:DXQ21BU0PaS
00<8@P@Q12401@Q20PaS00<8@PaS24800`Q200/48A246<HHaQ241248@QBU
36<DYBe[008mk`0@9BTHaQcW7>LDYAS67>LDY@Q248@Q23F]<H`Lia246<H2
36<224800a2436<<H`03248010@Q2488@PaS0PQ20`@Q00<8@P@Q12400`@Q
00H8@P@Q124000@Q248512400`Q212448@0212400`0012448@0512400`00
12448@0312400`Q212448@02124040Q236<HaQS67>LHaQBU48@LibDY=Je:
DTHaDYA>LdYB0Tic00ABU5JeCW=:DP9>L`07DYA>Le:DDYA>Le:DCW<00U:D
0dic00ABU4icCW=>L`9BU004E[EBU5:DDY@2E[D2DY@015[FG_MJeUJe0U[F
00=F]E[FDY@00U:D0eJe0Tic00UBU5JeF]INmeJeDYAF]E:DCW<00U:D0eJe
0U:D00IF]E[FF]IJeUJeF]H3G_L3F]H00eJeF]IF]@05F]H3E[D00e[FE[EJ
eP02F]H015JeF]IF]E[F0eJe0e[F00=F]E[FE[D00eJe00=JeUJeE[D015Je
00AJeUJeF]IF]@9JeP04E[EBU5JeE[D3F]H01EkgHaQJeU[FE[D015[F0UJe
00MJeUkgG_MJeUJeF]IF]@02F]H025kgF]IJeUJeF]INmeJeDY@2E[D00e[F
E[EBU002E[D2F]H015JeF]IJeUkg0U[F00IF]E[FF]INme[FE[D2F]H01Ukg
F]IJeU[FE[ENm`IJePINm`9JeP03HaQNme[F009JeP03G_MS65kg009JeP9F
]@04F]INmekgG_L2F]H3G_L016<HG_MNmekg0e[F0f<H0Ukg00=S65kgF]H0
0e[F0Ukg1F<H00=NmeJeE[D00U[F0DHa000812402@Q212448@aS@Q1oofLi
=Je6<@04E[D00dicBU9:DP02AS42@Q0014HaBU9:DTYB1DHa0T8@00E:DTic
DYABU4ic009:DP03CW=:DTHa00=24004?Nm2448@@Q02BU8044icBU9244Ha
@Q0mkdHaBU9>Ld8@?NlicTHaBU96<D8@0TYB0Tic00Q6<D8@=JdicT8@AS5:
DT8@0Sg_00A244YBAS52408mk`96<@04@Q0icSW>?Nl2AS40148@>LhicSW>
0Sg_010icSF]<H`icSg_AS5243W>BU9JeTHa>Lh@Q1BU36<8@P8<H`0348@<
H`Q200@8@P8<H`<8@P041248@PQ2248336<00a2436<8@P0324801@@Q248<
Ha2424800PaS00<@Q0aS24800P@Q00@8@PaS48@@Q08<H`0348@<H`aS00P<
H`8@Q00?7>L]JbU:5:D8@Q248@PLi`aS1248@PaS248HaR48008U:@<DY@03
6<HDYABU00X<H`03248<H`Q200@<H`L8@P848@0324848@Q20088@P0536<8
@P@Q24848@0224800`@Q36<<H`0236<324800`aS5:DHaP036<H01acW8@PQ
22U:9BTLiaBU008<H`0324848@Q200D8@P<<H`D8@P0?124@Q1S66<H@Q0@Q
36<DY@Q25:DaS48@?NlU:ABU008Li`8HaP057>LDY@aS48@Q2002=Jd00acW
5:D@Q00336<3248236<00`Q2124<H`0336<01@Q212448@@Q24802@@Q00@8
@P@Q1248@Q/48@04248<H`aS5:D26<H021cW5:D@Q1cW8@PicTHaBU82CW<0
24YBCW=BU5:DCW=BU4icBU82CW<02e:DCW=BU5:DCW=BU5JeDYA>LdYBDY@0
14ic00=BU5JeDY@00U:D00=F]E[FDY@00U:D0e[F00=F]E[FF]H00U[F0e:D
0eJe0Tic00MBU5JeG_MJeUJeDYAF]@05DY@00eJeDYABU002E[D3F]H00eJe
F]IJeP02G_L01E[FE[EJeU[FE[D00U[F00=F]E[FF]H00U[F0eJe0U[F00EF
]E[FF]IF]E[F00AF]@EJePEF]@9JeP9F]@04DYAJeUJeE[D4F]H2E[D01E:D
F]IJeUJeF]H00Ukg0e[F00AF]E[FF]IJeP9F]@9JeP03G_MJeU[F009F]@9J
eP05G_MJeU[FE[EJeP02E[D00e:DE[EJeP04E[D2F]H01EJeF]IJeU[FG_L0
1U[F00=F]E[FF]H00U[F00UNme[FF]IJeUJeF]INme[FE[D00U[F15kg00=J
eUkgG_L00ekg0e[F00ENme[FG_MNme[F009F]@04F]INmekgG_L3F]H00ekg
HaQNm`03G_L01E[FE[EJeUkgIcT01Ekg0e[F00=Nme[FG_L00f<H00=Nmf<H
G_L00UJe0Ekg0E[F0D8@00001`00124000@Q00048@000088@P0900048@aS
@Q1oof<H=Je:DTic009BU09>L`04DYAF]DicBU84AS4014YBCW=>LdYB0THa
00I:DTHaAS5244HaBU83DY@014YBCW=:DTYB14Ha0d8@0dYB0THa00M243g_
>Lhmkd8@CW=6<@02@Q02BU83AS401DicBU9:DTic@Q000cW>0T8@0Sg_0dHa
00=243g_?Nl00T8@00TmkcW>?Nm6<D8@?Nle[CW>@Q000cg_00TicSg_?Nle
[C6<>LhmkcF];F/00S6<00<]Jb4836<00PQ20P@Q0PQ200@48@Q21248@P84
8@07248<H`aS24848@aS48@00QBU00H@Q0aS36<<Ha2436<248@00`aS248<
H`0248@01@aS1248@PaS48@00PaS0`Q20PaS0a240QBU00<@Q0aS36<00`aS
00X8@PaS5:DDYBDY;F/Q21S624848@88@P0436<8@PQ2248236<248@35:D0
0`aS48@DY@0236<00`Q248@@Q00536<224800`aS2488@P0236<3248010@Q
2488@PQ20PaS0PQ20P@Q1@Q200@48@Q21248@P<<H`88@P0436<@Q1245:D3
48@011BU48@DYABU0QS60QBU00@@Q0Q22488@P8<H`0324848@@Q0088@P@<
H`0424848@@Q248236<2248436<248@45:D01A245:DDYABU48@00PaS00T8
@QBU7>LQ21cW5:D<Ha2424800`aS00L8@PaS248<H`Q236<8@P0336<42487
124224821242248;12400`0012448@0712400`0012448@07124010aS48@H
aQBU0Q2400HHaQcW<H`mkdHaCW<3BU8024icDYA>LdicDYA>Le:DCW<3DY@3
CW<01DYBCW=>LdicDY@00Tic00EBU4icDYABU5Je009BU008E[EJeUJeDYA>
LeJeF]IBU09F]@9JeP03E[EBU5Je009BU09F]@05DYA>LdicDYAJeP02E[D0
25[FE[EBU4icDYAJeUkgF]H2E[D01E:DF]IJeU[FE[D00e[F00ANme[FF]IF
]@=JeP9F]@04G_MJeU[FF]H2E[D00e[FE[EJeP03E[D00ekgF]IJeP03E[D0
0e:DE[ENm`02G_L01E[FDYAJeUJeF]H015Je00=JeUJeE[D00U[F00EF]E[F
E[EF]E[F00=F]@=JeP=Nm`AJePAF]@9JeP04G_MJeUkgG_L3E[D02U[FG_MN
mekgF]IF]E:DF]IF]Ekg1EJe0U[F00AF]E[FF]IJeP9F]@05F]INmf<HF]IF
]@02F]H2G_L4F]H2G_L015[FG_MNmekg15[F0Ukg00=JeUkgG_L015kg00MJ
eUkgHaQS65[FG_MF]@03F]H3G_L3F]H00ekgHaQNm`02G_L015[FG_MNmekg
0V<H00ANmf<HHaQS60=Nm`9S6007IcUS66<HHaQNmf<HF]H00UJe0Ekg0E[F
0DHa000812402@Q212448@aS@Q1oofLi>Li6<@02DY@2CW<01DYBDYABU5:D
BU800T8@0THa0dic00a:DTHa@Q1:DTHaBU9244HaBU9BU5JeCW<4BU83AS43
@Q003dHaBU9:DTYBAS4mkd8@?NlicSg_AS5:DTHa?Nm24002BU82AS401T8@
BU9>LdicBU9240<icP9240<mk`07AS5:DT8@?NlicT8@AS400SW>00<mkd8@
@Q000cg_00PicSg_?NlmkcW>@Q0icS6<0SF]00U243F];F/aS3W>;F/Q20aS
24801@@Q00@8@P@Q2488@P848@03248<H`aS00<8@P0448@DYABU48@236<0
0`Q236<@Q00236<224801PaS48@DY@aS24848@88@P8<H`<8@P0336<@Q124
008<H`0348@DYA2400@<H`0;48@<H`Q248@DYBU:;F/Q21BU36<8@P0236<3
248236<01a2436<@Q1245:D@Q1BU008@Q08<H`0348@<Ha24008<H`05248<
H`aS36<8@P021242248010aS24848@@Q0PQ200<48@Q224801PQ200<48@Q2
24800PQ20P@Q0PQ21PaS0Q2400<DYA245:D01ABU00@HaQBU5:D@Q0<8@P05
36<8@PQ224848@0536<02`Q236<48@@Q248<Ha2436<8@PaS48@00`aS00@@
Q1BU6<HHaP@DY@036<H@Q0aS0088@P056<HLiacW7>LHaP0248@00`aS248<
H`0336<224800`aS2488@P0424831242248010@Q00048@@Q0PQ200<48@Q2
12400`@Q00<8@P@Q12402P@Q00<000@Q12400P@Q00<000@Q12402@@Q00/<
Ha245:DHaQBU48@DYB48<Ha244Ha00A:DP9>L`9BU09>L`03DYA>Le:D00=B
U003CW=:DTic00A>L`04DYA>LdYBCW<5DY@00eJeF]IF]@03DY@01EJeDYAF
]EJeF]H00UJe00=BU5JeE[D00eJe00EBU4icDYABU5Je009JeP9F]@9BU09F
]@9JePAF]@=JeP05E[EJeUkgG_MJeP02E[D01U[FG_MF]EJeF]IF]@9JeP04
E[EJeUJeF]H3E[D00e:DF]IJeP02F]H5E[D015[FG_MJeU[F0eJe00=JeUJe
E[D00UJe00=JeUJeE[D00UJe00MJeUJeE[EJeUJeF]IF]@02F]H00eJeF]IN
m`02G_L01E[FE[EJeUJeF]H015Je0U[F0Ukg00=JeUJeE[D00U[F0Ukg00=J
eUkgE[D00UJe15[F00MBU5JeE[EF]E[FE[EJeP02G_L00e[FE[EJeP02G_L2
F]H01UJeF]INme[FG_MF]@=JeP9Nm`9JeP9Nm`03E[EJeUkg009Nm`9JeP9N
m`06HaQJeUkgF]INmf<H0Ukg00EJeUJeF]IF]E[F009Nm`=JePINm`=JeP9N
m`AS60=Nm`QS6006G_MF]EJeE[ENme[F0D8@00001@00124000@Q00000`@Q
00d8@P@Q000<Hcg_Oom[FSg_BU9>LdYBDYA:DP02DY@015JeDYA>Ld8@0dHa
00U>Le:DBU9:DT8@BU9>LdYBAS400Sg_00A:DTicDYABU0A:DPE6<@03BU96
<DYB00=6<@06@Q16<D8@>Li244Ha0TYB00=6<D8@AS400dHa00M:DTHaAS56
<E:DCW=24002>Lh014Ha@Q0mkcW>0cg_1D8@0Sg_00I6<DYB@Q0mkcF]>Lh2
@Q0023g_=Jde[CF]?Nm:DT8@?Nl2;F/01BU:9BTLia245:D010@Q00<8@P@Q
124010@Q00l8@P@Q24848@Q2124@Q1BU9BTYBQcW5:D@Q0Q236<00Q240QS6
00<@Q0Q236<00QS600D@Q0Q21248@Q24008DY@0948@8@PQ236<8@PaS48@D
YA24008<H`0448@<H`aS248236<01`Q248@@Q1S67>LDY@aS0088@P0?36<8
@PQ224848@aS48@<H`@Q36<HaQcW5:D8@PaS008@Q00536<@Q1S65:D@Q003
24800`@Q2488@P03248236<00`Q212448@03248236<01AS67>LLiaBU36<0
0P@Q0`Q20P@Q10Q200<<Ha2448@00QBU00H@Q0aS36<@Q0aS48@35:D236<0
112436<<Ha2410aS1@Q200H@Q1S66<HDY@Q21242248010@Q2488@PaS0PQ2
0Q240PQ200HHaRU:9BTDY@Q248@336<00`Q248@<H`045:D248@010aS248<
Ha240PaS0`Q20PaS00@@Q0aS36<8@P@<H`0424848@@Q1243248010@Q2488
@PQ210@Q00<8@P@Q124010@Q00<000@Q12404`@Q00@8@P@Q248<H`8@Q006
5:D@Q1cW:DXe[DHa0TYB00E>LdYBBU9:DU:D009F]@03CW=BU4ic009BU003
CW=BU4YB00=>L`03DYAF]Dic00=BU004E[E>Le:DDY@2E[D2DY@00eJeCW=B
U003DY@3F]H3E[D02E:DE[EBU5JeF]IF]E:DE[EBU002E[D2F]H2DY@2E[D2
G_L4F]H01EJeF]IJeU[FE[D00U[F0eJe0e[F00AF]EkgHaQNm`=F]@=JeP07
E[EBU5JeF]INme[FG_L00UJe00MJeU:DE[EJeV<HG_MF]@02DY@3F]H2DY@0
1E[FG_MJeUJeDY@00e[F0UJe15[F00EBU5JeF]INmf<H009Nm`03F]INme[F
00=F]@=JeP06G_MJeU[FF]IF]E:D0U[F00AS66LiG_MJeP=F]@IJeP03E[EJ
eUJe009F]@=JeP03E[EJeU[F009Nm`05F]INmekgG_MS6003G_L015[FG_MJ
eU[F0ekg00=F]E[FE[D00Ukg00IS65kgG_MJeUkgHaP2G_L3HaP3G_L2F]H5
G_L2F]H015kgHaQS66<H0e[F0Ukg00AJeUkgG_MNm`=S609Nm`03F]INmekg
00=S6008IcUS65kgG_MF]E[FG_MF]@5240001@@Q00@000@Q1248@P848@05
36<mkgooIcTmk`02BU84CW<015JeDYABU4ic14Ha0dic00]:DTHaBU9>LdYB
AS4mkd8@BU9>Le:D009>L`A:DP03AS5:DT8@0096<@9:DP96<@07BU92448@
?NlicSg_AS400TYB0T8@0THa00A244HaBU9:DP96<@03DYA:DT8@008e[@92
4003?NlicSg_00924003?Nm243g_0092408mk`03@Q1:DTHa008icP03?Nm2
448@008icP8e[@0>@Q16<D8@=Jd]JbDY:DXU:AcW5:D@Q0Q2124000T48@0=
24848@Q224848A246<HQ22DY7>LDYA2424800`aS00<DYAS648@00PaS00/D
YAcW48@8@P@Q36<@Q1BU48@<H`@Q00<8@P<@Q0<<H`0348@<H`aS008<H`88
@P0436<DYAcW7>L248@324800`aS2488@P0224802PaS2488@PaS6<HLiaS6
248<Ha240PaS0aBU00<@Q0Q224800PaS1@Q20PaS0PQ200@48@Q236<8@P8<
H`086<HQ21S648@<H`@Q24848@88@P031248@P@Q0088@P0536<8@PaS36<D
Y@0348@011BU48@<Ha240aBU10aS00`@Q0aS48@@Q0aS1248@P@Q248<H`Q2
36<35:D00`aS12448@03248010aS2488@PaS0Q240PQ200DHaRDY9BT@Q0aS
00<@Q0@<H`<DY@066<HDY@aS36<8@PaS0Q2400D<H`Q21248@PaS008@Q08<
H`88@P8<H`88@P848@0524848@@Q24848@0236<01@Q200048@@Q24802P@Q
00<000@Q248010@Q00<000@Q12402P@Q00<8@PaS36<0112400DLibU:=Je:
DTHa00A:DP03CW=BU5Je009BU0=>L`9BU09>L`03BU9>Le:D00IBU006E[EB
U5:DCW=BU5Je25:D0e[F15Je0U:D0eJe0e:D00=F]E[FE[D00UJe00=BU5Je
F]H00Ukg0e[F00AF]E[FF]IF]@=JeP04E[EJeU:DF]H2G_L00eJeF]INm`02
G_L00e[FE[EJeP02F]H4E[D015[FG_MNme[F0eJe0U:D0ekg00=F]E:DE[D0
0U[F0eJe0U[F0UJe00ABU5[FF]IJeP=F]@=JeP9BU004F]INmekgHaP2G_L0
1E[FE[EJeU:DE[D01E[F00INme[FE[EJeUJeF]H2HaP015kgF]IF]E:D0U[F
00=F]E[FF]H015[F0eJe00ENme[FF]IJeUJe009Nm`04HaQNme[FF]H3G_L4
F]H00ekgF]INm`02G_L01E[FE[EF]E[FHaP00Ukg00=JeUkgG_L00ekg16<H
1E[F15kg00EJeUkgG_MNmf<H009Nm`9JeP03G_MJeU[F009Nm`9S6004G_MS
65kgF]H3G_L3HaP00fLiG_MS6004F]H1E[D1@Q00000300048@0000D48@0;
248000@Q36<mkgooKg]244icDYA:DP03CW<2DY@00eJeDYA>L`02AS43CW<5
BU82AS401Cg_>LhicT8@CW<00TYB00A>LdHaAS56<@=:DP96<@03BU9244Ha
008mk`04AS5:DTYBBU82@Q02AS40148@?Nm244Ha0Tic00A:DT8@@Q16<@9B
U004AS4icSF]>Lh2AS40148@>LhicT8@0THa00A243W>?Nlmk`96<@03@Q0m
kd8@00924096<@09>Lhe[CF]<Ha244icBU8mkbe[008Li`046<HDY@aS2486
12400`0012448@04124010Q21248@PQ20Q2400DDYAS65:DHaQ24008<H`8@
Q0077>LQ21S648@8@PaS5:D00QS60Q2400@DYAS65:D<H`88@P<<H`0348@<
H`aS00<<H`@8@P0436<8@PaS248:36<2248236<00`Q248@DY@037>L25:D0
1AcW9BTLiaBU24800PaS30Q20P@Q00d8@PaS8@PLibDY?NlaS1cW24848@Q2
36<48@0224821242248236<010Q248@@Q1240`aS0Q240QBU0Q240`Q200P4
8@Q236<<HaS67>LDY@aS10Q200<<Ha245:D00PaS0PQ200@48@Q224848@@8
@P0436<8@PaS48@26<H02ABU48@<Ha245:DHaQ2436<@Q00436<448@020Q2
48@HaQ2436<8@PaS6<H248@00`aS48@@Q00248@336<01`Q212448@Q236<8
@PaS00D8@P848@0324848@@Q00/48@0324848@@Q00848@0300048@@Q00T4
8@88@P8<H`085:DHaQS65:DHaRU:?NmBU0A:DP04CW=BU5:DBU82CW<2DY@0
0dicDYABU002DY@2CW<2DY@015JeDYABU4ic0e:D00=>Le:DDY@00e:D0dic
1UJe00=JeUJeE[D00UJe0U[F0eJe00=BU5JeE[D00eJe00=BU5JeG_L00U[F
00=NmeJeF]H00UJe00=JeUJeE[D00eJe00=NmeJeE[D00UJe00IJeUkgF]IJ
eUJeF]H2G_L2E[D2F]H2E[D2F]H01EkgE[EBU5JeDY@01E[F0eJe0e[F00=F
]E:DE[D00UJe00=JeUJeF]H01UJe00EBU5JeDYAF]E[F009Nm`9JeP06G_MJ
eU:DDYAF]E[F0UJe00AJeUkgG_MJeP9F]@03F]IF]E[F009JeP05G_MJeU[F
E[EBU002F]H00ekgF]IJeP02DY@00eJeF]IJeP02E[D2F]H6G_L2F]H01ekg
HaQS65kgF]IF]E[F009Nm`03F]INmeJe00AJeP03HaQNmekg009JePANm`=S
609Nm`EJeP=Nm`9JeP03G_MS65kg009Nm`=JeP03E[ENmekg00ANm`9S609N
m`03HaQNmf<H00ENm`04F]INmf<HG_L1AS4000D48@0400048@@Q24821240
1`aS?Nmoof]J?Nm>Le:D009:DP03CW=BU5:D00=BU006BU96<DHaBU9BU4ic
0TYB00E6<DYBAS56<D8@008icP05@Q16<DicBU96<@03BU800dHaBU9:DP03
AS401TYBAS56<Cg_>Li6<@9:DP04AS4mkdHaBU82AS403cg_@Q16<DicBU96
<D8@?Nm:DU:DCW=6<CW><H`mk`03@Q02>Lh00cg_AS524002?Nl00cW>@Q12
4002AS401d8@?Nlmkd8@AS5243W>00<e[@06@Q1>LdYB?NlYBQcW0QS600@D
Y@Q2248000/48@0524848@@Q248<H`0248@01ABU6<HLiaBU48@00PaS00P@
Q1BU7>LQ21BU36<8@PaS0aS60Q240QBU00H@Q0aS2488@PaS248236<248@2
36<2248010aS2488@PQ20PaS00<8@PaS24800`aS00@8@PaS36<@Q08<H`88
@P0736<8@Q2448@HaR487>L00QBU00@Lib487>LDY@P8@P031248@PQ200<<
H`0=24848@@Q36<@Q2487>LU:CW>=JdLi`Q200001PQ20P@Q00<8@PaS2480
0PaS00<DY@aS36<00PaS00HDYA245:DDYA2436<624802A246<HHaQ2436<4
8@Q248@8@P0448@424800`@Q2488@P03248236<00`Q236<@Q0035:D248@0
0aBU48@@Q00448@336<00a245:D@Q00236<00a245:D@Q00224800a246<HD
Y@0236<448@336<824800`aS2488@P0324821242248>12400`0012448@02
12400`0012448@0512401@Q2124<H`aS5:D00QS600@DYAS6;F/icP9>L`06
BU96<DYBDYAF]E:D0TYB00EBU4icCW=BU4ic009BU09>L`03DYA>Le:D00=B
U003CW=BU5:D00MBU09>L`03DYAF]EJe00=F]@03F]IF]E[F009F]@03F]IF
]E[F00EF]@9JeP9F]@03DYAJeU[F009Nm`=JePEF]@03DYAF]E[F009JeP03
E[EBU5Je00QJeP04E[EJeU[FF]H2E[D4F]H015JeDYABU5Je0e[F15Je0U[F
0UJe00=BU5JeE[D015[F0eJe00=BU5JeE[D00UJe00=BU5JeF]H00Ukg0e[F
0UJe00IBU5[FF]IBU5JeF]H2G_L015[FE[EF]EJe15[F00=NmeJeE[D00eJe
00ENme[FF]IJeU:D00AF]@9JeP03E[ENme[F00INm`03F]INmf<H009Nm`03
E[EJeU[F009JeP06G_MJeU[FF]IF]E[F0Ukg00AS65kgF]IJePANm`9S6003
G_MS65kg009JeP06E[EJeU[FF]INme[F15kg00=S65kgG_L01E[F0Ukg00ES
65kgG_MNmf<H00ANm`03HaQNmf<H00=Nm`04F]INmfLiF]H1AS4000040004
8@@Q0004124020Q2124000aS>LioofLi@Q02DY@01DicBU96<DicE[D00e:D
0dYB00E>Le:DE[E>LdYB0096<@03@Q16<D8@00<icP06@Q16<DHa@Q1:DT8@
0Sg_00=244YBBU800THa0TYB00E6<Cg_?Nm244Ha009BU007CW=6<D8@?Nm2
43g_>Lh00TYB00ABU4YB?Nlmk`96<@03BU96<Cg_00<e[@04?Nm6<D8@AS47
@Q000dHa@Q16<@02AS401Sg_>LhicT8@>Lhe[@8aS007>Li243F]<H`Q21BU
48@00PaS4@@Q0PQ200<<H`Q224800PaS00<@Q0aS24800PQ200@<Ha2448@<
H`88@P0536<@Q0aS36<@Q00336<01a245:DHaQcW5:DHaQ2400L<H`@8@P06
1248@P@Q248<Ha240PaS00<8@PaS36<01PaS0Q240QBU0Q240PaS00@Q22U:
<H`U:@8<H`0424848@aS36<324801P@Q2488@PaS248<H`@8@P0636<DYAcW
6<HDY@aS0`Q20PaS00@8@P@Q1248@P<<H`<8@P8<H`06248@Q1BU5:D@Q0Q2
0PaS00<8@PaS24801@Q20Q240QBU00<@Q0Q224800a240PQ200<<H`Q22480
0PQ200<48@Q224800`Q200H<H`Q236<DYAcW:DX29BT01R485:DDYA245:D@
Q08<H`<8@PD<H`8@Q00836<8@Q248@PU:B4848@8@P<<H`0448@<H`aS36<2
248336<00`Q236<<H`025:D01PaS2488@PQ21248@P848@0324848@@Q01D4
8@0300048@@Q00848@88@P0348@HaQS600<HaP068@PicT8@DYA>LdYB0dic
0e:D00=>LdYBBU8015:D00=>LdYBDY@00e:D0dic0U:D00=F]E:DE[D00U:D
00A>Le:DDYA>L`=BU003E[EBU5Je00AJeP=F]@07F]IF]EJeDYAF]E:DF]H0
0eJe00=BU5JeF]H00U[F0eJe00AJeUJeE[EJeP9F]@03F]IF]EJe00=F]@03
G_MJeU[F00AJeP03E[EJeUJe009F]@IJeP=F]@9JeP04E[EJeUkgF]H3E[D2
F]H3DY@01UJeF]IJeU[FDYAF]@9BU004E[EBU5JeF]H4E[D2F]H00f<HG_MJ
eP02E[D2F]H2E[D00e:DF]IJeP02F]H4E[D01E[FG_MJeUkgF]H015Je00AJ
eUkgF]IF]@9BU0=F]@03F]INmf<H009Nm`9JeP=Nm`9F]@06G_MS66<HG_MJ
eUJe1U[F00=Nme[FE[D00U[F0Ukg0e[F0ekg00=JeUkgHaP00Ukg0e[F00EF
]E[FF]IJeUkg00=JeP03G_MJeUkg00=Nm`04E[EJeU[FG_L3HaP00ekgHaQJ
eP04G_L2HaP00ekgHaQNm`02HaP00ekgHaQNm`01BU800003124000@Q00<4
8@0300048@Q200848@0536<icWooIcTmk`02DY@3BU84DY@01DicBU96<DYB
CW<00U:D00=>LdYBAS400d8@00I6<CW>>LhicT8@BU83AS40148@?Nm244Ha
0dYB0THa00Y244Ha?NlicT8@AS5>Le:DCW=:DP924004AS4mkcg_AS43CW<3
@Q001DHaBU96<Cg_<H`00SF]00<mkdHaAS400d8@00<mkdHa@Q000d8@00U6
<D8@AS56<D8@?NlicSg_>Lh00S6<00de[Cg_>LhaS2e[9BTHaQ24248<H`Q2
1240000212401@Q212448@@Q000010@Q0PQ200<48@Q224800`Q200@<Ha24
48@<H`@8@P0336<@Q0aS0088@P0336<DYA24008<H`0348@<H`aS008DY@04
7>LHaQ2448@736<324800`@Q2488@P03248836<00a2436<<H`0248@00`aS
48@DY@025:D01a2436<<Hb48:DX]JacW008<H`D8@P031248@P@Q00<8@P03
36<8@PQ200<8@P0548@DYAS66<H@Q00236<:248536<2248011245:D@Q124
0PQ20PaS00@8@PaS24848@88@P0536<@Q1BU5:DHaP02248236<00aBU48@<
H`0524801@@Q2488@PQ212400PQ200D<H`Q236<@Q1cW008YBP8U:@8DY@@@
Q088@P0436<8@PaS36<248@236<248@01@aS5:DLibDY7>L00PaS0Q240`aS
0`Q200@<Ha2436<8@P8<H`@@Q00536<8@P@Q24848@02248B12400`001244
8@081242248011245:DHaQBU0QS600<YBSg_@Q000Tic0dYB0e:D0Tic00=:
DTicCW<00U:D00=>LdYBCW<015:D0dic0e:D00AF]E:DDYABU0=>L`EBU09F
]@=JePEF]@04F]IF]EJeDY@2E[D015:DE[EBU5:D15[F15Je00YJeUJeF]IF
]E[FE[EJeUJeDYAF]@=JeP9F]@=JeP04E[EJeUJeE[D6F]H4E[D2F]H01eJe
F]INme[FE[EBU5Je009JeP04E[EBU5JeDY@3F]H00eJeDYABU003DY@6E[D0
1U[FHaQNmekgF]IF]@=JeP04E[EBU5JeE[D2G_L4E[D3F]H2G_L015[FE[EF
]EJe15[F00=F]E:DDY@00U:D0U[F00=Nmf<HHaP00e[F0Ukg0U[F00EF]E[F
G_MS65kg009F]@QJeP04E[EJeU[FG_L6F]H2G_L2HaP2G_L3E[D3F]H00ekg
F]IJeP04F]H00ekgHaQJeP02F]H015JeG_MNmekg0f<H00ENme[FG_MJeUkg
009S6003G_MS65kg009S609Nm`5S605JeP56<@000P@Q00<000@Q00000`@Q
00/8@P00124<HcW>OomNmcg_CW=BU4ic0096<@05BU9>Le:DDYA>L`02BU80
0dicBU9:DP02CW<2BU8024HaBU96<D8@>Lhe[CW>?Nl3AS401T8@>LhicSW>
@Q16<@8mk`06AS5>Le:DCW=243g_0T8@0e:D00A>LdHa@Q16<@=2400:AS5>
LdicBU9>Ld8@AS5243g_@Q02?Nl013W>=JdmkdHa0Tic00=:DTicAS400d8@
0THa00A:DTicBU8mk`8icP04?NlicSF];F/3<H`00bU:7>LHaP0236<2248=
12400`Q21248@P02124010Q236<8@PaS0`Q200<<H`Q224800`Q200<<H`Q2
36<010Q2014<Ha245:DDYAS65:DHaSW>@Q1W>G>L>LhQ20Q2124@Q0aS00D8
@P848@88@P<<H`<@Q0`<H`<8@P0736<@Q1247>LQ21BU48@01PQ200<48@Q2
12400PQ200@<H`Q224848@88@P8<H`03248<H`aS00<8@PD<H`<8@P<<H`06
24848@Q236<8@Q240QBU00<<H`Q224801PaS1@Q200H@Q1BU5:D<H`Q236<2
48@4248236<00`Q212448@0224801@@Q248<H`aS48@00QS600@LiaS648@@
Q08<H`066<HLibU:9BTHaPaS0PQ200D<H`Q22488@PaS00<8@P0336<DYABU
00<@Q0<8@P0336<8@PQ200H8@P0:36<8@Q248@P]Je[FG_M242e[12422480
0`@Q24848@08124010Q212448@002P@Q00<000@Q12401@@Q00/8@Q246<HL
iaS648@DYB48;F]:DTic009:DP03AS5:DU:D009BU005BU9>LdYBCW=BU002
CW<3DY@00dicDYA>L`02DY@01dYBCW=BU5JeF]IF]E:D009>L`9BU005CW=B
U4icCW=BU005E[D00e[FE[EJeP03F]H2DY@00eJeDYAF]@05DY@3E[D00e:D
E[EJeP02F]H4E[D00e[FE[EF]@02G_L00e[FE[EJeP03F]H2E[D01E[FE[EJ
eU[FE[D00U[F00ANme[FF]IJeP9F]@=BU005E[EJeUkgF]IF]@02DY@2F]H0
0eJeDYABU002E[D02E[FE[EF]E:DE[EJeUJeDYAF]@02F]H2E[D01e:DE[EN
mf<HG_MJeUJe00=JeP03DYAJeU[F00=F]@06F]IF]EJeE[EBU5[F0ekg00=F
]E[FE[D015Je0U[F00ABU5JeDYABU09JeP9S609Nm`03F]INmf<H009JeP9F
]@=JeP05HaQJeUkgF]IF]@08F]H00ekgF]INm`02F]H3G_L3F]H3G_L01EJe
F]IJeU[FG_L00e[F00=NmeJeF]H00U[F00=S65kgG_L01U[F00ANmf<HG_MN
m`9JeP03HaQNmf<H00QS605W>@5Nm`56<@0000<000@Q12400P@Q00@000@Q
1248@P848@05248icW_NG_Lmk`02DY@00dYB@Q16<@05CW<01TYBCW=:DTic
DYA>L`9:DP05AS5:DTYBAS524002>Lh2?Nl014HaBU9244Ha0SW>0Sg_00U6
<D8@?Nm6<DicDYA>Ld8@?Nl00T8@00ABU5JeCW=:DP924007BU9243g_@Q16
<E:DCW<00TYB0THa0d8@0SW>00@aS3W>@Q12409>L`03BU9>LdHa00=24003
AS5:DTYB009:DP06AS4icSW>?Nle[C6<0Re[0SF]00<YBR485:D00PaS00<8
@P@Q12403P@Q00<8@P@Q24800P@Q00@8@PaS36<<H`88@P031248@PQ2008<
H`<8@P0636<8@PQ2248<Ha240QBU0QS600LDYCW>AS5W>Fmk=JdQ20021242
36<324800`@Q24848@03248236<248@336<00`Q236<<H`0736<224801@aS
248@Q1245:D00QcW00D@Q0aS1248@PaS0088@P031248@P@Q00D8@P071248
@PQ2248<H`Q236<010Q210aS30Q200<<Ha2448@00Q240PQ21`aS10Q200LD
YAS648@<H`@Q248DY@0236<2248236<2248010@Q2488@P@Q0PQ200L<H`Q2
5:DDYAS67>LHaP025:D01a2436<DYB489BTYBQBU008<H`03248<H`aS0088
@P0336<8@PQ2008<H`0648@DYA2448@<H`Q20`aS0`Q200<48@Q224800PQ2
00D<H`Q25:DU:CF]009JeP04?NlYBPQ2248212400`Q212448@0412400`00
1240000512400`0012448@0<124010Q21248@Q240aS600DDYAS69BTYBTHa
00=:DP04@Q1:DU:DDY@3CW<00dYBDYA>L`03CW<3DY@3CW<015:DCW=>Le:D
0eJe00=>Le:DDY@00U:D00=F]DicCW<00Tic15Je00=JeUJeF]H00U[F15Je
0U:D00EF]E:DDYA>Le:D00=F]@03DYAF]EJe009JePAF]@9JeP03E[EJeUkg
00=JeP07E[ENme[FF]IF]E[FE[D00U[F00MF]E[FF]INme[FE[ENm`02E[D0
3e:DCW=F]E:DE[EJeUkgF]IF]DicDYAJeUJeF]IF]@02DY@3F]H4E[D3DY@3
F]H2DY@015[FG_MNmekg15[F0eJe00AJeU:DE[EF]@9JeP04E[EBU5JeE[D2
G_L2F]H01EJeF]IF]EJeDY@00eJe15:D0U[F0V<H00=Nme[FF]H00ekg00=J
eUJeE[D00U[F0ekg25[F00=F]E[FF]H025[F00=F]E[FF]H035[F00=F]E[F
F]H00Ukg00=S65kgF]H01E[F0V<H00=Nme[FF]H00Ukg1F<H00=Nmf<HHaP0
0Ukg0FLi0Ekg0DYB00000`@Q00048@0512402@Q2124000aS=Jeg_EJe=Je:
DP02E[D2CW<00e:DCW=>L`02CW<01E:DCW=6<DYBAS400Tic00QBU4icBU96
<DYBCW=:DTHa1T8@00DmkcW>>Li244Ha008mk`0:@Q16<DicCW=6<D8@?Nm6
<DYBCW<3BU82AS400dYBCW=:DP02AS4014icDYA:DT8@0THa0T8@00@mkd8@
?NlicP92409:DP9>L`03BU9>LdHa00=2409:DP03AS4mkcW>008icP0=?Nle
[C6<<H`YBRDY7>LDYA24248<H`@Q24803@@Q0PQ200<48@Q212400PQ200@4
8@Q22488@P<<H`0424848@@Q124224802@@Q24848@aS248DYB48:DXicP02
<H`03SF]8@PDYC6<AS5JeUJe9BT@Q0Q21248@PaS1246248436<00a2436<<
H`0248@436<2248212402@Q236<8@PQ2124@Q1BU7>LHaP0236<324831240
0`Q236<8@P0336<524800`@Q2488@P0324800`aS248<H`04248336<00a24
36<<H`0424801@aS5:DHaQS65:D00Q240PaS00<8@PaS36<00`aS00<8@PaS
36<01PaS00H8@PaS248<H`Q236<5248010@Q24848@@Q0`Q200@<Ha2448@@
Q08<H`88@P045:DLib486<H448@00`aS2488@P04248010aS48@@Q1BU0`aS
0PQ20`aS0`Q200`<H`Q236<@Q1BU6<HLib489BTQ21cWAS42G_L00dYB48@<
H`0212400`Q212448@0;12400`001240000:12401`Q212448@@Q248<Ha24
008DY@<HaP06<H`mkeJeBU9244Ha0TYB0Tic00IBU4icCW=BU4icDY@2CW<0
1DYBCW=>LdicDY@00dic00EBU5JeF]IF]E:D00=>L`9BU0E>L`08DYAF]E[F
E[EJeUJeF]INm`9JeP04E[EBU5JeE[D8DY@015[FE[EJeUJe0U[F00=F]E:D
E[D00UJe00=BU5JeF]H00Ukg00AF]E[FE[EF]@9JeP9F]@09F]IF]E[FF]IN
me[FG_MJeUJe009JeP05E[EBU4icE[EJeP02G_L3F]H00eJeDYAJeP0:E[D2
DY@01DicDYABU5[FDY@00eJe0U[F00=NmeJeF]H00U[F1EJe0U:D0UJe00=J
eUJeE[D00U[F00=Nme[FE[D00e[F1E:D15Je0U[F00INme[FF]IJeUkgF]H3
G_L2F]H00eJeDYAJeP02F]H00ekgE[EF]@02F]H00eJeF]IJeP05F]H00ekg
F]INm`03F]H2E[D00e[FE[EF]@02F]H00eJeF]INm`04F]H2G_L3F]H01Ekg
F]IJeU[FE[D015[F00=Nmf<HHaP00ekg0V<H00ENmf<HG_MNmf<H009Nm`04
HaQNmfLiG_L1@Q0000848@0600048@00124000Q20`@Q00X<HcW>MkeF]CW>
BU9F]E:DCW=BU0I>L`9:DP03AS5:DTYB009BU09:DP05AS5:DTHaBU96<@03
@Q000dHa@Q124002>Lh2?Nl01DHa?Nlmkcg_BU800U:D148@0dic0TYB00M2
44HaCW=>LdYBAS5:DP03CW<00dHa@Q124003@Q02>Lh00cg_@Q124002BU82
CW<2BU8024Ha@Q0mkdHaBU9>LdYB?Nl2>Lh00cg_>LhicP02<H`012e[9BTH
aQBU0PaS0PQ220@Q00<8@P@Q12400P@Q0PQ200D48@Q21248@P@Q008<H`<8
@P0436<@Q0aS2482124424804`@Q248<H`aS5:DU:Be[>Lhe[Be[<H`Q21S6
=Je>Le[FE[DLi`aS00848@0336<8@P@Q0088@P0536<48@Q236<8@P0336<0
112436<@Q0aS0a240PaS1@Q200H48@Q22488@Q245:D26<H236<00`@Q2488
@P06248436<3248010@Q2488@PaS0`Q20PaS00<48@Q224800PQ200@<H`Q2
48@@Q08<H`<8@P8<H`095:DHaQS65:D@Q0aS48@<Ha24008<H`<8@P8<H`03
248<H`aS008<H`88@P0536<8@PQ2248<H`07248010@Q2488@PQ20`aS0a24
00@<H`Q236<<H`8Li`038@PLia24008@Q0@<H`03248<H`Q20088@P0636<D
YA24248<H`Q20PaS0Q240PQ200/48@Q22488@PaS48@HaQcW6<HLibDY008Q
2004CW=Nme[F@Q0236<D12400`0012448@09124224801@aS5:DDYAS67>L0
0QBU00LaS48@DYA>Ld8@AS5>L`02BU85CW<00e:DCW=>L`07CW<00dYBCW=B
U003E[D2DY@024icDYABU4icDYA>Le:DCW<3DY@02EJeF]IJeU[FE[EJeUJe
F]IBU004E[D3DY@00dicDYABU002E[D00e[FE[EJeP06E[D2DY@015[FG_MN
mekg0UJe0U[F00AF]E[FF]IF]@EJeP04G_MJeUJeF]H3E[D2CW<00eJeF]IS
6003F]H4E[D015[FE[EF]E:D1eJe0Tic00ABU5JeE[EF]@9BU003F]INmekg
00EJeP04E[EBU5[FF]H2DY@2E[D01U[FE[EF]EJeF]INm`9JeP03E[EJeU[F
009F]@9BU003CW=F]E:D009F]@9JeP9Nm`AJeP03G_MJeUkg00=JeP9F]@9J
eP04G_MJeU[FE[D3F]H00eJeF]IF]@06F]H015kgF]IJeUJe0U[F0UJe00=J
eUJeF]H00U[F0Ukg0e[F00ENme[FF]INme[F00=Nm`03F]IF]E[F009JeP03
G_MS66<H00=Nm`=S6006G_MS65kgHaQNmf<H0Ukg0V<H0Ekg0DHa00000`00
12448@0512402PQ2124000aS?NmkgUJe=Je6<EJe1U:D0dYB00=>LdYBAS40
0TYB00ABU5JeDYA>L`96<@07BU9>LdicBU9243g_@Q000THa00a243g_?Nm2
44Ha@Q0mkdHaBU9>LdYBAS43@Q03AS42@Q0033g_AS5>Le[FDYA:DT8@AS5B
U5JeBU8mk`8e[@03?Nm244Ha0096<@03BU96<D8@00=24004AS5:DTHa?Nl4
@Q0013g_>LhicSW>0cF]00P]JbDY6<HDYAS648@<H`@Q10Q200D48@Q236<@
Q0aS00L48@P8@P0436<8@PaS48@25:D00`aS12448@021244248236<00aS6
8@PaS002BU801E[FE[E:DTYB;F/00RDY0RU:00@HaQ242488@P<<H`88@P05
36<8@PQ236<8@P0236<01A246<HLiaBU36<00PQ20`aS00<8@P@Q24800`Q2
00H48@Q248@@Q1BU48@824800`aS48@DY@025:D236<010Q236<48@Q20`@Q
0PQ20`@Q0`Q200<<H`Q236<00PaS00P8@PaS248<Ha245:DHaQcW0R4800HY
BS6<8@PLi`Q236<348@236<2248436<00`Q236<8@P06248336<?248336<2
5:D011245:D@Q0aS0PQ20a2400D<H`Q224848@aS008@Q0055:D@Q1245:D@
Q00236<248@00`aS2488@P0236<01aBU6<H]JcW>@Q1:DT8@0096<@06:DXH
aSW>G_MJeS6<0P@Q00<<H`Q224800P@Q00D000@Q12448@0000L48@030004
8@@Q00X48@0524848@Q2248@Q0045:D02B48:DXmkd8@AS5:DTHaBU9BU004
CW<4DY@00dicBU9:DP03DY@00dicBU9BU002DY@2F]H2DY@00dicBU9BU002
DY@01EJeDYA>LdicDY@00ekg0UJe00UJeUkgG_MJeUJeDYAF]E:DE[D00U:D
00=F]E:DCW<00U:D0U[F00INmeJeE[EJeUJeF]H4E[D00e:DE[EJeP03F]H2
E[D00e[FE[EF]@03F]H00ekgF]IJeP03F]H01EJeF]IJeU[FE[D00U:D0U[F
00ANme[FHaQJeP=F]@9JeP05E[EBU4icDYAF]@02DY@014icE[EBU5:D0Tic
0U:D00EJeUJeE[EF]E[F009Nm`03E[EJeU[F00=JePAF]@9JeP04E[EJeU[F
F]H2E[D01E:DE[EF]E[FE[D00e:D00=F]E:DDY@00eJe00=JeUJeF]H015[F
00AF]E[FF]INm`9JeP=F]@9JeP9F]@9JeP9Nm`04F]INme[FF]H2E[D2F]H3
G_L2F]H00eJeG_MJeP02F]H3G_L01E[FG_MNmekgF]H015kg00=JeUkgE[D0
1e[F00=Nmf<HHaP00Ukg1f<H00ANmf<HG_MS609Nm`5W>@5JeP52400010@Q
00d000@Q00048@Q200048@aS@Q1kgUJe<Ha6<@07DY@024icBU9:DTicBU92
44HaBU82E[D01E:DBU96<D8@BU800Tic00A6<D8@@Q124096<@0;@Q0mkcg_
@Q16<D8@?Nm244YBCW=:DP03@Q02AS402DYB@Q1244Ha?Nm6<E:DE[EBU003
AS42DY@014Ha?Nle[C6<0d8@00A6<D8@AS5:DP=24003AS5:DTHa0092408m
k`03AS5243g_00<icP8e[@03>LhYBR4800<HaP0348@<H`Q200D48@0436<@
Q12436<212400`Q212448@0212400`Q21248@P0224800`aS2488@P022480
1@aS5:DHaQBU24800`@Q00<8@P@Q24800PQ200L@Q0aS6<HQ236<BU9>L`02
E[D2AS400be[8@PU:@02:DX00b4836<48@02248336<00`Q21248@P0436<0
1PQ236<HaQcW6<H<H`P8@P031248@PQ20088@P8@Q0075:D<H`Q224848@Q2
12400`Q200H<Ha2448@DYA2436<2248010@Q24848@@Q10Q21P@Q00@8@PaS
36<<H`<8@P<<H`0948@DYAcW9BTLibU:;F/U:AS60088@P0636<@Q0aS36<8
@P@Q0PaS00<@Q0aS36<00PQ200<48@Q2248010Q20`aS00D8@P@Q2488@P@Q
0088@P0536<8@PQ2248<H`0424800`aS248@Q0026<H00aBU248<H`0436<0
0`Q236<<H`0424835:D248@010aS48@@Q1240PaS0PQ20PaS0QS600d]JcW>
@Q1:DSg_@Q16<BU:6<HicV<HF]H]J`0212400`aS12448@0412401P001248
@P@Q0008@PP48@0300048@@Q00T48@0436<@Q1BU6<H25:D012DY:DXmkcg_
0dHa0Tic00QBU4icBU9>Le:DCW=BU4ic0TYB00A>Le:DDYABU0=>L`04DYAF
]E[FF]H2DY@014YBCW=>Ldic0e:D0Tic00AF]E[FHaQJeP9F]@04F]INmekg
F]H2DY@01E[FDYABU5:DE[D015:D00AF]E[FG_MJeP=F]@04F]IF]E[FE[D3
DY@00eJeF]IJeP02F]H2E[D00e[FE[EJeP05F]H015kgF]IJeU[F0UJe0U[F
0U:D00=F]E[FG_L00U[F00ENme[FE[EBU5Je009JeP07E[EBU5:DDYAF]E:D
CW<015:D00=>Le:DDY@00U:D0UJe0U[F00=Nme[FF]H01E[F15Je00AJeUJe
F]IF]@9JePEF]@05F]IF]E:DDYAF]@02DY@00eJeDYAF]@03F]H00eJeF]IF
]@03F]H02EJeF]IJeUkgF]IBU5JeF]IF]@02F]H00eJeF]IJeP02F]H015kg
F]IJeU[F0eJe0ekg25[F0Ukg0U[F15kg0U[F0ekg2E[F0Ukg00AS65kgG_MN
m`ES6004G_MS65kgHaP2G_L2HaP1F]H1@Q00000400048@@Q000412402@Q2
12448@aS=JecW5:D>Li6<@07DY@014icBU9>Ldic14Ha14ic0dYB0Tic00E:
DT8@?Nlmkd8@0096<@04@Q0mkd8@AS44@Q02BU800dHa@Q16<@02BU801dHa
@Q0mkd8@AS5:DU:D009>L`03BU96<DHa009:DP08AS5243W>=JdicT8@AS5B
U09:DP09AS5243g_>LhmkdHaBU96<D8@008mk`03@Q16<D8@008icP8e[@8a
S0078@PHaQ2448@DYA2436<00`Q200<<Ha245:D00Q2410aS00<8@P@Q1240
0P@Q1PQ20`aS00P48@Q25:DLib4848@48@Q20P@Q01X8@P@Q2488@Q2436<Q
23F]CW=_Nf]JOomg_FmkHaQ:DU:D:DXDYA247>L]JacW36<48@Q20P@Q0PQ2
00<<H`Q236<00PaS0Q240QS600@DY@Q21248@P@<H`D8@P07124<HaBU7>LH
aPaS12400PQ200X48@Q2248DY@aS5:DQ22U:9BTHaP8@Q08<H`<8@P848@<8
@P848@0524848@@Q1248@P0236<050Q236<<H`aS5:D<HacW=Je:DVmkIcUB
U4YB7>LHaQ2436<DY@aS48@236<224800`@Q2488@P042483124336<22480
0`aS248<H`04248212400`Q236<8@P05248236<548@236<00`@Q248<H`02
5:D00`aS12448@0224825:D00aS67>LDY@025:D02`Q2124DYBDY7>L@Q0Q2
36<]JcF]E[D00VLi00ecW6]JIcUNmdHa?NlQ21BU:DXmkc6<6<H000081240
100012448@000`@Q00<000@Q124010@Q00<000@Q124020@Q00D8@Q245:DH
aQcW008DY@07:DXe[E:DDYA:DU:DCW<00dYB00M>Le:DDYA>Le:DCW=BU003
CW<00dYBCW=>L`03DY@2F]H2E[D2BU8015:DE[EF]EJe0Tic00=BU5JeF]H0
0U[F0UJe00IJeUJeG_MNme[FE[D2DY@00dicDYA>L`02CW<2DY@3F]H00ekg
F]IF]@02E[D3F]H2E[D00e:DE[EF]@03E[D015[FE[EF]EJe0e[F00AF]E[F
F]IJeP9F]@05DYAJeUkgG_MJeP02E[D00e:DE[ENm`02G_L015[FDYABU5Je
0e[F00=F]E:DDY@00eJe0U:D00=JeUJeDY@00Tic0U:D0eJe00ABU5[FF]IF
]@ANm`=JePEF]@06DYAF]E[FE[EJeU:D15Je00AJeUJeE[EF]@=BU0QF]@03
F]INmekg009JeP9Nm`03F]IF]EJe00=F]@IJeP9Nm`9JeP9F]@9JeP04G_MJ
eU[FF]H4G_L015[FG_MNmekg0U[F0f<H15[F00AS65[FE[EJeP=Nm`04E[EJ
eU[FF]H3G_L6HaP015kgHaQNmekg0f<H0Ukg0F<H0E[F0D8@000212400`00
12448@0312402PQ200048@Q2=JecW5Je=Je:DTic1U:D00U>LdYBBU9>LdYB
AS5244HaCW<00U:D00A>LdYBAS5:DP9>L`96<@03>Lhmkd8@0096<@Q24006
AS5:DTHaAS5244Ha0TYB00Y6<Cg_@Q1244HaCW=BU4icAS52409:DP08CW=6
<Cg_>Lhe[Cg_@Q1:DP9>L`9:DP8mk`8icP96<@06BU8mkcg_?Nm244Ha0Sg_
0SW>00He[Be[<H`Q21S648@25:D00a2436<48@0224800`aS48@<H`0448@3
2483124624801`aS248<H`Q2124<HaBU008Li`0548@8@P@Q00048@042482
48@00b48=Je>L`02Kg/2Nmh036]JIcU:DTHa9BT@Q1BU8@P]JacW24848@88
@P<48@0;248<H`aS36<@Q0aS48@DYAS648@<H`02124436<21243248236<0
3ABU6<H@Q0aS24848@Q2124<H`Q236<@Q1BU00<Q20066<HDYA2436<8@PaS
20Q20P@Q00@8@P@Q2488@PH<H`8@Q0097>LicTHaKg][FU:D@Q0HaQBU00D@
Q08<H`P8@P848@@8@P<<H`03248<H`Q200<8@P031248@PQ200P8@P0336<8
@PaS00<@Q0<<H`88@P0436<@Q12448@2124224801ABU6<HLiaS65:D00Q24
0PQ200`DYB487>L@Q0Q236<]JcF]E[E[FVLiLi`2IcT00ekg?NlaS0027>L0
136<?NlYBQBU1@@Q00<000@Q124040@Q00<000@Q124020@Q00<@Q1BU7>L0
0QS600HDYBU:=Je>Le:DBU83CW<2BU82CW<014YBDYA>Le:D0Tic00=BU4ic
CW<00Tic0e:D0U[F00EF]E:DBU9:DU:D00=F]@04DYA>Le:DDY@3F]H3E[D2
F]H01ekgF]IF]EJeCW=BU4YB009>L`=BU0=JeP03G_MJeUJe009F]@=JePAF
]@04F]IF]EJeF]H3E[D5F]H015JeF]IJeU[F0UJe00=JeUkgG_L01EJe00AN
mf<HG_MJeP9BU09F]@04F]IF]E:DDY@2E[D015[FE[EBU5:D0U[F00EBU4ic
CW=F]E:D009F]@07DYAF]EJeF]INme[FHaP00ekg0e[F0eJe00IBU5JeF]IF
]E[FE[D2DY@6E[D2DY@00dicDYABU006E[D2F]H00ekgF]IF]@02G_L2F]H0
1EJeF]IF]E:DE[D01E[F00=Nme[FF]H00e[F00=F]E[FF]H00Ukg0e[F00IN
mf<HG_MNme[FG_L3F]H2HaP03UkgF]IJeU[FG_MS65[FE[EJeUkgHaQJeUJe
F]H2G_L00e[FG_MNm`05HaP00ekgHaQNm`04G_L2HaP00ekgHaQJeP01@Q00
000900048@@Q124000@Q00048@Q200848@0736<icVmkE[De[D8@DY@00dic
00=:DU:DDY@00Tic00=6<D8@BU800TYB00=6<D8@AS400TYB00I243g_>Li6
<DYBCW<3@Q0014YBAS56<DHa0d8@0TYB00I243g_?Nm6<DYBAS44@Q04AS40
1TicBU96<DHaDYA:DP=24096<@04?NlicSg_AS42CW<01THaBU9BU5:DBU8i
cP8mk`06@Q16<DHa?Nm244Ha0Sg_0T8@0TYB00<aS2DY48@00QBU0PaS00@@
Q1BU48@<H`88@P07;F/icTYB?NlDYA2436<00`Q21@@Q00H<Ha2448@<H`Q2
36<224801@aS5:DDYAS648@00PQ20P@Q0PQ201P<H`Q236<<Hb48>LiBU7Nm
Liag_FmkMkeooekgBU8HaPaS48@HaR486<H<H`@Q248412422480212436<@
Q1BU6<HLiaS636<3248010aS248<H`Q20PaS00D8@PaS48@<Ha24008DY@04
48@<H`@Q2483124336<010Q248@DYA240PaS0QBU0PaS0QBU00<<H`Q22480
0PaS0PQ20`@Q0`Q200T<Ha24248DYB48<H`e[C6<:DX00be[00EJeVmkF]I:
DQ24008<H`03248@Q1S6008DY@0336<8@PQ200<48@<8@P041248@PaS36<2
248020aS2488@PaS48@DYA2424831246248536<00a2436<<H`0224821240
10Q236<@Q1240`Q200<<HaBU5:D00`aS00<8@PaS24800PaS00<8@PaS36<0
0Q2400L]Jcg_IcUg_FmkMkecW002Nmh036<HCW<HaPaS48@Q21cW36<000@Q
248000@48@0400048@@Q00021240100012448@0010@Q00D000@Q12448@00
00<48@0324848@@Q00<48@0336<HaQcW00<HaP057>LicTHaE[EBU002BU80
1dicBU9>LdYBCW=:DTic00=BU0=>L`03DYA>Le:D009BU003E[EJeU:D00=>
L`9BU006E[EBU5:DDYAF]E:D0UJe0U[F00=F]E:DE[D00e[F00EF]E:DE[EF
]E:D00=>L`AF]@03DYAJeV<H00=JeP07E[ENmekgF]IF]E:DE[D015:D00AJ
eUJeDYAF]@=JeP=F]@03F]IF]EJe009F]@9JeP03G_MF]E[F009F]@05F]IN
me[FF]IBU007E[D5DY@4E[D3DY@01eJeDYABU5JeF]INme[F009F]@05F]IN
me[FF]INm`03F]H2E[D3DY@00eJeF]IJeP02F]H00e:DE[EF]@04E[D3DY@2
E[D015[FE[EF]E[F0UJe0Ukg00=S65kgF]H00e[F00AF]E:DE[EJeP9Nm`9J
eP9F]@05F]INmekgG_MS6003F]H01EJeF]INmf<HG_L00e[F0ekg0e[F0ekg
00AS65kgG_MJeP9Nm`04F]INme[FF]H2G_L00e[FG_MJeP02G_L01e[FG_MJ
eV<HG_MS65[F009Nm`9JeP9Nm`06IcUS65kgF]IS65[F0Cg_000312401@00
12448@@Q24800P@Q00P000aS=JecW5:D=Je244YB1Dic00ABU4icBU9:DP96
<@05CW=:DTHa@Q16<@02BU8014Ha?Nlmkd8@0TYB00E243g_AS56<DYB0096
<@06@Q0mkd8@AS5>LdHa0Sg_00Y244YBAS5243g_@Q16<DYBAS52409:DP96
<@05BU9>LdYBAS4mk`02AS401D8@?NlicT8@AS400Tic00E6<DicDYA>LdYB
00<mk`06@Q16<D8@AS5244Ha0Sg_00I6<D8@BU9:DRe[8@P35:D236<031BU
6<H@Q0aS1248@RU:>Li>Lcg_5:D<H`88@P0336<8@P@Q00848@0324848@aS
00<<H`88@P0436<8@PaS48@26<H00aBU2488@P021242248236<0512436<U
:CW>DYAg_G>LMkecW7_NOomJeTYB5:D8@QBU6<HU:AS624861242248236<2
5:D01QS67>LHaQ2436<48@88@P0536<8@PaS36<8@P0336<248@25:D02124
24848@@Q24848@aS248236<348@236<00a245:DDY@0236<248@00`aS2488
@P0336<00`Q212448@0224800`@Q248<H`0236<01a248@PaS3F];F/U:BU:
008aS009G_McW5[F@Q0<H`Q248@<HaBU00<@Q00336<8@P@Q00848@052484
8@@Q248<H`0424801@aS2488@P@Q36<00a2410@Q0`aS10Q200<<Ha2436<0
0`aS0Q2400<<H`@Q24800PQ200<@Q0aS36<00`Q200D@Q1S65:D<H`@Q0088
@P0436<8@PQ248@236<248@03S6<@Q1W>GNmKg]g_G>LNmiooe[FBU8HaPaS
48@27>L00`aS12448@041240100012448@000P@Q00<000@Q12401@@Q00<0
00@Q124030@Q00@8@PaS6<HLi`<HaP057>LmkdHaDYAF]@07BU82CW<2DY@0
1DicDYA:DU:DCW<00U:D00E>LeJeE[EF]E:D00=>L`=BU007E[EBU5:DDYAF
]E:DE[D00e[F0U:D0e[F00MF]E:DDYABU4icDYA>L`02DY@2E[D00e:DE[EN
m`02G_L025[FE[EJeUkgHaQJeUJeCW<2E[D2DY@5E[D2F]H4E[D00e[FE[EF
]@02E[D00e[FG_MJeP02F]H00e:DE[EJeP02G_L015JeDYAF]E[F0eJe00AJ
eU:DDYABU0AF]@03F]IBU5:D009BU003E[EBU5:D009F]@9JeP9F]@9JeP9N
m`AJeP9F]@07F]IBU5:DDYAF]E[FG_L00U[F00=F]E:DE[D015Je15:D00=J
eUJeE[D00UJe00ABU5[FF]IS609Nm`=JeP=F]@=JeP03G_MJeU[F00AJeP03
G_MS65kg00=JeP03E[EJeUkg009Nm`AJeP03G_MJeU[F009JePINm`03F]IN
mf<H009Nm`03F]INmekg009Nm`9JePQNm`04HaQNmekgF]H2G_L2HaP2G_L0
0e[FG_MJeP01@Q000003124000@Q00848@0400048@@Q2482124020aS<Hac
W5:D<H`mkdHaBU82CW<01DYBCW=>LdicBU800THa00]>Le:DCW=:DTHa@Q16
<DYBAS5243g_00924096<@08BU96<DHaAS5:DU:DCW=:DP924096<@04BU8m
kcW>?Nl2BU800dHa?Nm24004AS4014ic@Q0mkdYB0U:D00=6<Cg_@Q000THa
00=244HaAS400TYB00A6<DYBCW=BU09F]@96<@924004AS5:DT8@?Nl3>Lh3
@Q0014Ha;F/Q21240QBU0PaS00@@Q1BU5:DDY@8<H`087>LHaTYBJeY:DRe[
1240008<H`0624848@Q21248@PaS0Q240`aS00@@Q0aS36<<H`<@Q0042484
8@@Q248236<01`@Q248@Q0aS6<H]JdHa009Nm`9cW09g_@05AS4icQS65:D@
Q00336<248@010aS24848@@Q0`Q210aS00@@Q0aS36<<H`<8@PD<H`0348@<
H`Q20088@P0348@DYABU008Q200448@<H`@Q124824802PaS5:D@Q2489BTQ
21BU248<Ha2410aS1@Q200<<H`Q224800Q2400LU:Be[?Nm>Le:DE[EBU002
>Lh01RU:7>M6<FLiE[D]J`848@8DY@<@Q00436<8@P@Q1242248010aS2488
@PQ20P@Q0PQ200<48@Q224800PQ200<<Ha2424800`@Q0PQ200D<H`Q2248<
Ha2400@<H`035:D@Q0aS008<H`0524848@@Q248<H`0348@01@aS48@@Q1BU
36<00PQ200<48@Q224800PaS0PQ200H<HaBU48@]JcW>F]H2JeX027NmKg]o
ogooG_M6<AS65:D324800`@Q2488@P0<12400`0012448@0:12400`Q21244
8@0212400`Q212400002124236<01QS67>LQ21cW9BTYBP924003AS5BU4ic
009>L`05BU9>LdicBU9>L`02DY@014icDYA>Le:D0TYB0Tic0UJe1E:D0dic
00=F]E:DE[D00U:D00AF]E[FDYAF]@9>L`03E[EBU5[F00=JeP06E[EBU5:D
E[EBU5Je0U:D00=F]E:DDY@00UJe0U[F00EF]EkgG_MS65kg009F]@0>DYA>
LdicDYAF]E:DCW=BU5JeF]IF]E[FE[EJeP9F]@03DYAF]E:D00AJeP03DYAF
]Ekg009JeP05E[EJeU[FF]IF]@04DY@00eJeDYABU004E[D4DY@00eJeDYA>
L`02DY@2F]H3E[D015kgF]INme[F0Ukg00=JeUJeE[D00e[F00EF]E:DDYAJ
eUJe009JeP03E[EJeUJe00AJeP9BU004CW=BU5:DE[D5F]H2G_L02F<HG_MF
]E[FE[EJeUJeF]IF]@07F]H00eJeG_MNm`02HaP5F]H2G_L2F]H3G_L5F]H6
G_L00f<HF]IJeP03G_L2F]H2G_L016<HG_MJeUkg0U[F00QNme[FG_MS65kg
HaQJeV<H0ekg00IS65kgG_MJeUkgF]H1AS4000848@0300048@0000<48@08
248000@Q248aS6mkE[De[@924003BU9>LdYB009:DP=>L`07BU96<DYBCW=B
U4YB@Q0014Ha148@0dHa0TYB0116<DYBCW=BU4Ha?Nm244YBAS5243W>?Nm2
44HaBU96<@924003BU96<DHa009:DP0:@Q0mkdHaDYAF]D8@>Li244YBAS42
@Q003DHaBU9>LdYBAS5>Le:DF]IF]DHa@Q0mkd8@009:DP07AS4icSW>=Jdm
kdHa?Nl00T8@00DYBR4848@@Q1BU0088@P0648@DYAS65:D@Q1BU0QcW00A6
<FLiBU8YBP848@0336<8@PQ20088@P848@8<H`8@Q003248<H`aS00@<H`03
5:D@Q0Q200848@@8@P0636<@Q0aS7>L]JdHa0V<H0W>L00Eg_G_NAS4e[ABU
008@Q00436<@Q0aS48@236<6248336<0112436<<H`aS0PQ20`aS00@8@PaS
248@Q0@<H`08248<HaBU6<HLiaS648@8@P848@P8@P0836<@Q1247>LQ21S6
5:D8@P<<H`04248<H`aS48@524801`aS248@Q1249BT]Jcg_009>L`0<E[E>
Lcg_=JdYBR48AS5S64ic<H`8@P@Q0Q240QBU00@@Q0aS36<48@<8@P8<H`D8
@P041248@P@Q248436<010Q212448@@Q0PaS0`Q20PaS00<@Q0aS48@00Q24
10aS00D48@Q21248@PaS008@Q08<H`0348@DY@aS00L8@P@<H`0@48@<HbU:
>LiNmfmkJeYg_FmkOomkgUkgAS4HaQ242484124010Q212448@000P@Q00@0
00@Q124000848@0400048@@Q000212400`001240000212400`0012448@07
12401@Q21248@PQ248@011cW00DU:Be[?Nm6<DYB00A>L`9:DP9>L`9BU09>
L`08BU9>LdicCW=:DTicDYAF]@=BU005CW=F]E:DDYA:DP06DY@3E[D015:D
CW=BU5:D0UJe00=JeUJeE[D015:D00=F]E:DE[D00U:D0eJe15[F00MNmf<H
HaQJeUJeF]IBU002CW<3DY@2CW<4E[D015[FE[EF]E:D15Je00=JeUkgF]H0
0eJe00=NmeJeF]H00e[F00MF]E:DDYABU5JeDYAF]@02DY@3E[D3DY@2E[D0
15:DCW=BU5Je0U[F0UJe0U[F00YNme[FG_MJeUkgF]IF]E[FE[EJeP9F]@9B
U003E[EJeU[F00=F]@03F]IF]E[F009JeP=BU006CW=F]EJeE[EJeUJe0U[F
0Ukg00=S65kgF]H00eJe00=JeUJeE[D01U[F00AF]E[FF]INm`9S609JeP9F
]@=JeP9Nm`04F]INme[FG_L4F]H5G_L01F<HG_MJeUkgF]H00Ukg0e[F15kg
0U[F00=Nme[FG_L00Ukg00=S65kgG_L00ekg00AS65kgHaQJeP9Nm`5JeP52
400000<000@Q12400`@Q00<000@Q24800P@Q00H8@S6<Kg]F]C6<?Nl2@Q00
0dYBCW=>L`02CW<014HaBU92448@0TYB00=>Le:DAS400THa1T8@00<mkd8@
AS400dHa00M:DU:DDYA>LdHa?Nm6<@02BU800d8@?Nlmk`02BU82AS43BU80
248@AS5:DTYBAS5243g_@Q02BU83@Q000dYBCW=:DP06BU801U:DE[E:DT8@
?Nm6<@9:DP09@Q0e[C6<>Li245:DBU8e[C6<008HaP0736<8@PQ2248<Ha24
5:D00a240QS600HDYAS68@PLia24248336<01@Q21248@PaS24800Q2400P<
H`Q248@@Q1S65:D<H`Q20PaS00@@Q0aS12448@88@P03124<Ha24008DY@8L
i`09<Ha>LeJeIcUJeTHaBU8]JbDY00<DY@0748@<H`aS36<@Q1BU48@010aS
0`Q200@<Ha2448@@Q0D<H`8@Q00336<@Q0Q200<8@P<<H`0648@<HaBU5:D@
Q0aS0PQ200@48@Q22488@P<<H`88@P0948@HaS6<<H`Lia2436<@Q1S6008@
Q00436<@Q0aS36<224805PaS48@<H`aS5:DHaSW>BU9Nmg>LKg]g_FmkG_MS
63F]9BTYBSF]@Q0e[A240PaS00<8@PaS36<00`aS0QBU00<@Q0aS24800PQ2
0`@Q0PQ200<48@Q2248010Q20P@Q0PQ21@aS0Q240PaS00h@Q1BU6<HQ21cW
5:D<H`Q236<8@P@Q248@Q1S60Q2400<<Ha245:D00PaS00D48@Q2248<Ha24
008<H`0?248@Q1BU6<HQ22DY?Nm>Le[FIcUNmf<HF]HicRe[008@Q00536<4
8@Q21248@P0312400`Q212448@0412400`0012448@0912400`0012448@0;
124224800a245:DLi`027>L01B48<H`icTHaCW<01DYB0dic0U:D0dic00AB
U4icCW=>L`EBU004CW=:DTYBCW<2DY@00eJeDYA:DP03DY@015JeDYAF]Dic
15:D00AJeUkgF]IF]@9BU0=JeP9BU003E[EJeU:D009BU003F]IF]EJe009J
eP04HaQNme[FE[D4DY@01EJeDYA>LdicDY@00e[F00AF]E:DE[EJeP=F]@03
DYAF]EJe00AJeP04E[EJeU[FG_L2F]H2DY@2CW<2DY@015JeDYA>Le:D0UJe
00=BU5JeE[D015:D00=F]E:DE[D00UJe0U[F00=Nme[FF]H00Ukg00AJeUJe
E[EF]@9Nm`03F]IF]E:D00=F]@=JeP04E[EJeU[FF]H3E[D4DY@2E[D6F]H2
G_L2F]H01U:DE[EF]EJeF]IF]@YJeP=Nm`=JePANm`06F]INme[FF]IF]E[F
1Ekg00=S65kgHaP00Ukg0U[F00ANme[FG_MJePANm`05HaQNme[FG_MJeP03
G_L00f<HG_MNm`02G_L2F]H00f<HG_MNm`02F]H1E[D1@Q0000<48@030004
8@0000D48@0:248aS6]JDY@e[Cg_AS5244HaCW<2DY@03TYBAS5:DTHa@Q16
<DYBDYA>LdHaBU96<D8@AS42@Q02?Nl0148@AS56<D8@0THa00A:DUJeDYA:
DP=2409:DP0=@Q0icSg_AS5:DTHa@Q16<DYBAS5244HaBU800THa00Pmkd8@
AS5:DTHa@Q0mkd8@0dYB00A>LdYBBU9:DP=>L`08DYA6<Cg_?Nm244YBCW=2
408aS006>Li6<E:DBU8e[C6<0QS600D@Q0aS24848@aS008@Q0035:D@Q1BU
008HaP055:DHaR487>L@Q00224801Q2436<8@PQ21248@P<<H`88@P0436<@
Q1BU48@436<00a2424848@02124224800`aS48@HaP025:D02b48<HaBU5[F
HaQJeTHaBU8]Jb485:D00Q2400@<Ha24248<H`<@Q00436<8@PaS36<22480
0`@Q248<H`0348@010Q236<8@PaS0Q240PaS00<8@PaS36<00PQ200<<Ha24
48@00Q2400@DYA2436<48@88@P051248@PQ2248<H`0324804ABU6<HYBS6<
7>L@Q0Q248@HaQ24248<HaBU36<8@P@Q248010aS01<DYAS6>Li>Le[FMkec
W7NmJeYNmf<H=JdQ22DY?Nm:DSW>48@<H`02248436<548@00`Q212448@02
248312422482124236<00`Q21248@P05248236<011BU48@@Q0aS0Q2400/H
aQcW6<HDYA24248<H`@Q248<Ha24008DY@D@Q088@P041248@PaS48@436<2
5:D02bDY:DY244icF]IW>EkgHaQNmcg_:DX00Q2400@<H`Q212448@88@PH4
8@0324848@@Q01048@0300048@@Q00848@0300048@@Q00848@88@P0448@D
YAcW7>L28@P0136<>Li244ic0dYB00=6<DYBBU800Tic00ABU4icCW=:DP9B
U003CW=:DTic009BU003CW=BU5:D00=>L`03BU9BU5:D00=BU09>L`03E[EB
U5:D00EBU006E[EJeU[FF]IBU4ic0UJe00AJeUJeDYABU09F]@9BU004E[EJ
eUJeDY@2F]H2HaP2F]H00e:DCW=BU002DY@3CW<00e:DF]IJeP02F]H015:D
E[EF]E[F15Je00AJeUJeE[EF]@9JeP06E[EJeU[FF]IF]E:D0Tic25:D0UJe
0U:D00AF]E:DDYABU0AF]@04DYAJeU[FG_L2F]H02ekgF]IJeU[FDYAF]E[F
G_MJeUJeDY@00UJe00AJeUJeF]IF]@EJeP04E[EBU5:DCW<3DY@7F]H2G_L0
15[FE[EBU5:D0UJe0U[F00=F]E[FF]H01U[F15kg0e[F0ekg0U[F00=Nme[F
E[D00U[F00ANme[FG_MNm`9S60ENm`9JeP03G_MJeU[F00=Nm`9S6003F]IN
me[F00UNm`08F]INmekgHaQNme[FG_MF]@52400000<000@Q12401@@Q00l8
@P@Q0008@Re[Kg]F]CW>AS5243g_@Q16<DYBCW<00dYB00A6<Cg_AS5:DP9B
U003BU96<DHa00924008BU9>LdHa?NlicSg_BU9>L`9:DP06AS5>LeJeDYA:
DTHa0dYB00A6<Cg_@Q16<@9:DPA24007AS5:DTHaAS5:DTHa@Q000dYB00=6
<D8@@Q00148@00=6<D8@@Q000T8@00=:DTicAS400Sg_00e244HaAS5243F]
>Lhmkd8@?Nle[B487>L@Q00236<01@Q236<48@Q248@00QS600@<H`Q236<@
Q0<<H`@8@P0336<8@PaS0088@P0336<8@PaS00H<H`03248<H`aS008<H`<8
@P0B1248@PQ21248@PaS48@<Ha245:DU:F<HLiaW>D8@5:DLib480QcW00DH
aQBU36<8@PaS00<@Q00336<@Q0aS00<<H`88@P8<H`0448@DYA2448@336<0
1Q245:DDYA2436<8@P8<H`03248<H`Q20088@P8<H`0348@<H`Q20088@P04
1248@PaS48@236<224801QBU6<HLiaS6248<H`88@P8@Q0055:DLiaS636<8
@P0212404@Q236<<H`Q25:DHaSW>E[E[FW_NKg]g_G>LNmioodHa<H`00Q24
00<LiaS65:D00PaS00@48@Q224848@8@Q0056<HDY@aS36<48@0224800`@Q
2488@P0324800`aS2488@P02248236<3248236<00`Q236<<H`026<H27>L2
5:D26<H28@P00acW48@8@P02124248@00aBU48@8@P0336<00a2436<<H`04
248236<448@02AcW5:D]JeJeLiag_DYB;F/YBP027>L236<2124324871240
0`001248@P0312400`0012448@0C12401PQ212448@aS48@HaP8Li`055:DL
ibe[?Nm6<@02@Q001DHaCW=>LdicBU800Tic00EBU4icCW=:DTic00=BU0A>
L`9BU09>L`9F]@04DYA>LdYBCW<2E[D00e:DE[EBU002DY@015JeDYABU5:D
0U[F00AF]E[FDYABU0EF]@04F]IF]EJeDY@2E[D015[FE[EF]EJe0U[F0UJe
0e:D00AF]E:DE[EBU09F]@03DYAF]EJe009F]@9BU003E[EJeU:D009BU004
E[ENmekgF]H3E[D015[FG_MF]E[F0e:D00E>Le:DDYABU4ic009BU0=F]@9J
eP03E[EJeU[F00MF]@04G_MJeUJeF]H3G_L015JeDYAF]EJe0U[F00MF]E:D
E[EJeUJeF]IF]@05F]H00eJeDYABU005DY@2E[D00e[FG_MNm`03F]H2G_L3
F]H2E[D2DY@01EJeDYAJeU[FG_L00U[F00AF]E[FG_MJeP9Nm`=JeP9Nm`05
F]INme[FF]IF]@02F]H01EkgF]INmekgHaP015kg00=S65[FF]H00e[F0Ukg
0e[F1Ekg00=JeUkgG_L00ekg00=JeUkgG_L01ekg0EJe0Cg_000212401000
12448@001@@Q00D<Hbe[Kg]JeSF]0096<@03?Nm244Ha00=:DP06CW=:DT8@
@Q16<DYB0U:D0TYB0d8@00I:DTic@Q0mkcF]?Nl2BU801TicAS5:DU:DE[E>
L`96<@=:DP08@Q0mkcg_AS5>LdHa@Q0mk`924096<@9:DP06AS52448@AS5:
DTHa0d8@00=6<D8@AS401D8@00A6<DYBBU92408mk`0<@Q1:DTHa?NlicSF]
?Nm243g_<H`Q21cW0Q240`Q20P@Q00X@Q1cW6<H<H`Q236<@Q0aS248<H`<8
@P0336<8@PaS00<8@PL<H`04248<H`aS36<2248236<224800`@Q24848@02
248030aS48@8@Q246<H]Jf]JLiaNmd8@5:DLi`8Q208Li`8@Q08<H`8@Q003
36<@Q0aS00<<H`<8@P8<H`0=48@DYA2436<@Q0aS248DYAS65:D<H`@Q2480
0PaS00H@Q0aS36<8@P@Q248336<010Q21248@PQ21@aS0PQ200PDYAS67>LD
Y@aS248<H`Q20Q2400TDYAS65:D<H`Q21248@PaS24800PaS00HHaQcW?NmF
]F]JNmh2Li`3Mkd014Ha;F/@Q1240QS60Q241@Q200H<HaBU5:D@Q0Q236<2
248212400`Q212448@05248010@Q2488@PaS1@Q20PaS00<@Q1S67>L00QS6
0QBU00LHaQcW7>LU:AS648@8@P02124236<00aBU48@<H`0536<2248336<0
0`Q236<<H`0248@01ABU6<HDYC6<G_L00W>L00Q:DRU::DXLiaBU48@<H`Q2
0`@Q00<8@P@Q124030@Q00D000@Q24848@0000`48@0324848@@Q00@48@04
36<@Q1S67>L26<H01RDY:DXicSg_@Q16<@9:DP04CW=:DTYBBU83DY@2BU82
CW<2DY@01TicBU9>Le:DE[EBU09>L`9BU004E[E>LdicCW<2DY@00eJeDYA>
L`05DY@2E[D2F]H5DY@01E[FE[EJeU[FE[D00e:D0eJe00=BU5JeF]H00U[F
00IBU4icDYAF]E:DE[D2DY@00eJeDYAF]@03E[D2DY@4E[D2DY@00eJeF]IN
m`02F]H2E[D01UkgF]IJeU[FDYA>L`ABU0=>L`04E[EBU5JeF]H3E[D00e[F
E[EJeP05E[D2F]H00ekgE[EF]@03G_L4E[D015[FE[EF]E:D0eJe0U[F00=F
]EkgE[D00U[F1e:D0eJe00IJeUkgG_MJeUJeF]H2G_L01E[FE[EF]E:DF]H0
0e:D00=F]E[FF]H00e[F00EF]E[FF]IJeV<H00=Nm`=JeP03G_MJeU[F00=J
ePINm`05HaQJeUkgHaQNm`05F]H00ekgF]INm`02F]H2G_L016<HF]INme[F
15kg00=JeUkgF]H01ekg0E[F0EJe0D8@000312400`0012448@02124020Q2
00048@Q2;F][FUJe>Lh2AS400d8@AS56<@03BU802DHaBU92448@AS5244YB
CW=:DP02AS400d8@AS5:DP02AS404d8@>Lhe[D8@BU9>LdHa@Q1:DTicDYA>
LdYBCW=:DTicAS5243g_00924003AS4mkcW>008icPE:DP924005AS5:DTic
BU8mk`06@Q04>Lh04T8@BU9:DTHa@Q1:DTHa?NlicSg_AS5BU4YB=Jd]JaS6
7>L@Q0@8@P041248@PaS48@236<224800`aS2488@P021242248010@Q2488
@PaS0`Q21@aS00D8@PaS2488@P@Q008<H`0324848@Q20088@P051248@P@Q
248<H`0224800`aS48@Li`02=Jd00bU:7>LDY@027>L00aS648@<H`0:36<0
1A2436<@Q0Q236<00PQ20Q240QS600DDYA2448@DYAS6008DY@0336<8@Q24
008@Q00436<8@P@Q124248@011BU36<48@Q20PaS00DDYA2448@<Ha24008<
H`0648@DYA2448@8@P@Q0PQ21A240`Q210aS00H@Q1S66<HaS48@F]H2JeX0
1W_NMkecW6]J>LhaS08DY@0836<8@PaS36<@Q0aS24848@<8@P0336<8@PQ2
00h8@P@<H`03248<H`aS00@<H`8DY@<Li`039BTQ21S600<@Q00336<8@PQ2
008<H`0448@<H`aS248336<2248436<01@Q26<HQ21S648@00PQ200/DY@aS
9BU:DUkgBU8U:ABU8@PHaQ2400<8@P041248@PQ224831242248412422489
12400`0012448@0412401@0012448@@Q00001`@Q00<8@Q245:D00aS600PL
ibU:=JdmkdicBU9>Le:D1Tic00=:DTicCW<015:D00=:DTicBU800TYB0Tic
0U:D0dYB00E>LeJeE[EBU4ic009BU005E[EBU5:DDYAF]@02DY@00eJeF]IB
U002DY@025JeF]IJeUJeF]IBU5JeDY@5E[D2DY@6E[D00e:DCW=BU005DY@0
15JeF]IF]E[F0U:D0UJe0e:D00QF]EkgG_MF]E:DE[EJeUkg0U[F0U:D00E>
Le:DDYABU4ic009F]@AJeP9F]@9JeP04G_MJeU[FE[D2F]H01UkgF]IJeU:D
E[EJeP=Nm`9F]@05F]IBU5:DE[ENm`02F]H3E[D2G_L5E[D015:DCW=F]E:D
0UJe00ABU5[FE[EJeP=Nm`04F]IF]E[FG_L2F]H01EJeDYABU5:DE[D00U:D
00=F]E[FF]H00U[F00EF]E[FF]IJeUJe00EJeP04E[EJeUkgF]H2E[D5F]H3
G_L00f<HG_MNm`02G_L2F]H015JeF]INme[F0UJe00=JeV<HHaP00Ukg1U[F
00ENme[FG_MF]E[F00ENm`5S605F]@52400000<48@0012400P@Q00<000@Q
12400P@Q00H000Q2<Ha_NeJe>Lh2AS400d8@AS56<@02BU82AS4024YBAS52
448@AS5:DTicBU82AS40148@BU9:DTYB0T8@0SW>00U244HaCW=6<D8@BU9>
Le:DCW<00dYB00=>LdYB@Q000d8@0116<Cg_=JdicT8@AS5>LdYBAS5:DT8@
?Nm244YBCW=:DPA24003AS4mkcW>008icP04?NlicTHaBU82AS404D8@AS5:
DSg_>LhmkdYBCW=6<CF];F/LiaS648@<H`Q236<010Q20Q240`aS1@Q20P@Q
00@8@PaS36<8@PP<H`<8@P041248@PQ236<2248010@Q2488@PQ20P@Q0PQ2
00D@Q0aS36<DYAcW008aS006;F/LiaBU5:DLiaS60Q2400<8@PaS36<03`aS
00<DYAS65:D00Q2400`DYAS67>LDYA2436<8@PaS48@DY@aS2482124020aS
48@@Q12424848@Q248@25:D010aS48@<H`aS11240PaS0PQ200<<Ha2448@0
0Q240PaS00<8@PaS36<010aS01<LiaS6<Ha6<E[FKg][FWooMkecW6Li>Lh]
Ja2436<@Q0Q236<8@P0336<824800`aS2488@P0:248236<02a2436<8@PQ2
36<8@Q2436<@Q1BU6<H00acW00<Q21S66<H00a2400@8@PaS248<H`<@Q005
36<8@PaS36<8@P0536<00`Q236<HaP027>L04A24248<HaS648@U:E:DF]I>
LbDY5:DLiaS648@8@P@Q24800P@Q0PQ25`@Q00@000@Q124000848@052484
8@@Q1248@P04124224802A245:DHaQS67>LHaRU:=Je24005CW<014YBCW=>
Le:D0Tic00=:DTicDY@00U:D00=>LdYBCW<00TYB0Tic00MBU5JeDYA>LdYB
AS5>L`04DY@00dicE[EBU002DY@2E[D2DY@00eJeF]IF]@02DY@00eJeF]IJ
eP03E[D00e:DE[EF]@03E[D2DY@01EJeF]IF]EJeDY@00UJe0e:D00=F]E:D
DY@00U:D00=F]E[FE[D00U:D1EJe00=BU5[FG_L00UJe00=BU5JeG_L00Ukg
00MJeU:DDYABU4icDYA>L`02DY@00eJeF]IJeP06F]H00ekgF]IJeP02E[D4
F]H2E[D015[FG_MNmekg0eJe0U:D00IF]E[FF]IJeUJeDY@4F]H00e:DE[EJ
eP04DY@015JeDYABU5Je0e[F00=Nme[FF]H015[F00ANme[FE[EBU09F]@04
DYAF]E:DE[D3F]H01EJeF]INme[FE[D00U[F00ANme[FF]IF]@AJeP=F]@=J
ePANm`04F]INmekgG_L3F]H01EJeF]IJeU[FE[D00U[F0V<H0Ukg00=JeUJe
F]H00U[F0Ukg0e[F00=F]E[FHaP015kg0E[F0D8@00000`00124000051240
2@Q212448@Q2;F]W>Dic=Je6<@02BU82@Q02AS42BU83AS42@Q0014HaBU9:
DTYB0d8@0THa0T8@0SW>0Sg_0T8@0TYB0Tic0TYB00I6<DYBCW=>LdYB@Q04
?Nl3>Lh03T8@BU9:DTicBU9243g_@Q1:DTicBU8mkd8@?Nl6@Q001cW><H`m
kdYBCW=6<C6<008icP0?<H`icTYBE[ES65:D;F/Q21BU7>LHaQ2424848@Q2
00848@09248<HaBU5:D@Q0aS124<H`Q200<48@0424848@Q2124724821243
24801@aS2488@PQ212400PQ200<<H`Q224800PQ200LDYAS648@@Q0Q236<@
Q0025:D00a2436<DY@026<H011242488@PaS0PQ20PaS00H@Q0aS2488@PaS
248348@010aS2488@PaS0Q240QBU00PHaQcW7>LLiaBU6<H@Q0aS0a2400PD
YA2436<8@QS69BTLia240P@Q0PaS00@DYA245:D<H`<@Q0096<HLiaS648@<
H`Q248@<Ha2400@<H`<8@P0636<8@P@Q36<LibDY0QcW00/]JdHaF]IBU5kg
E[E:DT8@8@PLiaBU008@Q00836<@Q0aS248<H`Q236<8@P8<H`@8@P<<H`03
248<H`Q2008<H`03248<H`aS00@8@P0448@<H`aS248336<248@26<H27>L0
1aS67>LDYABU48@DYA24008<H`88@P@<H`03248<H`aS0088@P05124<H`aS
36<@Q00336<00`Q236<<H`0236<011246<HLiacW0QBU0QS600<DY@aS1240
0PQ200D<H`Q224848@Q200P48@88@QX48@88@P041248@PQ25:D46<H012DY
=Je:DTYB0Tic00M:DU:DCW=>LdYBCW=BU002CW<3DY@01TicDYA>LdicBU9>
L`=BU003BU9>Ldic00A>L`=F]@03DYA>Le:D009BU004E[EBU5:DCW<2E[D0
0e:DE[EBU005E[D2F]H2E[D015:DE[EF]E:D0UJe0e[F0eJe0e:D0Tic0U:D
0U[F00EBU5JeDYABU5Je00ABU09F]@08F]IF]EJeE[EJeUkgF]INm`9F]@05
DYA>LdicCW=BU004F]H00eJeG_MJeP02F]H2HaP00ekgF]IF]@05F]H2E[D0
0e[FE[EJeP03F]H00eJeDYABU003F]H00eJeDYAF]@04E[D2F]H2E[D01E:D
E[EF]E:DE[D00U:D0eJe0U[F00IF]E[FF]IJeUkgF]H2E[D3DY@5E[D3F]H0
2EJeF]IF]E:DE[ENme[FG_MBU004F]H3E[D2F]H00eJeF]INm`02G_L015[F
G_MNmekg0U[F00=Nme[FF]H01U[F0Ukg00=JeUkgF]H01E[F00ANme[FE[EF
]@AJeP9Nm`5S605JeP52400010@Q00h000@Q12448@Q200048@Q2;F]S64ic
=Je244YB0THa00=244HaAS400TYB0THa0d8@00A6<DicBU9:DP=24096<@03
@Q0icSW>008icP07?Nm244HaAS5>LdYBCW<00dYB00M>LdYBBU9:DT8@?Nli
cP02?Nl2>Lh00cg_BU9:DP02BU801dic@Q0icT8@BU9>LdYB008mk`05@Q0m
kd8@?Nm24002?Nl00cW>=Jdmk`02BU803Cg_<H`e[Cg_<H`e[DYBE[ES65:D
;F/Q21BU008HaP0548@8@PQ224848@0224801@aS48@DYA2436<00PQ21@@Q
20Q200<48@Q2124010Q200L48@Q22488@PaS24848@02248010@Q248<Ha24
0QBU0PaS00X8@PaS5:DDYAS648@DYAS65:D@Q088@P0336<8@PaS00H<H`05
248<H`aS48@<H`03248236<00a245:DDY@036<H011cW6<HDYA240PaS0Q24
0PaS0PQ200@LibU:7>L<H`848@8<H`0448@DYA2448@336<36<H00aBU248@
Q00336<00a2436<<H`0424801Q242488@PaS7>LU:@8Li`08;F]6<E[FE[EN
me[FAS4icP8Q208@Q0@<H`0548@8@PQ2248<H`04248010aS2488@PQ20PaS
0PQ200@<H`Q22488@P8<H`06248<H`aS248<H`Q21@aS00L@Q1S66<HLib48
7>LHaP035:D348@236<00`Q236<<H`0236<00`Q236<8@P03248836<00a24
36<8@P0248@26<H01acW6<HDYABU6<H@Q0aS00848@88@P0536<8@PQ21248
@P091242248K124236<021BU6<HLiaBU7>LYBSW>CW<3BU83CW<2BU85CW<3
DY@00dicDYA:DP02BU8014icE[EBU4YB0Tic00A:DTicCW=>L`9BU09F]@05
DYA>LdicDYAF]@04DY@015JeDYABU5:D1EJe00AJeUJeE[EBU0=F]@9BU006
E[EJeU[FE[EJeUJe15:D00A>Le:DDYABU09F]@03F]IBU5:D009BU003E[EB
U5:D009BU0=JeP=F]@9JeP05G_MJeUJeDYA:DP02CW<00e:DF]IJeP02E[D5
F]H2HaP2F]H00eJeG_MJeP02F]H2E[D015[FE[EJeUJe0U[F0UJe0U:D00AF
]E[FG_MJePAF]@05F]IF]EJeE[EJeP02E[D5DY@4E[D00e[FE[EJeP02F]H0
15kgF]IF]EJe0e:D25Je0e[F0eJe00=JeUkgE[D00UJe0e[F0eJe0U[F00IF
]E[FF]IS65kgF]H3G_L6F]H00ekgF]IJeP02F]H2G_L00e[FG_MJeP04F]H0
15kgF]IJeU[F0UJe0e[F00ANme[FHaQJeP52400000@000@Q124000848@03
00048@Q200848@0<248aS6]JBU8aS4YBCW=6<D8@?Nm244Ha0dYB00E6<DYB
BU9:DTHa00I2408icP04=JdicSW>>Lh2?Nl2@Q02AS43BU8014HaBU9:DTYB
0U:D00=:DTHa>Lh00Sg_00@e[CW>>Li24096<@9>L`04AS5243W>?Nl2AS42
@Q02?Nl00d8@?Nlmk`02AS40148@?Nlmkd8@0SW>014aS3F]?Nlmkd8@CW=:
DTHa>LhQ21cW6<HLiaS65:D8@PaS00<8@P031248@QS6008Q20036<H8@PQ2
0088@P<48@<8@P848@@8@P031248@PQ20088@P071248@P@Q24848@Q21240
0`aS0PQ200H<Ha2436<8@PaS48@2248236<25:D248@436<224800`aS2488
@P0436<224801PaS48@@Q12436<8@P8<H`0648@DYABU6<HDYAS61ABU00D@
Q0aS48@@Q1BU00<Li`045:D<H`aS248436<448@01PaS48@YBSF];F/Li`88
@P<@Q00E36<8@PaS48@8@P@Q48@Q21cW36<48A246<H8@QBU<HaF]G_NIcU6
<CF]008DY@049BT]Jb486<H236<01QBU36<<Ha245:D@Q0@<H`@8@P0436<8
@PQ2248436<010Q236<<Ha2410aS00@@Q0aS248<H`8@Q08DY@076<HLib48
7>LHaQBU48@00aBU00@@Q0aS248<H`88@P0436<8@PaS248236<324800`@Q
2488@P02248336<011245:DDYA240`aS00P8@PaS6<HU:AS636<48@aS0QBU
00<@Q0aS24800P@Q00<8@P@Q12400`@Q00<8@P@Q24800P@Q0PQ220@Q00@0
00@Q124000<48@0524848@@Q12400004124224800`@Q36<DY@046<H02B48
>Li6<E[FDYA:DTicAS5:DP02CW<2DY@00dYBCW=>L`02DY@2CW<2BU800dic
DYABU002DY@014icDYA:DTYB0Tic00=BU5JeDY@01e:D00=JeUJeDY@01E:D
00=>LeJeE[D00e[F0eJe0U[F00EF]E:DE[EF]E[F00=F]@05G_MJeU:DCW=B
U005E[D01E:DE[EBU5JeDY@01eJe00eJeUJeDYAJeUJeG_MS65[FG_MF]Dic
E[EBU003F]H00ekgF]IJeP03F]H4G_L5F]H015JeF]IJeU[F0UJe00QJeUkg
F]IJeUJeDYAF]E:D0UJe00=BU5JeF]H00UJe00IBU5JeF]IJeUJeF]H2E[D2
DY@01dicDYABU5:DE[EJeUJe009JeP03G_MJeUJe00AF]@03DYAF]E:D009J
eP9F]@04DYAJeUkgF]H4E[D4F]H2E[D2G_L01e[FG_MJeUJeF]IF]E:D009J
eP9Nm`03F]INme[F009Nm`03F]INme[F00ENm`03E[EJeU[F009JeP=Nm`9F
]@06F]IF]E[FE[EJeUJe1E[F00=Nmf<HF]H00D8@00000`@Q00048@081240
30Q2<Ha[FTic=Je6<DicBU8mkcW>?Nm6<@9:DP96<@9:DP05AS52448@@Q0m
k`03@Q000cg_>Lhe[@03>Lh2?Nl2@Q001THaBU9:DTHaBU96<@9:DP9>L`03
DYA:DT8@00HicP07?Nm6<DYBCW=:DTHa@Q000Sg_0dHa00E243g_>Li243g_
00A2408icP08?NlicSW><H`e[Cg_>Li2409:DP08AS4icR487>LHaQcW6<H@
Q0<<H`@8@P046<HLib485:D22488124524800`@Q2488@P0424801@@Q2484
8@Q212401@Q21@aS00L8@PaS36<8@PaS48@DY@0348@00`Q236<<H`0336<2
248636<010Q248@<Ha241PaS00HDYAS66<HHaQBU6<H35:D548@00aBU6<HD
Y@026<H236<2248236<348@020aS48@@Q0aS:DXicRe[7>L2248348@436<0
0`Q2124DY@027>L03PaS248@Q1S6248HaS6<F]Ioof<H@Q0aS1S65:D2:DX0
1BDY6<H<H`aS5:D00`aS0QBU0Q2400<<H`Q224800PQ21`aS0PQ21@aS00D8
@PaS36<<H`Q2008<H`<@Q0075:DHaQcW7>LHaQBU48@00QS60QBU0Q241PQ2
0`aS0PQ20P@Q0PQ200H<H`Q22488@PaS248448@236<01a2436<<HaS68@PH
aPaS0088@P8DY@0748@<H`@Q1248@P@Q24801@@Q0`Q20P@Q00<8@P@Q1240
1@@Q00<000@Q12403`@Q0PQ200<@Q1BU7>L00aS600HU:Cg_BU9F]DicAS42
BU8014HaBU9BU5:D0dic0e:D0Tic00A6<DYBCW=F]@9BU003CW=BU4ic00=:
DP03DYAF]E:D009BU005CW=BU4icCW=BU003E[D2DY@01EJeDYABU4icDY@0
0UJe00IJeUkgF]IF]E:DE[D2F]H015JeDYAF]EJe0U[F0UJe0U[F00EBU4ic
CW=F]E[F00EF]@ABU0EF]@9JeP=F]@05F]IS65kgG_MJeP04DY@7F]H00eJe
F]INm`02HaP5F]H00eJeF]IF]@05E[D3F]H00eJeDYABU006E[D00e[FE[EB
U003E[D00e[FE[EJeP02E[D00dicDYABU002DY@3E[D5F]H2E[D01E:DE[EB
U5:DE[D00U[F00=F]E:DE[D01E[F0U:D00MF]EkgF]IJeUJeF]INm`02F]H0
15JeF]IJeU[F0eJe00=Nme[FG_L00U[F0Ukg00AJeUkgF]IJePANm`EJeP03
G_MJeUkg009JeP03E[EJeU[F009JeP9F]@AJeP04G_MJeV<HF]H1@Q0000<4
8@0300048@0000848@0B248000@Q248icV]JBU8]Jcg_BU96<Cg_>Li243g_
AS5:DTHa0TYB0THa2Cg_0SW>0Sg_0dHa00<mkd8@@Q000Tic0TYB00=>LdYB
AS400Tic00=6<Cg_>Lh00T8@00@mkcW>>Li24096<@A:DP0@AS5243g_AS5:
DTicAS5243g_@Q16<DicBU9243g_<H`3>Lh02CF]:DXaS48@CW=JeTYB<H`Y
BP026<H01ABU48@@Q1BU48@00PaS0Q240PQ200@HaRDY:DXQ20@8@P8<H`H4
8@04248<H`Q248@236<010Q212448@@Q0PQ200@48@Q21248@P<<H`88@P<<
H`03248<H`Q200<8@P0336<@Q1BU00<DY@036<HDYA240088@P0336<8@PQ2
00L8@P8<H`88@P0336<@Q124008@Q0<DY@<@Q0@DY@8@Q08<H`8DY@046<HD
YABU5:D548@00aBU48@<H`0236<01a24:DX]JbDY6<H48@Q200<@Q00336<8
@PQ200@<H`0<48@<H`Q2124<Ha24248@Q2DY=JdicRe[0QcW00PHaQcW6<HH
aPaS248<Ha2411BU0Q2400<DYA2448@010Q200<@Q0aS48@00a2400<<Ha24
48@01@aS1Q2400<<HaBU5:D011S600<LiaS66<H011BU00<@Q0aS36<00PaS
00<8@PaS36<00PQ200<48@aS48@00PaS00@8@P@Q24848@@8@P@<H`8@Q0@<
H`8@Q00336<48A24008Li`045:D8@P@Q24841242248020@Q2488@P@Q2484
8@Q2124224800`@Q24848@0812400`0012448@0712401`Q212448@@Q0008
@PaS00@DY@037>L]JcF]009BU004CW=:DTHaBU83CW<3BU84CW<00e:DCW=:
DP02CW<2DY@00dicDYA>L`02BU82CW<00e:DCW=>L`02DY@00dicDYABU003
E[D7DY@014icDYAJeU[F0UJe00=BU5JeDY@00UJe00EJeUJeE[EBU5Je00EJ
eP9BU004CW=BU5:DCW<2DY@00eJeF]IBU003DY@2F]H015JeDYAF]E:D0U[F
0UJe0U[F00=Nme[FF]H01EJe1E[F00AF]E[FF]INm`9JeP9S609JeP04E[EJ
eU[FF]H2E[D00e:DE[EJeP03F]H3E[D02e:DE[EBU5:DE[EJeU:DE[EBU5Je
F]H00UJe00AJeUkgF]IJePQBU09F]@04F]IF]EJeDY@2E[D01E[FE[EF]EJe
F]H00UJe00=JeUJeF]H00U[F0eJe00MJeU:DDYABU5[FG_MJeP02E[D00e[F
G_MNm`03E[D2F]H00eJeF]IJeP02G_L4F]H2G_L00e[FG_MNm`02G_L3F]H0
0eJeF]INm`03G_L00e[FE[EF]@02E[D3F]H01ekgF]IJeU[FG_MS65[F004m
k`000P@Q00<000@Q12400`@Q00d8@P@Q124<HcF]JeY:DRU:?Nm:DTHa?Nli
cP02?Nl00d8@BU96<@02BU82AS42?Nl2>Lh3?Nl2>Lh01cF]>Lhmkcg_AS5:
DT8@008mk`03AS5:DTic009:DP0=CW=:DTYBBU9BU4Ha?NlicSg_AS4mkcW>
?Nl00T8@00=6<DYBAS400TYB00M243g_@Q16<DicBU96<@02?Nl01T8@AS5>
LdYB@Q0icP8e[@8icP0;=Jd]JcF]@Q1BU5[FAS4aS2U:6<HLi`025:D448@2
36<01a241248@QS68@P]JacW00<8@P8<H`0324848@@Q00<48@88@P8<H`H8
@P848@88@P041248@PQ2248436<01PQ236<<H`aS248<H`@8@P8@Q0086<HD
YAS67>LDYA2436<48@<8@P8<H`@8@P8<H`88@P8<H`D@Q0035:D@Q0aS008@
Q08DY@076<HDYA2448@<Ha245:D00QS600<DYA245:D00Q2400<<Ha245:D0
0Q240`aS00PDYBU:;F/U:AcW36<8@PaS0Q2400<<H`Q224800PaS00@8@Q24
48@<H`<8@P0736<8@QBU:DXe[Cg_:DX00QcW00@HaQcW6<H@Q08<H`0348@<
HaBU00HDY@0348@<H`Q20088@P8<H`0748@<Ha2448@<Ha2436<00a241@aS
00D@Q0aS36<<Ha2400<DY@046<HLiacW7>L26<H011BU48@DYABU0a2400@<
H`Q236<<H`<8@P@<H`88@P031248@PQ200<8@P0336<8@PQ200<@Q00:248<
H`aS36<@Q0aS48@<H`Q25:D27>L011BU1248@PQ20`@Q0PQ200<48@Q21240
0P@Q00@8@P@Q1248@P848@0324848@@Q00/48@0300048@@Q00H48@062484
8@@Q248@Q1BU0QS600T@Q1cW;F/mkeJeDYA:DTicAS400TYB0dic0TYB1Dic
0TYB0Tic0U:D00A>Le:DCW=6<@9:DP=BU004CW=BU5:DCW<4DY@00eJeDYAB
U002CW<2DY@01dicDYABU5JeF]IF]E:D009F]@9BU003F]IF]EJe009BU005
E[EJeU[FE[ENm`02E[D2CW<4DY@2E[D00e[FDYABU002DY@2F]H2E[D01E:D
E[EF]E[FE[D00U[F0Ukg0U[F0UJe00=JeUJeF]H00e[F00ENmeJeF]IF]E[F
00ANm`03HaQNme[F009F]@9JePAF]@EJeP=BU003E[EBU5:D009F]@05F]IF
]E:DDYAJeP02E[D3G_L00eJeCW=BU002DY@00dicDYABU002DY@3F]H2DY@7
E[D01e[FE[EF]EJeF]INme[F00EF]@03DYAF]E[F00EJeP9Nm`06F]IBU5Je
E[EJeUJe0U[F00=Nme[FF]H00U[F0ekg00=JeUkgG_L00Ukg00]JeUJeE[EF
]E[FG_MS65kgF]IF]E[F00=F]@AJeP=Nm`03F]IS65[F0052400000L000@Q
12448@001240000224802000124<HcF]JeY>LbU:=Jd2@Q001DHa@Q1243g_
@Q000TYB0U:D0THa00<mkd8@AS400T8@0THa00I243W>=JdicT8@AS42BU82
AS42@Q02BU82CW<014YBAS5244Ha0TYB00I6<Cg_?Nm244YBAS42?Nl00cW>
@Q1:DP03BU801DHa@Q16<D8@BU800U:D00A6<Cg_?Nm:DP9>L`92408e[@<i
cP8e[@0:>Lhmkd8@?NlaS2DY6<HDYA24248636<02a2436<<HaBU8@PLiaS6
248<Ha2436<00Q240PaS10Q21@aS0PQ20P@Q00L8@P@Q24848@Q21248@P03
48@336<448@01@aS2488@P@Q36<00aS600HDY@aS48@DYA2436<524821240
3PQ212448@aS5:DLiaBU36<8@Q246<HDYAcW5:D248@01PaS248<H`aS5:D@
Q0@<H`0>5:D@Q1BU<Ha246LiHaPaS2DY48@<HaS65:D@Q0<8@P0336<@Q124
00<<H`04248<H`Q236<348@01@aS248<H`Q2124010Q20PaS00<@Q1BU5:D0
0QS60aBU0a2400<<Ha2436<00PQ200L<HaBU5:D@Q1BU6<HDY@0236<348@0
1PaS248@Q1246<HDY@D@Q00536<8@PaS48@DY@0348@02ABU48@DYB48:DX]
Jb487>LQ20027>L348@010aS48@<H`aS1@Q200<48@Q2124010aS10Q200<4
8@aS36<00a2400X<H`Q2248DYAS68@PU:AcW5:D@Q0<8@P0436<@Q0aS1242
248312400`Q212448@02124010Q212448@Q20P@Q1@Q21P@Q00<000@Q0000
10@Q00D000@Q12448@0000D48@88@P@DY@096<HLibDY@Q16<EJeCW=6<DYB
009>L`A:DP=>L`9BU004CW=:DTHaBU83DY@2CW<2BU800dicDYABU002CW<4
DY@00eJeF]IJeP06DY@2CW<00dYBE[EF]@02F]H2DY@2E[D00e:DE[EJeP03
DY@00eJeF]IJeP02F]H00eJeDYABU002DY@2CW<00e:DCW=F]@03DY@014ic
E[EF]EJe0e:D00EF]E[FE[EF]E:D00AF]@03G_MJeU[F00=F]@9JeP04G_MJ
eUJeE[D4F]H01ekgHaQNme[FE[EBU5Je00=JeP=F]@04F]IF]E[FF]H2G_L2
E[D01e:DE[EF]E:DE[E>Le:D009F]@=JeP9Nm`03F]IF]EJe009BU003E[EB
U4YB009BU00<E[EBU5:DDYAJeUJeF]IF]E[FE[EJeU:D0eJe0e[F0UJe0U[F
0UJe0U:D15[F0UJe0e[F00MF]E[FF]IJeUkgE[EJeP03G_L01U[FE[EJeU[F
HaQNm`9JeP=Nm`04E[EJeU[FE[D4F]H01UkgF]IJeUJeF]IF]@9Nm`9JeP=N
m`03E[ENmeJe0052400000@48@00124000H48@0?000<HcF]JeY>LbU:=Je2
44Ha@Q16<D8@?Nm244Ha009>L`03DYA6<D8@00=24005?Nm2448@AS4mk`03
>Lh2@Q0014YBAS5244Ha0T8@00E6<DYBDYA>LdYB0096<@=:DP03AS52448@
00=6<@04@Q0icSW>@Q04BU802d8@AS56<D8@BU9BU4icAS5243g_AS400Tic
00=6<D8@<H`00SF]00<icSg_=Jd00SF]00DicTHa?Nle[BDY008DY@@<H`03
48@<Ha24008DY@0636<8@QBU7>LQ21BU10aS00<@Q0aS36<00PQ200<48@Q2
24800`aS1@Q210@Q0108@P@Q2488@PaS48@<H`Q236<@Q1BU48@<Ha2436<4
8@88@P0636<HaQcW5:D@Q0aS0QBU00D@Q0Q22488@P@Q00<8@P081248@P@Q
124<HaS67>LDY@8<H`8DY@036<HDYA24008@Q00436<8@PaS36<248@336<0
3A245:D@Q124>Li6<F<HG_L]Jb4848@<HaBU008@Q005248<H`Q236<DY@02
48@030aS248<H`aS248<Ha245:D@Q0aS248<H`@8@P@<H`0348@DYABU008H
aP8DY@0448@DYA2448@336<00`Q236<<H`0248@020aS5:DHaQ2436<8@Q24
5:D336<011245:DDYABU0Q2400DDY@aS36<8@PaS00<@Q00;5:D@Q12448@<
HaBU9BTYBRe[8@PHaP027>L011S648@@Q1240`aS00<8@PaS36<010Q20P@Q
00D8@PaS36<<H`Q200<48@07248<H`Q248@DYA2436<00PQ200D@Q1S67>LU
:AcW008DY@031248@PaS008@Q00436<48@@Q248412422483124224831242
248236<00`Q212448@0B12401PQ212448@@Q248DY@8HaP0648@DYAS6:DY6
<DYB0Tic00=6<DYBCW<00Tic0dYB0dic0U:D00U>LdYBAS5:DTicDYA>Le:D
CW<00TYB0Tic00ABU4icCW=>L`=BU0=F]@9BU003CW=BU5:D009BU004BU9>
LeJeF]H2E[D2DY@00e[FE[EF]@03E[D3DY@4F]H00eJeDYABU003DY@2CW<2
DY@03EJeDYABU4icDYAJeUJeDYA>Le:DE[EJeUJe00=BU003F]IF]E[F00AJ
eP9F]@IJeP9F]@05G_MJeUkgG_MS6002F]H015:DE[EJeU[F0eJe0U[F0UJe
0Ukg00MJeUJeDYABU5JeDYAF]@03DY@3E[D6F]H2E[D2DY@2CW<2DY@00eJe
F]IBU005E[D015[FE[EF]EJe0U:D00=F]E[FF]H00U[F0UJe0U[F0e:D00EF
]E[FF]IJeUJe00=JeP=F]@9JeP03E[EJeU[F00=Nm`04F]IF]E[FF]H2G_L2
F]H3G_L00eJeF]IF]@03F]H2G_L01U[FE[EJeUJeDYAJeP=Nm`03F]INmf<H
009JeP5Nm`5F]@4mk`0010@Q00D000@Q12448@Q200848@0:248aS6]JDY@]
JcF]?Nm244YB@Q02?Nl01D8@BU9:DU:DBU800THa00<mkd8@@Q000T8@0THa
0T8@00LicSg_?Nm244Ha@Q16<@02BU800dHa@Q16<@03BU8014HaBU9:DTYB
0THa00Hmkd8@?Nm243g_=Jd2>Lh0148@BU96<DYB1DHa00A:DTicBU96<@8m
k`96<@03@Q16<Cg_008mk`0==JdaS3F]>LhmkdHa=JdYBQcW5:DLiaBU48@0
0PaS00D@Q0aS36<<Ha2400<<H`8@Q0045:D@Q12436<348@021S67>LU:C6<
:DXDY@Q2124536<32483124010Q21248@PQ21@aS00<8@PaS36<00PaS0QBU
00P<H`@Q12448@aS248<H`@Q0PaS00<@Q1BU36<01@Q200<48@Q224800P@Q
00@@Q1cW:DXLi`88@P0<36<8@PaS36<@Q1S67>L@Q0aS1248@PaS0`Q200L@
Q248;F/YBRDY6<HLi`02>Lh01F<HMkeBU4Ha6<H00PaS0P@Q00@<Ha2436<8
@P848@<8@P031248@PaS008<H`P8@P8<H`0;48@<H`Q248@LibU:8@P@Q0Q2
36<@Q00236<01A2436<8@P@Q24800PaS00H@Q1S65:D<H`Q248@27>L011BU
1248@Q240aBU00@@Q1BU48@@Q08<H`03248<H`aS00@<H`065:D<HaBU;F]2
46Li0Ukg00AS63F]:DX@Q0<<H`<8@P031248@P@Q00L8@P8<H`D8@P8<H`D@
Q08<H`045:DLia2436<2248010aS1248@PQ20PaS0PQ20P@Q00<8@P@Q1240
0P@Q10Q200<000@Q12400P@Q00<8@P@Q24800PQ22`@Q00<000@Q12402P@Q
00@8@PaS5:DHaP<DY@03:DXicU:D009:DP03DYA>Ldic00A:DP07CW=BU5:D
DYA>LdYBCW<00TYB00M>Le:DDYA>Le:DBU9BU003BU8014icDYABU4ic0U:D
00EF]E:DDYABU4ic009BU004E[E>LdicCW<3DY@3E[D015:DE[EF]E:D0UJe
0U:D00A>Le:DF]IF]@9JePQBU003E[EBU5:D009BU005E[EBU4icDYAF]@04
DY@2F]H015:DE[EBU5:D15[F00EF]E[FF]IJeUJe00AJeP04E[EJeUJeF]H2
G_L4F]H00eJeF]IJeP03E[D00e[FE[EF]@02E[D2F]H00eJeCW=BU002E[D4
DY@00eJeDYAF]@03F]H00eJeF]IJeP02E[D4DY@2CW<2DY@00eJeF]IF]@03
F]H00eJeF]IJeP03E[D3F]H2DY@2E[D00e[FE[EF]@02DY@025[FE[EJeU[F
DYAF]E[FE[D4F]H015kgF]IJeU[F0ekg0U[F00=Nme[FF]H00U[F0Ukg0U[F
0ekg0e[F00INmf<HHaQNme[FE[D2F]H015kgHaQJeU[F0Ukg00AJeUJeF]IF
]@5240000P@Q00<000@Q12400`@Q00d8@P00124<Hc6<JeY>LbU:=Jdmkd8@
BU96<@02?Nl00d8@AS5>L`02CW<014Ha@Q1243g_0d8@0dHa00Q243W>=Jdm
kd8@AS5244Ha0TYB00=6<D8@AS400dYB0THa0TYB0THa00<mkcW>?Nl00T8@
00DicSF]=JdmkdHa00=:DP08@Q16<D8@@Q1:DTicBU96<@E24008?Nm243g_
?Nle[C6<=JdicP924003=JdYBQcW008HaP035:D@Q0aS00H<H`8@Q08<H`03
48@DYABU00<@Q0085:D@Q1S67>LU:Be[8@P@Q088@P0336<@Q0aS00@8@PH4
8@05248<H`Q236<@Q00636<348@00`aS24848@0224801@aS2488@PQ236<0
0Q240PaS1@Q200P48@Q212448ABU9BTYBQcW0PQ200<<H`Q236<00Q240QS6
0Q2400P48@Q22488@PaS248@Q1cW0RU:00dU:AS67>LicSg_IcUg_E:D?NlD
Y@Q236<48@0224800`aS48@<H`05248212401@aS48@<H`Q212400PQ200@<
H`Q2124<H`<@Q00836<8@PaS7>LU:AcW36<8@P8@Q005248<H`aS36<8@P02
12402`aS48@@Q1BU6<H<H`Q248@HaQcW5:D00PQ20Q240aBU0Q240PaS00<8
@PaS36<01@aS00`@Q0aS5:DaS48@JeYS65[FE[DaS2DY48@236<224801P@Q
2488@P@Q24848@88@P@48@H8@P<<H`8@Q00=5:D@Q124248<HaBU6<HDY@aS
248<H`Q212400PQ200<<H`Q224800`Q21P@Q00D8@P@Q12448@Q200848@06
24848@Q224848@Q22@@Q00<000@Q124030@Q00<<Ha245:D00QS600D@Q1S6
;F/e[E:D009:DP=>L`=:DPM>L`=:DP9>L`9BU005BU9>LdicCW=:DP02CW<0
0e:DCW=BU003DY@00eJeDYABU005DY@3CW<01E:DE[EF]EJeDY@00UJe00AB
U5JeE[EJePABU006E[EJeUJeE[EBU4ic0e:D00E>Le:DDYABU5Je00UBU003
CW=BU5Je00=F]@9BU0=F]@MJeP03E[EJeU[F009JeP03E[EJeU[F00=Nm`9J
eP03E[EJeU[F00=JeP03E[EJeU[F009BU003F]INme[F00ABU005E[EBU5:D
CW=BU003E[D2F]H01EJeF]IF]E[FE[D00U:D00MF]E:DDYABU4icE[EBU002
E[D3F]H01eJeF]IJeU[FE[EBU5Je00=JeP05E[EBU5JeE[EJeP02E[D2DY@0
0eJeF]IF]@06E[D2F]H00ekgF]IJeP0<F]H2G_L3F]H2G_L4F]H016<HG_MN
me[F0UJe00EJeUkgG_MNmeJe009Nm`AJeP52400000H000@Q124000@Q0002
12402@Q2124000aS=Jeg_E[F;F/e[@02?Nl4@Q000dHaBU9:DP02CW<014Ha
@Q0icSg_0d8@0THa0Sg_00=244HaAS400d8@00A:DTicBU96<@924003AS5:
DTHa00=:DPA24004?NlicSg_>Lh2<H`013F]@Q16<DYB1DHa00=243g_@Q00
1DHa00<icSF]?Nl00THa00XicRe[;F/mkdHa@Q0e[BDY6<HLi`8HaP055:D@
Q12448@DY@0248@236<00`Q248@@Q00236<01@Q236<@Q1245:D00Q2400PD
YAcW7>LQ21S65:D@Q0aS0PQ200<<H`Q2248010Q200@48@Q224848@88@P04
36<8@PQ21243248236<01A245:D@Q12424800`@Q1@Q21@aS0PQ20PaS00D8
@PaS2488@PaS008DY@0448@8@PQ236<424825:D02a2436<48@Q236<8@Q24
36<HaR48<H`00T8@00A6<DYB;F/YBP8aS005E[EcW5:D:DX8@P02124010aS
2488@PQ20`@Q00<8@P@Q12400PQ200<<H`Q224800PaS0Q240PaS0PQ20`aS
0PQ200<@Q1BU5:D00Q2400@DYA2436<<H`<@Q00936<8@PQ25:DQ21cW5:D<
HaBU008HaP8DY@L@Q0045:D@Q12436<2248020aS48@@Q0aS48@<HaS6;F/2
>Lh02c6<9BTYBTHaDYA[FW>L>LhQ20Q212400PaS0`@Q0PQ20P@Q10Q200<4
8@Q224800`Q21@aS00D@Q1S65:D@Q0Q2008<H`H8@P848@0436<DYABU36<2
124010Q212448@@Q0`Q20P@Q00<8@P@Q12400P@Q10Q200@48@Q212448@88
@P0336<8@P@Q00/48@0324848@@Q00<48@04248@Q1S66<H248@02AcW;F]:
DTYBCW=BU4YBDYA>L`02BU800dHaBU9>L`03CW<01DYBDYA>LdicBU800Tic
0e:D0Tic0TYB0Tic00EBU4icDYABU5Je009BU09>L`MBU09>L`03DYAF]EJe
00=F]@05DYA>Le:DDYA>L`02DY@2E[D00e:DE[EF]@02DY@3E[D6DY@2F]H3
DY@02eJeDYABU5:DE[EJeUJeDYAF]E:DE[D00e[F00=F]E[FF]H00U[F00EF
]E[FF]IJeUkg00=F]@aJePEF]@06F]IF]EJeE[EBU5Je1e:D0UJe00=JeUJe
F]H00eJe0e:D00=F]E:DDY@00TYB00=>LeJeF]H00eJe0U[F0UJe0e[F15Je
00=BU5JeE[D00eJe00=JeUJeE[D00U:D0eJe00=BU5JeE[D00U[F00ENme[F
F]IJeUkg009JeP07E[EJeU[FF]INme[FE[D015[F0ekg00=S65kgF]H00U[F
0Ukg00AS65kgG_MNm`=JeP9F]@03G_MJeU[F009JeP5Nm`5F]@4mk`0000<4
8@00124020@Q00D<HcF]LiaF]Be[008icP03?Nm243g_008mk`96<@05BU9>
Le:DAS524002>Lh00d8@?Nm24003@Q02?Nl2AS43@Q001dYBCW=:DTHa?Nm6
<DYB0096<@03BU9>LdHa00924003AS5243g_00<icP8aS008=JdmkdYBAS5:
DT8@AS5:DP=24003?Nm244Ha00=6<@06>Lhe[CW>AS4mkcF]0Re[00@mkdYB
@Q0aS08Li`038@PLiaS600<DY@0348@<Ha2400<<H`8@Q08<H`03248<H`aS
00<@Q0075:D<HaBU7>LU:AcW5:D00Q240`aS0`Q20PaS0PQ210@Q2@Q20`aS
0QBU00<<H`Q212400PQ200<48@Q224800PQ20PaS00<@Q0aS12400PQ20`aS
00L8@P@Q124<Ha245:D@Q004248336<011BU6<H@Q0aS0P@Q01D8@PaS48@<
HaS69BT]Jd8@?Nm244Ha;F/U:Be[<HaJeWNmBU8YBP@Q00000`Q200<48@Q2
12400PQ20`@Q00<8@P@Q12400PQ20`aS00@@Q0aS36<<H`<8@P0436<8@PaS
36<35:D248@336<248@236<01PQ248@DYAS67>LDY@8@Q08DY@036<HDYA24
00<<H`<DY@8@Q08<H`88@P@<H`0748@DYAcW<H`icSF]<H`00RU:00e>Le:D
JeY[FS6<8@P8@P@Q24848@Q21248@P05124324800`@Q2488@P04248436<3
5:D01A24248<Ha2436<00PQ200T<H`Q212448@Q236<DYA2436<00P@Q00H8
@P@Q12448@Q236<32484124010Q212448@@Q0PQ20`@Q0PaS00<8@P@Q1240
3`@Q00@000Q236<@Q08HaP0536<@Q1cW;F]>L`02BU801DicBU9>LdicBU80
0THa00E:DTicBU9>LdYB00A>L`04BU9>Le:DDY@3CW<01DYBCW=:DTicDY@0
0Tic3e:D00E>Le:DDYAF]E[F009F]@ABU00;CW=BU5:DE[EBU5JeDYAF]E:D
E[EBU002E[D4DY@00dicDYAF]@02E[D2DY@015JeDYABU5:D15Je00EBU5Je
E[EF]E[F00=F]@03F]INme[F009F]@03F]INme[F00=F]@03F]INme[F00=J
eP9F]@04F]INme[FF]H6E[D00e[FE[EBU004DY@00dicDYAF]@02DY@015Je
F]IF]E[F0UJe00=BU5JeDY@015:D0dic0U:D00EF]E[FE[EJeUJe009JeP05
E[EJeUJeE[EJeP02E[D2DY@00eJeF]IF]@05E[D01E:DE[EF]E[FE[D00U:D
00MF]E[FG_MJeUkgF]INm`04F]H015JeF]IJeUkg0U[F00EF]E[FF]INme[F
009Nm`03HaQNme[F009JeP=Nm`07F]INme[FG_MF]E[FE[D00e[F00ENme[F
F]INmeJe004mk`000P@Q00D000@Q12448@000088@P0700048@aS=Jeg_EJe
=Jd00T8@0Sg_00=244Ha@Q000T8@00=6<E:DBU800T8@00DaS3F]>LhmkdHa
00924004?Nm2448@AS43BU82AS401DYBAS5243g_>Lh00THa14YB00=6<D8@
@Q000Sg_0SW>00@e[CW>=JdaS08icP03@Q16<DHa0096<@9240<icP0B?Nm6
<DYB@Q0mkcW>?Nm6<CW>:DXe[D8@F]IF]CF]7>LDY@aS0acW00<DYA2436<0
0QBU00L<HaBU7>LHaQBU36<8@P0248@00`aS48@<H`0348@65:D248@236<0
0`Q236<8@P0624800`@Q2488@P0:248436<0112436<<H`aS0PQ200L48@Q2
36<8@PaS48@<H`0224800`@Q2488@P03248020aS48@@Q0aS248<Ha2436<2
248336<010Q2124<H`aS0QBU0PaS00TDYAS6=Je6<EJeKg][FVmkIcT00U:D
00<]JacW9BT00SW>00/Li`@Q12448@Q21248@P@Q24848@Q200L48@88@P05
36<@Q0aS48@DY@0236<01PQ236<<H`aS48@HaP8Li`0;6<H@Q0aS1248@Q24
5:DLiaS648@DY@036<H020aS248@Q1S67>LDYA247>L28@P0112436<<H`aS
0a240PaS0PQ2010<Ha245:D@Q1BU7>Le[DYBCW=JeU:DAS5>LbU:7>Le[@9F
]@04=Jd8@P@Q36<22484124010Q21248@PQ20P@Q00@8@P@Q248<H`88@P05
36<8@PQ248@<H`0248@00`aS248@Q00248@00`aS2488@P02124010Q21240
00aS0QBU00<<H`@Q24800PaS00<8@PaS24800PQ21@@Q00<8@P@Q24800PQ2
30@Q00<000@Q124030@Q0PQ200P<Ha2436<<HaS69BU244Ha0U:D00I:DU:D
BU9:DTHaBU82CW<2DY@2CW<2DY@01dicAS56<DicDYAF]E:D009:DP0<AS5:
DTYBBU9>Le:DCW=F]E:DCW=BU4ic15:D0U[F0UJe00=>Le:DE[D00UJe00AB
U5JeDYAF]@MBU0=F]@=BU0AF]@9BU005CW=BU5:DDYAF]@02DY@2E[D00dic
DYABU002F]H00eJeDYABU002DY@2E[D4F]H00eJeF]IF]@03F]H00ekgF]IJ
eP03E[D2F]H4E[D2F]H00ekgF]IBU005E[D2DY@01EJeDYABU5:DCW<00UJe
0U:D00E>LeJeF]INme[F009F]@05CW=BU4icDYA>L`04DY@00dicDYABU002
DY@025JeDYAJeU[FDYAF]E:DE[D2DY@2F]H4E[D01E:DE[EF]E[FE[D00e:D
1eJe15[F00EF]E[FF]IF]E:D00AJeP03E[EJeU[F00=JeP03G_MJeUkg00=N
m`03F]INme[F009JeP9Nm`9JeP03E[EBU5Je009JeP06G_MJeU[FG_MS65kg
0D8@00001@0012448@@Q00001P@Q00H<HcF]LiaF]CF]@Q03?Nl2@Q02?Nl0
2DHaBU9>Ldic@Q0mkcF]<H`icP03@Q02>Lh00cg_@Q16<@03BU82@Q000dYB
AS56<@02?Nl0148@AS56<Dic0TYB0T8@00=6<Cg_>Lh00SW>00@mkcF]<H`e
[@<mk`04@Q16<DYBBU82@Q003cW>=Jdmkcg_AS5:DTHa?Nle[CW>AS4icRU:
=Je24002F]H02Re[7>LDYA247>LQ21S65:D@Q0aS0a2400@DYAS67>LDY@8<
H`0848@<H`aS248<Ha2436<@Q0<DY@0448@DYA2448@436<010Q236<<H`aS
0`Q200@48@Q224848@@8@P031248@PQ20088@PD<H`8@Q08<H`031248@PQ2
0088@P0836<@Q12436<8@P@Q248<H`<8@P0336<@Q0aS00D<H`03248<H`Q2
00<<H`<8@P<@Q00836<8@QBU6<HaS4YBDYA_N`9[FP06HaQ>Le:D;F/HaRDY
0Sg_00<Q20@Q12400`@Q00H8@P@Q1248@P@Q24841243248236<0412436<@
Q12436<8@PaS248<H`Q248@HaQcW8@PHaPaS0PQ200X48ABU6<HLiaS65:DH
aQcW6<HDY@8<H`095:DLiacW48@DYAcW8@PHaQ2400<<H`8@Q00536<@Q0aS
24848@0236<02ABU48@HaR48>Li6<DicE[EBU002BU801RU:6<He[E[FE[De
[@848@@8@P<48@88@P848@0324848@@Q00<8@P0436<8@PQ2248236<248@4
36<248@00`Q21248@P0236<01`Q212448@aS5:DHaQ2400848@0336<8@PaS
0088@P041248@P@Q2484124524841242248312402@0012448@@Q24848@00
124000061242248010@Q248@Q1240PaS00@HaRDY@Q1:DP9>L`9:DP05CW=:
DTYBAS5>L`02DY@014icBU9>Le:D0Tic0THa00I>Le:DDYABU4YBAS43BU83
CW<01E:DCW=F]E:DCW<01E:D00EF]E[FF]IBU4ic00=BU003E[EJeU:D009F
]@=BU005CW=BU5:DDYAJeP02E[D2DY@2E[D2F]H015JeDYABU4ic0U:D00UF
]E:DE[EBU5JeDYA>Le:DE[D00U[F00IF]E:DE[EBU5JeDY@2E[D01E[FG_MF
]E[FDY@00U[F00=F]EkgF]H015Je15[F0UJe00=BU5[FG_L00U[F00=F]E:D
E[D00eJe00=BU5JeDY@00U:D0Tic00=BU5JeDY@00e:D0e[F0UJe0U:D0Tic
15:D00=>Le:DDY@015:D00IJeUJeE[EF]E:DF]H:E[D2DY@00eJeDYABU002
DY@00eJeF]IF]@02E[D00e:DF]IJeP02F]H00eJeF]IJeP04E[D7F]H00ekg
F]IJeP02F]H4G_L3F]H3G_L00e[FE[EBU002E[D5F]H00ekgHaQJeP01@Q00
0004124000@Q0004124020Q2124000aS=JecW5[F>Lh2AS42@Q02?Nl033F]
>Lhmkd8@CW=:DTHa@Q0e[CW>?Nm24096<@08?NlicSg_?Nm244YBCW=6<@92
4096<@03@Q0mkcg_0096<@07CW=:DTYBBU9>LdYB@Q000SW>1Cg_00He[C6<
=JdicT8@?Nl4AS401Sg_>Lhe[C6<>Lhmk`=6<@09?NlicS6<:DXicTYBAS4i
cQcW008HaP055:D@Q1S67>LDY@0236<011245:D<HaS60RDY00HLia245:DH
aQ2436<2248348@236<011245:DDYA240PaS00<8@PaS48@00aBU0PaS0PQ2
00D<H`Q22488@P@Q00H8@P8<H`88@P0336<8@PaS008<H`8DY@036<H@Q0aS
008<H`0348@DYA2400<8@P031248@PQ2008<H`<8@P<<H`035:D@Q1240088
@P0536<8@PQ224848@02248336<04PQ25:DHaSW>G_M[FW_NKg]g_G_NMke[
FT8@>LhLiaBU36<8@P<48@0400048@@Q248:1242248636<00a2436<<H`03
48@35:D01@aS2488@PQ236<00Q2400<DYA245:D00QS60QBU00@<Ha245:DH
aP8Q208Li`068@PYBRDY7>L@Q0Q21@aS00@DYAS648@@Q08<H`09;F/icUJe
Lia_NgooLia[FUkg009:DP03:DXHaQS6008YBP0348@48@000088@P031248
@P@Q0088@P<48@88@P031248@PQ2008<H`<8@P0536<8@PQ236<8@P0336<0
0a2436<8@P0324801PaS24848@Q236<@Q0<<H`8@Q08<H`H8@P<48@<8@P03
1248@PQ201X48@88@P8<H`8DY@096<He[Cg_E[EBU4YBDYA:DTHa009:DP=>
L`03BU9>Ldic009>L`06DYA>LdYBBU9>Le:D0Tic0U:D0dHa00I:DUJeDYA>
LdYBCW<2DY@01UJeCW=BU5:DE[EJeP9F]@9BU09F]@9BU0=F]@9BU003CW=B
U5:D009BU0=F]@0;DYA>LeJeF]IF]E:DE[E>Le:DCW=:DP02DY@3E[D4DY@4
E[D01U[FE[EF]E:DE[EBU09JeP04E[EJeUJeE[D2DY@2E[D015[FE[EJeU:D
0UJe0U[F0UJe00=BU5JeF]H00UJe00AJeUJeE[EBU0=F]@9BU09F]@07DYA>
LdicCW=:DU:DE[D00U[F00ABU5JeE[EF]@=BU09>L`08DYA>Le:DCW=BU5Je
G_MF]@=BU09JeP04E[EBU5:DE[D4DY@00eJeF]IJeP02F]H4E[D2DY@014ic
E[EJeU[F1eJe0e[F0eJe0e[F00ANme[FG_MNm`=JeP=Nm`03F]INme[F009N
m`9JePEF]@05DYAF]E[FF]IF]@02F]H3G_L1HaP1E[D1AS40000300048@@Q
00848@0300048@@Q00<48@0536<e[GNmE[DicP02AS40148@?Nlmkcg_0cW>
00=244icDY@00T8@0SF]0T8@0THa00E243W>>LhicSg_00=:DP03AS4mkd8@
0096<@03@Q0mkd8@009:DP07CW=6<DYBDYA6<D8@>Lh01Cg_00dicSF]=Jda
S3W>?Nm244Ha@Q16<DYB?NlicP02<H`03CW>?Nm244Ha@Q0icSg_<H`YBSW>
BU9243F]008HaP097>L@Q1BU5:DHaQBU48@<Ha24008DY@0?7>LU:B486<H@
Q1BU6<H@Q0aS248<Ha2436<@Q0aS00D@Q0@<H`045:D@Q1BU5:D236<52480
0`@Q2488@P07248236<424800`aS5:DDY@025:D2248010aS48@DYABU1@Q2
00<<H`Q224800`Q200<<H`Q248@00Q2400<<H`Q224800PQ200<<H`@Q1240
0PQ20PaS0PQ2010HaQcW?NmJeV]JNmi_NgNmOomcW6]J?Nle[AS65:D<H`88
@P0300048@@Q0088@P848@0524848@@Q124000041242248236<01`Q236<@
Q12436<8@PaS008@Q0<DY@8@Q0041248@PQ2248248@26<H25:D011S65:DD
Y@aS0Q2400@DYB488@PQ208Li`06;F/U:AS648@<Ha240PaS00H8@PaS48@D
YA2436<248@00c6<>LiF]@02Kg/037_NMkeS65[FAS5:DRU:7>LHaRDY8@P@
Q0848@88@P848@0424848@00124324821246248336<224800`aS248<H`04
36<8248436<01A2436<@Q0Q236<010Q200D48@Q212448@Q200848@88@PX4
8@0400048@@Q000>124020Q248@<H`aS5:DLicF]?Nl2DY@01dYBCW=:DTYB
AS5:DU:D009>L`04BU9>LdicBU84CW<02TYBCW=BU5:DCW=BU4icBU96<DYB
0Tic00IBU4icCW=>Le:DE[D2DY@00dicDYAF]@02F]H015JeCW=F]EJe0U:D
0UJe00IJeUJeDYABU4icDY@2CW<01EJeF]IF]E:DCW<00UJe0U:D0UJe00=B
U4icCW<015:D00EF]E:DDYA>Le:D00AF]@05F]IF]E[FDYAF]@02DY@01UJe
F]IJeU[FE[EBU0AF]@9JeP9F]@04DYAF]E[FG_L2E[D01e:DF]IF]E[FE[EJ
eU:D00AF]@9BU003E[EJeU:D00E>L`03DYAF]EJe00EF]@04DYA>Le:DDY@2
CW<015:DCW=:DU:D0e[F00IBU4icE[EF]E[FE[D3DY@015JeDYABU5:D0UJe
0U[F00=F]E:DE[D00UJe00ABU4icDYABU09JePEF]@04F]IF]EJeF]H3E[D>
F]H015kgF]INmekg0e[F0UJe00=JeUJeE[D00UJe00=JeUJeF]H00U[F0ekg
0F<H0E[F0D8@000212400`0012448@03124020Q200048@Q2=JecW5Je>Lh3
BU82@Q001SW>=JdicSW>?Nm6<@9:DP05@Q0icSg_?NlicP02?Nl02D8@AS52
43g_>Li244HaBU96<@03@Q001Cg_@Q0mkcg_AS400Tic0TYB00I>LdYB@Q0i
cSg_AS43@Q03?Nl013F]>Lhe[Cg_0T8@00A6<D8@?Nm240<icP06AS5:DTic
AS4icS6<0SF]0Sg_00H]JacW5:DDYAS648@936<00aBU48@DY@0248@35:D2
36<348@236<2248448@236<011245:DDYCF]0THa00<icPaS24800P@Q00@<
H`Q224848@@8@P8<H`05248<Ha2448@<H`0224801`aS48@<HaBU48@DYA24
008<H`@8@P041248@PQ236<4248010@Q36<<Ha240`aS00D@Q0aS36<8@P@Q
00H8@P0936<8@QBU6<H]JdYBF]Ig_Fmk00AkgP05?Nl]J`aS248<H`02248?
1246248236<248@236<00`Q236<<H`0448@01@aS2488@PaS24800PaS00D8
@PaS48@@Q1BU008@Q0035:DQ22U:008aS00>9BTQ22DY9BTaS3F]9BTLi`aS
1248@PaS248@Q0<<H`0648@<Hbe[@Q1S67_N0g>L00EkgWooG_M>LacW00<@
Q0046<H<H`@Q124224800`@Q24848@05124010Q212448@@Q0`Q200D<H`Q2
12448@Q2008<H`03248<H`aS008@Q0<<H`<@Q08<H`<@Q0<<H`8@Q0@8@P8<
H`88@P@48@<8@PD48@88@P@48@0324848@@Q00848@0300048@@Q00D48@88
@P@48@8<H`8@Q0035:DYBS6<00I:DPU>L`9:DP9>L`03DYA>LdYB009BU006
E[EBU4icBU9244Ha0TYB0dic00EBU5JeDYABU4ic00MBU0IF]@04DYAJeUJe
DY@2CW<2DY@025JeDYABU5:DCW=BU5JeF]H3E[D01E[FDYA:DTicDY@00UJe
0U:D00EF]E[FG_MJeU:D009F]@9JeP03DYA>Le:D009JeP05E[EBU5:DF]IF
]@03DY@01e[FE[EF]EJeDYAF]E:D00=F]@05DYAF]E[FE[E>L`02DY@00e[F
E[EF]@02E[D00e:DE[EF]@03E[D01DicDYA>LdicDY@00UJe00UBU4icDYAB
U5JeDYAF]E:DCW<00U:D00I>Le:DDYAF]E:DE[D2DY@015JeDYAF]EJe0U:D
0UJe00MBU5JeDYABU5JeF]INm`02F]H2E[D2DY@:E[D00e[FE[EJeP03F]H0
15JeF]IJeUkg0U[F00=Nmf<HG_L015[F00ES65kgG_MF]E[F009Nm`9S6008
F]IF]EJeCW=F]E[FE[EJeP=F]@03F]INmekg009JeP9Nm`56<@0000D48@00
12448@0000H48@0736<aS7>LF]HmkdHaBU800THa00A243W>=Jde[@8icP9:
DP05AS5243W>>Lhmk`02>Lh02Sg_AS52448@>Lhmkd8@AS5:DTHa1D8@00/i
cSg_AS5>Le:DBU96<DicAS5243g_00=2408mk`07@Q0icSF]=JdicSg_>Lh0
0Sg_0T8@0Sg_00licSF]>Li6<DYBCW=6<CF];F/aS3F]@Q0mkbDY7>L00QBU
00<HaQBU36<00PaS0Q240`aS00<@Q1BU5:D00a240QBU00H@Q0aS48@@Q1BU
36<2248236<01a2436<<Ha245:D<Ha24008DY@04>Li:DSg_<H`324800`@Q
2488@P04248010@Q2488@PQ20PaS00<@Q0aS36<010aS00D@Q1S66<H@Q0aS
00P8@P0336<8@PQ200<8@P041248@PaS48@536<00`Q21248@P0212462480
1ABU6<He[DicG_L00W>L00YkgWNmMkeg_Cg_;F/<H`Q236<8@PD48@032484
8@@Q00P48@88@P0336<8@PaS00D<H`0448@<H`aS248236<248@436<00`Q2
36<8@P0336<248@04QBU6<H@Q1BU9BTYBSF]<H`Q21cW9BTYBS6<=JdU:AS6
48@48@88@P0336<@Q124008<H`0>5:D@Q2e[@Q1Nmg_NKg]g_G>LNmiooe[F
BU8HaP8@Q08DY@0436<48@@Q1242248312401@Q212448@Q212401`Q200<4
8@Q224800PQ20`aS00<8@PaS48@00Q240`aS0Q241PaS00@@Q0aS36<<H`<8
@P0336<8@PQ200H48@<8@P<48@88@PL48@0300048@@Q00@48@0324848@00
00L48@03248<Ha24008DY@04:DXaS4YBCW<5BU83CW<014YBCW=BU4ic0TYB
0Tic00IBU4icBU9:DTicE[D2DY@2BU800dHaBU9:DP02BU800dicDYABU00;
DY@03e[FE[EF]E:DE[EBU5JeDYAF]E:DCW=BU4icDYAF]@03DY@00dicDYAB
U005E[D3CW<01e:DE[EF]EJeDYAF]Ekg009JeP9BU09JeP05E[EBU5:DDYAJ
eP07E[D3DY@2E[D015[FDYABU5:D0UJe00ABU5JeDYAJeP9BU004CW=F]EJe
E[D2DY@015JeDYABU5:D0U[F15:D00=:DU:DE[D00U:D00I>Le:DE[EBU5Je
CW<3DY@01TicDYA>LeJeDYAF]@ABU09F]@03F]IBU5Je009BU005E[EBU5:D
DYAF]@04F]H01UJeDYAF]E:DE[EBU0]F]@08F]INme[FF]IF]E[FG_MJePEN
m`05F]IF]EkgG_MS6004F]H01F<HG_MS65[FE[D00U:D00=F]E[FF]H015Je
00=JeUkgG_L00Ukg0F<H0E[F0DHa00000`0012448@0312403@001248@P@Q
0008@Re[MkeS63W>@Q0mkd8@009:DP05AS4mkcW><H`icP02@Q0014YBAS52
448@0cg_0SW>0T8@00e6<D8@@Q0mkd8@BU96<D8@?Nm244Ha@Q0mk`02@Q00
14HaBU9:DTYB148@00A6<D8@AS52408mk`03@Q0mkcW>008e[@04>Lhmkd8@
AS42?Nl2>Lh2@Q002DHaCW=>LcW>;F/YBS6<>LhaS0027>L00aBU36<<H`03
36<010Q236<<H`aS0PQ21@aS1a2400X<Ha2424848A246<HYBRDY7>LHaP8L
i`038@PU:BDY00@Q208U:@036<H@Q0Q200<48@03248<H`Q200@8@P0448@D
YABU48@424801PaS48@DYABU48@<H`<8@P031248@PQ20088@P0336<8@PQ2
00<8@P0336<8@Q24008<H`0948@<H`aS36<8@P@Q24848@aS008@Q088@P0?
36<LiaBU7>LaS4HaG_MF]F<HIcUBU4YB9BTLiaBU008@Q0D8@P031248@PaS
0088@P031248@P@Q00<48@D8@P<<H`05248<H`aS48@<H`02248010aS248@
Q1240`aS0PQ200<48@Q224800PQ20`aS0Q2400<DYBU:;F/00THa00@e[Be[
9BTYBP8aS0049BTHaPaS1242248336<01`Q236<@Q0aS9BTe[E:D009W>@0;
MkecW7_NNmi>Ld8@6<H@Q0aS248<H`082485124224800`@Q2488@P022480
0`@Q24848@0224801PaS248@Q1cW8@PDY@88@P8<H`03248<H`aS00@<H`07
48@DYA2436<8@P@Q36<00PQ200<<H`Q248@00PaS00<8@P@Q00000`@Q0PQ2
0P@Q10Q25`@Q00L8@PaS48@@Q1BU8@PYBP02AS400dYBCW=6<@03CW<00dYB
CW=>L`02DY@2CW<4BU85CW<3DY@2CW<2BU82DY@3CW<2DY@00eJeDYABU003
DY@01TicDYAF]E[FG_MF]@=BU003E[EJeUJe009>L`03DYAF]E[F009F]@IB
U09F]@03F]IF]E:D009BU0MF]@03G_MJeUJe009F]@9JeP09DYAF]E:DE[EJ
eU:DCW=F]E[F009F]@03DYAF]EJe00=F]@07DYAF]E:DCW=BU4icDY@00eJe
00=>Le:DDY@02UJe00AJeU:DDYA>L`9BU004E[EBU5:DCW<4DY@00eJeDYAB
U005DY@3E[D2F]H2E[D2DY@025JeDYAF]EJeDYAF]E:DE[D6F]H3E[D015:D
E[EJeUJe15[F0eJe00EBU5[FF]IJeUkg00AJeP04G_MJeU[FG_L2HaP00ekg
F]IJeP02G_L00f<HF]INm`02G_L2F]H00ekgF]IF]@02E[D015[FG_MJeU[F
0UJe1Ekg0FLi0Ekg0DYB00021240100012448@000P@Q00/8@P001248@S6<
LiaNmcW>@Q0mkdHa009:DP06@Q0icSW>=JdicSg_0dHa0T8@00@mkcW>?Nli
cP8mk`96<@05@Q0mkd8@AS5:DP02AS400cg_@Q124002@Q000cg_AS56<@03
AS43@Q001Sg_@Q1:DT8@?NlicP<mk`03>Lhe[CW>008icP@mk`8icP06?Nm6
<DHaCW=:DSF]0RU:00He[CW><H`LiaS65:D248@336<00`Q236<<H`0736<4
48@00`aS48@@Q00348@2248010aS6<HU:B480QS600<Lib488@P00b4800PL
ib488@PU:B486<H@Q0aS0P@Q00X8@P@Q248<H`Q21248@PaS48@DY@8@Q088
@P<<H`045:D@Q12448@424800`aS1248@P02248336<224801@@Q2488@PaS
48@01@aS0PQ20P@Q0Q2400/<H`Q2248<HacW6<HQ23F]BU9S65Je009S6004
DYA:DRDY7>L348@236<6248010@Q2488@P@Q0PQ20P@Q00D8@P@Q2488@PaS
00<8@P0336<8@PaS008<H`03248<H`Q2008<H`0348@<H`aS00@8@P051248
@PQ236<8@P0236<248@00aBU:DXaS002AS40136<;F/U:BU:0S6<00DU:AS6
48@8@P@Q00@<H`0;248@Q1BU48@U:CF]DYA[FVLiMkecW002Nmh01Dic?Nl@
Q12436<00`Q200<48@Q236<00PQ21P@Q00<8@P@Q12401PQ20`@Q0PQ200T<
HaBU7>LLiaBU36<8@PaS24800PaS00<8@PaS48@00`aS0Q2400@<H`Q2248<
H`@8@P0436<@Q0Q22486124010Q212448@@Q0`Q260@Q00L8@QBU48@@Q248
:DY6<@02BU802DicBU9:DTicBU9>LdYBCW=BU002CW<4BU800dicBU9>L`03
CW<015:DCW=BU5:D0dYB0Tic00=BU4icCW<00U:D00AF]E:DDYA>L`EBU09J
eP04E[EBU5:DDY@3E[D015:DCW=>Le:D0U[F0e:D00E>Le:DCW=BU5[F00=F
]@ABU0=F]@9BU0=JeP9F]@9JeP9F]@9BU09F]@9BU004E[EJeU[FE[D2DY@3
E[D015:DE[EBU5:D0Tic0U:D00EF]E[FDYABU4ic00=F]@03DYAF]EJe00MF
]@9BU004CW=BU5:DE[D2DY@014icDYABU5Je0e:D00AF]E:DCW=>L`EF]@04
F]IF]EJeDY@2E[D2DY@2E[D00e:DE[EBU002E[D01E[FG_MJeUJeF]H00U:D
0UJe00EJeUJeE[EJeUJe009JeP04DYAF]EJeE[D9F]H3G_L01V<HG_MJeU[F
G_MS609Nm`06F]INme[FF]INme[F15Je0e[F0UJe0U[F00INmf<HG_MNmf<H
F]H1BU8000<48@0300048@@Q00848@0:24848@@Q248e[G_NF]He[D8@BU82
@Q03BU801T8@?Nm243g_>Lhmk`=24007?Nm6<D8@@Q0mkd8@AS400TYB00M6
<Cg_@Q1244icBU96<@03?Nl2@Q02?Nl01d8@BU92448@AS4mkd8@00Dmk`07
@Q16<CW>>Lhe[CW>?Nl00SW>00=243W>=Jd00SF]00m243g_>Lhmkd8@>Lha
S2e[>Lh]JacW48@HaQcW6<H00`aS0`Q200H48@Q2248<Ha245:D248@01PaS
48@<Ha246<HDY@8Li`0436<8@P@Q24825:D05AS65:DHaR48<Ha:DTicE[EB
U4YBE[D]JaBU6<HaS4ic>LhDY@@Q24848@0224801@@Q248<Ha2436<00Q24
0`aS0PQ20PaS00<@Q0aS5:D00aBU00@8@PaS36<<H`<8@P<48@88@P<<H`88
@P8@Q0035:D@Q0aS00848@<8@P0D36<8@PQ236<DYAS636<DYC6<DYAkgV]J
BU8mkacW8@PLiaS65:D<H`<8@P0336<8@PaS0088@P031248@P@Q0088@P03
1248@PQ200<8@P041248@PQ236<324801`aS248<H`aS48@<H`Q200H<H`D8
@P041248@PQ236<224801@aS48@Q22DY<H`00cW>00E245:DCW=6<BDY008D
Y@<8@P8<H`88@P0:48@HaQS67>LQ23W>CW=JeVLiE[D2DY@01S6<9BTDYABU
48@<H`88@P8<H`03248<H`Q200@48@0324848@@Q0088@P0736<8@PaS2484
8@Q212400PQ200<48@Q22480112400<<H`Q224800PQ200D48@Q22488@PaS
00<@Q00336<8@PaS00H8@P8<H`0324848@@Q00848@0524848@001248@P02
36<3248H124010Q236<DYA240QcW00DicT8@CW=>LdHa009:DP9>L`04DYA>
LdicCW<4BU85CW<00dYBCW=BU003DY@01DicBU9>LdicE[D015:D00EF]E[F
E[EF]Dic00=BU09F]@9JeP9F]@03DYAF]EJe009F]@9>L`04DYAF]EJeDY@2
E[D2DY@014icDYABU5:D15Je0U[F00=F]E:DDY@00UJe00=JeUJeDY@00eJe
00EBU5JeDYABU5[F009F]@05DYA>Le:DE[EJeP03DY@01EJeF]IF]E:DE[D0
0e:D00=:DU:DDY@00UJe0U:D00=>Le:DCW<00U:D0UJe0U[F00=F]E[FE[D0
0UJe0U:D00=>LeJeE[D015:D0UJe0e:D0eJe15:D00=JeUJeE[D00U[F0UJe
00ABU5JeE[EJeP=BU003F]IF]EJe009BU005E[EJeUkgG_MJeP07E[D6F]H3
E[D5F]H015JeF]IJeU[F1Ekg00AJeUkgG_MS609JeP04E[EJeU[FG_L2HaP0
0ekgF]IJeP04F]H015:DE[EJeUJe0U[F00=Nmf<HG_L00D8@00000`@Q0004
8@0212400`0012448@0312401`aS=Jeg_E[F<Ha244YB00I6<@@icP96<@92
4003?Nm244Ha00=24004AS5:DTHaAS42@Q000dHaBU9:DP02@Q001SW>@Q16
<Cg_>Lhmk`M24003?NlicSg_008mk`9240@icP8mk`03>LhmkcW>008e[@03
>LhmkcW>008icP0>@Q0icRe[;F/icRU:7>L@Q1BU7>LDY@aS248<H`@8@P04
1248@PaS48@25:D236<00a2436<@Q0036<H00aBU36<8@P0224825:D04QS6
5:DHaR48<Ha:DTicE[E>LdYBDY@YBQBU7>Le[DYB>LhDY@<48@D8@PL<H`03
248<H`aS008@Q00836<DYABU5:D@Q0aS248<H`<8@P<48@88@P0336<8@PaS
00@<H`<@Q00436<48@Q2124424804`@Q36<DYAcW36<@Q36<E[EoofLi@Q0i
cQcW8@PHaQBU36<@Q0aS0088@P0736<@Q0aS24848@Q212400`Q210@Q00<8
@P@Q248020Q20PaS00@@Q0aS36<8@P8<H`03248<H`Q200@8@P061248@PQ2
248<H`Q20PaS00<DYB489BT00SF]00TmkcW>@Q1BU4ic?NlQ21BU48@00`Q2
00H<H`Q2124<HaBU8@P26<H02R48>LiBU5[FHaQJeU:DE[DaS2DY0a2400<<
H`Q224800`aS00<8@P@Q124010@Q00<8@P@Q248020Q20P@Q0`Q200@<HaBU
48@<H`88@P0336<8@P@Q0088@P0536<8@PaS36<@Q00236<010Q236<<H`aS
10Q20PaS0PQ200<000@Q124010@Q00@8@PaS48@8@P/48@0300048@@Q00`4
8@04248<HaBU48@27>L01SW>@Q1>Le:DAS5:DPE>L`I:DP9>L`04DYA>LdYB
BU82CW<015:DE[EBU4ic0TYB0e:D0Tic00EBU5[FF]IF]E:D009>L`9BU005
E[EJeU[FF]IF]@04DY@015JeDYABU4ic0U:D0UJe1E:D00E>Le:DDYAJeUJe
009BU0=F]@03DYAF]EJe009F]@=BU003E[EBU5Je009BU004F]IF]EJeE[D2
DY@4E[D015:DE[EF]EJe0e:D0UJe0dic00MBU5JeE[EBU4icDYA>L`03DY@0
0eJeDYAJeP02F]H4E[D6DY@00eJeDYAF]@03DY@00dicE[EF]@02E[D01Tic
DYABU5:DE[EJeP9F]@03F]IF]EJe00AF]@03DYAF]E:D009F]@=BU004E[EN
mekgF]H4E[D00e[FDYAF]@02E[D3F]H015JeF]IF]EJe0e[F00=Nme[FF]H0
0UJe00AJeUkgF]IS60=Nm`9JeP03G_MS65[F00AJeP05G_MS65kgG_MF]@02
F]H015kgF]IF]E:D0UJe0e[F00=Nmf<HF]H00DHa00000`00124000051240
2@Q2124000aS>Lig_E:D;F/mk`02BU84@Q02AS401Cg_>Lhmkcg_>Lh00T8@
0THa00E243g_@Q0mkd8@009:DP06AS52448@AS5:DTic0dHa00Dmkd8@?Nlm
kd8@009:DP924003AS5243g_008icP03@Q16<DYB009:DP03@Q0icSg_0092
4009>Lhe[CW>>Lhe[C6<>LhmkcF]00<aS00=>Lhe[CF]=JdLiaS648@DYAS6
5:D<H`@Q36<00PQ20PaS0`Q200<@Q1BU6<H00Q2400PDY@Q236<YBT8@=JdL
i`001@Q20Q2400<Q23W>DY@00Vmk00akgWNmJeYcW48@;F/HaPaS9BU244Ha
9BT312400`aS248<H`0236<01A2436<<H`aS24800PaS00<8@PaS48@00Q24
00LDYAS66<HHaPaS48@<H`0248@02@Q212448@@Q24848@Q236<8@P0236<0
1PQ248@HaQcW5:D<H`848@88@P0436<8@P@Q248336<040Q248@aS4icE[Dm
kaS67>LHaQBU8@PU:AcW5:D8@P@Q0PQ20`aS10@Q00@8@P@Q24848@88@P04
1248@PQ2248336<010Q236<8@PQ21@aS1Q240PaS0PQ200<<H`Q236<010aS
00@@Q1S67>LQ208YBP0:@Q1>LeJeE[DicSF]:DXQ21cW36<2248236<00`Q2
36<@Q00248@26<H03C6<HaQcW6]JAS4Lib487>LHaQ245:D<H`Q2008<H`07
48@<H`aS1248@P@Q248010@Q00@<H`Q22488@P<<H`0324848@Q20088@P<4
8@88@P<<H`08248<H`Q224848@Q236<8@P<<H`8@Q00336<8@PQ200<8@P84
8@0436<@Q12436<31242248212401PQ248@<H`Q21248@PL48@0300048@@Q
00@48@0424848@@Q1243248412400`aS48@HaP026<H02RU:>Li>Le:DBU96
<DYBCW=BU4ic24YB0Tic00MBU4icBU9:DTicDYAF]@02DY@3E[D2DY@02eJe
DYABU5:DF]IF]E:DCW=F]E:DCW<00U:D0U[F0e:D0UJe0e:D0UJe00ABU5Je
F]IF]@9BU003CW=BU5:D00=BU0=F]@05F]IBU5:DCW=F]@02F]H015:DCW=B
U5:D0U[F15:D1EJe0U:D00=F]E:DE[D00eJe00=BU5JeE[D00e:D00=>Le:D
CW<00Tic15:D00E>LeJeE[EF]E[F009F]@AJeP03E[EBU5Je009BU004CW=B
U5:DF]H2E[D2CW<2DY@2E[D00e:DE[EBU003DY@2F]H01EJeDYABU5:DE[D0
0e[F00=F]E:DE[D00e[F0U:D0eJe0U[F00=F]E[FE[D00e[F00AF]E[FF]IF
]@=JeP9Nm`04E[EJeU[FF]H2E[D6F]H00ekgHaQNm`02F]H2E[D00e[FG_MJ
eP03F]H00ekgHaQNm`06F]H00eJeF]IJeP02E[D2F]H1HaP1F]H1@Q0000@4
8@0500048@@Q1248@P0212401`aS>Lig_EJe;F/mkdYB0096<@924096<@92
40<icP05?Nm2448@@Q16<@05@Q002dHaBU96<D8@?Nm244icBU96<D8@?Nl0
0T8@0SW>00E244YBBU9243g_0096<@05?Nle[CW>?Nm6<@02BU800dHa?Nlm
k`04?Nl00cW>?Nle[@02<H`3=Jd2<H`01cF]>Lhe[C6<=JdLiaBU008@Q006
6<H@Q0aS24848@Q20PaS0PQ200D48A2448@HaQBU00<@Q08<H`04;F/mkcW>
7>L21242248236<04a2436<Q23W>CW=g_FmkMkecW6]JLi`icRe[6<H@Q2U:
@Q0mkb4800<48@0336<8@PQ200D<H`04248<H`aS248236<011245:D@Q1BU
0QS600@DYA2436<<H`8@Q00624848@@Q1248@P@Q0PQ20PaS00L8@PaS48@H
aQcW5:D8@P021247248236<01P@Q48@aS4icG_LicP8Li`8DY@078@PU:B48
5:D8@P@Q24800`aS0PQ210@Q00<8@P@Q24800P@Q0`Q200<<H`Q236<00`aS
0`Q20`aS1a2400@<H`Q22488@P8<H`0=248<H`aS248<Ha245:DLib48;F/Y
BT8@CW<00U[F00<mkc6<:DX00QcW0PaS0PQ201<<H`Q236<@Q1BU36<DYAS6
=Je[FW>LIcTmkaS68@PLiaS65:D@Q00636<01PQ236<8@PQ21248@P848@H8
@P8<H`88@P848@88@P<48@05248<H`aS248<H`0224800`@Q24848@022482
36<248@336<2248020@Q24848@@Q248@Q0aS248212400`Q212448@021243
36<00`Q212448@0?12400`Q212448@022482124010001248@PQ20QBU0QS6
00@]JcW>CW=>L`=:DP05CW=BU4icBU96<@06BU802DicDYA>LdicAS5:DTic
DYAF]@03DY@00eJeDYABU004DY@015JeF]IF]Dic0e:D0Tic00=F]E[FF]H0
15:D0UJe15:D00=F]E:DE[D00UJe00MBU4icCW=>Le:DE[EBU003E[D015[F
DYABU5:D0eJe0U:D00M>LeJeE[EF]E:DCW=BU003E[D00e[FE[EF]@04DY@3
E[D01U:DE[EBU5[FDYAF]@I>L`04DYAF]E:DCW<3DY@01E[FE[EF]E[FE[D0
0U[F15Je0e:D00E>Le:DE[EJeUJe009>L`03DYAF]EJe009F]@EBU09F]@04
F]IBU5:DDY@3E[D015[FE[EF]EJe0U[F00AF]E:DDYABU09F]@=JeP05E[EJ
eUJeE[EJeP05E[D00e[FG_MNm`03F]H015JeF]IF]E[F0UJe0e[F15kg2U[F
0ekg00=JeUJeF]H00U[F1UJe0U[F0F<H0EJe0D8@00000`0012448@031240
40001248@P00124<Hcg_Kg]:DRDY=Je:DT8@?NlicSg_0T8@00=6<D8@>Lh0
0SW>00@mkd8@@Q124096<@92408mk`03@Q16<D8@009240E6<@03@Q0mkcg_
00=24005AS5243g_?Nm24004?Nl01DHa?Nm2448@AS400TYB00=243g_>Lh0
0d8@00DicSF]>Lhe[CW>008aS0039BTQ23g_009:DP07?NlHaQBU48@DYAS6
48@00PQ200D<H`Q22488@PaS00<8@P0348@LiacW00<DY@0736<@Q2DY:DXL
ia2412401@Q20Q2400hQ23W>E[EkgW>LMkecW7NmOomF]CW>5:D<HaS60R48
00@HaPQ212448@88@P848@88@P0336<8@PQ20088@P8<H`D@Q0055:D@Q124
36<8@P0336<2248412402`Q236<<H`Q236<8@QBU7>LHaQ24248010@Q0PQ2
00@@Q1cW5:D<H`88@P0348@HaQS6008HaP<DY@036<HDYA2400<<H`03248<
H`aS008<H`0524848@Q224848@0324800`@Q24848@0324801PaS48@@Q0aS
248<H`88@P848@X<H`03248<H`aS00<<H`<8@P0536<LibDY9BTQ20027>L0
13W>AS5242e[0QS60R4800TLiaBU48@8@P@Q5:DU:B485:D00P@Q00<DYAS6
9BT00T8@00H]JacW48@HaQcW5:D336<010Q248@@Q1240`Q200@@Q1BU36<4
8@D8@P@<H`03248<H`aS0088@P031248@P@Q00<8@P0536<8@PaS248<H`02
24801P@Q2488@PQ236<8@P8DY@8HaP0536<8@PQ21248@P02124010aS5:DL
iacW0PaS00<8@P@Q24800P@Q1PQ20P@Q00<000@Q12402@@Q00<8@P@Q1240
20@Q00L8@PaS5:DDY@aS9BTaS002CW<01D8@BU9:DTYBCW<00TYB0Tic00=B
U4icBU800dYB00E>Le:DCW=>LdYB009>L`04E[EBU5JeF]H2E[D015:DE[EF
]Dic0e:D0UJe0e:D00=:DU:DE[D00U[F00=F]E:DDY@015:D00=F]E[FDY@0
0e:D0UJe0U:D00E>Le:DDYABU4ic00AF]@05DYA>LeJeE[EJeP02E[D2CW<2
DY@015JeF]IBU5Je0U:D00=>Le:DE[D00UJe00=BU4icDY@00UJe00aBU5Je
F]IJeUJeDYA>Le:DCW=BU4icBU82DY@01eJeDYABU4icDYAF]E[F00=F]@03
F]IF]E[F009JeP9F]@9BU003CW=BU5Je00=JeP=BU09F]@=BU006E[EBU5:D
E[EBU5Je0e:D00=F]E:DE[D00eJe00=BU5JeE[D00U[F00=BU5JeE[D00e[F
00ANme[FF]IF]@EJeP9F]@9JeP03E[EJeUJe00=JePAF]@EJeP03G_MJeU[F
00=F]@9JeP9Nm`04F]IF]EJeF]H2G_L2F]H00e:DE[EJeP03F]H015JeDYAF
]EJe0e[F0D8@000212400`001240000312402`Q212448@aS?NmcW4YB9BTi
cTHa@Q000cW>00I244HaAS4mkcW>?Nl2>Lh01T8@?Nm244YBAS52408mk`92
4005AS5243g_?Nm6<@02BU83@Q03?Nl01D8@AS52448@?Nl00d8@0SW>00@m
kd8@@Q124096<@9:DP06@Q0icSW>@Q16<D8@0cF]0SW>00T]JbU:8@PU:D8@
BU96<CW>5:D00Q2400DDYAS648@<H`Q2008<H`<8@P0436<48@aS48@26<H0
3ABU48@@Q1245:DQ22U:7>L<H`@Q248<H`@Q0088@P8@Q0058@Q245JeMkec
W002Mkd02g_NOomBU3g_5:D<HaS67>LU:ABU24800P@Q00@8@P@Q24848@88
@P0636<8@PaS248<H`Q20PaS0Q2400L<HaBU5:DDY@aS1248@P0236<00a24
36<8@P021242248336<224801PaS48@LiaS648@8@P848@0824848@Q2248D
YAS65:D<H`88@P055:DLiacW7>LHaP0248@01ABU6<HDYA2424800`aS00@8
@PaS36<<H`88@P848@X8@P<@Q088@P0336<8@PQ20088@PD<H`<@Q003248<
H`aS008<H`0;248<H`aS248<H`Q248@HaR489BTQ20027>L01SW>BU92436<
5:DHaP8YBP0C7>L@Q12424848ABU8@PLia241248@QBU6<HYBSg_@Q0aS1cW
5:D00QcW00<@Q0Q224800`aS0Q241PaS00D8@P@Q24848@aS00<8@P0336<8
@PaS00D8@P031248@P@Q0088@P0636<8@PQ2248<H`Q20P@Q10Q200H<Ha24
6<HHaQBU36<2248020@Q24848@@Q48@DYAcW5:D224800`@Q24848@021244
248512400`0012448@0312401@0012448@@Q24801P@Q00<8@P@Q12400`@Q
00T<HaBU6<H@Q248<Ha>Le:D@Q000TYB0Tic00=:DTHaBU800Tic00=BU4YB
BU800TYB0dic0TYB00=>Le:DE[D01EJe00IBU5JeDYABU4icDY@2E[D3DY@0
1DicDYABU5JeG_L00UJe0e:D00=>Le:DDY@00eJe0U:D0eJe00ABU4YBCW=>
L`9BU003CW=BU5Je009F]@04CW=BU5:DE[D2F]H01e:DBU9>LdicDYAJeUJe
00=BU003CW=BU5Je00=F]@0=CW=BU5:DE[EBU5JeDYAJeUJeF]I>Le:DCW<0
0U:D00=>LdYBCW<00eJe0Tic0U:D00=F]E[FE[D00UJe0e[F0eJe00EBU4ic
CW=>LeJe009JeP9F]@9BU005E[EBU5:DE[EBU002E[D3DY@00eJeDYABU002
DY@3E[D00e[FE[EF]@02E[D015[FE[EF]E:D0UJe0U[F00AF]E[FE[EF]@AJ
eP=F]@=JeP9F]@08F]INme[FF]IBU5JeF]IF]@9JeP03E[ENmekg009JeP9B
U004F]IF]E[FG_L3F]H00eJeF]IJeP03F]H3E[D2F]H3E[D01E:DE[EJeUkg
E[D00D8@00000`0012448@021240100012448@Q20P@Q00P8@SF]NmiJeRU:
<H`e[CW>0d8@00<mkcW>>Lh00Sg_0SW>0Sg_00LicSg_AS5>LdYB@Q0mk`02
@Q002Cg_@Q1244Ha@Q16<DYBCW=:DP02@Q02?Nl00d8@?NlicP04?Nl2>Lh0
13g_AS56<D8@0SW>00DmkdYBBU9:DT8@008icP<mk`@icP0;=JdaS2487>M6
<F<HF]He[@aS48@HaP0248@836<224800`aS248HaP027>L00aS65:DDY@02
6<H011BU36<8@P@Q0`Q200T48@Q248@@Q1cW<Ha:DV<HG_L00g>L00Ag_D8@
=JdDY@8@Q08<H`D8@P@48@<8@P041248@PQ236<248@536<010@Q2488@PQ2
1PaS0`@Q00<8@PaS36<00`Q200@<Ha2448@<H`D48@D8@P0736<@Q12448@8
@PaS5:D00QcW00@@Q0Q236<@Q0P<H`@8@P848@0436<HaQcW5:D212422485
36<00`Q236<8@P04248536<01Q2436<<H`Q236<8@P8<H`0B248<H`aS36<8
@PaS6<HLibU:9BTQ21cW6<HQ21cW5:D@Q0aS0Q2400<DYA2436<00a240PaS
00<8@PaS24800Q2411BU00<@Q1BU5:D00QBU00<<H`Q236<00QBU00<@Q0Q2
12400PQ200H<Ha2448@<H`Q2124424800`aS48@@Q00436<00a2436<<H`02
124010Q21248@PQ20PaS1`Q200<<H`Q248@00aBU00D@Q0aS36<48@aS0084
8@0:5:DLidicE[E>LeJe;F/DY@aS124424800`@Q2488@P0B12400`001240
0006124236<00`Q28@PaS002DY@2BU800dicBU9>L`02BU82CW<01U:DCW=>
Le:DBU96<@9:DP03CW=BU4ic00ABU003E[EJeU:D00IBU008BU9BU5JeF]IF
]E:DCW=BU0=F]@0=F]IF]EJeDYA>Le:DCW=BU5JeDYAF]E[FE[D00U:D00=>
Le:DDY@00e:D00EF]E:DDYAJeUJe00=BU003E[EBU4ic00=F]@EBU09JeP9B
U09>L`09DYAF]E:DCW=:DTicDYAF]Dic009F]@0;G_MF]E:DDYAF]E:DE[E>
Le:DCW=F]@05DY@01EJeDYAF]EJeF]H01UJe00=BU4icDY@00U:D0eJe00QJ
eUJeE[EF]E:DE[EJeU:D0UJe00=BU5JeDY@00UJe00ABU5JeDYAF]@ABU004
E[EBU5:DE[D2F]H2E[D00e:DE[EJeP06F]H5E[D00e[FE[EF]@02E[D2F]H2
E[D00e:DE[EF]@05F]H3E[D4F]H00eJeF]IJeP02G_L015[FE[EJeUJe0U[F
0eJe0U[F00AF]E[FE[EBU09F]@03F]INmeJe004mk`000`@Q00<000@Q1240
10@Q00`00124?NmcW5:D9BTe[CW>=Je244Ha@Q03>Lh0148@?Nle[CW>0Sg_
00PicSg_AS5>LdHa?NlicSg_0d8@00A6<D8@@Q16<@=:DP05@Q0mkcW>?Nm2
4003>Lh043g_@Q0mkcg_>LhmkdYBAS5243W>=Je244YBCW=6<D8@0SW>13g_
0cW>00`aS2e[8@PQ24icIcUBU36<36<DYAS648@536<010Q236<8@PaS0`Q2
00H<HaBU6<HLiaS65:D36<H0112424848@@Q10Q200P<Ha2436<Q236<BU9W
>F<H0W>L00Yg_G>L@Q0aS1BU36<@Q0aS248<H`H8@P<48@88@P0536<8@PaS
36<@Q00636<324801P@Q248<H`aS48@<H`D8@P0336<8@PQ20088@P0536<@
Q12436<8@P0312401`Q236<<H`Q21248@PaS008@Q00936<8@PaS5:DHaQBU
48@<Ha24008<H`88@P0836<@Q0aS36<8@P@Q24848@88@P05124<HaS67>LD
Y@02124224800`aS48@<H`0336<224800`@Q2488@P0436<00a2436<<H`03
36<00`Q236<8@P0236<00`Q236<<H`0236<02QS68@PYBRDY7>LHaQcW8@PH
aQBU0PaS0QBU0Q2410aS00<@Q0aS36<00PaS00P@Q0aS48@DYAS65:D@Q1BU
0QS600@DY@Q2248<H`8DY@0348@8@P@Q00<8@P8@Q088@P848@0336<8@PaS
00X<H`H8@P0336<8@PaS00@8@P@<H`0448@DYABU48@236<224803@aS1248
@QS68@QBU5JeCW=BU2DY48@8@P@Q0088@P848@88@P@48@0300048@@Q00H4
8@030008@P@Q00L48@0:00048@@Q1248@Q2436<8@R48;F/2E[D00dHaCW=:
DP03BU82CW<01E:DCW=>LdicDY@00TYB00=6<DYBDY@014ic0U:D15Je0U:D
00EF]DicCW=>Le:D009F]@9BU007CW=BU5JeF]IF]E[FE[D00U:D00=>Le:D
DY@00e:D00EF]E[FE[EBU4ic00=BU003CW=BU5Je00=BU09F]@EBU003E[EB
U5Je009BU003CW=F]E:D009F]@03F]IBU5:D009>L`=BU007CW=:DTicE[EB
U4icDY@00U[F00EF]E:DDYABU5Je009BU09>L`03DYAF]E:D00IBU0QF]@=B
U003CW=BU5:D00=F]@07F]IF]EJeDYAF]E:DF]H00eJe0U:D0UJe0e:D00AF
]E:DDYABU09F]@9BU004E[EJeU[FE[D2DY@2E[D2F]H015JeF]IJeU[F1EJe
0U[F00=F]E:DDY@00e[F00ABU5JeE[EF]@9JeP9F]@9JeP=F]@9JeP9F]@9J
eP9Nm`03E[EJeUJe009JePAF]@AJeP03DYAF]EJe009F]@5Nm`5BU0524000
00D48@0012448@0000<48@0824848@@Q248aS7NmG_LaS0<e[@05?Nm2448@
?NlicP02=Jd2?Nl00d8@AS4icP02>Lh00d8@CW=BU002AS400d8@?Nm24003
@Q0023g_BU9:DTicDYA:DTHa@Q02?Nl2>Lh013g_@Q1243g_0SF]13g_0cW>
00A244HaBU9:DP96<@03?Nm2448@008icP96<@0@>Lh]Jb488@PmkdYB>LhU
:@aS5:DLiaBU48@<Ha2436<548@236<020Q236<<H`aS48@DYAS67>L26<H0
2QBU36<8@P@Q36<8@P@Q248@Q2480QS600XQ23F]DYAF]F<HG_M243g_8@PH
aP8DY@0448@<H`aS1242248010aS2488@P@Q10Q200<<H`Q212400PQ20PaS
0Q2400<<H`Q224800P@Q00<8@PaS5:D00aS600<@Q0aS36<00P@Q00<8@PaS
36<00`Q200<<H`Q224800PQ200<48@Q2124020Q20PaS0PQ200<@Q1BU6<H0
0`aS00<DYA2448@00PaS00<8@PaS24800PaS0PQ20`@Q10aS0`Q20PaS00H@
Q0aS36<<H`Q236<5248236<2248536<348@010Q236<<H`Q20PaS0Q2400TD
YAcW7>LHaQBU48@DYA245:D011240PaS00P8@PaS248<H`Q236<8@PaS0a24
00P<H`Q2248<HaBU6<HLia240PaS00XDYBDY9BTLiaS636<48@Q21248@P@<
H`0424848@Q2248236<00a2436<<H`0236<01Q2436<DYAS65:D<H`848@<<
H`055:D@Q1BU48@<H`03248936<248@25:D031S67>LQ21cW<H`icUJeKg]F
]C6<5:D48@8<H`0324848@Q200D48@0300048@@Q00@48@0324848@@Q00/4
8@<8@P0436<HaR48@Q03DY@00dYBAS5>L`02CW<2DY@024icBU9>LeJeDYA:
DT8@AS45CW<6DY@014icDYA>Ldic1U:D00QF]DicDYABU4icE[EJeUJe0U:D
00=>Le:DDY@00Tic00MBU5JeF]IF]E:DBU9>L`04DY@01dicDYAF]EJeDYAF
]E:D009F]@04DYA:DTYBE[D2F]H01E:DBU9:DU:DE[D00U[F0e:D0Tic00E:
DTicBU9BU4ic00ABU09F]@06F]IBU5:DDYA>Le:D0eJe00=>Le:DDY@00UJe
0e:D00AF]E[FE[EBU0=F]@05F]IBU5:DBU9>L`05DY@2F]H01E:DE[EBU5Je
F]H015Je00=JeUJeE[D015:D00AF]E:DDYABU0=F]@03F]IF]EJe00=F]@9B
U005E[EBU5JeF]IF]@02F]H3E[D4F]H025JeDYAF]EJeF]IF]E[FE[D5F]H0
15JeDYABU5Je0e[F00AF]E:DDYAF]@ANm`04F]INmeJeF]H7E[D3DY@01EJe
DYAF]E[FE[D00Cg_00000`0012448@0212407@0012448@Q2124000aS=Jec
W5[F;F/aS3F]<Ha244Ha@Q0mkcW><H`icSg_>Lhmkd8@?NlicSg_AS400Tic
00E6<Cg_?NlmkdHa00924004?Nm244HaBU82CW<3AS42?Nl013F]>Lhmkd8@
0Sg_00<e[CW>>Lh00Sg_0SW>00@e[Cg_@Q16<@9:DP04AS5243g_?Nl3>Lh0
348@AS4e[Be[7>LU:Cg_BU8icR4836<DY@8HaP8@Q00736<@Q1BU5:D@Q0aS
48@00PaS0PQ200D@Q0aS5:D@Q1S6008Li`046<HDY@Q2124224801@aS124<
HaBU8@P00QBU00XQ23F]E[EF]F<HF]I243W>8@PLi`8DY@0348@<H`Q200P8
@P031248@PQ200<8@P071248@PQ248@<Ha2436<00PQ200H48@Q236<<Ha24
5:D26<H01QBU36<8@P@Q248<H`88@P0436<8@PQ236<524800`@Q24848@06
248336<224800a246<HDY@0236<00a245:DDY@0736<2248212400`Q2124<
H`0236<3248436<00a2436<<H`0236<01P@Q24848@Q236<8@PT<H`0548@<
H`aS36<8@P0336<01A245:DHaQcW8@P00QS60Q2400<DYA2448@00Q241PaS
10Q20PaS0Q2400P<H`Q236<<Ha247>LHaQ240PaS00HDYBDY9BTHaQBU48@2
24801@@Q248<Ha2436<00`Q200<48@Q224800PaS00<@Q0aS48@00`aS00@D
YAS65:D@Q0848@03248<HaS600<DY@0448@8@PaS248936<548@031BU7>LQ
21cW=JdmkeJeKg]>Lbe[36<48@8<H`0324848@@Q01448@0300048@@Q00H4
8@88@P0636<8@QcW8@Q244ic0U:D00Y6<DYBCW=>Le:DCW=BU4icBU9>L`9B
U003CW=6<DHa00E>L`9BU003E[EBU5:D00=BU0=>L`9BU003E[EBU5:D00IB
U09JeP06E[E>LdicDYA>Le:D0Tic00AF]E[FE[EBU09>L`9BU005E[E>Le:D
E[EBU002E[D015:DE[EF]EJe0dic00AF]E[FE[E>L`9:DP08DYAF]E[FE[EB
U5JeCW=BU0=:DP9>L`=BU005CW=F]EJeF]IF]@05DY@01EJeF]IBU5:DCW<0
0UJe0e:D00=F]E:DE[D00UJe0U:D00IJeUJeDYABU4icDY@4CW<4E[D2DY@0
0eJeF]IJeP03E[D2F]H01UJeDYABU5JeDYA>L`ABU004E[EJeUJeF]H3E[D2
DY@00eJeDYAF]@04E[D2F]H2E[D3F]H01EJeDYABU5:DE[D00U[F00MBU5[F
F]IF]E[FE[EJeP02E[D00e:DE[EJeP03F]H2DY@2E[D016<HG_MJeUkg0e[F
1UJe0e:D0UJe00ABU5JeF]IF]@4mk`000P@Q00<000@Q12400`@Q00/8@P00
1248@Re[JeYBU3F]?NlicSF]008mk`04AS5243W><H`2=Jd00cW>?Nlmk`03
>Lh01Cg_AS56<DHa@Q000THa0TYB00A244HaAS5>L`=:DP9>L`04BU8mkcW>
=Jd4?Nl02CW>@Q16<DHa@Q0mkd8@?NlicP02=Jd00cg_BU9>L`02CW<00dHa
BU8mk`02>Lh2@Q0023W><H`]Jc6<@Q16<Be[7>L248@26<H011BU36<8@PaS
0QBU0a240`aS00D8@PaS248DYAS6008Li`<DY@88@P848@<8@P<<H`0:5:DQ
23F]JeYcW5[F>Lh@Q1BU8@P27>L01AS648@@Q0aS12400`Q20PaS0PQ200@<
H`Q236<8@P848@0424848@Q2248248@00`aS2488@P02248248@01QS67>LL
ib485:D<H`88@P04124<H`aS48@824800`@Q24848@0624800`aS2488@P02
24800`aS5:DLi`029BT00acW6<H@Q00248@336<01PQ236<<H`Q236<8@P84
8@88@P<<H`05248<H`aS36<8@P0236<0112436<8@PaS0a240`aS1@Q20PaS
00@DYAcW6<HDY@<<H`03248<H`aS00HDY@0648@<H`Q236<8@QBU0R4800@H
aPaS1248@P8<H`0348@DY@aS00<8@PL<H`0>48@DYA2436<DYAcW:DXQ21S6
7>LHaQ2436<00088@P0436<@Q0aS124224800`@Q248<H`0248@436<00`Q2
36<<H`0348@236<248@00aS648@@Q00236<010Q236<@Q0aS0`Q200D<H`Q2
36<@Q1S6008Li`8Q2006=JdmkdHaAS4aS2e[0S6<00Dmke:DCW<]JaBU0084
8@D8@PL48@0300048@@Q00L48@0300048@@Q00D48@08248<HaBU48@YBSW>
BU9>L`96<@07DYA>LdicCW=BU4icBU800Tic0U:D00A>LdYBBU96<@9>L`06
DYA>Le:DCW=BU4ic0U:D0dic0e:D00=>Le:DDY@00UJe00=BU4icDY@00eJe
00=BU4icDY@00U:D00M>Le:DDYABU5JeF]IF]@04DY@014icDYABU4ic15:D
00A>Le:DDYAF]@=BU003E[EBU4ic009>L`03DYA>LeJe00=F]@03CW=:DTic
00IBU0=F]@9BU003E[EBU5Je009BU004E[EJeU[FE[D3DY@2E[D00e:DE[EB
U002DY@2E[D015[FE[EF]E[F0U:D00Q>LeJeDYA>LdYBCW=BU5Je1E[F00AF
]E:DE[EF]@=JeP03E[EBU5Je00ABU09JeP05E[EBU5:DE[EJeP02E[D01U:D
E[EF]E:DE[EBU09F]@0<DYAJeU[FE[EJeUJeG_MJeUkgE[EBU5Je0U:D00=J
eUJeG_L00U[F00=NmeJeE[D015:D25Je0U[F0Ukg0U[F0UJe15[F00]BU5Je
E[EF]E[FE[EBU5JeDYAF]E:D004mk`0000D48@0012448@0000H48@09248a
S6mkE[DaS3g_>Lhe[CW>00924003?NlicS6<008e[@04>Lhmkcg_?Nl2>Lh0
1Sg_@Q12448@AS52409:DP04AS52448@AS43BU801DicBU9>LdHa@Q000SW>
0cg_0SW>00@mkd8@AS5240<mk`8e[@06>Li244icBU9>LdYB0THa00<mkcW>
=Jd00T8@00@icRe[;F/aS0924004:DXQ20aS36<26<H021BU36<8@PQ248@D
YA245:D236<01Q2424848@Q236<DY@<Li`046<HDYA2436<724801A24248D
YBDY>Lh00Vmk00EBU3F]48@DYB48008Li`075:D<H`aS36<8@P@Q24800PaS
10Q200P<H`Q22488@P@Q24848@Q20a2400<<H`Q224800PQ20Q2400DLib48
7>LLiaS6008<H`848@04248<H`aS36<824801@@Q2488@PQ212400PQ200/<
H`Q22488@PaS248<HaBU6<HU:B48008Li`8@Q0<<H`@8@P8<H`<48@08248@
Q0aS248<H`Q236<@Q0<<H`8@Q0<<H`8@Q00436<8@PQ2248236<00`Q21248
@P0236<26<H00aBU48@8@P0236<00`Q236<<H`045:D00aS648@@Q00236<0
0a2436<DY@028@P011BU36<48@Q20PaS0Q240PaS0PQ21`aS00d@Q1S648@<
Ha246<HU:B486<HQ21cW48@8@P021242248248@01@Q236<48@@Q24800PaS
0Q240PaS00@8@PaS36<<H`H@Q0055:D@Q12436<@Q00336<00a2436<<H`02
24802`aS248<Ha246<HLiaS68@PU:CW>?Nl00T8@00`aS2U:;F/e[D8@F]I:
DRU:48@48@Q236<224800`aS12448@0;12400`0012448@09124324825:D0
336<?Nm>Ldic@Q1:DTicDYA>LdYBDYA>L`9:DP03CW=BU5Je00A:DP9>L`9B
U0=>L`9BU0=>L`9BU003CW=BU4ic009BU09F]@=BU09F]@04DYA>LdicCW<3
DY@2CW<3E[D6DY@3CW<3DY@014icDYABU5Je0e:D00EF]E:DDYA>LdYB009>
L`9BU003E[EBU5:D00A>L`9BU004CW=BU5JeDY@6E[D4DY@015[FE[EF]EJe
2E:D0UJe00AJeUJeE[EJePABU09>L`03BU9>Le:D009F]@04F]IF]E[FF]H5
E[D01e[FE[EF]EJeDYAF]Dic009BU004F]IF]E:DDY@2F]H2E[D01E:DE[EF
]E:DE[D015:D00YF]E[FE[EJeU:DE[EJeUkgF]IF]@=BU09F]@EJeP9F]@9B
U005E[EBU5JeE[EJeP05E[D2F]H01EkgF]IJeUkgE[D00U[F00AF]E[FE[EF
]@9BU0AF]@9BU05JeP5BU04mk`0000<000@Q12400`@Q00<000@Q24800P@Q
00d8@SF]LiaF]C6<@Q16<CF]>Li244YBAS4e[@02<H`00cW>=Jdmk`04>Lh0
2Cg_AS52448@?Nm244HaBU9>L`03BU8014Ha@Q16<DYB0Tic00=:DT8@?Nl0
0SF]0Sg_0THa1T8@00HmkcF]>LhaS3W>AS42BU82@Q002DYB@Q0icSF]>Li6
<CF]<H`e[@02?Nl013F]9BTU:ABU0Q2400<DYA2436<00PQ20a2400<<Ha24
36<010Q200@<Ha2448@DY@8HaP035:D@Q0Q200<8@P0>1248@P@Q1248@P@Q
36<HaR48=JdaS2486<HDY@<HaP8<H`03248<Ha24008<H`88@P8<H`0348@<
H`aS00<<H`0324848@@Q00@8@P0348@<H`aS00<<H`<@Q0085:DLiacW6<HD
Y@aS24848@88@P8<H`D8@P0336<8@PQ200<48@88@P0436<8@PQ236<22482
36<00a245:DHaP027>L00aBU48@<H`0248@01@aS248<Ha2436<02@Q200@<
Ha245:D@Q088@P0836<8@PQ2248<Ha2436<@Q0H<H`@8@P8<H`035:D@Q1BU
008@Q00836<@Q0aS36<@Q1BU48@<H`<@Q00636<8@PaS48@<HaS60R4800PH
aQ241248@Q245:DHaQ240`Q200P<Ha2436<@Q1BU6<HQ21S60QBU00L<H`Q2
48@DYAcW6<HDY@027>L01A2436<48@@Q248010aS10Q200<<Ha245:D00Q24
00D<H`@Q248<H`Q200<<H`8@Q0<HaP085:D<H`aS36<@Q1BU48@<H`<8@P@<
H`0648@HaRDY@Q16<FLi0f]J00YBU5[FAS4U:B48?NmF]DHa8@P48@88@P03
1248@PQ2008@Q00336<8@P@Q00D48@0324848@0000<48@0324848@@Q00L4
8@0;248<H`aS248Lic6<BU9>Ld8@AS5BU002CW<2BU83CW<01DYBCW=BU5Je
CW<00TYB00I>Le:DDYA>LdYBCW<3DY@2BU82CW<3DY@5E[D2F]H00eJeDYAF
]@03DY@00dicDYA>L`02DY@4CW<4DY@01DicBU9>LdicDY@00dic0U:D00=>
Le:DE[D00UJe00=BU4icBU800U:D0dic00IBU5[FF]IBU4YBCW<4DY@00eJe
DYABU004E[D4DY@2E[D00e[FE[EF]@04E[D2DY@00eJeF]IBU002DY@01Dic
E[EF]EJeF]H00eJe1e:D00A>Le:DF]INm`9JeP03DYAF]EJe009JeP9F]@04
F]IF]E:DE[D2DY@3F]H3E[D00e[FE[EBU002DY@2F]H2E[D2DY@01UJeF]IF
]E[FE[EJeP9F]@=JeP9F]@9BU09F]@07F]INme:DE[E>LeJeF]H01UJe0U[F
00=F]E[FF]H01E[F00=F]E[FE[D00U[F00=F]E[FE[D00eJe00=JeUJeE[D0
0eJe0Dic0Cg_000312400`001240000212402PQ200048@aS=Je_Ndic<Ha6
<D8@0SW>00A244YB@Q0icP8aS004=JdicSg_?Nl3>Lh00cg_@Q124002@Q02
AS45BU8034Ha@Q16<DHaBU9BU4YB@Q0mkc6<>Lhmk`Y24005=JdicSF]>Li6
<@02BU802d8@?Nm6<DHa>Lhe[CW>?NlicS6<=Jd00SW>00DaS2DY9BTDYA24
008<H`0448@<H`Q2248548@236<424806@aS48@DYAS65:DHaQ2436<8@P@Q
24848@Q21248@PaS248@Q1S69BTaS2e[9BTLiaBU00<HaPD<H`0548@<H`aS
36<8@P0336<00a2436<<H`04248212401@Q236<<H`aS24800`aS0Q240aBU
00DLiaS648@<H`@Q00<8@P<<H`<8@P0336<8@PQ200<48@@8@P0536<@Q0aS
36<8@P0236<01a245:DHaQcW8@PHaQ24008<H`0348@<H`aS008<H`0348@<
H`Q200<48@@8@P0436<@Q1BU48@336<3248436<248@636<010@Q248<H`aS
0QBU00@@Q1BU48@@Q08<H`0548@<Ha245:D@Q0025:D436<248@01ABU9BTU
:AcW36<00P@Q00H@Q1BU7>LDY@Q21242248348@26<H27>L02ABU48@8@PQ2
48@HaQcW5:DHaP027>L02QBU36<48@@Q36<8@Q2436<8@PaS0`Q200@<Ha24
5:DDY@8<H`@8@P8<H`0348@<HaBU00@DY@<<H`0448@DYA2436<424800`aS
48@<H`025:D01BDY@Q1:DVLiJeX00VLi00=BU5Je@Q000R4800Dmke[F@Q0L
i`@Q0088@P051248@PQ25:D@Q002248312400`001240000;12400`001244
8@0212401PQ236<@Q0Q27>Le[@9>L`04?Nm:DU:DCW<3BU801DicBU9>LdYB
CW<00e:D00M:DTHaCW=>Le:DCW=:DP04DY@3BU800dicDYABU004DY@00eJe
F]IJeP02E[D3DY@01TicDYA>LdicDYA>L`9BU003CW=BU5:D00ABU0=>L`04
DYA>LdicCW<2DY@01dicDYA>Le:DF]IF]E:D009:DP9>L`04DYA>LdYBE[D2
F]H00eJeBU9:DP02DY@2E[D3DY@4E[D2DY@3E[D2F]H00eJeDYAF]@02E[D2
DY@4E[D00e:DCW=>L`02E[D01E[FE[EF]E:DE[D015:D00E>Le:DCW=BU5Je
00=JeP9F]@07DYAF]E[FE[EJeUJeF]H00UJe00=BU4icDY@00e[F0UJe00=J
eUJeE[D00U:D1EJe0U:D0UJe0U[F0eJe0e[F00=F]E:DE[D00U:D00QF]E[F
G_MJeUJeCW=BU5Je0U[F00=BU5JeE[D00U[F0UJe00=JeUJeF]H00U[F00AN
me[FF]IJeP9F]@AJeP=F]@05F]IF]EJeE[EBU002E[D1DY@1>Lh000030004
8@0000P48@0=248]JfmkE[DmkdicBU8icS6<?Nm:DTHa>Lh00S6<0SF]0d8@
0SW>00Dmkd8@?NlicSg_00924003?Nm6<DHa009>L`07@Q0mkcg_BU9BU5Je
CW<00THa00@mkcW>>LhicP96<@03@Q16<Cg_008mk`=24005?NlicSg_>Lhm
k`02@Q001dHaBU96<DHa?Nm243g_008aS008BU9JeTYB<H`HaR486<H@Q08<
H`0:48@8@P@Q248<Ha2436<@Q0aS48@436<00`Q236<<H`0336<348@00`aS
2488@P041242248336<25:D00a2436<@Q0026<H00a2424848@0236<01Q24
36<<H`aS48@<H`88@P0536<@Q12436<@Q00224821243248236<00a2436<<
H`0336<35:D01A245:D@Q12436<01PQ200@48@Q2248<H`D8@P031248@PQ2
008<H`88@P041248@PQ2248348@01AcW9BTQ21cW24800`aS0Q2400@<H`Q2
12448@<8@P041248@PQ236<248@436<624800`aS24848@02248236<42482
36<348@35:D248@736<00`Q236<@Q00236<00`Q236<@Q00436<2248336<0
1Q242488@P@Q248@Q0<DY@<@Q0@<H`0548@DYAS66<HDY@026<H01QBU48@<
H`aS48@DY@8@Q08<H`0648@<Ha245:DLia240PaS00<@Q0aS36<00PQ21PaS
0QBU0a240`aS01TDY@aS248<Ha246<H@Q0aS248DYAS68@QBU5kgNmig_G>L
Oomg_FmkDYA242e[7>LDY@0248@00`aS24848@0412400`Q212448@071240
100012448@0010@Q00D000@Q12448@Q200<48@0:248@Q0Q25:DQ23g_@Q0m
kdHaBU82CW<00dHaBU9:DP04CW<3DY@3CW<2DY@7CW<2DY@014icDYABU5:D
0eJe0U:D0UJe00=JeU:DDY@01U:D00=F]E:DDY@00Tic00MF]E:DE[EJeTic
DYA>L`02BU82CW<2DY@01DicE[EBU5JeCW<00U:D0dic1e:D0UJe0U:D00=>
Le:DDY@015:D0UJe0U:D0Tic00=BU5JeE[D00UJe00IBU5JeE[EBU5JeDY@2
E[D01U[FE[EBU5:DE[EBU09F]@9JeP05E[EBU5:DDYA>L`02E[D4DY@01UJe
F]INme[FE[EBU0AF]@03DYAJeU[F009JeP=BU004E[EJeU[FE[D3F]H01UJe
DYA>Le:DE[EJePAF]@=BU0=JeP9F]@=JePIF]@=BU0AF]@04F]INmeJeF]H2
E[D2F]H2G_L00e[FE[EJeP04F]H015JeF]IF]E[F0UJe00=BU5[FE[D00e:D
0U[F00=F]E[FCW<00Cg_000612400`001248@P0212402PQ2;F][FU:D?NmB
U4Ha>Lhe[Cg_0THa00<icS6<<H`00SW>00A243g_>LhicPHmk`=24008AS5:
DTicBU9243g_@Q16<@9BU003CW=6<DHa00@icP06@Q16<DHa@Q0icSg_0T8@
0Sg_00DicSg_@Q1243W>008mk`04BU9>LdYB@Q02>Lh033g_=JdaS4YBF]I:
DS6<6<HQ21S648@8@P<<H`88@P<<H`H@Q00436<8@PaS248336<348@010aS
2488@PQ20`@Q00H8@P@Q248<Ha245:D248@01@aS48@HaQBU48@00PQ20PaS
0a240`aS0a241@aS00@48@Q212448@8<H`0448@<H`Q236<224800`aS48@D
Y@025:D011S65:D@Q0aS0PQ20PaS0PQ200<48@Q224800PaS0PQ200<48@Q2
12400PQ20`aS0`Q200<48@aS36<00a2400@Q22DY9BTLi`<8@P0436<@Q124
248236<00`@Q24848@031242248348@236<00`@Q2488@P0624800`aS2488
@P0224800`aS2488@P02248236<45:D00a245:D<H`0736<02@Q236<8@PaS
124<Ha245:D@Q00336<010Q2124<H`aS0Q240PQ200H48@Q236<@Q1S65:D3
48@010aS248<H`aS0aBU0QS600DLiaS648@@Q0aS008@Q00436<@Q0aS36<2
48@01@aS48@DYAS65:D00PaS00D@Q0aS24848@Q200H<H`0448@DYA2448@2
36<00a245:D@Q00336<25:D0312436<8@Q247>LYBUJeHaQkgWNmKg]oo`9c
W004CW<icRU:6<H25:D011242488@P0010@Q0PQ20`@Q00<000@Q12402P@Q
00<8@P@Q12401@@Q0PaS00<8@QS6:DX00T8@00@icT8@CW=BU0A:DP9>L`04
BU9>Le:DDY@2CW<00dYBCW=BU002DY@2BU800dicDYA>L`05CW<2DY@3E[D0
1U:DE[EF]E[FE[EBU09>L`EBU003E[EBU5:D009>L`03DYAF]E[F009BU09>
L`9:DP04CW=BU4icCW<2DY@2E[D3DY@3CW<3DY@2CW<01U:DE[EF]EJeDYA>
L`9BU004E[EBU5:DCW<5DY@2CW<015:DE[EJeUJe15:D00MF]E:DE[EBU5[F
DYAF]@04DY@2E[D3F]H2DY@00dicDYABU002E[D3DY@015JeG_MJeUJe0U:D
00AF]E[FE[EBU09F]@9JeP07E[EBU5:DDYAJeUJeF]H00UJe0U[F00EF]E:D
CW=BU5Je009JePEBU0=F]@0<F]IF]EJeF]IF]E[FE[EJeUJeF]IBU5Je0e:D
00=F]E:DE[D015[F0eJe00EJeUkgF]IJeUJe00EJeP=F]@9JeP04E[EBU5Je
E[D3DY@00eJeF]IJeP02F]H1DY@1>Lh0000500048@001240000512402`00
248aS6LiBU8e[DYBAS4icS6<=Jd00Sg_00@icSF]>Lhe[@8icP04@Q0mkcg_
>Lh2@Q02>Lh023g_@Q0icSF]>LhmkdicDY@2AS42?Nl03DHaCW=>LeJeDY@m
kcW><H`icTHaBU9243g_008icP03AS5:DTYB009:DP04@Q0mkcW>?Nl2@Q00
1dYB@Q16<DYBAS5243g_008aS008DYANmdHa9BT<HaBU6<H@Q08<H`0448@<
H`aS1242248248@01@aS6<HQ22487>L00PaS0`Q200D48@Q236<@Q0aS00@8
@P848@88@P081248@QS68@PLi`aS124<H`8@Q00336<@Q0aS008<H`<8@P03
36<@Q124008DY@0548@<H`Q2248<H`0248@00`aS12448@03248536<02@Q2
36<8@QBU8@PU:BU:7>LDY@0248@336<2248212400`Q21248@P0424821240
0`Q236<<H`0224801P@Q24848@Q236<8@P8@Q0035:D@Q124008DY@<<H`<@
Q0<8@P051248@PQ224848@0236<248@324800`aS248<H`02248312400`Q2
1248@P03248436<0412436<@Q2U:<HaS67NmCW<e[A2436<DYA2436<8@PaS
0`Q200<<H`Q236<00PQ200<48@Q2124010Q210aS00D48@Q22488@Q2400<<
H`035:DHaQcW008HaP0436<@Q1BU5:D37>L26<H02AcW8@PLiaBU48@DYA24
5:D@Q00336<00a245:DHaP025:D00a245:D<H`03248336<3248236<248@0
0`aS48@<H`0248@01@aS2488@Q245:D00Q2400H8@Q246<HYBTYBDY@2Li`3
Mkd01WooG_LicQS6248<H`<48@0400048@@Q000212401@0012448@@Q0000
0P@Q00<000@Q00000P@Q00<000@Q12400`@Q00<000@Q00001@@Q00`8@PaS
248@Q1S6=Jdmkd8@BU96<DYBCW<4BU84CW<3DY@3CW<01EJeCW=:DTHaBU80
1E:D00=>Le:DCW<00U:D00MF]E:DDYABU5JeF]IF]@02F]H00eJeDYAF]@06
DY@00dicDYA>L`02DY@2E[D00e:DBU9:DP02CW<3DY@2CW<4DY@2BU82CW<0
1e:DE[EBU5:DCW=F]E:D009F]@9BU008CW=BU5:DE[EBU5JeDYAF]@=BU09>
L`AF]@EBU09F]@03F]IF]E[F00AF]@03DYAF]EJe00=F]@9BU09>L`ABU003
E[EBU5Je00=JePAF]@9BU003F]IF]E[F009F]@04F]IBU5:DDY@3E[D2F]H0
0eJeDYABU005DY@00eJeDYAF]@02DY@00eJeF]IJeP02E[D01E[FE[EJeUJe
DY@00UJe0U[F00IBU5JeE[EJeUJeF]H2E[D3F]H00eJeDYAF]@02F]H00ekg
F]IJeP08F]H2E[D2F]H2E[D015:DE[EF]EJe15[F0EJe0Cg_000512401000
12448@Q20P@Q00X8@RU:IcU>LcW>AS5243W><H`e[@8mk`05>Lhe[CW>>Lhe
[@02?Nl01D8@?NlmkcW>?Nl00SW>00I244Ha=JdaS3F]@Q02DY@2@Q02?Nl0
2TYBCW=>LeJeCW<mkcW>=JdaS4Ha0TYB00PmkcF]>Li6<DYBAS5:DTHa0T8@
00<mkcW>@Q000dHa00E244Ha@Q1243W>008aS007DYANmdHa9BT<Ha246<H0
0PaS0Q2400<<H`Q212400PQ20Q2400H<HacW8@PU:AcW36<6248020aS48@<
H`aS1248@P@Q248212401`Q212448AS69BTQ21240088@P0348@<Ha2400H<
H`06248<H`aS36<@Q1BU10aS0Q2400<<H`Q224800PQ200@<H`Q236<8@PH<
H`085:DLib48:DXLiaBU48@8@P<<H`88@P<48@<8@P031248@PQ200848@04
248<Ha2436<2124424805`aS48@@Q12436<@Q1BU48@<H`Q236<@Q1BU48@<
H`Q2124<H`@Q24848@Q236<00Q2400@<H`Q2248<H`@8@P848@88@P031248
@PQ200<8@P@<H`8@Q00:36<YBS6<HaQcW4YB<H`@Q0Q25:D248@01PaS2484
8@Q236<8@P8<H`<8@P031248@PQ20088@P05124<H`aS48@<H`04248336<2
48@37>L00a2436<<H`025:D57>L28@P011S65:D@Q0aS1A2400<<Ha245:D0
0QS600@@Q1BU48@<H`<8@P8<H`88@P031248@PaS00@@Q0<<H`0548@<H`Q2
36<@Q0025:D236<01QBU6<HQ24HaE[Eg_@9cW007Nmig_GooG_Le[AS61240
0PQ27P@Q00<000@Q12400P@Q00P<H`Q25:DQ23F]?Nm244Ha0dYB00=6<DYB
BU800TYB0Tic00IBU4icDYABU4icBU82DY@01DicBU96<DYBCW<00e:D00=>
Le:DCW<01U:D00IF]E:DE[EJeUJeF]H2DY@01EJeDYAF]E:DCW<00e:D00E>
Le:DDYABU5[F009BU006CW=:DTicDYA>Le:D0Tic0U:D00IF]E:DCW=>LdYB
CW<4DY@00dicDYA>L`03E[D015:DCW=BU4ic0U:D00=F]E:DE[D00e:D00I>
Le:DDYABU5JeF]H2DY@00dicDYABU004E[D3F]H015JeDYABU5:D0UJe00AJ
eUJeE[EBU0=>L`EBU004E[EJeU[FF]H2E[D015:DE[EF]EJe0U:D0e[F00EF
]E:DDYAF]E:D009F]@0:F]IF]E[FDYAF]DicDYA>LeJeDY@2E[D4DY@01EJe
F]IJeU[FE[D00U[F0UJe00ABU5JeF]IJeP9F]@9BU003E[EJeUJe009F]@04
F]INmeJeF]H2E[D4F]H01EJeF]IJeU[FE[D015[F0eJe00=JeUJeDY@00U:D
00AF]E[FF]IF]@9JeP5BU04mk`0000<48@00124020@Q00P<HcF]G_M242e[
?Nm:DSg_0S6<0SW>0Sg_00DicS6<=Jde[CW>008mk`03>LhmkcW>00@mk`8i
cP8e[@04@Q16<DYBAS42?Nl2AS401dicE[EBU4Ha>LhaS3W>00=24005AS52
448@@Q0mk`02AS43BU801Sg_@Q1244HaCW=:DP96<@0=?Nle[C6<;F/e[Cg_
>LhU:AcW48@DYA2436<00PQ210aS00D8@PaS48@HaQBU00<Li`036<H<Ha24
0088@P848@<8@P<48@03248<H`Q20088@P848@8<H`8@Q08<H`0348@HaQS6
008Li`8HaP0348@8@PQ20088@P0336<8@PaS008@Q005248<HaBU7>LDY@03
36<524801@aS2488@PQ236<011BU00LU:Cg_CW=cW6<H=JdLi`0212400`Q2
12448@0224800`@Q248<H`0236<224800`@Q2488@P022483124424800a24
5:DDY@0436<348@00aBU48@DY@0248@010aS2488@P@Q0PaS00@@Q1BU36<<
H`88@P8<H`D8@P@48@0324848@aS00<<H`0348@DYAcW00<Q20087>L]Jc6<
E[E_Ne[FAS4Q208@Q00336<8@PQ200H8@P031248@P@Q00<48@88@P0436<8
@PaS36<224800`@Q36<<H`0336<01A246<HQ21cW6<H00Q2400<DYAS66<H0
0aS611BU0a2400HDYA2448@@Q0aS248236<011BU7>LHaQBU0Q2400<DYA24
36<00PaS00<@Q0aS24800PQ210aS0Q2400<DYA2436<00PQ20Q240PQ2014@
Q1S66<HLic6<@Q1S65[FG_M[FV<HF]HicRU:6<H<H`Q200H48@030008@P@Q
00P48@0300048@@Q00l48@<8@P045:D@Q2e[@Q02CW<2AS402TicBU96<DHa
BU9>LdYBAS5:DTic0U:D14ic0U:D0Tic00YBU5JeE[EF]E:DCW=BU4icDYA>
L`IBU003E[EJeUJe009F]@03DYAF]E:D009BU09>L`04DYA>LdicDY@2E[D0
0e[FDYA>L`03DY@00eJeCW=BU006DY@8CW<2DY@00dicDYABU002DY@024ic
DYAF]EJeDYAF]E:DCW<2DY@00eJeDYAF]@03DY@00eJeDYABU002DY@00eJe
F]IF]@04F]H01EJeF]IBU5:DCW<00U:D0UJe00=>Le:DBU800Tic0U:D00EF
]E:DDYABU5Je00=JeP=BU003E[EJeU[F009JeP=F]@ABU004E[EBU5[FDY@4
E[D015:DCW=BU5:D0UJe00MBU5JeDYABU5[FE[EJeP02E[D00e[FE[EF]@04
E[D015[FE[EJeU[F1EJe0e[F0UJe0e[F15kg15[F00ENme[FF]IJeUJe009J
ePAF]@07F]IF]E[FF]IF]EkgE[D00Cg_0000100012448@000P@Q018000@Q
248000@Q248]Jekg@Q0]Jd8@AS4mkcF]<H`e[CW>?Nl2>Lh2=Jd2>Lh013g_
>LhicSW>13g_00<icSF]>Lh00SW>00A244Ha@Q12408mk`03AS5:DU:D009B
U006AS5243W>>Lhmkd8@0THa0cg_00M244HaAS56<DYBAS524002?Nl01T8@
BU9:DT8@AS4icP@aS08icP06:DXLia246<H@Q0aS0PQ21@aS0Q2400<HaQBU
5:D00aS600<@Q0aS24800PQ210@Q10Q200@48@Q224848@<8@P0336<@Q124
008<H`0348@HaQS6008Li`035:DLia240088@P0:124<Ha2436<@Q1BU36<8
@PaS48@26<H00a2436<8@P04248010@Q2488@PQ20PaS0Q2400THaQBU9BTm
kdYBJeYS636<7>L00P@Q00<<H`@Q12401`Q200@<H`Q212448@H8@P0<1248
@P@Q124DYAS65:D@Q0Q236<@Q0aS0Q2400LDYA2448@@Q1BU48@<H`032480
0`aS48@DY@0236<2248010aS248<H`Q21@@Q00<8@P@Q12400PQ201@<Ha24
248<HaS68@PYBRDY6<HLic6<=JeJeV]JF]I6<B4836<@Q0aS1@Q200@48@Q2
1248@P848@0424848@Q21242248236<01@Q212448@aS24800`aS00<8@PaS
5:D00QcW00<HaQ2448@00Q2411S600<DYA245:D01Q2400@DYA2436<8@P8<
H`@HaP@@Q08<H`0548@<H`aS36<48@0224801@aS48@<Ha245:D00Q2410aS
00@@Q0aS36<<H`<HaP0;=Je246<HG_MS66]JG_MJeSW>9BTDY@0324821240
1P0012448@Q2124000H48@0500048@@Q1240000412400`0012448@031240
100012448@Q20`@Q00X<HaS66<HYBSg_BU9BU4Ha@Q1>L`A6<@=:DP9>L`9B
U0=>L`9BU09>L`05BU9BU5JeF]IF]@08CW<015JeDYABU5:D0UJe00=JeUJe
DY@00U:D00=F]E:DDY@014ic00EBU4icDYAJeUJe009BU004CW=BU5JeDY@3
CW<3DY@01TicDYABU4YBCW=:DPA>L`9BU003CW=BU5:D00EBU09F]A1BU003
E[EJeUJe00EJeP9F]@03CW=BU5:D009F]@=BU003CW=:DTic00EBU0EF]@05
DYAF]E:DDYAF]@03F]H3E[D00e:DE[EBU002DY@00eJeDYAF]@03E[D2DY@0
14icDYABU5:D0UJe0U:D0UJe00AJeUJeE[EJeP9F]@03DYAF]E[F00AF]@9J
eP9F]@03F]IF]E[F00=JePAF]@9JeP=Nm`05F]IF]E[FF]INm`02F]H015:D
F]IJeU[F15Je0U[F00EF]E[FF]INmeJe004mk`000P@Q00<000@Q12400`@Q
00T8@P@Q1248@S6<IcU:DRDY<H`013W>0SF]0SW>1CF]00HicSF]>LhicSg_
AS42@Q002Cg_>LhicSW>=JdicSg_AS524002AS43BU801U:DCW=:DTHa>Lhe
[@8icP=2408mk`0;=JdicT8@AS5:DTHa@Q0mkd8@?Nm6<@02@Q02AS400cg_
>Lh]J`02;F/0136<9BTHaQ240PaS0PQ200H48@Q236<@Q0aS48@26<H27>L0
1AS65:D<Ha2436<00Q240PQ200<48@Q212400`@Q00@8@P@Q24848@@<H`88
@P8<H`0>48@HaQcW6<HDYAS67>LU:B4848@<H`@Q248<H`<8@P<<H`88@P04
36<@Q12436<224801@aS1248@PQ236<00PQ200/@Q1S69BTQ22DY;F/aS2e[
:DX]Jc6<008icP067>L@Q000248<H`@Q1PQ20P@Q00D8@P@Q2488@PaS00<8
@P081248@P@Q248DYAcW8@PHaP8<H`8@Q0045:D@Q0aS36<448@010aS248<
Ha240QBU00@@Q0aS248<H`88@P0436<8@PQ236<2124010Q236<<H`aS0PQ2
0PaS0Q2400LDYAcW8@Pe[CW>@Q16<@02>Lh022e[9BTe[DicDY@icQBU2482
36<00`Q21248@P022483124010Q21248@P@Q0`Q200@48@Q2248<H`<8@P03
36<8@PaS00@<H`045:DHaQcW7>L26<H00aBU48@@Q00348@536<45:D22480
0`@Q2488@P0236<248@736<00a2436<<H`0224800a2436<<H`045:D32482
36<04@Q236<DYBDY6<H@Q2DY>Li_Ng>LF]IBU2U:9BTQ21BU48@00PQ21`@Q
00<8@P@Q12406P@Q00P8@PaS48@@Q1S6<Ha6<E:D0THa00U:DTicBU96<DYB
AS5:DTicBU800dic00=:DTicCW<00Tic1E:D0UJe1E:D0Tic0e:D00E>Le:D
E[ENme[F00AF]@03F]IF]E:D009BU0=>L`9BU09F]@9BU004E[EJeU:DDY@2
CW<8DY@00dicBU9>L`02CW<2DY@2CW<00dYBCW=>L`02DY@2E[D00e:DE[EB
U004DY@014icDYABU5Je15:D0Tic00=BU5JeF]H00U[F00IF]E[FF]INme[F
E[D2DY@014icDYABU5Je0U:D00E>Le:DDYA>Le:D009F]@=>L`03E[EJeU[F
00=BU003E[EJeU[F00EF]@03DYA>Le:D009BU005E[EBU5:DDYAJeP02E[D0
0e:DCW=F]@03E[D01U:DE[EF]E:DE[EBU0IF]@ABU09F]@9JeP06E[EJeU:D
DYAJeUJe0U[F00=NmeJeE[D00UJe00iJeUkgG_MS65kgF]IF]E[FG_MJeUJe
F]IF]E[F0UJe00=JeUJeF]H00UJe00EJeUJeF]IJeUJe004mk`0000<000@Q
12400P@Q00`000@Q1248@P001248@S6<IcU:DRDY=Jd3>Lh2=Jd3>Lh2=Jd0
0c6<=Jde[@02=Jd2>Lh013g_@Q1243g_0SW>00@mkcW>=JdicPA24003AS5:
DTic00=>L`03AS5243W>008icP03?Nm244Ha009240<icP04?Nm6<DYBBU82
@Q0013g_@Q12448@0THa0T8@00dicS6<;F/]JbU:9BTQ21245:D8@P@Q2484
8@0336<248@01QBU6<HLiacW6<HDY@8<H`0348@<H`aS0088@P031248@P@Q
00848@0324848@Q200<8@P8<H`03248<H`Q2008<H`0:48@LiacW6<HDYAS6
8@PU:B485:D236<5248236<324801@aS48@@Q12436<01PQ200@<H`Q248@L
i`8U:@058@P]Jc6<;F/YBP02<H`013W>=JdDYA240P@Q0PQ200@48@Q22484
8@@8@P051248@P@Q248<H`0224802P@Q248<H`@Q248DYAcW8@PDY@aS0Q24
0PaS0Q240PaS00<@Q1BU36<00`Q211BU10Q200@<H`Q2248<H`88@P848@03
36<@Q0aS0088@P8<H`8@Q0035:DLibDY008e[@924005>Lhe[Be[:DXe[@02
CW<00cF]6<H48@0236<010@Q2488@PQ21@@Q0PQ200D48@Q21248@P@Q00@8
@P031248@PQ200H<H`036<HDYAcW008HaP035:D@Q12400@@Q08<H`03248<
H`aS008HaP065:D@Q0Q2248<H`Q20PaS11241PaS00@@Q0aS2488@P@<H`04
48@HaQBU48@2248236<04Q242488@QS69BTHaQ249BTicW>LKg]JeTic;F/U
:AcW6<H@Q088@PP48@0324848@@Q0088@P04124000@Q000712401@Q21244
8@@Q00001P@Q00/000Q2248DY@aS7>LaS4YBDYA244Ha00=:DP04AS5:DTYB
CW<3BU84CW<01DYBCW=>Le:DE[D00Tic00IF]E[FE[E>Le:DE[D2DY@2CW<5
DY@3F]H00eJeDYAF]@04E[D014icDYA>Ldic0e:D0UJe00=BU5JeE[D00UJe
00=BU4icBU8015:D00I>LeJeDYABU4icBU83CW<2DY@2CW<2BU8014icDYAB
U5Je0U:D00EF]E:DE[EBU4ic00aBU003E[EJeU[F00=JeP04G_MJeU[FE[D2
DY@00dicDYAF]@06DY@00dicDYABU002DY@01DicDYAF]E[FE[D00U:D0UJe
0U[F1EJe00ABU4icCW=BU09F]@ABU003F]IBU5:D00=BU005E[EBU5JeDYAF
]@03DY@4E[D00e[FE[EF]@02DY@3E[D3F]H4E[D2F]H01UkgF]IF]E[FDYAF
]@9Nm`03HaQNme[F00=JeP04G_MJeU[FE[D2F]H2E[D2F]H2E[D01U[FE[EJ
eUJeG_MF]@4icP0000D48@0012448@0000<48@0<24848@@Q36<aS6mkDY@Y
BS6<=JdaS3F]0cW>0SF]0cW>00Pe[CW>=JdaS3W>=JdicSg_0d8@00<mkcW>
>Lh00Sg_00dicT8@@Q16<DicBU9243g_AS5>LdYB@Q0aS002=Jd00cW>?Nlm
k`03?Nl00cW>?Nm24002AS42?Nl00d8@AS56<@02AS402D8@AS52448@?Nli
cSF]:DXQ20027>L00aBU48@8@P04248236<01`Q236<aS4YBAS4U:@@Q008<
H`03248<H`aS008<H`0324848@@Q00H48@88@P8<H`03248<H`Q200<8@P05
36<@Q12448@<H`0248@021BU48@<H`Q236<8@PaS248336<3248010@Q36<<
Ha2420aS00/8@PaS6<HHaSg_BU9F]E[FDYA:DT8@008aS0069BTLibDY:DXL
ia240P@Q00@8@P@Q1248@P848@D8@P<<H`0324848@@Q0088@P0736<@Q1BU
7>LQ21BU48@00PaS0Q2400P<H`Q236<DYAS65:D<H`Q20a241PaS00<8@PaS
36<00PaS0P@Q00<8@Q2448@00PQ20QS600H@Q0aS248Lic6<?Nl2HaP02Fmk
JeYJeU[FBU9243F]9BTQ2002;F/00acW24848@0=124524800`@Q2488@P02
36<01@Q236<<H`aS24800PaS010@Q2DY<H`U:AcW36<@Q1S65:D@Q0aS48@<
H`Q236<@Q08DY@8@Q00336<8@PQ20088@PD<H`88@P8<H`@@Q08<H`06248@
Q0aS248<H`Q20`aS00P48A247>LU:AS624848ABU0PQ200`YBSg_HaQNmc6<
;F/DYAS67>L@Q0aS24831243248B12400`Q212448@0612400`0012448@02
124336<00acW:DXicP02@Q0014HaBU9>Ldic14Ha00E:DTicCW=:DTic00=B
U0=:DP03CW=BU5:D009BU0EF]@=BU0A>L`04DYAJeU[FF]H8E[D2DY@01dic
DYABU5JeDYAF]E[F009F]@=BU003CW=BU5:D00=BU003E[EBU5Je00=BU0I>
L`03DYA>Le:D00ABU005E[EBU5JeE[EJeP02DY@01DicDYABU5JeCW<015:D
00A>Le:DDYAJePAF]@04F]INme[FF]H3E[D3DY@00eJeF]IJeP02DY@2CW<3
DY@01DicDYA>Le:DF]H00UJe0U:D00=JeUJeE[D00e[F00AF]E:DCW=>L`9B
U0AF]@05DYAF]EJeG_MF]@02DY@01DicDYABU5:DF]H00U:D0Tic00=BU5Je
E[D015:D0eJe0U[F0eJe00=JeUJeE[D00UJe15[F00EBU5JeDYANme[F009N
m`03F]INmekg00=JeP9F]@05F]IF]EJeF]INm`02F]H015JeF]IJeUJe0U[F
0EJe0Cg_000212400`0012448@0512401P0036<aS6mkDY@YBP8e[@03<H`e
[CW>008icP03=JdaS3F]008icP8e[@04<H`e[CF]=Jd2?Nl0148@?NlmkcW>
0cg_0SW>0Sg_0dYB00M6<D8@AS56<DYB@Q0icP03=Jd0148@?NlicSg_0cW>
00=244Ha@Q000T8@00DmkdHa@Q1244Ha00=2400>?Nm243g_>LhYBQcW6<HL
iaS636<48@Q236<48@88@P0<48@8@PQ2=Je:DTHa9BT48@Q236<8@PaS0`Q2
00<<H`Q212400P@Q00<8@P@Q248010Q20PaS0`Q20PaS00<8@PaS48@00a24
00<DYA2448@00PQ210aS0PQ200<<H`Q212400P@Q1@aS00@8@PaS36<@Q08<
H`0?248<HaS67>LicTHaDYANme:DBU92436<;F/U:B48008U:@046<H<H`@Q
1243248010@Q2488@P@Q0PQ200<<H`Q236<00`aS0`@Q0PQ20QBU0QcW00@D
YA24248<H`8@Q00936<8@PaS48@LiaBU36<8@PaS008@Q00436<@Q0aS36<2
248536<00`Q2124<H`0248@224800a247>LDY@0236<01AS6<H`icVLiHaP0
0V]J0U[F00E6<D8@<H`YBRDY008]J`056<H8@P@Q1248@P05124224821246
248010@Q2488@PaS0`Q20PaS00T@Q0Q2248@Q1BU:DX]JbDY7>L00Q240QBU
00T@Q0aS48@<H`Q248@<HaS65:D00Q240PaS00@8@P@Q24848@<<H`@8@P<@
Q0045:D<H`aS248336<3248336<01@@Q36<LibDY7>L00PQ200L@Q0Q2248]
Jcg_JeYS6002;F/01aS65:DHaQ2436<48@Q200/48@0324848@@Q00H48@03
24848@@Q00L48@0300048@Q200<48@0=24848A2436<HaRU:>Li243g_AS5:
DU:DCW<00THa00M244HaCW=>LdYBCW=:DP02DY@014icBU9:DTYB1U:D0eJe
0U:D00=>Le:DDY@00Tic00Y:DUJeE[EJeUkgDYAF]E:DE[EJeP9F]@9BU003
CW=BU4ic009BU006E[EBU5JeE[EBU5Je0Tic1E:D00IF]E:DDYABU5JeDY@8
CW<7DY@2E[D015[FE[EBU4ic1e:D00A>Le:DCW=>L`9BU004F]IF]EJeE[D2
F]H00ekgF]IF]@02E[D024icDYABU5:DF]IF]E:DE[D2CW<5DY@014icE[EB
U5Je0U:D0eJe0U:D0U[F00=F]E:DCW<00e:D0eJe00ABU5JeDYAJeP9F]@9B
U003CW=BU5:D009BU003E[EBU4ic009BU0=F]@ABU0=F]@03F]IF]EJe009F
]@05F]IF]EJeDYAF]@02F]H2E[D015:DE[EJeU[F0Ukg00=JeUkgG_L00Ukg
15Je00AJeUJeF]INm`9JeP9F]@05F]IF]EJeG_MF]@01?Nl0000400048@@Q
000212400`001248@P0212401@Q2>LikgUkg:DX00c6<0SW>00@mkcF]=Jde
[@8icP04?Nle[C6<=Jd2>Lh00cF]<H`aS002>Lh2?Nl00cW>@Q1:DP02@Q00
2SW>?Nm2448@?NlicT8@AS5:DT8@0SW>00DmkcW>=JdaS3F]00@icPHmk`03
@Q16<DYB009:DP08@Q0mkcW>>Lhe[CW><H`Q208HaP057>LDY@aS248<H`02
48@01PaS248<H`aS5:DQ208YBP047>L<H`aS12452482124010Q212448@@Q
0PQ20P@Q1`Q200<<H`@Q24800PaS00<DYA2436<00`aS00<@Q0aS36<010aS
0PQ200H48@Q22488@PaS48@236<030Q21248@Q247>LDY@aS1248@RU:;F]N
m`9_N`0<OomcW7>LIcU6<D8@5:D8@RDYBU96<B480P@Q00<8@P@Q12400`@Q
0PQ200<<Ha2448@00Q2400<<H`Q224800PQ200@48@Q236<@Q08HaP8@Q08<
H`8@Q00336<8@PaS00X<H`0448@<H`aS36<648@00`aS248<H`04248236<2
48@00acW>LiBU002Mkd03W>LMkeg_GooG_M:DRDY36<@Q1S6:DXDY@Q20009
124224800`@Q2488@P031242248236<02A2436<8@PQ21248@PaS248@Q003
5:D248@02AS67>LLiaBU48@<Ha2436<@Q00236<25:D248@21243248010aS
248<H`aS0PQ200@48@aS36<8@P8<H`0348@<H`aS00H<H`0624848@Q236<@
Q0aS0PQ200T<H`Q236<8@PaS5:DHaR487>L00QS600D@Q1BU48@<H`Q200<4
8@<8@Q<48@0324848@@Q00D48@0300048@@Q00<48@08248<H`Q26<HQ23W>
BU96<@=24006CW=:DT8@@Q1:DTic0dYB0U:D0Tic14YB00=>Le:DDY@00U:D
0UJe1U:D0Tic0e:D00]F]E:DE[EBU5JeDYAF]E:DE[EBU5Je00=BU0AF]@03
DYAF]E:D00=BU09>L`0<DYA>LeJeE[EJeUJeCW=BU5JeDYAF]E:D0dic0U:D
00=>Le:DCW<025:D0dic0U:D00Q>Le:DE[EF]E:DCW=BU5Je0U:D00EF]E[F
DYABU5Je00=JeP03DYAF]E[F009BU004E[EJeUkgF]H4DY@4CW<2DY@01dic
DYAF]EJeF]IF]E[F00AF]@04F]IBU5JeCW<2DY@5E[D00e:DE[EF]@02F]H2
DY@014YBCW=BU5:D0UJe0U:D00E>LeJeE[EF]Dic00ABU003F]IF]E[F00=J
eP06E[EJeU[FE[EJeUJe0e[F00=F]E[FE[D00e[F15kg1e[F00=BU5JeE[D0
1E[F00EF]E[FE[ENme[F0052400010@Q00`000@Q12448@Q2124000aS=Jeg
_E[F:DX2=Jd00c6<>Lhmk`02>Lh2=Jd013W>?NlicSF]0S6<00@e[CW>>Lha
S08e[@8icP8mk`03@Q1:DT8@008icP04?Nm2448@?Nl2>Lh01DHaBU96<CW>
=Jd00SW>00He[C6<=Jde[CW>?Nl3>Lh3?Nl2@Q0014HaBU9:DTHa0Sg_00/i
cSF]=Jde[C6<8@PHaQBU7>LDYA240088@PH<H`055:DU:BDY9BTLi`022480
0`@Q2488@P0624821242248010@Q2488@P@Q20Q200<48@aS48@00Q240PaS
00@@Q0aS48@@Q0D<H`88@P848@88@P@<H`<8@P0448@HaQBU48@224800bDY
<HaS6002Kg/02GooLiacW6<HAS4icQ24248YBP02AS4022DY00048@Q21248
@P@Q2482124010Q236<DYA2410aS00D8@P@Q2488@PaS008@Q08HaP0348@<
H`aS008@Q00536<8@PaS36<@Q00336<00`Q236<<H`0836<011245:DDYA24
0PaS00D8@P@Q24848@Q2008<H`07248@Q0aS7>Lmke:DMkd00W>L0WNm00Ao
oekgAS4Li`8@Q0037>LQ21BU00D48@0400048@@Q00061248248248@01@aS
1248@PaS24800PaS0QBU0a2400@DYAS66<HDY@@<H`07248@Q1BU48@DY@Q2
36<00`Q200H48@Q2248<H`Q236<3248010aS2488@PQ20Q241`aS1PQ20`aS
0PQ20PaS00H8@QBU6<HU:B486<H248@00aBU48@<H`031242248412400`Q2
12448@0312400`Q212448@071242248>12401@aS248DYB48>Lh00THa0T8@
00=6<DYBBU800T8@00E6<DicBU9:DTic00=BU09>L`04BU96<DYBCW<4DY@0
0eJeDYAF]@04DY@4CW<2DY@2E[D2DY@01UJeDYABU5JeDYAF]@9BU003CW=B
U5Je009F]@03DYAF]E:D009BU09>L`9BU003CW=BU5:D009F]@9BU009CW=B
U5JeDYA>Le:DCW=BU4ic00ABU003CW=BU5:D00IBU09>L`9BU006CW=BU5:D
E[EBU4ic0U:D1EJe00E>Le:DF]INme[F00AF]@03DYAF]E[F009JeP9BU003
CW=BU5:D009>L`9BU006CW=BU5:DDYAJeUJe0U[F0e:D00IJeUJeE[E>Le:D
E[D2DY@5E[D00e:DE[EJeP02E[D00dicBU9>L`02DY@015JeDYABU4ic0U:D
0UJe00ABU4icDYABU09F]@=JeP=F]@=JePEF]@9JeP04E[EJeUJeF]H4G_L5
F]H015JeF]IF]E:D0UJe0U[F00MF]E[FF]IF]E[FG_MF]@01@Q0000030004
8@0000<48@030008@PQ200848@0736<mkgNmF]H]JcF]>Lh00cF]0cW>0T8@
00@mkcW><H`aS08icP04?NlicS6<;F/2<H`00cF]>Lhe[@02?Nl01DHaBU96
<DHa?Nl00cW>00@mkd8@AS5:DP924003AS4e[C6<008]J`06?NlicSg_?Nli
cSF]0SW>13g_00hicSg_@Q1244Ha>LhaS2U:;F/aS2486<H@Q1BU0R4800@H
aQ241248@P<<H`0548@DYAS65:D@Q00236<224821242248512400`Q21244
8@07248010@Q24848@@Q0`Q21@aS00<@Q1BU5:D00Q2400<8@PaS36<00PaS
0`Q20PaS00<@Q0aS24800PQ200<48@Q212400PQ20`aS00<YBS6<HaP00W>L
00eg_G>LOomooekgAS4HaQ245:DLiaS65:D8@P0312400`Q212448@021242
36<011S67>LHaQS61@Q200@@Q1BU5:D<H`88@PH<H`88@P0336<8@PaS00H8
@P@<H`0348@DYABU008DY@<HaP045:D8@PQ2124236<3248248@01QS6=Je6
<FmkJeYcW09g_@0;OomS648@8@P@Q1BU48@<H`Q21248@P05124010001244
8@@Q1PQ200D48@Q236<@Q0aS0088@P<<H`<8@P0336<@Q0aS00<<H`8@Q0<D
Y@0548@<Ha2436<@Q0025:D00aS65:D@Q00224800`@Q2488@P0436<010Q2
36<8@PaS1@Q21@aS112400<8@PaS24800PQ200<48@Q2248010aS00@@Q0aS
248@Q0<DY@H8@P8<H`<8@P848@88@P031248@P@Q00X48@0324848@@Q00h4
8@08248<HaS67>LYBSW>@Q1:DP9240=:DPA>L`9:DP9>L`03BU9>LdYB00A:
DPABU004CW=F]EJeF]H3DY@4CW<4DY@2E[D055:DE[EJeUJeF]IBU5JeCW=F
]E:DCW=BU5JeF]IF]E:DCW=:DTicDY@4BU800e:DE[EBU002DY@00eJeDYAB
U003DY@00eJeDYAF]@02DY@014icDYAF]EJe1E:D0Tic0U:D00A>Le:DDYA>
L`9BU0AF]@05DYAF]E:DE[EBU002E[D015[FE[EF]E:D0UJe00YBU5JeE[EJ
eUkgF]IF]E:DCW=:DP9>L`05DYAF]E:DE[EBU003E[D2F]H00eJeF]IF]@04
E[D01U[FDYABU4icDYAF]@=JeP05CW=BU5:DDYAF]@02DY@02DicDYABU5:D
F]IF]E:DF]IBU005E[D4DY@00eJeF]IJeP02F]H015JeF]IF]EJe1e[F00EN
me[FF]IF]E[F00ANm`=JeP05E[EJeUJeE[EJeP03E[D00e[FG_MNm`03F]H1
G_L1F]H1@Q0000D48@0;00048@@Q248000@Q36<icW_NE[DYBP02>Lh3=Jd3
>Lh01Sg_@Q0icSW><H`]J`8e[@8icP8aS003;F/aS3W>008icP8mk`05BU96
<D8@AS524002>Lh00cF]?Nm6<@02BU83@Q001CW><H`]Jc6<>Lh00Sg_00<i
cSF]>Lh013W>00<mkcW>>Lh00T8@0THa00dicRe[:DX]Jc6<8@PDYA245:DL
ib485:D@Q002248236<348@25:D248@22482124224800`@Q24848@041240
0`Q21248@P05248212432482124236<0212436<8@PaS48@DYAS648@336<0
0`Q236<8@P03248010aS48@<H`aS10Q200@48@Q22488@P8<H`0?48@YBSF]
HaQ_Ng>LNmi_NgooNmiJeSg_5:D@Q1S6008Li`045:D48@@Q248312401PQ2
1248@PaS48@Li`<HaP8<H`0424848@aS48@25:D3248010aS48@<H`aS0`Q2
00<48@Q236<00PaS1@Q200@<H`Q236<<H`8DY@8HaP055:DHaQS65:D@Q004
248236<2248236<00acW>Li:DP02Kg/037>LMkeg_GooF]I6<AcW48@DY@aS
48@8@P/48@<8@P848@0324848@aS008<H`88@P0436<8@PaS36<2248010aS
248@Q12410aS11BU00<@Q0aS48@00PaS00@DYA246<HHaP8<H`848@052484
8@Q236<@Q00236<8248536<01a2436<@Q12436<8@P@Q00H8@P0436<@Q124
248236<25:D248@324800`@Q24848@0424821242248412400`Q212448@04
12400`Q212448@0<12402P00124000@Q248<H`Q25:DHaRe[0T8@00M6<D8@
@Q16<DYBAS5>L`02DY@014YBAS5>Le:D0Tic0TYB0THa00=:DTicDY@00U:D
00=>Le:DDY@00U[F00EBU4icCW=>Le:D009>L`=BU004E[EBU5:DDY@2E[D0
15[FE[EBU4ic1E:D0eJe00EBU4icCW=:DU:D00=:DP03CW=BU5:D00ABU009
E[EBU4icDYAF]E:DE[EBU5Je00ABU004E[EBU5:DCW<2DY@01TicDYABU4ic
DYA>L`EBU0AF]@03DYAF]EJe009BU0QF]@03DYAJeU[F009JeP9BU09>L`05
BU9>Le:DDYAF]@03DY@00eJeF]IF]@02F]H01e:DE[EF]E:DE[EJeUJe00AB
U004E[EJeU[FE[D6DY@4CW<6E[D2DY@3E[D3DY@2E[D6F]H3E[D015[FE[EJ
eUJe15[F0UJe00AJeUkgHaQNm`QJeP=F]@=JeP9Nm`04E[EJeUkgF]H1@Q00
000500048@001240000612401`Q2;F][FU:D=Je243W>008e[@08<H`icSW>
?NlicSg_>Lhe[@LicP8]J`03=JdmkcW>008e[@05>Li6<DHaBU96<@02?Nl2
@Q002DHa@Q1244HaCW=6<D8@<H`icP03=Jd01CW>?NlmkcW>=Jd00SW>0Sg_
00dicSF]<H`icTHa@Q0icRU:8@PU:Be[<H`Q20025:D00acW8@PHaP022480
0`@Q248@Q0025:D011S65:D@Q1240PaS0`Q200@48@Q21248@P848@88@P<4
8@03248<H`@Q0088@P0436<@Q0aS36<2248236<01@Q236<<Ha2436<00aBU
0Q2400<DYA2436<00`Q200L<H`Q236<<Ha2436<@Q00236<00`Q21248@P03
248236<03a2436<U:BU:CW=F]F<HLia_NgNmJeY6<C6<5:DHaP0248@536<4
248236<248@37>L00aS648@<H`0236<548@01PQ2124<H`Q248@<H`D8@P<<
H`0324848@Q200<<H`<8@P8@Q0075:DHaQS68@PU:AS65:D00PQ201L<Ha24
48@<H`Q236<DYA246<HQ236<CW=BU6LiHaQNmf<H?NlaS1S65:DHaQ2400H8
@P848@<8@P031248@PQ20088@P8<H`<8@P<<H`88@P0336<8@PaS008<H`04
248<H`aS36<348@00`aS48@@Q0035:D248@010aS48@@Q1240aS60QBU00<@
Q0aS36<00PaS00<DYA2436<00QBU0QS600<@Q0aS24800PQ20`aS0PQ200<<
HaBU48@00PaS0`Q200<48@Q224800PaS0PQ200L<H`Q2248DYAcW6<H<H`02
124436<00a245:D@Q00236<01@Q212448@@Q248010@Q0`Q20`@Q0PQ24@@Q
00P8@PaS5:DDYB48<Ha244YB0d8@00E>Le:DDYABU4YB009>L`9:DP04AS5:
DTYBBU82CW<00dYBCW=>L`03DY@014icE[EF]EJe0e:D00=>Le:DCW<00Tic
00=BU5JeE[D00eJe0U[F0UJe0U:D0Tic0e:D00=F]E[FE[D00Tic00=BU4YB
BU801dic25:D00AF]E:DDYAF]@ABU09F]@9BU09>L`03DYA>Ldic00=>L`AB
U0=F]@9BU003E[EBU5Je00=BU005CW=BU4icE[EBU002E[D01E[FE[EF]EJe
F]H00UJe0TYB00E>Le:DE[EJeUJe009JePEF]@=JeP08DYAF]EJeF]INmeJe
DYA>L`=BU09F]@07DYAF]DicDYA>LdYBCW<00e:D00E>LeJeE[EJeU:D009>
L`04DYAF]E[FF]H3E[D01E:DE[EF]EJeF]H015Je0U[F00=F]E[FE[D00U[F
00=Nme[FF]H00eJe0Ukg00AS65[FF]IJeP=F]@=JeP07E[EJeU[FF]INme[F
E[D00U[F0Ekg0E[F0D8@0008124030Q2124000aS;F]W>Dic<H`mkcW>=Jda
S08e[@03>Lhmkcg_00DicP05=JdicSF]>Lhe[@02;F/01c6<>LhicSW>=Jdi
cT8@009:DP03AS4mkcg_00E240=:DP06?Nle[CF]=JdaS3F]0SW>00@mkcW>
>Lhe[@<icP04?Nle[CF]?Nl2@Q001cg_:DXQ22DY:DXaS248008DY@046<HQ
21S636<224800`@Q36<<H`036<H25:D00`aS2488@P03248312400`Q21244
8@031245248336<8248336<248@25:D011245:DDY@aS1PQ210aS00D@Q0aS
2488@P@Q00@8@P0A36<@Q1248@PYBU:DF]IW>GNmKg]kgV]J@Q0]JaBU6<HD
Y@0336<248@324800`@Q36<8@P0236<00a246<HLi`027>L536<248@01@aS
2488@PaS24800`aS00D8@P@Q12448@Q200<<H`88@P03124<H`aS008<H`04
248<HaBU48@25:D01AS68@PQ21cW48@00PQ200@<Ha2448@<H`88@P8DY@0;
6<HU:CF]CW=F]F<HIcUNmf<H?Nl]J`035:D236<010@Q2488@P@Q0PQ210@Q
00<8@P@Q24801`Q200<<H`Q236<00`Q20`aS0`Q20PaS0Q2400@<H`Q236<@
Q08HaP<@Q08<H`0648@DYAS66<HDYAS61PaS0Q2400<DYA245:D00QS60PaS
0P@Q00<8@PaS36<00PQ200@<Ha2448@@Q088@P031248@P@Q00D8@P0@36<8
@PaS36<8@QBU6<HDY@aS1248@PaS248<Ha245:D248@010Q236<48@Q21P@Q
00<8@P@Q12401@@Q00<8@P@Q12403`@Q0PQ200XDYAS69BTe[D8@AS5243g_
@Q1>L`=BU004BU9>LdYBBU82AS42BU84CW<2BU800dicDYA>L`02DY@3E[D0
14icDYA>Le:D14ic1UJe0e[F00=BU4icCW<00U:D00=>Le:DF]H00UJe00=B
U4YBCW<00Tic00I:DTicCW=>LdYBCW<5DY@00dicDYABU00?DY@2CW<015:D
CW=:DTic1E:D00=JeUJeCW<00U:D00=F]E:DDY@00U:D0Tic0U:D15Je00AJ
eUJeF]IJeP9BU004BU9>LdicCW<2E[D00e[FE[EF]@03E[D015:DF]IF]E[F
0UJe0U:D0e[F00EF]DicCW=F]E:D009F]@=BU0E>L`ABU003F]IF]E[F009>
L`9BU09JeP03E[EBU5:D009BU09JePMF]@04F]IF]EJeE[D3F]H3E[D00e[F
G_MNm`02G_L2F]H00e:DE[EJeP03F]H015JeF]IF]Ekg0U[F0UJe00=JeUkg
E[D00D8@00002000124000@Q00048@00248312402@Q2;F]W>Dic<Ha243W>
?NlicP04=Jd01Cg_@Q0mkcW>=Jd00SW>0SF]00@icSg_>Lhe[@<aS08icP08
<Ha2448@BU96<D8@?Nm2409:DP924004?Nm6<D8@?Nl2>Lh4=Jd2?Nl3>Lh0
236<=Jde[C6<@Q0mkd8@AS42<H`00bDY7>LQ2002;F/00bDY5:D@Q0026<H0
0a24248<H`0224801A247>LYBRU:8@P00RU:00@LiaBU2488@P8<H`88@P03
1248@P@Q00<48@L8@P0348@DYAS6008@Q00<6<HQ21S648@8@Q2424848AS6
<Ha243F]0a2420Q200H@Q0aS48@DYA2436<2124424803PaS48@HaQcW6<Hi
cTicIcU[FTYBAS4icRDY7>L25:D248@236<248@01ABU48@8@PQ236<01124
0aS600<DYA2448@00Q2400DHaQcW7>LHaQ2400848@0436<@Q12448@42482
36<00a2436<@Q00236<010Q236<<H`Q20Q2400<DYAS65:D01AS600DDYA24
2488@PaS0088@P0436<@Q1BU48@26<H01BDYE[E[FW>LE[D00RU:00<Q21S6
6<H00QBU00<<H`Q224803@Q210aS00<8@PaS36<00PaS0PQ20PaS00P@Q0Q2
24848@Q21248@PaS0a2400H<Ha246<HDYA245:D248@05QBU36<<HbDY;F]N
mf]JAS4mkaBU48@HaQ245:DHaR48=Jd]Jc6<=JdHaPaS0P@Q00<@Q0aS2480
0PQ200<<Ha2436<01PQ200@48@Q2124<H`@8@P0436<@Q2488@P29BT00aS6
5:D<H`0236<248@00aBU36<<H`02248512401PQ212448@Q21248@P<48@03
24848@@Q00@48@03248000@Q00848@0300048@@Q00<48@030008@PaS008@
Q0076<H]Jcg_BU8mkcW>AS401Dic0U:D0TYB00I244YBCW=>Le:DCW<4BU80
14icDYA>LeJe0e:D00EF]E:DE[EF]E:D00=>L`04DYAF]EJeE[D2F]H01eJe
DYABU5JeF]IBU4ic009:DP05CW=F]E[FDYA>L`02DY@014icBU9>Le:D0Tic
0TYB0U:D00=F]E:DDY@015:D00=>Le:DDY@02E:D00=F]DicDY@00Tic00EB
U4icDYABU5Je00EBU003E[EBU5:D00=BU09>L`05DYA>LdicDYA>L`02E[D0
15[FDYABU5:D0UJe00=JeTicCW<00Tic00=F]E[FE[D00U[F1EJe00AJeUJe
F]IF]@9BU0=JeP03E[EBU5Je00ABU09F]@9BU09>L`03DYA>Le:D009>L`=F
]@9>L`05DYAF]E[FE[EJeP03E[D01U:DE[EF]EJeDYAF]@9BU004E[EJeU[F
F]H2E[D01E[FE[EF]E[FE[D00e[F00=F]E[FG_L00e[F0UJe0e[F00EF]E:D
E[EJeUJe00AJeP03E[EJeUJe004mk`002`@Q00L8@Re[HaQ>LcF]?NlicP02
=Jd01S6<=Jde[CW>@Q0mk`8icP03=JdmkcW>008e[@<icP03=JdaS3F]00@e
[@05?Nm6<DHaAS4mk`02@Q02AS45@Q000cg_=JdicP02=Jd0136<>Lhmkcg_
0cW>0SF]00XaS3F]>LhmkdHa@Q0aS2e[9BTLi`8U:@07;F/Q21S66<HLiaS6
48@00PQ200/<H`Q25:DLibDY:DXQ22U:9BTLia240088@P<<H`0624848@@Q
24848@Q20P@Q1PQ200<@Q1S65:D00Q2400dHaQcW6<H@Q0Q236<8@P@Q7>Le
[D8@<H`@Q00236<224801PaS2488@P@Q248<H`<@Q00:5:D@Q0aS24848@Q2
1248@PaS48@25:D27>L02CW>DYAW>FLiCW=6<CW>8@PLi`025:D02A2436<<
H`Q248@DYAS648@<H`0224800a245:D@Q00248@26<H02QBU48@@Q1BU48@D
YAcW8@PDY@aS0P@Q0PaS00@@Q0aS12448@88@P8<H`8@Q08<H`03248<H`aS
008<H`8@Q08DY@<HaP047>LHaQBU5:D324804PaS48@8@PaS48@HaQ245:DH
aR48F]I[FVmkF]HU:BU:7>LHaP8DY@0348@<H`aS008<H`88@P051248@PQ2
24848@0224800`@Q248<H`0336<2248236<00a2436<8@P0224800`aS48@@
Q0032482124236<01A2436<@Q1BU6<H00QBU0a2400TDY@aS48@U:Be[F]I[
FTYB<H`00Q2400DHaQBU48@HaQcW00<aS005;F/DY@aS1248@P0236<42483
36<224800`@Q24848@08248010aS48@Lib480RDY0QBU10aS0Q240`aS00D8
@P@Q12448@Q200D48@0724848@@Q1248@P@Q24801@@Q00D000@Q12448@00
00L48@88@P045:D@Q1cW;F/2@Q02?Nl01D8@CW=>Le:DBU800Tic00=BU4ic
AS400THa00E>Le:DDYA>LdYB009>L`03BU9>LdYB00=BU008E[EBU5:DDYAF
]E:DCW=BU09>L`9BU003E[EJeU[F00AF]@04DYAF]E:DDY@2BU801E:DE[EJ
eUJeCW<00e:D0Tic00EBU4icBU9:DTic00ABU005CW=BU5JeDYA>L`04DY@0
14icDYABU4ic0e:D00=F]E:DDY@00Tic0U:D00A:DTicE[EF]@ABU003E[EB
U5:D009BU004E[E>LdicCW<3DY@014icDYAF]E[F0UJe00MBU5JeE[EJeUJe
DYA>L`02BU83E[D3F]H2E[D01e:DE[EF]EJeF]IBU4ic009F]@9JeP03DYAF
]E:D00=BU0=F]@04DYA>LdYBBU83DY@2CW<015:DE[EBU5:D0Tic00AF]E[F
E[EJePQF]@9BU0=F]@03F]IF]E[F00EF]@=JeP04E[EJeU[FG_L2F]H3E[D3
F]H4E[D5F]H00eJeF]IF]@01?Nl0000500048@0012400003124020Q20004
8@Q2:DYS64YB=Jd2?Nl03SW>=Jde[CF]<H`e[Cg_@Q0mkcW><H`e[CW><H`2
=Jd3>Lh00cg_>LhicP03=Jd013g_@Q16<DHa0cg_00@icSg_>Li240Dmk`06
>Lhe[CF]>Lhe[CW>0d8@00DicS6<<H`e[C6<008mk`04>Lhe[Be[:DX29BT2
8@P011cW6<HHaQBU0Q2400<DY@aS48@00PQ200<<Ha245:D00aBU00@HaRDY
9BTQ208HaP057>LHaQS636<8@P07124224801PaS48@@Q0aS48@HaP8Li`03
5:D<H`aS00<@Q00736<DYAS68@PU:AS648@00`Q200D48@Q212448@Q200@<
H`8@Q00336<8@PQ200<8@P8<H`0=248<Ha2448A246LiLiaNmbU:5:DLiaS6
48@00aS600LDY@@Q1248@Q245:D@Q002248236<348@35:D03QS648@8@QBU
9BTaS2U:6<HDYAcW48@8@PaS48@25:D4248348@25:D27>L01Q2436<<H`aS
5:DHaPDDY@046<HLiaBU5:D2248236<26<H0312436<8@P@Q48@DYAS6BU9S
65:D;F/@Q08Li`035:D8@PQ2008<H`L8@P0436<@Q0aS24821243248336<2
48@01`aS2488@Q246<HLiaS6008<H`0324848@Q200848@88@P045:D@Q124
48@336<00a245:DHaP046<H011cW;F/aS5:D0f<H00HicQS65:D<HacW:DX3
9BT01A2436<8@PQ236<010Q20`aS10Q200<48@Q224800PQ200/48@Q22484
8@Q27>LQ23W>=JdQ21cW00@<H`0348@<Ha24008@Q00436<8@P@Q24891242
48@01@aS24848@@Q24803@@Q00`000@Q12448@aS48@<HaBU9BTe[DHa?Nl2
@Q001dYBCW=>LdicBU9BU4ic009:DP05AS5:DTicCW=BU003CW<3BU800dic
DYABU003DY@4E[D2DY@014icDYA>Ldic0eJe00=JeUJeE[D00eJe0Tic0TYB
0U:D0UJe0e:D0Tic00=:DTicDY@00Tic0U:D00EF]E:DE[EBU4ic009BU09>
L`IBU007F]IBU5:DCW=BU5JeDY@014ic00=BU4icBU800U:D0UJe0Tic00=B
U4icDY@015:D00=>Le:DDY@01E:D0UJe00EJeUJeDYABU5Je00ABU0=F]@9J
eP9F]@03DYAF]EJe00=JeP9F]@03DYAF]E[F009JeP08E[EJeTicCW=F]E:D
E[EJePMBU0E>L`04DYAJeU[FE[D2DY@00eJeF]IF]@03DY@00dicDYABU003
DY@01EJeF]IJeUkgF]H00UJe00=BU5JeF]H00e[F00=F]E[FE[D00e[F0eJe
0U[F0UJe0e[F00=F]E:DE[D00U[F00=F]E[FDY@00Cg_000;124020aS:DYN
mdYB<Ha243g_>Lh2<H`013F]<H`e[CW>0Sg_00@icSF]=JdaS0<e[@8icP05
?NlicSF]=JdicP02=Jd013g_@Q16<D8@0SW>0cg_00M243g_@Q0icSg_@Q0m
k`03=Jd023g_<H`e[Cg_AS4mkcF]<H`3=Jd013W>?NlicSW>0RU:00HU:B48
8@PLiaS67>L26<H011BU48@@Q0aS0`Q200<<Ha245:D00QBU0QS60RDY00<Q
21cW6<H00QcW00@DY@aS2488@PD48@<8@P0:36<@Q12436<@Q1S67>LHaQ24
36<348@031BU36<DYAS68@PU:AS648@8@P@Q36<8@P848@03248<H`Q2008<
H`<@Q00636<8@PQ2248<H`Q20`aS00X8@QS648A246]JLiaNmbU:6<HQ208D
Y@046<HLiaBU36<2248011245:D@Q0aS0PQ200D<Ha2448@@Q0aS00<@Q008
6<H@Q0aS48@U:C6<;F/DY@8HaP0448@8@PQ248@25:D010aS1248@PQ20a24
00PDYAS66<HHaQ2436<8@PaS0aS600@DYA2448@DY@<HaP0C5:D<H`Q236<@
Q1BU6<H<H`Q236<8@Q246<HLidYBG_M>Lc6<48@00QcW00@DY@aS248<H`P8
@P0436<@Q0aS248212400`Q2124<H`0236<02a2436<<Ha2436<8@PaS5:DL
iaS636<00`Q200<48@Q212400PQ200L@Q1BU48@@Q0aS248@Q0025:D27>L4
6<H2<H`01U:DIcUNme[F>LhHaP8@Q0057>L]JbDY:DXQ200248@4248010aS
1248@PQ20`aS00D48@Q21248@PaS0088@P0:1248@P@Q24848@Q26<HU:CW>
=Jd27>L236<00a2436<@Q00448@00`aS2488@P04124010Q21248@PQ20P@Q
00@8@QBU48@8@P`48@0300048@@Q00@48@88@P0648@<HaBU:DXe[D8@0Sg_
00=6<DYBBU801Dic0TYB00=6<DicCW<00U:D00E>LdYBCW=:DTHa009:DP04
DYA>Le:DDY@3E[D015:DE[EBU5:D0dic0e:D00AJeUJeE[EBU0=F]@05DYA>
LdHaBU9BU002E[D3DY@01EJeCW=:DTicDY@00Tic00=:DTicDY@00UJe0e:D
00=>Le:DDY@01U:D0UJe0e:D00E>Le:DDYABU4YB00E>L`IBU006CW=BU5:D
DYAF]E:D0Tic00=BU4icDY@015:D00=F]E[FE[D00UJe15:D00I>Le:DDYAB
U5JeF]H3E[D00e:DE[EJeP03F]H3E[D4F]H00eJeDYABU002DY@00eJeF]IJ
eP07DY@024icDYA>LdYBCW=BU5[FE[D2DY@5E[D014icDYABU5Je15:D0UJe
00=Nme[FE[D01EJe15[F00IF]E[FF]INme[FDY@3E[D3F]H00eJeF]IF]@02
E[D2F]H2E[D1F]H1DY@1?Nl0000700048@00124000@Q00000`@Q00H000Q2
;F]S64Ha<H`2@Q000cg_=Jd]J`02;F/01cF]>Lhe[CF]<H`icSF]008icP8e
[@09<H`e[CW>?Nm243g_>Lhe[CW>00924003AS5243g_008icP05=JdicT8@
@Q0mk`06>Lh00cg_=Jde[@02<H`2>Lh2<H`01CF]<H`aS3W>?Nl00SF]0RDY
0RU:00HU:B486<HDYAS65:D348@236<324800`aS48@@Q00648@02QBU36<8
@Q245:DQ22DY5:D<H`Q20P@Q00<8@P@Q24800`Q200@<H`Q236<8@P<@Q0<D
Y@8@Q08HaP8DY@037>LDYA2400848@88@P0:36<8@P@Q36<DYAS648@8@PaS
248336<00`Q236<@Q00224801@@Q248@Q1249BT00SF]00<YBQS648@00QS6
00HDY@aS36<8@PaS48@236<348@536<248@01QBU48@@Q1245:D@Q08HaP0@
7>LQ21cW6<HLiaBU48@DYAS68@PLiaBU48@<H`Q248@25:D27>L00b486<HD
Y@0236<248@636<00aBU48@@Q00436<010Q236<<H`aS0`Q200/<Ha245:DQ
21cW6<HDYA246<HLiaBU00@<H`0348@<H`aS00848@0436<@Q1BU5:D22480
0`@Q2488@P04248448@010aS248<H`aS0QBU00L@Q0aS2488@PaS24848@04
248236<01A2436<8@QBU8@P00bDY00d]Jcg_@Q1243g_:DXQ23F]E[EW>Dic
9BT8@P035:D00a245:D<H`0324800`aS2488@P04248010aS2488@PQ20PaS
1@Q200X48@Q212448BDY>Li:DSW>5:D@Q088@P@<H`8@Q003248<H`aS008<
H`0324848@@Q00D48@04248<H`Q2248412400`Q212448@0212400`Q21244
8@031240300012448@@Q00048@Q248@<Ha248@P]J`E24003AS5>LdYB00E:
DP96<@04CW=BU5JeDY@6CW<5DY@00eJeF]IJeP04DY@2CW<01DYBDYABU5Je
G_L00U[F0UJe00UBU4YBDYABU4YBCW=BU5JeF]H00U:D2Dic0e:D0UJe0U:D
00=>Le:DDY@00U:D0Tic0U:D0UJe00EBU4icDYAF]E:D00A>L`06DYA>Ldic
BU9BU5Je0U:D00=>Le:DDY@00dic00=BU5JeDY@015:D0Tic00=:DTicE[D0
0U[F00=F]E:DDY@00UJe0e:D00EF]E[FE[EF]E:D00=JeP9F]@03DYAF]E[F
009F]@9BU007E[EJeUJeDYA>Le:DE[D00e[F00=F]E[FDY@015:D00AF]E:D
BU9:DP9BU003E[EJeUJe009JePAF]@=BU004CW=BU5:DDY@2E[D015[FE[EJ
eU[F15Je00EJeUkgF]IJeUJe00=JeP03E[EJeUkg00=JeP03E[EJeU[F009J
ePMF]@5JeP5F]@52400020@Q00P8@P@Q1248@RU:G_M:DS6<0Sg_00<icSF]
;F/00S6<0cF]00<aS3F]=Jd00cW>00/e[C6<=JdaS3F]?Nm6<Cg_>Lhe[CW>
00924096<@0:?NlicSF]=JdicSg_@Q0mkcW>=Jd2>Lh01Sg_>LhicSF]<H`e
[@8icP8e[@8aS003=JdaS3W>008icP03<H`U:BDY00<U:@048@PLiaBU6<H2
48@02`aS48@<H`aS24848@Q236<DYA245:D00`aS0QBU00D<H`Q2248DYAS6
008Q20035:D<H`Q200@48@H8@PD<H`035:DHaQBU008@Q0095:DHaQBU5:DH
aQBU48@<H`@Q00@8@P05124<HaBU5:D@Q0022480112436<<H`Q210aS00<8
@P@Q24800Q2400DU:CF]<H`]JaS6008DY@8HaP0348@<H`Q2008@Q0<<H`07
5:D@Q124248<H`Q236<01a240QBU00<Lib487>L00QS600<LiaS648@00QS6
0QcW0a2400H<Ha2448@DYAcW8@P27>L348@236<01Q2436<<H`aS248<H`8@
Q0045:D<H`Q2248436<02PQ236<8@PQ236<@Q1BU7>LQ21S60aBU00<HaQBU
36<01@aS00/8@P@Q124<Ha245:D@Q0Q21248@P@Q00@8@P8<H`<@Q0<<H`06
48@DYA2448@8@PaS1PQ200<<H`Q224800Q2400D8@PaS6<HU:BU:008Q200B
9BTmkdHa@Q0icRe[8@PicUkgIcU:DR4836<@Q1BU48@DYA240PaS2PQ200<4
8@Q224800PaS0`Q200@48@Q21248@P848@09:DXicTic>Lh<Ha2436<8@PaS
0088@PD<H`0448@8@PQ2124224831245248412400`Q21240000912400`Q2
12448@02124224801A2436<DYB48<H`00T8@00=6<D8@AS401dYB0dHa00I>
Le:DDYABU4YBCW<2BU82CW<00e:DCW=BU002DY@2F]H2E[D2DY@2CW<00dYB
CW=>L`02E[D4F]H01E:DCW=>Le:DCW<00U:D00A>LeJeE[EF]@9BU003BU9>
LdYB009>L`05BU9>Le:DE[E>L`02DY@2E[D00e:DCW=BU002DY@2CW<01E:D
CW=F]EJeDY@00Tic00EBU5JeDYABU4YB009>L`06DYA>LdYBCW=BU5Je0U:D
00I>Le:DCW=>Le:DCW<4DY@014icDYABU4ic0TYB00UBU5[FE[EJeUJeDYAF
]E:DE[D00e:D00AF]E[FE[EBU09F]@9JeP9F]@03DYAF]EJe009JeP9BU0=F
]@03DYA>Le:D00=JeP03G_MF]EJe009BU003CW=F]EJe009BU005CW=:DTic
DYAJeP03E[D2F]H00eJeDYABU002DY@01TicDYABU5:DE[EBU09F]@=JeP=F
]@AJeP03E[EJeU[F00QJeP03E[EJeU[F009JePMF]@5JeP5F]@52400000P0
00@Q00048@00124000Q20`@Q00T8@S6<IcU:DS6<?Nm243W>=Jd00c6<00<i
cSF]=Jd00S6<00DicT8@>LhicS6<008e[@05<H`e[CW>@Q0mk`02>Lh2AS42
@Q02AS400d8@>LhicP03>Lh2=Jd2>Lh01D8@>LhicSg_=Jd00RU:00L]Jcg_
@Q0mkcF];F/aS002>Lh03S6<;F/e[Be[9BTQ22U:;F/U:AcW6<HLiaBU48@2
36<348@336<01ABU6<HDYA2424800PaS0PQ200H48@Q236<8@Q246<H29BT0
0aS636<8@P0324801`@Q2488@P@Q24848@Q200<<H`D@Q08DY@0536<DYAcW
7>L@Q00212400`Q236<8@P02248236<248@00`Q236<8@P0336<3248010@Q
36<8@PQ20PaS00<@Q1BU5:D00a2400<DYA2448@00PaS0QBU00DLiaS65:DD
YA2400<<H`@@Q00436<@Q1245:D348@25:D031S67>LLiaS67>LDYA248@Pe
[CW>:DX@Q08DY@0348@DYABU00<HaP057>LHaQcW7>L@Q00536<224801`aS
248<H`Q236<8@PaS00@8@P@<H`0348@<H`aS008<H`0848@<HaS69BTQ21BU
248<H`8DY@0348@<H`aS008<H`8DY@8@Q0<8@P041248@PQ2248236<25:D0
112436<@Q1240QS60PaS0`Q20PaS10Q201h48@Q224848@aS48@DYA246<HQ
23F]E[EJeVLiHaQNmfLiAS5242U:7>LYBSg_AS4YBQ241248@QBU48@236<5
248212400`Q236<8@P0224801@aS6<HLiaS648@01@Q200P48@Q28@Pe[CW>
:DX<Ha240PaS00@8@P@Q2488@PT<H`<8@P8<H`0524848@@Q1248@P0?1240
0`001248@P0412402PaS48@HaQS69BTe[D8@BU96<D8@0dYB0THa0TYB00M>
LdHaAS5>Le:DE[EBU007CW<4DY@2E[D5DY@3CW<01e:DBU9>LeJeF]INmeJe
00=>L`9F]@05CW=:DTicDYAJeP02E[D4DY@014icAS5:DTic0e:D00=>LeJe
E[D01U:D00E:DTicCW=BU4ic009BU004CW=BU4icE[D2DY@2CW<6BU8014ic
DYABU5:D1Dic00=BU5JeE[D00e:D0dic00=:DTicDY@00UJe00=BU5JeF]H0
0UJe00=BU4icE[D015Je0U:D0UJe00AJeUJeE[EJeP9F]@IBU004E[EBU5:D
DY@2E[D3F]H3DY@01TicDYA>LdicBU9>L`9BU09F]@AJeP05E[EJeU[FE[EB
U002E[D01U:DE[E>LdicDYAF]@=JeP04E[EJeUJeE[D4G_L00eJeG_MJeP02
E[D00e[FG_MNm`05F]H01EkgF]IJeUJeF]H015Je0F<H0E[F0D8@000:1240
1`0036<aS6LiBU8]JcW>008mk`03=JdaS36<008aS08e[@0@<H`e[CW>>Lhm
kcW>=JdaS3F]<H`e[Cg_@Q0mkcW>?Nl2AS42@Q001DHaBU8mkcW>=Jd01CW>
0Sg_00U243g_>LhicS6<;F/YBS6<>Lh00Sg_0c6<00He[CW><H`]Jc6<;F/2
9BT022e[<H`U:AS65:DLiaBU48@636<348@25:D00a2436<8@P04248236<0
0`Q236<Li`028@P00aBU36<8@P0424800`@Q2488@P0324800`aS2488@P02
48@00aBU48@@Q0025:D01a245:DLiaS648@8@P@Q00<8@P<<H`<@Q00536<8
@PQ2248@Q002248212400`aS2488@P0224800`aS48@DY@0548@436<25:D0
1AcW6<H@Q12436<00a240`aS0Q240QBU0a2400<<HaBU5:D00aS60QcW00HD
Y@aS9BTe[CW>;F/248@45:D26<H37>L26<H248@336<324801PaS2488@PaS
248<H`D8@P0436<8@PQ236<248@00`aS248<H`0236<021S69BTLia24248<
HaBU48@336<0112436<DYABU0Q240PQ200<48@Q224800PQ20PaS0QBU00@@
Q0aS36<@Q08HaP<<H`03248<H`aS00<<H`0524848@@Q1248@P0236<02124
5:D@Q1BU9BTe[E:DF]H2IcT03E[FHaQ:DSW>;F/Q22U:?Nm242DY48@000aS
008@Q00336<@Q0Q20088@P041248@PQ236<324801`@Q36<@Q1S67>LDYA24
0088@P0<36<8@PaS1248@RDY=JdicRU:36<DY@aS0PQ200<48@Q224800`Q2
00<<H`Q248@00PaS0`Q20PaS00<8@P@Q12401@@Q00<8@P@Q12400P@Q00<8
@P@Q00000`@Q00<000@Q12401@@Q00T8@PaS36<DYAS68@PicT8@BU801DHa
0dYB00Q>LdYBAS56<DYBDYAF]E:D24ic00QBU4icDYAF]E[FE[EBU4ic0e:D
0dic01=:DU:DE[EJeUkgE[E>LdYBDYAF]E:DCW=:DTicE[EBU5[FE[E>L`03
DY@3BU800dicDYABU003DY@2E[D5DY@3CW<4DY@2CW<2DY@00eJeDYA:DP05
BU83CW<3DY@00dicBU9>L`02CW<2DY@2E[D2CW<01E:DBU9>LdYBCW<00U:D
1EJe0U:D00M>Le:DDYAJeU:DE[EBU002E[D00e[FE[EF]@02E[D00e[FE[EF
]@07DY@014icDYAF]Ekg0U[F0UJe00E>Le:DDYAF]Dic009:DP03CW=F]E:D
00=F]@03G_MJeU[F009F]@9JeP04E[EBU5:DE[D4DY@00eJeF]IJeP02E[D0
15[FE[EF]E[F0ekg0e[F0UJe00EJeUkgF]IJeUJe009JeP06G_MJeU[FE[EJ
eU:D15Je0Ekg0E[F0Cg_0000100012448@0010@Q00/8@P@Q1248@Re[G_M2
42e[>Li243g_008icP8e[@08>Lhe[C6<=JdaS3W>?NlicP@e[@<aS006>Lhe
[CW>?Nm6<DYB0T8@00I6<D8@?Nle[CW>?Nl2>Lh0136<>Lhe[C6<0cW>00<e
[Be[<H`00cW>0Sg_0cF]00<aS3F]<H`00SW>00LaS2U::DXicT8@>LhU:@02
6<H00aBU48@8@P02248336<02A2436<@Q2489BTLi`aS24848@0224831243
24801`aS5:DLiacW6<H<Ha2400<8@P031248@P@Q00<8@P0336<@Q124008D
Y@8@Q08DY@0348@DYABU008@Q00324848@Q20088@P<<H`8@Q00336<8@PQ2
008<H`<8@P<48@09248<H`Q224848A249BT]JacW0088@P0448@<H`aS5:D2
7>L01aS65:DLiacW5:D<H`Q2008<H`8@Q00336<@Q1BU008@Q00336<@Q0aS
0088@P0336<@Q12400D@Q00:5:DLiacW6<HLibU:;F/U:AcW6<H27>L26<H3
5:D236<010Q236<<H`aS10Q200@<H`Q22488@P<<H`@8@PP<H`05248<Ha24
5:DHaP0348@25:D00aS648@@Q00248@25:D00a242488@P02248236<00a24
5:DDY@025:D00a2436<Q2002<H`012DY36<<H`aS0`Q200D<Ha2448@8@PaS
0088@P0936<8@Q245:DQ21cW9BTe[DHa009_N`9g_@0;LiakgV]JHaPicQcW
5:DHaR486<H8@P0212400`aS248<H`0324851246248248@00`aS2488@P02
248336<01@Q248@@Q2DY8@P00QS600P8@P@Q12448@Q2124<Ha240`aS00<8
@PaS48@00PaS00<@Q0Q224803P@Q00D000@Q12448@0000L48@0424848@aS
48@36<H022e[?Nm:DTHa?Nm6<DYBAS45BU82AS4014YBCW=BU5Je14ic00AB
U4icCW=>L`=BU003E[EBU5Je009BU09>L`03DYA>Ldic009:DP07CW=F]E[F
F]IF]E:DCW<00U:D00EF]E:DCW=:DTic00AF]@06DYAF]DicCW=:DTic0U:D
0dic1e:D00=>Le:DCW<00Tic1U:D00A>Le:DDYABU09>L`9:DP9>L`03AS5:
DTYB009BU09>L`9BU0=F]@05CW=F]E:DCW=:DP03CW<00dYBCW=BU002E[D0
0e:DE[EBU002DY@025JeDYAF]E:DE[EBU5JeDY@3E[D00e:DE[EF]@02F]H3
DY@2CW<3DY@2CW<4DY@00eJeDYABU005CW<00e:DE[EBU002DY@01EJeG_MJ
eU[FE[D00e[F00=F]E:DE[D00eJe00ABU5JeDYAF]@9JeP03E[EJeU[F009N
m`9JeP04G_MS65[FF]H2E[D00ekgF]INm`02F]H2E[D00e[FE[EJeP05F]H2
DY@00eJeF]IF]@01@Q000003124000@Q00848@0300048@@Q00<48@08248a
S5kgAS4YBSW>@Q0mk`@e[@04>Lhe[CW><H`2=Jd01CW>?NlicSF]>Lh00SF]
0S6<00@e[CW>>Li2409:DP924004AS5243g_=Jd3>Lh02CF]>LhicSF]<H`e
[Cg_>Lhe[@02;F/01CF]>Lhmkcg_>Lh00SF]00LaS3F]<H`aS3F]>Lhe[@02
:DX01SW>@Q0e[B486<HLi`8@Q088@P0436<8@Q2448@236<01Q247>LQ21cW
48@48@88@P031248@PQ200<8@P06124<HaS67>LQ21BU0`aS10Q200<48@Q2
24800`aS00<@Q1BU5:D00Q240QBU0Q240QBU00<<H`Q212400PQ20PaS00<8
@PaS48@00Q2410Q200<<H`Q212400P@Q00@8@PaS36<<H`848@075:DU:BU:
8@P<H`Q248@00PaS00@DYAcW8@PLi`8HaP8DY@0448@<H`aS36<448@010aS
48@@Q1240PaS0`Q21124018DYA2448@DYAS67>LDYAcW9BT]JbDY6<HDYAcW
8@PLiaS65:D348@436<524800`@Q24848@0236<01@Q236<8@PQ236<00`Q2
0`aS00<8@PaS24800`aS00<DYA2448@00a2400LDYA245:D@Q0aS48@DY@02
48@4248236<248@25:D02QS65:D<HacW:DXaS2DY36<8@PaS0PQ20PaS00<@
Q0aS36<00PQ20`aS00L@Q1S68@PQ22DY=Je:DP02Kg/03G_NMkecW7_NJeYN
mcF]6<H@Q1S69BTHaPQ200848@@<H`041248@P@Q248212400`Q21248@P02
24800`aS248<H`0248@01@aS24848@aS24800`aS00LDYAS68@PQ21S65:D<
H`022482124436<2248636<324800`@Q24848@0312400`Q212448@061240
0`0012448@09124020aS48@HaQBU7>L]Jcg_BU82@Q000dHaBU9:DP03AS45
BU84DY@3CW<2DY@3CW<2DY@2E[D015:DE[E>Le:D0dic00E:DTicBU9BU5Je
009JeP03E[E>Ldic00ABU09>L`9BU0=F]@9BU008CW=:DTYBCW=BU5JeCW=B
U0=>L`EBU003E[EBU4ic00A>L`=BU004CW=BU5:DE[D2DY@3BU801TicBU9:
DTHaCW=BU0A>L`08DYAF]E[FE[EBU5JeDYA:DP9>L`05DYA:DTicCW=BU003
E[D2DY@025JeDYABU5JeDYAF]E:DE[D2DY@4E[D015:DE[EF]EJe0e:D0Tic
00=BU5JeDY@00Tic00EBU5JeE[EBU5Je009BU0=>L`07BU9>Le:DDYAF]Dic
DY@00e[F00=F]E[FE[D00U[F0UJe00ABU5JeE[EF]@=BU004E[EJeUJeE[D4
F]H015kgF]INmekg0U[F00=F]E[FF]H00e[F0UJe00EJeUJeF]IJeUJe00=J
eP06E[EBU5:DE[ENmeJe0D8@000212400`001240000312402@Q200048@Q2
<HaNmd8@:DXe[@03>Lh2?Nl00cW>=JdaS002=Jd0136<=Jde[CF]0S6<00Xe
[CW>>LhicS6<=JdaS3W>@Q0mk`924003?NlicT8@00924003?NlicS6<008i
cP8mk`03=JdaS36<008aS007=Jdmkd8@>Lhe[C6<>Lh00Sg_014icS6<>Li2
43g_>LhYBRDY<H`icT8@>Lh]Jb487>LDYA240088@P0436<@Q12448@236<0
0`Q236<@Q00236<324800`@Q248<H`022482124324800`aS48@Li`036<H2
2482124236<348@25:D00a245:D@Q00248@00`aS48@<H`0436<224800`aS
2488@P0336<224801P@Q24848@Q21248@P848@0324848@Q200<8@P0336<@
Q1BU008DY@056<HLiaBU48@YBP02>Lh0124836<@Q1BU0Q242ABU00<HaQBU
5:D00`aS0`Q20PaS00X8@PaS36<@Q1S65:D@Q248;F]:DP9F]@04IcU>Lc6<
8@P348@236<2248236<2248010@Q2488@PaS0`Q200<<Ha2448@00Q240`Q2
00<<Ha2436<00PaS00<@Q2487>L00R4800DDYA2436<<Ha2400<DY@0@48@<
Ha2448@<Ha2436<@Q0aS6<HQ22U:8@PHaQBU6<H448@03BDY;F/U:AcW36<4
8@Q21248@PaS248DYAS6008@Q006248<Ha24248<Ha240QS6010Q23F]AS5S
66]JLia_NgNmOomg_F]J=JdHaPaS248<H`848@H8@P8<H`0324848@Q20084
8@<8@P0:36<8@P@Q24848@Q236<8@PaS248236<224800`aS5:DHaP0248@0
0aBU2488@P02124224800`aS2488@P02248010aS248<H`aS0Q2400<<H`@Q
12401`@Q00<8@P@Q12404@@Q00<8@Q246<H00QBU00<U:CW>BU800T8@00E6
<DYBBU96<DYB0096<@05@Q16<DYBDYA>L`02DY@00dicDYA>L`02CW<00e:D
CW=BU002CW<2DY@01eJeF]IF]E:DCW=:DU:D00=>L`9BU09F]@9JeP9F]@E>
L`05BU9BU5:DDYAF]@03DY@4CW<2BU800dicDYABU003CW<015JeDYABU5:D
0UJe00ABU4YBCW=F]@9BU00=E[EBU4icCW=BU5JeDYA>LdHaCW=:DTicBU80
0THa00A:DTicE[EF]@=BU09F]@03DYA>Le:D009BU09>L`03DYA>LdYB009>
L`=F]@=BU09F]@04DYAF]E:DCW<2DY@02E[FG_MJeU:DE[EBU4icDYAF]@02
DY@4CW<01E:DCW=BU4icE[D00U:D0Tic0e:D0dYB00IBU5[FF]IBU5JeDY@2
F]H3E[D01e[FE[EJeUJeF]IF]E[F009F]@03DYAF]EJe009F]@9JeP=Nm`9J
eP9Nm`03HaQJeU[F009F]@AJeP05E[EJeUJeF]IF]@02F]H015JeG_MJeU[F
1EJe0D8@00000`0012448@071240200036<aS5kg@Q0YBSF]?Nl3>Lh013g_
>Lhe[C6<0SF]00DaS3F]=Jde[C6<00De[@<aS006>Li2448@AS5243W>0cg_
00=243g_>Lh00SF]0cW>00He[C6<<H`aS2e[>Lh2@Q000cW><H`]J`04>Lh0
436<=Jdmkcg_>Lh]JbU:<H`icT8@>LhU:AcW8@PDY@aS0PQ20PaS0Q2400<<
H`Q236<00PaS00H@Q0Q224848@Q2124336<00`Q200048@03248248@01AcW
6<HHaQBU36<00PQ200@48@Q2248<H`@@Q0045:D@Q1BU48@336<00a2436<<
H`0336<5248236<00`Q212448@0224800`@Q2488@P031245248236<35:D0
2QS67>LDYA24:DXmkcW>9BT8@Q240aBU00@@Q1BU5:DHaPDDY@046<HDYABU
36<4248236<01@Q236<<H`aS48@00QBU00X@Q248:DY:DUkgE[ENmdic;F/L
i`<@Q00336<8@PQ2008<H`88@P848@D8@P8<H`0348@<H`aS00H<H`05248<
Ha245:DHaP027>L01B485:DDY@aS24800Q2400<HaQBU5:D00`aS0Q240`aS
00DDYAcW9BTQ21S6008DY@8@Q08DY@059BTYBRDY8@P<H`03124224801PaS
5:DHaQS636<8@P@<H`0A48@HaQcW9BTicTYBIcU[FW>LKg]g_GooLiaW>C6<
6<H<H`02248412462484124424800`@Q2488@P07248020aS48@8@PQ236<D
YAS65:D248@00`aS24848@0212401@Q236<<H`Q212400PQ21@aS0`Q20P@Q
00D000@Q24848@Q201<48@09248<Ha245:D@Q1S6:DXicTHa008mk`07AS5:
DTYBAS5:DTHa@Q000THa00=:DTicDY@00e:D00E>Le:DCW=>Le:D00=>L`9B
U0AF]@0ADYA>LdYBCW=BU4icBU9>Le:DE[EJeUJeF]IF]E:DCW=BU002CW<0
1DYBCW=>Le:DE[D00e:D0dic0TYB00A>LdYBDYAF]@9>L`05BU9BU5:DE[E>
L`02E[D2DY@2CW<2DY@00eJeDYABU002CW<015:DE[EBU4ic1DYB00=6<DYB
BU800U:D00EF]E:DDYABU5Je009BU005CW=BU5:DCW=:DP04CW<02TYBCW=F
]EJeDYAF]DicE[EBU5Je0e:D0Tic00=F]E[FF]H00UJe1E:D00=F]E:DCW<0
0Tic0e:D00=>Le:DDY@00U:D0Tic0U:D00E>LdYBBU9:DTic009JeP03E[EB
U5Je00=JeP=F]@05F]IF]E[FE[EJeP02E[D3DY@4E[D3F]H00ekgF]IJeP02
F]H01V<HG_MJeUJeF]IF]@AJeP03E[EJeUJe009JeP03E[EJeU[F009JeP05
E[EBU5JeF]IBU001?Nl00007124000@Q124000@Q00000PQ20P@Q00P<HcF]
JeY6<BDY=JdmkcF]0SW>0cg_00<e[C6<<H`00cF]00`aS3F]<H`aS3F]?Nli
cSF]<H`]JcF]?Nl3@Q001cW>=JdicT8@AS5243W>008e[@8icP8aS0<]J`08
<H`icT8@@Q0mkcF]<H`e[@8icP0=?NlicSW><H`icSg_<H`U:BU:BU9F]DYB
9BT00aBU00<HaQBU48@010aS1@Q200<48@Q224800`Q20PaS0Q240PQ20P@Q
00L8@P@Q248<Ha246<HDY@0436<0112436<HaSg_0U:D00<]Ja2448@00PaS
0Q2410Q200@<Ha2448@<H`D8@P041248@PQ2248212400`Q212448@021243
24801@aS2488@PQ236<00QBU00THaRDY9BTHaPaS6<HQ22U:7>L00PaS00D@
Q0aS5:D@Q1BU00<Li`055:D@Q1BU5:D@Q0026<H25:D336<00`@Q248<H`02
48@04`Q26<HYBSF];F/Q22U:<H`YBSW>CW=F]F]JE[DYBQS61248@PaS00/8
@P8<H`05248<H`aS36<@Q00236<00`Q236<<H`0336<00a246<HHaP026<H0
0aBU48@@Q00248@00aBU48@DY@0248@236<348@011BU6<HLiacW0aBU0a24
00@DYA2436<@Q08DY@0548@<H`aS36<8@P0236<020Q25:DLiaBU36<48@aS
48@236<04@Q248@@Q1cW9BTYBTHaCW=W>F<HIcU_Ne:D@Q0Q21S648@00PQ2
00<48@Q224801@Q20PaS2@Q20P@Q10Q20`aS0Q2400H<H`Q248@@Q1BU48@2
36<324800`@Q2488@P0236<5248336<00a2436<8@P0712400`Q212448@07
12400`0012448@041240300012448@@Q248<HaBU48@DYBDY=Je6<@<mk`0;
@Q16<DYBCW=6<D8@?Nm244YBDYA:DP02CW<01e:DE[E>Le:DCW=:DU:D009>
L`03BU9>Ldic009BU003E[EBU5Je009>L`9:DP9BU003E[EBU5:D00=JeP03
E[E>Le:D009BU09>L`9BU09F]@09DYA>Le:DDYA>LdYBAS5:DTic00ABU09>
L`ABU005E[EBU4icBU9>L`03DY@00eJeDYABU004DY@01dicBU9:DTYBAS5:
DTic00A:DP04CW=F]EJeF]H3DY@01DicBU9:DTYBCW<00U:D0Tic00=:DTic
E[D00U[F00=F]E:DDY@00e:D00=>Le:DDY@00UJe00EJeUJeE[EF]E[F009B
U006CW=BU5:DCW=BU4ic1E:D00=F]E:DDY@00e:D1Dic00QBU5JeF]IF]E:D
E[EBU5[F0UJe00ABU5JeF]IBU0=F]@9Nm`04E[EBU5:DDY@4E[D01E[FG_MN
me[FG_L00U[F00ANme[FF]IJeP9F]@05F]IF]E[FE[EJeP02E[D00e[FE[EJ
eP03F]H3E[D015:DE[EJeU:D0D8@000212400`0012448@0512401`0036<e
[FLiAS4U:C6<00LicP8e[@03<H`e[C6<008aS004;F/aS36<=Jd3>Lh00cF]
;F/aS002?Nl2@Q001SW>=Jdmkd8@AS4mk`<e[@06>Lhe[C6<<H`YBRe[0S6<
00`icTHa@Q0mkc6<;F/e[CW>?NlicSF]<H`2=Jd02Cg_<H`U:C6<BU9JeTHa
8@P@Q0026<H25:D00a2436<<H`0336<01@Q212448@Q236<00PQ200@<H`@Q
1248@P8@Q00336<8@P@Q00<48@88@P0448@DYABU5:D236<224802ABU36<L
id8@DYA>Lbe[36<@Q00536<3248010aS5:D@Q0aS1@Q200<48@Q224801P@Q
00<8@P@Q24801@Q20PaS00<@Q1BU6<H00RDY00<DY@aS6<H00RDY00DHaPaS
36<@Q0aS008@Q0055:DLib487>LHaP0248@25:D01AS67>LDYABU36<01@Q2
01D@Q0aS248HaRU:>LhaS2489BTaS2U:=JeBU5[FIcUBU2485:D48@Q236<0
10Q200<48@Q224801@Q21@aS0Q2400<<H`Q224800`aS0Q2400@HaQBU6<HH
aP8DY@8<H`<@Q08DY@@<H`<DY@046<HLiacW6<H25:D00a2436<@Q00448@3
5:D010aS2488@PQ20PaS00D8@QBU6<HDYA240088@P@<H`8@Q0056<HQ22e[
BU9>L`03IcT017>LDYA242480Q240`Q200<48@Q224800`Q200<<H`Q22480
0`Q20P@Q10Q20`@Q0`Q200<<H`Q236<01PaS00DDYA2448@@Q0Q200<48@D8
@P07124<H`Q236<8@PaS48@00PaS00<8@P@Q124010@Q00<8@P@Q12402@@Q
00<000@Q00001`@Q00d8@PaS5:D@Q1BU9BTe[DHa?NlicSg_@Q16<@03BU82
?Nl01D8@CW=>LdicBU800e:D00=>Le:DCW<024ic00AF]E:DDYABU09>L`04
BU9>LdicDY@2E[D015:DE[EJeU[F0e:D00=>Le:DCW<00Tic00ABU5JeE[E>
L`9BU09>L`=6<@04CW=BU5JeDY@2CW<3DY@01DicDYAF]EJeDY@00TYB00A>
Le:DE[EF]@MBU09:DP96<@03BU9>Ldic00=:DP03CW=BU5Je009F]@03CW=B
U4YB009:DP03AS5>Le:D009BU003CW=:DTic009F]@03F]IF]E:D00ABU005
BU9BU5:DDYAJeP05E[D6DY@2CW<4DY@01EJeDYABU5:DCW<00e:D0Tic00U:
DTicDYABU5JeF]IBU5JeDY@02EJe0e[F00AF]E:DDYAF]@9JeP9F]@9JeP9N
m`MJePIF]@03F]IF]E[F00=F]@=JeP07E[EJeU:DE[EBU5[FE[D00Cg_0000
1@0012448@@Q00000`@Q00T8@P@Q124<HcW>JeY6<B48<H`013W>0cg_00He
[Be[:DX]JcF]<H`5=Jd00c6<>LhicP02?Nl00cW>=JdicP04?Nl2>Lh04Cg_
AS5243W><H`U:Be[<H`e[C6<;F/aS3F]@Q0icSF]?Nl00SW>0S6<00<e[CW>
>Lh00SF]00haS3W>>Lh]JbU:;F/aS3F]:DXQ21S648@<Ha240`aS10Q20P@Q
00@8@P@Q248<H`8@Q00336<8@PaS008@Q0<8@P848@05248<Ha2436<DY@02
6<H00a245:DLi`039BT022U:<HaF]EkgIcUBU1cW48@224800a242488@P02
248336<424801P@Q24848@@Q24848@88@P848@0400048@@Q124524801@aS
48@@Q1245:D00QS60Q240QBU0PaS00<@Q0aS36<00PaS00<DYAS66<H00R48
00L@Q0aS248<HaBU48@DY@0348@01@aS2488@PQ236<00Q2400TQ22U:AS5>
Le:DE[E:DTHa>Lh00RDY00HicT8@=JdLi`@Q248336<00`Q21248@P032480
10@Q2488@PQ210aS0PQ200P<H`Q236<8@PaS248<Ha240PaS1A2400@DYA24
5:DHaP<DY@0348@8@Q24008DY@0648@8@PaS36<@Q1BU11240QBU1Q2410aS
00P@Q0aS36<@Q1BU48@<H`Q21PaS00`DYAcW6<HDYCg_F]IkgV]J>LhmkbU:
7>L36<H236<00`@Q24848@0524801`aS2488@PQ236<8@PaS00L8@P031248
@PaS00<<H`<8@P0336<DYABU008HaP8@Q0<8@P848@<8@P031248@P@Q00P8
@QD48@0300048@@Q00@48@07248<Ha245:DHaRDY;F/00Sg_148@00U6<DYB
AS5243g_@Q1:DTicBU8024ic0TYB0Tic00=BU4icDY@00U:D00=F]E:DBU80
0dYB00=BU5JeDY@00U:D00=F]E[FF]H00U:D00=F]E[FF]H015:D00MF]E:D
CW=>LeJeDYA>L`02AS42BU800dicDYABU007DY@01EJeCW=>LdYBCW<00e:D
0Tic0U:D0Tic00A:DU:DCW=>L`96<@9:DP05CW=:DTYBBU9BU003E[D2CW<0
1E:DCW=:DTHaCW<00e:D00e:DTicDYABU5JeDYAF]E[FDYAF]DYBCW=:DP02
CW<025:DE[EF]EJeDYAF]E:DE[D4DY@00dicDYA>L`04DY@4E[D2DY@00dic
DYA>L`02CW<01E:DE[EBU5:DCW<00UJe00IBU5JeDYAF]E[FE[D2DY@01Dic
E[EJeU[FE[D00e:D00AF]E:DE[EJeP9F]@06DYAF]E[FG_MJeV<H0Ukg0U[F
00=Nme[FE[D00UJe0U[F00=F]E[FE[D00e[F0UJe00=JeUJeE[D00U:D00=F
]E[FE[D00D8@000312400`0012448@0212402`Q212448@aS=Je[FTHa8@Pa
S3g_=Jd013W>00@mkcF]<H`]J`<aS003=JdaS3F]00<e[@8icP03?NlicSF]
008aS08icP0<?NlicSW>>LhmkdHa@Q0icRe[9BTYBS6<0SF]0Re[00<icSg_
>Lh00cW>00@e[C6<<H`aS0<icP@e[@03;F/YBS6<008aS0039BTHaQBU008@
Q08<H`04248<H`aS2482124224800`@Q2488@P0336<00`Q236<<H`0336<0
0`Q212448@02248336<00aBU6<HHaP025:D031cW:DXQ22DY:DXe[E[FIcUN
mdYB5:D<H`88@P0448@8@P@Q248336<6248212400`Q212448@0512432480
1P@Q2488@PQ236<8@P8<H`0348@HaQS6008DY@<@Q0035:D@Q0aS00<<H`8@
Q08HaP8Li`0448@<H`Q236<348@021BU48@<H`aS248<H`Q248@236<01R48
:DY:DTYBCW=JeP96<@07>LhYBRDY>Li6<C6<6<H00PQ200<<H`Q236<020Q2
00<<H`Q224801@Q20`aS0PQ20PaS0PQ200<<Ha2448@01A240QBU0QS600HD
Y@aS36<@Q1BU48@236<01A245:D@Q1245:D0112400TDYA2436<<Ha245:D@
Q0aS48@00PaS00<8@PaS36<00aBU00<<H`Q236<00`aS00h8@Q245:DQ21S6
5:E245[FNmi[FSW>?NlU:AcW0QS600<@Q0aS24800P@Q1`Q200<<H`Q22480
0PQ200P<H`Q224848@Q21248@P@Q0PQ20PaS00<@Q0aS36<00`Q20Q240QS6
00@@Q0aS2488@P848@P8@P03124<H`Q2008<H`88@Q<48@0300048@@Q00H4
8@0:248<HaS648@DYB48<Ha243g_>Lh3@Q000dHaBU96<@02?Nl00d8@BU9:
DP02BU800dicDYABU004CW<2BU83CW<015:DCW=BU5Je0U:D00A>LdHaBU9>
L`ABU004CW=F]E[FF]H2DY@01EJeF]IF]EJeCW<015:D00=>Le:DE[D00Tic
00I244YBBU9>Le:DCW<4DY@00eJeCW=BU003DY@01DicBU9>Le:DCW<00U:D
0Tic00=BU4icBU800dic0TYB00=244HaCW<00Tic0dYB0eJe00A>LdYBDYA>
L`96<@03BU9F]E:D00A>L`03DYAF]EJe00=F]@05DYA>LdYBCW=:DP02DY@3
E[D2DY@2E[D3DY@024icDYA>Le:DCW=BU4icDY@2E[D015[FE[EBU5:D0Tic
00=BU4icDY@00e:D00E>Le:DDYABU5Je009BU0=F]@06DYA>Le:DDYAF]E[F
0UJe0e:D1EJe00=JeUJeF]H00U[F0ekg0U[F0Ukg00=F]E:DDY@01e[F0eJe
0U[F0UJe00A>LeJeF]IF]@4mk`0000<000@Q00000`@Q00`000@Q12448@00
248]Je[FAS4YBRe[=Jd2>Lh2=Jd3>Lh0136<;F/]JcF]0Sg_00@icS6<=Jdi
cP8e[@04>LhmkcW>>Lh4=Jd01CW>=JdmkcW>?Nl00TYB00dicRe[:DXaS3g_
>Lhe[Be[=JdicTHa@Q0e[@02>Lh2=Jd0136<=JdaS36<0SF]0SW>00<aS2e[
;F/00S6<00LYBR486<HHaQ2436<8@P0336<324800`@Q2488@P0224801`@Q
36<@Q0aS24848@Q2008@Q00436<8@PQ2124236<00a246<HLi`026<H25:D0
1Be[=Je244YB?Nl00SW>00XYBRDYDYA[FU:D<H`000@Q36<48@<8@P0436<8
@PQ2248512401@Q212448@@Q24800`@Q00@8@P@Q2488@P848@<8@P8<H`<@
Q0@DY@0348@<H`aS008<H`0;248<H`Q2248<Ha247>LYBR486<H<H`022480
0a2436<<H`0324800a245:DHaP0336<011BU>Li246mk0W>L00MoofmkHaQ>
LdHa?NlQ200248@25:D00a24248<H`0312401`Q236<8@PQ21248@P@Q0088
@P0336<8@PQ200<8@P0336<8@PQ200@<H`<8@PD@Q0085:DLiacW6<HDYA24
36<@Q0D<H`03248<Ha2400<@Q00536<@Q1BU5:DHaP035:D348@00`aS48@<
H`0336<00`Q21248@P0236<01@Q236<@Q1BU36<00PQ200PDY@aS36<mkf<H
Kg]:DQBU0QcW0QBU00<@Q1BU48@00`Q20P@Q0`Q20P@Q1@Q20PaS1`Q20P@Q
00<<H`Q224800PQ20PaS0PQ200LDYAS65:D@Q0Q21248@P02124324801@@Q
2488@P@Q24800P@Q00@<Ha2448@8@P/48@0300048@@Q00X48@0400048@@Q
1242248248@00aBU8@P]J`02?Nl4@Q000dHaBU9:DP03@Q0014YBCW=:DTYB
0Tic00=:DTicDY@00U:D00E>LdYBBU9:DTic00=BU005CW=BU5:DCW=BU002
BU82CW<3DY@2E[D2F]H01U:DE[EBU5:DE[EJeP9F]@08CW=:DTicDYAF]E:D
CW=:DPI>L`04E[EBU5:DCW<3DY@5CW<01DYBCW=>LdYBCW<00dYB00=6<DYB
CW<00Tic00=:DTicCW<00Tic0dYB0Tic1E:D14YB0e:D00=>LeJeE[D00U:D
0Tic0e:D1Dic1e:D00=>Le:DDY@00e:D00=F]E:DCW<00e:D0UJe1U:D0Tic
00ABU5JeE[EBU09>L`03DYAF]E:D00=BU09JeP=BU09JeP9F]@03DYAF]EJe
009BU09F]@9JeP04E[EBU5JeF]H3G_L7F]H00e:DE[EJeP05F]H3DY@025Je
F]IJeU:DE[EBU5kgE[D1@Q0000D48@0400048@@Q248212401PQ2;F]Nmd8@
8@P]J`8e[@05>Lhe[CF]=JdicP02=Jd2;F/013F]?NlicSW>0S6<0cF]13W>
0cF]0cW>0SF]00M244YBAS4icS6<:DXaS002>Lh01SF]<H`aS3g_@Q0mk`8i
cP04?Nle[C6<;F/3<H`4>Lh2<H`3;F/01BDY8@PHaQS648@010aS0PQ200<<
H`Q224800P@Q00T8@P@Q248<Ha2436<8@P@Q24800Q2400@<H`@Q24848@8<
H`0348@HaQcW00<HaP065:D]Jc6<@Q16<Cg_0SF]00H]JbU:DYA[FU:D;F/2
124524800`@Q2488@P06248:12400`Q21248@P02124010Q236<8@PaS0Q24
1ABU0a241PQ200<@Q1BU7>L00RDY00<DYA2424800PQ20PaS0PQ20PaS0Q24
0`aS00@DYCW>AS5_N`9cW00@Oom[FV<HDYA6<Cg_8@PHaPaS48@DY@aS2484
8@Q2124:248236<010Q21248@PaS0`Q20PaS00P8@P@Q248<H`Q236<@Q1BU
0Q2400@DYAS67>LHaP@@Q08<H`88@P@<H`0348@<H`aS008<H`8DY@8HaP03
48@DYA24008@Q0D<H`@8@P8<H`88@P8@Q00;36<8@PaS48@<H`Q2@Q1W>F]J
AS4DY@027>L01QBU48@DYABU48@<H`@8@P051248@PQ224848@0524800`aS
248<H`02248010@Q2488@P@Q1PQ200<<H`Q224800PaS00D@Q1BU5:DDY@Q2
00<48@H8@P031248@PQ200848@8<H`0348@<H`@Q00H48@0324848@@Q0184
8@0?248<Ha2436<@Q2DY;F]243W>?Nm244Ha@Q16<DYB0096<@9240=:DP06
CW=:DTYBBU9>Le:D0Tic0dYB0Tic00=BU4icDY@00e:D00E>LdYBBU9:DU:D
00=>L`04DYAF]EJeF]H2E[D2DY@2E[D00e[FE[EBU002CW<4DY@00dicBU9>
L`02CW<2BU87DY@5CW<2BU83CW<3BU8014HaBU9:DTYB0Tic0dYB0Tic0dYB
00A>Le:DCW=BU0A>L`96<@04CW=BU5:DCW<:DY@014icBU9>Ldic1E:D0dic
0e:D00=>LeJeE[D00U:D00A>Le:DCW=BU0=F]@04DYA>LeJeDY@3CW<01U:D
F]IF]DicBU9>L`IBU0=F]@05CW=BU5[FE[EJeP02DY@3E[D2DY@015JeF]IF
]E:D0UJe15kg0e[F00INme[FF]IBU5JeF]H2E[D015[FG_MJeUJe0U:D1EJe
00ABU5JeF]IF]@4mk`0000D000@Q00048@0000H48@0?248U:E:D@Q0YBRe[
<H`e[CW>=JdaS3F]>Lhe[C6<008e[@<mk`05>LhaS3F]=JdaS002=Jd00cW>
?Nlmk`03<H`00cF]>LhicP02>Lh3=Jd2>Lh023F]<H`e[CW>?NlicSF]<H`2
>Lh2?Nl2=Jd00c6<=JdaS004<H`2=Jd2<H`00bDY8@PLi`029BT00b485:D<
H`0336<010Q236<8@P@Q0PQ20PaS0`Q200@<Ha2436<<H`848@0436<HaQS6
5:D224800`aS48@@Q00248@236<04bU:=JeJeV]JIcUcW6<HF]IBU3W>=JdY
BQcW:DXicR4848@000@Q0088@P051248@PQ21248@P0812400`Q212448@03
1246248010@Q248@Q1240PaS00@@Q1BU6<HDY@<HaP0348@<H`Q20088@P0;
36<8@PQ236<@Q2DY:DXQ21BU1248@P0336<010Q21248@PQ20PaS00l8@PaS
48@@Q3W>AS5cW7NmLiag_G>LOom_NdYB;F/010aS00@@Q0aS2488@P<48@03
248<H`Q200<48@0324848@Q200D8@P0336<8@PQ200H<H`@8@P0636<DYAcW
6<HDYAS60acW00<DYA2436<00Q2400<<H`Q224800PaS00@@Q0aS248<H`8D
Y@0648@DYAS67>LHaQ241`aS00<8@PaS248010Q200H@Q1BU5:D@Q0Q21242
36<01Q247>LU:B487>L@Q0<DY@0448@8@PQ2248236<00`Q21248@P052480
10@Q2488@PaS0`Q200@48@Q22488@P848@88@P<48@<8@PH<H`8@Q08<H`04
24848@Q2248236<224800`aS24848@03248236<01@Q21248@P@Q24802`@Q
00<000@Q124020@Q00D000@Q2488@PaS008@Q0096<HU:CF]>Li6<D8@?Nm2
44Ha009:DP924004AS5:DTicCW<2BU82CW<00e:DCW=:DP08CW<3DY@2CW<0
15:DCW=:DTYB14ic0e:D00=F]E:DE[D00UJe0U[F00QF]E:DDYA>Le:DE[EB
U4ic0TYB0Tic0dYB15:D00=>LdYBCW<00dYB0Tic00=:DTHaBU800dYB00A6
<D8@BU9BU09>L`03AS5>Ldic00=>L`=BU09:DP04AS5>Le:DE[D2CW<00dYB
DYABU003BU83DY@2E[D3CW<2DY@3E[D01E:DCW=>Le:DCW<00U:D00=>LdYB
DY@00UJe0U:D00I>Le:DE[EBU5JeDY@3E[D00e:DE[EBU002E[D01E:DCW=>
LdicE[D00e:D0dic00=BU4icDY@00U:D0UJe00AJeUkgE[EF]@9BU0AJeP9F
]@ABU09F]@=JeP9Nm`9JeP03E[EJeU[F009JeP06DYAF]EJeF]INme[F0UJe
0U:D00AF]E[FF]IJeP=F]@5JeP5F]@5240002@@Q00T000@Q248YBU:D?NlU
:Be[<H`013F]00@aS3F]<H`e[@8aS004>Lhmkcg_>Lh4<H`013F]>LhicSW>
0SF]00<aS3F]<H`00SW>00LmkcW>>Lhe[CW>=JdicP02<H`01SW>?NlmkcW>
<H`e[@8icP07?NlicSF]<H`e[C6<=Jd0136<00He[CW><H`aS2U:7>L28@P0
1bDY7>L@Q0aS248<H`Q2008<H`<8@P<<H`<8@P8@Q00;36<8@P@Q124@Q1cW
6<H@Q0@Q248<H`0248@01`aS248<Ha24<H`e[E[F009[FP0<Kg]S65[FDY@i
cS6<9BTQ22e[<H`HaPQ20P@Q00<<H`Q212400P@Q00H8@P@Q1248@P@Q2487
12400`Q212448@0212432482124010aS48@DYA240PaS00PDYAS66<HLiaS6
48@DY@aS1PQ200H<Ha249BTU:B485:D8248010aS24848@Q20Q2400dDYCW>
BU9g_G_NKg]g_G>LOom[FTHa:DX@Q00436<224831245248212401@Q21248
@PQ2124010Q21`aS0`Q20PaS11BU0aS600<LiaS65:D00a240PaS0PQ20PaS
00@@Q0aS36<<H`@@Q08HaP035:D<H`aS008<H`88@P0336<8@PQ200848@@8
@P0736<@Q1BU48@8@P@Q48@00PaS00DLibDY8@PLia24008DY@0448@<H`Q2
248236<824821242248010aS2488@P@Q1PQ21P@Q00@8@PaS48@<H`88@P8<
H`8@Q00836<8@P@Q1248@PaS248<H`L8@P8<H`<8@P031248@P@Q00@48@03
24848@@Q00P48@0300048@@Q00848@0400048@Q2124224801`aS248DYAcW
9BTicSF]00924096<@06@Q16<DHaAS4mkd8@1TYB00=BU4icCW<00TYB0dic
0TYB0dic00EBU4icCW=:DTic00A:DP04DYA>LdicCW<2DY@00eJeDYABU002
E[D2F]H00eJeDYA>L`04DY@014icBU9:DTic0TYB00=>LdYBDY@00U:D0Tic
00E:DTicBU9:DTHa009:DP04AS5:DTHaAS42BU82AS400dYBCW=BU002BU88
CW<014YBAS56<Dic0e:D0TYB00=BU4icCW<00TYB00A>Le:DE[EF]@=BU09>
L`05DYAF]E:DE[E>L`02DY@2CW<015:DCW=>LdYB15:D0Tic0U:D0UJe0e:D
00YF]E:DDYAF]E:DE[EBU4icBU9>L`9F]@04DYA:DTYBCW<5DY@00eJeDYAB
U003F]H01EJeDYABU5JeG_L00U[F15:D00AF]E:DDYABU0AJeP9Nm`EJePAF
]@=JeP04E[EBU5:DDY@3E[D01U[FE[EF]EJeF]IF]@4mk`0000H48@001240
00@Q000212402PQ2124000aS:DYJeSg_9BTaS3W>1CF]00<aS3F]>Lh00cW>
00<e[CW>>Lh00SF]0S6<00<icSF]>Lh013W>00@e[CW>=Jde[@8aS08e[@07
>Lhmkcg_<H`]Jc6<>Lh00T8@00HicS6<=JdmkdHa?Nl2<H`3=Jd00cW>=Jdi
cP02>Lh00cg_<H`]J`048@P00acW5:DDY@0248@011BU48@@Q1240PaS00<8
@PaS48@00Q240PaS00@@Q1BU36<@Q0848@0648@U:Be[7>L8@P@Q0`aS01L4
8@aS36<<Hc6<?Nm[FWNmLiag_G>LNmi_Ndic?NlDYA245:DLiaBU36<48@00
00L48@0324848@@Q00D48@0324848@@Q00848@0324848@@Q00<8@P8<H`8@
Q0066<HDYABU48@DYB480RDY00<HaQ245:D00PaS0PQ200H<H`@Q24848@Q2
6<H29BT01QS636<<H`aS48@<H`88@P<<H`88@P0B36<@Q124:DXicV<HIcU[
FWNmLiag_Ekg>LhU:@aS48@<H`Q210aS00<8@P@Q24800PaS00D8@P@Q1248
@P@Q008<H`<8@P0436<8@PaS248236<01A245:DHaQ2436<00P@Q0PQ200<@
Q1S66<H00QBU00L<HaBU7>LQ21S648@<H`025:D236<00a245:D@Q0022480
0`aS5:DDY@055:D0112436<<H`aS0PQ200<<H`Q236<00PQ200<48@Q236<0
0Q2400<8@PaS24800PQ20a2400@8@PaS48@DY@8<H`8DY@0348@48@Q200<<
H`8@Q00336<8@P@Q00<8@P0336<8@PQ200@8@P041248@PaS36<424801P@Q
2488@PQ21248@P8<H`0348@<H`aS0088@P0348@DYABU008DY@8@Q0H<H`@8
@P<<H`0424848@@Q124324800`@Q24848@0512400`0012448@0:12400`Q2
1248@P0236<01A246<HQ236<>Lh00d8@00A6<DYBCW=:DP96<@04@Q16<DYB
BU82AS42BU82CW<014YBDYA>Ldic0TYB0dic15:D24ic00=BU4icCW<00UJe
00AJeU:DE[EF]@9JeP=BU0=>L`04DYA>Le:DCW<2DY@2CW<01U:DCW=>Ldic
BU9>L`A:DP9>L`03BU9>LdHa00=6<@06CW=6<D8@BU9>Le:D0Tic0e:D1Dic
00I6<DYBAS5>LeJeDY@3BU82DY@01DicBU9>LeJeDY@00Tic15:D00AF]E:D
CW=BU09F]@9BU004CW=BU5:DDY@2CW<2DY@2E[D2DY@014icDYABU5:D0e[F
0e:D0UJe0dic00MBU4icCW=F]E:DE[EBU002CW<00e:DE[EBU003DY@00eJe
F]INm`02E[D01DicE[EJeUJeG_L00UJe00EJeUJeDYA>Le:D00=F]@03F]IF
]Ekg00=JeP03DYAF]EJe009F]@9BU003F]IF]E[F009F]@04DYAF]EJeDY@2
E[D00e[FE[EF]@02E[D1DY@1@Q00000300048@@Q00P48@06248YBU:D>LhY
BS6<0cF]00@icSF]<H`aS08e[@04>Lhe[CF]=Jd2>Lh2=Jd2<H`02cF]>Lhm
kcW>=JdicSF]>LhmkcW>=Jd00S6<0SF]0cW>00haS2e[<H`icTHa@Q0aS2e[
<Ha244Ha?NlaS2e[1CF]0cW>00<mkc6<:DX01B4800@DYA2448@@Q08DY@04
48@<H`aS248236<448@01@aS48@DYA2436<00P@Q00@DYBDY;F/HaP848@05
48@<H`Q2248<H`0248@01C6<AS5_Ng_NKg/00gNm00Y_NdYB>LhDY@aS5:DL
iaS636<000<48@0324848@@Q00D48@0324848@@Q00T48@@8@P8<H`0348@H
aQBU008@Q0065:DHaR489BTLiaS60Q2400<<H`Q224800`Q20P@Q00D<HacW
8@PQ21S6008<H`<8@P031248@PQ200<<H`06248@Q12448@aS3W>0V<H00M_
Ng_NLiacW5[F>LhU:@0248@536<224800`@Q2488@P032482124524800`aS
248<H`0224801`aS48@@Q1S65:D<H`Q200848@0336<8@QBU00<DY@8<H`08
48@Lib487>L@Q0Q25:D@Q08<H`0348@DY@aS008<H`0448@DYABU5:D348@0
11BU48@<H`aS0PQ200<<H`Q224801PQ210aS00D8@P@Q248<Ha2400<<H`04
5:D@Q0aS36<25:D00`aS2488@P0336<00a2436<<H`0224800`@Q248<H`04
24800`aS24848@02248010aS2488@PQ20`@Q00H8@P@Q1248@P@Q248436<0
1@Q236<@Q1246<H00Q2400@<Ha2436<@Q0@<H`@8@P8<H`88@P848@<8@P03
1248@P@Q00/48@0600048@@Q00048@000`@Q0PQ20PaS00D@Q1S68@PaS3F]
00=24006AS5:DTicBU96<Cg_0T8@0THa00=:DTHaBU800Tic0TYB0dic0dYB
0dic0e:D0Tic14YB0dic00=:DTicDY@00UJe00EBU5JeF]IF]E[F009BU004
CW=:DTicCW<3DY@6CW<01E:DBU9:DTYBCW<02DYB14Ha00E244HaBU9BU5Je
00=>L`=BU09:DP9>L`06BU96<DHaCW=BU4ic0TYB0Tic00IBU4YBBU9>Le:D
E[D2DY@014icDYABU5Je1E:D00AF]E:DDYA>L`=BU005CW=:DTicDYAF]@02
DY@014icDYA>Le:D0eJe00EJeU:DE[EBU5Je009BU004BU9>Le:DCW<2DY@0
15JeDYABU4ic15:D00]F]E:DDYABU5[FG_MF]E:DCW=BU5Je00=JeP03E[EJ
eUJe009BU003CW=F]E[F00AF]@03G_MJeU[F009BU0EF]@06DYAF]EJeE[EB
U5Je0U:D1UJe00=BU5JeE[D00Cg_000212404P0012448@@Q00048@Q20004
8@Q2:DYBU3W>9BT]JcW><H`e[@8icP09=JdaS3F]=JdicSF]<H`e[CW>0092
4003>LhaS36<00<icP03?NlicSF]00@e[@06<H`e[CW>?NlicS6<0SF]136<
00Q244Ha@Q0e[C6<>Li243g_0SF]00<icSF]>Lh00S6<0SW>0Sg_00@]Jc6<
9BTQ20@Li`075:D<H`aS36<@Q1BU6<H00aBU00<<Ha245:D00QS600<@Q1BU
5:D00Q2400H8@P@Q5:D]JcF]8@P2124324801`@Q36<@Q0aS:DXe[F<H009[
FP07NmicW7ooLia6<BU:48@00QBU00<@Q0Q212402`@Q00@8@P@Q1248@P@4
8@0324848@Q20088@P0336<8@PQ200<<H`8DY@8Li`046<H@Q1BU48@35:D0
0`aS2488@P0336<212401PQ236<HaQS65:D@Q08DY@<@Q00536<8@PQ2248@
Q00212400a246<HLi`026<H03R48BU9BU5kgIcU:DTHa<H`Q21cW5:DHaPaS
248248@00aS65:D8@P0224800`@Q2488@P0324800`aS248<H`03248336<0
2PQ236<@Q1BU8@PHaPaS24848@Q20PaS0Q2400DDYAcW9BTQ21cW008Q2005
6<H@Q0Q2248DY@0248@436<01Q245:D@Q1245:DHaP8DY@<<H`05248<H`Q2
248<H`0724800`aS48@<H`0224803@@Q248<H`aS24848@aS5:DHaQ2436<8
@PaS008@Q00736<@Q1BU8@PU:AcW48@00PaS00D8@PaS248<Ha24008<H`@8
@P<<H`0324848@Q200H8@P<<H`8@Q00436<@Q1245:D248@25:D36<H35:D2
36<00`Q236<8@P072482124224800`@Q2488@P08124010Q212448@0020@Q
00<8@Q2448@00QBU00@HaS6<>Li:DP924006BU96<DHa@Q16<DYB0T8@00Dm
kd8@AS5:DTic009:DP04CW=:DTicCW<3BU800dicBU9>L`03CW<4DY@014ic
DYA>Ldic0e:D00a>Le:DE[EF]E:DCW=BU5JeDYA>Le:DE[D3CW<3DY@3CW<2
DY@01DicBU9:DTicDY@00Tic1dYB00A6<DYBAS56<@A:DP03CW=BU5:D009B
U005CW=BU4icDYA>L`02DY@3BU83CW<2BU801DicDYAF]E:DCW<00U:D00=>
Le:DDY@00U:D00=F]E:DDY@00Tic0U:D0UJe0e:D0Tic15:D00A>Le:DCW=B
U0=>L`04E[EJeU[FDY@3E[D2DY@024icDYABU5JeDYA>Le:DE[D2DY@2CW<2
E[D01U[FDYABU5:DE[EJeP9F]@07DYA>Le:DE[EBU5[FE[D00U[F0U:D00I>
Le:DE[EBU5JeDY@4E[D015[FE[EF]EJe15:D00=F]E:DE[D01EJe00=BU5Je
F]H00U[F0UJe0E[F0EJe0Cg_00001@@Q00048@@Q00001P@Q00H8@RU:DY@m
kbDY<H`7=Jd00c6<=JdaS002=Jd01C6<>Li243g_=Jd00S6<00DicSg_?Nli
cSF]008icP8e[@8aS003=JdicSW>00<e[@0=>LhaS36<<H`e[Cg_@Q0icSF]
<H`e[D8@?Nl00SF]0SW>00Xe[C6<<H`e[Cg_@Q0mkbe[:DXU:@@Li`036<HD
Y@aS008<H`0348@DYABU008DY@<@Q0@DY@8@Q00836<@Q0Q2124DYBe[=JdL
i`848@0<36<8@PQ2248<Ha2436<YBSW>IcU[FVmk0WNm00Aoof]J?NlYBP<@
Q00336<8@P@Q00848@0424848@@Q248:124010Q212448@@Q10Q200<48@Q2
24800`aS00LDYAS68@PQ21S65:D@Q0025:D01AS65:D<H`aS24800`aS00H8
@P@Q248@Q1BU6<H25:D348@00aBU48@<H`03248040aS1248@Q248@PLiaBU
6<HQ24YBDYAS66LiBU92436<0QcW00D@Q1BU48@8@PaS008DY@0548@48@@Q
24848@0324800`aS2488@P03248336<00`Q236<8@P0248@36<H010aS2484
8@Q20PaS0QBU00<HaQcW8@P00QcW00HQ22DY6<H<H`Q236<348@336<01124
36<@Q1240QS60aBU0`aS30Q200T<Ha2436<<H`Q21248@PaS48@00PQ200D<
HaS66<HDY@@Q00<<H`0448@<Ha247>L28@P00aBU48@<H`02248236<00a24
36<8@P0236<4248010aS2488@PQ20P@Q1PQ20Q240PaS0Q2400<DYA2448@0
0QBU00DHaQBU5:DDYA24008DY@8<H`@8@P<<H`0624848@@Q1248@P@Q0PQ2
4`@Q00<000@Q24800PQ200L<Ha246<HQ23F]?Nm6<@02@Q0014HaBU92448@
0THa0T8@00@mkd8@AS56<@9>L`9:DP=>L`04BU96<DYBBU87CW<00e:DCW=B
U002CW<3DY@00dicBU9BU003DY@01DicE[EBU5:DCW<00U:D14ic0U:D0dic
0U:D00=>LdYBCW<014ic24YB0THa0TYB00A6<DYBBU9>L`ABU003CW=BU5:D
009>L`9BU004CW=:DTYBBU83CW<00dYBCW=BU003DY@01DicDYABU5:DCW<0
0U:D00AF]E:DDYABU09>L`9BU09F]@9BU003BU9>Ldic00=BU09>L`9BU09>
L`9BU008F]IF]EJeDYAF]E:DE[E>L`EBU003CW=F]E:D009BU09>L`9F]@AB
U0=F]@9BU004CW=BU5:DE[D2F]H00eJeF]IF]@04DY@00eJeDYABU007E[D6
DY@2E[D00e:DE[EF]@03E[D00e:DF]IJeP02E[D00e:DF]IBU001?Nl00004
00048@@Q000412403@Q200048@aS;F]BU3W>8@Pe[Cg_>Lhe[C6<008icP8e
[@<aS004=JdicT8@@Q03>Lh023F]>LhicSW>?NlicSF]<H`2=Jd2>Lh2?Nl6
>Lh02CF]<H`aS3W>@Q0mkcW>;F/aS002=Jd2>Lh2=Jd01CW>;F/YBRe[<H`0
0SW>00<aS2e[9BT00R480QcW0QS600<DYA2436<00PaS0QBU00<HaQ245:D0
0a240PaS00d@Q0aS48@DYA24124@Q36<=JdLi`@Q000<H`02248236<248@2
8@P02D8@CW=JeV]JF]IF]DHa:DXQ20025:D0112436<48@Q20P@Q00D8@P@Q
24848@Q200@48@<8@P<48@88@P848@88@P8<H`08248<H`aS36<48@aS48@H
aP@Li`8@Q0045:DHaQBU48@236<01Q2436<<H`Q236<8@PD<H`@@Q0<8@P03
36<@Q1240088@P0<5:D<H`Q27>LQ25[FLiaW>E:D8@PHaQcW0QBU00<@Q0aS
36<00PaS0`Q200<<H`@Q12401@Q20`aS1@Q210aS0Q240aBU0PaS00<8@PaS
48@00a2400HHaQcW9BTQ21cW6<H248@336<00a245:DDY@025:D01Q245:DD
YA2436<@Q0<DY@0548@8@PQ2248<H`06248010aS248<H`aS0`Q200<48@Q2
12401@Q200<<Ha247>L00QcW00<HaQBU48@00QBU0aS60Q2400<<Ha2448@0
10aS0a241`aS0PQ200<48@Q212400`Q200L@Q1S66<HDY@aS248<H`0248@0
3`aS248Libe[DYA[FU[FBU8icR487>LHaQBU48@<H`04248336<224800`@Q
2488@P02248912400`001240000:124236<01ABU6<HLibU:<H`00cg_00Q2
44HaBU96<DYB@Q16<D8@0Sg_00=6<DYBCW<00TYB0Tic0dYB00E>LdYBBU9:
DTHa009:DP04CW=BU5:DDY@2CW<01U:DBU9:DTicDYAF]@ABU003E[EBU5:D
009>L`=BU0=>L`03DYA>Le:D009>L`03BU9>Ldic00=>L`9BU0A>L`M:DP=6
<@04BU9>Le:DBU82DY@01UJeDYA>LdicDYAF]@9BU003CW=BU5:D00=>L`03
DYA>Le:D009>L`9BU006CW=:DTHaBU9BU5Je0U:D00E>Le:DDYA>Le:D009>
L`=BU0=>L`=BU00:CW=BU4YBDYA>LdYBCW=6<DicE[D2F]H3DY@015JeDYAB
U4ic0eJe0e:D00AF]E:DDYA>L`9BU004E[EJeUJeDY@2E[D00e:DCW=BU004
DY@01TicF]INme[FE[E>L`=BU003E[EBU5:D00ABU0UF]@03DYAF]EJe009J
eP=F]@9JePAF]@9JeP5F]@4mk`001@@Q00<000@Q12400`@Q00H8@Re[DY@e
[BDY<H`2>Lh0136<=Jde[C6<13F]00HaS3F]>Li243g_>Lh2=Jd00c6<>Lhi
cP02?Nl00cW>=Jde[@02<H`00cF]>Lhmk`03>Lh013F]>LhicSF]0c6<0Sg_
0SW>0S6<00<e[C6<=Jd00SW>00@e[C6<;F/YBP8aS006>LhaS2e[<H`U:AcW
0QS600LLiaS66<H@Q1BU36<8@P0248@00aS65:D@Q00248@336<00a2436<<
H`0248@01PaS248HaRe[<H`HaP848@0=36<8@PQ2248@Q1BU48@Lib48AS5B
U5[FIcT00UJe00A:DRU:7>LDY@8@Q00436<8@PQ224821243248312400`Q2
12448@032484124624800`aS248<H`02248248@01acW8@PHaQS65:D@Q0aS
00<DY@8<H`8@Q00336<8@PaS008<H`0348@<H`aS00<<H`<@Q00936<48@Q2
36<DY@aS1248@Q24008<H`0;7>LU:F<HNmiS64YB7>LDYB486<HDY@0248@0
20aS2488@P@Q36<@Q0aS248212400`aS2488@P0224800`aS248<H`0236<0
1@Q236<8@PaS24800a240QBU00P@Q0aS2488@PaS48@DYA240QBU00HLib48
7>LLiaS648@336<00aBU48@@Q00348@26<H00aBU48@@Q00248@25:D236<6
24800`aS2488@P02248010aS248<H`aS0PQ20P@Q00<8@P@Q36<00PQ200<<
HaBU7>L00acW00PDYA2448@DYAS67>LHaQ240PaS0a2410aS11240`aS00H8
@PaS2488@P@Q2482124224801a246<HHaQBU36<8@PaS008@Q00936<8@QcW
;F]BU6]JDYA:DS6<008Li`8DY@0348@<H`Q200<8@P<<H`0324848@@Q00<8
@PT48@0300048@@Q00@48@0300048@0000848@88@P0336<@Q1BU008HaP05
;F/e[D8@@Q0mk`03@Q03AS42@Q001cW>?Nm244HaCW=:DTHa009:DP03CW=:
DTYB00=:DP04AS5:DTHaBU84DY@01dicDYABU4YBCW=BU5Je009BU09>L`=B
U09>L`9BU007E[EBU4icCW=:DTicDY@014ic0U:D0dic0e:D0Tic00=:DTic
BU800THa0dYB0THa0TYB00ABU4YBBU9>L`9F]@03DYA:DTic00MBU0A>L`9B
U005BU9BU4icDYA>L`03BU801DicDYABU4icDY@00Tic00=BU4icCW<00Tic
0U:D14ic0e:D1Dic0TYB00I>Le[FF]IF]E:DCW<2E[D015:DCW=BU5:D0eJe
00EBU5JeE[E>Le:D009>L`06DYAF]EJeE[EBU5Je0U:D0Tic00MF]E:DDYA>
Le:DF]INm`02F]H01U:DCW=BU5JeDYAF]@IBU0=F]@05DYAF]E:DE[EBU003
E[D00e[FE[EF]@08E[D2F]H1DY@1?Nl0000300048@0000P48@08248]Je:D
=JdYBSW>?Nle[@8aS08e[@03<H`e[CW>00<e[@<icP05=JdicSW>=JdaS003
>Lh01cF];F/aS36<=JdicSF]00<icP8mk`<icP08?NlicS6<=JdmkcW>=Jd]
J`8aS08e[@05?Nm243F]<H`YBP03<H`5;F/00bU:8@PLi`036<H00a242488
@P0236<00`Q236<@Q00248@00`aS248<H`0336<224801`aS48@@Q1BU7>L@
Q0aS00848@<8@P0436<@Q0aS36<27>L01DicJeY_Nf<H<H`00R480QS600@L
ibDY5:D<H`848@0336<8@PQ20088@P041248@PQ236<22482124424831240
1PQ212448@@Q248<H`8@Q0<<H`04248@Q1BU6<H35:D00aS65:DDY@0248@0
0`aS48@<H`0536<2248236<00`Q236<<H`0336<00`Q236<@Q00248@01@aS
1248@PQ236<00QS600DaS3W>;F/U:A2400<HaP0336<8@PaS0088@P848@88
@P0336<8@PQ2008<H`88@P03124<H`Q200D<H`03248<H`aS00<<H`0648@D
YABU48@<H`Q210aS00<8@PaS48@01ABU00<@Q1BU24800PQ200D<HaBU5:DH
aQcW008DY@0348@<Ha24008@Q08DY@0348@<H`@Q00<8@P0436<8@P@Q1248
248236<22482124236<248@01QBU48@<H`aS48@DY@8HaP035:D@Q0aS00<8
@P0336<@Q124008<H`8@Q0045:DLiaS66<H248@236<224800`aS24848@02
24801@aS48@DYABU48@01PaS00<Lib489BT00bDY00PmkdicE[E_Nf<H>LhU
:@aS0a240PaS1@Q20`@Q0`Q20P@Q00<8@P@Q12403`@Q00<8@PaS48@00QS6
00<LibU:<H`00Sg_0SW>00dmkdHaBU96<Cg_@Q16<D8@?Nm244HaBU96<@02
BU84CW<3BU83AS4024YBCW=BU4icDYA>Le:DCW<2BU800dicDYABU002CW<2
DY@025JeDYA:DTYBCW=F]DicBU84CW<01DYBCW=BU5:DCW<00dYB1Tic00=B
U4icCW<024YB00=>Le:DBU800TYB0U:D0UJe15:D0dic0U:D0dic0e:D0Tic
0e:D00I:DTHaBU9BU4icBU82CW<2DY@4BU8015:DCW=>Le:D0Tic00=BU4ic
BU800dic0TYB00I6<DicCW=>LeJeF]H2E[D3CW<3DY@00eJeDYAF]@03E[D3
DY@00dicDYABU002DY@015JeF]IF]EJe0dic0U:D15Je00IJeUJeDYABU5Je
DY@2E[D00e:DE[EBU005DY@5E[D3F]H3E[D015[FE[EF]EJe0U[F0UJe00EB
U5JeF]IJeU:D005240000`@Q00<000@Q00001@@Q00T8@RU:CW<e[BU:=Jdm
kcF];F/00S6<00P]Jc6<<H`icSF]<H`e[CW>0Sg_0SW>13F]0SW>00@aS2e[
;F/aS08e[@03>Lhe[CF]00LicP06=JdaS3W>?NlicSF]0Re[00<e[C6<=Jd0
0SW>00LaS2e[;F/aS3F]<H`]J`05:DX00b487>LHaP026<H25:D224800`@Q
248@Q00348@2248336<424800a2436<DY@025:D00`aS24848@0324801`aS
48@<H`aS6<HLidic009[FP06G_Le[AcW8@PHaQBU0QcW00<DYA2412402`Q2
00<48@Q2248010Q200H<H`@Q24848@Q2124224800`aS48@@Q00236<020Q2
36<@Q1245:DHaQBU6<H25:D448@236<224800`aS48@<H`0524803A2436<@
Q0aS24848@aS48@DYA2424848@aS0088@P0<6<HLicF]?NlYBQcW5:D@Q1cW
5:D@Q0aS0PQ200D<H`Q212448@Q2008<H`@8@P8<H`05248<H`aS36<@Q003
248536<01Q245:DDYA2436<8@P<<H`04248<H`aS36<248@55:D436<35:D2
6<H25:D00`aS48@@Q0035:D236<00`Q2124<H`0<248436<224801@aS248@
Q1245:D00Q2400H<Ha245:DDYAS65:D248@010aS24848@aS0a240PaS00@@
Q0aS5:DHaP8Li`035:D<H`aS00<<H`88@P081248@P@Q36<@Q1S65:D<H`88
@P0C36<@Q12436<DYB48:DXQ22DY:DXmke:DE[E_Nekg>LhYBPQ236<00a24
00<<H`Q212400P@Q1@Q230@Q00<000@Q12400P@Q00<000@Q00000P@Q00T8
@PaS5:DDYAS67>LYBSF]@Q000cW>0T8@0THa0T8@00U6<Cg_>Li244HaCW=:
DTHaBU800Tic00M:DTicCW=>LdYB@Q16<@02BU800e:DCW=>L`03DY@3BU80
0dicDYABU003CW<00e:DE[EBU002BU800dicDYA>L`02BU8014icDYA:DTYB
14ic00EBU4YBBU9:DTic009BU008BU9>LeJeCW=:DTHaBU9>L`E:DP=>L`9:
DP9BU003F]IBU5:D00=BU09>L`04DYA>Le:DDY@3CW<2DY@3CW<01U:DCW=:
DTYBAS5BU09>L`03BU9>Ldic009>L`=:DP03CW=BU4ic009>L`03DYA>LdYB
009>L`04DYA>LdYBAS43BU801e:DE[EF]E[FE[E>Le:D009>L`EBU008E[EJ
eUJeE[E>Le:DCW=BU09>L`04E[EJeUJeF]H2DY@01DYBCW=BU5JeDY@00UJe
00=JeUJeE[D00e:D00AJeUJeDYAF]@EBU003E[EBU5Je00=F]@=JeP=F]@03
F]IF]EJe00=F]@9JeP06E[EBU5JeE[EJeUJe0Cg_00000`0012448@051240
2`Q200048@Q2;F]BU3W>8@PaS3W>=Jd00S6<1SF]00<icSF]=Jd00SF]00<i
cSg_>Lh00cF]00<icS6<<H`00cW>0c6<0cW>0Sg_0cW>00=243W>=Jd00SW>
00<mkcW>;F/00c6<00<e[CW>>Lh00Sg_00<e[C6<;F/00S6<00HYBRe[=Jda
S2e[9BT27>L011S65:D@Q0aS0`Q200<48@aS36<00PaS1@Q20PaS00<@Q0aS
36<00PQ200@<H`Q224848@88@P848@04248<H`Q2248248@01SW>DYA:DSF]
5:D@Q08Li`036<H@Q12400<8@P051248@PaS248<H`02248236<00`Q236<8
@P04248010@Q24848@Q21@@Q0PQ20PaS0a241@aS0Q2400<DYA245:D01A24
0PaS00<8@PaS36<01PQ200<<H`Q224801PQ200<<H`Q224800PaS112400<D
YA2448@00QcW00<HaQ2436<01@Q20P@Q00D<HaBU5:DDY@Q200H<H`@@Q004
36<8@PaS248236<00a2436<<H`0536<3248236<25:D248@236<348@236<0
3248;F]:DV]JDY@icQS636<@Q1BU36<@Q08DY@0448@48@Q2124524800`@Q
2488@P0224801@@Q2488@PQ236<01PQ20PaS00@@Q0aS48@@Q08DY@0436<@
Q0aS36<4248336<011246<HHaQBU0Q240QBU00<HaQ2436<00PaS00<@Q0aS
36<00PaS00@8@Q2448@@Q0@<H`0G48@DYABU48@Q22U:@Q16<CF]>LhaS248
:DXmke:DHaQF]BU:7>L<Ha245:D8@P0212400`Q212448@02124324841240
1@Q212448@@Q000010@Q00<000@Q124010@Q00d8@P@Q36<<HaS67>LQ23F]
>Li6<D8@>Lhmk`02@Q03AS43@Q000dHa@Q124002AS4014icBU9:DTic14YB
00Q>LdYBBU9:DU:DCW=:DTic0U:D00E>LdHaBU9>Le:D00A>L`=BU0E>L`9:
DP03CW=BU4YB009:DP03CW=BU4YB009:DP=>L`=:DP04CW=BU4icCW<2BU80
35:DCW=:DTYBCW=BU4icBU9>Le:DCW=BU09>L`03DYAF]EJe009BU003CW=B
U4ic00=BU003BU9>Le:D00ABU004E[EBU5:DCW<2BU88CW<4BU82CW<3DY@3
BU82CW<2BU800dHaBU9:DP04DY@01UJeDYAF]DicBU9>L`ABU0=F]@EBU005
CW=:DU:DDYAJeP02E[D00e:DCW=>L`02DY@3E[D01U[FE[EF]EJeDYAF]@9J
eP9F]@9BU003E[EBU5:D009BU0=F]@04F]IF]E[FE[D3F]H01EJeDYAF]E[F
E[D015[F00=F]E[FDY@00UJe0E[F0Dic0Cg_000212400`00124000061240
20Q2:DYBU3W>9BTaS3W>=Jd2<H`01CF]<H`aS36<=Jd00SW>0SF]00<aS3F]
>Lh00SW>0cF]00@icSF]<H`e[@8icP8aS009=JdicSW>>Lhmkd8@>Lhe[CW>
008mk`0:=JdaS3g_?NlicS6<;F/aS2e[=Jd2>Lh2?Nl01CW><H`aS36<;F/0
0RU:00@]Jc6<;F/Q208Li`035:D@Q124008<H`@8@P<<H`0324848@Q20088
@P<<H`0448@8@PQ2248236<224800`@Q2488@P0324802P@Q248@Q1BU>LiB
U4Ha<H`HaQ240QcW00<DYA2436<01PQ20PaS10Q200<<H`Q236<00`Q20`@Q
00<8@P@Q12400P@Q00<8@P@Q24800`aS0Q241@aS0a2400D<Ha2448@@Q0aS
008@Q08<H`03248<H`aS008<H`88@P0636<8@PaS36<8@P@Q0PQ200<<H`Q2
24800PQ200@<H`Q22488@P<@Q0045:D@Q1245:D36<H00a24248<H`022483
12401`Q236<@Q1BU48@<H`Q200D<H`<@Q003248<H`aS00D<H`0348@<H`aS
00<<H`03248<H`aS0088@P0436<@Q1S65:D248@236<248@02PaS248LibU:
CW=[FUJe<H`Li`Q20QBU0Q240QBU00<<H`Q224800PQ200<48@Q224800`Q2
00H48@Q21248@P@Q248336<3248236<348@00`aS48@DY@025:D536<00`@Q
2488@P0336<00a246<HHaP0348@011BU6<HDYABU0PaS00@@Q0aS48@<H`<8
@P0836<@Q12436<@Q0Q236<@Q08DY@0348@Q22e[008mk`8e[@0:<H`Q2248
@Q1BU6LiDY@Q21cW36<248@01@Q212448@@Q24800P@Q0`Q200@48@Q21244
8@88@PT48@0300048@@Q00848@0:0008@PaS36<@Q1BU6<HU:CF]?Nl2@Q03
?Nl2@Q02AS44@Q02AS40148@AS56<Dic14YB00I>LdYBBU9:DTHaBU82CW<0
1DYBCW=BU5:DBU800THa00E>Le:DCW=:DTic00ABU0E>L`9:DP05CW=BU5:D
AS5:DP03CW<3BU800dicBU9:DP03BU800e:DE[E>L`02AS400dicDYA>L`02
BU86CW<5DY@2E[D3CW<4DY@4CW<00e:DCW=F]@03DY@014icBU9:DTYB0Tic
0TYB00=BU4icCW<00dHa00=:DTicCW<00U:D0Tic00=6<DYBCW<00Tic0THa
0TYB0Tic00EBU5JeDYAF]E:D009>L`07BU9BU5:DDYAF]E:DE[D01E:D0dic
0U:D00AF]E[FE[EBU09>L`=BU003E[EJeU[F009F]@05DYAF]EJeE[EJeP03
E[D5DY@2E[D00e[FE[EF]@02E[D2F]H3E[D015:DE[EJeUJe15[F00AF]E:D
E[EF]@9JeP5BU04mk`0000<000@Q12400`@Q00<000@Q12400P@Q00H8@Re[
E[E24248;F/2>Lh00cg_>LhaS002=Jd3>Lh6=Jd2>Lh00cF]>Lhe[@02>Lh0
13F]>LhmkcF]0S6<00@icSg_>Lhe[@8icP<e[@8icP8e[@04<H`e[CF]=Jd3
<H`3>Lh04D8@?Nle[Be[:DXicSF]9BT]JdHaDY@mkb486<HLiaS65:D00Q24
00DDYAS648@<H`@Q00<8@P031248@PQ20088@P<<H`0548@<H`Q224848@02
248312400`Q21248@P0224801@@Q36<<HaS67>L00QBU0Q2400<DYA2436<0
0`aS2PQ20`aS00D48@Q236<<H`Q200<48@88@P<48@0324848@Q20088@P<D
Y@056<H@Q0aS48@<H`025:D00aS65:DDY@0248@010aS48@@Q12410aS1PQ2
00<<H`Q224800P@Q0PQ200H<H`Q224848@Q248@35:D01@Q236<<H`aS5:D0
0QS600L@Q0aS48@DYA2424848@0224800`@Q48@HaP027>L00a2436<@Q004
36<011BU48@HaQS60a2410aS0PQ20`aS00<8@PaS36<00`Q200H<Ha2436<@
Q0Q236<248@03AS67>LHaQS67>LQ236<>Li246LiHaQF]CW>008@Q08<H`8@
Q0<<H`051248@P@Q248<H`02248010aS1248@P@Q1PQ20PaS00<8@PaS2480
2PaS0`Q200<48@Q224800PaS00<@Q0aS36<00`aS00<@Q1BU6<H00Q2400H<
Ha245:D@Q1BU6<H25:D01@aS248<H`Q236<0112401PHaQcW?Nm6<EkgIcUN
mfLiE[E>LdHa8@PHaSF]E[EBU2e[124@Q0aS24848@00248412400`aS2488
@P031242248212401@0012448@@Q00000`@Q00<000@Q12400`@Q00d8@Q24
48@DYAS68@PicT8@AS4mkcW>AS524002?Nl00dHaBU9:DP04BU801DHaBU9:
DTYBAS400TYB0dHa00=:DTicBU8014YB00=244YBDY@00U:D1TYB00=>Le:D
DY@00e:D00IF]E:DDYA>LdYBDY@2CW<00dYBCW=>L`02DY@6CW<3BU82CW<0
14YBCW=BU5:D0Tic00=BU4icBU800TYB00ABU4YBBU9>L`9BU09>L`ABU0=>
L`9BU003CW=BU5:D00=>L`=BU003CW=:DTYB009>L`A:DP04DYA>LdYBBU84
AS400dYBCW=BU002DY@2BU801THaBU9:DTicBU96<@9:DP9BU09>L`03DYA:
DTYB00A:DP9BU005E[EJeU:DDYAF]@02DY@5CW<2DY@00eJeDYABU004DY@0
0dicDYABU002E[D00e:DE[EF]@02F]H6E[D3DY@2E[D015:DE[EJeU[F0eJe
00=JeUJeDY@00eJe00=JeUJeF]H00e[F0UJe00ABU5JeG_MF]@52400010@Q
00d000@Q12448@Q2124000aS:DYF]CW>8@P]J`04>Lh00cF]<H`icP04>Lh0
1C6<=Jde[C6<=Jd00cW>0SF]0SW>00@e[CW>?Nle[@8aS003=Jdmkcg_008i
cP<e[@0<>Lhe[CF]>Lhe[C6<=JdicSF]<H`]Jc6<0cW>00<mkd8@<H`00Re[
00/e[C6<9BTaS4YBCW<mkb486<HQ21BU008@Q0035:DHaQS6008<H`062484
8@Q21248@P@Q0PQ21@aS00<8@PaS248010Q200<48@Q212400`Q200@48@Q2
36<@Q0<HaP8DY@0448@DYA2448@436<4248010aS1248@PQ20`aS0`Q20PaS
00@8@P@Q1248@P<48@0524848@@Q24848@0236<011245:DHaQBU0Q2400D<
Ha2448@DYA24008DY@0348@<Ha24008@Q0D<H`P8@P031248@PQ200L8@P8@
Q0035:D@Q0aS00<<H`0448@HaQBU48@236<00aS648@8@P0212401`Q2124<
HaBU7>LHaQ2400D<H`8@Q0<DY@<@Q08<H`03248<H`aS00D<H`D8@P0836<@
Q12436<8@PaS48@DY@8Li`8HaP0;7>LHaS6<=Je:DVmkIcU>Lc6<36<@Q002
36<348@00`aS2488@P0324800`@Q2488@P03248312400`Q236<8@P022482
36<00`Q236<<H`0836<3248010@Q2488@PaS0Q240PaS00<8@PaS48@00Q24
00@HaQBU5:D@Q08<H`8@Q08HaP035:D@Q0aS0088@P8<H`0I48@DY@aS36<H
aQcW@Q16<E[FIcUNmfLiE[E:DSg_8@PDYCW>E[E>LbU:248<Ha2424800`@Q
00@000@Q248<H`88@P031248@P@Q01848@0<248<H`aS48@DYAcW9BTicSg_
BU9243g_0T8@00@mkd8@@Q1:DP=6<@=:DP04AS5:DTHaBU82AS400dYBAS5:
DP04BU800dHaBU96<@02AS401TicDYA>LdHaBU9>L`9:DP04CW=BU5JeCW<3
DY@015JeDYA>LdYB14ic00I:DTicCW=BU4icDY@6CW<014YBCW=>Ldic0TYB
1Dic00=BU4YBAS400dic00I:DTicE[EBU4icBU82DY@00eJeCW=BU002CW<0
1E:DCW=BU4icDY@00Tic15:D00A>LdYBAS5:DP9>L`=:DP9>L`9:DPA6<@05
BU9>Le:DDYA>L`03BU801THaBU9>LdHaBU96<@I>L`04BU9>LdHaAS42BU80
15:DE[EJeUJe0U:D00=>Le:DE[D00Tic00=:DTicDY@00U:D0eJe00E>Le:D
DYABU4ic009BU004E[EBU5:DDY@2F]H2E[D00e:DE[EJeP02E[D3DY@015[F
DYAF]E:D0UJe00UJeUJeE[EJeU:DE[EBU5JeF]H00UJe0e[F15Je0U[F0E:D
0Cg_00000`@Q00048@0212400`0012448@0312402@Q2;F]JeTHa9BT]JcF]
>Lhmk`02>Lh01S6<=JdicSF]>Lhe[@8icP04=Jd]Jbe[<H`4=Jd01CW>=Jdi
cSF]<H`00SF]00<icSF]>Lh00SW>00<aS3F]>Lh00cg_0SF]00DaS2e[<H`a
S3F]00<aS005>Lhmkd8@>Lhe[@02<H`3;F/022U:;F/]Jc6<;F/U:B487>L2
6<H01Q24248HaR489BTLi`<8@P848@0524848@Q2248<H`0248@010aS2488
@P@Q0PQ210@Q00H8@P@Q1248@P@Q2482124010aS5:DLiaS60a240PaS00<8
@PaS24800`Q20PaS00<8@PaS248010Q200@<H`Q236<<H`<8@P848@032484
8@Q20088@P031248@PQ20088@P0?36<@Q12436<HaSF]DYA:DRe[9BTYBRDY
6<H@Q0aS0088@P0336<8@PaS008<H`H8@P041248@P@Q2482124324831249
36<02A245:DHaQBU48@DYAS65:D<H`0212401PQ2124@Q1246<HLi`<@Q08<
H`0448@<Ha2436<448@236<2248836<07`Q236<8@PaS248<H`Q236<8@PaS
5:DLibDY7>LQ22DY>Li6<D8@?NlaS2U:;F]>Le[F@Q0U:@Q236<DYA24008<
H`0424848@Q21242248010@Q2488@PQ20`@Q1PQ200<<H`Q236<010aS0Q24
0`aS00@8@PaS36<<H`88@P@<H`H8@P0536<@Q1BU5:D<H`0248@00aBU48@@
Q00248@01ABU48@8@PQ236<00QBU00X<H`Q248@Lib48CW=S67NmNmi_N`9g
_@08Kg]JeSF]9BTHaQcW6<H@Q0<<H`0424848@@Q000212401PQ21248@P@Q
24848@88@P<48@0300048@@Q00<48@0500048@@Q1240000212401@002488
@QBU48@00QS600<LicF]?Nl00TYB0d8@00<mkd8@BU800TYB0THa00=:DTic
CW<01dYB00A244HaBU9:DP96<@03BU96<DYB009:DP9BU003CW=:DTYB00=:
DP=>L`05DYA>Le:DDYAF]@02DY@014YBDYABU4ic0TYB0dic0U:D00EF]E:D
BU9>Le:D00=>L`03DYA:DTYB009>L`04DYA>LdicDY@4CW<02E:DCW=>Le:D
CW=BU4icDYA>L`04DY@01DicBU9>LdYBCW<015:D1dYB00=>Le:DCW<00Tic
00A:DTicBU96<@=24008BU9>Le:DDYA>LeJeDYA6<@924007BU9BU4icBU96
<DYBAS401TYB00=6<DYBCW<014ic00=BU5JeDY@00U:D00=>Le:DCW<00TYB
0e:D0dic00ABU5JeDYA>L`EBU006CW=BU5:DF]IF]E[F1EJe0U:D15Je00AB
U5JeE[EJePAF]@=BU09F]@03DYAF]EJe00MF]@5JeP5F]@52400000@000@Q
124000848@0;00048@Q200048@Q2;F]JeSg_8@P]J`03>Lh02Sg_>Lhe[C6<
=JdicSg_>Lhe[CW>0S6<0Re[00DaS3F]=Jde[C6<00@e[@04<H`e[C6<=Jd2
>Lh3=Jd013W>@Q1243W>0SF]0Re[0S6<00DicSF]=JdaS3F]00<icP08=Jda
S36<;F/aS2e[9BTYBP8aS00<;F/Q21S66<HDYAS648@<HaBU7>LU:AcW0PQ2
0P@Q10Q200D48@aS48@@Q0aS00<8@P<48@0324848@@Q00848@0324848@aS
0088@P03124<Ha24008Li`0548@<Ha2436<8@P0236<4248236<2248010aS
2488@PQ20PaS00D8@PaS36<<H`Q200848@0824848@@Q1248@P@Q24848@88
@P0B36<@Q12448@8@QcW>Li>LdYB;F/Q22U:9BTLi`Q236<48@Q20`aS0PQ2
0PaS1`Q20P@Q00<8@PaS24800PQ200@48@Q2248<H`88@PH<H`035:DHaQBU
008DY@056<H@Q0aS1248@P0212401@aS5:DLiaS65:D00Q2420aS00<@Q1BU
36<00`Q20`aS00H8@PaS36<<H`Q236<2248536<224800aBU7>LU:@028@P0
1RDY=Je2448@?NlaS08YBP06BU9JeT8@9BT48@Q20Q2400<<H`Q212402@Q2
00<48@Q224801`Q20PaS00<8@PaS36<00Q240PaS0PQ20`aS0`Q210aS0`Q2
00H48@Q2248<Ha245:D236<00a245:D@Q00236<248@07aBU36<8@PQ236<D
YA2436<8@PaS8@PU:EJeHaQg_G_NKg]kgWNmJeYF]Be[8@PHaQcW6<H@Q0aS
48@<H`Q200H48@88@P848@0324848@@Q00L48@0300048@@Q00L48@03248<
Ha24008DY@076<HQ23F]?Nm:DTHa?Nl00T8@00<mkd8@AS400TYB0THa0dYB
00=>LdYBBU800dYB1DHa0TYB00A6<DYBAS5:DP=>L`03DYA:DTHa00=:DPE>
L`9BU09F]@04CW=:DTicDY@4BU8015:DCW=>LeJe0U:D1Dic00=BU4YBCW<0
2Dic0U:D14ic00IBU4icCW=>Le:DCW<2DY@2CW<3BU803dicDYABU5:DCW=:
DTicBU9>LdYBAS5:DTicDYA>L`02BU801dicBU9:DT8@AS5244Ha009:DPEB
U009AS4mkd8@AS5>LdYBAS5:DTHa00E:DP0:CW=2448@AS5>Le:DCW=:DTic
E[D3DY@01DicDYABU5:DBU800Tic0U:D0Tic1E:D00E>Le:DDYAF]Dic00=B
U007E[EJeUJeE[EBU5JeF]H015:D00AF]E[FDYABU09F]@03F]IF]E:D009F
]@EBU0IF]@06F]IF]EJeDYAJeUJe0Cg_000212400`0012448@0312402@Q2
12448@Q2;F]NmdHa9BT]J`02>Lh00cg_>Lhe[@02=Jd2>Lh013F]>LhicSW>
0S6<00@]JbU:<H`aS08icPDe[@<aS004;F/aS3W>?Nl3=Jd3>Lh01SF]>Lha
S2e[:DXaS08e[@@icP05=JdaS36<;F/YBP03=Jd01c6<9BTQ22489BTQ21cW
00@DY@<<H`<@Q00436<8@P@Q248212400`Q2124<H`0236<00`Q21248@P02
248712400`Q212448@04248348@336<25:D248@224800`aS248<H`0236<5
248336<248@236<324801P@Q24848@@Q24848@8<H`<@Q00>5:DQ2248:DXU
:C6<@Q1>Lg>LJeY6<C6<24848@L8@P041248@PQ22482124324800`@Q2488
@P022483124010Q21248@PaS0PQ200@<Ha245:DHaP@DY@D@Q0D8@P0736<@
Q1245:DHaQBU48@010aS00<8@PaS24800`aS0PQ200@<HaS66<HDY@8HaP04
7>LHaQBU5:D236<010Q236<<H`aS0PQ20PaS00L@Q2DY;F]BU5JeHaQ[FP02
F]H02dic@Q0icRU:8@PYBSF]9BTDY@@Q24800PaS0`Q20P@Q0`Q20P@Q00@8
@P@Q12448@88@P031248@PQ200<<H`0748@<HaBU5:D@Q1BU36<00`Q20`aS
00@@Q1BU5:DDY@8<H`<8@P041248@PQ2248236<0112436<<Ha240`aS0a24
0`Q210aS00l8@Q247>LLidHaE[E_NgNmKg]kgWNmNmiS63g_9BT00`Q200<4
8@aS5:D00Q2400<48@Q2248010Q20`@Q00<8@PaS24800`@Q00<000@Q0000
10@Q00<000@Q12400P@Q00D000@Q124<HaS6008DY@086<HQ23W>@Q1BU4ic
@Q1:DP=6<@A24096<@=>L`=:DP03CW=:DTHa00924006AS5:DTYBBU96<D8@
0dHa0TYB0Tic0TYB00I>Le:DBU9>LdYBCW<4DY@00dicDYA>L`05BU83CW<2
DY@00eJeDYA>L`02CW<01E:DCW=>LdicBU8014ic00=BU4icCW<00dYB00=>
Le:DE[D015:D00=F]E:DBU800dic00ABU4YBBU9:DP9>L`04BU9>LdicCW<6
BU800dHaCW=>L`02DY@2BU800dHaBU96<@02AS40248@BU9:DU:DE[EBU4ic
BU83@Q001THaCW=BU4icDYA6<@=2409>L`0:BU96<D8@BU9>Le:DCW=:DTHa
BU82DY@00dicBU9>L`02DY@01eJeDYABU5:DCW=BU4ic00EBU0A>L`03DYA>
Le:D00=F]@9BU004E[EBU5:DDY@5E[D01U[FE[EBU5[FE[EJeP9BU003E[EB
U5:D009BU006E[EBU5:DE[EBU5Je0U:D00EF]E[FF]IJeUJe0052400000<0
00@Q12400P@Q00<000@Q12400`@Q00P8@Re[G_M242DY<H`icSF]0SW>0SF]
00<icSF]<H`013W>00@]Jc6<;F/YBP8aS08icP8e[@04<H`e[C6<;F/2<H`0
0be[=JdicP02>Lh2<H`5>Lh0136<;F/]Jc6<0cF]00@icSF]>Lhe[@8aS003
:DX]Jc6<008e[@03<H`U:B48008Q20039BTLiaBU008DY@0348@<H`aS00@<
H`0348@8@PQ200@48@04248<H`aS36<224800`@Q24848@0612401@Q21248
@P@Q24800P@Q00@8@PaS48@@Q0<<H`0448@DYABU36<2248636<224801`aS
2488@PQ236<@Q0aS00@8@P<48@@8@P8<H`0648@<Ha245:DLib480RDY00La
S4HaDYAcW6]J@Q0]J`0324800`@Q2488@P0324801@@Q2488@P@Q24800P@Q
00@8@P@Q12448@@8@P051248@P@Q248<H`0224800`@Q248<H`026<H35:D0
0a245:D@Q00248@236<00`Q212448@0236<021245:DDYAS65:D<Ha242482
36<01PQ236<<H`aS48@<H`88@P0536<@Q1cW5:DHaP025:D01AS65:D@Q0aS
24800`aS0`Q20a2400HQ22U:CW=JeV<HIcT2F]H02Dic?Nle[BDY8@PYBS6<
8@PDY@0224800a2436<8@P03124324800`@Q24848@02124010Q21248@P@Q
0PQ20`aS00@8@PaS48@DY@8@Q0055:D<H`aS36<8@P0236<01A245:DDYABU
48@00PaS00H8@P@Q1248@PaS248536<248@336<248@00`aS24848@022484
36<021247>LQ24YBF]I_NgNmKg/2Nmh017NmHaPe[BDY0PQ20P@Q0a2400@<
H`Q21248@P848@P8@PP48@0300048@@Q00848@0600048@@Q1248@Q240QBU
00P@Q1S68@Q244YBDYA>Ld8@0dHa148@00A6<D8@AS5:DP=>L`96<@=:DP=2
4003AS5:DTHa0096<@924096<@E:DP=>L`9:DP03CW=BU4ic009BU0=>L`9:
DP03AS5:DTYB00=>L`=BU004E[E>LdicCW<2DY@01DicBU9:DTYBDY@00dic
00A:DTicCW=:DP9>L`ABU003CW=BU5:D009>L`03BU9>Le:D009>L`A:DP06
CW=:DTicCW=:DTHa0dYB00=6<DYBCW<00U:D00=>LdYBBU801THa00A:DTic
DYABU09>L`06BU92448@@Q16<E:D0Tic00i:DT8@@Q1244HaBU9>LdYBAS52
44HaBU9BU4ic0dYB00A>Le:DCW=:DP9>L`09E[EBU5:DDYA>Le:DCW=BU4ic
00ABU0I>L`05DYAF]EJeE[E>L`02E[D2DY@3E[D00e:DE[EF]@05E[D2DY@0
1EJeDYA>Le:DCW<00eJe0U:D00=F]E:DE[D00eJe00=JeUkgDY@00Cg_0000
1@@Q00048@@Q00000`@Q00T8@P001248@Re[E[E242U:;F/00SF]0cg_13W>
00<e[C6<<H`00c6<00<]Jc6<<H`00c6<0cF]00<aS3F]<H`00Re[00<aS3W>
=Jd00SW>00<mkcF];F/00Re[0SW>00@e[BU::DX]J`8icP8e[@<icP@aS08i
cP06=JdaS2U:9BTLiaBU11S600<DY@aS36<00`Q200H48@aS48@@Q0Q20004
124224801PaS24848@Q21248@P848@0324848@Q200848@0324848@Q20084
8@<8@P8@Q0035:DHaQ24008<H`88@P0348@<Ha2400@<H`03248<H`aS00<8
@P8<H`0348@<Ha2400<DY@0524848@@Q124<H`0224801PaS5:D@Q1247>LU
:@@icP0<=Jd]Jc6<AS5>Lf<HE[DU:AS600048@aS1@Q21@@Q00D8@P@Q1248
@P@Q0088@P0836<8@PQ21248@P@Q248<H`@8@P8<H`<@Q0<DY@8@Q0<DY@04
48@8@PaS48@26<H011BU48@@Q1240`aS10Q200<<Ha2448@00PQ200P<HacW
8@PQ22DY;F/YBRDY0QcW00P@Q0aS248<Ha245:D@Q0Q20PaS01DDYC6<>Li[
FW>LMkekgW>LMke_NeJe?NlDY@aS5:DU:AcW36<48@Q236<00PQ20P@Q00<8
@P@Q12401P@Q20Q200D<Ha2448@<HaS6008Li`035:D<H`aS00D<H`<@Q004
36<8@PQ236<2248010@Q248<H`aS0PQ200<<H`Q236<00`aS00@8@PaS2484
8@88@P0336<@Q12400<<H`065:DHaQS6<H`icUkg0V<H00I_NfLiG_M:DRU:
7>L4248010aS248<H`aS0Q2410Q20PaS10Q200<<H`Q2248040@Q00<<HaBU
5:D00QS600HU:CF]?Nm>LdYB@Q02AS400dYB@Q0mk`02?Nl00dYBCW=:DP02
CW<014YBAS56<DHa0Tic0TYB0THa00I:DTHaAS56<DYBAS42@Q000dHaBU9:
DP02AS400d8@BU9BU004CW<2DY@01DicBU9:DTicDY@00TYB00A6<DYBBU9:
DP9>L`9BU003CW=BU5:D00=>L`03DYA>Ldic009>L`9:DP9>L`04DYA>Ldic
DY@2CW<4DY@2CW<00e:DCW=:DP02BU82CW<00dYBCW=>L`02BU801dHaCW=>
Le:DCW=:DTHa009>L`=:DP05DYA>LdYBAS524002AS42BU82AS401TYBCW=B
U4icBU96<@9:DP04CW=:DTYBBU83CW<014YB@Q12448@0TYB0THa00A:DTHa
BU9:DP9>L`06BU96<DHaCW=:DTic0U:D00=>Le:DDY@00U:D00MF]E:DCW=B
U4icDYA>L`03DY@014icBU9>Ldic0eJe00=BU4icCW<00U:D00=>Le:DE[D0
0U[F00AF]E:DE[EJeP9F]@05DYAF]E:DCW=BU002CW<00eJeDYAF]@04DY@4
E[D015[FE[ENmeJe0Cg_000212400`0012448@0612401@Q2:DYF]Cg_9BT0
0S6<00<e[CW>=Jd00SW>00DmkcW>>Lhe[C6<00@]J`03<H`]Jbe[008]J`03
<H`e[CF]00<e[@@]J`03>Lhe[CF]008icP8aS008;F/aS3W>@Q0aS2e[9BT]
J`8icP<e[@04<H`e[C6<;F/2<H`013W>=Jde[CF]0RDY00<LiaS66<H011BU
00<@Q0aS24800PQ200D48@Q25:D@Q0Q200848@88@P031248@PaS0088@P04
1248@PQ200021242248612402PQ21248@PQ2124<Ha246<HDYA240PaS00<8
@PaS36<00PaS00P@Q0aS36<<H`Q236<8@PaS0`Q20`aS00HDYA245:DDY@aS
24821243248248@25:D03aS68@Pe[CW>=JdicSF]:DXaS4YBE[ENmdic7>LD
Y@02124010aS2488@PQ21@@Q00P8@P@Q12448@Q21248@P@Q0`Q200<48@Q2
124010Q200L48@Q2248@Q0aS48@<H`035:D348@35:D336<011246<HDYA24
0QBU0Q240PaS10Q200<<Ha2448@00PQ200D@Q1cW9BTLibDY00<YBP036<HL
ia240088@P0536<@Q12436<8@P0336<00c6<>Li_N`02Li`037_NLiakgVmk
DY@icQS648@DYB486<H<H`848@0336<8@P@Q0088@P031248@P@Q00<48@03
24848@@Q00L8@P<<H`8@Q0056<HLiaS66<H8@P0436<00`Q236<@Q00248@0
1@aS2488@PQ212400PQ200H<H`Q22488@PaS248236<00`Q236<8@P052480
10@Q248@Q1240`aS00h@Q1S65:DaS3g_HaQW>EkgKg]W>EkgBU8U:AS610Q2
00@<Ha2448@@Q0<<H`D8@P031248@PQ200<8@PH48@0300048@@Q00848@03
00048@@Q00848@03248<Ha24008DY@076<HQ23W>@Q1:DTHa@Q000dHa00E2
43g_?Nm244Ha009:DP07CW=BU4YBAS5244YBCW<00TYB0THa0dYB0T8@00=6
<D8@@Q000T8@0dYB00M244HaAS5>Le:DCW=:DP02CW<015:DCW=:DTHa0dic
00=:DTHaBU800TYB0dic0U:D00=F]DicDY@01Dic14YB0dic00=BU4icCW<0
0dic0U:D00=>Le:DCW<00Tic0dYB0Tic0TYB00=>LdYBAS400TYB00M>Le:D
BU9:DTHaBU9>L`02BU803DicBU9:DTYB@Q16<D8@AS5:DTHaBU96<DYB00=>
L`M:DP05CW=:DTicCW=6<@03@Q04AS42BU801THaBU9>LdicBU96<@=:DP03
CW=BU5:D00IBU003CW=BU4ic00ABU003CW=BU4YB009>L`9BU004E[EBU4ic
CW<5DY@01UJeF]IF]E:DE[EBU0AF]@=BU09>L`=BU00:E[EBU5:DE[EBU5Je
DYAF]E[FE[D2F]H1DY@1>Lh0000500048@@Q1240000512401P0036<YBU:D
@Q0YBP8aS005;F/aS3W>?Nm24002>Lh01Cg_<H`aS2e[:DX00c6<0bU:00@e
[CW>=Jde[@8aS004=JdaS36<<H`2=Jd013W>=JdicSF]0S6<0SF]0SW>00He
[Be[;F/aS3F]<H`2=Jd00cW>?Nle[@02=Jd2<H`4=Jd01c6<;F/Q21cW6<H@
Q1BU008HaP055:D@Q0Q236<48@05248212401@Q21248@P@Q24800P@Q0PQ2
00<48@Q212400PQ200D48@Q212448@Q200<48@0724848@@Q24848@Q21240
10Q20PaS112410aS00<8@PaS36<00PQ20PaS00L@Q1BU48@@Q0aS48@<H`02
24804@aS48@<H`aS248<HaBU7>M244HaF]IW>EkgIcUBU4Ha>Lh00RDY00@a
S3W>;F/Li`88@P848@<8@P848@0300048@@Q00848@0424848@Q212422480
0`aS48@<H`02248010@Q2488@PQ20P@Q00D8@PaS48@<Ha24008<H`<@Q004
36<8@PaS48@55:D01A245:DHaQS65:D00a2400<DY@aS48@0112400@<Ha24
48@HaP8Li`089BTYBR485:DU:CF];F/HaP848@0448@<H`Q2248236<01A24
;F/icV<HJeX00g>L00Ioog_NG_LicQBU48@336<01PQ21248@PQ21248@P84
8@0524848@@Q1248@P0512401@Q21248@PQ236<00`Q200/<Ha245:D@Q0aS
6<HQ22DY7>L<Ha24008<H`04248<H`aS36<32482124010Q236<<H`aS0PQ2
00<<Ha2436<00PaS2@Q2014<Ha242488@Q249BTLia248@Pe[FLiJeYF]E:D
>LhU:AcW008DY@8<H`041248@PQ2248336<6248236<010Q236<8@PQ20`@Q
00<000@Q00000P@Q00<000@Q12400P@Q00P000@Q12448@Q236<DYA240QBU
00<Libe[=Jd00THa00=244Ha@Q000Sg_0THa1dYB00A6<D8@@Q16<@A:DP03
@Q16<DHa009:DP08AS52448@@Q16<D8@AS524096<@08BU9>LdicCW=:DTHa
CW=BU09>L`04AS5:DTYBCW<2BU801THa@Q16<DicDYAF]@=>L`05DYA>Ldic
CW=BU003CW<3BU801TicDYABU4icBU9>L`=BU09>L`08DYAF]E:DCW=:DU:D
CW=BU09>L`A:DP03CW=:DTic00=:DP03AS5:DTic00A:DP03DYA>Ldic009:
DP06CW=:DTicCW=:DTic0dYB00=6<DYBBU8014ic00=:DTicDY@00TYB14Ha
00=243g_AS400TYB00A>LdHaBU9>L`9:DP07@Q16<DYBCW=BU4icDY@014ic
15:D00A>Le:DCW=>L`ABU00:CW=BU4icCW=BU4icDYA>Le:DCW<2DY@2E[D0
1e:DE[EBU5:DE[EBU5Je009BU003E[EBU5:D00ABU0=F]@ABU007E[EJeUJe
F]IF]E[FDY@00CW>000312400`001240000512401@Q29BUF]D8@:DX00c6<
0SF]0Sg_0cW>00@e[Be[:DX]J`8aS004:DX]JbU::DX2<H`00cF]<H`aS003
=Jd3<H`00cW>=JdicP02=Jd01S6<=JdaS36<=JdicP8aS003:DXaS36<00<a
S08icP04?Nle[CF];F/2<H`01Be[=JdicS6<;F/00QcW00<HaQBU48@00aBU
00H<H`Q22488@P@Q248236<010Q200048@@Q0`Q200@48@Q21248@P<48@@8
@P848@0524848@@Q1248@P0412400`Q21248@P02248212401@Q236<DYABU
48@010aS00@8@PaS2488@P@<H`045:D@Q12448@436<010Q236<DYA240PQ2
00D<HaBU6<HicTHa009S600;G_MS65:D@Q0icRDY7>L]JcW>;F/Li`021244
248912401@Q212448@@Q24800PaS00L@Q0aS2488@P@Q24848@03248236<0
0a2436<<H`0448@336<00a245:D@Q0025:D00aS65:D@Q0035:D00a2436<@
Q00248@00`aS48@@Q00548@00aBU7>LQ20028@P27>L01RU:<H`U:ABU1248
@P8<H`88@P<<H`03:DXicVLi009_N`09Mke_NgooNmiF]CF]48@<H`Q2008<
H`0324848@@Q00848@0324848@Q200848@0324848@@Q00<48@0324848@Q2
00<8@P0336<8@PQ20088@P0=36<@Q1BU36<DYAcW8@PHaQ2436<@Q0aS2480
0PaS0PQ200L48@Q22488@PaS248<H`02248336<00a2436<8@P0424800`@Q
2488@P0224801@aS48@8@P@Q5:D00R4800D@Q248>Li[FVmk009BU003>LhU
:B48008@Q0<8@P03124<H`Q200<<H`88@P031248@PQ200@<H`@8@PD48@03
00048@@Q00P48@0<248<Ha245:D@Q1BU7>LaS3W>AS5243g_0T8@00<mkd8@
@Q000dYB00A6<DYBBU9>L`9:DP924096<@=:DP9240=6<@924003AS52448@
00924003AS5244YB00=:DP08CW=:DTYBBU9>Le:DCW=6<@=:DP03CW=6<DHa
00924005CW=BU5:DDYA:DP02DY@5CW<2BU8014icAS56<DYB0U:D00=>LdYB
DY@00e:D00=:DTicDY@00U:D0TYB00A>Le:DCW=>L`A:DP03CW=:DTYB009:
DP04CW=6<DHaBU82CW<01dYBAS5:DTicDYA>LdHa00=:DP=>L`A:DP03AS5:
DTYB00A>L`9:DP03CW=:DTYB00=6<@A24003AS5:DTYB0096<@06CW=:DTYB
AS5244YB0Tic00ABU4icCW=BU09>L`EBU0A>L`9BU003CW=BU4ic009BU0=>
L`04DYA>Le:DDY@2E[D00e:DE[EBU003DY@01EJeDYABU4icE[D025:D00EF
]E:DDYA>Le:D00=F]@9JeP5F]@5BU04icP0000<000@Q124020@Q00D8@RU:
DY@icRU:00<aS08e[@8icP8mk`06>LhaS36<;F/aS3F]0S6<00H]Jc6<<H`a
S2e[<H`3>Lh2=Jd00c6<=JdicP03=Jd3>Lh00cF]<H`aS002<H`2>Lh02C6<
;F/aS3F]>LhaS2U:;F/e[@02>Lh02C6<;F/]Jc6<?NlicRe[:DXU:@02:DX0
1AcW5:DDYAS648@00PQ20PaS00D8@P@Q1248@PaS0088@P041248@P@Q2482
12401@Q21248@PQ212400PQ200<<H`Q212400P@Q00D8@P@Q24848@Q200@4
8@0324848@@Q00848@04248@Q1246<H35:D236<4248236<01a2436<8@QBU
8@PYBRDY008DY@0936<48@Q248@DYA2436<48@aS008Li`0<CW=JeWNmNmi_
NgooMke[FTic;F/Q21BU0a240PQ200<48@0012400`@Q00<000@Q12400P@Q
10Q20P@Q00D<Ha2448@DYA240088@P848@88@P@<H`8@Q00536<@Q0aS48@<
H`04248348@25:D011245:DDYAcW0QS60QBU00<@Q1BU5:D011240aBU00/H
aR489BTU:B486<HDYAS67>LDYA240088@P8<H`88@P0336<@Q124008Q200A
BU9>Lf<HJeYS66mkE[DmkbU:48@HaQ2436<48@Q21248@P0236<011245:DD
Y@aS0P@Q00<<H`@Q12400P@Q0PQ20P@Q00<8@PaS36<00`Q21@aS0Q240aBU
00DHaQBU36<8@P@Q0088@P848@88@P031248@PaS00<<H`04248@Q12436<2
48@224800`@Q248<H`02248030@Q248Lib487>L<H`@Q5:D<H`@Q9BTmk`9W
>@07<H`YBQS65:DHaQBU36<00`@Q00@8@PaS36<<H`88@P031248@PQ200<8
@P0336<48@Q20088@P03124000@Q00L48@0300048@@Q00D48@0336<@Q1BU
008DY@0548@Libe[=Je:DP04@Q000dHa@Q124002AS401DYBCW=:DTYBAS40
0TYB00A6<D8@@Q1:DP9>L`=:DP03AS5:DT8@008mk`03@Q1:DTYB00=6<@92
4096<@9:DPE>L`03DYA>Ldic009:DP04AS5:DTYBAS42BU800dicDYA>L`02
DY@2E[D2CW<3DY@4BU83CW<2BU800dicE[EBU004CW<00e:DCW=>L`04CW<0
14YBCW=>Ldic0TYB00A>LdYBBU924096<@08@Q16<DYBBU9244HaCW=BU0A:
DP03CW=:DTic009>L`A:DP04CW=:DTYBCW<2DY@2CW<00dYBAS5:DP03BU84
AS46CW<00dYBAS56<@03AS400d8@BU9:DP03BU83CW<00e:DCW=BU003CW<0
25:DCW=BU4icDYA>Le:DCW<2BU800dicDYABU003CW<015JeDYABU4ic1E:D
00E>Le:DCW=>Le:D009F]@03DYAF]E:D009BU003F]IBU4ic009BU003E[EJ
eUJe009F]@5JeP5>L`4icP000P@Q00@000@Q124000D48@05248U:Dic>LhU
:@04<H`00cF]>Lhmk`02?Nl00cW><H`]J`04<H`00bU:;F/aS002;F/0136<
=Jde[CF]0SW>00De[CW>>LhicS6<008e[@8icP03=JdaS2e[00<aS08e[@06
<H`]Jbe[<H`icS6<0Re[00@e[CW>>LhaS08]J`06=JdicSW>;F/YBRDY0RU:
00@LiaBU48@DY@8<H`031248@PQ200@8@P061248@P@Q24848@Q21@@Q00<8
@P@Q12400P@Q00<<H`Q212400`@Q00<8@P@Q24802@@Q00H8@PaS48@@Q1BU
6<H25:D336<212400`Q236<<H`0336<011S67>LYBR480Q2400@<H`@Q248<
H`8DY@0336<48@aS008Li`0@BU9NmgNmNmi_Ng_NLiaW>E:D:DXLia245:D@
Q0aS248:12400`0012448@03124010Q21248@PaS0QBU00/<H`Q212448@Q2
36<8@PaS248<H`Q200@<H`0548@<H`aS24848@0224801Q245:DDYA2436<@
Q08HaP055:DHaQS65:D@Q0045:D236<248@25:D01AS67>LQ22487>L00aBU
00HQ21S636<48@Q248@236<040Q236<@Q1248@PU:DHaBU9S66]JHaQ[FU[F
>LhU:ABU0Q2400<<H`Q224800`Q200@<Ha246<H@Q088@P848@0324848@@Q
0088@P848@L8@P0336<8@PaS00<<H`8DY@8@Q0066<HDYA2424848@Q20`@Q
1@Q200@@Q0aS36<@Q0H<H`88@P0E1248@PQ2248000Q25:DQ21S636<48A24
36<48B48?Nm[FV<H<H`U:AcW008DY@0548@<H`@Q1248@P0236<524831246
2486124010Q212448@001@@Q00H000@Q12448@Q236<25:D248@01QS6;F/i
cTHa@Q0mk`=24006AS52448@AS5:DTic0TYB00A6<DYBBU96<@924004AS5:
DTicBU83AS401DYB@Q0icSg_@Q000TYB0dHa00A244Ha@Q16<@9:DP04CW=:
DTicCW<2DY@01DicBU9:DTYBCW<014Ha00=:DU:DCW<00e:D00=F]E:DDY@0
0U:D0Tic0TYB00A6<DYBBU9>L`=:DP=BU006CW=:DTicDYA>Le:D0Tic00=B
U4icCW<014YB00=>LdYBBU800TYB0THa00=244HaBU800TYB00=244HaBU80
0Tic00=:DTHaCW<00Tic2TYB0Tic00ABU4icBU96<@=:DP08AS5:DTYBAS52
44HaBU9BU0=>L`=:DPE6<@03@Q16<DYB00=>L`03BU9>Ldic009BU0A>L`03
DYA>Le:D00=>L`04DYA:DTYBBU82DY@00dicBU9BU004DY@00dicDYABU003
DY@00dicDYA>L`03DY@01EJeDYABU5:DE[D01E:D1UJe0E:D0CW>00001@00
12448@@Q00001@@Q00L000Q2:DYBU3W>9BT]J`02<H`4=Jd013W>=Jde[C6<
0cF]00LaS3F]<H`]JcF]<H`e[@02<H`00cF]>LhicP04=Jd2>Lh2<H`013W>
@Q0icS6<0RU:0S6<00<e[C6<<H`00SF]00<icS6<<H`0136<00<]Jc6<;F/0
0cg_00<icRU:8@P00RDY00<Q21cW5:D00QS600L@Q0Q22488@PaS24848@02
24801P@Q2488@PQ236<8@PP48@88@P041248@P@Q124224801@@Q24848@@Q
248020@Q0PaS00<@Q1S66<H00QS600L@Q0Q212448@Q21248@P0348@01@aS
5:DQ22486<H00`aS0PQ20PaS0188@PaS248<HaS67>M6<E:DLiag_F]JOomk
gWNmF]H]JaS6248236<812400`0012448@0224821242248212400`Q236<@
Q00248@00`aS248<H`0424800`@Q2488@P0336<248@236<01@Q21248@P@Q
24801@aS00@@Q1BU5:D@Q0<<H`0348@<Ha24008@Q08DY@<HaP085:DHaR48
9BTYBRDY6<HDY@<@Q00536<8@PaS48@8@P0236<02A245:DHaQS648@mke[F
Mke[FP02>Lh00c6<7>LHaP025:D236<4248236<00a2436<<H`0436<41240
0`Q21248@P0336<224801PaS2488@PaS248<H`<8@P8DY@8Li`046<HDYA24
248512400`Q21248@P0236<02A2436<8@PaS48@DYAS65:D<H`02248010@Q
2488@PQ22@aS00<8@QBU7>L00R4800<HaQBU5:D00Q2400<<H`Q212400P@Q
00<8@PaS24801@Q200<48@Q212400PQ20P@Q00<8@P@Q124020@Q00<000@Q
12401P@Q00@8@QBU6<HDY@8@Q0047>L]JcF]@Q02?Nl00d8@AS56<@02AS44
BU801THaBU9:DTicDYA:DP924003AS5>Ldic00=:DP96<@=:DP96<@05BU9>
LdicBU924002?Nl2AS42BU8014icDYA>Ldic0e:D0TYB0THa00E:DTicCW=>
LdYB009>L`03DYAF]Dic00EBU004CW=:DTYBCW<2DY@2CW<2BU82CW<014YB
CW=>Le:D0dYB00=>Le:DBU800THa0Tic00=BU4icBU800TYB00=>LdHaAS40
0T8@00E:DTHa@Q0mkdHa009>L`A:DP9>L`9:DP=>L`03BU9>LdYB00=>L`03
BU9BU4ic009>L`924006AS5:DTicBU96<D8@1DYB00E>Le:DBU9:DT8@0096
<@03BU96<Cg_008mk`E:DPA>L`03DYA>LeJe009>L`=BU003CW=:DTic00=>
L`05BU9>LdYBDYA>L`02DY@2CW<5DY@00dicDYA>L`03DY@4CW<00e:DE[EF
]@02DY@2CW<3DY@015JeDYAJeU:D0CW>000312400`0012448@0512401@Q2
9BU:DSW>9BT01S6<00<icSF]=Jd00c6<00<e[C6<=Jd00c6<00H]Jc6<=Jd]
Jc6<=Jd2>Lh00cF]<H`e[@02>Lh00cF]<H`icP03>Lh01S6<:DXYBRe[<H`e
[@8aS08e[@8aS003;F/aS36<00<aS006;F/aS3W>@Q0icS6<0bDY00TYBRDY
6<HDYA245:D@Q0Q2124010Q200<48@Q212400P@Q0PQ200<48@Q212401P@Q
00L8@P@Q24848@Q21248@P031242248712401`002488@Q2436<DYAS6008L
i`0448@8@P@Q1244248348@011S67>LLiaBU0`aS00<8@P@Q248010Q200D@
Q1S67>M6<E:D009cW008Kg]oogooLiaF]BDY6<H8@P8<H`88@P@48@040004
8@@Q12422482124224821243248348@724801@aS2488@P@Q36<00a2400D<
H`Q236<8@P@Q0088@P@<H`0448@DYABU48@336<00a2436<@Q00248@00`aS
48@HaP026<H25:D00aS68@PQ20029BT01QS648@@Q1BU48@<H`88@P@<H`8D
Y@0<6<HDYA24?NmJeWNmJeXicSF]:DXQ21S60a2400D<H`Q22488@P@Q008<
H`0348@<H`Q200@<H`<48@88@P061248@PQ236<@Q0aS1@Q200d<H`Q22488
@PaS48@DYAS67>LHaQBU48@8@P0512401@Q21248@PaS48@00PaS00/8@PaS
48@@Q1BU48@8@PaS1248@P@Q00<8@PD<H`<8@P0336<DYAcW008Q208DY@<@
Q08<H`848@@8@P031248@PQ20088@PH48@<8@P848@0300048@@Q00848@03
00048@@Q00P48@8<H`@DY@067>L]Jc6<?Nm243g_0d8@0dHa1dYB00]BU4YB
@Q1244HaBU9>LdYBAS5:DT8@0096<@09BU96<DHaBU96<DYBCW=6<D8@008m
k`03AS5:DTHa00E>L`04DYA>Le:DCW<2BU801DHaBU9>Le:DCW<00TYB0U:D
00E>Le:DDYABU5Je00=>L`9:DP05CW=BU5:DDYA6<@02BU801dicBU9>LdYB
CW=BU4ic009:DP03DYA>Ldic00=:DP03DYA>Ldic009:DP08CW=6<DHa?Nm2
44HaBU96<@924005AS5:DTicBU96<@02BU8015:DCW=:DTYB0dic0TYB00=>
LdYBDY@014ic0TYB0dHa00M:DTicBU96<D8@AS5:DP02CW<2BU801DicBU96
<DHa@Q000dHa00A243g_@Q1:DP96<@9:DPE>L`03DYA>Ldic00=BU09>L`E:
DP05CW=:DTYBBU9>L`02DY@2CW<5DY@014icDYA>Le:D0Tic0U:D00=>Le:D
CW<00eJe00MBU4icDYA>Le:DE[EBU002E[D1DY@1>Lh00003124000@Q0084
8@0=00048@@Q248000@Q248U:Dic>LhU:C6<=Jd00c6<13F]00DicS6<=Jde
[CW>008e[@LaS004>Lhmkcg_>Lh2<H`3=Jd2<H`01CF]>LhicSF]<H`00be[
00<e[C6<=Jd00cF]00/aS3F]=JdaS3F];F/aS3g_@Q16<D8@008aS005;F/Y
BR488@PLi`036<H011cW5:D<H`Q20PaS0`Q20`@Q00P8@P@Q2488@P@Q2484
8@Q210@Q0PQ200<48@Q2248010@Q0PQ200<<H`Q212401@@Q00<8@P@Q2480
0Q2400@DYA2448@DY@8<H`@48@07248<H`aS5:D@Q1S67>L00QBU0PQ20`aS
00X8@PaS1248@PaS48@HaQBU<H`icP=Nm`04Kg]Nmdic=Jd26<H0112436<<
H`aS1PQ20`@Q00D8@P@Q2488@P@Q00<8@P071248@PaS48@<Ha2436<00`Q2
00<<H`Q224800P@Q0PQ20`aS00DDYA245:D@Q0aS00<8@P0336<48@aS00<D
Y@@<H`04248<H`Q2248336<248@011S648@DYA2411S600HDYA2448@<Ha24
5:D336<041BU7>LHaQ2436<48@aS5:D<HcW>G_MW>Dic6<HDYB4811BU0Q24
2@Q200<<Ha2448@00PaS0`Q200<<H`Q236<00Q2400<DYA2436<00PQ200X<
Ha2436<<H`Q236<8@Q246<HLi`8HaP8Li`0348@8@P@Q00@48@03248<H`aS
008<H`0724848@Q248@HaR485:D00Q2400@<H`Q224848@L8@P8<H`88@P05
36<@Q0aS36<8@P0336<2248312400`Q236<<H`0324800`aS2488@P021244
24800`@Q24848@0812400`0012448@0312401P0012448@@Q248@Q0@DY@08
8@PYBRU:>LhmkdYBAS5240=6<@08BU92448@@Q16<DicBU9>L`=:DPA6<@=:
DP96<@0=BU9BU5:DAS5244YBCW=:DTHa@Q16<D8@AS400TYB00=>LdYBCW<0
0U:D1Tic1DYB0dic0e:D0Tic00E:DTicCW=BU4ic009:DP03CW=BU5:D009B
U003CW=BU4ic009:DP9>L`08BU96<DYBCW=BU4ic@Q16<@9:DPE>L`E:DP03
AS52448@00924003AS5:DTic009:DPE>L`04BU9>LdicCW<3BU86CW<2BU82
CW<00dYBAS5>L`02AS42@Q04BU801DicAS56<Cg_@Q000THa1D8@0TYB00=>
Le:DBU800TYB00A>Le:DDYA>L`9:DP03CW=BU5:D009>L`04BU9>LdicCW<2
BU800dicDYABU002CW<00e:DCW=>L`02CW<01E:DE[EBU5JeDY@014ic00=:
DTicBU801E:D0Tic00=BU4icDY@00UJe0E[F0Dic0CW>00001@0012448@@Q
00001P@Q00D8@RU:CW<e[BDY008e[@<]J`@e[@09<H`e[C6<=JdaS3F]>Lhe
[C6<008]J`8aS004=JdicSW>=Jd3<H`3=Jd2<H`2>Lh00cF]<H`YBP03;F/0
0c6<=Jde[@04=Jd4<H`2;F/013W>AS56<Cg_0Re[0RU:00<U:B487>L011S6
00<@Q0Q2248010Q200D48@Q21248@P@Q00@8@PL48@D8@P848@@8@P041248
@P@Q000512400`Q236<@Q00348@25:D01A242488@P@Q24800P@Q00P8@Q24
48@@Q1BU7>LHaQ240PQ200@<H`Q2248<H`<8@P0?36<DYAS65:DaS3W>G_MS
65kgKg]NmdYB<H`DYAS6008@Q00536<8@P@Q24848@03248212401@Q21248
@PQ212400`Q200L48@Q236<@Q0aS48@<H`0724821244248248@011BU48@<
H`aS1@Q200@@Q1BU6<H@Q0D<H`0<248<H`Q2248<H`Q236<@Q1BU6<H@Q1BU
11S60QBU0a240PaS00D@Q0aS5:DDYAS6008<H`0<124@Q1BU36<mkekgHaQ>
LaBU6<HQ21BU112400<<H`Q224801`Q200@<Ha2448@<H`@8@P0636<8@PQ2
36<DYA242@aS00@48@Q25:DDY@8Li`055:DLiaS636<8@P0212400`Q21248
@P02248336<01`Q21248@Q246<HQ21cW008@Q088@P031248@PQ20088@P84
8@03248<Ha24008<H`04248<H`aS48@236<00`Q236<8@P0824800`aS2488
@P052482124010Q21248@PQ20P@Q00<000@Q12401@@Q00@000@Q124000<4
8@0524848@aS48@HaP0248@01QS68@P]Jbe[>Li24096<@0:@Q16<DHaBU96
<D8@AS5244HaBU83CW<014HaBU96<D8@0dHa00]:DTHa@Q1244icDYA>LdYB
@Q16<DYB0096<@03@Q16<DHa0096<@06CW=:DTYBBU9>Le:D0Tic0U:D00=>
LdHaBU800dic0TYB0Tic0U:D0dic0TYB0dic00M:DTicCW=F]E:DCW=BU003
CW<2BU82CW<00dYB@Q1:DP02DY@01DYBAS56<DYBAS401Dic00A:DTHaCW=:
DP96<@07?Nm2448@@Q16<DYBCW<00dYB00E>Le:DCW=>LdYB00=>L`9:DPM>
L`I:DP96<@04@Q16<DYBAS42BU82CW<01DYB@Q0mkd8@AS401D8@00=6<DYB
BU800Tic00A:DTHaBU9>L`9BU09:DP9>L`03DYA>Ldic009:DP9>L`=:DP03
CW=BU5:D00A>L`07DYA>Le:DDYA>LeJeDY@00Tic0TYB00=>LdYBBU800Tic
0U:D00=>Le:DDY@00dic0UJe00=BU5JeDY@00CW>000212400`0012448@06
12401`Q2:DYBU3g_9BTe[CW>00<aS00:>Li2448@?Nle[C6<=JdicSF]>Lh4
=Jd2<H`012e[<H`e[CW>0Sg_00De[C6<<H`aS3F]00@aS08e[@06<H`]Jbe[
<H`e[C6<0SW>00HmkcW><H`aS2e[:DX3;F/02T8@AS56<Cg_;F/aS2U:8@PL
ib480RU:00<U:B486<H00QS600@@Q0aS248<H`88@P@48@D8@P@48@88@P03
1248@PQ200848@03248<H`aS0088@P8<H`0324848@@Q00<48@<8@P8<H`8@
Q0D<H`04248<H`aS1242248548@336<01PQ236<<H`aS248<H`88@P0;48@L
iaS636<U:CW>Kg]cW4icAS4]J`026<H27>L00aBU48@8@P02248010@Q2488
@PaS10Q20P@Q1`Q200P48@aS48@@Q0aS24848@Q20PaS00<8@P@Q12400`Q2
00<<Ha245:D00QcW00HQ21cW48@<H`@Q248236<448@236<01A2436<<H`Q2
124010aS00T8@PaS36<<Ha245:D@Q1BU48@01`aS0Q2400<<H`Q236<00PaS
0`Q200T@Q0aS7>LU:B487>LDYA245:D00Q241PaS0`Q200D48@Q236<<Ha24
00<<H`03248<H`aS008<H`8DY@0448@<H`aS48@436<00a2436<<H`0236<0
10Q236<@Q1S60QBU00@LiaS648@<H`<48@04248<H`aS36<224800`@Q248<
H`0236<248@00`aS12448@0212400`Q21248@P0824800`aS248@Q0025:D0
10aS1248@PQ20P@Q0PQ20PaS00<8@PaS36<00PaS00@@Q0aS36<<H`<48@@8
@P031248@P@Q00@48@0300048@@Q00X48@0336<@Q1BU00<DY@038@PaS3F]
00=24007?Nm:DTicCW=:DT8@?Nl00T8@0dHa00A:DTHaBU9:DP96<@924003
BU96<DYB0096<@09BU9>LdYBAS5244YBCW=:DTHa009:DP96<@9:DP03CW=:
DTYB00A>L`03DYA>Ldic009:DP03CW=:DTYB009>L`03DYA>Ldic009BU004
CW=:DTYBCW<3BU800e:DCW=>L`02CW<2DY@4CW<00dYBCW=>L`02BU8014Ha
BU9>Le:D0TYB00=244HaAS400dic00E:DTHaBU9:DTic00M:DP08AS5:DTic
DYA>Le:DCW=BU09>L`03BU9>LdYB00=>L`=BU004CW=:DTYBCW<2DY@2CW<0
1TYBCW=>LdYBAS5240A6<@924007AS5243W>>Li244YB@Q000Sg_00I:DTic
CW=BU4YBAS43BU8024icBU9:DTYBCW=BU4icDY@6CW<2BU801dicDYABU5:D
CW=BU4ic00=:DP=BU003E[EBU4ic00=>L`03DYA>Ldic009BU003CW=BU5:D
00=BU09>L`04DYAF]EJeCW<1?Nl00003124000@Q00848@0300048@@Q0084
8@0;000<HbU:DY@e[BU:=JdicS6<;F/aS002?Nl00d8@>LhicP03<H`03SF]
>Lhe[C6<=JdaS2e[<H`YBS6<=JdicSg_>Lh2<H`00be[<H`e[@04<H`2=Jd0
136<;F/]Jc6<0SF]0SW>00He[CW><H`]Jc6<:DX2;F/0236<?Nm6<DHa>LhY
BRe[:DX38@P39BT27>L248@436<424801@@Q24848@Q212400PQ210@Q00H8
@P@Q24848@Q2124324801@aS2488@PQ236<00PQ20`@Q00D8@P@Q248<H`Q2
008<H`<@Q08<H`04248<H`Q236<324800`aS5:D@Q00348@436<010Q236<<
H`aS0PQ200d@Q1cW6<H<HbDY?Nm_NgNmBU8mkbU:5:DLi`026<H011BU48@<
H`aS0P@Q10Q20`@Q2PQ200@<Ha245:D<H`<8@P0436<8@PQ2248212422482
48@01aS68@PQ22487>L@Q0aS00<8@P0336<@Q1BU008@Q0D<H`03248<H`Q2
00H<H`<@Q0035:D@Q12400@<H`88@P0536<@Q12436<8@P0336<3248248@0
11cW9BTU:AcW0Q2400<DYA2436<00`aS00<@Q0aS36<00`Q200<48@Q236<0
0a2400@8@PaS36<8@P8<H`0:5:D@Q1BU5:D<Ha2436<8@PaS248636<22480
11246<HDYABU0QcW00L@Q0Q212448@Q21248@P0336<00`@Q2488@P022482
48@010aS2488@PQ20`@Q00@8@PaS2488@P848@03248<H`Q20088@P0636<@
Q1BU48@<H`Q20P@Q1@Q20PaS00<8@PaS36<010aS00T8@P@Q1248@PaS2484
8@0024801@@Q00<000@Q12400`@Q00<000@Q12401@@Q00L<HaBU5:D@Q0aS
5:DQ2002=Jd3?Nl2@Q001DYBCW=:DT8@?Nl00THa00=244HaAS400TYB00=6
<DYBBU800d8@0TYB0dHa00=:DU:DBU800T8@0dYB0THa0TYB0THa00=:DTic
BU800TYB14ic00=BU4icBU801DYB14ic0e:D14YB00A>LdYBBU9:DP9>L`03
DYA>Le:D009>L`9:DP=>L`04BU96<DYBBU82DY@2BU801DHa@Q1:DTYBCW<0
0TYB0THa24YB00I6<DYBBU9BU4icDY@2CW<00e:DBU9:DP03CW<2BU8014ic
DYABU5:D0dYB00=>Le:DDY@00Tic00Q:DTicCW=:DTHa@Q16<DYB0THa00A2
43g_AS52408mk`03@Q16<D8@00=24007BU9>LdicCW=:DTHaBU800Tic14YB
00E>Le:DDYABU4ic009:DP05CW=:DTYBBU9>L`02DY@00dicDYA>L`02CW<0
1DYBCW=BU5:DE[D00U:D00Q>LdYBBU9BU4icDYA>Le:D0Tic15:D0dic0eJe
0Dic0CW>00001@0012448@@Q00000`@Q00X8@P001248@RU:E[DmkbU:<H`e
[@<aS003=JdicSF]008aS003;F/aS36<008e[@<icP03=JdaS36<00@]J`<i
cP06=JdaS36<<H`icSF]0be[00@e[C6<<H`]J`8aS003;F/aS36<00@e[@03
<H`]Jc6<008]J`04?Nm243g_>Lh3;F/29BT01B48:DXU:BDY7>L00aS600<@
Q0aS36<00PaS00D8@P@Q1248@P@Q00@8@P<48@0324848@@Q00<48@L8@P<<
H`88@P8<H`88@P8<H`03248<H`aS00<<H`03248<H`Q200D<H`0348@<H`aS
00<<H`8@Q08DY@8@Q088@P0536<DY@aS24848@0236<01`@Q:DY:DVLiF]HY
BR4800<HaP0348@<H`aS00@<H`P8@P041248@P@Q124224800`aS2488@P03
248010aS24848@Q20PaS00D8@P@Q1248@P@Q008<H`0548@DYAS66<HDY@02
7>L26<H336<00`Q236<@Q0025:D01aS67>LLiaS648@<H`Q200@@Q088@P8@
Q0045:D@Q0Q2248336<01`@Q24848@@Q248<Ha24008<H`06248<Ha2436<@
Q0aS0PQ20Q2400<DYA2436<00a240`Q20Q240QBU00@<Ha2448@@Q0D<H`07
48@<H`aS36<@Q0aS6<H00QcW00@HaQBU5:DHaP8@Q00836<@Q12448@<Ha24
36<8@P8@Q08Li`036<HDYA24008DY@0348@<H`aS00<<H`L8@P041248@P@Q
248412432482124224800`aS248<H`0536<01ABU6<HDYAS65:D00Q2410Q2
00H<H`Q236<<Ha2436<324800`@Q2488@P0312400`Q21248@P0612400`00
12448@09124011245:DDYA240QBU00@Q22e[;F/mk`A24009AS5:DT8@@Q0m
kd8@AS5:DTHa00E:DP=6<@A:DP96<@04@Q16<DYBCW<3BU8014HaBU9:DTYB
0dHa00=:DTicBU800TYB0THa00=:DTHaBU800dYB0THa00A:DTicDYABU0I>
L`M:DP04CW=BU4icDY@4CW<2BU84CW<01THaBU9:DU:DCW=6<@8mk`08AS5:
DTicCW=6<DYBCW=:DP96<@03BU9>LdYB00A:DP9>L`=BU003CW=:DTYB00=:
DP9>L`=BU003CW=:DTYB00ABU003E[E>Ldic009:DP07AS5:DTYB@Q16<Cg_
@Q000dHa00A243g_?Nm24096<@03@Q0mkd8@009:DP05AS5:DTHaBU9>L`04
AS42BU82DY@4CW<015:DBU9>LdYB14ic00ABU4icDYABU0=>L`9BU09>L`03
E[EBU4ic009:DP04DYA>Le:DE[D2DY@2CW<4DY@01TicDYABU5JeF]IBU04m
k`000`@Q00<000@Q12401@@Q00H8@RU:E[E242U:=Jd4<H`3=Jd2<H`01Be[
<H`e[C6<=Jd00SW>0SF]0S6<00PYBRe[;F/aS3W>?NlicSF]0S6<00@e[CW>
=JdaS08]J`03<H`]Jbe[00<aS08]J`8aS08e[@03<H`]Jbe[008]J`05<H`i
cSg_?NlicP02;F/00bDY8@PQ20029BT38@P011cW5:DDYA240PQ20PaS00D8
@P@Q1248@PaS00@8@P041248@PQ2248412400`Q21248@P05248536<22483
36<324800a2436<@Q002248336<2248736<248@01ABU48@@Q1BU48@00PQ2
00d@Q1BU48@8@P@Q48@<H`@Q;F]:DVLiF]HU:@027>L01ABU6<HDYA242480
0`aS1`Q200<48@Q224801@Q200<<H`Q224802PQ20P@Q0PQ20PaS00H@Q1S6
7>LHaQBU6<H27>L00aBU36<<H`0236<01a2436<DYA246<HLiaS6008DY@06
36<8@PaS48@DY@aS0PQ200H@Q1BU5:D@Q0aS248236<32482124436<22482
36<248@236<00`Q236<@Q00248@236<00a2436<<H`0336<448@236<348@3
36<00a2436<<H`0236<01A246<HQ21cW6<H00Q2400<HaQBU48@00`aS0a24
00H8@PaS48@@Q1S67>L26<H248@00aBU36<<H`0436<5248010aS2488@PQ2
0`@Q00@8@P@Q12448@@8@P041248@PQ2248636<25:D26<H011BU48@<H`aS
0PQ200<<H`Q236<00PaS00@@Q0aS2488@P<48@<8@P848@0624848@Q20004
8@0010@Q00@000@Q124000848@0500048@@Q248<H`035:D02Q245:DLibU:
<H`mkd8@BU9244Ha0TYB00A243g_@Q1:DPA6<@=:DP05CW=:DT8@@Q16<@02
BU800dHa@Q124002AS44BU84AS4014YBAS56<DHa0dic0TYB14Ha0dYB00I6
<DYBBU9:DTicDY@2CW<01DYBCW=BU5:DCW<00TYB00=6<DYBBU800TYB0Tic
00=BU4icCW<014YB00=>LdYBCW<00dYB00M6<DicDYA:DTHa>Lhmk`02BU80
14icBU96<DHa0TYB0THa00=:DTicCW<014YB00A>Le:DDYABU09>L`9:DP04
AS5:DTYBBU83DY@01TicBU96<DicDYAF]@ABU003CW=:DTHa009:DP96<@05
?NlicT8@AS5:DP02AS400cg_>Lhmk`02AS40148@?NlmkdHa0TYB0THa00A:
DTicBU9:DP924003BU9>Le:D009BU0I>L`A:DP03DYA>Le:D00=BU09>L`06
DYA>Le:DCW=F]E:D0Tic00=:DTicDY@015:D0Tic15:D00I>Le:DDYAF]E[F
DY@1>Lh0000300048@0000<48@0300048@@Q00848@07248]JeJe>LhQ22e[
=Jd00S6<00D]Jc6<<H`aS2e[00LaS005=JdicSF]<H`]J`02<H`2;F/2=Jd0
0d8@?Nle[@02=Jd00c6<=Jd]J`02;F/2=Jd00c6<;F/]J`03<H`2;F/3<H`5
;F/3>Lh013F];F/]JbU:0Re[00@YBRDY8@PQ208Li`036<HDY@aS00<@Q088
@P848@05248<Ha2436<8@P0212400`Q212448@051245248212400`Q236<@
Q00248@336<00a2436<<H`03248336<224800`aS2488@P05248436<02`Q2
48@DYBDY=Jd]JacW36<8@QBU48@01@Q200@HaQcW8@PQ20<DY@8HaP8@Q004
248<H`aS248336<324800`@Q24848@021242248236<00`Q236<8@P0236<5
24803@aS2488@PQ236<8@P@Q5:DU:BU:7>L<H`Q2008@Q00836<@Q12448@8
@PaS48@DY@<@Q0078@P]Jcg_JeYW>DYB<H`00PaS00<@Q0aS36<00`aS0Q24
0PaS20Q20PaS00D@Q0aS36<<H`Q200<<H`0624848@aS5:DHaQBU10aS1a24
0PaS00<@Q0aS48@010aS00L8@PaS48@@Q1BU36<Li`02;F/01bDY6<HU:BDY
7>L@Q0Q200D<H`0:48@<Hbe[>LiF]FmkE[DmkbDY48@26<H248@236<00a24
36<8@P0312400`Q236<8@P021240100012448@@Q0`Q200D<H`Q22488@PaS
00848@0848@LiaS636<8@PaS5:D@Q08<H`8@Q0<<H`@8@P<<H`0348@<H`Q2
00L48@0324848@@Q00@48@0300048@@Q00X48@04248<Ha245:D248@01ABU
6<H]Jc6<@Q000SW>00Dmkd8@AS56<DYB00E6<@A:DP03AS5:DTHa0096<@9:
DP03CW=6<D8@0096<@03@Q16<DYB009:DP924003AS5:DTYB0096<@05BU96
<DYBBU9>L`06BU83CW<3BU82CW<015:DCW=>Le:D0Tic1dYB1Dic00IBU4ic
BU9:DTHaBU83CW<3BU8014icDYA:DTHa0T8@0THa0TYB00A6<DYBBU96<@9:
DP06DYA>LdicBU96<Dic0dYB00=6<DYBBU800TYB00=6<DYBCW<00U:D0Tic
0U:D0THa00=244YBDY@01E:D00E:DTHa@Q1244YB00<mk`04@Q1:DTYB@Q02
>Lh01Sg_@Q16<DHa@Q0mk`924096<@06BU96<DHaBU96<Cg_0T8@14YB0Tic
0U:D00=>Le:DDY@00U:D0dYB00=>LeJeDY@01Dic00=BU4icDY@00e:D14YB
00=>Le:DDY@00TYB00=>Le:DDY@01U:D0E[F0Dic0CW>000512404@001244
8@Q200048@Q2:DYJeSg_8@P]Jc6<;F/aS3F]<H`012e[1S6<0SW>00@e[C6<
;F/]J`8aS007;F/e[Cg_?NlicS6<>Lh00SF]12e[00<e[C6<<H`00be[0S6<
00@]Jc6<<H`e[@8]J`05:DXaS2e[;F/e[@03>Lh2;F/01BU:;F/]JbU:9BT0
0R480QcW00<HaQBU48@010aS0PQ200<48@aS36<00PaS00D8@P@Q24848@Q2
00L48@<8@P848@04248<H`Q236<348@436<2248010@Q36<<H`aS0PQ20PaS
00<8@P@Q24801@Q20`aS00L8@Q2448@YBSF]:DXHaP0236<011S65:D<H`@Q
0`Q200PHaQcW8@PQ21BU48@DYAS60QBU00@<H`Q22488@P8<H`88@P0336<8
@P@Q00848@88@P031248@PQ20088@P0336<8@PaS008<H`88@P031248@PQ2
0088@P<<H`88@P0748@Q22DY7>L<H`Q236<011240`aS0Q240QBU00@@Q1S6
;F/mk`9[FP03BU8]J`Q2008@Q0P<H`T8@P8<H`8@Q08<H`0>248<H`aS36<8
@P@Q36<DYAcW5:D<H`Q248@<H`8@Q08DY@D@Q00436<@Q0aS48@536<03PQ2
36<@Q1248@PYBRe[8@PDYB48:DXHaPaS124536<04A2436<]JcW>E[E_NeJe
?NlQ21246<HDYA2436<8@PaS48@00PaS00<8@P@Q24800`Q21`@Q0PQ20PaS
1@Q200D@Q1BU5:D@Q0aS008@Q08<H`<@Q08<H`<8@P<<H`88@P0336<8@PQ2
00848@0324848@Q200/48@0300048@@Q00@48@0800048@0024848@Q248@H
aP8DY@0;48@HaRe[=Je243g_>LhmkdHa@Q16<@03BU82AS400d8@AS56<@02
BU8014HaBU96<D8@0THa00I:DTHaAS56<DYBAS42@Q02BU800dHa@Q124003
AS42BU82AS46BU82AS400dYBCW=BU002CW<2BU801TicDYABU4icBU9BU09>
L`A:DP06CW=:DTYBBU9>Le:D0Tic00=BU4icBU800THa0dic14YB0Tic0THa
00Dmkd8@BU9:DTHa009:DP=6<@06@Q1>LdicDYA>LdHa0TYB00=>LdYBBU80
14YB00A6<DYBBU9>L`=BU003BU9BU4ic0096<@03@Q1:DTic009BU008E[E>
Le:DBU96<D8@AS5240<mk`03AS5:DTYB0092408icP96<@05@Q0mkd8@?Nm2
4003AS43BU801Cg_>Lhmkd8@CW<00dYB0dic0U:D00=>Le:DDY@00Tic00=6
<DYBDY@00e:D0Tic00A:DU:DCW=>L`=BU003CW=:DTHa00I>L`03BU9>Ldic
00EBU004CW=F]EJeCW<1=Jd0000500048@001240000312402PQ212448@Q2
;F]F]D8@9BTaS3F]0S6<00@]Jc6<<H`]J`<aS003=JdaS2e[008]J`<e[@06
>Lhe[Be[;F/YBRe[0SF]0SW>00De[C6<<H`aS3F]008aS005;F/aS3F]=Jda
S002;F/0136<;F/]JbU:0S6<00D]JbU::DX]JbU:008]J`05<H`icSF]<H`]
J`05:DX01RDY8@PLiacW6<HDY@8<H`03248<H`aS00@<H`8@Q00336<8@PQ2
0088@P848@0324848@@Q00848@0336<8@PQ20088@P<48@04248@Q12448@2
36<01a245:DDYABU48@<H`Q200D<H`T8@PD<H`09248HaR48;F/icRDY48@8
@P@Q008<H`03248<H`aS00<<H`08248@Q1245:DLib486<H<H`88@P0336<8
@PaS008<H`0548@<H`aS24848@05248336<00`Q236<8@P0336<4248336<0
10Q236<<HaBU0QS600<DY@aS24800`Q20`aS00L8@QS6:DXaS2485:DHaP02
:DX01be[=JdaS5kgMkeF]CW>0088@P8<H`0348@<H`Q200X8@P0536<8@PaS
36<@Q0025:D00aS648@@Q00236<010Q236<<HaS611cW00<HaR488@P00QcW
00<HaQ2436<010aS0Q2400@<H`Q236<8@P8<H`0@248<H`aS8@PU:C6<>Lhe
[Cg_<H`HaPQ2124<Ha2436<248@02acW9BTYBRDY;F/aS4HaHaQNme:D>Lh0
0QBU00<<H`Q236<00PaS0`@Q0`Q210@Q00@000@Q1248@P8<H`03248<H`Q2
00D8@P<<H`88@P0336<8@PaS008<H`0448@<H`Q236<4248236<324841240
1@Q21248@P@Q24801`@Q00D000@Q00048@0000L48@03248@Q1BU008HaP05
5:DHaQcW;F/aS003>Lh2?Nl01D8@AS56<DHa@Q000THa00A:DTHaBU9240]6
<@=24004BU96<DYBAS42@Q000dHa@Q16<@02AS43@Q000dYBCW=:DP02AS47
BU83CW<2BU800dicDYABU004CW<3BU85CW<2BU82DY@00dicAS5:DP02BU80
0dicDYA>L`03CW<01dYBAS5:DTHa@Q0mkd8@00=:DP92409:DP03DYA>LdHa
00A:DP96<@9:DP924003?Nm244YB00=>L`96<@03BU9>Ldic00=:DP03CW=B
U4ic00ABU005CW=:DTHaAS5:DP02?Nl00cW>?Nm24002@Q02?Nl5@Q000cg_
AS524002@Q02AS402DYBAS5243g_@Q0mkdHaBU96<@02BU83CW<00e:DCW=B
U002CW<4BU82CW<2BU82DY@00dicBU9:DP02CW<00e:DCW=:DP02BU8014ic
DYABU5:D0Tic00=:DTicDY@00U:D0Tic00ABU4icDYA:DP4e[@002P@Q00P0
00aS:DYBU3g_9BTaS3F]0S6<00<]Jc6<;F/00c6<00<e[C6<;F/00Re[00<a
S3F]>Lh00SF]00<aS2e[;F/00Re[0SF]0SW>0SF]00@aS3F]=JdaS0<]J`07
<H`e[C6<;F/YBRe[<H`00Re[0S6<00<]JbU::DX012e[00DaS3F]>LhaS2e[
008U:@8YBP8U:@057>LQ21cW5:D@Q00636<00a2436<@Q00436<00`Q236<4
8@0512400`Q21248@P05248010@Q2488@PaS0Q240PaS0Q2400LHaQBU48@<
H`Q236<@Q00236<:248336<01A2436<<HaS68@P00S6<00<Q21BU36<00PQ2
00D<H`Q2248<Ha2400@<H`0748@HaR487>L@Q0aS124010Q210aS0PQ200<4
8@Q212400`Q20PaS0PQ210aS1PQ21@aS00@DYAcW6<H@Q088@P0336<8@PQ2
00<<H`07248LibU:;F/U:ABU6<H00RU:0S6<00De[F<HLiaF]CW>0088@P06
36<8@Q2436<8@PaS1`Q20PaS0PQ20PaS00L@Q1BU5:DDYA2436<@Q0022480
1@aS48@HaQS67>L00QS60QcW00/Q21cW6<HHaPaS48@8@PaS48@<Ha24008<
H`88@PH<H`8U:@09=JdicSF]>Lh]JaBU36<48@aS00@@Q00;7>LQ22U::DX]
JcW>AS5S65kgCW<aS00248@224801`aS248<H`Q21248@P@Q00<8@PD48@88
@P0336<@Q0aS008<H`03248<H`Q200H8@P8<H`88@P0636<@Q12436<8@P@Q
0`Q20`aS0PQ220@Q00<8@P@Q124030@Q00<000@Q12400P@Q00H8@P@Q48@H
aQcW6<H25:D02B48;F/aS3W>=JdicSg_@Q16<@04@Q03AS400dYBAS56<@02
@Q02AS43@Q000dHaBU9:DP04@Q000dYBAS56<@04AS40148@AS56<DHa0T8@
0THa00=:DTicAS400THa0TYB0Tic0THa00I>Le:DCW=:DTHaCW<2DY@3CW<4
BU83CW<00e:DCW=:DP02CW<015:DBU96<DHa0TYB00M>LdYBCW=>Le:DBU9>
L`03AS400d8@AS56<@02BU8014Ha?Nm244Ha0dic00=:DTHaBU800dYB0dHa
00M243g_@Q1244HaBU9>L`0:BU800dicDYABU003DY@00dicAS524002AS40
1D8@?NlicSg_@Q000Sg_0T8@00@mkd8@@Q16<@8icP03?Nm6<DHa00924003
AS5:DTHa00924005?Nm244Ha@Q16<@02BU84CW<2DY@2CW<00dYBAS5:DP02
CW<2BU801TicDYA>LdicBU96<@9>L`9BU004AS5:DTYBBU82DY@2CW<014YB
CW=>Ldic0e:D1Dic0CF]00001`00124000@Q00048@0000@48@05248]Jekg
@Q0YBP02>Lh4<H`013F]<H`aS2e[0S6<00@e[C6<:DX]J`8aS004=Jd]JbU:
;F/3<H`012e[<H`e[CF]0SW>1C6<0Re[0c6<0RU:00DaS2e[;F/]Jc6<008e
[@05;F/YBRU::DX]J`02=Jd2>Lh01CF]<H`YBRDY8@P00RDY0R480acW00<H
aPaS36<00P@Q00L<H`Q248@@Q0aS48@DY@0248@00`aS2488@P0524800`@Q
2488@P0224800`@Q24848@0324800`aS48@@Q00348@01AcW:DX]Jb485:D0
0PaS0Q240PaS00@48@Q22488@P848@03248<H`Q200@<H`0448@<HaBU5:D3
7>L012487>LHaQ240PQ200@<Ha245:DDY@88@P0336<8@PaS00D@Q00336<8
@PQ2008<H`035:D@Q12400<@Q00336<8@PQ20088@P<@Q00336<8@PaS00D<
H`0324848@Q200<8@P0436<@Q1BU5:D248@00`aS2488@P0224803`aS48@<
H`aS48@DYBDY:DXe[DHaBU9F]DYB>LhaS002;F/013g_@Q0YBQBU0PQ200@@
Q0aS24848@T8@P0536<8@PQ236<DY@0348@25:D04A245:DDYABU6<HDYAS6
48@<HaBU7>LYBS6<:DXQ21S648@00PaS00@8@PaS36<8@P8<H`0324848@Q2
00<8@P0636<@Q1BU6<HU:Be[0RU:00@Lia2448@<H`<@Q0046<HDYBe[<H`2
@Q02>Lh023F]:DXU:E:DIcU>LbU:1242248212400`Q21248@P0224800`@Q
2488@P0412402PQ236<8@P@Q36<DYAcW48@8@P@Q0`Q20P@Q1@Q210aS00H4
8@Q22488@Q2436<5248812400`Q212448@0>124010001248@PaS0aS600P@
Q1BU8@PYBS6<;F/e[Cg_0T8@00<mkd8@@Q000cg_00]244Ha@Q1:DTicAS4m
kcW>@Q1:DTHa00924096<@06BU96<D8@?Nm244Ha0dYB0THa148@00=6<D8@
?Nl00THa0TYB00I6<DYBBU9:DTicBU82AS401dYBAS5:DTYBAS5:DTic00AB
U008CW=:DTYBBU9>LdYBCW=BU09>L`05BU9>Le:DCW=:DP02AS48CW<2BU80
1DicAS4mkcg_@Q000dHa0T8@00E6<DYBBU96<D8@0096<@03BU96<D8@0092
4096<@=2400<BU9>LdicCW=6<DicBU96<D8@>Li244Ha0TYB0Tic0e:D00=>
Le:DBU800THa0dYB00=6<Cg_?Nl00T8@00U:DTHa@Q0mkcW>?Nm243g_@Q00
0Sg_00A244Ha@Q0mk`92409:DP=6<@9:DP04CW=:DU:DDY@2CW<00dHaBU9:
DP03BU801TicBU9:DTYBCW=BU0=>L`04BU9>LdicDY@6CW<2DY@3CW<2DY@3
CW<014YBCW=F]E:D0D8@0008124020Q200048@Q2:DYJeT8@;F/2=Jd00be[
<H`aS003=Jd00c6<:DX]J`02<H`2;F/012U:;F/e[C6<0Re[00<YBS6<<H`0
1C6<00<e[C6<=Jd0136<00<YBRe[;F/00S6<00H]JbU:;F/aS2e[<H`3=Jd0
1be[9BTYBRU:;F/e[C6<008e[@03<H`]JbDY00@U:@<Li`038@PHaQBU008<
H`<8@P8<H`P@Q00324848@@Q00D8@P8<H`88@P848@<8@P@<H`035:D@Q1BU
008U:@038@PDY@aS008<H`0748@<H`Q224848@Q212400PQ200<<H`Q22480
1@aS00@@Q1BU5:DHaP<Li`036<HDYA240088@P0436<@Q12448@2248436<0
0a245:D@Q00236<2248236<01A245:D@Q1BU48@00PaS0`Q200D<Ha2436<<
H`Q2008<H`8@Q00536<8@PQ2248<H`0224800`aS248@Q00348@236<01Q24
36<8@PQ2124<H`8@Q08<H`0D5:DYBRU:>Li6<DicDYA6<CF]<H`]Jc6<>Li2
42486<H48@Q248@<H`D8@P0436<8@PaS36<4248236<248@35:D448@46<H0
2ABU36<@Q1cW:DXe[BU:7>LHaP0836<324801P@Q2488@P@Q36<@Q08HaP06
8@PYBRe[:DXHaQ240PaS00TDYA2448@DYAS6<H`e[Cg_@Q000cF]00TU:BU:
DYAW>DYB8@P48@Q236<00`@Q00P8@P@Q1248@PaS24848@000`@Q10Q200H<
HaBU6<HDY@Q2124224800`@Q24848@0224801@aS248<H`aS48@00PaS0`Q2
00<<H`Q224800`aS00<8@P@Q12400P@Q0PQ20`@Q0PQ20P@Q00<000@Q1240
1@@Q00<000@Q12400`@Q00D000Q236<DYAcW00<HaP0;7>LU:Be[;F/icSg_
@Q0mkcW>?Nm24003?Nl00d8@AS524002BU801D8@?NlicT8@BU800T8@00@m
kdHaBU96<@924003?Nm244Ha00=:DP96<@Q24096<@I:DPA6<@9:DP96<@06
BU9>Le:DDYA>Le:D0Tic00=:DTHaCW<00dic00ABU4icCW=:DP9>L`05BU96
<DYBBU9>L`03BU8015:DCW=>Ldic0TYB00A6<D8@?Nlmk`96<@03@Q0mkd8@
0096<@03BU96<DHa00A6<@924004?Nm6<D8@AS42@Q02BU8014icBU9:DTYB
0THa0Sg_0dHa0TYB00ABU4icDYABU09>L`=:DP=6<@03@Q0mkcg_00924004
AS5:DT8@?Nl2>Lh2?Nl00d8@>LhicP02@Q0014Ha@Q0mkd8@1dHa00A:DTic
CW=BU09>L`03AS5:DTYB00I:DP9>L`9BU0=>L`04BU9>LdicDY@2CW<2BU83
DY@00dicBU9>L`03DY@01TicBU9:DTicE[EBU04mk`0000P000@Q00048@00
124000Q20P@Q00H000Q2:DYF]Cg_;F/3=Jd00c6<=Jde[@03;F/2<H`4;F/4
<H`3:DX5;F/01C6<=JdicSW><H`00Re[00DaS3F]=Jd]JbU:008]J`8aS003
;F/YBRU:008]J`<aS004;F/YBRDY:DX2;F/01S6<=Jd]Jbe[9BTQ208U:@04
:DXU:B488@P27>L01ABU36<<H`Q212400PQ20`aS112400DDYA2436<8@P@Q
00@8@P8<H`0324848@@Q0088@P06124<Ha245:D@Q0aS0Q2400TDYAS68@PU
:Be[:DXQ21cW48@010aS00<8@P@Q24800`Q20PaS0Q240`Q200`<HaBU5:DD
YA245:D@Q1cW<H`mkcF]8@P436<01ABU6<HHaQS65:D00QS600@DYA245:DD
Y@8@Q004248<H`aS36<248@236<02A242488@PaS48@HaQcW6<H@Q00336<0
0a2436<<H`04248010@Q36<@Q1240PaS0QBU00<<H`Q224800`Q20`aS0108
@QS66<I244icHaQg_FmkMke[FUJeBU8e[C6<9BTHaP8@Q00536<8@P@Q1248
@P0412400`Q21248@P0324800`@Q248<H`0236<248@00aBU6<HHaP025:D2
48@00aBU48@DY@0348@010aS48@@Q1BU112400<DY@aS36<00PaS0`@Q00D8
@P@Q12448@Q2008DY@8Li`8HaP055:D@Q1245:DLi`0248@020aS48@U:Be[
DYANmfLiJeX2G_L00e:D>LhaS0029BT0136<>LhLia240P@Q00<8@P@Q1240
0P@Q00<8@P@Q24800PQ20P@Q1`Q200<<H`Q2248010aS0PQ20`aS0PQ20`aS
00<48@Q224800PQ20PaS0PQ22@@Q0PQ200<48@Q2124010@Q00<000@Q1240
2@@Q00l8@Q246<HHaQBU48@HaR48;F/icS6<>LhmkdHa@Q000Sg_0SW>00<e
[Cg_@Q000THa00A244Ha@Q124096<@04@Q0mkcg_@Q06AS42@Q000dHaBU9:
DP02AS400d8@?Nm24003AS401Cg_>LhmkdYBAS400Tic0TYB0dic0TYB0T8@
00E6<DYBBU9:DTic00=BU0=>L`I:DP04DYA>Le:DDY@3BU801THaCW=:DTic
DYA>L`I:DP05?Nle[CW>?Nm:DP02AS44?Nl01T8@AS4mkcg_>Lhmk`=24003
AS5244Ha0096<@0;@Q16<DYBCW=:DTHaCW=:DT8@?Nm24002AS42@Q000dHa
CW=:DP02BU82CW<01dYBAS56<DHaCW=:DTic00I:DP09AS52448@@Q0mkcF]
<H`e[Cg_00=24005AS5244Ha@Q0mk`02@Q03BU8014HaBU9:DTYB0dic0TYB
0dic0TYB00=>LdYBBU800Tic00=BU4icBU800Tic00EBU4icDYA>LdYB009>
L`03DYA>Ldic00ABU09>L`=BU05F]@5BU05240002`@Q00X<HbU:E[DmkbU:
<H`icSF]<H`e[@<aS005:DX]Jbe[;F/aS003;F/0136<=JdaS2e[0RU:00@a
S2e[;F/]J`<aS003=JdicSF]008]J`06<H`e[Be[;F/U:BU:12e[00@YBRDY
:DXYBP<aS003;F/YBRU:00<]J`<aS004;F/U:B488@P39BT28@P27>L01QS6
36<8@P@Q248<H`88@P0436<@Q0aS36<448@00`aS24848@0224801@@Q248<
H`aS24800`@Q00H8@P@Q36<DYAS65:D236<01ABU48@Lib489BT00Re[00@L
iaS648@@Q08<H`0324848@Q200@8@P0436<@Q12448@2248236<25:D03a24
5:DHaQ245:DaS3g_=JdQ20Q236<@Q0aS48@DY@036<H01aBU6<HHaQBU48@<
Ha24008<H`03248<H`aS008@Q0<<H`88@P8<H`046<HLiaBU48@236<348@2
36<01`Q236<8@P@Q36<@Q1BU008<H`<@Q00336<8@PQ200D8@P0C36<HaQS6
?Nm>Lf<HNmi_NgNmJeYBU4YB=JdaS1cW6<H@Q1BU36<00PQ200@48@Q21244
8@P8@P0436<8@PQ2248236<011246<HDYAS60a2400DDYA245:DDYA24008<
H`0448@HaQBU5:D348@00aBU48@<H`05248020@Q24848@@Q248<HaBU48@2
6<H04ABU6<HDYA2436<DYAS65:D@Q0aS48@YBRe[E[EJeVLiKg/00Ukg00=>
LcW><H`00RDY0S6<00DLia2412448@Q200<48@0324848@Q200<48@88@P03
1248@PQ200@8@P0436<8@PQ2248236<6248436<010Q236<8@P@Q0PQ20PaS
10Q21@@Q0PQ20P@Q0PQ22@@Q00<000@Q00000P@Q010000@Q1248@Q246<HL
iaBU48@DYAcW;F/icSF]>Lhmk`9240DicP05?Nm2448@@Q16<@04@Q000dHa
@Q0mk`02@Q000dYBAS56<@02AS42@Q000dHaBU96<@03AS42@Q000cg_@Q1:
DP02@Q000cg_@Q16<@04BU800dicBU9:DP02BU801DHa@Q1244HaBU800Tic
00E:DU:DDYABU4ic00=:DP9>L`=:DP=>L`03DYA>LdYB0096<@03BU9>Ldic
009>L`04BU96<DYBCW<2BU8013g_>LhicSg_0THa00M243g_?Nlmkd8@AS52
4003?Nl00cW>@Q124004@Q0024Ha@Q12448@BU9>LdYBAS42BU82@Q0013g_
AS56<D8@0THa0dYB00A>LdYBCW=:DP96<@9:DP03CW=:DTHa009:DP03CW=:
DTYB009240<mk`06=JdaS3F]?Nm6<Cg_0T8@0THa0cg_00=244YBBU800TYB
00I6<DYBBU9:DTicBU84CW<3BU801DicBU9:DTicDY@00Tic00A:DTicCW=B
U0=>L`=:DP04CW=BU5:DCW<3DY@00dicDYABU002CW<2E[D1@Q0000050004
8@0012400003124020Q200048@Q2;F]BU3W>9BT2=Jd3;F/00cF]<H`aS002
=Jd2<H`01Be[<H`aS36<;F/00S6<0Re[00<aS2e[;F/00be[00<aS2U:<H`0
0cF]0c6<0SF]00<]JbU::DX00S6<00<YBRDY9BT00be[00DaS2e[<H`]JbU:
008]J`05:DX]Jbe[;F/YBP079BT022487>LHaQS648@<H`Q236<4248336<3
5:D00`aS2488@P0224801@@Q24848@@Q24800PaS0PQ200@48@Q248@<H`<D
Y@8<H`04248DYA246<H27>L01D8@BU8icRU:36<00Q2400L<H`Q21248@P@Q
36<DY@027>L00aBU36<8@P02124236<00a2436<<H`045:D02R48:DXQ21S6
48@DYBDY<H`YBQcW0Q240QS60aBU0Q2400@<Ha2436<<H`88@P0336<8@PQ2
0088@P8<H`045:D@Q12448@736<010Q236<8@PaS0PQ200@@Q1BU5:DDY@8@
Q00936<8@PQ248@HaQBU36<48@Q2008HaP05BU9JeW>LMke[FP02Mkd01G_N
Kg/mkbU:24800PaS0PQ220@Q0PQ20P@Q00@8@PaS36<<H`88@P<<H`0;5:DH
aQBU5:D@Q0aS48@<Ha245:D@Q00236<00`Q236<DY@0248@236<00`Q248@D
Y@0236<212400`Q212448@0424804aBU6<HQ22486<HDY@aS248<Ha246<H@
Q0aS248DYCF]?Nm_Ng>L009g_@08LiakgVmkE[DmkaS65:D@Q08DY@032484
8@@Q01448@<8@P031248@PQ200<@Q00336<@Q12400<@Q00436<@Q0aS36<3
24800`@Q248<H`0336<32483124010Q21248@PQ21`@Q00@000@Q124000T4
8@0448@DYABU6<H25:D00aS69BT]J`02>Lh00cF]>LhicP03@Q02>Lh2?Nl0
0d8@AS56<@02@Q02AS40148@?Nlmkd8@0THa00=244HaAS400THa00M243g_
@Q16<DicBU924002AS4013g_@Q0mkdHa0cg_00A244icBU9>L`=:DP=>L`06
@Q0mkcg_@Q1:DTic0TYB00I>Le:DE[E>LdYBCW<2DY@01TicBU96<D8@AS5:
DP9>L`04BU96<DicCW<3BU801TicDYABU5:DBU96<@9:DP04AS4mkcW>?Nl2
@Q0014Ha@Q12448@14Ha00DmkcW>>LhicTHa009:DP924004BU9>LdicAS42
?Nl01DHaCW=>LdYB@Q000THa00=:DTHa@Q001D8@0THa00E>LdYBAS5244Ha
00A:DP96<@04BU9>LdYBBU83@Q02?Nl013F]>LhicSg_14Ha0T8@00Pmkd8@
AS56<DYBAS5:DTHa0dYB0dic0dYB0dic0U:D0dYB0U:D0dic00ABU4icDYAB
U09>L`07BU9>Le:DDYA>Le:DE[D01e:D0EJe0E:D0Cg_000;12401@Q2:DYB
U3W>9BT00S6<0Re[0S6<00<e[C6<<H`00S6<0be[0S6<1Re[00@aS2U::DXY
BP8aS08]J`03<H`e[C6<008]J`06<H`e[C6<;F/YBRe[0S6<00<YBRDY9BT0
12e[00<aS2e[:DX012U:0Re[00<YBRe[9BT00R4800DU:BU::DXQ21cW00<H
aP8@Q0<8@P031248@PaS00<<H`0:5:DHaQBU48@8@P@Q24848@Q212432483
36<2248336<348@336<031245:DLiacW8@PmkdYB?NlYBPQ236<@Q0@8@P03
1248@QS6008Li`056<H8@PQ21248@P0336<00a2436<<H`035:D03BDY:DXQ
21BU48@DYBDY;F/U:AcW48@DYAS6008DY@8@Q0<<H`0348@<H`aS00P8@P05
36<@Q1BU5:D@Q00236<00a2436<<H`0336<00`Q236<8@P0236<248@25:D3
48@020@Q248<HaBU48@<H`@Q24827>L034HaF]IcW7_NKg]g_G_NMkeW>CW>
:DX@Q08<H`<8@P848@0700048@@Q24848@Q2124010Q200P<H`Q22488@Q24
36<@Q1BU0QS600@DYA2448@<H`<@Q0@<H`@@Q0<<H`<@Q088@P<48@052484
8@Q2248<H`025:D01248:DXHaQBU0PQ200@<HaBU48@@Q08<H`0B5:De[Cg_
JeYg_G>LNmicW7_NKg]JeT8@6<H@Q0aS5:D@Q0aS2@@Q00<8@P@Q12400P@Q
0PQ20`@Q0PQ20`@Q00@<Ha2448@@Q08<H`<@Q0<<H`0348@<H`Q200848@88
@P8@Q08<H`0324848@@Q0088@P<48@0624848@@Q24848@Q21`@Q00<000@Q
12401P@Q00@<Ha246<HHaP8DY@046<HQ22e[>Lh3=Jd02Sg_@Q12448@?Nli
cSg_>Lhmkd8@0THa00=243g_@Q000T8@00@mkd8@@Q1240E6<@03@Q0mkd8@
009:DPA6<@05@Q0mkd8@@Q0icP02?Nl00d8@BU9:DP04BU800dicDYA>L`02
@Q001cW>@Q16<DYBCW=:DTic009BU006CW=:DTYBCW=BU4ic0THa0T8@0TYB
00=>LdYBBU800Tic00M:DTHaBU9:DU:DE[E>L`04BU8024Ha?Nlmkcg_@Q16
<D8@?Nl2@Q001DHa@Q0mkd8@?Nl00cW>00=244HaAS400T8@00A6<DicBU92
408mk`A:DP9240=6<@04@Q0mkd8@@Q03AS43BU82AS400dYBAS5:DP02BU82
AS4014YBCW=>LdYB0d8@00<mkcW>=Jd00SF]00TmkdHaAS5:DTHa?Nm243g_
@Q001dHa00E:DTHaBU9>LdYB009>L`A:DP=>L`07BU9>LdicDYA>LdYBCW<0
0U:D0Tic00ABU4YBBU9:DP9BU003CW=BU5Je009BU003CW=BU5Je00ABU052
400000@48@00124000848@0=00048@@Q124000aS;F]F]CW>7>L]JcF];F/0
0RU:00X]Jc6<<H`e[C6<:DX]JbU:;F/aS08e[@<aS003=Jd]Jbe[008aS004
;F/YBRU::DX2<H`2=Jd01C6<=JdaS2e[<H`00Re[00<YBRe[;F/00RU:00@]
Jc6<<H`aS08]J`05<H`e[Be[9BTYBP02<H`012e[9BTYBRe[0RU:12DY11cW
00<DYA2436<010aS00@8@PaS248<H`8@Q00436<8@PQ236<224800`@Q2488
@P03248010aS1248@PaS0Q2400<<H`Q236<010aS00<DYAS69BT00R4800XY
BS6<F]IS65[FE[DLiaS636<48@88@P0736<HaQS66<H@Q0@Q24800P@Q00D8
@PaS2488@PaS0088@P0536<@Q1BU6<HDY@0248@011BU8@PQ21cW0aBU00<H
aQBU36<00PQ20`aS00H8@Q246<HDYA242482124010aS48@@Q0aS0PQ20P@Q
00D8@PaS48@<H`Q2008<H`H8@P0448@HaQS66<H436<01`Q236<<H`Q236<8
@PaS008DY@06=Je246<HKg][FW_N0W>L00AS62e[8@P8@P8<H`0=24848@Q2
24848@Q21248@P@Q24848@Q212401@Q20`aS0a240QBU00@@Q0aS48@@Q08<
H`<@Q08<H`D@Q00336<8@PaS00<<H`848@88@P848@88@P0736<@Q1BU7>LQ
21S648@00PQ20PaS00L@Q0aS36<<Ha24;F/e[@02JeX02FmkMke_NgooNmiN
mcW>5:D@Q00324800`@Q24848@0712400`001248@P0512400`Q212448@06
248010aS248@Q1240QBU0QS600DQ22DY8@PQ21BU0088@P0;1248@PaS248@
Q1BU48@<H`Q21248@P04124010Q212448@Q21P@Q00<000@Q12401P@Q0PQ2
00lHaQBU6<HLiaS648@HaRDY<H`mkcW>=JdicSg_@Q000THa00Q243g_?Nle
[Cg_@Q16<DYB0dHa00E243g_@Q1244Ha00924003AS5>LdYB00=24004AS52
44HaAS42BU82@Q0013g_>Lhmkcg_0T8@0Sg_0TYB0THa00E:DTicCW=:DTHa
00=2409:DP06CW=BU4icCW=:DTic0U:D0dic00A6<D8@@Q16<@A:DP06CW=:
DTYBBU96<DYB0Tic1DYB0THa00=243g_@Q000Sg_00A6<DYBAS4mk`924006
AS5243W>>Lhmkd8@0THa00E:DT8@@Q1244Ha009:DP05@Q0icSg_AS5>L`03
AS42CW<00dYB@Q124002>Lh013g_@Q12448@0THa00A:DTicBU9:DP96<@03
BU96<D8@00=:DP96<@05BU96<D8@>Lhmk`03@Q0014HaBU96<DYB0Sg_00A2
44HaCW=:DP=6<@A:DP05AS5:DTYBCW=:DP04CW<4BU801DicDYABU5:DCW<0
25:D00I>LdYBCW=BU5JeF]H3DY@01UJeF]IBU5:DE[EBU04mk`0000<000@Q
12400P@Q00@000@Q1248@P848@06248YBU:D>LhQ22e[0S6<0RU:0Re[00@a
S3F]=Jd]J`8YBP07;F/aS36<<H`]Jc6<=Jd00S6<1Be[00<YBRe[<H`00S6<
00<]Jc6<<H`00S6<12e[00DaS2U:9BTYBRe[00<aS08]J`8aS003;F/YBRU:
008aS005;F/U:BU::DX]J`039BT00b489BTQ20027>L02B485:D<H`@Q36<@
Q0aS248<H`0224801PaS48@DYA2424848@/8@P8<H`8@Q00536<8@PaS36<8
@P0236<03QBU7>LQ21cW8@P]Jc6<G_MW>EJeBU8LiaBU36<4248011BU6<HH
aQ2410Q200<<H`Q224800`Q20`aS014DYAS648@@Q0aS5:DQ22DY7>LDYA24
5:DHaQBU48@8@PaS0088@P8<H`<DY@0848@<H`@Q248<H`Q248@<H`88@P84
8@05248<H`aS248<H`04248010@Q248<H`Q20QBU00@HaQBU48@<H`<8@P<<
H`03248<H`aS008HaP0;>Li:DV<HKg][FWooMke_Ne[F;F/Q200248@010aS
2488@PQ20P@Q00<8@P@Q12400`Q20P@Q1@Q20PaS00D@Q0aS36<DYAS6008D
Y@0336<@Q0aS00<<H`0348@<H`aS008@Q0035:D@Q0aS0088@P8<H`0448@<
H`Q2124224800`@Q2488@P0324801PaS48@LibDY5:D@Q088@P0448@<H`aS
248348@00c6<?NmW>@02Kg/01gNmLiaoog_NF]HicQ2400D8@PL48@030004
8@@Q00H48@0624848@@Q1248@PaS0`Q20`aS00<@Q1BU5:D00QBU00HLib48
:DXU:AcW5:D3248236<01@Q248@DYABU48@01@Q21@@Q0PQ22@@Q00@000@Q
124000848@0536<DYAS65:DHaP025:D011S68@PaS3W>0cF]00@mkd8@AS56
<@92408mk`03>Li2448@0096<@03@Q16<D8@008mk`06@Q16<D8@@Q1:DTic
0THa00Hmkd8@@Q1244HaBU83AS400d8@>LhicP03?Nl013W>?Nm6<DHa1DYB
00E>LdYBAS56<Cg_00924003BU9BU5:D00=>L`06BU9>LdicCW=BU4YB0d8@
00=6<DYBBU800dYB0Tic0THa0TYB00Q>LdYBBU9:DTHaBU9244Ha0T8@0Sg_
00=244HaBU800T8@00Hmkd8@@Q1243g_>Lh2?Nl01THaBU96<D8@?Nm240=:
DP8icP06?Nm244icAS5244Ha0dYB00A243g_>LhicP8mk`=24005AS5:DTYB
AS5:DP03AS400d8@AS56<@02BU800dHa@Q1:DP02AS4013g_@Q12448@1DHa
0Sg_0T8@0TYB0dHa0dYB00A6<DYBAS5>L`9:DPA>L`A:DP=BU09>L`9BU003
CW=BU5:D00=BU09:DP03CW=BU5Je009F]@9BU09F]@ABU05240000P@Q00<0
00@Q12401P@Q00H<Hbe[F]Hmkb48;F/3<H`2:DX01Be[<H`e[CF];F/00RU:
00DaS3W>=Jde[CW>00LaS08YBP05;F/aS3F]<H`]J`02<H`00be[<H`]J`02
<H`013F]<H`YBRU:0Re[0RU:12e[00<aS3F]>Lh00SF]00HaS2e[;F/]JbU:
;F/2:DX00bDY8@PQ20028@P01AcW8@PLiaS648@00PaS112400<<H`Q22480
0`aS2`Q200H<HaBU48@DYA24248336<04Q2436<@Q1BU8@P]Jc6<=Jd]Jc6<
>Lhe[C6<@Q1>LdHa=JdDY@8<H`04248<H`aS48@236<324821247248436<0
0`Q236<8@P0248@011BU48@@Q1240QBU00<@Q0Q224800P@Q00H8@P@Q36<D
YAS65:D3248010aS48@<H`Q210@Q0`Q200<<H`Q224800P@Q00<8@P@Q1240
0PQ20Q2400@DYAS648@<H`88@P8<H`0B48@8@PQ248@HaQcW5:DLibU:DYAJ
eU:DHaQJeT8@;F/DYAS60Q240PaS00@8@P@Q2488@P@48@0324848@@Q0088
@P0336<8@PQ200D<H`@@Q00336<@Q12400@<H`8@Q0<DY@0548@<H`aS36<@
Q00336<00a2436<<H`0424800`aS2488@P02248020@Q48@DYABU36<48@aS
48@436<03a245:DQ22DYAS5>LfLiJeYNmfmkE[DicRDY48@DY@0424871240
0`Q21248@P0812400`Q236<48@021245248248@00b48:DXQ200248@021cW
;F/aS2DY5:D<H`@Q248536<4248212400`Q212448@0B12400`Q236<Li`04
7>L01AS67>LYBS6<>Lh00SF]00TicT8@?Nm:DTicBU96<CW>=Jd00Sg_00A2
44HaBU96<@9240=6<@04@Q0mkd8@AS42BU800d8@AS56<@03@Q001Cg_AS56
<DHa@Q000Sg_00E244Ha@Q1243g_0092409:DP96<@9:DP9BU003CW=6<DHa
008mk`08AS5:DU:DDYA:DU:DCW=:DP96<@07BU96<D8@@Q16<DicBU800dic
1TYB14Ha0TYB0Tic0TYB00=6<D8@@Q000Sg_0d8@00<mkd8@AS400T8@00<m
kd8@AS400THa00E244Ha?Nlmkd8@0096<@8mk`05@Q16<DHa@Q16<@02BU83
@Q02=Jd00cW>@Q1:DP03@Q001DYBCW=:DT8@?Nl00T8@0dYB0THa00E:DTHa
AS56<D8@0096<@9:DP03AS5244Ha0096<@05BU96<DYBBU96<@03BU82AS43
BU800dHaBU9:DP04CW<01U:DBU9:DTHaBU9>L`MBU005E[EBU5:DDYAF]@06
DY@2CW<4DY@2CW<1DY@1BU81?Nl0000@00048@@Q124000@Q00048@Q20004
8@Q2;F]F]CW>8@P3<H`3:DX02be[<H`e[C6<:DXU:Be[<H`mkcF];F/00SF]
0S6<00H]Jc6<<H`aS2e[:DX2;F/013F]<H`aS36<12e[0c6<0be[00@YBRe[
:DXYBP@]J`8aS004>Lhe[C6<<H`2;F/2:DX2;F/01RU:9BTQ21cW8@PLi`<Q
20055:D@Q0aS36<@Q00336<0112436<<H`Q20`aS0PQ200D48@Q236<8@PaS
0088@P8<H`8DY@8@Q003248<H`aS008<H`8@Q0045:DLibU:;F/2<H`03Be[
=Jde[Be[?Nm>Ld8@=Jd@Q0Q236<8@PaS008@Q00336<8@PQ200@8@P031248
@P@Q00D8@P@<H`88@P8@Q0035:D@Q0aS00<DY@0336<8@P@Q00@8@P0636<D
YABU48@<H`@Q0PQ200<@Q0aS248010@Q0PQ20PaS0PQ20P@Q0PQ200@48@Q2
248@Q08DY@056<H@Q0Q236<8@P0236<0412436<8@Q247>LU:ABU7>L]Je:D
F]IF]F<HE[DmkbU:0QS600@DY@aS36<<H`<8@P@48@0624848@Q2248<Ha24
0PQ200<48@Q236<00PaS00<@Q1BU48@00Q2400<<Ha2436<010aS00<DYA24
48@00QBU00<@Q0aS36<00Q2400<<H`Q248@00PaS00<8@P@Q12400`Q200<<
H`Q212400PQ200@@Q1S65:D<H`88@P8@Q08<H`8@Q0055:DQ22DYBU9>L`02
IcT01f<HJeYF]Cg_9BT@Q0aS00D8@PD48@0324848@Q200848@88@P@48@04
24848@@Q1247248248@00acW9BTLi`025:D02AcW;F/e[BDY48@8@P@Q248@
Q00236<324800`aS2488@P0312400`Q212448@03248412400`0012400003
12401P00124000@Q248<H`8Q20<Li`046<HLibDY<H`3=Jd01CW>?Nm244Ha
CW<00TYB00HmkcW>>Lhmkd8@AS45@Q0034YBAS5243g_@Q1:DTicBU9243g_
@Q16<@924005?Nm244YB@Q0mk`02>Lh3AS42?Nl2@Q04AS42BU800dicDYA>
L`02AS4013g_@Q16<DYB0U:D0Tic0dYB00=6<DYBAS400d8@0TYB00E>Le:D
BU9>LdHa00A:DP96<@03@Q1:DTYB009:DP04CW=:DTic@Q02?Nl3@Q03?Nl0
0d8@AS56<@03@Q0024Ha@Q1244Ha@Q0mkcW>@Q02AS401cg_>Li244YBAS52
44Ha009:DP03@Q0mkcg_008e[@03?Nm244Ha00924004AS5:DTicBU82@Q00
0cg_AS5:DP02BU83AS402DYBAS5243g_@Q16<DicBU96<@02@Q03AS400dYB
AS5:DP03BU800dHaBU9:DP03BU801THaBU9>LdYBCW=BU09>L`06BU96<DYB
BU9>LeJe0e:D0Tic00=F]E:DE[D00UJe25:D0Tic00=BU5JeCW<014ic0Cg_
00000`@Q00048@0512402@Q212448@aS;F]Nmd8@8@P]J`03>Lh00cF];F/]
J`03<H`4;F/01C6<>LhicSg_=Jd00c6<00<e[C6<;F/00be[0c6<0be[00DY
BRDY:DXaS3F]008]J`03:DXaS36<008]J`0?:DX]Jbe[:DXaS2e[=JdmkdHa
>Lh]JbDY;F/icSF]00<YBP059BTYBRDY8@PU:@028@P011S65:DDYAS60Q24
00DDYA2436<<H`Q200@<H`03248<H`Q2008@Q007248<H`Q2248@Q1BU6<H0
0QcW00<DYA2436<010aS01<8@QS67>LicTicE[EW>EkgE[EBU3g_@Q0YBR48
6<HQ22DY6<H<H`0324800`@Q2488@P04124424800`@Q2488@P0224821242
24801@aS2488@PaS24800`aS0QBU0Q2400D<H`@Q2488@P@Q008@Q0046<HL
ia241242248248@01PQ212448@@Q248<H`@8@PD48@0A24848@@Q248<Ha24
5:D@Q0aS24848@Q26<HU:AcW36<48@0248@030Q27>Le[EkgLiaBU3g_:DXD
YAcW6<HDY@8@Q0<<H`88@P061248@PQ224848@Q20P@Q0PQ20PaS10Q20PaS
00L@Q0aS36<<Ha2436<@Q00336<248@01@aS48@@Q1BU48@00PaS0Q240PaS
00<8@PaS36<01@aS00@8@P@Q1248@P848@04248@Q12436<224801a2436<8
@PaS48@DYAS6008DY@07?NmJeW>LKg/icS6<:DX00QcW00@<H`Q224848@88
@P@48@0324848@@Q00D48@0324848@@Q00D8@P031248@PQ200@8@P04124<
H`aS9BT2:DX02RDY6<HDYB48;F/aS2485:D48@Q210aS00<8@PaS36<01@Q2
10@Q0`Q23@@Q00H<Ha247>LLiaS67>L28@P01RDY<H`e[D8@?NlicP8mk`05
@Q16<DYBBU96<@03@Q0013g_@Q1244Ha0cg_00E244HaAS4mkd8@008mk`08
AS5244HaAS5244Ha@Q0mk`=24003AS52448@00924003AS5244Ha00924004
AS5:DTHaAS43BU8014HaCW=BU4YB0THa00=:DTicBU800dYB00m>LdYBAS56
<D8@AS5:DTic@Q0mkd8@AS5>LdYBAS400TYB00=244HaAS4014YB0dHa0dYB
00A6<D8@@Q0mk`924006AS5:DT8@?Nm244Ha0TYB1D8@00=6<D8@?Nl00SW>
1D8@0THa00E:DTHa?Nm244Ha00924007>Lhmkd8@AS5243g_>Lh0148@00<m
kd8@AS400dYB00A6<DYBBU9>L`9:DP04@Q0mkdHaAS42BU83AS46BU84CW<0
0dYBAS5:DP02AS44CW<014YBCW=BU4ic0dYB0Tic15:D1Dic00ABU4icDYAB
U0=>L`04DYA>Le:DDY@3CW<01E:DCW=:DU:DBU800Cg_0002124010001244
8@001@@Q00L8@S6<F]I24248;F/e[@02>Lh0136<;F/]Jbe[0c6<00<]Jc6<
;F/00SF]00@icSg_=JdaS08]J`<aS006;F/YBRe[;F/aS3F]0S6<00@]JbDY
:DX]J`8aS08]J`03<H`]Jbe[00<]J`04:DX]Jbe[;F/2<H`00cg_AS4e[@02
:DX01Be[=JdaS2e[:DX00bDY00HQ22DY8@PQ21S65:D26<H348@35:D22482
36<248@00`Q236<<H`0248@236<224801Q245:DHaR487>LDY@D<H`88@P0<
6<HQ23W>DYAF]F<HF]IF]Dic@Q0mkbDY0QcW00HYBRDY5:D8@P@Q36<32482
124224800`@Q2488@P021242248010aS2488@P@Q1PQ21@aS00H@Q1S65:D<
H`Q2124324801`aS5:DHaQS648@<H`Q2008<H`88@P848@@8@P051248@PQ2
1248@P0212400`Q212448@0224806`aS48@DYA2436<8@P@Q248LibDY6<H<
H`@Q48@DY@@Q7>LicVLiMke:DSF]:DXHaQcW6<H@Q00236<624800`@Q2488
@P0224821242248020aS2488@PQ236<8@PaS48@536<00a2436<<H`0536<3
48@436<00a2436<<H`0248@236<01@Q236<8@PQ236<00PQ20`@Q0`aS0`Q2
10aS0Q2400`DYAS648@mkekgMke[FSW><H`]JacW5:D236<00`@Q2488@P02
248312400`Q212448@0712400`Q21248@P0224800`@Q2488@P0224801`@Q
24848@Q248@<Hb48008]J`048@PDYABU8@P2<H`0124836<48@Q20PaS00D8
@PaS36<8@PaS00@8@P@48@88@P<48@0400048@@Q000212400`0012448@03
12401@aS5:DQ22486<H00QcW00DQ22U:<H`e[D8@008mk`05>Li2448@BU9>
L`02BU800dHa?Nlmk`02@Q000dHa@Q124002?Nl4@Q0013W>?Nlmkcg_0d8@
00I6<D8@@Q1243g_@Q02AS40148@?Nm244Ha0T8@00<mkd8@AS400THa00=2
44HaAS4014YB00=>LdYBBU800THa00A:DTHaAS5:DP9>L`05BU96<DHa@Q16
<@02BU801DHa?Nm244YBDY@00TYB1DHa00=:DTHaBU8014Ha0dYB00E6<D8@
?Nm243g_0092400:BU96<CW>?Nm6<DYBAS4mkd8@AS43@Q0034Ha?NlicSg_
@Q16<D8@?Nm244HaBU96<@=24003AS5243g_008mk`03@Q16<D8@00<mk`96
<@05?Nm2448@BU96<@04BU82CW<01TYBAS4mkcg_@Q16<@9:DP04AS5244Ha
AS45BU82CW<4BU82AS400dYBCW=>L`02CW<014YBCW=>Ldic0dYB0dic00=B
U5JeDY@00Tic00E:DTicDYA>Le:D00I>L`9BU09>L`04BU9>LdicBU83CW<1
>Lh0000500048@@Q1240000312402PQ200048@aS>Li[FTYB8@PaS3g_0cW>
00@aS2U:<H`]J`<aS08]J`8e[@03>Lhe[C6<00<aS004=JdaS36<;F/3<H`0
22e[:DX]Jc6<;F/YBRDY:DX2<H`012e[:DX]Jbe[0bU:00<]Jc6<;F/00be[
00de[CW>>LhaS2e[:DXaS3F]<H`]Jc6<;F/YBP059BT01acW6<HHaQcW8@PH
aQBU008@Q003248<H`aS00<<H`0448@DYABU48@636<02A246<HLibe[9BTH
aQ24248<H`0224801@aS248Lic6<DY@00Vmk00ioogNmMkecW5:DCW<Q21BU
48@DYAcW5:D8@P@Q0PQ20P@Q00<8@P@Q124010@Q0PQ200<48@Q224800P@Q
0PQ20PaS0PQ20P@Q1@aS00@@Q1BU7>LHaP8Li`8<H`05248<HaBU5:D@Q003
36<01QBU48@<H`Q21248@P<<H`@8@P848@0724848@Q224848@Q236<00a24
10Q20a2400L<H`@Q36<<H`@Q6<HYBP02>Lh00b486<HHaP0248@011S68@PH
aQ240PQ20`aS0PQ200@48@Q224848@<8@P0336<8@PQ200<8@P8<H`04248<
H`Q2248236<248@336<00a2436<<H`0236<00aBU48@@Q00548@936<00a24
24848@02124536<224803PaS48@@Q0aS248<Ha24248icUkgIcU>LaS648@3
7>L012486<H@Q0aS0`@Q0PQ21P@Q00<8@P@Q12400`@Q1@Q200@48@Q236<@
Q08<H`848@0448@HaRU:9BT28@P37>L012DY:DXU:AS60PaS0PQ20PaS0Q24
00<<H`Q2248010Q200<48@Q224800P@Q00<000@Q12401`@Q00H000@Q1244
8@aS5:D27>L25:D01b489BT]JcW>?Nm244Ha00<icP03?Nm6<DHa00=:DP06
@Q0icSW>?Nm244Ha0T8@00<mkcW>@Q000T8@00M6<D8@>LhicSg_@Q0mk`02
>Lh00cg_@Q124003?Nl3AS401T8@?Nlmkd8@?Nm24096<@05BU96<DYBCW=:
DP03CW<2BU800dHaBU9:DP02CW<3DY@2CW<3AS42BU8014Ha?Nm244Ha0Tic
00=6<DYBBU800THa00E244HaCW=:DTHa00924004AS5:DTYBAS44@Q000cW>
?Nm6<@02BU801DHa@Q16<DHaBU801D8@00<mkcW>>Lh00T8@0Sg_00I244YB
BU96<DYBAS42@Q001Cg_@Q1243g_@Q000THa00A243g_>Lhmk`9240<mk`07
AS5244Ha@Q16<DicBU800Tic0THa0T8@0dHa00=244HaBU8014YB00=6<Dic
CW<00U:D0Tic00=BU4icDY@00U:D0Tic00=:DTicDY@00U:D00M>LdYBBU9>
LdYBCW=BU003CW<01TYBAS5:DTYBCW=:DP=>L`=BU003CW=BU4ic00=>L`06
BU9>LdicCW=BU4YB0CF]000312400`0012448@0212402@Q2124000aS>LiW
>DHa8@PaS003>Lh2<H`00be[<H`]J`04;F/2<H`2=Jd00cW>=JdaS002;F/4
<H`00be[<H`aS005;F/3:DX0136<=JdaS2e[1RU:1Be[00HaS3F]=JdaS2e[
:DX3<H`00be[<H`YBP039BT2:DX012DY6<HDYAS60acW0Q241@aS00L8@PaS
5:DDYA2436<8@P0236<01@Q236<8@QBU7>L00RDY00<Q21BU5:D010Q200P<
H`Q28@PaS5[FLia_Ng_N0WNm00A_Ne:DBU8Li`8@Q0035:DLia2400<8@P84
8@0424848@@Q000312400`Q212448@04124424800`aS2488@P0424800`@Q
36<@Q0025:D01AS67>LLiaS636<00PQ200@<HaS65:D@Q0<<H`8@Q00436<8
@PQ2248236<00`Q21248@P0224800`@Q24848@02248010@Q2488@PaS0Q24
0`aS0PQ20a2400<<H`Q236<00PQ200DLibe[>LhicR48008HaP085:D@Q1S6
7>LDY@aS1248@P8<H`@8@P848@0524848@Q236<8@P0336<3248436<00`Q2
36<<H`0436<0112436<@Q0Q20PaS0Q2400<DYA2448@00Q2410aS00<@Q0aS
36<010aS00<8@P@Q12401`Q20PaS00/@Q0aS2488@PaS48@<Hcg_G_MS64YB
008DY@<Li`8HaP0336<8@P@Q0088@PL48@0324848@@Q00848@<8@P0336<4
8@Q200848@09248<Ha2436<8@P@Q248DYAcW008YBP<Li`066<HQ22U:9BTL
iaBU1`aS00D@Q0aS36<8@P@Q00D8@P031248@P@Q00@48@0300048@0000L4
8@8DY@077>LHaQS66<HLibDY<H`00SW>00=244Ha@Q000SW>00HmkdYBBU96
<DicAS42?Nl013F]?Nm243g_0T8@00<mkd8@?Nl00d8@00@mkcW>?Nlmk`92
408icP09?Nm243g_?NlicSg_@Q1:DTHa00Dmk`924006AS5:DTYBBU96<DYB
0dic0dYB00A6<DYBCW=BU09>L`0?DYA>LdYBAS5244HaBU9>Ld8@>LhmkdHa
DYA:DTHa009:DP=240=:DP03AS5243g_0096<@0;BU9244YB@Q0mkd8@>Li2
44HaBU96<@02@Q000dHaBU96<@02@Q000cg_AS524003>Lh01Sg_@Q0mkcg_
@Q16<@=:DP05AS4mkd8@?Nm6<@06@Q02?Nl03cW>?NlmkcW>?Nm244Ha@Q0m
kd8@AS5>Le:DCW=:DP03@Q000cg_@Q124005AS45BU82DY@01DicDYA>Ldic
DY@00Tic00=BU4icCW<00dic00EBU4icCW=:DTHa00M>L`03BU96<DHa009:
DP03CW=:DTYB00=BU0=>L`9BU008CW=:DTYBBU9>LdYBCW=:DP4e[@0000<0
00@Q12400P@Q00<000@Q12400`@Q00H<Hc6<JeY>LbU:;F/2=Jd013W>=Jda
S2e[0c6<0Re[0RU:0S6<00PicS6<<H`aS3F]<H`]JbU:0Re[0S6<1Be[0RU:
00<]Jc6<=Jd00S6<0be[00HaS2e[:DXYBRe[<H`3;F/00c6<=Jde[@05<H`0
1be[<H`e[C6<;F/U:AcW008U:@07:DXQ21S66<HQ22DY8@P00QS600H@Q0aS
2488@PaS48@336<6248236<01a247>LLiacW6<H@Q1BU008<H`88@P0536<8
@R48<HaBU002JeX027NmKg]kgWooHaQ:DQcW5:D248@010Q212448@@Q0PQ2
0`@Q0PQ200@48@Q212448@D8@P8<H`045:DHaQ2436<2124424801@aS248<
H`aS48@00QS60R4800@HaQBU36<@Q08DY@0548@<Ha248@PYBP02F]H00d8@
:DX8@P0336<3248312400`Q212448@02124436<01`Q236<8@PaS24848@Q2
00<@Q00836<8@P@Q48@DYAS65:D@Q0<<H`035:D@Q0aS0088@P0536<8@PaS
248<H`04248010@Q2488@PQ20PaS10Q200<<H`Q236<00`aS0PQ200@<Ha24
48@@Q08<H`0348@<Ha24008<H`<@Q08DY@0348@<Ha24008<H`88@P0836<@
Q0aS36<Q22DY5:D8@P848@<8@P0=1248@P@Q36<Lib485:D8@P@Q248@Q0aS
7>L00R4800<Lia2436<011240PQ21@@Q0`Q21P@Q00@8@P@Q24848@88@P03
36<8@P@Q0088@P8<H`8@Q08<H`8@Q0<DY@8HaP035:DHaQBU00<Li`8@Q088
@P8<H`8@Q00336<8@PQ200<8@P031248@P@Q00/48@0300048@@Q00848@05
248@Q1S66<HLi`026<H27>L01Re[@Q16<DYB@Q0icP<mk`=2409:DP04@Q0i
cSW>?Nl3@Q02>Lh01Cg_@Q16<D8@?Nl00cW>00=244Ha?Nl00cW>0T8@00hm
kd8@@Q16<D8@AS5243F]>Lhmkd8@BU9244Ha1TYB0THa14YB0T8@0THa0e:D
00=>LdYB@Q0014YB00A6<D8@AS5:DP9>L`05DYA6<D8@?Nm6<@02CW<00dYB
AS5:DP02BU800dHa@Q124003@Q001Sg_>LhicT8@AS5>L`96<@03BU96<DHa
0092408mk`92400<?Nm6<DHa?NlicSg_@Q1:DTHa@Q0mkdHa0T8@00=6<D8@
AS400dHa00=243g_>Lh00Sg_0cW>00<mkdHaBU80148@00Q>Le:DCW=>Ld8@
?Nm6<D8@0THa0T8@00@mkd8@AS56<@9:DP03CW=:DTYB009>L`=:DP9BU004
E[EBU4HaAS42BU800e:DCW=>L`02CW<01TYBCW=BU4icDYA>L`9:DP07AS5:
DTYBAS5>LdYBCW<00TYB0Tic00=BU4icCW<00Tic00QBU4YBBU9:DTHaCW=B
U4YB0CW>000212400`001240000312402@Q212448@Q2=JeW>DYB9BTaS004
=Jd01C6<;F/]Jbe[<H`00Re[0RU:00DaS3W>=Jde[Be[008aS08]J`03:DX]
Jc6<00<aS003;F/aS36<008YBP08;F/aS36<<H`]JbU:;F/aS08]J`8U:@@]
J`03:DX]Jc6<00<aS08e[@08<H`]Jc6<<H`icS6<;F/U:@8Q208U:@048@PH
aQcW6<H29BT011S65:D<H`Q21`aS0PQ200/48@Q236<8@PaS248@Q1S68@PL
iaBU008@Q08<H`0;1248@Q24248Q236<CW=_Nf]JMke_N`02Ool01E[FAS4H
aQ245:D00PaS0PQ21@@Q0PQ20`@Q0`Q200@48@Q2248<H`88@P0448@HaQBU
36<212400`Q21248@P03248236<00a246<HHaP028@P00aS648@<H`0448@0
30Q248@Q22U:F]INmcW>9BT8@PaS48@<H`88@PH48@0424848@Q2248636<0
10Q21248@PQ20PaS00H@Q0aS2488@PaS48@25:D0112436<<Ha240`aS0`Q2
00@<H`Q22488@P8<H`88@P031248@PQ20088@P<<H`<8@P0436<@Q0aS36<2
248236<248@:36<00a245:D@Q00248@336<3248236<011248@PQ21BU0`@Q
00<<H`Q212400P@Q00h8@PaS6<HLiaBU24848@Q25:D@Q1S68@PLiaS60Q24
00@DYA2436<<H`@8@P<48@0424848@@Q248412400`Q21248@P0724800`@Q
2488@P0248@01`aS48@<Ha2436<DYA24008HaP<DY@8HaP047>LHaQBU36<2
248236<00a2436<<H`0324800`aS24848@021242248=124224803a245:DL
iacW6<HDYAcW8@P]Jcg_AS5:DTHa>Lhmk`02>Lh2@Q000dHaBU96<@02?Nl0
0cW>?Nm24003>Lh01Cg_>Li244Ha@Q000SW>00Pe[Cg_AS56<D8@>Lhe[Cg_
1T8@00=6<D8@@Q000cW>00=244HaAS400THa00E:DTHaAS56<DYB00=6<@=:
DP=24003AS5>Le:D009>L`03BU96<DHa0096<@924096<@05CW=:DTicCW=:
DP02@Q000dHaCW=>L`03AS400dYBAS524003@Q03?Nl01CF]>Li244HaBU80
1DHa00=243g_?Nl00cg_00Y244HaBU8mkcW>?Nm244YBAS4mk`I24008AS52
44Ha@Q0mkd8@>Lhmk`<icP04=Jdmkd8@AS42@Q001cg_@Q1>Le:DCW=:DSg_
00924005AS52448@@Q0mk`03@Q03BU800dicBU9:DP02BU800dicBU9:DP03
DY@00dicAS56<@02BU82DY@2BU86CW<2BU82AS43BU8014HaBU9:DTYB0Tic
00=BU4icCW<014ic1DYB0Dic0DYB0CF]00000`0012448@0212400`001244
8@0312401PaS;F]S64YB:DXe[@HaS003=Jd]Jbe[008YBP8]J`04<H`]Jc6<
<H`3=Jd2<H`3;F/00c6<=JdaS002<H`022e[:DXYBRDY;F/YBRe[<H`2=Jd4
<H`00be[:DX]J`06<H`022U:>Li243g_<H`YBRe[=Jd2<H`00be[:DXQ2002
8@P012U:9BTLiaS60b4800<DYA2436<00`Q20PaS0`Q200<<H`Q224801@Q2
00T<Ha245:DHaQ245:DHaQ2436<00PQ20PaS010HaR48>Li>LeJeJeYW>F]J
Kg]2436<5:DLiaS648@8@P848@<8@P@48@0324848@Q200H8@P0536<@Q0aS
48@<H`07248236<248@011BU36<<H`aS0QBU00<HaQcW7>L00R480QBU00@H
aR489BTU:@8]J`09F]IW>E[FBU8DY@aS24848@Q200<48@88@P041248@P@Q
248336<5248010@Q2488@PaS0Q2400D<H`Q236<<HaS6008Li`0348@<H`Q2
00L<H`03248<H`aS0088@P848@@8@P0436<8@PaS36<2248010aS2488@PQ2
0PaS00D8@PaS5:DDYA2400<<H`03248<H`aS00@<H`0448@<H`aS36<248@2
36<3248010aS48@DY@aS0P@Q00<8@P@Q12400P@Q00H8@P@Q24848@Q236<2
24802@@Q248<H`aS248<Ha245:D<H`02248010aS2488@PQ20`aS00@48@Q2
12448@@8@P0336<8@PQ200D8@P8<H`0624848@@Q24848@Q21@aS00D@Q1BU
5:D@Q1BU008@Q0065:D@Q12448@HaQcW0QS600<DY@aS36<00`Q200<<H`Q2
36<00PQ23P@Q00@000@Q124000848@05248<HaBU5:DHaP027>L01QS67>LY
BSF]@Q0mk`<icP03@Q16<CW>008icP03AS5244Ha0096<@<mk`06AS5243g_
=JdicSg_0T8@0Sg_00U6<DicBU96<Cg_@Q16<DYBAS400T8@0dHa00A244Ha
AS5240<mk`924096<@A:DP03AS52448@0096<@03BU96<D8@008mk`03>Li6
<DHa009>L`9:DP9>L`03BU96<DHa00924009BU9>LdicBU9243g_AS5:DTic
009:DPA6<@05@Q16<Cg_?NlicP05?Nl3AS44?Nl0148@BU96<D8@0Sg_00A6
<DYBBU96<@8icP09?Nm243g_?Nm244Ha@Q16<D8@0096<@05BU96<D8@?Nli
cP03@Q001Cg_>Li244HaBU800THa148@00A6<DYBBU924096<@03@Q16<Cg_
00<mk`03@Q16<DHa009:DP04AS5:DTYBCW<5BU82DY@2BU800dicDYABU005
CW<01TYBCW=>Le:DCW=:DP96<@9:DP9BU09>L`03BU9>Ldic00Q>L`07DYA>
LdicBU9>Le:DBU800CW>000312400`0012448@0212402@Q200048@Q2;F]S
64YB:DXe[@05<H`013F]<H`aS2e[0RU:00@]JbU:;F/]J`<aS08e[@8aS004
;F/YBS6<;F/2=Jd00c6<;F/U:@03:DX00be[:DX]J`03<H`00be[<H`aS004
;F/01C6<;F/aS36<=Jd00Re[00HicT8@?NlaS2DY:DX2=Jd0136<;F/YBQcW
0R4800@U:B486<HLi`8Q20037>L@Q12400@8@PH<H`@8@P061248@PQ236<@
Q1BU1A2400<<H`Q224800PaS00LLib48>Li>Le[FJeYS6002JeX00d8@:DXD
Y@026<H01A242488@PQ212401@Q210@Q1@Q200<48@Q236<00a240PaS00T8
@P@Q2488@PaS248<Ha245:D00Q2400D8@PaS48@DYAcW008HaP038@PLiacW
008HaP037>LQ22U:008]J`05F]I_Ne[F@Q0@Q00224800`@Q24848@061240
0`Q236<<H`0336<6248236<248@010aS2488@PaS0QS600<@Q0aS36<00`aS
00@8@PaS36<<H`@8@P0536<8@PQ224848@07248236<7248011245:DDYA24
0PQ210aS00<@Q0aS36<00`aS00<8@PaS36<00Q2410Q200D<Ha2448@<H`Q2
00848@0424848@@Q248312400`Q236<<H`0324802@aS48@<H`@Q248<HaBU
48@8@P0236<01@@Q2488@PQ236<00PQ20`@Q0PQ200<<H`Q212401`Q200@<
H`Q236<8@P<48@0336<8@PaS008<H`8@Q0<DY@L@Q0<HaP8DY@8<H`88@P8<
H`88@P848@0324848@@Q00D48@0424848@@Q00041240100012448@@Q0PQ2
00@DYAS67>LLi`8HaP0=8@P]Jc6<@Q0mkcW><H`icTHa@Q0mkcF]>Lh00dHa
0d8@00@mkd8@@Q0mk`8icP8mk`05@Q0mkcW>@Q16<@02BU8014Ha@Q0mkd8@
0TYB00A6<Cg_@Q16<@A240<mk`E240=:DP96<@=24003AS5:DTHa00@mk`03
@Q16<Dic00=>L`9:DP03CW=6<D8@00924004BU9>LdYBBU83@Q001DHaBU9:
DTHa@Q000dHa00E243g_@Q0mkd8@008mk`06>Lhmkd8@@Q1:DTHa0T8@0Sg_
0dHa0T8@00Dmkd8@BU9:DT8@008icP924005?NlicSg_@Q16<@02@Q03AS42
@Q02?Nl3@Q03>Lh5AS402d8@?Nm2448@BU96<DYBAS5244Ha@Q000Sg_00<i
cT8@@Q000THa00A:DTHaBU96<@9:DP05AS5:DTHaBU9BU003CW<014YBCW=>
Le:D0Tic00E:DTicCW=>LdYB009>L`9:DP924004BU9>LdicDY@3CW<00dYB
CW=>L`03CW<00dYBCW=:DP02CW<01U:DCW=:DTYBCW=:DP4icP0000D48@00
12448@0000<48@0824848@@Q248YBU[FAS4YBP8aS004;F/aS2e[<H`2=Jd0
136<;F/YBRU:0be[0S6<00<]Jc6<=Jd00SF]00<aS2e[<H`01C6<00LicS6<
;F/YBRDY:DXU:@02:DX01Be[<H`]Jc6<>Lh00SF]0RU:00@]JcF]=JdaS08]
J`04<H`icSW>;F/2:DX3;F/02BU:<H`aS2U:7>LQ22DY:DXU:@047>L00aBU
36<48@0212400`Q236<@Q00236<2248236<324800`aS248<H`0236<02124
36<@Q1BU48@<H`@Q36<248@01aS65:DYBTicHaQ_Ne:D008aS0038@PLiaBU
008@Q00336<8@PQ2008<H`<8@P041248@PQ2124:248236<4248212400`Q2
36<8@P0336<0112436<<H`Q20PaS0QBU014HaQcW8@PQ22U:<H`icTHaBU8m
kcW>:DXU:DYBJeYBU2e[00848@88@P848@0324848@Q200@8@P0536<8@PQ2
24848@02248010@Q2488@PQ20`aS0`Q200H@Q1BU5:D@Q0aS48@26<H00a24
248<H`02248536<224801@@Q2488@PQ236<00Q2400<DY@Q224801@Q20PaS
00/DY@aS6<HLia2436<48@Q248@<H`Q200<<H`0524848@Q2248<H`0348@0
0`aS24848@02248236<00`Q21248@P0312422482124010Q236<<H`aS0`Q2
00L<H`Q2124<HaBU6<H@Q0021243248236<00a2436<8@P0224800`aS2488
@P02248436<2248336<324800`@Q2488@P0236<00`Q236<<H`0236<01124
5:DHaQS60aBU00@@Q1BU48@@Q08Li`035:D8@P@Q00<8@P031248@PQ20088
@P<48@0424848@@Q000>12402PaS48@HaQS65:DHaQcW8@PYBRe[0SF]00Ti
cSF]<H`mkdHa@Q0icSF]?Nl00THa0Sg_0d8@0cg_0cW>00<mkcW>?Nl00T8@
1THa00<mkd8@@Q000dYB00=244Ha@Q000T8@00@mkcW>?Nlmk`96<@03?Nm2
448@00=6<@04?Nm6<DHa@Q02>Lh00d8@AS524002>Lh2@Q002DYBCW=6<Dic
DYA>LdYBAS524002AS401DYBCW=:DTYBAS400d8@00M6<DYBAS56<D8@AS5:
DP02AS42>Lh00cF]>Lhmk`02AS400d8@>Lhmk`03@Q02?Nl014HaBU9:DTHa
0T8@00A:DTicBU9240@mk`8icP03?Nm244Ha00A6<@06@Q0mkcW>>Lhmkd8@
0Sg_1D8@0dHa00Y243g_>LhicT8@AS5244Ha@Q0mk`A24007?Nm244HaAS52
43g_>Lh00THa0TYB14Ha00A>LdYBAS5:DP9>L`9:DP04AS5:DTHaBU83CW<6
BU800dicDYABU002CW<4BU8014HaBU9>Ldic0dYB00=BU4icCW<00Tic0E:D
0DHa0CW>00000`0012448@0212400`0012448@0212401P0036<YBU[F@Q0Y
BP8aS007:DX]Jbe[=JdaS3F];F/00bU:0Re[1S6<00<icS6<<H`00RU:00<a
S3F]<H`01C6<00<U:BU:9BT00bDY00@aS2e[;F/aS08icP03<H`]JbU:008a
S008=Jd]Jbe[;F/e[CW>=Jd]J`8YBP04;F/aS2e[:DX2;F/01bDY8@PQ22DY
:DXU:B48008Li`056<H@Q0aS12400002248348@2248010aS248<H`aS1@Q2
00L<Ha2436<8@PaS5:D@Q003248248@26<H032U:DYAW>F]JCW<]Jc6<8@PL
iaBU6<H@Q0<8@P0736<8@PQ21248@P@Q24800P@Q1@Q200L48@Q21248@PaS
248<H`04248010@Q24848@Q21@aS00LDY@aS36<8@PaS5:DHaP027>L04B48
7>L]JcF]?Nm:DTHa>Lhe[C6<:DY6<FLiBU8YBP@Q00000PQ21`@Q0PaS00<8
@PaS24800PQ200@48@Q224848@<8@P0636<8@PQ2248<HaBU0Q2400L<Ha24
5:DHaQBU48@8@P0336<010Q236<<H`aS0PQ21@@Q00@<Ha2448@<H`848@H8
@P0336<@Q124008HaP065:D@Q0Q2248<H`Q20PaS00<@Q0Q224800PQ20PaS
0Q2400d<Ha2436<8@P@Q36<@Q0aS24848@Q21248@P041242248236<62480
1`@Q36<DYAS648@8@P@Q0088@PH<H`L8@P8<H`0548@<H`Q224848@0336<0
0`Q212448@0424801PaS248<Ha2436<@Q0<DY@0348@DYABU008@Q00936<D
YAS66<HDYA241248@P@Q00<8@P031248@PQ200<48@0324848@@Q00X48@03
00048@@Q00848@8<H`@HaP8Li`039BTaS36<008icP03<H`e[Cg_00924003
>Lhe[Cg_0096<@92408mk`03>Lhmkcg_00<icP8mk`8icP04@Q16<DHa@Q03
AS44@Q000dHaBU96<@04@Q0014Ha?NlicSW>0T8@00A6<D8@?Nlmk`9:DP07
@Q0mkd8@AS5243W>?Nl00T8@0cW>00<mkdHaBU800TYB14ic0d8@00=6<DYB
BU800TYB00A6<Cg_@Q1240=6<@06@Q16<DYBBU9244Ha0SW>0SF]148@00Di
cSg_AS56<Cg_008icP05@Q1:DTYBBU924002AS401DicBU9243g_>Lh00cg_
00@icSg_@Q124096<@=24004?NlicSg_?Nl2>Lh2?Nl02dHa@Q12448@?Nm2
44YB?NlicSF]?Nl00dHa00=243g_?Nl00Sg_00E243g_@Q1244Ha00924003
>Lhmkd8@00=:DP=6<@I:DP03CW=:DTHa00E:DP9>L`A:DP0:AS5:DTicCW=B
U4icBU9>LdHaBU82AS400dYBCW=>L`02BU82CW<01U:DCW=:DTYBCW=:DP4e
[@000P@Q00<000@Q12401P@Q00L8@RU:DYA242e[=JdaS002:DX00be[=Jde
[@03;F/00bU:;F/]J`02;F/2<H`01Re[<H`e[CF]>LhaS08]J`04:DX]JcF]
=Jd2<H`2:DX012e[9BTU:BDY0Re[00@YBS6<;F/e[@<aS0@]J`03<H`YBRU:
008]J`03=JdaS2e[00<YBP06<H`]Jbe[:DX]Jb480RDY00TYBS6<;F/U:AcW
6<HQ21S648@00`@Q00<8@PaS6<H00Q2400<<H`Q236<020Q21`aS0PQ200X4
8@Q25:D<Hb48DYA[FU[F<H`@Q08Li`045:D@Q12436<3248236<224801P@Q
2488@P@Q24848@<8@P031248@PQ200<8@P<<H`88@P031248@PQ200<8@P8<
H`0348@8@PQ20088@P0436<8@PaS36<25:D02bU:>Li>Lf]JIcU_NfLiE[EB
U3W><H`00RDY00DQ21cW36<<H`Q200@48@0324848@Q200H8@P031248@P@Q
00@8@P051248@PQ236<8@P0236<01aBU6<HHaQcW6<HLiaS6008@Q0@<H`03
48@<H`aS008<H`88@P041248@PQ2248448@01PaS2488@PQ236<8@PD<H`06
7>LQ22485:D<H`Q21@aS00H@Q0Q224848@Q236<248@336<00`Q236<8@P04
24800`@Q2488@P0412401@Q236<@Q12436<00`Q20PaS0PQ200H@Q1S67>LD
YA2436<4248236<248@536<00`Q236<<H`0236<00`Q236<<H`0236<22482
124224800`aS48@<H`0236<01Q246<HU:AcW8@PLi`8Q20057>L@Q12448@D
Y@029BT011BU36<48@@Q0PQ20`@Q00@8@PaS2488@P848@0324848@@Q00h4
8@8@Q08HaP065:DHaQcW8@PYBRe[0S6<00<e[CW>=Jd013g_00<e[CW>?Nl0
0T8@00=6<D8@>Lh00SW>0T8@00<mkcW>>Lh00Sg_0d8@0cg_00=244YBBU80
13g_00A6<D8@@Q0mk`E6<@8mk`924004AS4mkcg_?Nl3AS42CW<00d8@>Lhi
cP02AS400d8@>LhicP02AS401dYBAS5244YBCW=:DTHa00<mk`03@Q1:DTYB
009:DP96<@=24005BU9>LdYB?NlicP02@Q000cg_=JdaS003>Lh0148@AS52
448@0SW>0Sg_0T8@00@mkd8@?Nlmk`A6<@=2408mk`05=JdaS3F]>Li24007
?Nl0148@?Nlmkcg_0T8@00I6<D8@?NlmkcW>@Q02?Nl01SW>=JdicSF]?Nm6
<@8mk`8icP03@Q16<DHa00=6<@924006?NlicSF]?Nm244YB0dHa14YB00A>
LdYBCW=6<@9:DP03CW=:DTYB0096<@E:DP04AS5:DTYBBU84CW<3AS42@Q00
14HaBU9>Ldic14YB0dic0DYB0DHa0CF]00001@@Q00048@@Q00001P@Q00X8
@RDYE[DmkbU:=JdaS2e[:DX]J`8aS0<]J`06:DXU:BU:;F/e[C6<0be[00@a
S3W>>LhaS0<YBP03;F/e[CF]008aS0DYBP039BTYBRU:00<]J`8e[@04<H`]
JbU:;F/2<H`4;F/3<H`012U:;F/YBRU:0Re[00<YBRe[:DX00R4800HU:BU:
<H`YBRDY8@P27>L248@312401@aS48@DYA2436<00`Q200<<H`Q224800PQ2
00D48@Q2248<H`Q2008<H`8@Q088@P0;1248@P@Q48@<HbU:F]IW>EJe;F/@
Q0027>L00aS648@<H`0324801PaS48@8@PQ21248@P848@0324848@Q200@8
@P061248@PQ2248<H`Q20PaS0`Q200H48@Q22488@PaS248336<2248336<0
1a2436<DYABU:DXicU:D009[FP06LiaS65:DDY@icRe[0RDY00<LiaS648@0
0PQ20`@Q0PQ200@48@Q2248<H`@8@P<48@0324848@Q200<8@P0336<8@PQ2
0088@P045:DHaR487>L36<H011BU48@<H`aS0Q241@aS0`@Q00T8@PaS248<
Ha245:D@Q0Q236<00PQ200D48@Q236<<Ha24008<H`067>LU:AcW6<H48@Q2
0`aS00@@Q0aS248<H`88@PD<H`0348@<H`aS0088@P0336<8@PQ200<8@P<4
8@0524848@Q236<@Q00236<010Q236<<H`aS0PQ20Q240QcW0QBU00<@Q0Q2
24800PQ200<@Q1BU48@00`aS00@@Q0Q22488@P8<H`0448@8@PaS248336<3
248010@Q2488@Q2410aS0QS600LQ22DY8@PQ21cW8@PLi`0348@01AcW:DXQ
21BU36<01P@Q0PQ200D<H`Q212448@Q201048@03248<HaBU00<HaP065:DL
ib48:DXaS2e[0S6<0SF]00<icT8@?Nl00cW>00I243g_?Nlmkd8@?Nl2>Lh3
?Nl2>Lh2?Nl3@Q03?Nl01T8@AS52448@?NlicPA24004?Nm2448@AS42@Q02
?Nl2@Q02?Nl01CW>?Nm6<D8@AS400TYB00HmkcF]>Li244Ha?Nl2>Lh00d8@
AS56<@03AS42BU800d8@?Nm24002@Q0014HaBU9>LdYB0dHa0T8@00=6<DYB
AS400cg_00=243g_>Lh00SF]00<icSg_@Q000T8@0Sg_00<icSg_@Q001Cg_
0T8@00I6<DYBAS56<D8@?Nl2>Lh01CF]<H`icSW>@Q000Sg_00@icSg_>Lhi
cP@mk`07@Q0mkd8@@Q0icSg_>Lh00Sg_0T8@0SW>0SF]0d8@00@mkcF]=Jdm
k`96<@04BU92448@@Q02?Nl2=Jd01SW>@Q16<DYB@Q16<@=:DP04CW=:DTic
BU82AS42BU800dicBU96<@02AS4014YBAS5:DTHa1DYB0Tic00=:DTHa@Q00
0T8@0THa0Tic00=:DTHaBU800dYB0dic0DHa0C6<00000`0012448@031240
30001248@P@Q0008@RU:F]I6<BU:=JdaS08]J`05:DX]Jbe[;F/YBP04;F/0
0bU:;F/aS002;F/00bU:;F/e[@02>Lh02CF];F/Q22DY;F/aS3F];F/U:@04
:DX00be[<H`YBP02:DX4<H`2=Jd00c6<;F/]J`02;F/2<H`01RU:;F/]Jc6<
;F/YBP8U:@<YBP0B9BTQ22DY7>LQ22e[<H`e[Be[8@PU:AcW5:D8@P@Q248<
Ha240QBU0PaS00<8@P@Q48@00QBU00<<H`@Q12400`Q200<<H`Q224800PQ2
00P<H`Q224848@Q236<@Q1BU0RDY00@LiaBU48@@Q08HaP055:D@Q0Q2248<
H`02248010aS24848@@Q0PQ20PaS0PQ200<48@Q236<010Q20PaS0a2400D<
H`@Q2488@P@Q0088@P@<H`03248<H`aS008<H`0A248<HaBU5:DaS4HaHaQk
gVmkMkekgWNmJeY>LdYB8@PHaP07248412400`Q212448@0924800`@Q2488
@P0424801a245:DHaQS65:DHaQBU008HaP0348@<Ha2400<DY@0636<@Q124
48@<H`Q20P@Q0PQ20PaS00D@Q0aS36<<H`Q2008<H`<@Q0<8@P0536<DYAcW
6<HDY@0336<01@Q236<<Ha2436<00`Q20PaS00@@Q0aS36<8@P<<H`H8@P04
1248@PQ2124224802`aS248<H`aS48@<H`Q236<@Q1cW6<H00QBU1@aS00P8
@PaS2488@PaS248@Q1BU0Q2400<8@PaS24800PaS00<@Q0aS48@010aS00<8
@PaS248010Q20`aS01@8@QBU48@DYC6<?Nm[FW>LE[EBU2U:6<HDYA246<HQ
21cW6<H@Q0Q21P@Q00@8@PaS2488@Pl48@0400048@Q2248248@00aS67>LL
i`027>L00b48;F/aS003<H`013F]?NlicSF]0SW>0Sg_00<icSg_@Q000d8@
00HmkcW>>Lhmkd8@?Nl2>Lh00cg_AS56<@02@Q001THa?Nlmkcg_AS5:DPA2
40<mk`=2408mk`=6<@03@Q0mkcW>008mk`=6<@9:DP04@Q0mkcg_@Q02AS42
?Nl00cW>?Nm6<@02@Q0014HaBU9:DTHa0T8@00@mkcW>@Q16<@9>L`04AS52
44Ha@Q02AS401D8@?Nm243g_@Q000Sg_00@icSF]>LhicP924096<@03BU92
448@00HicP03?Nm2448@00@mk`92408mk`<icP08=JdmkdHa@Q0mkcF]>Lhm
k`924005?NlicSW>@Q16<@02@Q001CW>?Nm243g_>Lh00SF]00DicSF]<H`i
cT8@0096<@8icP05?Nm6<DYBCW=:DP02@Q0013g_@Q1243g_0T8@00A:DTHa
BU96<@A:DP04CW=:DTHaBU83CW<2AS43BU8014HaBU96<DHa14YB00A6<D8@
BU96<@9:DPE6<@03BU9>Ldic00M>L`5:DP4e[@000`@Q00<000@Q00001@@Q
00P8@RDYDY@mkc6<=Jd]JbU:0be[00@YBRe[;F/YBPX]J`07=JdmkcW><H`Y
BRDY:DX00S6<0Re[00<YBRDY:DX01bU:00<]Jc6<;F/00c6<00<e[Be[:DX0
0RU:00<aS2e[:DX00S6<0Re[00@U:BU::DX]J`8YBP069BTQ22488@PU:Be[
0S6<0RDY00DYBQcW48@8@P@Q0088@P0748@HaQ2436<8@P@Q36<00a2400<<
H`@Q248010Q20PaS0PQ200D<H`Q224848@Q2008<H`075:DQ22DY7>LDYA24
5:D00QS600<@Q0aS248010aS0PQ20P@Q0PQ200@<H`Q224848@88@P0436<8
@PQ2248336<021245:D@Q0aS24848@Q21243248236<00`Q236<<H`0236<3
24805AS65:DaS4YBIcUkgVmkMkekgW>LIcU:DT8@7>LDY@Q2124<H`Q236<8
@P0212401PQ21248@P@Q24848@H8@P0=1248@P@Q24848@Q236<8@PaS248<
Ha246<H00aBU0QS600<DYA2448@00PaS0Q2400DDYA2448@<H`Q200<48@03
248<H`aS008@Q00536<@Q0aS36<8@P0336<01A24248<H`Q236<00aS600@D
Y@aS48@<H`88@P0436<@Q12436<224801@aS48@@Q0aS24800`aS00<8@PaS
24801PQ200<48@Q224800PQ20PaS00/@Q0aS36<8@Q245:DHaQBU48@DYA24
008<H`05248<H`Q224848@02248011245:DDYA240PaS0`Q20PaS00<@Q0aS
36<010aS1`Q200<<Ha2436<00Q2400`DYCW>@Q1[FWNmE[E>Lb4848@DYA24
7>L28@P25:D010@Q24848@Q20`@Q0PQ200<<H`Q212400`@Q00D8@P@Q1244
8@Q200P48@06248<HaBU48@DYAS60QcW00<Q22DY:DX0136<00<e[CW>>Lh0
0SF]00Pmkd8@>LhicSg_@Q16<D8@0Sg_0SW>00=243g_?Nl00SW>00<mkd8@
@Q000d8@0Sg_0T8@0THa0T8@0Sg_00<icSg_?Nl00T8@00@mkd8@@Q16<@92
408icP03?Nm244Ha00924008AS5>Ld8@>Lhmkd8@AS52408icP8mk`03@Q0m
kd8@00A6<@92408icP05@Q1:DTicCW=6<@03@Q000dYBAS524004?Nl5>Lh2
?Nl2@Q0014HaBU9243g_0SW>00<mkcW>>Lh00cg_00<icSg_?Nl01Cg_00<i
cSF]=Jd00SW>00<mkd8@@Q000SW>00<e[Cg_@Q000T8@0SW>00=244HaAS40
0cg_00@icSg_>LhicP<e[@03<H`mkcg_0092408icP06?Nm244YBBU96<D8@
0Sg_0T8@0Sg_00=6<DYBBU800THa0dYB00Q>Le:DBU9244HaCW=BU4YB0THa
00A:DTHaAS5:DPA6<@9:DP96<@=:DP03AS5:DTYB00A6<@05CW=:DTicCW=:
DP04CW<1BU81@Q01=Jd0000300048@0000D48@08248000@Q248YBUJe?NlY
BP8e[@03<H`YBRU:008]J`03:DXaS36<008]J`05:DX]Jbe[<H`]J`02:DX0
1Re[<H`mkcW>;F/YBP8Q208aS005=JdaS2U:;F/YBP02;F/00bU:;F/YBP02
;F/3<H`00be[<H`aS002;F/2:DX00be[<H`]J`02:DX00be[<H`]J`039BT3
:DX01RDY8@PU:B487>L]J`8e[@06;F/U:BU:8@PLi`aS0`Q20`aS0`Q200<4
8@Q236<00PQ20P@Q1PQ200D48@Q22488@PaS00@8@P<<H`88@P0648@HaQcW
6<H8@PaS0PQ200<<H`Q224800`Q200<48@Q224800PaS0`Q200<<H`Q22480
1@Q20PaS00P@Q0aS248<H`Q21248@P@Q10aS01@48@aS5:D@Q0aS124<HaS6
5:DYBSW>F]I_Nf]JNmicW7_NMke:DSW>0Q2400<<H`Q224800P@Q0PQ210@Q
00<8@P@Q24801@Q200<48@Q224800PQ200<<H`Q224800PQ200D<Ha2448@D
YAS600DDY@<@Q00836<@Q0aS48@<H`Q236<@Q08<H`H8@P0348@<H`aS00<<
H`0348@<H`aS008<H`88@P0448@DYABU5:D236<01a2436<@Q1BU48@DYAS6
00<DY@8@Q0045:D@Q0aS248236<3248010@Q2488@P@Q10Q200<48@aS2480
1`aS00@DYAS68@PU:@8Li`D<H`06248<H`aS36<@Q1BU0Q240PQ210aS00<8
@Q2448@00PaS00<8@PaS36<00`Q20PaS0Q2400XDYA245:DYBSF]>LhaS2U:
<Ha>L`9S6004DY@]JaBU6<H248@012487>LLiaBU1P@Q00<8@P@Q24803@@Q
00H000@Q12448@Q248@25:D01Q245:DQ2248:DX]J`DaS003=JdicSF]008e
[@8mk`<icPM24004?Nm243g_?Nl5@Q000dHaBU8mk`02?Nl0148@BU96<Cg_
0SW>00@mkd8@@Q0mk`A240=6<@9240Dmk`E2408icP07AS5:DTYB@Q0icSg_
@Q000dYB0THa00a:DTHaBU8mkcW>?Nm244icDYA:DTicBU82AS42?Nl013W>
@Q1243g_13W>00<mkcW>@Q000T8@0THa00=243g_=Jd00cF]0cg_00I243g_
?NlmkcW>=Jd3>Lh00cg_>LhicP02=Jd01CW>?Nm243g_>Lh00cg_00DicSg_
AS5243g_008icP<mk`DicP06?NlicSW><H`icSg_0cW>00LmkdYBBU9:DTHa
@Q0mk`02@Q001THa@Q1244HaCW=:DP96<@03@Q1:DTYB009>L`=:DP9BU003
CW=:DTYB00=>L`=:DP03AS5:DTic009:DP96<@9:DP03CW=:DTic00=6<@E:
DP07CW=BU4icDYA>LeJeCW<00CF]000512400`0012448@0312401@Q2:DYF
]D8@:DX00S6<00<]JbU::DX00RU:00@]Jc6<<H`aS0<YBP03;F/aS36<00<]
J`0=<H`icSW><H`YBR489BT]Jc6<=JdaS2U:9BT00RU:0Re[0bU:00@]Jc6<
<H`aS08]J`05<H`]Jbe[:DX]J`06:DX022e[:DXU:B489BTYBRe[9BT28@P0
12DY8@PU:Be[0S6<00L]JbU:;F/LiaS636<48@0224800`aS48@8@P052482
36<224800`@Q24848@0324800`aS2488@P0324800`@Q2488@P02248236<2
24801A245:DLiaS636<02PQ210aS0PQ200<<H`Q236<00PQ200@48@Q22488
@PH<H`031248@P@Q00<8@P0@36<8@PQ248@DYA2424848@Q26<HDYBe[@Q1N
mfmkJeX2Mkd027_NLia2436<36<@Q0aS248312422483124224800`@Q2488
@P07248010aS248<H`aS10Q20Q240QBU00@HaQBU5:DDY@D@Q00636<@Q0aS
248<Ha240PaS1@Q20`aS00<8@PaS36<00Q240`aS0`Q200H<Ha245:DHaQBU
48@336<248@00aBU6<HDY@035:D248@010aS48@<H`aS0PQ200@<H`Q22488
@P848@<8@P848@88@PH<H`8@Q00;6<HDYAcW8@PLiaS636<8@PaS248<H`02
24801PaS248DYABU48@<H`88@P0536<8@PaS36<@Q00836<2248336<01a24
5:DDYABU:DXe[CW>00<]J`05DYA[FUkgCW<Q20025:D01Q245:DLib486<H@
Q0L48@88@P031248@P@Q00848@0424848@@Q000312400`0012448@021240
2@aS48@HaQBU6<HDYAcW8@PYBP02;F/4<H`01cF]>Lhe[Be[=JdicT8@00<i
cP03@Q0mkd8@00=240<mk`E2408mk`96<@07?NlicSg_@Q1:DTHa?Nl00cW>
0T8@00=6<D8@AS400T8@00@mkdHa@Q16<@Dmk`9240Dmk`05>Li244YBBU92
4002>Lh014HaBU9>LdYB14Ha00E:DSg_>LhmkdHa009BU003CW=:DTHa0096
<@03@Q0icSg_00<mk`8e[@05>Lhmkcg_>Lhmk`02@Q001TYB@Q0mkcW>=Jda
S08icPDmk`8icP04=JdicSW>=Jd4?Nl02CF]<H`icSg_@Q0mkcW>=JdicP03
?Nl00d8@?Nm24002>Lh013g_>Lhmkcg_0SW>00<e[CW>>Lh01SW>00@mkcW>
@Q16<@9:DP03AS4mkcW>00924004AS52448@AS42BU801DHa@Q16<DHaBU80
0Tic00=:DTHaCW<00U:D00=>LdHaBU800TYB00A>LdYBBU96<@E:DP=6<@9:
DP04CW=:DTHaAS45BU801DicDYA>Le:DCW<00U:D0DYB0CF]000010001244
8@001`@Q00D8@RU:E[DmkbU:008e[@03<H`YBRU:00@]J`03:DX]Jc6<00@Y
BPHaS004=JdaS36<:DX29BT01Be[<H`aS2e[:DX00be[00<YBRe[;F/00be[
0S6<00Te[CW><H`aS2e[:DX]Jc6<;F/00RU:0RDY00@YBRe[<H`]J`8YBP0D
9BTQ22489BTYBR487>LYBS6<>Lh]Jb489BT]JbU:7>LDY@aS248<H`88@P84
8@88@P0436<8@P@Q124>24800`@Q24848@03248010aS2488@PQ20PaS00<@
Q0aS24800PQ20PaS0PQ200@48@Q236<<H`8@Q00336<8@PQ200<<H`07248<
H`aS1248@P@Q24800PaS00<@Q0aS24800PQ201448@Q22488@PaS248<Ha24
36<8@PaS48@HaQ247>LYBT8@009F]@06IcUS65JeDY@]Jb480QBU00H@Q0aS
24848@Q21242248212400`Q21248@P03248020aS2488@PQ21248@PaS48@2
36<00`Q236<@Q00336<45:D00aS648@DY@0448@00`aS2488@P03248336<0
0`Q236<48@0224800`aS48@<H`0236<00a2436<<H`0236<010Q236<<H`Q2
0a240PaS0Q2400H<Ha2448@U:Cg_AS42Kg/00dHa<H`<H`0248@236<22480
0`@Q24848@0324800`aS2488@P0312400`Q236<8@P0536<00a245:DDY@02
6<H28@P011S65:D<H`Q20`aS1A2400@HaQ2436<8@P<<H`<@Q0045:D@Q0aS
36<2248236<248@01aBU48@HaRDY;F]:DTic009BU08icP09:DXQ23W>E[EN
mdHa9BT8@PaS008DY@8U:@035:D<H`0000@48@<8@P<48@0324848@@Q00T4
8@03248<Ha24008@Q08DY@049BTYBSF]<H`3;F/013F]>LhmkcW>0SF]00Di
cSg_?NlmkcW>00924004AS52448@@Q02AS4023g_>LhicSg_AS4mkcW>?Nl7
@Q000cg_>Lhmk`03>Lh2?Nl01d8@AS56<D8@?Nm243g_0096<@05@Q0mkcg_
>Lhmk`02@Q000dHa?NlicP02?Nl00cW>@Q16<@02BU82@Q02AS43BU83AS45
@Q000dicBU9:DP02CW<00d8@?NlicP02>Lh00cg_>LhicP02=Jd00cW>=Jdm
k`06@Q02?Nl3>Lh3?Nl00cW>?Nlmk`02>Lh3=Jd6>Lh2?Nl2>Lh2?Nl2>Lh0
23F]>Li2448@?NlicSF]>Lh2?Nl01CW>=Jde[CW>?Nl00T8@0Sg_00<icSg_
>Lh00SW>0SF]00PmkdYBCW=:DTHa@Q0mkd8@0THa00=:DTicBU800T8@00<m
kd8@BU800Tic00I:DTHaCW=>LdYBCW<4BU8014HaBU9:DTYB14Ha0T8@00=6
<D8@AS400THa0dYB00A6<D8@@Q16<@9:DP05AS5:DTicDYAF]@02DY@1CW<1
>Lh00003124000@Q00L48@06000<Hbe[E[DmkbDY0c6<0be[0bU:0be[0bU:
00<]Jc6<<H`00c6<0SF]0S6<0RDY00@YBRe[<H`]J`<YBP<]J`8YBP04;F/a
S36<=Jd5<H`3;F/00bU:<H`YBP029BT01bU:;F/]Jbe[<H`YBRDY008Q208U
:@04:DXU:B48:DX2<H`02RU:9BTYBRDY:DXLia2436<8@PaS0PQ20P@Q0`Q2
00<<H`@Q24800P@Q0PQ200<48@Q224800PQ210@Q10Q200<48@Q236<00`Q2
00D<Ha2448@@Q0aS0088@P0336<8@PQ200<8@P0436<8@PaS48@236<32480
10aS248<H`aS1@Q210aS00@8@P@Q2488@P8<H`88@P8<H`0F48@8@PQ2248D
YAcW6<HLibU:@Q1BU5JeJeYS65JeBU8YBR485:DHaQ242482124224831240
1@Q21248@PQ212400PQ200@<H`Q224848@88@P@<H`04248<H`aS36<248@0
11BU48@DYAS60QBU11240`aS10Q200<<H`Q236<00`aS10Q200<<Ha2448@0
1@aS00H8@PaS2488@Q245:D248@236<0312436<DYABU9BTmkdHaKg][FT8@
;F/<H`8@Q00336<8@PQ20088@P041248@P@Q248212401@Q21248@PQ21240
0PQ20PaS0`Q200D<Ha246<HDYAS600<Li`035:D@Q12400<8@P0336<DYABU
008@Q08<H`8@Q00336<8@PaS008<H`D@Q00536<8@PQ2248<H`0248@01ABU
48@HaRDY<H`00Tic0U:D00dicSF]:DXLicF]E[ENmdHa7>L8@PaS48@DY@02
9BT01A2436<48@@Q248010@Q00@8@P@Q1248@P848@0300048@@Q00@48@05
00048@Q2248<H`0348@01QBU6<HU:Be[<H`e[@8aS003=JdaS3W>008icP03
=JdicSW>00@icPE24004AS52448@?Nl2>Lh01D8@?NlmkcW>?Nl01D8@13g_
1CW>00@mkd8@AS56<@924003?Nm2448@00=2400<?NlicSW>@Q16<D8@?Nli
cSg_>Lhmkd8@0dYB0d8@00Q6<DicBU96<D8@AS5244Ha148@0dYB00ABU4YB
@Q0mk`8e[@<mk`<e[@8icP8mk`05@Q16<D8@@Q0mk`04>Lh01Cg_>LhicSW>
?Nl013W>0SF]00LicSF]>LhicSF]>Lhmk`02>Lh4?Nl4>Lh0248@AS4icSW>
=JdicSg_@Q03>Lh013F]?NlmkcW>0cg_13W>00@e[CW>@Q16<@9>L`92408m
k`A:DP96<@03@Q0mkdHa00M:DP03CW=:DTic00M:DP03AS52448@0096<@04
@Q0mkd8@BU82AS4014YBCW=:DTHa0T8@00=:DTHaBU800TYB00I>Le:DDYAB
U5JeBU81>Lh000848@0@00048@00124000@Q248000@Q248]JeJe>LhU:Be[
<H`3:DX02Be[9BTYBRU:;F/e[C6<;F/YBP02;F/013F]>Lhe[C6<0Re[00<e
[C6<;F/01Be[00<aS2e[:DX00RU:0cF]0c6<00<e[C6<<H`01C6<12e[12U:
00L]Jc6<<H`e[Be[:DXQ20079BT02RU:<H`aS36<:DXU:Be[9BTHaPaS0PQ2
0P@Q10Q20P@Q10Q210@Q0PQ200D48@Q22488@P@Q00<8@P041248@PQ236<2
5:D26<H0112436<8@PQ20PaS0`Q20`aS00D8@Q2448@@Q1BU008<H`D8@P8<
H`<8@P<<H`05248<H`aS36<8@P0236<01`Q236<8@PQ248@HaQ240088@P06
48@HaPaS6<HQ248@0V]J00IJeSg_8@PQ21cW6<H248@236<7248010@Q2484
8@@Q0PQ200H<H`Q224848@Q2124224801PaS48@@Q0aS48@<H`<@Q08DY@@H
aP035:D@Q12400H8@P031248@PQ200<8@P0536<8@PQ2248<H`0348@011BU
48@DYABU0Q240`aS0`Q200H<Ha2448@8@Q248@P2;F/28@P02bU:@Q0icV<H
Kg]>LcW>36<48@Q212401PQ20`aS0PQ20P@Q10Q21@aS00<8@PaS5:D01ABU
00@@Q0Q2248<H`8DY@0:48@DYAS65:D@Q0aS48@DYA2436<448@25:D236<0
1@Q2124@Q1BU6<H00QBU00`@Q2DY?Nm>LfmkLiag_G>LG_MS648@;F/29BT0
1C6<;F/Lia2436<00PQ20PaS00@@Q1BU48@8@P<48@88@PD48@0424848@@Q
000612400`Q236<@Q00336<26<H012e[=JdicSF]0Re[00De[CW>>LhmkcW>
008mk`04@Q0mkcW>>Lh2@Q000dHa?Nlmk`03?Nl00d8@?Nlmk`02@Q02AS42
?Nl0148@>LhicSW>0T8@00DmkcW>@Q0mkd8@008icP05?NlicT8@AS5:DP02
AS45@Q02?Nl01d8@?NlicSW>@Q16<Cg_008icP03?Nm:DTYB009:DPI6<@04
BU9243g_@Q05AS400dYBAS5:DP02BU80248@?NlmkdHa@Q0mkcF]>Lh3?Nl2
>Lh01Cg_@Q12448@?Nl0148@0SW>00<mkd8@@Q000Sg_0SW>00DmkcF]=Jdi
cSg_00@icP04AS5>LdicAS42?Nl014YBAS5243W>0Sg_0T8@00@mkcW>?Nm2
408mk`8e[@03>LhmkdHa00<mk`<icP07?NlicSF]>LhmkdHaCW<00TYB00M>
LcW>>Li244HaDYA>L`02@Q02?Nl0148@AS5:DTic0TYB00M>LdHaAS56<DYB
CW=:DP02AS42BU8014Ha@Q1243g_0d8@00A6<D8@AS5240=6<@03CW=:DT8@
0092409:DP=6<@05BU9BU4icE[E>L`01=Jd0000300048@@Q00P48@0536<]
JeJe>LhQ2002<H`00be[:DXYBP04:DX01Be[<H`e[Be[:DX00Re[0SW>00<a
S2e[;F/00c6<0Re[00@aS2e[:DXYBP8]J`079BTYBRU:<H`icSF]<H`00Re[
0S6<00@]Jc6<<H`aS0D]J`06:DXU:BU::DX]JcF]0c6<00@YBRDY9BTQ208U
:@0@:DXQ22489BTYBS6<=Jd]JbU:9BTYBR486<H<H`Q236<4124224801P@Q
2488@P@Q24848@<8@P031248@PQ20088@P848@L8@P0648@DYA246<HDY@aS
0PQ200<<Ha2424800PQ20PaS00<@Q0aS36<00Q2400<DYA2436<00PQ200<4
8@Q224800`aS00D8@P@Q248<Ha2400@<H`88@P<<H`88@P0C36<@Q1BU48@8
@PaS48@DYA247>LYBTYBKg][FU[F?NlLib486<H00QBU00<@Q0aS24800PaS
0PQ200@48@Q21248@P<48@<8@P0636<8@P@Q24848@Q20PaS00@@Q0aS36<<
H`<@Q08DY@066<HDYAcW7>LHaQBU0PaS0PQ200@48@Q224848@88@P@<H`D8
@P8@Q0065:D@Q1246<HDYA240PaS00@@Q0aS2488@P8<H`0:48@<H`Q248@Q
236<;F/U:B48<H`2?Nl025kgLia:DSF]24848@aS124324801`@Q2488@PQ2
36<@Q0Q200<48@<8@P<<H`0348@<H`Q2008<H`8DY@8HaP<@Q00<36<@Q124
48@DYA245:DHaQBU48@<Ha240QBU00<@Q0aS48@011240PaS00D48@Q236<D
YAcW00<DY@0B:DY244icLia_NgNmKg]NmfLi?NlYBQcW:DXe[Be[6<H8@PaS
0PQ200H@Q0aS5:DDY@aS24821242248512400`Q21248@P0812400`Q236<@
Q00248@01aBU6<HHaRU:<H`icSg_00<aS003>Lhmkcg_00@icP04?NlicSg_
?Nl2@Q000cW>?Nlmk`02@Q000cg_>Lhmk`03AS40148@?Nlmkcg_0SW>0T8@
00=6<Cg_?Nl00Sg_0cW>0cg_0T8@0THa00=243g_@Q000d8@00<icSg_?Nl0
0SF]00a244Ha@Q0mkcF]>Li6<DYBCW=:DTHa@Q03AS400dYBAS524002@Q02
AS42@Q04AS400dicBU924002?Nl2@Q0013g_>LhicSW>0Sg_0SW>00Pmkd8@
@Q1243W>@Q0mkd8@13g_0T8@0Sg_0cW>0cF]00HicSg_=JdicSF]@Q02CW<0
2DYB?Nlmkd8@AS5243g_=Jdmk`02@Q04?Nl00d8@?NlaS002=Jd01cg_@Q12
43g_@Q0icSg_00<icP04<H`icSg_AS42CW<01DHa@Q0mkcW>@Q000dYB0Sg_
00Q243g_@Q16<DYBCW=:DTHa0TYB0THa00A:DTicBU96<@9:DP04AS52448@
?Nl5@Q000dHaBU924002AS43BU8014Ha?Nm244Ha0TYB0THa0Tic0U:D0DYB
0C6<00001@@Q00048@@Q000010@Q00P000@Q248]Jdic=JdLibDY0be[00<Y
BRe[:DX00Re[00HYBRe[<H`aS3F];F/3:DX013F]<H`]Jc6<0SF]00@aS2U:
:DXYBP<]J`@YBP8]J`<aS003;F/aS36<00@aS005=JdaS3F]<H`]J`03:DX4
<H`2;F/4:DX29BT3:DX02b486<He[D8@AS4icR489BTQ21S65:D010Q210@Q
00H8@P@Q1248@P@Q248312401`Q21248@PQ21248@P@Q00<8@PD<H`8DY@04
48@<H`Q236<3248236<248@25:D248@010@Q248@Q1BU0QS60PaS1@Q200D4
8@Q22488@Q24008<H`0448@<Ha2448@336<00a2436<<H`0436<04@Q236<<
H`Q25:DQ23F]DYA>LcW>9BT<Ha247>LQ21S65:D01@Q200H<Ha242488@P@Q
2482124324800`@Q2488@P0524801ABU48@HaQBU48@00`aS00LDYA246<HQ
22DY8@PHaP0236<2124424800`@Q2488@P0324801PaS1248@PQ236<DY@<<
H`8@Q0095:DHaQBU5:D<H`Q236<8@PaS008@Q0055:D@Q1S67>LaS002?Nl0
2TYBAS4icS6<;F/U:CW>AS4]JaS60P@Q00@<H`@Q1248@P8<H`03248<H`aS
008<H`848@0424848@Q2248236<4248636<448@01QBU6<HHaQS65:DHaP<@
Q0035:D@Q12400<<H`@@Q0<8@P03124<H`aS00<@Q0055:DU:DHaF]IkgP02
Li`2Mkd01W_NF]I6<AcW5:D@Q0<8@P031248@P@Q00<48@0636<DYAS648@<
H`Q21@@Q00<000@Q12402@@Q00<<Ha245:D00a2400XHaQcW<H`icSg_@Q0m
kcF]>Lhe[@@icP03@Q0mkcW>008e[@03?NlicSg_008icP8mk`03@Q0mkd8@
00924004AS4mkd8@?Nl2@Q0013g_>LhicSg_0T8@00<mkd8@?Nl00Sg_0SW>
00Hmkd8@@Q16<D8@AS42@Q0013g_AS52448@13g_0T8@00A6<D8@>LhicP<m
k`924008AS5:DT8@@Q0mkd8@BU92408mk`04@Q16<D8@?Nl7AS401T8@AS56
<D8@?NlicP<mk`03>Lhmkcg_00@icP924004AS5243W>@Q03>Lh4?Nl04SW>
?Nlmkd8@>Lhe[C6<>LhmkcW>@Q16<DYBAS5244HaBU96<@A24003?Nm2448@
009240Dmk`<icP=240<icP03@Q0mkcW>008icP03@Q16<DHa0096<@04@Q16
<DYBCW<2BU82@Q000cg_>Li24002AS43BU82AS43BU82AS42@Q000dHaBU96
<@03@Q03?Nl2@Q02AS400d8@AS56<@02BU801DHa@Q1244icDY@01DYB00=>
Le:DCW<00CW>000212401`0012448@@Q00048@Q200848@0936<YBU:D>LhH
aR48;F/YBRe[00DYBP8]J`8aS005=Jd]JbU:9BT]J`02<H`012e[<H`e[C6<
12e[0bU:00<]JbU::DX00RU:00<]Jc6<<H`0136<00<]Jc6<<H`00cF]0S6<
12U:0c6<00D]JbU::DX]JbU:008U:@<YBP0=9BTYBR487>LaS48@BU8icQcW
8@PLiaS648@00PaS10@Q0PQ210@Q00D8@P@Q24848@Q200@48@0524848@Q2
1248@P0536<01A245:DHaQ2436<01PQ20PaS00L@Q1BU5:D<H`Q236<8@P04
5:D224800`@Q248<H`0324801P@Q2488@PQ236<@Q0<<H`0448@<H`aS2484
36<00a2436<<H`0224803`aS248HaR48=JeF]Dic=JdQ20aS5:DLib487>LD
Y@02248010aS1248@PQ20PaS00D8@P@Q1248@P@Q00D8@P041248@PQ22482
36<011245:DDYABU0Q240PaS0Q2400DHaR488@PQ21S6008<H`031248@P@Q
0088@P848@88@P0336<8@PaS0088@P03124<H`aS008@Q08<H`<@Q08HaP8@
Q088@P8<H`<@Q00836<DYAcW;F/mkd8@AS52408e[@06;F/U:CF]@Q0YBQS6
0P@Q1@Q200<<H`Q224800PaS0`Q200<48@Q224800`Q200<<H`Q224800PQ2
0`aS00@8@PaS48@DY@8@Q0045:DHaQS65:D248@25:D348@336<248@00`aS
48@@Q00236<324804@aS48@<HaBU6<HU:DYBG_MkgWNmKg]cW7NmOomF]D8@
7>L00Q240`Q21@@Q0PaS00@HaQBU36<<H`P48@0324848@@Q00D48@040008
@PaS48@25:D236<27>L01SF]>Lhmkd8@?NlicP8e[@<icP<mk`8e[@LicP03
@Q0mkcW>00924004AS52448@?Nl2@Q001Cg_>LhicSW>?Nl00d8@00@mkcW>
>Lhmk`<icPA24003AS5243g_00A24003>Lhmkd8@008icP04@Q16<D8@?Nl2
>Lh013g_@Q12448@0dHa0Sg_00=244HaAS400T8@0THa00<mkd8@@Q000THa
00=244HaAS400d8@00A6<D8@>LhicP8mk`DicP08?Nle[CW>?Nm244Ha@Q0m
k`8icP04?NlicSW>>Lh2?Nl3>Lh013g_=Jde[C6<0cW>00HmkdHaAS56<D8@
AS42BU800d8@?Nm24002?Nl3@Q000dHa?NlicP02>Lh00d8@>LhicP02>Lh0
0d8@?Nlmk`02>Lh2?Nl013W>=JdicT8@0dHa0d8@00I6<DYBBU9:DT8@>Lh2
?Nl00d8@AS5:DP02BU83AS42BU82AS40148@AS52448@0dHa00=243g_?Nl0
0cg_0THa00Y244Ha@Q16<DYBCW=6<D8@AS5:DP9>L`07AS5:DTYBBU9>Le:D
BU800CW>0000100012448@001P@Q00L000Q2:DY:DS6<7>LU:@02:DX00be[
<H`]J`02:DX01RDY:DX]JbU:<H`]J`8YBP8U:@05:DX]Jc6<<H`]J`02<H`0
1Re[:DX]Jc6<=Jd]J`8YBP04;F/YBRe[:DX2;F/3<H`2;F/0136<=Jde[CF]
0S6<0be[0RU:00<]Jc6<<H`00be[0S6<0Re[00hYBRDY:DXYBRe[9BTLic6<
@Q1F]E:D<H`YBQS60QcW00<@Q0aS24800PQ200@48@Q22488@P848@050004
8@@Q1248@P02124224821245248236<25:D01Q245:DDYABU48@<H`<8@P8<
H`8@Q0035:D@Q124008<H`051248@PQ2248@Q0035:D236<7248736<35:D0
0`aS2488@P0224802AcW8@PHaPaS1248@QBU48@HaP027>L02AS648@@Q124
5:D@Q0aS248<H`0324801`@Q248<H`Q236<8@P@Q00T8@P041248@PQ22482
48@25:D248@336<00a246<HHaP027>L03ABU48@@Q0aS1248@P@Q24848@Q2
124<H`Q200<<H`0624848@aS36<DYA240`Q200<48@aS36<00Q2400@<H`Q2
248<H`8DY@8<H`0448@]JcW>DY@2JeX01fmkHaQJeU[F>Lh]Jb48008U:@06
7>L@Q0Q224848@aS0Q240PaS1@Q200@48@Q212448@88@P8<H`0324848@@Q
00<8@P051248@PaS36<DY@026<H25:D248@00aS65:DDY@0248@336<00a24
36<@Q0035:D0112436<8@PQ20`aS00T8@PaS5:D@Q248>Li>LfmkJeX00gNm
00Aooe:D?NlHaP8@Q0L48@080008@P@Q48@LiaS65:D8@PX48@0300048@@Q
00848@88@P8DY@046<H@Q1245:D28@P01CF]>Li244Ha@Q000SW>00@e[CW>
>LhicP8mk`8icP03=JdicSW>008e[@04>Lhmkcg_?Nl2@Q03?Nl0148@AS52
43g_0THa00A243g_>Lhmk`924096<@8mk`8icP05?Nm2448@@Q0mk`02AS40
1TYB@Q0mkdHa@Q0mk`8icP04?NlicSg_AS42CW<00d8@?Nm24003?Nl4@Q00
1CW>@Q1244YBAS400Sg_00=244HaBU800THa00A243g_@Q0mk`924096<@92
4005?Nm6<D8@@Q0mk`02>Lh00cg_>LhicP02>Lh4?Nl00cW>@Q0icP02=Jd0
0cW>?NlicP02>Lh023g_@Q0mkcg_>Lhe[C6<>Lh4@Q001DHaBU9:DTicBU80
1DHa0d8@0Sg_0SW>0T8@00DmkcW><H`e[Cg_00924003?NlicSW>008mk`05
>Li244HaAS524005AS4024YBAS5>LdYBAS5243g_BU82AS4014YBAS5:DTHa
14YB0THa0T8@00A6<DYBCW=6<@924003AS5243g_0092409:DP03@Q16<D8@
009:DP03CW=:DTHa009:DP03CW=:DTYB00=6<@5BU05>L`4icP0010@Q00<0
00@Q124010@Q00L8@R48AS4e[AcW9BTYBP03;F/3:DX29BT01BU:;F/]Jc6<
:DX00bDY0Re[00DaS2e[;F/]Jc6<00<]J`04<H`]Jbe[9BT2:DX29BT00bU:
;F/aS003<H`3;F/0136<=JdaS2e[0S6<0Re[0RDY00@YBS6<<H`]J`8YBP8a
S08]J`0>:DXU:BDY:DX]Jb486<H]Jd8@F]IBU2U:9BTLi`8HaP075:D8@PQ2
1248@P@Q24800P@Q0PQ20`@Q00@8@P@Q1248@P<48@H8@P8<H`0348@DYABU
008DY@8<H`@8@P<<H`0348@<Ha24008<H`@8@P0336<@Q124008DY@0348@<
H`Q200<8@P0436<8@PaS248536<01A245:DDYA2436<010Q200TDYAcW5:D<
H`@Q248@Q1BU6<H00QcW0QBU00H<Ha2448@@Q0Q236<324801@@Q24848@Q2
36<00`Q200@48@Q22488@P848@<8@P8<H`88@P8@Q0035:D@Q0aS008<H`05
248<Ha245:DLi`036<H011BU36<8@PQ20P@Q00D8@P@Q248<H`Q2008<H`<8
@P05124<Ha245:D@Q00324800`@Q36<<H`0248@030aS1248@PaS6<HDYA24
36<@Q2e[?Nm>L`=_N`06HaQF]E[F>LhYBQcW0RU:00<Li`aS24800`Q200<<
H`Q236<010Q200<<H`@Q24800P@Q0`Q200<<H`Q2248010@Q0PQ200<48@Q2
48@00QS61ABU00@@Q1BU48@@Q08<H`0448@<H`aS36<248@011BU48@@Q0aS
0PQ20PaS0Q2400l<Ha2448@LicW>BU9_Nf]JLiakgWNmOomBU3W>6<H00Q24
00<8@P@Q124010@Q0`Q200D@Q1cW7>LHaPQ200P48@0300048@@Q00848@06
00048@Q236<DYAS60QBU0Q2400HQ22DY=Jdmkd8@AS42?Nl01cW>=Jde[Cg_
>LhmkcW>008e[@03<H`icSW>008e[@8icP04?NlicSW>@Q03?Nl5@Q001DHa
@Q0mkcW>?Nl00T8@00M6<D8@?NlicSg_>Lhmk`03@Q0013g_@Q1:DTYB0Sg_
0T8@00<mkcW>>Lh00cW>00M:DTicBU8mkcW>?Nm24002>Lh3@Q001SW>?Nlm
kdYBAS52408icP0<?Nm:DTHaAS5243g_@Q0mkd8@?Nm244Ha0T8@00@mkd8@
@Q12408mk`03>Lhe[CF]00DicP8mk`8icP03?NlicSW>008e[@8icP8mk`05
>Lhmkd8@?NlicP02<H`2?Nl014Ha@Q12448@1DYB0THa00=244Ha@Q000d8@
00TmkcF]>Lhmkd8@>LhaS2e[>Lh00T8@00DmkcW>>Lhmkd8@00<icP03@Q1:
DTHa00I6<@=:DP04@Q0mkd8@@Q05AS400dYBAS5:DP03AS42@Q000dHa@Q1:
DP02BU8024Ha?Nlmkd8@?Nm244HaBU82AS400d8@AS5:DP02BU800dHaBU9:
DP02CW<2BU82AS400dYBCW=:DP01>Lh0000300048@0000<48@0300048@@Q
00848@05248U:DYB=JdQ2003:DX2;F/01BU:9BTU:BDY;F/01RU:00<U:BU:
;F/00bU:0Re[00HYBRe[;F/e[C6<;F/3:DX2<H`022e[:DXYBRe[<H`e[C6<
:DX3;F/0136<;F/YBRU:1Be[0RU:00@]JbU:<H`icP8aS08YBP0=;F/YBRU:
:DXaS2U:9BTaS3F]E[ES64YB=Jd00QcW00<Q21cW5:D00PaS00<8@P@Q1240
0P@Q00<8@P@Q12400P@Q0`Q21P@Q00@8@PaS48@@Q08<H`0448@<Ha245:D2
6<H02ABU36<<H`aS248<Ha245:D@Q00236<32482124010Q21248@PQ20PaS
2@Q200D<Ha2448@@Q0aS008@Q08DY@0348@8@PaS00<<H`88@P8@Q0035:D@
Q0aS008<H`0348@DYABU00<@Q08<H`L8@P848@03248<H`Q20088@P<<H`04
24848@@Q1245248236<011BU6<HDY@aS0PQ200<@Q0aS5:D01AS600<LiaBU
48@00PQ20P@Q0PQ20`aS10Q200<<Ha2448@00PaS10Q20Q240PaS0PQ20`aS
00h8@Q245:De[DYBHaQg_FmkMkecW7_NOom6<C6<0Q2400@DYA242488@P<4
8@88@PD48@88@P<48@0324848@Q200X8@P0336<8@Q24008Li`065:D@Q0aS
48@HaQBU0Q240PaS00<8@PaS36<00PaS0Q2400<DYA2424800`aS00/@Q0Q2
36<DYAcW6<HLibDY=JeBU5Je009S609F]@06<H`U:ABU36<@Q0Q210@Q00D8
@P@Q12448@Q200D<H`0324848@@Q00/48@05248<Ha247>LHaP025:D01A24
5:DU:Be[>Lh00cF]0cg_0SF]00LicT8@?NlicSF]>Li24002>Lh013F]>Lhi
cSg_0SW>00<mkd8@@Q000cg_0T8@1DHa0Sg_00]243g_AS56<D8@?Nle[CW>
?NlicSg_009240I:DP0@AS4mkcW>?Nm243W>?NlicT8@AS5:DT8@>Lhe[CW>
AS42BU83@Q000dYBAS56<@03@Q0014Ha@Q0mkcg_0T8@00DmkcW><H`icSg_
0092408icP8mk`8icP03AS4mkcW>008aS008>Li6<DHa@Q0icS6<=Jdmk`8i
cP8e[@05>LhmkcW>>Li24002BU800d8@>Lhe[@02=Jd01T8@AS56<DHa?Nm6
<@M:DP96<@05@Q16<D8@?NlicP02@Q001cg_=Jde[CW>?NlicSg_008icP03
?NlicSF]008icP03@Q1:DT8@00=24096<@=240=:DP04AS5243g_BU84AS40
2TYBCW=>LdYBAS5244Ha@Q16<D8@0dYB0THa0TYB00E243g_?NlicSg_00A2
4005BU9>LdicBU96<@02BU82AS401T8@AS56<DHaDYA:DP4e[@001@@Q00<0
00@Q12400P@Q00L000Q29BU:DSF]7>LQ20029BT012U:;F/]JbU:0bDY00DY
BRDY:DX]JbU:008U:@03:DX]Jbe[00<YBP039BTYBRe[008aS006=JdYBRU:
:DX]Jc6<0Re[00HU:BU:;F/e[C6<;F/2:DX2<H`2;F/00bU:;F/aS002;F/0
1RU:;F/YBRU:9BTYBP8aS005=JdaS2U::DX]J`029BT02RU:<H`YBR48<H`e
[E[FG_M6<CF]0QcW00@U:AS648@<H`H8@PD48@0624848@@Q1248@P@Q10Q2
00H<Ha2436<8@PaS48@236<25:D00acW5:D<H`03248348@011BU36<<H`aS
0PQ200P48@Q212448@Q236<@Q0aS10Q200P48@Q22488@P@Q36<@Q1BU0`aS
00<DYAS65:D00PaS00<8@PaS36<010aS11240PaS00@@Q1BU48@<H`8@Q08<
H`D8@P848@D8@P05124<H`aS36<8@P02124724801@aS48@HaQBU48@00PaS
00@8@PaS48@@Q08DY@047>LHaQcW6<H248@224821242248236<4248436<0
1A2436<8@P@Q24800`aS10Q210aS00L@Q1BU<Ha:DV<HOom_N`02Mkd017oo
Mke6<C6<112400@<H`Q212448@88@P031248@P@Q00848@0324848@@Q0088
@P<48@88@P0636<8@PQ21248@P@Q10Q200<<Ha246<H00QS600<@Q0aS48@0
0Q2400@DY@aS36<8@P8<H`0548@<H`aS48@DY@0248@324801PaS48@<H`aS
5:DQ208Li`0>:DXicU:DCW=S66LiE[E>Lbe[8@PDYA2436<8@P<48@072484
8@@Q0008@P@Q48@00`aS00<8@P@Q124010@Q00@000@Q124000D48@03248D
YAcW008HaP0648@DYABU9BTYBS6<0SF]0SW>0Sg_00<icSF]=Jd00Sg_0SF]
00<icSg_>Lh00cF]00<icSg_?Nl00cg_00=243g_>Lh0148@0dHa00=243W>
?Nl00Sg_0THa0cW>00<e[Cg_>Lh00d8@00I6<DYBBU9:DTHaCW<2@Q02>Lh0
0d8@?NlicP02?Nl014YBAS4mkcW>0SF]0THa0TYB0T8@0THa0T8@00@mkd8@
@Q12408mk`08@Q0mkcg_>LhaS3F]>Li2408mk`04>Lhmkcg_>Lh3?Nl013F]
<H`aS3W>0T8@00@mkcW>=Jde[@@icP03<H`e[CW>008icP924003AS5243W>
00<e[@03?Nm244Ha00=24003AS5:DTYB00=:DP96<@924003AS5243g_008i
cP04?NlicSW>=Jd:>Lh013g_AS5244Ha0T8@0THa148@00I6<DicBU9243g_
@Q02AS43@Q001TicDYA>LdYB@Q16<@=24096<@0:BU96<DYBBU96<D8@?Nm2
43g_>Lh2?Nl3@Q000dHaBU9>L`02AS400dYBAS56<@02@Q02AS400dYBCW=:
DP01=Jd0000400048@@Q000712401@Q28@Q6<C6<8@P00RU:0bDY0bU:0RDY
00<Q22DY:DX00bU:0RDY0bU:0Re[0RU:00<]Jc6<<H`00RU:0be[12U:00<U
:BU:;F/00S6<00@]JbU:9BTYBP@]J`03<H`]Jbe[008]J`04:DXU:BU::DX5
;F/00bU:;F/YBP05;F/2:DX01T8@DYA>LdHa:DXU:@8Q20036<H@Q0Q20084
8@0324848@@Q00X48@0:24848@@Q1248@PaS48@<H`Q236<248@336<25:D0
112436<<H`aS0QBU00<@Q0aS36<010aS10Q20P@Q00@8@PaS36<8@P848@03
24848@Q200<8@P0436<8@PQ236<348@01@aS248<H`Q236<010Q20PaS0a24
0PaS00@@Q1BU48@@Q08<H`045:D@Q12448@336<224800`@Q2488@P032480
1@aS48@<H`aS124020Q20PaS00P@Q1BU5:D@Q0Q236<@Q0aS0QBU0aS600HL
iaS67>LU:ABU48@224800`aS48@DY@0236<010Q236<@Q1240PaS00H8@PaS
36<DYA2436<2248236<00`Q236<<H`0236<03`Q236<DYA24;F/mke[FKg][
FW_NLiakgWooBU8e[@0348@236<00`@Q24848@031240100012448@@Q0PQ2
0P@Q0PQ200<48@Q224800PQ200<<H`Q236<01`Q200D<HaS67>LHaQBU0088
@P8<H`8@Q005248<H`aS248<H`0224800`aS48@@Q00236<010Q248@<H`aS
0PQ200d<HaBU48@@Q248;F]W>G>LIcU>Lb489BTLi`0248@236<324800`aS
24848@05124010Q21248@PaS10@Q00<8@P@Q12401`@Q00H8@QBU6<HQ21S6
48@25:D00aS6:DX]J`03=Jd5>Lh00cg_>LhicP02=Jd2>Lh01Sg_@Q0icSg_
>Lhe[@8aS003=JdicSg_00<icP03?Nm6<D8@00924096<@03@Q0mkcg_00A:
DP03@Q0mkcW>00@icP05?Nm243g_?Nm6<@02BU800dHa@Q0mk`04@Q002DHa
?Nlmkd8@BU8mkcW><H`mk`02AS43@Q03AS401dYB@Q12448@BU96<D8@008i
cP8mk`03@Q0icSW>008mk`03@Q0mkcF]00<e[@8mk`07>LhaS3F]=JdmkdHa
@Q000SW>00@e[CW>?NlicP8aS08icP03?Nm2448@00924006?NlicS6<=Jdi
cSF]0T8@0THa0dYB00=6<DYBAS400T8@00DmkdYBBU9:DTHa00<mk`=2408i
cP03=JdicSg_00924006>LhmkcW>=JdicSg_0T8@0Sg_00=244HaAS40148@
00E6<DYBBU9:DSg_00A24004AS5:DTYBBU82AS42@Q04AS401DYBAS5:DTic
BU800THa1cg_0T8@0dYB00A>Ld8@@Q0mk`E24003AS5>LdYB004e[@0000<4
8@00124020@Q00D8@RDY@Q0aS1cW008YBP<U:@8YBPHU:@03:DXU:BU:00<Y
BP039BTYBRU:00<YBP03;F/aS2e[008YBP8aS005;F/YBRU::DXU:@03:DX2
<H`012U:9BTYBRU:0S6<00LYBRe[;F/aS2e[<H`]J`04:DX00be[<H`aS003
:DX00be[:DXYBP02:DX2;F/01RU:9BTmkdicDYA240<Q20057>LHaPaS36<4
8@0324800`@Q24848@09124224800`@Q248<H`0436<248@010aS248<Ha24
0QBU00<@Q0Q236<0112400@<H`Q236<<H`@8@P031248@PQ200H8@P071248
@PQ236<8@PaS248010aS00<@Q0aS36<00`Q20PaS00<8@PaS24800`aS00@@
Q0aS36<<H`8@Q0035:D<H`aS008@Q0045:D@Q0aS36<32482124324800`aS
248<H`0248@01@aS24848@Q212401@Q20PaS00@@Q1BU36<@Q08<H`0348@D
YAS600<DY@<Li`048@PLiaBU48@2248236<00a2436<<H`0336<01A2436<<
H`aS24800a2400@<H`Q2248<H`<8@P0548@<H`aS248<H`025:D00be[@Q1J
eP02Kg/2Mkd2Nmh01T8@;F/<Ha245:D<H`88@P051248@P@Q248000041240
10Q212448@Q20P@Q0PQ200<<H`Q224800`aS0PQ20`aS0PQ200D@Q1S67>LH
aQBU0088@PT<H`03248<Ha24008@Q00336<8@PQ20088@P0B36<8@PQ248@H
aPaS48@Q23W>Kg]cW5[FBU8LibDY6<HDY@aS1`Q210@Q00<8@PaS12400PQ2
10@Q00<8@P@Q12400P@Q00T000@Q124000Q2124<HaS67>L00QS600H@Q1BU
5:DHaRU:<H`2=Jd0136<>LhicSg_13W>0cF]0Sg_00=243g_>Lh00SW>00@a
S3F]<H`aS08icP04?Nle[CW>?Nl3@Q002THa@Q0mkd8@?Nm244HaBU9>LdYB
0SW>0SF]00@mkcW>>LhicP<mk`05BU9>LdYBBU8mk`02@Q003DHa@Q1243g_
=Jdmkd8@BU9243F]<H`icTHa00I240I6<@0:@Q0mkcW>>Lhmkd8@?NlicSg_
>Lh2@Q003Sg_=Jde[CF]>Lhmkd8@>Lhe[C6<=Jdmkd8@?Nl6>Lh3=Jd01SW>
?Nm2448@AS52408icP0J=JdicSF]>LhmkcW>@Q16<DYBCW=6<DYBAS5244Ha
?Nm244HaCW=:DTHa?NlicSg_>Li2408mk`<icPDmk`<icP03?Nm243g_008m
k`03@Q16<DHa00=24005?Nm6<DYBBU96<@03?Nl2@Q0014HaBU9:DTYB148@
00A6<DYBAS5:DP96<@03BU96<DYB0096<@8mk`03>Lhmkcg_00<mk`96<@03
CW=:DTYB00924003?Nm2448@00=24003AS5:DTHa004e[@000P@Q00h000@Q
00048@001248@P@Q0008@R48BU8e[B480RU:0bDY00LYBRDY:DXU:BU:9BTQ
20029BT00be[:DXYBP02:DX01RDY;F/]Jc6<;F/YBP@]J`8YBP8]J`03:DXU
:BU:008YBP079BTYBRe[<H`]JbU:9BT00RU:00@]Jc6<<H`aS08]J`8aS005
;F/YBRDY9BTYBP05;F/0136<;F/]JbU:0Re[00De[Be[9BTaS48@009BU008
?Nl]JbDY7>LQ21S636<8@PH48@0324848@@Q00@48@0324848@Q200848@05
248<H`aS36<8@P0236<01A2436<8@PQ236<00aBU0PaS0Q2400<<H`Q236<0
0PaS00<@Q0aS24801@Q210aS0`Q200<48@Q2248010Q20`aS00@8@PaS36<<
H`H8@P0336<8@PaS0088@P0736<8@PaS36<DYAS67>L00QS600<@Q0aS36<0
0Q2400@<H`Q2248<H`88@P031248@PaS008@Q00536<8@PQ2248<H`042480
1`aS2488@PaS48@HaQBU00<@Q008248@Q1S68@P]JbDY8@PLi`8Q20039BTQ
21BU008DY@D@Q00336<@Q124008@Q00436<DY@aS36<2248236<01@Q236<<
H`aS24800`aS00<8@Q2448@00QBU00<LibU:?Nl00U:D00IW>F<HF]IF]Be[
9BT348@236<324800`aS1248@P021242248236<03@Q21248@PQ236<8@PaS
24848@aS48@DYA240088@P0636<8@PaS248<HaS60QcW00H@Q0Q22488@P@Q
248336<224800`aS2488@P0436<4248236<04A2436<<H`Q236<HaR48AS5>
LcW>:DX@Q1BU6<H@Q0aS12400PQ200D@Q1BU6<H<H`Q200D48@@8@P848@05
24848@@Q1240000312401@0012448@Q25:D00R4800PU:AS648@@Q1cW8@Pa
S2e[0S6<0SF]0SW>00DmkcF]<H`]Jc6<008icP924004>LhmkcW>>Lh2=Jd0
136<=Jde[CF]1CW>00<mkd8@AS400THa0d8@00=6<DYBBU800THa00<mkcW>
>Lh00Sg_0cW>0Sg_00@icSg_AS56<@8mk`03AS5>LdHa0096<@03BU9243g_
00Dmk`M24006AS52448@AS5:DTHa0d8@00PmkcW>>Lhmkd8@?Nle[Cg_0d8@
00<icSF]>Lh00Sg_00DicSF]<H`icSg_00924003?NlicSW>008icP03=Jda
S3F]008icP0>=JdicSW>@Q16<DYB@Q0icS6<=JdicSg_>Lhmk`924007AS5:
DTHaAS5:DT8@AS400T8@00A6<DYBBU9:DP<mk`A24003>Lhmkcg_00<mk`8i
cP8mk`03@Q0mkd8@00<mk`A2408mk`924096<@924004>Lhmkcg_?Nl3BU80
0dHa@Q124004@Q02AS401dYBAS52448@AS5244Ha009240=6<@<mk`03@Q1:
DT8@00=:DP05AS4mkd8@@Q16<@02BU800dHaBU924001<H`0000300048@@Q
00H48@0700048@Q28@Q6<CF]8@P00RDY00<Q22DY9BT00bU:0bDY00@YBRDY
9BTU:@HYBP03;F/aS2U:008YBP8]J`8YBP09;F/aS2U:9BTYBRe[:DXU:BU:
00@]J`<YBP8]J`<aS008:DX]Jbe[<H`]JbDY8@PU:@@YBP@]J`8YBP8]J`05
<H`]Jb48<Ha24002DY@00c6<:DXQ20028@P00aBU36<48@02248712400`Q2
1248@P06124224800`aS248<H`0436<224801PaS48@DYA2436<@Q0@<H`05
248<H`aS36<@Q00524800`@Q248<H`0236<7248236<010Q236<8@P@Q0`aS
0PQ200<48@Q224800PQ20PaS1@Q200<<Ha246<H00QcW0QBU0Q2410aS00<8
@PaS24800`Q200<<Ha2448@00PaS20Q20PaS00D8@PaS5:DHaQBU00@<H`05
5:DHaRDY:DXU:@028@P01acW8@PLiacW5:DHaQ2400<<H`<@Q00336<@Q124
008<H`8@Q088@P8<H`04248<H`Q236<3248436<03Q245:DDYB48:DY245:D
E[E[FV<HF]I:DRU:7>L248@236<010Q236<<H`aS0`Q200<000@Q24800`aS
0PQ200<<H`Q224800`Q200<<Ha2448@00Q240PaS00H8@PaS36<8@PaS6<H2
7>L01Q242488@PQ21248@P8<H`0724848@@Q36<8@PaS24800PaS0PQ200@<
H`Q22488@P<<H`0524848@aS7>LU:@02BU8013F]8@P@Q1240QBU00/<H`@Q
2488@Q246<H@Q0aS24848@Q200<48@@8@P`48@88@P0=48@Q22DY8@PLia24
5:DLibDY;F/aS2e[<H`00SF]0SW>00LmkcF]=Jd]Jc6<=JdicP03?Nl4>Lh4
<H`3=Jd013W>=JdicSg_0T8@00I6<D8@?Nlmkd8@AS42BU82AS4013g_>Lhi
cSg_0SW>00<e[CW>>Lh00SW>00U244YBBU8mkd8@AS5:DTHa@Q000THa00=2
43g_>Lh00T8@00<icSg_?Nl01d8@00<mkd8@BU800THa00]243g_@Q0mkcF]
>Li244Ha?NlicSg_00924004?Nle[CW>?Nl3>Lh3=Jd00cg_@Q124004>Lh5
=Jd2>Lh00cF]>Lhmk`02AS4013g_>LhaS3F]0SW>00@mkcW>>Li240E6<@=2
4005?Nm:DTYBBU96<@02?Nl00d8@?Nm24007?Nl4>Lh2?Nl2@Q000cg_@Q0m
k`04@Q03?Nl01DHa@Q12448@?Nl00cW>00=244YBBU800THa00Dmkd8@?Nlm
kd8@00M6<@I24003BU9243g_008icPA6<@03BU96<D8@008mk`96<@A:DP4m
k`4aS00000D48@0012448@0000H48@06248U:Dic>LhQ22e[0RU:12DY00PY
BRe[;F/]JbU:9BTQ22DY1BU:0be[0bU:00L]JcF]<H`]JbU:8@PU:@03:DX0
1Re[:DXYBRDY;F/aS08]J`039BTYBRU:00@]J`8YBP04;F/aS2e[;F/49BT3
;F/2<H`2;F/012U:9BTYBRe[12U:00dmke:DCW=242e[8@PU:B487>L@Q0Q2
1248@P0212400`001248@P04124010Q21248@P@Q0`Q21@aS00<@Q0aS48@0
0PQ200@<H`Q248@@Q08HaP0<48@<H`Q2124<H`Q236<HaQBU48@<H`@Q0PaS
0PQ200@<Ha2448@<H`@8@P0536<8@PaS248<H`0424800`aS248<H`0436<0
1A2436<<H`Q236<010Q20PaS00<@Q1BU48@00Q2400<<Ha2436<01@aS1@Q2
00L@Q1BU5:D@Q0aS248<H`02248010@Q2488@PQ20PaS00@HaQBU6<HDY@<@
Q00>5:DHaQ247>Le[DHaF]I6<CF]<H`Q21cW5:D@Q0@<H`@DY@0448@<H`aS
48@236<01124248<H`Q20`aS018@Q0Q2124HaRDY7>L<H`@Q36<Lia245:DL
icF]IcU[FV<H@Q028@P00aS65:D@Q00236<00`Q236<8@P0236<2248236<0
1PQ25:DQ22485:D48@88@P0336<8@PQ200<8@P8@Q08DY@0448@<H`aS2483
36<011245:DDYA240PQ20`@Q20Q200<<H`Q224800`Q200<<H`Q236<00QS6
00<@Q0Q212400PaS00<@Q1S65:D00a2400HDYA242488@P@Q248248@011cW
5:D@Q0aS10@Q10Q200<48@Q212400`@Q00<000@Q000010@Q00L8@PaS6<HU
:B487>LHaP025:D01B489BTaS36<;F/00S6<00P]Jc6<>LhicSF]<H`e[CW>
0THa00a243W>>Lhmkd8@?NlicS6<=JdaS2e[=Jd2>Lh2=Jd023W>BU9>LdHa
?NlicSF]?Nl2@Q0014YBAS56<DHa0Sg_00<icSF]>Lh00d8@00<mkcF]>Lh0
0T8@0dHa0TYB00I6<D8@@Q1244Ha@Q02?Nl013W>?Nm243g_0T8@0Sg_00Xi
cT8@AS5243g_AS5>LdYB@Q0e[@8icP06=Jdmkcg_@Q0mkcW>0Sg_13W>00Lm
kd8@?NlicSF]<H`icP04?Nl3>Lh3=Jd00cg_@Q0icP02>Lh00d8@AS524003
>Lh2?Nl2>Lh3?Nl00cW>?Nm6<@02BU83AS43BU801TicAS56<D8@?Nm240<m
k`05@Q0icSg_?NlicP03?Nl4@Q03?Nl014Ha@Q0mkcW>0T8@00M6<D8@@Q12
43g_>Lhmk`02@Q0013g_@Q1244Ha148@00<mkd8@@Q000THa0T8@00A6<Cg_
?Nlmk`=2400:?Nm244HaBU96<D8@?Nm6<DYBAS42@Q0024HaBU9:DTHaBU96
<DYBAS42BU81AS41@Q01;F/000848@0300048@@Q00H48@07248U:Dic<H`Q
22e[:DX00bDY00<]JbU:9BT00be[00@YBRDY9BTYBP8U:@03:DX]Jbe[008Y
BP05;F/YBRU::DX]J`02<H`2:DX00bDY:DXYBP02:DX01BDY:DXU:BDY:DX0
0S6<00<YBRDY9BT00RU:0Re[00@aS2U::DXYBP8aS003;F/U:BDY008U:@03
:DX]Jbe[008]J`05:DX]JbU::DX]J`02:DX012DY:DX]Jd8@0TYB00Q242e[
8@PU:AcW6<H<H`Q20P@Q00<8@P@Q12401`@Q0`Q20P@Q0`Q20PaS00<@Q0aS
48@00`aS0PQ200@DYAS66<HDY@8<H`88@P0336<8@PaS008DY@0548@8@PQ2
248<H`02248010aS48@@Q0aS0PQ200@48@Q22488@P8<H`03248<H`Q2008<
H`0;248<H`aS48@<H`Q236<8@PaS48@<H`0224800`@Q24848@0236<00a24
6<HDY@0248@2248536<010@Q24848@Q20PaS11240PaS1`Q200D<Ha245:DH
aQBU008@Q00336<@Q124008DY@097>Le[DHaE[E6<CF]<H`LiaS6008DY@04
48@<H`aS36<35:D248@236<248@336<00`Q236<8@P0336<02@Q2124HaRDY
7>L<H`@Q48@Li`025:D021cW?Nm[FV]JF]HicQcW8@P26<H0112436<8@PQ2
10aS10Q200D48ABU9BTQ21BU00848@0336<8@PaS00@8@P0436<@Q1S65:D2
48@01@aS248<H`Q236<00aBU00<@Q0aS24800P@Q1`Q200<<H`Q212400`Q2
0PaS00H8@P@Q48@DYAS648@212400`Q248@@Q0025:D00a2436<<H`0248@0
30aS12448@Q248@HaQcW5:D<H`Q2124000848@<8@P848@0300048@@Q00T4
8@03248@Q1S6008U:@0:7>LHaQ2448@U:Be[=Jd]JbU:;F/2<H`00be[=Jdi
cP03=Jd013W>AS5243g_13W>00LmkcF]=JdaS2e[<H`e[@02>Lh2=Jd00cW>
AS5:DP02@Q02>Lh2?Nl00d8@AS56<@02AS42?Nl013W>=JdicSW>0Sg_0cW>
00=244Ha@Q000T8@00I6<DYBBU8mkd8@AS42@Q02>Lh2?Nl00d8@?Nlmk`02
@Q02>Lh0248@AS5243g_AS5:DTHa?Nl2=Jd01CW>=JdicSg_@Q000Sg_00Di
cSg_>LhicSF]008icP05?NlicSF]<H`e[@02>Lh2?Nl2>Lh00cg_>Lhe[@02
=Jd3>Lh2=Jd00cW>@Q124002=Jd01SW>?NlicSW>?Nle[@8icP05?Nm244Ha
AS5:DP02AS40248@BU9>LdYBCW=6<D8@?Nl2@Q06?Nl2>Lh5?Nl2@Q02?Nl2
@Q001Sg_>Lhmkcg_@Q0mk`924005?NlicSW>>Li24003>Lh00d8@BU96<@03
@Q000cg_@Q124002AS42@Q0014Ha?Nlmkcg_1D8@00=6<DYBAS400cg_0TYB
0d8@00E:DTHaAS5244Ha00=:DP03AS5243W>004]J`0000@000@Q12400084
8@0=00048@Q2124000Q2:DYBU3g_9BTaS3F]<H`012U:0be[12U:0RDY00<Y
BRe[:DX00bU:0Re[00<YBRe[;F/00SF]00@aS2e[9BTU:@<YBP03;F/YBRU:
008YBP049BT]Jc6<;F/39BT3:DX3;F/012U:;F/]Jbe[12U:00<U:BU::DX0
0bU:0Re[00daS2U::DX]JbU:8@PaS48@CW=F]D8@=JdYBP029BT011S648@4
8@Q22@@Q0`Q200@<H`Q2248<H`@8@P0336<DY@aS00L<H`8@Q08<H`032484
8@Q2008<H`8DY@0348@<H`Q2008<H`05248<H`aS6<HLi`026<H00aBU48@<
H`0236<4248010aS2488@PQ210aS00H8@PaS48@<H`Q236<248@00`aS2488
@P0836<3248248@236<424802@aS48@<Ha2436<8@PaS248<H`0524801@aS
48@@Q0aS48@00aS60QBU00lQ22DY<H`aS3F]@Q16<F]JLia>Lcg_36<8@PaS
24800a2400<DYA245:D00QBU0a2400@<H`Q236<<H`8@Q08<H`03248<H`aS
008<H`<8@P8<H`0>248DYAS6:DYF]E:D?NlU:@Q236<LibDY8@P@Q088@P8<
H`848@88@P8<H`04248<H`aS48@236<00`Q236<<H`0224801@@Q248<H`aS
48@00PaS0a240PaS00<8@PaS24800`aS0PQ20P@Q00@8@P@Q24848@88@P05
36<8@PQ2248<H`0324802@aS48@@Q0Q236<8@P@Q24848@06248336<01PQ2
12448@Q236<@Q08DY@046<H<H`aS1244248<12401`0012448@Q248@DYAS6
008Q20067>LHaQS67>LYBRe[0S6<00/YBRe[<H`]JcF]>LhmkcW><H`icT8@
0096<@LicP8e[@8aS003=JdmkcW>00<e[@04?Nm2448@>Lh2=Jd2?Nl01d8@
?NlicSg_@Q0mkd8@00@e[@04@Q0e[CF]?Nl2AS401Cg_@Q1:DTYBAS400Sg_
00=6<D8@?Nl01CW>00@mkcW>=JdicP9240<icP03@Q0mkcg_008icP<mk`04
>LhaS3F]?Nl2@Q0014Ha>Lhe[CF]0SW>00<mkcW>>Lh00SW>00<mkcF]<H`0
0cW>0Sg_0SW>0c6<00<e[CW>>Lh00cW>00@mkcW>>LhicP<e[@<icP<mk`05
>Li244HaBU96<@02@Q02BU802DHaBU96<DHaBU9243g_>Lhmk`02@Q03?Nl0
1CW>=JdicSg_@Q000Sg_00a243g_?Nlmkd8@AS5243W>=JdicT8@AS42@Q02
>Lh00cg_>Lhmk`02>Lh00cg_@Q0mk`02?Nl01DHa@Q1243g_@Q000dYB00=6
<D8@@Q000cg_1D8@00<mkdHaAS400THa00M243W>>Li244HaBU96<@03BU80
1THaBU96<D8@AS52404aS00010@Q00<000@Q124010@Q00P8@RU:CW<e[BDY
<H`icS6<1bU:00@]JbU:9BTYBP8U:@05:DXU:BU:9BTYBP02;F/2:DX2;F/0
1CF]<H`]Jbe[:DX00RDY00<YBRe[:DX00RU:0bDY0Re[0RU:00DQ22DY:DXY
BRe[008YBP069BTYBRe[<H`]JbU:0RDY0RU:00<]JbDY9BT00RU:00X]Jc6<
:DXYBRDY;F/YBR48<H`mk`9BU003?NlaS2e[008U:@046<H<H`@Q24821240
0`0012448@04124324800`@Q2488@P03248436<00a2436<8@P03248236<2
48@5248236<01ABU48@@Q0aS24800PaS00@8@PaS48@DY@8HaP035:D@Q0aS
00<<H`H8@P0436<8@PQ2248336<00`Q236<<H`0336<00a2436<8@P0336<0
10Q236<<H`aS0PQ220aS00@48@Q236<<H`8@Q007248<H`aS248<H`Q236<0
10Q200<<Ha2448@00PaS00<@Q1S66<H00QcW00/Q22DY<H`]JcF]@Q16<F]J
Lia:DSF]008<H`0348@8@Q24008@Q0035:D@Q12400D@Q0L<H`<8@P8<H`D8
@P0936<8@Q247>Le[E:DCW<aS248008<H`077>LQ21cW5:D48@Q236<00`Q2
00@48@Q22488@P<<H`03248<H`Q20088@P8<H`0324848@@Q008<H`06248<
H`aS48@DYA2410aS00<@Q0aS36<010Q20P@Q1@Q200<<H`Q2248010Q210aS
10Q20P@Q00H8@P@Q248<H`Q236<324801@@Q2488@P@Q24800Q2400@LiaBU
48@8@P848@@8@Pd48@0624848A245:DHaR481AcW00<U:BU:;F/00Re[0c6<
00Te[CW>@Q0e[C6<=JdmkdHa?Nl01cW>00DaS3F];F/aS3F]00<icP03<H`i
cSg_00@mk`03=JdicSg_00924005>Lhmkcg_@Q0mk`02=Jd0236<>LhicSW>
=JdicT8@AS42@Q02AS400d8@?Nm24003@Q06>Lh2=Jd00cW>?Nlmk`02>Lh0
1Cg_@Q1243g_=Jd00SW>00]243W>>LhaS2e[?Nm244Ha?NlicS6<00@icP8e
[@07>LhmkcW>=JdaS3W>=Jd00Sg_0SW>00<e[C6<<H`00S6<0cW>0SF]0cW>
00De[C6<=Jde[C6<00DicP03?Nm244Ha0096<@924096<@=:DP96<@06@Q0i
cSW>>Lhmkd8@0cg_00@e[CW>>LhicP92400;?Nm2448@>Lhmkd8@AS5243W>
=JdicP02@Q000dHa@Q0icP05>Lh3?Nl01T8@?Nm2448@AS4mk`924005AS5:
DTYBBU924003?Nl013W>@Q12448@0Sg_00A244HaAS56<@924003>Lhmkd8@
00=6<@04@Q1:DTYBBU83@Q01AS41@Q01;F/0000300048@0000P48@06248Y
BU:D=JdQ236<0Sg_0SW>00De[BU::DXU:BU:00<]J`05<H`YBRDY8@PU:@05
:DX01Be[<H`]JbU:;F/00S6<00<]JbDY9BT01BU:00DU:BU:9BTQ22U:00<]
J`059BTQ22DY:DX]J`02<H`01Be[:DX]Jbe[<H`00bU:00DU:B488@PU:Be[
00<YBP0;;F/aS2e[;F/aS2U:9BT]JcF]CW=F]@02DY@01d8@>LhaS1cW6<H<
H`Q200@48@0300048@@Q00848@88@PL<H`06248<Ha2448@DYA240PaS00<8
@PaS36<00PaS00<@Q0aS36<00PQ200<@Q0aS36<010aS00<@Q1BU36<00Q24
00`<Hb48:DY6<F]JHaQ6<Be[248<H`Q2124424800`@Q2488@P0248@536<2
248236<00`Q236<8@P0436<00a2436<8@P02248348@25:D00a2436<8@P02
248010aS48@<H`aS0`Q20PaS00@8@PaS36<8@P8<H`0448@<H`aS5:D27>L0
21BU48@DYBDY<H`mkdYB@Q03>Lh033F]G_Mg_Dic<H`48@Q25:D@Q1BU48@H
aP8Q20069BTLiaS67>LDY@aS0PQ20a2400D<H`Q236<8@PaS00H8@P03124<
Ha24008Li`8DY@@@Q00336<8@PQ20088@P0336<48@@Q00<8@P041248@PQ2
248336<01PQ236<<H`aS24848@<8@P0436<8@PaS36<45:D436<224801P@Q
2488@PQ236<8@P<<H`L8@P8<H`8@Q00536<8@PQ224848@0324800`@Q2484
8@0524800`@Q2488@P0436<248@436<2248812400`0012448@02124020Q2
12448@@Q248@Q1S68@P29BT27>L012DY;F/icSW>0c6<00<e[CW>=Jd00S6<
0SF]0S6<00@icSF]=Jde[@8mk`03>Lhe[CF]008icP<aS0<icP8e[@8icP<e
[@03>Li243g_008mk`8icP04=Jdmkcg_@Q03>Lh0136<=Jde[CW>0T8@00=6
<D8@?Nl00Sg_00DicSg_AS5:DT8@00<icP04=JdicSW>>Lh2?Nl2>Lh2=Jd0
0cg_>LhicP03>Lh013F]?Nlmkcg_0cW>00<mkcW>?Nl00Sg_0cF]0Sg_00di
cSF]>LhicT8@?NlicS6<>LhmkcW>=JdaS002=Jd01SW>=JdicS6<=JdicP8m
k`04>Lhe[Be[<H`2>Lh2?Nl00cW>=JdicP03>Lh01Cg_AS52448@AS400dYB
148@00<mkcW>>Lh01SW>00<mkcW>>Lh00Sg_00E244HaAS56<Cg_008icP04
?Nm6<D8@?Nl2>Lh3@Q03?Nl00d8@?Nlmk`02?Nl2@Q03>Lh01T8@AS5:DSg_
>Li240=6<@03@Q0icT8@00<mk`03@Q1:DTYB00A24003AS5243g_00=6<@8m
k`03@Q1:DTYB0096<@924096<@52404]J`001@@Q00d000@Q1248@P001248
@RU:CW<e[BDY=Jdmk`02>Lh01cg_<H`YBRDY:DX]Jc6<008YBP05<H`]JbU:
8@PU:@05:DX01Be[<H`aS2U:;F/00S6<00<]JbDY9BT00RU:0Re[1BDY00@Y
BRe[:DXYBP8U:@03:DXU:BU:00<]J`08:DX]Jbe[;F/YBR48:DXU:@8Q2004
9BT]Jbe[:DX5;F/01c6<:DXQ22e[>Li>Le[F009>L`07@Q0aS2e[8@PLi`aS
248020@Q00<8@P@Q24800PQ20PaS00H8@PaS36<<Ha2436<348@010aS2488
@PQ20PaS0Q2400<<H`Q2248020aS1A2400X<HacW;F]6<G>LHaQ6<BDY248<
H`L8@P031248@PaS008@Q088@P<<H`<8@P0536<8@PQ2248<H`0248@02PaS
248<H`Q236<@Q0aS5:DHaQ240PaS00<48@Q236<01@aS0PQ20`aS00@8@PaS
36<@Q0@<H`035:DLiaS6008DY@0848@YBS6<@Q1:DT8@<H`e[@8icP09HaQc
W4YB<H`8@P@Q48@<Ha24008DY@067>LQ21cW7>LHaQcW0Q240PQ20a2400H<
H`Q22488@PaS124624800`aS48@DY@027>L00a2436<<H`0248@01@aS2488
@PQ236<00`Q200<48@Q212400`Q21PaS10Q200@48@Q22488@P8<H`0548@D
YABU5:D@Q00336<01@Q236<8@PQ212400PQ200<48@aS36<00PaS00<48@Q2
24801PQ210aS00<8@P@Q24800PQ210@Q0`Q20P@Q0`aS0PQ220aS10Q210@Q
00<000@Q12401`@Q0PQ200<DYAS68@P00RDY00HQ21cW9BT]JcF]<H`2;F/0
0c6<=JdicP06<H`3>Lh2<H`023F]>LhicSF]>Lhe[C6<=Jd2<H`01CF]>Lhi
cS6<=Jd00SW>00<e[C6<<H`01Cg_00HicSF]>LhicSg_@Q02>Lh2<H`3>Lh0
2D8@?Nm2448@?Nm243g_>Li24002AS400d8@>LhicP06>Lh2?Nl2=Jd3>Lh0
0cF]>LhicP03>Lh2?Nl013W>=JdicSW>13g_00<icSF]>Lh00cW>0SF]00<i
cSg_>Lh00cF]00<mkcW>=Jd00S6<0SF]010icSF]=JdaS3W>?Nm243F]<H`]
Jc6<=JdicSg_>Lhe[@8icP8e[@03>Lhmkcg_0096<@=:DP96<@05?Nm2448@
@Q0mk`03>Lh00cg_>LhicP04>Lh2?Nl4@Q001SW>=JdicT8@AS4mk`8icP04
?Nm2448@?Nl3>Lh00d8@?Nlmk`03?Nl01d8@>LhicSW>?Nm6<D8@00@mk`07
AS52448@?Nm243g_>Lh00T8@00E6<D8@@Q1243g_0096<@04@Q0mkcg_AS44
@Q02BU82AS43@Q01AS41@Q01<H`0000500048@001240000612401PQ2:DYB
U3g_8@PYBP8e[@8icP04=Jd]Jbe[:DX2;F/00c6<;F/]J`06:DX29BT012U:
;F/aS2e[0bU:00@]JbU::DXYBP8U:@0::DXU:BU:9BTYBRDY8@PYBRe[<H`2
:DX012DY:DXU:BU:22e[0RU:00DQ21cW9BTU:BU:00<]J`8aS003;F/YBRU:
008U:@8]J`04@Q1BU5[FE[D2BU801THa>LhaS12436<000@48@0600048@@Q
1248@P@Q0`aS0`Q200L<H`@Q48@DYAcW9BTLi`0248@336<00`Q236<@Q002
48@436<3248011BU7>LQ21S60QBU00@Q22DY;F/]J`8aS005=JdmkcW>:DXL
i`0236<22482124010Q2124<H`Q20`aS10Q20PaS0PQ20PaS00<@Q0aS36<0
0Q2400H<H`Q236<@Q1S67>L56<H00aBU36<8@P0336<01@Q236<<H`aS2480
1PaS00<8@P@Q5:D00QcW00TDY@aS36<Q22DY@Q1>Le:DHaP00UJe00iBU3F]
9BTe[DHaCW=6<AS648@<Ha248@PU:B480RU:00H]JbDY8@PLiaBU48@436<0
1@Q236<<H`Q248@00`Q20PaS1PQ200@@Q1BU48@<H`T8@P031248@PQ200<8
@P<<H`88@P0636<8@PaS36<@Q0aS10Q200@<H`Q236<8@P8@Q0035:D@Q0Q2
008<H`H8@P0336<8@PQ200D8@P<<H`04248<H`Q236<2248010aS2488@PaS
1`Q200TDYAS66<HDY@aS248<H`Q236<00`Q21PaS0PQ220@Q00X8@P@Q1244
8@001248@P@Q36<@Q08Li`038@PU:BDY008Q2006:DXaS3F]=JdaS3F]0S6<
12e[00He[C6<<H`icSg_>Lh2<H`00cW>@Q0mk`02=Jd01CW><H`aS2e[<H`0
1CW>00<mkcW><H`00SF]0T8@00<mkcW>>Lh00cW>00daS3W>?Nm243g_>Lha
S3F]>Li6<Cg_>Lhmk`02AS400cg_=Jde[@02?Nl00d8@?Nm24002?Nl2>Lh0
0cF]<H`icP02@Q001Cg_<H`e[CW><H`00cF]136<0SF]0SW>0Sg_00=243g_
>Lh00SF]00<icSg_>Lh00cF]0cg_00<icS6<=Jd00c6<00@e[CW>>LhicP8e
[@8icP04=JdicS6<=Jd2<H`00cF]?Nlmk`02@Q02>Lh013F]<H`icSW>1d8@
00HmkcW>@Q1244Ha@Q03?Nl00cW>=JdaS002>Lh9?Nl01T8@>LhicSW>@Q16
<@=24003?NlicSg_00=24005>Li2448@?NlicP02?Nl013W>=Jde[CF]148@
00@mkcW>>Li24096<@E24008?Nm2448@?Nm243g_AS5240=6<@04@Q0icSW>
@Q04BU800d8@AS56<@02AS41<H`000/48@08248]Je:D>LhQ22U:<H`e[@8i
cP05<H`]JbU:9BTYBP02;F/00c6<;F/YBP029BT00bU:;F/U:@029BT022U:
<H`aS2e[:DXQ22DY:DX2;F/01BDY8@PYBRU:9BT00R480RU:00<U:BU:;F/0
0Re[00DQ22DY9BTU:BU:00<]J`03:DX]JbU:008aS004:DXU:B488@P29BT2
:DX00be[<H`aS002;F/012DY:DXYBRU:0Re[00A245:DE[EF]@9:DP06AS4e
[BU:48@<H`Q20P@Q00<000@Q12400`@Q2PQ200P<HaBU8@PU:AcW5:D<H`Q2
10aS0a240`aS01D8@PaS12448ABU7>LU:B4848@DYB489BT]Jc6<;F/e[CW>
?Nle[BU:8@P00PaS00<8@P@Q24800P@Q0PQ21@aS0`Q200@<H`Q22488@PH<
H`0348@<H`aS008<H`8HaP067>LHaQBU6<HDYA241`aS00D8@PaS36<<H`Q2
00@<H`88@P0=5:DLiacW5:D8@Q248@PU:Cg_CW=JeV<HE[D00U:D00PaS248
=Je:DU:D@Q0DY@aS0Q2400<Q22DY8@P012U:00@Q21cW48@@Q0<<H`04248<
H`Q2248336<424800`aS2488@P0224800`aS48@DY@0236<00`@Q2488@P03
24800`@Q2488@P0224801P@Q36<8@PQ236<8@PD<H`04248<H`Q236<32485
36<011245:D@Q1240PaS20Q200<<H`Q224805@Q200<<H`Q248@00QBU00DH
aQBU36<<H`@Q00<8@P0536<8@PaS36<@Q00236<010@Q2488@PQ23@@Q0PQ2
0PaS00<HaR489BT00RDY0R4800@YBRe[>Lhe[@<]J`03<H`e[Be[008]J`<a
S008=JdmkcW><H`e[CW>@Q0icP<e[@8aS004;F/e[CF]=Jd3>Lh023g_=Jda
S36<=Jdmkd8@?Nl2>Lh013F]>LhaS36<0SW>0Sg_00he[C6<=JdicSg_@Q0i
cSg_@Q0mkcW><H`e[Cg_0d8@0SW>00HmkcW>>Lhe[C6<>Lh2?Nl00cW><H`a
S003=Jd01C6<=Jde[CF];F/00S6<00De[CW>>Lhmkd8@008mk`04>Lhe[CF]
=Jd2>Lh3=Jd3>Lh4=Jd01Be[<H`aS3F]>Lh00SF]0SW>00@e[CW>=Jde[@@a
S003?Nm2448@00<icP<e[@<mk`05>Li2448@AS524002>Lh01D8@AS52448@
>Lh00Sg_00PicSF]<H`e[CW>?Nm243g_13W>0Sg_13W>0d8@0cg_00TicT8@
@Q1243g_>Lhmkd8@?Nl00SW>00I243W>=JdaS3F]?Nl3@Q02>Lh2?Nl014Ha
@Q0mkcg_0T8@0Sg_0d8@00Pmkd8@@Q16<D8@AS5:DSg_0SW>00A244YBBU92
4096<@924056<@52404aS000014000@Q00048@00124000@Q248000@Q248]
Je[F@Q0Q22U:008]J`05=JdaS36<:DX]J`02:DX01Re[<H`aS36<:DX]J`<Y
BP<U:@03:DX]Jbe[008]J`DYBP03;F/YBR48008Q2008:DXU:BDY8@PU:BU:
9BTYBP8]J`03:DXU:BDY008YBP8]J`8aS08]J`06<H`YBRDY7>LQ22DY12U:
01D]Jc6<;F/aS2DY8@PU:Be[<H`YBRe[>LiBU5[FDYAF]DicAS5242DY7>L0
2P@Q0PQ200<48@Q2248010Q200/<H`Q248@HaQcW6<HDY@aS48@<H`Q2008<
H`0448@DYA2436<5248010aS5:DHaQS60RU:00i6<E:DE[EBU3g_>Lhe[B48
6<HQ22e[9BTDY@@Q0PQ20`@Q1PQ200<48@Q2248010aS00<8@PaS36<00PQ2
00<<Ha245:D00aBU00@Lib489BTYBP8Li`066<H@Q0aS248<Ha242`aS00@8
@P@Q248<H`D@Q003;F/icUkg009_N`0>Oomg_G>LJeY:DT8@:DXQ21cW6<HD
Y@aS48@DY@@U:@8YBP0:8@PLiacW6<H@Q0aS248<H`Q236<2248436<248@2
248212400`aS248<H`025:D011242488@PQ20PaS1PQ200D48@Q2248<H`Q2
00L<H`0348@<Ha2400<<H`05248<H`Q224848@03248248@00`aS2488@P02
248336<2248236<00`Q236<<H`0236<224800`aS2488@P0336<00`Q21248
@P02248736<02A2436<@Q12436<8@P@Q248<H`0212401@aS48@LiaBU48@0
0`Q21`@Q00<000@Q124010Q200D48@Q236<HaQBU008Li`049BTQ22DY:DX2
<H`00be[:DX]J`02<H`00cF]<H`]J`02<H`01BU:<H`e[CW>@Q000cg_0cF]
00DicSg_@Q0e[C6<008]J`05<H`e[CF]>Li24002>Lh3=Jd3?Nl4>Lh023F]
>LhicSg_@Q0mkdHa?Nl2>Lh02SF]>LhaS3F]?Nm243g_>Lhe[CW>0T8@0Sg_
13W>00De[CW>>Li243g_00@icP04<H`]Jc6<<H`3=Jd2<H`2=Jd3?Nl01D8@
>LhicSW><H`01SF]13W>00<mkcW><H`00S6<00De[Cg_?NlmkcW>008e[@03
?NlicSW>00<e[@05>Lhe[CW>=JdicP02@Q02?Nl2<H`01CW>?Nm2448@?Nl0
0T8@00@mkcW>=Jde[@8mk`05AS52448@@Q0mk`02>Lh2=Jd3>Lh5?Nl3@Q02
?Nl2>Lh3AS401Sg_<H`e[D8@AS5:DP924004?Nm2448@?Nl2>Lh01Cg_@Q0i
cSF]>Lh00THa00A243W>>Lhmk`96<@03@Q0mkcW>00<icP8mk`04@Q0mkcg_
?Nl2@Q03AS42?Nl02d8@AS56<Cg_@Q16<DYBAS5244Ha@Q000CF]000;1240
1@aS:DYF]D8@8@P00RU:00@]Jc6<=Jd]J`<YBPD]J`8YBP039BTYBRDY00<U
:@03:DX]JbU:00<YBP04;F/YBRe[:DX:9BT2:DX2;F/2:DX012DY8@PU:BDY
1Re[00<aS2U:9BT00QcW0RDY0bU:0Re[01@aS2e[9BTQ22DY:DXaS2DY<H`m
kdicF]IBU5JeCW=243g_9BTLi`Q21`@Q00<8@P@Q12400`Q20P@Q0`Q20PaS
00L@Q1S67>LLiaBU36<@Q002248020aS248@Q12436<@Q0Q2124324801`aS
48@HaQS69BT]JdHa009BU00<CW<mkcW>>LhQ21S68@PYBRDY5:D48@Q210@Q
0PQ200@<H`Q212448@@8@P@<H`@8@P8@Q0055:D@Q1BU5:DQ20029BT01B48
7>LLiaS648@02@aS00<@Q0aS36<00PaS10Q20PaS0Q2400dDYA24;F/icUkg
Kg]cW7ooMkecW6<HBU9240029BT00aS67>L@Q00236<011S69BTYBR480RU:
00HU:B487>LLiaS65:D236<00`Q236<8@P03248010aS48@@Q12410Q200<4
8@Q224800PaS00@@Q0aS2488@P@<H`88@P031248@P@Q00@8@PT<H`0348@<
H`aS0088@P0836<8@PQ21248@P@Q36<@Q08<H`88@P0336<8@PaS00@<H`<8
@P@<H`@8@P8<H`D8@P041248@PQ2248836<248@524801`@Q248<Ha246<HD
YA2400<8@P<48@0324848@Q200D48@D8@P0548@HaQS66<HLi`038@P012U:
;F/aS2e[0RU:1S6<0be[00<e[CW>@Q0013W>00He[CW>>LhmkcW>=Jd2<H`0
12e[<H`aS36<0cg_00<icS6<<H`00SW>00A243W>>Lhe[@DicP8mk`9240<i
cP<e[@03<H`icSg_008mk`03=JdicSg_00924005?NlicSF]>Lhe[@03>Lh0
13g_@Q0e[CW>0S6<00@e[C6<;F/aS08e[@8aS08e[@8icP<mk`8icP@aS08e
[@03<H`e[CW>00@icP07=JdaS36<;F/e[CW>@Q000Sg_00<e[CW>=Jd00SW>
00@e[C6<>LhicP8e[@8icP08@Q0mkcg_>Lhe[C6<>Lhmk`924004>LhmkdHa
>Lh3=Jd01cg_@Q1:DT8@?Nm243g_008icP8aS003=JdicSW>00@icP8mk`09
@Q0mkcg_?NlicSg_@Q16<Cg_00<icP07@Q16<DHa@Q0icSg_@Q0013g_00/i
cSg_>Lhe[Cg_@Q16<Cg_>Lhe[Cg_00=24005?Nle[CW>?NlicP05?Nl4@Q02
AS40148@?NlmkdHa0d8@00I6<DYB@Q1244Ha@Q01<H`0000500048@001240
000512401P00248U:EJe@Q0U:@<]J`0A<H`]JbU::DXU:BU:;F/aS2e[<H`e
[Be[:DXU:BU:;F/YBP039BT2:DX3;F/00bDY:DXYBP02;F/012DY8@PU:BDY
0Re[12U:0RDY0bU:00DU:B488@PU:BU:00<]J`8YBP04;F/YBRDY7>L39BT0
12U:9BTU:BU:0Re[00<YBR488@P00R480RU:0S6<00]245:DF]IS65[FCW=6
<CF]<H`HaQ2400<48@0400048@@Q124236<01PQ212448@@Q24848@@8@P07
36<8@PaS36<@Q0aS24800PaS0a240PaS00@8@PaS248<H`88@P8<H`067>LQ
24icDYA_Ng_N0W>L00YNme[FCW<Q21BU6<HU:Be[8@P8@PL48@<8@P848@0=
248<Ha2436<8@PaS24848@Q21248@PaS6<H00aBU00HQ236<>LhaS2e[7>L2
6<H25:D00a2436<<H`0336<00a245:D@Q00336<0112436<8@PQ20PaS0PQ2
010<HaBU48@]JcW>G_McW6]JMkecW7_NMkeS65:D9BTLi`<<H`04248@Q1BU
8@P29BT2:DX01bDY8@PQ21cW5:DHaPaS0088@P03124<H`Q2008<H`04248<
H`Q248@25:D01Q2436<<H`aS248<H`@DY@0436<@Q0aS36<4124224821243
248336<00`Q236<<H`0536<448@224821242248236<2248336<00aBU48@<
H`03248336<348@01PaS2488@P@Q248<H`T8@P0436<8@PQ2248636<72483
36<00a2436<8@P02248312400`Q212448@0312401@Q236<@Q1S68@P00aS6
00HLibDY9BTQ22DY:DX2;F/3<H`00be[<H`e[@02=Jd2;F/013F];F/aS3F]
0cW>00`e[Cg_>LhaS3F]@Q16<D8@=JdaS3F]<H`3=Jd5>Lh01Cg_>Lhe[C6<
>Lh00Sg_00<icSF]>Lh00T8@0Sg_00<e[CW>?Nl013W>00Te[CW>=JdicSF]
<H`icSg_@Q000Sg_0d8@00<icSF]>Lh00T8@00LicSF]=Jde[CW>=JdaS002
=Jd2>Lh2=Jd023W>=JdicSF]>Lhmkd8@?Nl2=Jd3<H`01CF]>Lhe[CF]>Lh0
0Sg_00@icSF]>LhicP<aS003>Lhmkcg_00924004?NlicSF]=Jd2>Lh00cg_
>LhicP02>Lh013F]>LhicSW>0Sg_0cW>00@mkd8@?Nm2408mk`8icP08<H`i
cSW>?Nm244Ha@Q16<@8mk`8icP04@Q0icSW>>Lh2@Q001dHa>LhicSg_@Q16
<D8@008icP05?Nm244HaBU96<@04>Lh2@Q002Cg_>LhicSW>?Nm244YB@Q0i
cP02?Nl01DHa@Q0mkd8@?Nl013W>00A244HaAS5240<icP06?Nm2448@?Nm2
44Ha0d8@0THa148@00HmkdHaAS56<D8@?Nl2AS41<H`000/48@05248YBU:D
?NlU:@02;F/012U:;F/YBRe[12U:0Re[0S6<00<]JbU::DX00Re[0RDY00TQ
22U::DXYBRe[<H`YBRDY:DX00Re[00@YBRDY8@PU:@8YBP03;F/YBRU:008Y
BP039BTYBRU:00<YBP<Q2003:DXaS2e[00@YBP049BTQ22488@P39BT02248
9BTYBRe[:DXU:AcW8@P29BT2:DX02Be[<Ha245:DF]IS65[FCW=:DP02<H`0
0aBU36<48@05124010Q236<<H`Q20P@Q00<8@P@Q24800`Q20`aS00H8@PaS
48@@Q0aS248236<00a2436<<H`0236<424805PaS248<HacW8@Q:DUJeKg]o
ofmkLiaS65JeBU8Li`aS5:DU:C6<7>L48@Q20P@Q00D8@P@Q1248@P@Q0088
@P848@88@P0348@<H`Q200H8@P0448@DYABU48@27>L013F]>Lh]Jbe[0aS6
00@DYA2436<@Q08<H`@@Q0D<H`L8@P0836<@Q124;F/mkf<HLia_N`Ag_@04
G_M>LbDY7>L424800a246<HQ20039BT01BU:9BTU:AcW6<H00QBU00@@Q0aS
2488@P<<H`06248<H`aS36<@Q1BU0Q2400/8@PaS36<8@PaS48@DYAS65:D@
Q0aS00@8@P@48@@8@P03124<H`aS008<H`88@PH<H`0348@<H`Q200<8@P03
1248@PaS008<H`04248<H`aS48@536<01@Q236<<H`Q236<00a242@Q200<<
H`Q224800`Q200<<H`Q224800PQ210aS1@Q200<48@Q212400PaS00D@Q0aS
2488@PaS0088@P<48@0324848@@Q00848@0336<DYABU00<Li`<HaP<Q2005
9BTYBRU::DX]J`02<H`01RU:<H`aS3W><H`]J`DaS003=JdicSF]008icP06
=JdaS3F]@Q16<Cg_0S6<0cF]00HaS3F]=JdicSg_=Jd3>Lh01C6<=Jde[Cg_
>Lh00SF]00DicSg_?NlicSF]00DicP<e[@8icP03=JdaS3F]008icP924003
?Nm2448@008mk`8icP8mk`03>Lhe[C6<008icP<aS0PicP06=JdicSW>@Q0m
kcF]0c6<13F]00HaS3W>>LhmkcF]<H`3=Jd2<H`2>Lh00cg_@Q0mk`03>Lh0
0cF]>LhicP03>Lh01SF]>LhicSF]>Lhmk`HicP924003?Nm243g_008e[@03
<H`e[Cg_008mk`04@Q16<D8@@Q02?Nl2>Lh2=Jd2?Nl2@Q03>Lh2@Q02?Nl0
0cW>@Q16<@02AS401D8@>Lhe[CW>?Nl00T8@0SW>00@mkcF]>Li24096<@04
?NlicT8@@Q02?Nl01T8@?NlicSW>=Je24096<@9240@icP04@Q0mkcg_?Nl2
AS40148@AS5244Ha0T8@00Xmkd8@@Q1244Ha@Q0mkd8@AS52404e[@000140
00@Q00048@00124000@Q248000@Q248Q25:D@Q0U:Be[00<YBP049BTYBRDY
9BT2:DX01Be[<H`aS36<:DX00RDY00<YBRe[:DX00RDY00<YBRDY:DX012U:
0bDY0RU:0bDY00<YBRDY:DX00bDY00HQ22DY9BTYBRe[9BT28@P00bDY:DX]
J`03;F/3:DX49BT37>L00b489BTU:@02:DX29BT00b489BTYBP02<H`022U:
<H`mkdYBIcUS65kgDY@2AS400be[8@P@Q002248212401@Q236<HaQBU36<0
0`@Q0PQ200@48@Q21248@P848@05248@Q1BU48@<H`02248236<00a245:D<
H`0724801@aS7>LU:E:DHaP00WNm00M[FW_NNmig_E[F:DXLi`0236<00a24
36<8@P07124224800`aS12448@02248236<00`@Q2488@P0224801P@Q248<
HaBU6<HDY@8Li`0:@Q1:DV<HJeY>LcW>:DXLib4848@236<00`Q25:D@Q002
5:D248@236<02A242488@PaS5:D@Q0aS124<H`0248@03BDY:DY245JeG_M_
Nf]JKg]S64icBU8U:AcW00<<H`04248<HaBU7>L49BT28@P27>L011BU48@8
@PQ20P@Q1`Q20`aS11240PaS00H8@PaS36<<Ha2436<524801@@Q24848@Q2
12400`Q200<48@Q224800`Q200<<H`Q236<00`aS00<@Q1BU5:D00Q240P@Q
0PQ200D<H`Q236<@Q2U:008mk`04=JdU:A2448@336<010Q236<<H`aS2PQ2
00<48@Q212401`Q200@48@Q236<@Q0T<H`L8@P@48@0524848@Q21248@P03
12401PQ25:DHaRDY8@PLi`8Q208Li`038@PYBRU:008YBP07;F/aS2e[=Jdm
kcW>=Jd00Re[00@e[CW>>Lhe[@8aS006=JdicSF]=JdaS3W>0Sg_00<icS6<
;F/00c6<0SF]1CW>00HmkcW>=JdaS3F]>Lh2=Jd2>Lh2?Nl013F]>Lhe[CF]
0Sg_00PicSF]=Jde[CW>?Nle[CW>0Sg_00A243g_?Nlmk`9240Dmk`06@Q0i
cSW>=JdaS3F]1SW>0Sg_0SW>0SF]00@icSg_>LhicPDaS0@e[@05?Nm243g_
>LhaS002>Lh2<H`01SW>?Nm243W>?Nm2408mk`09<H`e[C6<=JdicSg_@Q16
<Cg_00<icP05=Je6<DHa?NlicP02=Jd013g_@Q16<Cg_0SW>0T8@00<mkcW>
>Lh0148@00@mkd8@@Q12408mk`A24003AS4mkcg_008mk`04AS52448@@Q02
?Nl00d8@AS56<@02?Nl2=Jd2>Lh01Cg_>LhicSW>?Nl00THa00=243W>>Lh0
0T8@00<icSF]>Lh01Cg_00=6<D8@AS400T8@0Sg_00M243g_?NlicT8@AS52
4002?Nl2@Q000dHa?NlicP02?Nl3BU8014Ha@Q12448@0Be[000;12401PQ2
8@QBU3g_:DX]J`8YBP07;F/YBRU:9BTYBRDY:DX00c6<00<]JbU:9BT012U:
1BDY00LYBRe[:DXYBR489BTYBP069BT01BU:9BTU:BDY8@P01RDY0b4800HY
BS6<:DX]JbU:;F/2:DX39BT28@P27>L01R489BTU:BDY:DXU:@<Q200?9BT]
Jc6<:DX]JcW>DYA[FV<HG_MBU3g_AS4U:B4800<8@P848@05248<HaBU5:D8
@P0212400`0024848@0324801`@Q24848@Q248@DYA2400<8@P@@Q00436<8
@PQ21242248336<01acW9BUF]F<HLiag_F]J009oo`04LiaBU2DY6<H236<2
48@224841243248412401@Q236<<H`Q212401@Q20PaS00<@Q1BU6<H00R48
00i244icHaQ[FTYB>LhU:AS67>LDY@aS248<Ha240aBU00<@Q0aS36<00PaS
00<8@PaS36<00Q240PQ200P<Ha2436<U:BU:BU9F]Ekg0fmk00ES64YB@Q0Q
21cW00<<H`04248@Q1246<H28@P022DY8@PU:BDY8@PHaQ245:D2248010@Q
2488@PaS0PQ200L<H`Q22488@PaS48@<H`0248@436<01A2436<<H`aS48@0
0PQ20P@Q00<8@P@Q12402PQ200<<H`Q224800PaS00@8@PaS36<@Q08DY@03
48@<H`Q200<8@P0?36<48@aS5:DU:D8@?NlaS24836<@Q0aS248<H`Q2008<
H`@8@P0536<8@PQ2248<H`0324800`@Q24848@03248312400`Q236<@Q005
36<2248436<524801P@Q2488@PQ21248@P<48@0924848@@Q24848ABU7>LU
:B48008Li`048@PLiacW8@P4:DX3;F/013F]?NlicS6<0Re[00DicSF]=Jde
[C6<008e[@04<H`e[C6<<H`4>Lh3<H`2;F/2<H`3>Lh01Cg_>LhicSW><H`0
0cF]00@icSF]=Jde[@<mk`03=JdaS3W>008icP@e[@@icP04?Nm243g_>Lh6
?Nl2>Lh3?Nl4=Jd00c6<=JdaS004>Lh2?Nl2=Jd00c6<>LhicP02>Lh4<H`2
=Jd00cW>=Jde[@04>Lh00cF]>LhicP02<H`013F]>Li243g_0T8@0SW>0S6<
0SF]00DicSg_@Q1243g_00<e[@03?Nm244Ha008mk`06=JdaS3W>@Q16<Cg_
0SW>0cg_0SW>00Dmkd8@@Q1243W>008mk`=2408mk`=24003?NlicSW>00A2
4008?Nm243g_?Nm244Ha?NlicP8aS0@icP03=JdicT8@0096<@06?NlicSW>
@Q0mkcW>0SF]00U243g_?NlmkcW>@Q16<D8@?Nl00SW>0d8@00<icSF]@Q00
0THa0Sg_00A244HaAS52408icP03@Q1:DTic0096<@=2404]J`0000D000@Q
00048@0000L48@048@Q>LcW>9BT2;F/2:DX00bDY:DXYBP03:DX01Re[<H`a
S36<:DX]J`8YBP8U:@8YBP039BTQ22DY008YBP05;F/YBRU::DXU:@05:DX7
9BT28@P012DY8@PU:B480RDY00<YBRe[;F/00Re[00<U:B488@P00bDY00@Q
22DY9BTU:@<Q20<U:@8Q20087>LYBS6<<H`YBRDY;F/mk`9JeP04HaQJeTHa
?Nl2<H`01BU:7>L<H`Q236<00a2400<<H`Q212400`@Q0PQ20`@Q00/8@P@Q
248<Ha245:D<H`@Q248<H`Q200<<H`<8@P0536<8@PQ2248<H`026<H02d8@
CW=[FVmkJeYoogNmIcU:DRDY8@P00Q2400<<H`Q224800PQ21@@Q00<8@PaS
36<00`Q200<<H`Q236<00PQ200<<H`Q236<00PaS0a2400hDYAcW8@PmkdYB
HaQ[FU[FIcUBU3F]9BT<Ha240PaS00PDYA245:DDYA245:D@Q0aS0`Q200H<
H`Q22488@PaS48@46<H03C6<CW=S66]JCW<icSF]:DX]JbDY8@P@Q0aS0088
@P8<H`045:DLib48:DX28@P00acW6<HDY@0236<010Q21248@P@Q1@Q200<4
8@Q224800`aS00@@Q1S66<H@Q0<8@P0336<8@PaS00<<H`<48@88@P848@03
248<H`Q200<48@H8@P0336<8@PQ20088@P045:DLiaS65:D2248236<02A24
36<@Q1BU9BTaS3g_G_MJeP02HaP01Be[7>L48@Q236<01@Q200@48@Q2248<
H`88@P0336<8@PQ200H8@P0336<8@P@Q008<H`046<HDYA2436<412400`Q2
36<<H`0236<01@Q21248@PQ212400PQ21@@Q10Q200<<HaBU5:D00QcW00<Q
22DY8@P00QcW00<U:BU:;F/00bU:0S6<0SW>13F]00<aS3F]=Jd00SF]0c6<
00<]JcF]>Lh00SW>0c6<00<]Jc6<;F/00S6<00LicSF]=JdaS3W>?NlicP07
=Jd4>Lh2=Jd00cW>?Nm24002@Q02>Lh2=Jd4?Nl0336<=Jdmkcg_AS5243g_
>LhmkcW>=Jdmk`96<@03@Q0e[CF]00HicP06@Q1:DTHa@Q0mkcF]13W>0cF]
00<mkcW>>Lh00SW>00<mkcW>>Lh013W>0SF]00@aS3F]<H`icP92409>L`06
AS4icS6<=JdicSF]0SW>0Sg_00E243g_@Q0mkcW>0096<@05@Q0mkcF]>Lhm
k`02@Q03>Lh2@Q03?Nl013W>?NlicSF]0Sg_0T8@0Sg_00A243g_?Nm24096
<@05BU8mkcg_?Nm24002AS402Cg_@Q16<DYBAS5243g_=JdaS002>Lh2AS42
?Nl2>Lh3?Nl2@Q0023W>=JdaS3F]?Nm243g_@Q02AS4014YB@Q12448@0THa
00E243W>>Li243g_00=2408mk`A24005?Nm244Ha@Q16<@03BU81?Nl1;F/0
00D48@0<00048@@Q124000@Q248U:DYB>LhQ22e[1BU:00@U:BU::DXU:@<a
S006;F/YBRe[;F/YBRDY0RU:12DY0bU:00<]JbU:9BT00RDY00<YBRe[:DX0
0RU:12DY1B480RDY0R4800@U:Be[;F/]J`8aS005:DXU:B488@PU:@038@P0
12DY8@PQ22480RDY00<Q21cW7>L00R4800<YBS6<;F/00RU:00h]Jd8@E[EF
]EkgF]I6<Cg_;F/aS2487>L@Q0Q20PaS0Q2400<<H`@Q12400`@Q00D8@P@Q
24848@Q200<48@0436<@Q1BU36<3248436<00`Q236<8@P0224800`aS248<
H`027>L02d8@CW=[FVmkJeYkgWNmHaQ:DR487>L00Q2400<<H`Q224800`Q2
0P@Q00@8@PaS248<H`D8@P0336<8@PQ20088@P8<H`D@Q00<6<HQ21cW?Nm:
DVLiJeYJeUkgCW<e[B480PaS00<@Q0aS48@00QBU112400<<H`Q224800PQ2
00D<H`Q21248@QBU00@HaP0=<HaBU6<HJeY>LcF]<H`]JbU:8@PLia2436<0
0PQ20PaS00<DYAS67>L00R480QcW0QBU00@<H`Q2248<H`@8@P0336<8@P@Q
0088@P<<H`05248@Q1BU5:D@Q005248248@01@aS24848@@Q24800`@Q1@Q2
0`@Q10Q200L<H`Q2248<H`@Q36<DY@027>L01A242488@PQ236<00Q240QBU
00TU:C6<@Q1Nme[FHaQJeRU:6<H00PQ200<@Q0Q212400P@Q0`Q200<<H`Q2
248010Q200D48@Q22488@P@Q00@8@P8<H`045:DHaQ2436<212401`Q21248
@PQ236<@Q0aS0088@P848@@8@P<48@<8@P031248@PaS008HaP8Li`8Q2004
9BTQ21cW8@P4:DX00be[<H`e[@04=Jd2<H`01CF]>LhicSW>=Jd0136<0SF]
00<icS6<<H`0136<0Re[0cF]00DaS3W>?NlmkcW>008aS0<e[@8aS08icP0=
?NlicSF]=JdmkcW>?Nm6<D8@?Nle[C6<=Jd00SW>0cg_0SW>0Sg_00m243g_
?NlmkcW>=Je244HaBU9243F]<H`e[CW>?Nl00SF]00@icT8@BU96<@<icP8m
k`04>LhaS3F]=Jd8>Lh01cF]>LhicSW>=JdicSF]008aS004=JdicT8@?Nl2
BU82@Q02<H`2=Jd3>Lh00cg_@Q0mk`02?Nl2@Q000dHa?NlicP02>Lh2?Nl0
1T8@>LhicSW>?Nm2408icP04?Nm243g_=Jd2>Lh2?Nl01d8@?Nlmkcg_>Lhm
kd8@0096<@92408mk`=24005AS5244HaBU96<@02?Nl013F]<H`e[Cg_0T8@
0cg_0SW>00<mkcW>?Nl00Sg_0cW>00@mkcW>@Q1240=6<@I24006?NlicSg_
@Q16<D8@13g_00A6<D8@?Nlmk`=6<@05@Q1:DTYBBU924001:DX000030004
8@0000L48@080008@R48AS4aS248;F/YBP8U:@<YBP039BTYBS6<008e[@05
;F/aS2e[:DXU:@02:DX2;F/2:DX29BT4:DX29BT2:DX00be[:DXU:@02:DX6
9BT47>L28@P29BT3:DX39BT01R489BTU:BDY8@PU:@8YBP0:9BTQ22488@PY
BRe[9BTQ21cW8@P39BT01R489BTQ236<AS5>L`9S6007BU8mkcW>@Q0mkc6<
5:D00`aS00<@Q0aS24800P@Q00T000@Q12448@Q21248@P@Q24800P@Q00<8
@PaS36<00`Q200<<H`Q224800PQ20PaS014@Q0aS24848A247>LQ21S6:DXi
cU[FG_MBU5kgDY@mkbU:008HaP0348@<H`aS00D8@P0436<8@PQ2248236<0
0`Q236<8@P0236<3248736<01A2436<@Q1BU7>L00S6<00Y245:DBU9242e[
8@PU:AS65:D<H`8@Q00636<@Q12448@DYA240PaS00<8@PaS24800PQ200<<
H`Q224800PQ200PHaQBU<HaS66mkG_LaS1BU0QcW00DHaQcW6<H@Q0aS0088
@P0536<8@PaS48@DY@026<H01QBU48@<H`aS248<H`848@@8@P031248@PQ2
00@8@P0348@<H`aS008@Q08<H`04248<H`Q2248348@010aS2488@P@Q0PQ2
00<48@Q224800PaS0P@Q00<8@P@Q12402@Q200<<Ha2436<00PaS0Q2400@<
HaS67>LYBP8]J`04=JdaS36<<H`2=Jd2?Nl01B486<H48@Q236<00PQ200D4
8@Q236<8@PaS00<8@P8<H`D8@P041248@P@Q248248@00aS648@8@P041240
10Q21248@P@Q0`Q20P@Q10Q21@@Q0`Q200<<Ha246<H00R480QcW00@Q22U:
:DX]J`<YBP03;F/aS36<00<e[@03>LhaS36<008aS005>Lhe[CW>=JdicP02
<H`022e[<H`icSW>=JdicS6<=Jd4<H`012e[<H`icSW>0SF]00<icSg_?Nl0
0cW>0SF]136<00/e[Cg_>LhicSF]>LhmkcW>?NlicSg_008e[@8icP8mk`8i
cP8mk`05@Q0icSF]>Lhmk`02>Lh01d8@AS56<DHa@Q0mkcW>008mk`04>Lhe
[CW>@Q02CW<014YB@Q0icSg_0SW>00@e[C6<>LhicP8mk`@icP03?Nm2448@
00924004>Lhe[CF]>Lh2?Nl2>Lh02cg_AS56<DHa?NlicSg_>Lhe[C6<>Lh0
0Sg_1CW>0T8@00@mkd8@>LhicP<mk`0:>Lhmkd8@AS4mkcF]>Lhmkd8@>Lh2
<H`2>Lh00dHa@Q124002@Q0013g_>Lhmkd8@0TYB00Q6<D8@@Q1244YBAS52
44Ha0d8@00Hmkd8@?NlicSF]<H`2?Nl3@Q000cW>?Nm24002AS4023g_=Jdi
cSF]<H`e[CW>?Nl3@Q002Cg_AS56<D8@?NlicSg_@Q0mk`07@Q02?Nl00d8@
BU96<@04AS4014YBCW=>Ld8@0C6<000412400`0012448@0512401QcW@Q0a
S248:DX]J`8U:@07:DX]JbU:9BTYBS6<=Jd00S6<00<]JbU::DX00RU:00<]
JbU::DX00bU:0RDY0bU:0RDY1BU:12DY0RU:00@Q22DY8@PQ208Li`038@PU
:BDY00@U:@8YBP<U:@8YBP089BTQ22U:;F/U:B487>LQ208YBP8U:@8Li`DU
:@04:DXaS4HaCW<2G_L02DYB?NlicTHa>LhYBQ2436<@Q00236<224851240
0`Q212448@041243248236<01@@Q2488@PQ236<00PQ20PaS01L8@PaS2488
@QBU7>LQ21BU:DXicU[FG_M>Le[FCW<e[BU:6<HDYA2436<8@PaS0088@P03
124<H`aS00D8@P0336<8@PaS00@<H`88@P8<H`8@Q0<<H`8@Q0097>LHaRe[
<Ha6<E:DAS4mkbe[008Q20036<H@Q124008@Q0<<H`@@Q08<H`03248<H`Q2
0088@P<<H`09248DYABU>LiW>FmkE[DaS1BU008Li`036<HDYAS6008<H`0;
248<H`aS248<Ha246<HLiaS648@DY@0236<01@Q212448@Q212400PQ200D4
8@Q21248@PaS00<8@P0436<@Q1245:D336<010Q236<<H`Q20Q2400<DYA24
24800`@Q1`Q21@@Q20Q200<<Ha2436<00PaS00d@Q1BU36<DYB48;F/aS2e[
<H`e[C6<;F/e[@03>Lh00acW5:D8@P0224821242248236<2248336<:2480
10aS48@DYABU0PQ200<48@0024800`@Q10Q200<48@Q224800PQ21P@Q00H8
@P@Q248@Q1BU7>L28@P27>L01248:DXYBRDY0RU:0be[0S6<0cF]136<00<e
[CW>=Jd00SW>0S6<00DYBRe[<H`e[CW>008e[@<aS003=Jd]Jbe[008e[@06
>LhaS3F]>Li243g_0SW>00DmkcF]<H`]JcF]008aS005=JdicSW>>Lhe[@02
>Lh00cg_>LhicP04=Jd013W>?Nlmkcg_0SW>00Pmkd8@>LhicSF]?Nm243g_
0T8@0THa00dmkcW>>LhicSg_<H`e[Cg_AS5BU4icBU96<@02?Nl01CW>=Jde
[CF]>Lh00Sg_0cW>0Sg_00<icSg_?Nl00T8@00HicSF]<H`e[D8@?Nl3>Lh0
14HaBU9:DT8@0cW>0SF]00PicSg_>LhicSF]>LhmkcW>0cg_13W>0cg_00@i
cSg_AS52408icP03@Q0mkcW>008aS0<mk`924003?Nm243g_008mk`04@Q16
<DYBAS43@Q02AS43@Q001DHa@Q0mkcg_>Lh00cF]00<icT8@?Nl00d8@00<m
kd8@@Q000Sg_0SW>13F]00<mkd8@?Nl01D8@0cg_0T8@0Sg_00=6<D8@@Q00
0d8@00<mkd8@AS400THa0T8@00E:DTicCW=>Ld8@004aS00000<000@Q1240
0`@Q00<000@Q12400P@Q00L8@RDYAS4e[B48:DX]J`04:DX2;F/0136<;F/a
S36<0Re[00<U:BU::DX00bDY00<]JbU::DX012DY0Re[00@YBRDY8@PU:@<]
J`06:DXU:BDY9BTQ21cW0RDY00PQ21cW7>LHaRDY8@PU:B480RDY0RU:0RDY
00@YBRe[;F/U:@@YBP8U:@048@PU:BU::DX39BT00b489BTU:@02:DX02Re[
9BTYBSF]?NmNmf<HF]IBU48@0TYB00M6<Be[6<H@Q0aS48@8@P0;12400`Q2
12448@0224800`aS248<H`0424801`@Q2488@Q246<HDY@aS0088@P8@Q00=
36<]JdHaKg]g_DHa=JdU:AS67>LHaQBU48@01@aS00D8@P@Q36<@Q0aS0088
@P031248@PaS00d<H`0748@<Ha245:DHaQcW6<H00QcW00DQ21cW7>LHaQBU
008@Q0035:D@Q124008<H`08248@Q1BU5:D@Q0aS248<H`88@P045:DHaQ24
248212400aBU48@Li`02<H`012U:6<H<H`aS0aS600<@Q0Q224800`Q200@<
H`Q22488@P<<H`P8@P091248@P@Q1248@PaS248<H`Q200<<H`8@Q0@<H`<@
Q08<H`0448@DYA2436<2124324801@aS2488@P@Q24800P@Q2@Q200@<H`@Q
248@Q08HaP065:D<Ha248@PYBT8@0U:D00EJeTicCW=:DRe[008U:@04<H`e
[BU:36<224800`@Q2488@P05248436<32482124224801P@Q248@Q1245:D<
H`88@P848@0600048@Q224848@Q210@Q0PQ200<<H`@Q24801@@Q00@<Ha24
5:DDY@8Li`<Q208YBP04;F/YBRe[;F/3:DX01RDY=Jde[D8@?NlaS0<]J`8e
[@04<H`icSW>>Lh3<H`013F]<H`e[CF]0SW>00HmkcF]<H`]Jc6<=Jd3?Nl2
=Jd2>Lh2?Nl4>Lh01SF]<H`]JcF]>Li240<icP05?NlicSW>>Lhmk`02>Lh2
=Jd00cW>?Nm24002?Nl01THa@Q0mkcF]>Li240<mk`03@Q16<DHa0096<@03
@Q0mkcW>00<icP924096<@03?NlicSW>0092408mk`06>Lhe[CF]>Li244Ha
148@00E:DTHa?NlicSF]00<mk`924006>Lhmkcg_?Nm6<DYB0T8@00@icSF]
=JdicP8mk`03>Lhe[CW>008icP8mk`9240<icP03<H`icSW>00=24003?Nm2
43W>008icP=2408e[@06>Lhmkd8@BU9>Lcg_0SW>00=244YBBU800T8@00<m
kcW>?Nl00Sg_0d8@0Sg_00=243W>=Jd00S6<0SW>00=243g_@Q000Sg_0d8@
00DmkcF]=Jde[C6<008icP8mk`924096<@07BU9243g_>Lhmkd8@>Lh00Sg_
00=6<DYBAS400THa00@mkcW>?Nm240=6<@03BU9>Ldic009:DP52404aS000
00H48@00124000@Q000412402000248U:DYB<H`LibDY;F/3:DX00be[:DX]
J`03<H`3;F/2:DX49BT00bU:;F/]J`039BT3:DX49BT2;F/012U:9BTU:B48
0bDY0b4800<LiaS67>L00R4800PU:B488@PU:Be[:DXQ22DY0Re[00@YBRDY
9BTU:@8YBP059BTQ22488@PYBP039BT00b489BTU:@04:DX02R48;F/icSg_
G_MS65[FCW=244YB0T8@00DU:AS65:D8@PaS0088@PD48@@8@P<48@88@P8<
H`0324848@Q200H8@P0636<DYABU48@<H`Q20Q2400`8@RU:BU9g_G>L@Q0a
S2486<HLiaS65:D336<00`Q236<<H`0336<00`Q236<8@P05248236<01124
36<<H`Q22@aS00<DYAS66<H00acW00<Q21cW7>L00QS600@DYA2448@DY@8@
Q088@P8@Q08DY@0;36<8@PQ2248<HaBU6<H@Q0aS1248@P0248@03B48;F/a
S2U:6<H<Ha246<HLiaS648@8@PaS00H8@P041248@PQ236<5248612422480
10@Q2488@Q241@aS00@@Q0aS36<<H`<@Q08<H`0648@DY@aS36<8@P@Q0PQ2
00D<H`Q224848@Q200848@@8@P848@H8@P05124DYAcW6<H@Q00236<00bDY
:DY24002DY@02e[FDYA:DTYB;F/Lib48=JdicRDY36<00PQ200<48@Q21240
0P@Q00<8@PaS24800`aS0PQ200D<H`Q21248@P@Q0088@P03124<Ha24008@
Q00324848@@Q00D48@0324848@Q200848@0424848@Q21242248512400`aS
48@HaP025:D01QS68@PLibDY:DX]J`8YBP<]J`04:DXU:BU:<H`3>Lh2;F/0
1C6<;F/aS36<=Jd00SW>1C6<1CF]00<icSF]=Jd00S6<0SW>0Sg_0cF]13W>
00LmkcW><H`e[Be[:DXe[@02?Nl00cW>=Jde[@06>Lh00cF]>LhicP02>Lh3
?Nl2@Q02>Lh01SF]@Q0mkcW>?Nm24096<@03@Q16<D8@008icP09=JdicSW>
>Li6<DYB@Q0mkcW>008mk`8icP05?NlicSF]=JdicP04@Q002Cg_AS52448@
?NlicSF]>Lhmk`02@Q001Cg_>LhicSW>@Q000THa0T8@00DicS6<<H`e[Cg_
00<icP03=JdicSW>00Dmk`0:>Lhe[C6<>Lhe[Cg_@Q16<D8@?Nl2>Lh00cg_
@Q0mk`02>Lh01cF]>Lhmkcg_BU96<D8@00<mk`04BU96<D8@@Q02>Lh3?Nl3
@Q001CW>?NlmkcW>=Jd00S6<0cW>00I243g_?NlicSg_@Q02?Nl01CF]>Lhe
[C6<=Jd00cW>0d8@0THa00A243g_>LhicP8mk`03>Li2448@00A6<@<icP04
@Q1:DTHa@Q02BU8014icBU9:DT8@0C6<000;12401PQ28@Pmkbe[8@P]J`8a
S08YBPD]J`8YBP8U:@<YBP8Q20039BT]Jbe[008YBP8U:@048@PYBRe[:DX3
9BT4:DX01bDY8@PQ22487>LU:BU:008Q20036<HLib48008U:@03:DXU:BDY
00@U:@DYBP039BTYBRDY00@U:@<YBP03;F/YBRDY008U:@03;F/YBRDY00@Y
BP04@Q1>Lf<HE[D2BU801THa@Q0e[C6<8@PDY@<<H`0324848@@Q0088@P03
1248@P@Q00848@88@P8<H`@8@P051248@PQ224848@0224801Q247>LU:AS6
24848@8<H`03248Q236<008mk`057>LHaQS648@DY@026<H00aBU36<<H`03
48@236<01`Q236<<H`Q236<8@PaS0088@P0436<@Q12448@536<00a2436<<
H`0336<011245:DDYABU0Q2400<DYAS65:D00Q2400<<Ha2436<00PQ20PaS
00H8@PaS48@@Q0aS248236<00`Q236<8@P0724800`aS48@@Q00348@01QBU
48@<H`aS248<H`88@P@48@88@P031248@P@Q00@8@P061248@P@Q1248@P@Q
10Q200<48@Q2248010aS00<@Q1BU36<00PaS00<@Q0aS36<00Q2400<DYA24
5:D00Q240`aS2`Q200<<H`Q224800PQ200D<H`Q22488@Q24008HaP0648@<
HaBU=Jdmkekg0W>L00aoog>LLiaW>D8@<H`DYA245:DHaQBU36<812432480
11245:D<H`aS0PQ210@Q00L8@Q2448@@Q0aS1248@P061242248512400`Q2
1248@P02248312400`Q248@DY@027>L36<H00acW9BTYBP02;F/2:DX3<H`0
22U:9BT]JcF]@Q0mkc6<;F/2:DX00c6<=Jde[@02>Lh00cF]<H`]J`04<H`2
=Jd00cW>=JdaS003<H`8>Lh013g_>LhicSF]0cW>136<0SW>00@e[CW>>Lhm
k`=2408mk`03>Lhmkd8@00@mk`<icP8mk`8icP08@Q0mkcg_>LhmkdHaBU92
40<icP=2408mk`<icP06=Jdmkd8@@Q16<Cg_0SW>00<mkdHa@Q000Sg_00E2
44HaBU9243g_008icP@mk`07@Q0mkcg_?NlicT8@AS400T8@1SF]00@icSF]
>Lhe[@8icP06=Jdmkd8@?Nm243W>0SF]00<aS3W>@Q000THa00XmkcF]=Jdi
cTHa@Q0mkcF]>Lhmk`8icP03?Nm244Ha008mk`07>Lhmkd8@AS5243g_>Lh0
0cg_0SW>00A244Ha@Q1240<icP05=JdicSF]>Lhe[@02?Nl3@Q001Cg_>Lhe
[CF]>Lh00cF]00<icSg_@Q000T8@00Y6<DYBAS5243g_@Q0icSF]>Lhmk`96
<@A24007>Lhmkcg_AS5244HaBU800dHa0DYB0DHa0CF]00001P@Q00048@00
124000H48@0:8@Q242e[7>L]Jc6<;F/YBRDY:DX3;F/00bU:9BTU:@04:DX0
12487>LQ22DY0bU:0b4800LU:BU::DXYBRDY8@PU:@04:DX00bDY7>LQ2002
7>L012DY:DXU:AcW0QS600@U:B489BTU:@8YBP039BTQ2248008YBP8]J`@U
:@07:DXU:BDY8@PU:BU:9BT00RU:0bDY12U:00XU:BU:8@PU:D8@CW=NmeJe
AS5:DP924006<H`YBQcW5:D@Q0aS0`Q20`@Q0PQ200<48@Q212400PQ20PaS
0`Q200<48@Q212401@Q2010<Hb488@PDY@aS1248@PaS248Q23F]AS4icQcW
5:DHaP8@Q08HaP0748@<H`aS48@DYA2424800PaS00<8@PaS36<01@Q20PaS
0Q240`aS00@8@PaS36<@Q0@<H`8@Q0035:D@Q124008DY@0648@DYA2448@<
Ha240`aS00<8@PaS24800`aS00L8@PaS36<8@PaS248<H`0424800`@Q36<8
@P0248@00aBU48@<H`0248@01QBU36<8@PaS248<H`88@P848@0524848@@Q
24848@0224800`@Q24848@0424821247248436<0112436<<H`Q20PaS1A24
00DHaQBU48@<Ha2400<<H`<8@P051248@PQ2248<H`022482124224801PaS
2488@PQ2124<H`8DY@0648@DYA24=Je245kg0W>L00QoogNmKg][FSW>;F/D
YA240QS600<DY@Q2124020@Q0PQ200@<Ha2448@8@P848@0524848@Q21248
@P0348@010aS12448@000P@Q00<000@Q24800PQ20P@Q00<000@Q124010Q2
10@Q00H8@Q246<HLiaS65:D36<H00b48:DX]J`02:DX2;F/2<H`012U:9BT]
JcF]0Sg_00D]JbU::DXYBS6<008e[@8icP8aS003;F/aS3F]00<aS08e[@04
<H`]Jc6<<H`3=Jd5>Lh00cg_>LhicP04>Lh013F];F/aS36<13F]0SW>0Sg_
00=6<D8@?Nl00SW>00Hmkd8@?NlicSg_=Jd3>Lh00cg_>LhicP03?Nl01CW>
?Nm244YBAS400Sg_0SW>00<mkd8@?Nl00Sg_0SW>00<e[CW>?Nl00T8@00M6
<D8@=Jde[CW>@Q16<@02?Nl0148@AS5:DSg_0cW>00A243W>>LhicP@mk`05
>Li244Ha@Q0icP02<H`2=Jd013W>=Jde[C6<0cF]0SW>13g_00Le[C6<<H`a
S3W>AS524002?Nl013F]<H`icSg_0T8@0cF]0SW>00@mkd8@?Nlmk`8icP09
@Q16<D8@@Q0mkcW>@Q0icSg_008icP04@Q0mkd8@?Nl2>Lh00cF]>Lhe[@02
=Jd013W>?Nm243g_0T8@00@mkcW>=JdicP8e[@03<H`e[Cg_008mk`07@Q0m
kdHaBU96<Cg_>Lh00Sg_0SF]00TicTHaAS56<D8@AS4mkd8@?Nl00d8@0THa
00E:DTHaAS5>LdYB004aS00000<000@Q124020@Q00L8@R48?NlaS1cW9BT]
J`02<H`00cF];F/]J`02:DX012e[:DXYBRDY0bU:00@U:B489BTU:@<YBP8U
:@8Q208U:@03:DX]JbDY00<U:@<YBP049BTQ22489BT28@P27>L38@P01RDY
:DX]JbU:9BTQ208U:@8YBP@U:@05:DXU:B489BTYBP038@P2:DX02Re[9BTU
:BDY:DX]JbU:9BTQ22e[0RU:00<aS3F]CW<00UJe00QBU48@AS5:DTHa>LhU
:AcW0PaS0`Q200<<H`Q224800P@Q0PQ20`aS1@Q200D48@Q21248@P@Q0088
@P8@Q0<DY@0536<8@PQ2248@Q0035:D00a2436<<H`0336<010Q236<<Ha24
0PaS0Q2400@<H`Q22488@P<<H`<8@PH<H`0348@<Ha24008<H`03248<H`Q2
0088@P<@Q08<H`8@Q08<H`0348@<H`aS008<H`<8@PD<H`88@P0536<8@PQ2
24848@0324802@aS12448@Q27>LU:B4848@8@P0336<00`Q236<8@P021240
0`Q212448@0412401@Q21248@PQ212400PQ20PaS0PQ20P@Q1PQ200@48@Q2
248<H`@@Q00936<@Q12448@DYAS65:D@Q0aS00@@Q08<H`03248<H`aS008<
H`88@P0336<8@PQ20088@P<<H`<8@P8@Q0<<H`0948@DYCF]AS5S67NmLiag
_Fmk009oo`03E[DicQ24008<H`0324848@Q200X48@03248@Q124008@Q088
@P<48@88@P@<H`P48@88@P031248@P@Q00<48@0324848@Q200848@03248<
HaBU008Li`8Q208HaP8Li`07:DX]Jbe[;F/YBRe[<H`00SF]00H]JbU:;F/a
S3W>=Jd4<H`00cF]<H`e[@02=Jd013W>=JdaS2e[0S6<0SF]1Be[0SF]13W>
00Le[C6<=JdicSg_=JdaS002>Lh023g_>Lhe[C6<=JdicT8@?Nl3>Lh4?Nl2
>Lh2?Nl2@Q000cg_@Q124002@Q0013W>=Jde[CW>0T8@00XmkcW>?NlmkdHa
BU9243g_@Q0mk`=240DicP03=JdicSg_0096<@04?NlicSW>?Nl2@Q001CW>
@Q16<DHa?Nl00SF]00@icT8@@Q0mk`8icP8mk`08>Lhmkd8@@Q16<Cg_>Lhe
[@8icP0<<H`]Jc6<=JdmkcW>=JdaS3W>@Q16<D8@0cW>00@aS3F]>LhicP<m
k`06>Lhe[C6<=JdicT8@0SW>00<mkdHa?Nl00cW>00@mkcW>>Lhmk`A240<i
cP<mk`07=JdicSg_?NlicSF]>Lh00cg_0cF]00HicSg_@Q0mkcW><H`4=Jd0
136<=Jde[CW>0d8@00Dmkd8@AS5>LdYB008mk`07=JdicSW>>Lhmkd8@?Nl0
0THa0T8@00@icSg_@Q16<@9:DP03@Q16<DHa009BU04icP0010@Q00<000@Q
12400`@Q00L000Q27>Lmkc6<7>LYBP02;F/3<H`2:DX012DY:DXYBRU:0RDY
00<YBRDY9BT00b4800<YBRe[:DX00RDY00HLib489BTYBRe[:DX29BT00b48
9BTU:@03:DX58@P37>L03B48:DXYBRDY;F/YBR487>LQ22U:;F/U:B4800<U
:@8Q208YBP059BTQ22489BTQ2002;F/01RU:9BTQ22U:;F/YBP@U:@04:DXe
[C6<CW<2E[D025:D@Q1:DTHa@Q0e[BDY6<H236<524801@aS2488@P@Q2480
0PaS00<8@PaS36<00PQ200<48@Q212400`@Q0`Q20aBU00D<H`Q22488@PaS
008@Q08DY@0336<@Q0aS008<H`88@P0436<8@PQ236<348@010aS2488@PaS
0`Q200<<H`Q2248010aS00<8@PaS36<01@aS0PQ200<48@aS36<00`aS1A24
00@8@PaS248<H`88@P0336<8@PaS00<8@P0736<8@PaS24848@Q2124010Q2
00T<H`Q21248@QcW;F/U:@aS248010aS0PQ200@48@Q22488@P@48@042484
8@@Q1243248010@Q2488@PaS1@Q20`@Q00D8@P@Q24848@aS00<@Q08<H`<@
Q08DY@8@Q08<H`8@Q0<<H`<8@P0336<8@PQ20088@P0436<8@PQ2248436<0
1`Q236<<H`aS48@8@PaS008DY@07=Je6<FLiMke_NgNmLi`00Woo00IBU3W>
36<<H`Q21242248512400`0012448@0312401@aS48@<H`aS24800`@Q0`Q2
0`aS00<8@P@Q12401@@Q00@8@P@Q2488@PL48@0624848@@Q248<Ha240QcW
00<Q21cW6<H00QS600<LibDY;F/00Re[00DYBRe[<H`e[C6<00<YBP08<H`m
kcF]<H`]Jc6<;F/aS08e[@04<H`e[C6<=Jd7<H`022e[<H`YBRe[<H`icSg_
=Jd2>Lh3=Jd2>Lh3=Jd3>Lh0236<;F/icSW>@Q0mkcW>=Jd2>Lh3?Nl01CW>
=JdicSW>@Q0013g_00=243g_=Jd00SF]00<icSg_@Q000cW>00=244YBAS40
0Sg_00@icSg_@Q0mk`8icP09?NlicSF]>Lhe[CW>?Nm244Ha008mk`8icP<m
k`A24008>Lhe[Cg_?Nm243g_=JdicP8mk`03>Lhmkcg_0092408icP<e[@04
<H`]Jbe[=Jd2>Lh2=Jd01cW>@Q16<D8@>LhmkcW>00<e[@05>Lhmkcg_=Jdi
cP02<H`00cW>?Nlmk`02>Lh00cg_@Q0icP02=Jd2?Nl2>Lh013g_AS56<D8@
0SW>00@e[CW>>Lhmk`<icP03?NlicSW>00<icP03?NlicSW>00<icP924006
?Nle[C6<=JdicSF]0S6<0SF]0cg_00=243g_@Q000dHa0Sg_00<icSF]>Lh0
0SW>00<mkd8@AS400T8@0Sg_00<icT8@BU800TYB00=6<D8@BU800U:D0CF]
00000`@Q00048@0212400`0012448@0312401`Q28@Q242e[8@PU:C6<00<]
J`8YBP8]J`<YBP@U:@03:DXU:BDY008Q20069BTYBRe[:DXU:B480RDY00<Y
BRe[:DX00RDY00@Q22DY9BTU:@8YBP038@PU:AcW00<Li`8Q208U:@03:DXU
:BDY008Q2003:DX]JbDY008Q20049BT]JbDY7>L29BT28@P00bDY:DXYBP02
:DX00be[:DXYBP048@P29BT02bU:9BTU:BDY:DY6<DicHaQNme:DCW<00TYB
00]243g_<H`LiaBU24848@Q236<@Q0aS00D8@P0336<8@PaS008<H`88@P03
1248@PQ200<8@P041248@PQ236<248@00`aS48@<H`0336<2248436<00`Q2
36<<H`0336<00`Q236<<H`0236<00`Q236<8@P0324800`@Q24848@022485
36<348@424801@aS2488@PQ236<00Q2400<<Ha2436<00PaS00H8@PaS248<
H`Q2124236<00a2436<8@P06248236<248@224801@@Q2488@PaS48@00aBU
00DHaQ2424848@aS0088@PD48@88@P<48@88@P848@88@P8<H`8@Q088@P03
1248@PQ200848@0524848@Q2248<H`0348@01`aS48@@Q1245:DHaQBU008<
H`8@Q0@<H`<@Q08<H`03248<H`aS0088@P041248@PQ236<2248236<01A24
36<8@PQ236<00Q2400/YBSF]DYAS66LiLia_NgNmKg]2436<008@Q00336<8
@P@Q00T48@070008@PaS48@<H`Q236<01@Q20P@Q0`aS0PQ21@@Q0PQ200D<
H`Q212448@Q200<48@03248<H`@Q0088@P8DY@036<HQ21cW008Li`056<HL
ib488@P]J`05:DX01be[<H`aS2e[9BT]Jc6<008e[@8]J`05=JdaS3F]<H`e
[@03>Lh00c6<;F/aS003;F/00c6<;F/]J`03;F/2=Jd2?Nl01SF]>Lhe[CF]
>Lhe[@@icP03=JdaS3W>00@e[@06>Lhmkcg_?NlicSF]0SW>0cg_00HicSg_
>Lhmkd8@?Nl3@Q000cg_=JdicP02?Nl2>Lh2?Nl013W>?Nlmkd8@0Sg_0SF]
00HicT8@?NlicSF]>Lh2=Jd013W>?Nm243g_0d8@00HmkcF]>LhicSg_@Q02
?Nl2>Lh023F]?NlicSW>=JdicSg_AS43@Q000cg_=JdicP02?Nl01D8@=Jd]
Jbe[=Jd00Sg_0cW>00A243g_@Q1240<icP04=JdicSF]>Lh2@Q0013W><H`a
S36<1CW>00Pmkd8@=Jde[CW>@Q0mkcW>0Sg_148@00LmkcW>=Jde[Cg_>Lhe
[@02>Lh3=Jd00cW>?NlicP02>Lh01Cg_>LhicSg_@Q000SW>00<aS3F]=Jd0
0SW>00Le[CW>=Jde[CW>?Nm24003AS400d8@AS4mk`02>Lh3@Q002Cg_=Jdi
cT8@AS5243W>=Jdmk`02@Q001dHaBU9:DTHa@Q1:DT8@004aS00000@000@Q
124000H48@070008@RDY@Q0]JacW9BT01Re[00<YBRe[:DX00RU:0RDY00DQ
22DY9BTYBRDY008Q20059BTYBRU:9BTQ20029BT4:DX00bDY8@PQ20039BT2
:DX02bDY8@PLiacW8@PLib487>LQ22DY:DX00RDY00DQ22DY9BTYBRDY008Q
200:9BTYBRU:9BTQ22DY8@PU:B489BT2:DX2;F/02RU:9BTQ21cW9BTQ22DY
8@PYBRDY0RU:014]Jd8@DYAS65kgCW=BU4YBAS5243W><H`HaQ241248@PaS
0088@P0336<8@PQ20088@PD<H`88@P061248@PQ21248@P@Q10Q20`aS00D@
Q0aS36<@Q0aS00<8@P<<H`<8@P0336<@Q12400<8@P@<H`88@P031248@P@Q
00D8@P<<H`04248<Ha2448@236<00`Q236<8@P02248536<348@236<72482
48@010aS2488@PaS0`Q200D48@aS48@@Q0aS00<8@P03124<H`aS00<DY@03
6<HDY@aS00D8@P031248@PQ200T48@<8@PD<H`@8@P031248@P@Q0088@P03
1248@PaS008@Q00836<@Q1245:D@Q1BU48@<H`<@Q00336<@Q124008<H`<@
Q003248<H`aS008<H`0724848@Q2248<H`Q236<00PQ21PaS00hDYA24:DXe
[EJeHaQW>GNmKg]g_F]J@Q0]Ja240PaS00<8@P@Q00000P@Q00<8@P@Q1240
10@Q0PQ200<@Q0aS248010Q200@48@Q21248@P@<H`031248@P@Q00848@@8
@P@48@0324848@@Q00D8@P045:DLiacW8@P37>L26<H01b489BTYBRe[:DXU
:BU:008]J`03<H`e[Be[008YBP05<H`icS6<:DX]J`02<H`01cF]<H`aS3F]
>Lhe[C6<008]J`03<H`]Jbe[00@]J`06:DX]JcF]>LhmkcW>13F]1CW>00@e
[CW>=JdaS0@e[@04>Li2448@?Nl2<H`2>Lh00cg_>LhicP02>Lh5?Nl01THa
@Q0e[CF]<H`icP<mk`03>LhmkcW>00924005?Nm243W>=JdicP03?Nl00cW>
<H`icP04>Lh00cg_@Q0mk`02@Q0013F]>Lhe[CW>0Sg_00DicSg_>LhicSg_
008icP04=JdicSF]>Lh2?Nl2@Q02>Lh01CF]>Lhmkcg_=Jd00Re[00He[D8@
?NlicSF]>Lh2@Q001Sg_@Q0icSg_>LhaS08e[@04>Li243g_=Jd3<H`01CW>
=JdicSF]>Lh00Sg_0cW>0Sg_0cW>148@00<icSF]=Jd013W>00<e[CW>>Lh0
0SF]00DicSg_?NlicSg_008icP@mk`04=JdaS36<=Jd3>Lh033F]<H`e[CF]
?Nm244Ha@Q0mkd8@AS52408icP03@Q16<Cg_008icP=24004?NlicSW>>Lh2
@Q000dHaBU96<@04AS41<H`000848@0500048@@Q1240000412401PQ28@Q2
42e[7>L]J`8YBP039BTYBRe[008]J`059BTYBRDY9BTYBP049BT2:DX38@P5
:DX012DY7>LU:BU:0Re[00<Q22DY8@P00R4800DU:BU::DXYBR48008Li`03
8@PU:B4800DQ20039BTQ22DY008U:@037>LQ22DY00<YBP8U:@038@PU:BU:
008YBP059BTYBRe[;F/YBP028@P01QcW8@PU:B487>LQ20<YBP8e[@05CW=J
eUJeDYA6<@02DY@01dic>LhU:AcW5:D@Q0aS00<8@P0336<8@PaS00<8@P8@
Q00336<8@PQ200<48@0424848@@Q1246248236<010Q236<<H`aS0PQ20PaS
00<@Q1BU6<H00Q2400<8@PaS36<010aS0Q2400<<H`Q224801@Q200H48@Q2
36<8@PaS248336<248@236<2248236<01A2436<@Q0aS48@00`aS1PQ200D4
8@aS48@@Q0aS0088@P0336<8@PaS0088@P8<H`8DY@0:36<8@P@Q1248@PaS
5:DHaQBU36<52484124224800`@Q24848@041242248010aS2488@PQ20`aS
00@@Q0aS24848@H8@P0336<@Q124008@Q00636<@Q1S66<HDYA240PaS0a24
0PaS00<8@PaS36<00Q2400<<H`Q2248030Q201T<H`Q2248@Q1BU7>LDYAS6
7>LicTYBG_MW>E:DAS4mkb486<H<HaBU36<8@P@Q24848@0224800`@Q2484
8@06248236<00a2436<<H`05248348@00`aS12448@0312401PaS48@<H`Q2
1248@P@48@<8@P0;1248@PaS5:DLib487>LDYAS67>LU:@028@P00acW8@PQ
2002:DX2;F/0136<;F/]Jbe[0RU:00@aS3F]?Nle[@8aS003;F/aS3F]008e
[@03<H`e[C6<008aS0@]J`<aS08]J`04<H`icSg_>Lh2<H`2>Lh00d8@>Lhi
cP02>Lh2<H`01cF]>LhicSW>=JdaS3F]008mk`04>Lhe[C6<=Jd2>Lh01Sg_
>LhicSg_>Lhmk`<icP04?NlicSW>=Jd5>Lh2?Nl2@Q03?Nl00d8@?NlicP02
>Lh2=Jd2>Lh2?Nl4>Lh01D8@?NlicSW>=Jd00SW>00@mkcW>>LhicP8mk`8e
[@03<H`icSW>00DicP03?NlicSW>00@icP@e[@8mk`05>Lhmkd8@@Q0mk`04
>Lh00cg_>Lhe[@03>Lh3=Jd00c6<=JdaS002=Jd00cg_>Lhmk`06>Lh01SF]
?Nm6<D8@?NlicP924004>LhaS36<=Jd2>Lh2=Jd0136<=JdicSF]0SW>00@m
kcW>?Nle[@8icP<mk`03=JdaS3W>008icP03=JdaS36<00<icP8mk`92408m
k`U24096<@05?NlicSW>?Nm6<@02@Q001TYBCW=>LdHaBU92404aS00000<0
00@Q12400P@Q00<000@Q12400`@Q00L8@RDY@Q0YBQcW9BT]J`03:DX2;F/5
:DX29BT28@P2:DX01BDY8@PLib489BT012U:00XU:B48:DXYBRe[:DXU:AcW
8@PLi`<U:@8YBP8Q208Li`049BTQ22488@P29BT38@P29BT48@P012U:;F/Y
BRDY0R480RU:00<]JbU:8@P00RU:00@]JbU:8@PLi`DQ20049BTYBRDY:DX2
=Jd02e:DE[EF]E:DBU9>Le:DBU8icRDY8@P00Q2400@8@P@Q2488@P8<H`<8
@P@<H`0324848@@Q0088@P<48@0324848@Q20088@P0436<8@PaS248236<3
248336<35:D00a2436<8@P0436<02@Q236<@Q12436<8@P@Q24848@022480
1@@Q2488@PaS248010aS00D@Q0aS36<<H`Q200L<H`0448@<H`aS36<22480
10aS248<H`aS0PQ20PaS00D@Q0aS2488@PaS00<8@P0536<@Q12448@DY@02
36<2124236<00a245:D@Q00236<010Q236<8@PQ20P@Q00L8@P@Q12448@Q2
1248@P04124224801PaS2488@PQ236<@Q0<<H`03248<H`Q20088@P031248
@PQ200<<H`8@Q00336<@Q124008DY@8@Q08<H`8@Q0D<H`0348@<H`aS00@8
@P8<H`88@P031248@PaS0088@P8<H`0B24848@aS7>LQ21BU6<HLicg_DYAJ
eVLiDYA243W>7>LHaQ240PaS00<8@P@Q12400PQ200D48@Q212448@000088
@P0336<8@PQ200<<H`@8@P8<H`05248<Ha2448@<H`04124010Q236<@Q124
0PQ21P@Q0`Q20PaS00<DYAcW7>L011S60b4800DU:B488@PU:BU:00<]J`08
:DXaS2U::DX]Jc6<>Lhe[@8aS003;F/aS36<00TaS08]J`<aS004;F/YBRU:
=Jd3>Lh00c6<=JdicP02>Lh013g_>LhicSF]0S6<00He[CW>>Lhe[C6<=Jd5
>Lh3=Jd00cW>=JdicP03>Lh013F]>LhicSg_0SW>00<e[CW>>Lh00cW>00<m
kcW>@Q000T8@00@mkcW>?Nlmk`8icP0;?NlicSW>=JdaS3W>?Nm243g_>Lhe
[@03>Lh023g_=Jde[CW>@Q0mkcW>=Jd3>Lh4=Jd3>Lh00cF]>LhicP02>Lh0
0cF]>LhicP03>Lh2<H`01CF]>Li243W>?Nl00T8@0SW>00<e[CW>?Nl01SW>
00@e[C6<;F/e[@<aS08e[@03>LhmkcF]008icP04=JdicSW>>Lh2@Q02?Nl0
0cW>?Nlmk`02=Jd00c6<>LhicP02=Jd2<H`3=Jd3>Lh013g_>Lhe[CF]0SW>
00=243W>=Jd00S6<0SW>00@e[C6<<H`e[@<icP<mk`=24003?Nm2448@00M2
4003>Lhe[CW>0096<@05@Q0mkdHaCW=:DP02AS41@Q01<H`00005124000@Q
1240000512403000248Q248@;F/Lib489BTQ22DY:DX]J`<YBP03;F/YBRU:
008YBP<U:@<YBP059BTQ22489BTYBP02;F/012U:8@PQ22U:0Re[0RDY0R48
1BDY00<Q21cW8@P00bDY00<Lib488@P00RDY0R4800@HaQcW7>LQ208U:@05
8@PU:BU:9BTQ20039BT28@P012DY8@PQ22480bDY00@LiaS67>LQ20<YBP8U
:@8Q2006=Je245[FG_MBU5Je0Tic00=6<CW>:DX00QcW00<@Q0aS24800PQ2
00@<H`Q22488@P<48@88@PH48@0324848@@Q00848@H8@P0536<8@PQ2248<
H`0348@25:D348@00`aS48@@Q00236<2248348@22482124324800`@Q248<
H`0836<01a247>LU:BU:8@PDYAS600<@Q08<H`88@P031248@PQ2008<H`04
248<H`Q236<524800a2436<<H`0236<0112436<8@PQ20P@Q00L8@PaS48@D
YA2436<8@P021242248212401P0012448@Q21248@PD48@88@P051248@PQ2
248<H`02248336<224800`aS2488@P02248248@00aBU48@@Q00348@011BU
48@<H`Q210aS11240aBU00D@Q0Q2248<H`Q2008<H`L8@P0;36<@Q12436<8
@PaS248<HaBU6<I24002JeX015kg<H`HaQcW0QBU00@<H`Q224848@@8@P84
8@<8@P848@0424848@aS248448@436<01A2436<<H`Q236<010Q200<<H`Q2
36<00PaS0PQ20`@Q0PQ200H48@Q2248@Q1BU7>L46<H011cW8@PYBRe[12DY
00<]JbU:;F/00cF]00<aS2U::DX00RU:00<aS3F]<H`00Re[00<aS3W><H`0
0c6<0SF]0S6<0Re[00@e[CW>>LhaS08]J`8icP03=JdicSF]008e[@8icP05
?Nm2448@?NlicP04=Jd3>Lh2=Jd01CW>=Jde[C6<=Jd00S6<00@]JcF]>Lhi
cP8e[@03>Lhmkcg_00@icP03?Nle[CF]008e[@@mk`8icP04?NlicSg_?Nl2
>Lh00cg_=Jde[@02>Lh00d8@?NlicP03=Jd01CW>=Jde[CW>?Nl01CW>00Hm
kcW><H`aS3F]>Lh3=Jd01CW>@Q0mkcg_>Lh01CF]0cW>00De[C6<=Jde[Cg_
0092408mk`06=JdicSg_?Nm243g_0SW>00PmkcF]>Lh]Jc6<;F/aS3W>0SF]
0SW>00<e[CW>=Jd01CW>00E244Ha@Q0mkcF]008icP03=JdicSg_008mk`0?
>LhaS36<=JdicSF]<H`e[CW>@Q0mkcW><H`]JcF]00<mk`8aS004=JdicSg_
?Nl3=Jd00cW>?Nm24002?Nl01CW>@Q1244HaBU80148@00I6<DYBBU96<DYB
@Q02?Nl00dHaBU924002@Q001DYBCW=:DTYB@Q000Be[000212400`001244
8@0412401`001248@RDY@Q0]JacW008U:@8Q20039BT]Jbe[00DYBP049BTQ
22DY9BT2:DX012DY8@PQ22480bDY0Re[00@U:B488@PYBP8]J`039BTQ2248
008Q20049BTQ22DY9BT28@P00acW8@PU:@028@P01AcW9BTQ22489BT00R48
0acW0R4800<U:BU:9BT00b480RDY1R4800`YBRDY8@PLiaBU7>LU:BU:;F/Y
BQcW9BT28@P013W>@Q1JeU[F0U:D0Tic00=6<C6<;F/00QcW00<@Q0aS1240
0PQ200<48@Q2248010Q20`@Q00<8@P@Q12400`@Q0`Q210@Q0`Q200<48@Q2
24800`aS112400<DYA2436<00PaS0Q2400D<H`Q2248<Ha24008<H`032484
8@Q200<48@05248<H`Q236<8@P0436<0212436<<HacW9BT]Jb485:D248@0
10aS48@<H`aS10Q200D<H`Q236<<H`Q2008<H`88@P031248@PaS00L<H`<8
@P031248@PaS00<@Q00324848@@Q0088@PL48@88@P061248@P@Q1248@P@Q
1`Q20PaS00@8@PaS248<H`D8@P0436<@Q1245:D248@25:D348@236<22480
0`aS48@DY@0248@011BU6<H<H`aS0PQ200D<Ha2436<<H`@Q0088@P041248
@PQ2248248@236<04PQ236<<H`@Q6<HLidHaKg][FU:D;F/HaQcW6<H<H`Q2
36<8@P848@H8@P051248@P@Q24848@03248448@636<2248010aS2488@P@Q
0PQ200<<H`Q236<00PQ21`@Q00<<H`Q248@00QS600dLiaS65:DHaR487>LY
BRe[:DXU:B489BTYBP02;F/0136<=Jde[C6<12U:00<aS3F]<H`00Re[00<a
S3F]=Jd00Re[0cF]00P]Jc6<;F/YBS6<=JdicSF]0S6<00<e[CW>>Lh00cF]
0cW>00<mkd8@?Nl00SW>13F]00<icSF]>Lh00SF]00@aS3F]=Jde[@8aS08]
J`<icP8aS003>LhmkcW>00@icP<e[@03<H`e[CW>00<mk`<icP03?Nm243W>
00<icP8e[@8icP92408icP04<H`e[CF]=Jd2>Lh00d8@>LhicP02=Jd3>Lh0
0cF]<H`aS002=Jd3>Lh01Cg_@Q0icSW><H`00SW>00@e[CW>>LhicP8e[@04
<H`e[CW>?Nl2@Q001Sg_>LhaS3F]>Li2408mk`@icP8aS003;F/aS36<008e
[@8icP<e[@04<H`e[C6<>Lh2?Nl2@Q0013g_>Lhe[CF]13W>00<mkcW>>Lh0
0S6<0SF]0SW>00De[CW>>Li243W>00<aS003>LhmkcW>00@e[@<icP03<H`e
[CF]008mk`8icP05?Nm2448@@Q16<@04@Q05BU800d8@?Nm24004@Q000dHa
BU9:DP02BU81@Q01;F/0000500048@@Q1240000612401@Q28@Pmkbe[7>L0
0RDY0b4800<U:Be[;F/00bU:0Re[00<YBRDY8@P00bU:00@U:B487>LQ208U
:@8YBP0:9BTYBRDY8@PU:BU:;F/YBRDY8@P39BT2:DX012DY7>LQ22DY0RU:
124800<U:B488@P00b4800@Lib488@PU:@DQ20<Li`038@PU:BDY00<Li`8U
:@047>LHaR48:DX2<H`01BDY8@PU:BDY8@P00Re[00A6<E:DG_MS609JeP07
E[E6<CW>=JdicRDY6<H01@Q200<48@Q2248010@Q00<8@P@Q12400`@Q00<8
@P@Q12400P@Q0PQ200<48@Q224800PQ200@48@Q224848@88@P0536<@Q1BU
48@<H`025:D03Q2436<48@@Q24848@Q25:DHaQ2424848@Q21246248536<0
1A2436<DYBU:=Jd00UJe00MJeV]J?NlU:@aS124@Q00224800`@Q2488@P05
24800`@Q2488@P02248336<348@236<324800`@Q36<<H`0248@010aS2488
@P@Q0PQ200<<H`Q224800P@Q00<8@P@Q12401P@Q00H8@P@Q248<H`Q21242
248336<010Q236<<Ha240`Q200H48ABU6<HLiaBU36<548@00`aS2488@P02
36<548@35:D436<01Q242488@PQ2124<H`<8@P8<H`0548@<H`aS248<H`02
248248@01bU:>Lhe[Be[6<H@Q1BU008@Q088@P@48@03248<H`Q200<48@88
@P<48@06248<H`aS48@DYAS60QBU00D<H`Q22488@PaS00L8@P<48@D8@P84
8@88@P8@Q0075:DHaQcW6<HDYAS68@P012DY00XYBRe[:DXYBRe[:DX]Jc6<
;F/aS0<]J`04:DXU:BU:;F/2<H`2;F/3<H`2;F/01S6<=Jde[C6<;F/aS0@i
cP<aS003;F/aS3F]00<icP03=JdaS3F]008mk`07>LhaS3F]>Lhe[CW>=Jd0
0cW>0SF]0c6<0SF]00D]Jc6<;F/aS3W>008e[@03<H`icSW>008mk`8icP04
=Jd]JcF]=Jd2?Nl2>Lh00cg_>LhicP02>Lh3?Nl00cF]>LhaS002<H`00cF]
>Lhe[@02>Lh013F]<H`e[CF]0SW>00DmkcW>>LhaS3F]008icP08=JdaS36<
=JdicS6<=Jdmk`=240@icP0:?NlicSF]>Lhe[CW>=JdaS3F]>Lh2@Q000cW>
<H`e[@04>Lh2?Nl00d8@?NlicP02=Jd4<H`013F]?NlicSF]0Re[1CW>0T8@
00I6<D8@>LhmkcW>?Nl2>Lh3=Jd3>Lh2=Jd2>Lh2=Jd013W>@Q0mkcg_0cF]
00<icSg_>Lh00SW>00De[CW>=Jde[CW>00<mk`05>Li2448@@Q0icP02?Nl0
14YBAS56<DHa0T8@00E6<DYBBU9>LdYB0096<@924096<@03BU96<DHa009:
DP5>L`56<@4e[@000`@Q00@000@Q124000<48@060008@R48@Q0YBQS60RDY
0R4800<U:BU::DX00bU:00@]Jc6<;F/YBP8U:@8YBP8U:@@Q20039BTYBRU:
008U:@8Q20059BTYBRe[:DXQ20029BT28@P29BT38@P00bDY:DXU:@048@P0
0bDY8@PLi`057>L68@P00acW8@PHaP027>L28@P27>L48@P00aS67>LYBP02
=Jd00bDY7>LQ20028@P01RU:;F]:DU:DG_MS609JeP07E[E6<CW>=JdaS248
7>L01PQ23P@Q00<8@P@Q24800P@Q1PQ200@48@Q2248<H`88@P0336<@Q124
008@Q0035:D<H`Q200848@0324848@aS00<DY@0336<48@Q200<8@P051248
@PQ236<8@P0436<248@02ABU:DXaS5[FE[ENmfLi=JdQ200224801Q242484
8@@Q248<H`L8@P031248@PaS008<H`0448@<Ha2448@236<010@Q2488@PQ2
0PaS0Q2400<<H`Q224800P@Q10Q230@Q1@Q200D48@Q236<8@PaS0088@P08
48@<H`aS24848@Q248@DY@8HaP0348@<H`aS008@Q0<<H`05248<H`aS48@<
H`0248@35:D248@01@aS48@@Q0Q236<020Q200<@Q0aS48@010Q201448A24
5:DYBSW><H`YBQS636<@Q1BU48@<H`Q21248@P@Q00<8@P031248@PQ200<4
8@0324848@@Q0088@P035:D@Q1BU008DY@0348@<H`@Q00P8@P031248@P@Q
00D8@P@48@05248<HaBU48@DY@027>L01ABU48@HaQcW:DX00RDY1RU:00<]
Jc6<;F/00Re[00<aS2e[;F/00RDY0Re[00<aS2e[;F/0136<0Re[00<aS3F]
<H`00Re[00@aS3F]>Lhe[@8aS004;F/aS36<<H`2=Jd013g_=JdaS36<13W>
0SF]00<icSF]=Jd00SF]0SW>00<e[CW><H`0136<0Re[00<aS3F]=Jd00cF]
00@aS3W>>Lhmk`<icP05=JdaS3W>>Lhmk`02=Jd00cW>?NlicP02>Lh00d8@
?NlicP02>Lh4<H`3=Jd00cW><H`aS002;F/01SW>?NlmkcW>=JdaS0<e[@<a
S003=JdicSF]008icP04@Q16<D8@?Nl2>Lh2?Nl013W><H`e[CW>0SF]0Re[
00@icT8@@Q0mk`8e[@03>Lhe[CW>00Hmk`8e[@<aS009;F/e[CW>>LhaS2e[
<H`e[CW>008e[@05>Li2448@@Q0mk`02>Lh2?Nl013W>=JdicSF]1CW>00@e
[CW>=Jde[@8icP8mk`09>LhaS3F]=JdicSg_>Lhe[CW>00@e[@03>Lhmkcg_
008mk`03@Q16<Cg_008icP03?Nm6<DYB0096<@924096<@9:DP03CW=:DTHa
00924003AS5:DTHa00=6<@9>L`56<@4aS00000<000@Q000020@Q00D8@QcW
@Q0aS1cW008Q20039BTYBRDY008YBP8]J`03:DX]JbU:008YBP<U:@8YBP8Q
20067>LU:B488@PU:BU:0Re[0R4800DLibDY:DX]JbU:00<Q20<U:@0:8@PL
ib488@PU:B487>LHaQcW6<H67>L00aS67>LLi`027>L012487>LQ21cW0R48
00@Lib488@PLi`8Q20077>LQ22DY:DXU:B489BT012U:00<]JbU::DX00RU:
00<icSg_CW<00Ukg00A[FVLiG_MF]@96<@09=JdaS1cW6<H<H`@Q24848@Q2
00`48@0424848@Q2124224800`@Q248<H`02248010@Q2488@PQ20P@Q00@8
@P@Q36<@Q08DY@0348@8@PQ200848@0424848@aS48@25:D00a242488@P03
248736<248@03acW9BTYBS6<;F/aS2U:BU9F]E[FG_LaS1S636<48@032483
124010Q21248@P@Q0PQ200<48@Q224800`Q200<<Ha2448@00`Q200<<H`Q2
24800Q2400<<H`Q212400PQ200H48@Q236<@Q0aS24821242248212400`00
12448@03124010Q236<<H`Q20P@Q00<<Ha2436<00PaS00<8@PaS24800`Q2
0a240`aS0Q240PaS00<@Q0aS24800Q2400<DYA2448@00Q2400HDYAS648@8
@PaS48@26<H236<01PQ21248@PQ236<@Q08<H`@8@P848@04248<H`Q236<2
5:D00a2436<@Q00236<00`Q212448@02124236<32482124224800`@Q2484
8@0424800a245:DDY@0236<7248010@Q2488@PQ20P@Q00@8@P@Q24848@@8
@P04124<Ha246<H25:D01QcW8@PHaQBU7>LU:@8YBP8U:@03:DXU:Be[00<]
J`06:DX]Jc6<;F/aS2e[0RU:00/]JbU::DXYBRe[=Jd]JbU:;F/e[C6<008]
J`06<H`e[CF]<H`icSF]0S6<00De[CW>=Jde[C6<00<e[@03<H`e[CF]00<e
[@<icP8e[@07<H`e[CF]=JdicSg_>Lh00c6<0SF]00DaS2e[<H`]Jc6<008e
[@<icP8e[@8icP0<?NlicSF]=JdicSg_>Lhe[CW>?Nm6<DYB0Sg_00DicSg_
@Q0icSF]00@aS08icP8mk`05=JdaS36<<H`e[@05>Lh2=Jd00c6<=JdicP02
=Jd0136<=JdicSg_1CW>0cg_00=243W>=Jd00S6<0SF]0SW>00<mkcW>>Lh0
1SW>0Sg_0cW>0Sg_00@icSF]<H`aS0@e[@04<H`mkd8@>Lh2=Jd013W>AS56
<Cg_0cW>00A243g_?Nlmk`LicP04=JdicSW>>Lh3=Jd01CW>@Q1243g_>Lh0
0cg_0SW>0SF]0SW>00Dmkd8@AS56<DYB0096<@<icP05?Nm6<D8@@Q16<@02
@Q02AS400dYBCW=:DP02AS42@Q002DHaBU9>LdYBAS5:DTicDYA>L`01=Jd0
00D48@0300048@@Q00<48@06248Q23g_;F/Lib4812DY0RU:00<]JbU:;F/0
12U:0RDY00@Q22DY9BTU:@DQ208U:@8YBP049BTLib488@P2;F/03BU:8@PQ
22487>LU:B489BTQ21cW8@PLib48008Li`046<HLiacW8@P27>L26<H87>L0
0b487>LQ20068@P01acW9BTYBRU:9BTQ22DY008YBP8U:@DYBP0?>LhmkeJe
F]IS66]JIcUNmeJeAS4mkc6<=JdLiaBU0088@P0336<48@@Q00D48@030004
8@@Q00@48@88@P031248@PQ200<8@P848@0324848@Q200848@0324848@Q2
0088@P0448@DYABU36<324801@@Q24848@Q248@00QBU00<<H`Q224800PQ2
0`aS00P8@PaS48@DY@aS48@DYAcW0RU:00/]Jc6<<H`]JdHaE[ENmeJe9BTH
aPaS00<8@P<48@0324848@Q200<8@P041248@PQ2248336<248@236<21240
10Q236<@Q1240PaS0`Q20P@Q00@8@PaS36<<H`848@88@PH48@040008@PQ2
36<5248236<248@010Q236<<H`aS0PQ20PaS00<@Q0aS36<00a2400<<Ha24
36<010aS00<@Q1BU48@00Q240aBU0`aS00D@Q1BU5:D<H`Q200848@88@P<<
H`88@P041248@PQ21243248236<348@010aS248<H`aS0PQ20P@Q1@Q20P@Q
00@8@P@Q2488@P848@88@P03124<Ha24008DY@8<H`L8@P031248@P@Q0084
8@0624848@@Q1248@PaS10Q200@@Q1BU5:DDY@8HaP077>LHaQS67>LU:Be[
:DX00RDY00@YBRe[;F/aS0H]J`03<H`]JbU:00<YBP039BTYBS6<00@]J`06
<H`]Jbe[;F/aS3F]0S6<0SF]0S6<13F]00@aS3F]=JdaS0<e[@03<H`e[CF]
008icP<e[@8aS08e[@8icP@aS003=JdaS36<008aS004;F/aS36<=Jd3>Lh2
=Jd013W>?NlicSW>0SF]00HicSg_>LhaS3W>?Nl2BU800cg_>LhicP03?Nl0
1SF];F/aS2e[=Jdmk`<icP05=JdaS36<<H`icP03=Jd013g_>LhicS6<1cF]
0SW>00DmkcW>>Lhe[CW>00@mk`8icP<aS005=JdicSW>>Lhmk`04>Lh2=Jd4
?Nl2>Lh01cg_>LhaS36<;F/aS3F]008icP8aS009>LhmkcW>=JdaS3W>@Q16
<D8@00<icP05@Q0mkcW>>Lhmk`04>Lh4=Jd3>Lh023F]>LhicT8@?NlicSg_
>Lh2?Nl2>Lh2<H`2>Lh2@Q002DHaBU96<DHa?NlicSg_>Lhmk`06@Q02AS40
0dYBCW=:DP02AS42@Q000dHaBU9>L`02AS4014YBCW=F]DYB0CW>00001@00
124000@Q00001@@Q00L000Q27>M2436<7>LQ2002:DX0136<;F/U:BU:0Re[
00HYBRDY9BTU:BU:9BT37>L29BT38@P27>L01B489BTYBRU:8@P00QcW00TQ
22U::DXU:AcW6<HDYAcW8@P01QcW0QS621cW00<Q21cW7>L00R4800<Lib48
8@P00RU:0RDY00DYBRDY8@PQ21cW008Q20TU:@8]J`09<H`]JbU::DXaS2e[
>Li6<EJe009W>@06JeYW>EkgE[E>LdHa0S6<00DHaPaS12448@Q200`48@88
@P8@Q00736<8@PQ2248<Ha2436<00`Q200<48@Q212400P@Q00<8@PaS48@0
0QBU00@@Q0aS12448@88@P8@Q08<H`03248<H`Q2008<H`0824848@aS6<HL
iaS636<@Q08Li`0>;F]6<DYBE[EBU48@BU8aS2DY;F/icSg_;F/@Q088@P03
1248@P@Q00<48@0324848@Q200@8@P041248@PQ2124436<3248020@Q36<@
Q1BU48@8@P@Q24821242248348@010aS24848@Q21P@Q00<000@Q24801PQ2
00@DYA2448@<H`88@P0336<8@PQ200<8@P@<H`0348@DYABU008HaP8DY@0=
7>LQ22487>L<H`Q248@HaQcW5:D<H`@Q24800Q2400@DY@aS2488@P8<H`03
248<Ha24008<H`<8@P848@88@P041248@PQ236<32482124224800`@Q2484
8@0236<224800`@Q24848@0424800`@Q2488@P0236<224800`aS24848@02
124424800`@Q24848@071244248010aS48@HaQBU11cW00<HaR48:DX00bU:
0Re[00<YBRDY9BT00RU:00@]JbU::DXYBPL]J`8YBP8]J`04<H`]Jbe[<H`2
=Jd00c6<;F/]J`02<H`2>Lh01SF]<H`aS36<>Lhe[@8aS003=JdaS3F]00@a
S0<icP06?NlicS6<<H`]Jc6<0SW>00<e[C6<=Jd00cW>00<e[C6<<H`00S6<
0Re[00PaS3F]>LhicSF]<H`icSF]0Sg_00<icSF]=Jd00SW>00@mkcF]>Lhi
cP@mk`8icP04=JdaS3F];F/3<H`01Sg_@Q1243g_<H`YBP8]J`8icP07=Je2
44Ha@Q0icSF]>Lh00T8@00@icS6<=Jde[@<mk`8icP@e[@06@Q1:DTHa?Nle
[C6<0cF]1cW>00@mkcF]=JdicP@e[@<icP8e[@03>Lhmkd8@008mk`8icP04
@Q0icSF]=Jd3>Lh00cF]>Lhe[@02=Jd2>Lh01Cg_>LhicSg_>Lh00Sg_0SW>
00@e[CW>>LhicP8e[@04>Lhmkcg_?Nl3>Lh01cg_@Q0mkcW>=JdaS3W>008m
k`05>Li6<DYBAS524002>Lh0148@?Nm244Ha148@0THa0T8@1THa00=:DTHa
BU800dYB0E:D0DYB0CW>000;12401`Q28@Q2436<6<HQ22DY008]J`05:DXU
:BU:;F/YBP059BT28@P00acW9BTQ20038@P022DY7>LLib489BTYBRDY6<H2
7>L02R489BTYBR487>LHaQBU6<HLib480QcW0QS60acW00DHaQcW6<HLiaS6
008Li`038@PLiacW00@Li`038@PU:BDY00HU:@8Q20037>LQ2248008U:@06
8@PU:B489BTYBRDY0Re[00@aS2e[:DXYBP8]J`07?Nm6<EJeJeYW>FmkHaP0
0U[F00M6<D8@;F/YBQBU36<8@P0412400`0012448@0712400`Q236<@Q002
48@3248236<01@Q212448@@Q24800P@Q00<8@P@Q24800PaS0QS600@<H`Q2
12448@88@P0336<@Q124008<H`88@P0836<@Q0Q2124<HaS69BTHaP8<H`07
6<HQ236<BU9>LeJeCW<00THa00<]Jb48:DX00Sg_00@]J`aS1248@P@48@88
@P061248@PQ21248@P@Q0`Q200<48@Q224800PaS0PQ200P48@Q2248<Ha24
5:D@Q0Q210@Q00H8@PaS36<<H`Q236<2248512401@0012448@@Q24800PaS
0`Q20PaS00<DYA2436<00PQ20PaS0`Q210aS00D@Q0aS48@DYAS600<DY@04
6<HU:B486<H236<02Q246<HHaPaS24848@aS48@DY@aS0`Q200@<H`Q236<<
H`8@Q088@P03124000@Q0088@P031248@P@Q0088@P0336<8@P@Q00848@X8
@P848@<8@P031248@PQ200<8@P8<H`0524848@@Q24848@05248712400`Q2
1248@P02248336<00aBU6<HLi`036<H28@P00bDY:DXYBP07:DX012e[:DXU
:BDY0be[0RU:00HaS2e[:DXYBRDY;F/2<H`01Be[:DX]JcF]<H`00Re[00Ha
S3F]=Jde[CW><H`2;F/00c6<>LhaS002<H`00cF]>Lhe[@03<H`01cF]>Lhi
cSW>?NlicS6<008]J`03<H`icSW>008e[@06<H`e[CW>>Lhe[C6<0Re[00<a
S2e[;F/00S6<00<icSF]<H`00SF]00@icSg_?NlicP<e[@03?NlicSW>008i
cP06@Q0mkcW>>Lhe[CW>0SF]00<aS2e[;F/00S6<0T8@0SW>0be[00LaS3W>
=Jde[D8@AS524003>Lh2?Nl4=Jd00cW>?NlicP02>Lh4=Jd0148@AS52448@
0S6<00<e[C6<=Jd00cW>00DmkcW>>LhicSF]008icP<e[@05<H`e[CF]>Lhe
[@02<H`013F]?Nm243g_0SF]00<icSg_>Lh00c6<13F]00<aS3F]>Lh00SW>
0cg_1SW>0SF]0SW>0SF]00DicSg_@Q0icSF]008icP8mk`03@Q0e[C6<008e
[@0;@Q0icSg_@Q1:DTHa@Q0mkcW>@Q0mk`04@Q000cg_@Q124002@Q001DHa
@Q16<D8@AS400TYB0dHa00E:DTHaBU9>LdYB004icP0000L000@Q00048@00
1240000412403@Q28@Q242e[7>LQ22U:<H`e[Be[9BTQ22U:00@U:@8Q2004
7>LHaR487>L38@P27>L26<H27>L58@P00acW8@PQ20028@P26<H27>L00aS6
7>LLi`057>L48@P00bDY8@PU:@029BT38@P012DY8@PQ22DY0bU:0RDY0RU:
00LU:B489BTYBRe[:DXU:@068@P01Re[<H`e[C6<:DX]J`8YBP8e[@07AS5B
U5JeJeY_Nf]JHaP00U[F00E6<D8@8@PLia240088@PX48@0324848@Q2008@
Q0055:D<H`aS248<H`0424800`aS2488@P0224802@@Q2488@PaS48@HaQcW
6<HDY@0236<224801@aS48@@Q1BU36<00Q2400@<H`Q224848@8<H`@@Q007
9BTicTicMke_Ng_NMkd00VLi00=243g_8@P00QBU00<HaQcW48@010@Q00<8
@P@Q00000P@Q0PQ20P@Q0PQ200D48@Q2248<H`Q2008<H`031248@P@Q0088
@P0336<8@PQ200@8@P041248@PQ236<248@00`aS2488@P07124010Q21248
@PQ20PaS0PQ200<<Ha2448@00PaS00@8@PaS24848@88@P0@36<8@PaS36<@
Q0Q248@Libe[G_MS65JeBU8U:AcW6<H25:D00a2436<8@P02248312422482
36<00`Q236<8@P0436<0112436<8@PQ20`aS0PQ20`@Q00H<H`Q236<<Ha24
36<2124224801@@Q248<Ha2436<01@Q200D<H`Q21248@P@Q00@8@P@48@03
24848@@Q00848@0524848@@Q1240000412401`Q212448@aS5:DQ21cW00<H
aP047>LU:BDY9BT4:DX01be[<H`]JbU:9BTYBRe[00@YBP04<H`e[C6<;F/3
:DX00bDY;F/]J`02<H`3:DX02C6<>Lhe[Be[:DXaS3F]<H`e[@02<H`2;F/2
<H`3=Jd4<H`01Be[=Jde[D8@AS400T8@00Lmkc6<<H`]Jc6<=JdaS002=Jd2
>Lh2=Jd2<H`00cF]<H`aS002;F/01S6<=Jde[CF]>Lhe[@@mk`03>Lhe[CW>
00<icP03=JdicSg_008icP8e[@06>Lhe[CF]=JdicSF]0S6<00<e[Cg_>Lh0
0SW>136<00/e[C6<=Je:DTic@Q0e[C6<@Q1:DT8@00LicP8mk`8icP03=Jda
S3g_00=2400<>LhaS36<;F/aS3F]>LhmkcW>=JdaS3W>0Sg_00@icS6<<H`a
S0@e[@8icP8mk`8icP03=JdicSW>00<e[@03>Lhe[CF]00<e[@03<H`e[CF]
008e[@8icP04?NlicSF]>Lh7?Nl01SW>=JdicSF]?NlicPDmk`8icP03?Nli
cSW>008e[@09>Li2448@?NlicT8@?Nm243g_00E2400:AS5244HaAS5:DTHa
BU9243g_@Q02AS400dYB@Q1:DP03BU82CW<1>Lh000X48@080008@R48?Nl]
JacW8@P]J`8e[@03;F/U:B48008YBP039BTQ22DY008Q20DLi`038@PLib48
00<Li`036<HLib4800HLi`048@PLiacW8@P36<H77>L28@P01BDY8@PU:B48
9BT0224822DY00@YBRDY8@PU:@8YBP06;F/U:BDY8@PLib480RDY00@]Jc6<
<H`aS0<YBP049BTaS3W>BU82E[D3JeX02EkgF]IF]DHa>LhQ21cW36<8@P04
12400`0012448@0612401@aS48@DYAS648@00PaS2@Q200<48@Q224800PaS
00<@Q1S66<H00QS60`aS00@8@PaS48@DY@<@Q0<<H`061248@PaS36<@Q0aS
0QBU00<U:CW>E[D00W>L00Mg_G>LIcUW>Cg_>LhQ20025:D26<H01@aS1240
00@Q248010@Q0PQ20P@Q00D8@P@Q1248@P@Q0088@P0336<8@PQ200D8@P8<
H`<8@P0536<48@Q21248@P0436<00`Q21248@P0912401`Q236<8@PaS248@
Q0aS008@Q08<H`0324848@@Q00<8@P0<36<8@PaS48@8@PaS8@Pe[FLiHaQB
U4ic0R4800TDYAS65:D@Q0aS1248@P@Q24800`@Q00P8@PaS36<<H`Q236<8
@PaS0a2400<<H`Q224800PaS0PQ20`@Q00@8@P@Q2488@P8@Q088@P031248
@PQ20088@P@<H`<8@P0936<8@PQ224848@Q21248@P@Q0088@PD48@052484
8@Q21248@P0612401PQ212448@Q248@DY@8Li`045:DHaQcW7>L49BT3:DX3
;F/00bU:9BTYBP02:DX01be[9BTYBS6<=JdaS2e[00DYBP04;F/aS36<;F/2
:DX00c6<>LhaS002;F/00c6<>Lhe[@02<H`2;F/00c6<;F/aS002=Jd2<H`0
1be[<H`aS36<=JdicT8@008mk`07@Q0icS6<;F/YBS6<=Jd00S6<0SW>00Hm
kcF]<H`]Jc6<=Jd2<H`012U:<H`aS36<0cF]0SW>00<mkd8@>Lh013W>00@e
[CW>>LhicP<e[@<icP05<H`e[CF]>Lhe[@03<H`013W>?Nm243W>136<0SF]
00@icTHaCW=2408e[@03@Q1:DT8@00HicP8mk`8icP8e[@03<H`mkd8@0092
40<aS006;F/aS3F]>LhmkcW>0cF]0SW>0SF]00DaS3F]=JdaS3F]008icP06
=JdicSg_>Lhe[C6<0SW>00<e[C6<=Jd00SW>00Le[C6<=JdaS2e[<H`e[@02
>Lh2=Jd2>Lh00cF]>LhicP03>Lh3?Nl2>Lh00cF]>LhicP03>Lh00cg_@Q0i
cP02?Nl2>Lh023F]<H`e[Cg_@Q0mkcW>?Nl2@Q001Cg_>Lhmkd8@?Nl00THa
00E244Ha@Q16<DYB0096<@06?Nm2448@AS5:DT8@0THa00E:DTHaBU9>LdYB
004icP0000D000@Q00048@0000@48@0:00048@Q27>LicRU:7>LU:Be[:DX2
9BT012487>LLiacW0R481QcW00@Q21cW8@PQ20@Li`PQ20089BTQ22DY8@PU
:AcW8@PLi`@Q20039BTYBRDY008Q208U:@8Q20049BTQ22DY8@P29BT28@P0
1RU:<H`]Jbe[:DX]J`@U:@8YBP03;F/YBRe[008YBPDQ20039BTYBRDY008a
S08]J`8YBP8aS005>LhmkdYBE[EJeP02Kg/2HaP2DY@2AS401Be[7>L@Q0@Q
24800`@Q00<000@Q124010@Q0PaS00<DYA2436<00Q2400L<H`Q21248@PaS
248<H`02248236<010Q236<8@Q240QBU00HaS3g_;F/Q20@Q248348@236<0
11245:D@Q0Q20P@Q0PQ20PaS014@Q0aS9BU245[FNmi_NgNmLiag_GooE[Dm
kaS65:D@Q0aS0088@P<48@0300048@@Q00D48@0300048@Q200848@88@P03
36<8@PQ200@8@PD<H`0424848@Q236<224800`@Q248<H`0236<224800`@Q
2488@P03124224831242248336<348@336<010Q21248@PQ20a240PaS010H
aRDY:DXU:C6<?NmJeU:DHaQcW4Ha:DX8@P@Q36<8@PD48@<8@P8<H`0548@<
H`aS36<8@P0536<01248;F/U:AcW0P@Q00@8@P@Q36<<H`@8@P<48@062484
8@Q236<DYA241@Q200<48@Q212400`Q200<48@Q212400`@Q00<000@Q1240
0`@Q00<8@P@Q12400P@Q00@8@P@Q24848@88@P0;36<DYAS67>LQ21cW6<HL
ibU:;F/YBP029BT3;F/2<H`2;F/012DY:DX]JbU:0be[00@e[CW>>LhaS0@Y
BP06;F/aS2e[<H`]JbU:0be[00TaS3F]=Jde[C6<=JdaS3F];F/00RU:0Re[
0c6<00Le[C6<<H`]Jc6<=JdaS003>Lh01Cg_>LhicS6<:DX00Re[00<e[Cg_
?Nl00SW>0cF]00<aS3F]<H`00S6<00<]Jc6<<H`00S6<00He[CW>?Nm243g_
@Q02?Nl013W>=Jde[CF]13W>00<mkcW>>Lh00SW>0SF]0c6<0SF]0SW>00Xe
[CW>>Lhe[C6<;F/aS3F]>Li2408mk`03>Lhmkcg_00924003?Nm243W>00@e
[@03>LhmkcW>008e[@03>LhmkcW>00HicP@e[@<icP07=JdicSW>>Lhe[CW>
=Jd00S6<00@e[CW>@Q12408icP04;F/aS3F]<H`3=Jd2>Lh2=Jd0136<=Jda
S3F]0S6<0SF]13g_00=243W>>Lh00SW>0d8@00<mkcW>>Lh00cW>00<e[CW>
@Q000d8@00XicSg_@Q16<Cg_>Lhe[CW>@Q0mk`<icP8mk`924006?Nm243g_
@Q16<D8@0dHa00=:DTHa@Q000Sg_0dHa00M244HaBU9>LdYBE[E>L`01=Jd0
00D48@0300048@@Q00<48@09248Licg_:DXLib48:DX]JbDY008Li`056<HQ
22487>LQ20027>L02R487>LQ22486<HLiaS68@PLib480acW0R480acW00<Q
21cW8@P00bDY0R480acW0b480RDY0R4800@Lib488@PU:@@Q20<U:@038@PU
:BDY00<]J`8YBPDU:@03:DXU:Be[008YBP049BTQ22487>L28@P012DY:DXY
BRU:0Re[0bU:0S6<00DicSg_BU9F]Ekg009[FP09IcUS64icDYA243g_;F/L
ia2400`48@04248@Q1BU48@336<4248236<010Q236<<H`aS0PQ20PaS00L@
Q1S65:D]Jcg_:DXHaP0224800aBU48@<H`0236<248@01@aS24848@Q236<0
0`Q20QBU00<U:D8@G_L00WNm00McW7NmNmiooe:D?NlDY@0248@224831240
0`0012448@0612400`Q212448@0<248336<2248010aS2488@P@Q0PQ20PaS
0`Q200<48@Q212401@@Q00D000@Q1248@PaS00<8@P<<H`8@Q00336<8@PQ2
00<8@P<<H`0@248<HaBU8@PYBRDY<H`icUJeF]IS66]J@Q0U:@aS12422487
124236<00a2436<<H`0436<020Q236<<H`Q28@PYBR486<H2124224800`aS
2488@P02248312401`Q212448@Q248@HaQ2400@8@P031248@P@Q00<8@P84
8@88@PH48@0324848@@Q00T48@05248<Ha246<HDY@037>L00aS68@PU:@02
:DX29BT01BU:;F/]Jc6<;F/00RU:00<U:BU::DX00Re[00<YBRe[=Jd00SW>
00DaS2U::DXYBRDY008]J`03<H`]Jbe[008YBP8]J`03<H`]JcF]00<e[@03
;F/aS2e[00<YBPLaS004;F/aS2e[;F/2=Jd2>Lh2=Jd01S6<;F/YBRe[<H`m
k`<icP05=JdicSF]=JdaS002;F/3<H`00be[<H`aS003>Lh4?Nl01CW>?Nle
[C6<=Jd00SW>0cF]0SW>00@e[C6<=JdaS08e[@8aS003=JdicSF]008icP04
=JdicS6<;F/2<H`013g_@Q1243g_0SW>0T8@0SW>00HmkcW>>Lhe[C6<>Lh2
?Nl01SF];F/e[CW>?NlicP<e[@8icP8e[@8aS003>LhmkcW>00<e[@03>Lhe
[CF]008icP0:;F/aS36<>Li6<Cg_=JdaS2e[<H`4=Jd013W>=JdicSF]0S6<
00@]JcF]<H`aS0De[@04>Lhmkd8@?Nl3>Lh2?Nl2@Q02>Lh00cF]<H`icP02
>Lh00cg_@Q124003?Nl2AS4013W><H`aS3F]0Sg_0cW>0Sg_00=243g_@Q00
1D8@00e6<D8@AS56<DYB@Q0icSg_AS5:DT8@?Nm6<@03CW<1DY@1BU81=Jd0
000300048@0000T48@048@PicRU:5:D38@P00acW8@PLi`027>L28@P27>L2
8@P00bDY8@PQ20029BT01BU:9BTYBRDY8@P00bDY12480RDY124800<U:AcW
7>L00bDY0R4800<U:B488@P00R4800<U:B488@P00QcW00LQ21cW8@PU:B48
9BTQ2002:DX012e[:DXYBR480QcW00<Q22DY:DX00RU:1BDY124800<Lib48
9BT00RU:0be[00<YBRe[<H`00cF]00A244YBHaQS609W>@9S6007F]IF]D8@
@Q0]JaS648@01P@Q00<000@Q12400`@Q0PaS00@8@PaS36<<H`D8@P<<H`04
248<H`Q248@236<01QBU7>LaS36<9BTQ208<H`0348@8@Q24008<H`8@Q005
36<8@P@Q248<H`0324803Q2436<Q23F]BU9[FV<HMkecW7NmNmi>LcW>5:D2
48@2248@124324801PaS48@<H`Q21248@P@<H`@8@PD<H`0348@<H`aS00P8
@P848@0424848@Q21242248736<00`Q236<8@P0324800`aS48@DY@025:D0
3B48<H`mkcW>?Nm243F]:DY245[FDYA241BU0088@P061248@P@Q124000@Q
0PQ200@@Q1S648@@Q088@P0536<8@PQ2248<H`0248@25:D248@010aS2488
@P@Q0PQ200<48@Q224800`@Q00@8@P@Q12448@<@Q00424848@Q212442480
0`@Q2488@P0:12422487124010Q236<DYAcW11S60acW00<Q22DY;F/00RU:
0Re[00<YBRe[;F/00Re[00<aS2U:;F/00Re[00@aS2e[;F/e[@8icP06=JdY
BR48:DX]JcF]0Re[00HaS3W>=JdaS2U:;F/4<H`2;F/3<H`4;F/7<H`00be[
<H`aS003=Jd2>Lh00d8@>Lh]J`02;F/00c6<>Lhe[@02=Jd00cW>?NlicP03
<H`3=Jd3<H`00cF]>LhicP03>Lh7=Jd5>Lh3=Jd2>Lh3;F/2>Lh2=Jd01CW>
?Nm6<Cg_>Lh0136<00<e[CW>>Lh00cg_00HicSg_@Q1243g_>Lh4=Jd3>Lh0
13F]<H`e[CW>0Sg_0SW>0SF]0c6<0SF]00<aS3W>>Lh00SF]0Re[00@aS3F]
=Jde[@8aS08e[@03>LhaS2e[008aS004>Lhe[CF]>Lh2?Nl013F]<H`e[CF]
0S6<0SW>0cF]0c6<00<icT8@>Lh00SW>0dHa00@icSg_>Lhe[@DicP03?Nm2
448@00<mk`03@Q16<D8@00<mk`08@Q0mkd8@@Q16<Cg_>Lhmk`9240<mk`03
AS52448@00E24004AS52448@@Q02AS400d8@AS5:DP02CW<1AS41<H`000<4
8@0300048@@Q00<48@0800048@Q27>LicRU:5:DLi`<Q20LLi`DQ20<U:@03
8@PU:BDY008YBPDU:@@Q20039BTQ224800<Q20037>LQ2248008U:@038@PU
:B4800<Li`038@PU:B4800<Li`058@PU:B488@PLi`029BT00bU:;F/YBP02
9BT48@P2:DX01BDY:DXU:BU:9BT00R4800<Lib488@P00RDY00<Q22DY9BT0
0be[0RU:01D]JcF]<H`e[Cg_BU9Nmf<HJeYW>EkgIcUJeTic@Q0icS6<7>L<
H`0024802@@Q00<8@PaS36<00PaS00<8@PaS24800`Q21@aS00T8@PaS36<8
@PaS6<HQ236<;F/00QcW00<@Q0aS36<00PaS00H8@PaS36<@Q0aS24821240
10Q236<<H`Q20PaS00DQ23W>CW=[FVLi009cW005MkekgTHa=JdDY@0236<2
248@1242248010@Q36<@Q0aS0`Q200H<H`Q236<<H`Q21243248236<248@0
0`aS48@<H`0224801P@Q2488@PQ236<8@P@48@0524848@Q2248<H`022480
10aS48@<H`aS0PQ20`aS00X8@PaS48@DYA246<HQ22e[@Q0icP8mk`09=JdY
BT8@F]IF]CW>36<8@PaS00H48@88@P045:DHaQBU48@7248248@011BU48@<
Ha240PQ200<48@Q236<00PQ200<48@Q212401@@Q00h8@PaS5:D@Q0Q21248
@P@Q24848@Q21248@P@Q0`Q22P@Q00<8@P@Q124010@Q00<8@PaS48@00QcW
0QS600@DYAS67>LLi`8U:@DYBP05;F/YBRe[<H`]J`05:DX2;F/02S6<=Jde
[CF]<H`YBRDY:DX]JcF]0Re[0SF]00<aS2U::DX00Re[0c6<0be[00DaS2e[
:DX]JbU:008]J`DaS0<]J`0=<H`icS6<<H`e[D8@?NlicRe[:DX]Jc6<>Lh0
0cF]0cW>0c6<00<e[C6<=Jd0136<00<e[CW>=Jd00SF]00HicSF]=Jde[C6<
=Jd2>Lh2?Nl3>Lh4=Jd0136<;F/aS36<0SW>0SF]00HicT8@?Nlmkc6<;F/3
<H`2>Lh2?Nl013W>?Nlmkcg_0cW>0cF]00<aS3W>>Lh00SW>00TaS3F]>Lhi
cSg_>Lhe[CW>=Jd0136<00<e[C6<<H`00cF]0S6<00<]JcF]>Lh0136<0SF]
136<00@icSF]=Jde[@@icP03<H`]Jc6<00@e[@8aS003=Jd]Jc6<00<mk`0:
>Lhmkd8@AS5243g_>Lhe[CW>?Nl4>Lh2@Q02?Nl01SW>?Nm244Ha@Q0mk`8i
cP924005?Nm243g_?NlicP03?Nl00d8@?Nm24002@Q002Cg_@Q1243g_@Q0m
kd8@AS4mk`02@Q001dYB@Q1244YBCW=BU4Ha004aS00000<000@Q12400P@Q
00<000@Q12400`@Q00H8@QcW>Lh]JacW9BT48@P012DY8@PU:B480bDY00<Y
BRDY:DX00RU:0be[00LYBRDY9BTQ22DY8@PLi`028@P49BT012487>LQ21cW
0R480RDY00<Q22DY:DX00RDY00@Q21cW7>LLi`<Q20<Li`036<HQ22U:008U
:@038@PU:BU:008YBP8U:@057>LQ22DY9BTYBP029BT00b489BTQ20058@P2
7>L28@P00bDY:DX]J`02;F/2:DX00be[<H`aS002=Jd00cg_BU9>L`02G_L2
IcT02V<HJeYF]DYB>LhaS2e[7>L@Q0Q220@Q0PQ200@48@Q236<<H`@8@P03
36<8@PaS00D<H`<@Q0066<HLibDY8@PHaQBU0PaS00D8@PaS36<<H`Q2008@
Q00336<8@P@Q008<H`08124<Ha247>LDYAcW8@Pe[@9BU007HaQNmdicBU8]
Jb487>L00QS600H@Q0aS1248@P@Q2483124010Q2124000@Q0`Q20P@Q00@8
@P@Q248<H`8DY@0336<8@PaS008@Q0<8@P031248@PaS00P@Q0035:D<H`aS
0088@P8<H`03248<H`Q20088@P051248@PQ224848@07248010aS2488@PaS
0Q2400P<HaBU5:DaS4HaDYAW>F<H0Ukg00A6<D8@<H`]J`8U:@035:D<H`Q2
00<48@0924848@@Q248<HaS67>LHaQBU00<8@P031248@PQ200<8@P0636<@
Q0aS36<8@P@Q1`Q21P@Q0PQ20`aS00D8@P@Q2488@PaS0088@P031248@PQ2
0088@P@48@0324848@@Q00@48@0:24848@@Q1248@P@Q48@DYAcW8@P26<H0
1AcW6<HDYAcW9BT00S6<12e[00TaS2U:;F/aS3F]<H`]JbDY:DX012e[0S6<
00@e[C6<<H`]J`8YBP@aS08mk`03>Lh]JbU:00<aS003=Jd]Jbe[00L]J`03
<H`]Jbe[00DaS003;F/aS3F]008aS006=JdicSg_?NlicSF]0S6<00/]JcF]
<H`icSg_>Li243W>=JdaS3F]008icP04=JdaS36<<H`5=Jd01cW>=JdicSF]
>Lhe[CW>008e[@06>Lhmkcg_>Lhe[C6<0SW>00De[C6<<H`]JcF]008aS08e
[@05?NlicSW>>Lhe[@02<H`022e[<H`icSW>?NlicSF]>Lh3?Nl00d8@>Lhe
[@02<H`00cW>=JdaS003>Lh00c6<=JdicP02@Q03>Lh00cF]<H`aS003<H`0
13W>?NlicS6<0Re[00<icSF]>Lh00SW>00@e[C6<;F/aS08e[@03<H`e[C6<
008icP8e[@05<H`e[CW>?NlicP02=Jd00cW>=Jde[@03<H`2=Jd02C6<=Jde
[CW>@Q16<D8@?Nle[@06>Lh00cF]>LhicP02>Lh2?Nl01SW>@Q12448@?Nli
cP8mk`03@Q0mkcg_008icP04?Nm2448@@Q03?Nl02T8@AS56<Cg_>Lhmkd8@
AS4mkcW>0Sg_0T8@0THa0dYB0D8@0Be[000412400`0012448@0412401PQ2
7>LmkbU:6<HLi`@U:@8Q20<U:@8Q20039BTYBRU:008YBP<]J`03:DXU:BDY
00@Q20077>LQ22489BTQ22DY8@P011cW00<Q22DY8@P00RDY00HYBRDY9BTQ
21S67>L28@P012DY7>LLiaS60QcW00@U:B489BTQ20LU:@<Q20<U:@038@PU
:B48008Li`8Q20039BTQ21cW008Li`068@PYBRDY:DX]JbU:0RDY00PYBS6<
<H`aS3F]>Li:DTic0Ukg00]W>F]JHaQW>EJeBU8icS6<:DXHaPaS00H48@03
24848@Q200848@88@P0336<8@PQ200D8@PH<H`0748@<H`Q26<HQ22U:9BT0
0Q2400<<H`Q236<00`aS00L8@PaS48@<H`Q2124<H`0324801Q246<HHaQS6
9BTicP9BU007HaQNmdYBBU8YBR487>L00QS600<@Q0Q212400`@Q00<8@P@Q
12400P@Q00L8@P@Q2488@P@Q24848@0324801Q245:D@Q0aS248<H`8@Q004
36<8@PQ2124224800`aS48@@Q00348@35:D010aS2488@P@Q0PQ20PaS0PQ2
00@48@Q2248<H`T8@P041248@PQ236<248@01`aS5:DLic6<AS5BU6]J009S
6005F]I6<D8@<H`YBP028@P00aS636<48@0212403@Q212448@@Q248<HacW
8@PDYA2424848@Q200848@<8@P05124<Ha2448@<H`0224800`aS2488@P03
24800`@Q24848@02124010Q212448@Q20PaS1`Q200<48@Q2248010Q210@Q
0PQ200<48@Q212400P@Q00<8@P@Q12400PQ200L<HaS67>LQ21cW5:DHaP02
5:D28@P2<H`00be[<H`aS003;F/01bU:<H`aS36<:DXU:BU:00<]J`HaS0<Y
BP8aS006:DXaS3W>?NlicS6<0RU:00<]Jc6<<H`00Re[0bU:00<]JbU::DX0
0S6<0be[0c6<0Re[00<aS3F]=Jd00S6<00@e[Cg_>LhicPHaS08icP8mk`03
>LhaS3F]008icP04=JdaS2e[;F/2<H`7=Jd00c6<=Jde[@02>Lh00cF]>Lhm
k`02>Lh2<H`2=Jd01cW><H`YBRe[<H`e[C6<008e[@8mk`8icP8aS08]J`05
<H`icSg_?NlicP02=Jd2>Lh2@Q0013W>=JdaS36<0cF]0SW>00@e[Be[<H`e
[@92408icP8aS005=Jd]Jc6<;F/e[@02>Lh013F]<H`]Jbe[0SF]0cW>0S6<
00<]Jc6<<H`00c6<0cF]00@icSF]=JdaS0<icP0;<H`e[CW>>LhaS2e[<H`e
[C6<=JdaS002=Jd01SW>@Q12448@>Lhe[@8icP<e[@09>Lhe[CW>>Lhmkd8@
>LhmkcW>00=24004?NlicSW>?Nl2@Q0013W>?NlicSg_0T8@00@mkcW>>Lhm
k`=24003?NlicSW>0092408mk`03>Lhmkd8@0096<@05@Q16<DYBBU96<@01
;F/0000300048@0000<48@0<00048@@Q124000Q29BTmkbe[7>LU:Be[0RU:
0RDY00<YBRe[:DX01bDY0bU:0RDY00<Lib488@P00RDY0b480RU:00<U:B48
7>L00R4800@U:B487>LLi`8Q20049BTQ22U::DX28@P26<H01b489BTYBR48
7>LHaR48008U:@078@PU:B488@PU:BU:;F/00RDY00<Q22DY9BT00R4800/U
:B488@PLib489BTQ22DY8@PU:AcW008Q20059BTYBRU::DX]J`04:DX00c6<
;F/aS002;F/01SF]?Nm>LdicG_MS609[FP9S6003DYA6<CW>008]J`035:D@
Q0@Q00H48@@8@P041248@P@Q24821242248736<02`Q236<HaR48;F/YBQ24
36<48@Q236<00`Q200T<H`Q236<8@PaS248<H`Q212400PQ200DDY@Q25:DL
icF]009_N`03F]HmkacW008Li`056<HDYABU48@<H`02248512401@Q21244
8@@Q24800P@Q00H8@P@Q2488@P@Q248348@010aS48@@Q1240PaS0`Q200L<
Ha246<HaS3F]>Lh]J`026<H25:D00a2436<8@P0224800`aS2488@P0336<3
24801P@Q2488@P@Q24848@88@P848@88@P@<H`077>LQ23g_HaQ[FWooLi`0
0WNm00A[FV<H=JdYBP8@Q00336<8@P@Q00<48@88@P071248@PQ236<@Q0Q2
36<00P@Q00<8@P@Q24800P@Q10Q20`aS20Q20`@Q00<8@P@Q12400PQ20`aS
00<8@PaS248010Q200<48@Q224800PQ200@48@Q22488@P848@0524848@@Q
1248@P0212401PQ2124<HaBU6<HLi`@HaP037>LQ2248008YBP06<H`e[CF]
<H`]JbDY0RU:00<]JcW>>Lh00SF]12U:00<aS2e[<H`00S6<00P]JbU:;F/Y
BS6<;F/e[CW>0SF]00@aS2e[;F/YBP<]J`04<H`]JbU:<H`4:DX2<H`013F]
<H`YBRe[1S6<00Le[CW><H`aS3F]>Lhmk`03>Lh0136<=Jde[C6<0SW>0T8@
0SF]00DaS3F]>LhicSF]00<]J`03<H`e[CF]008icP03?NlicSW>00<icP<e
[@@icP05=JdmkcF]=JdaS002=Jd00c6<;F/]J`03=Jd00c6<=Jde[@02=Jd3
<H`2=Jd0136<=JdicSg_0cW>00<mkd8@>Lh00S6<00<]JcF]=Jd00SF]00Di
cSF]=JdaS3F]008icP04=Jdmkd8@=Jd2;F/00c6<>LhaS002=Jd7<H`2=Jd0
1C6<=Jde[CW>=Jd00c6<00He[CW>=JdaS3F]<H`3>Lh00cF]<H`e[@03>Lh5
=Jd2<H`2=Jd00cg_>LhicP08>Lh00cg_>LhicP02>Lh0148@>LhicSW>0T8@
00E6<D8@?Nm243g_0092408icP03=JdicT8@0092408mk`07@Q1:DTHa?Nli
cSF]>Lh01D8@00<mkd8@@Q000THa00=:DTicBU800C6<000312400`001240
0005124020Q28@Q242U:7>LYBRe[:DX29BT02BU:9BTYBRU:9BTQ22U:9BTQ
20029BT4:DX01BDY8@PLib489BT0124800@U:BU:9BTU:@8Li`048@PLib48
7>L28@P01AcW9BTYBRDY:DX011cW00DQ22DY9BTU:B48008Li`039BTQ2248
008U:@8Q20<YBP<U:@<Q20067>LQ22488@PLib480RDY0R4800LLib488@PQ
22DY:DX]J`02:DX00bDY:DXYBP03;F/02RU:;F/e[Cg_CW=BU5kgHaQW>F]J
0V<H00MBU48@>Lh]JbDY6<H<H`0612401@Q21248@PQ2124010Q20P@Q0PQ2
10aS00<8@PaS36<00PQ200@Lib48;F/YBP8<H`0424848@aS36<3248336<6
24802`aS48@8@QBU9BTmkf]JKg]F]Cg_6<H00QcW00<HaQBU5:D00PaS00<8
@P@Q12401@@Q00@8@P@Q24848@88@P@48@03248<H`aS00<@Q0@<H`@8@P09
36<@Q1S6<H`mkcW><H`DYAS6008DY@0348@<H`Q20088@P8<H`0348@<H`Q2
00@8@P<48@<8@P<48@@8@P0@36<@Q0Q26<HQ23g_HaQ_NgooLiag_G_NJeYN
mc6<9BT248@01@aS12448@@Q248010@Q0PQ20`aS00<8@P@Q124010@Q0PQ2
00`48@Q248@@Q0Q21248@PaS248<H`Q236<224800`@Q24848@0312422480
0`aS2488@P0236<2248010@Q2488@PQ20P@Q00H8@P@Q2488@P@Q24881243
248248@00aBU7>LLi`026<H011BU6<HU:B480Re[00HaS3F]<H`aS2U:9BT3
:DX013F]>LhicS6<0RDY1Be[136<0RU:0S6<00<icSF]=Jd00S6<0Re[00@Y
BRe[;F/aS0<]J`03:DX]JbU:008YBP06;F/e[CF]<H`]JbU:0c6<0Re[00Pa
S3F]=Jde[C6<=JdicSg_0SW>0cF]0S6<00He[CW>@Q0mkcW><H`2=Jd013W>
=JdaS2e[136<00De[CW>>LhicSg_00<icP03=JdaS3F]008icP8e[@09<H`i
cSF]>Lhe[C6<;F/aS2e[008aS003;F/e[C6<008e[@03<H`e[CF]00@aS08e
[@04>Lhe[CF]=Jd4>Lh2=Jd2<H`2=Jd01c6<>LhmkcF]<H`]JcF]00<icP04
?NlicS6<<H`2;F/4=Jd02S6<;F/aS36<=JdaS2e[<H`e[CW>136<00<e[C6<
<H`00SF]00DicSF]<H`aS3F]008icP06=Jd]Jc6<>LhmkcW>0c6<0SF]0S6<
00@e[CW>?Nlmk`@icP04=JdicSW>=Jd2>Lh01Cg_>LhicSW>?Nl00cW>00<m
kdHa@Q000cg_0T8@0SW>0SF]00<icSg_@Q000cg_0THa00E243W>>LhicSg_
00A240<mk`06@Q1:DTHaAS5:DTHa0C6<00000`0012448@08124030Q29BU2
42e[7>LU:Be[<H`]JbDY8@PYBP8]J`03:DXU:BDY00<U:@8YBP06;F/U:BDY
8@PU:BU:0b480RDY0R4800DU:BU:9BTQ21cW00@Q20037>LQ224800<YBP08
9BTQ22487>LHaQcW8@PU:@8Q20047>LQ22489BT2;F/2:DX29BT022U:8@PQ
22DY:DXU:B487>L58@P49BT28@P00bDY8@PQ20029BT01bU:;F/U:BDY8@PY
BRe[008YBP<]J`0:<H`e[CW>CW=BU6<HIcUS65kgE[D2DY@01T8@>LhYBRU:
5:D<H`848@@8@P0:1248@PQ224848@Q21248@P@Q248336<00`Q236<@Q004
36<248@25:D236<2248336<2248010aS48@<H`aS1PQ200`<H`Q248@LibDY
@Q0mkc6<8@P@Q1BU6<H248@236<224802`@Q24848@@Q24848@Q21248@P@Q
24800`@Q10Q200<48@Q224800`aS0PQ200D<Ha2436<<H`Q2008DY@046<He
[D8@G_L2F]H01V<H>LhU:@aS248@Q08<H`04248<H`Q2248236<00`Q21244
8@022483124224801P@Q2488@PQ236<8@P<<H`0=6<HLicg_F]I[FWNmKg]g
_G_NMkecW3W>:DX00`Q210@Q0PQ21P@Q00@8@P@Q2488@P848@0324848@@Q
00848@0324848@Q200H8@P0436<8@PaS2487124224800`aS248<H`032483
36<324800`@Q24848@032484124224800`@Q24848@0236<00aBU7>LLi`02
6<H011BU6<HQ22480Re[00@aS3F]<H`e[@<]J`059BT]JbU:<H`e[@02<H`0
1SF];F/YBRDY:DXe[@8aS08]J`03:DX]Jbe[008]J`@aS005=JdaS2e[:DXU
:@02:DX022e[<H`aS36<;F/U:BU:<H`2=Jd013W>=JdaS36<0SF]0c6<00@]
Jc6<<H`icP8mk`04>Lhmkcg_AS42?Nl00cF]>LhaS002=Jd3?Nl4>Lh013F]
<H`aS2e[0c6<0SF]00Xmkd8@@Q0e[C6<=JdmkcF]<H`e[@8icP8e[@8icP03
=JdaS36<00<aS003;F/aS3W>00<icP03=JdicSW>008aS08e[@8aS005;F/e
[CF]=Jdmk`02@Q001cW>=Je243g_>Lhe[C6<00@e[@03<H`icSW>008mk`<e
[@8icP07=JdaS36<<H`e[CW>=Jd00S6<0cF]0S6<00<e[C6<<H`00S6<0Re[
0S6<00@icSF]=JdicP<e[@03<H`e[CW>008icP03=JdaS3F]008icP05=Jdi
cS6<<H`]J`02<H`00cF]>LhicP02>Lh013g_>Lhe[CF]0cW>0SF]00HmkcW>
>LhicSg_@Q02>Lh013g_@Q0icSW>0cg_13W>0cg_00A244HaAS56<@A24003
?NlicSW>008icP03?Nm6<D8@008mk`06@Q16<DHaAS5:DTHa0CF]00031240
0`0012448@03124020001248@RDYAS4aS1cW9BT2;F/012U:9BTU:BDY0Re[
00HYBRDY8@PQ22DY:DX29BT2:DX29BT48@P27>L28@P01BDY:DXYBRU:8@P0
0QcW00<HaR487>L00QcW00<Q22DY9BT00RDY0R4800HLiaS66<HQ22DY8@P2
7>L29BT01B489BTYBRe[9BT00R480RDY00<Q22DY9BT00R4800DLib488@PL
ib4800@U:@048@PU:B489BT48@P00bU:;F/YBP028@P01BDY<H`]JbU:9BT0
0be[00HicSg_DYAF]EkgIcT2HaP02E:DE[E>LdHa=JdYBRDY36<8@P021243
24800`@Q2488@P0324801@@Q24848@@Q24802@aS00P@Q1BU5:DDYA2436<8
@P@Q0`Q220aS00@8@PaS24848@<8@P0848@HaRDY@Q0mkbe[7>L<H`<DY@8<
H`88@P0536<8@P@Q1248@P0212401`Q21248@PQ21248@P@Q0088@P031248
@P@Q00<8@P@<H`03248<H`aS008<H`0648@DYABU6<He[Cg_0Ukg00MJeV<H
<H`Q20aS248@Q00336<00`Q236<8@P0324800`@Q24848@0412400`Q21248
@P02248236<3248040aS7>LU:Cg_G_MW>G_NKg]kgWooNmi[FS6<:DX<H`Q2
10@Q00<8@P@Q12400P@Q00H8@P@Q2488@P@Q248212401PQ212448@Q21248
@P848@@8@P0336<8@PaS00<<H`88@PL48@88@P<<H`0324848@@Q00@<H`08
1248@PQ21248@P@Q24848@88@P031248@P@Q00<48@03248@Q12400<HaP8L
i`8DY@046<HQ22e[;F/2=Jd2<H`00bU:;F/YBP02:DX012e[<H`e[C6<0SF]
00@]JbU::DX]J`<aS0<]J`@YBP03;F/aS36<008e[@03<H`]JbU:008U:@8Y
BP03<H`e[Be[008YBP049BTaS36<>Lh2=Jd4<H`00cF]<H`]J`03<H`5>Lh0
13g_@Q1243W>0cF]00<aS3W>=Jd00cg_00@icSF]>LhicP8aS009;F/aS36<
;F/aS3F]?Nm243W>008e[@03<H`icS6<00<e[@8icP04<H`icSF]=Jd3<H`2
;F/2<H`013W>=JdicSW>0SF]0c6<00Xe[CW><H`YBRe[=JdicSF]>Lhmk`<i
cP8mk`03>LhaS36<008e[@03>Lhe[CF]008e[@03?NlicSW>00<e[@05>Lhe
[C6<<H`e[@02>Lh01SF];F/aS36<=JdicP@aS005=JdaS36<;F/aS002=Jd0
13W>=JdaS3W>13F]00@aS3F]>Lhe[@<aS0<icP03=JdaS36<008aS08e[@Di
cP<e[@8icP8e[@0:>LhmkcW>=JdicT8@?Nle[CW>@Q02?Nl00cW>?Nm24002
?Nl013W>=JdicSW>0Sg_00E244HaAS5243g_00=24003?NlicSW>008icP92
4009?NlicSW>?Nm6<DYB@Q1:DTHa004e[@0000<000@Q00000P@Q00<000@Q
12400`@Q00D8@RDYAS4aS1cW00@U:@03:DXU:BDY008YBP05;F/YBRU:9BTQ
20069BT28@P01RDY8@PQ2248:DXU:@<Q2004:DXU:BDY9BT58@P01bDY8@PQ
22487>LQ22DY008YBP8Q20056<HQ22489BTLi`038@P022U:;F/]Jbe[9BTQ
22DY8@P49BT28@P00acW8@PQ20059BT28@P3:DX00bDY8@PU:@03:DX012DY
:DXU:BDY1BU:00<]Jc6<;F/00SW>00E>LeJeG_MS65kg00AF]@08BU8mkbDY
9BTDYA2424848@P8@P848@04248<Ha2448@536<00a2436<@Q0025:D00a24
36<8@P0236<4248348@01@aS48@@Q12436<00PQ211240PaS00D@Q1S66<HD
Y@aS008@Q0035:D@Q0aS00<8@P8<H`88@P<48@@8@P041248@P@Q12422480
0`@Q24848@0324800`@Q2488@P0348@01@aS5:DLibe[<H`00Re[0SF]00TY
BTHaDYANmf<H=JdQ212424800`aS1PQ200<48@Q2248010@Q00@8@P@Q248<
H`8@Q00;36<8@PQ236<HaQcW9BTmke:DJeYS6002Kg/01E[FDY@U:AcW48@0
0PaS00D48@Q212448@Q200848@0424848@Q212422483124224800`aS2488
@P02248612401PQ21248@PaS248<H`88@PL48@88@P0336<@Q0aS00L8@P03
1248@PQ200L8@P848@06248<Ha2448@DYAS61QcW00<Q22U::DX00be[0S6<
0Re[12U:0cF]00TaS2e[=Jd]JbU:9BTYBS6<=Jd00S6<00<]JbDY;F/01Be[
00<YBRe[;F/00S6<00L]JbU::DXU:BU:<H`e[@02<H`012U:<H`e[C6<0SF]
1C6<00Pe[CW>=Jde[C6<;F/icSg_0THa00U243W>=Jdmkd8@?Nle[Be[<H`0
0SF]0cg_00E243g_=Jde[Be[00@aS008>Lhe[C6<<H`e[Cg_>LhaS0@e[@8i
cP8e[@05>Lhe[CF]=JdaS002>Lh2<H`00be[=JdicP02>Lh01C6<>Li243g_
>Lh0136<00<e[C6<<H`00S6<1CW>0T8@00@icSF]>Lhmk`<icP03=Jdmkcg_
008mk`8icP04=JdaS36<<H`2>Lh0136<=JdaS36<0SF]00<icSF]<H`00S6<
0SF]00<aS2e[;F/00SF]00HicSF]=Jde[CW>=Jd3>Lh2?Nl00cW>=Jde[@05
=Jd01CW>=Jde[CF]>Lh00SF]0S6<0SF]0T8@00HicSF]=Jdmkd8@?Nl2=Jd0
1Cg_@Q12448@?Nl00cW>0cg_0SW>00@mkcW>?Nle[@8icP05?NlicSW>?Nm2
4002AS47@Q0014Ha@Q12448@0SW>00<mkd8@AS400T8@0THa0C6<00041240
0`0012448@0312401`0036<U:DHa<H`HaR48008U:@04:DXU:BDY9BT2:DX0
0be[:DXYBP039BT01b489BTYBRDY8@PLib48008U:@<Q20039BTQ22DY008U
:@03:DXU:B4800HQ200=9BTQ21cW8@PLibU:;F/YBRDY6<HLib489BT00R48
00<Lib489BT00be[00<YBRDY8@P00RDY00<YBRDY9BT00R4800@Lib488@PQ
208U:@04:DXU:B488@P29BT01BU:9BTQ22DY8@P012U:00@Q22DY:DXU:@8Y
BP@]J`0><H`icSW>CW=F]EkgHaQJeUJeDYAJeUJeBU8icP8U:@0348@<H`Q2
00L8@P848@88@P03124<H`aS008@Q08<H`0748@<Ha2448@<HaBU6<H00Q24
1PQ20PaS00@@Q0aS36<@Q08DY@0336<8@PaS00<@Q08<H`0448@DYABU5:D3
48@01ABU48@@Q0Q212400PQ200<<H`Q224800`@Q1PQ200L48@Q22488@P@Q
24848@0424802`aS2488@PaS48@DY@aS48@Lic6<>Lh00Re[00/e[C6<;F]6
<EJeHaQJeRe[6<H@Q0Q200<<H`H8@P041248@P@Q124324800`@Q248<H`02
36<00a242488@P0236<041cW5:D]Jd8@DYAW>F<HKg]cW5JeBU8Q21cW48@<
H`Q20`@Q10Q200@48@Q21248@P<48@0324848@@Q0088@P0336<8@PQ20088
@P848@88@P848@88@P<<H`0424848@Q22483124010Q21248@PQ20PaS00<@
Q0aS36<02@Q200<48@Q224800`Q20P@Q00L8@PaS5:D@Q1BU6<HLi`028@P0
11S67>LLibDY0bU:0be[0S6<00H]JbU::DXU:Be[<H`2=Jd3<H`012U:9BTU
:BDY136<00@YBRe[;F/]J`8YBP8]J`03:DX]Jbe[008aS003:DX]Jbe[008U
:@03;F/aS3F]00<]J`8e[@03;F/aS36<00@aS08icP06=JdaS2e[;F/icSg_
0T8@0SW>0cg_00HicS6<<H`aS3F]<H`2?Nl2@Q02>Lh01CF]<H`aS2e[<H`0
0cF]0S6<00<e[CW>=Jd00SF]00<icSF]=Jd00S6<00He[CW>>LhicSF]<H`2
=Jd03CW><H`]Jc6<=JdicSg_=JdaS3W>?Nm243W>008]J`04=JdaS36<;F/2
<H`022e[>Lhmkcg_=JdicSg_@Q06>Lh2=Jd013W>?Nm243W>0cF]0c6<0cF]
00@aS3F]<H`]J`8aS0@e[@0:>LhaS36<:DX]Jc6<=JdicSF]<H`3=Jd2>Lh3
?Nl013W>=Jde[CF]0c6<0cW>00De[C6<=Jde[CW>008]J`0<<H`e[D8@?Nli
cSF]>Lhmkd8@?Nle[CW>0Sg_00DicT8@?NlicSg_008icP03?NlicSg_008m
k`04>Lhe[CF]=Jd2?Nl2>Lh013g_@Q16<D8@0Sg_00A6<D8@@Q0mk`E2408i
cP05?Nm244HaAS524002AS41=Jd0000300048@@Q00<48@0300048@@Q00<4
8@047>M243F]8@P29BT00b489BTYBP02:DX00bDY:DXU:@02:DX29BT28@P0
1bDY:DXYBRDY8@PLib4800@U:@8YBP039BTQ2248008YBP049BTQ21S68@P2
7>L00bDY8@PQ20028@P01acW9BT]JbU:9BTLiaBU008Li`<Q208YBP03<H`]
JbU:00PYBP8U:@067>LHaQcW8@PYBRe[0bDY00TQ22U:;F/]JbU:9BTLib48
9BT00bU:00<U:B488@P00R4800HU:BU:9BTQ22DY;F/2<H`2=Jd014HaDYAJ
eVLi0ekg00YF]E:DAS5242U:8@P@Q0aS24848@<8@P031248@PQ200@8@P03
36<@Q0aS00@<H`<8@P<@Q0D<H`@8@P8<H`05248DYAS67>LHaP0236<01Q24
5:DLibDY8@PLi`8HaP<DY@0348@<H`aS008<H`88@P@<H`88@P0336<8@PQ2
00<8@P8<H`03248<H`aS0088@P031248@PQ200<8@P@<H`0748@<HaS6:DXi
cU[FG_L00VLi00E6<Cg_:DXLicW>009S6005@Q0@Q0@Q248<H`0224800`@Q
2488@P0324800`@Q2488@P041242248020aS48@@Q0aS124<HaS69BT25:D0
2S6<E[EcW5[FBU9242U:9BTHaQBU0Q2400<<H`Q2124010@Q00<8@P@Q1240
0PQ200<48@Q224800P@Q00@8@PaS36<@Q08<H`<8@PH48@0324848@Q200<<
H`848@<8@P031248@PQ20088@P<@Q0D8@P031248@PaS00<8@P848@<8@P09
36<8@Q2448@HaQcW8@PU:B48008Li`038@PU:BDY008U:@<YBP08;F/YBRe[
<H`]JbU:9BTYBPH]J`0:<H`YBRDY9BTYBS6<;F/YBRe[<H`2;F/3<H`3;F/0
0cF]<H`e[@02<H`2:DX02BDY:DXaS36<=JdaS2e[<H`]J`04<H`012U:;F/]
Jc6<0SW>00@e[C6<;F/]J`8e[@@icP8e[@05>Lhe[C6<;F/aS002=Jd01CW>
@Q12448@>Lh00SF]0c6<00@]JcW>?NlicP8aS003>Lhmkd8@008mk`<icP8e
[@03<H`e[CW>00<e[@<icP04=JdaS2U:;F/2=Jd00cW>=Jde[@03>Lh00c6<
;F/aS002<H`2=Jd01C6<=JdicSg_>Lh00c6<00<mkd8@@Q000T8@0SF]00<i
cSg_?Nl00SW>0T8@00<mkcF]=Jd00cW>0SF]0c6<0cF]00@aS3F]=Jde[@Da
S08e[@@icP0:<H`]JcF]?Nm:DU:DAS4mkcW><H`2=Jd00be[<H`aS003>Lh0
0cF]<H`icP02>Lh2<H`00cW>?Nlmk`03=Jd3?Nl01CW>=JdicT8@AS400Sg_
00@aS3F]?Nm24096<@03>Lhmkcg_00<icP03?NlicSW>008icP=240=6<@=2
4006AS5243g_?NlicSg_0d8@0SW>00A244HaAS4mk`4]J`000P@Q00<000@Q
00001@@Q00X000Q27>M2436<7>LU:B487>LU:@@YBP059BTQ22U::DXU:@03
8@P2:DX01RDY8@PLiacW9BTQ208U:@8Q20079BTYBRDY9BTYBRDY8@P00QcW
0b4800<Lib488@P00R4800LLibDY:DX]JbDY7>LHaP037>L012487>LU:BU:
0Re[1bU:00@U:BU:9BTQ20@Li`03:DXU:BU:00@U:@04:DX]JbDY9BT28@P0
0bDY8@PU:@029BT28@P00acW9BTU:@029BT00b48:DX]J`02<H`2=Jd014YB
DYANmf<H0Ukg00eJeUJeDYA243g_9BTQ212436<8@P@Q24848@07248536<2
48@236<010Q236<@Q1240PaS10Q200@<H`Q236<48@88@P0536<HaQS67>LH
aP0236<011245:DLib480acW0aBU0Q2410aS0`Q20PaS0PQ200<<H`Q236<0
10Q20`aS2`Q200<<H`Q236<00Q2400`LibU:?NmNme[FIcUS648@?NlU:AcW
?Nl2G_L00cW>36<48@0236<9248010@Q2488@PQ20`@Q0PaS0Q2400/<H`@Q
36<DYB4848@DYCF]F]IcW5[F0092408U:@8DY@8@Q088@PD48@0324848@Q2
00848@88@P848@<8@P0648@<H`Q2248<H`Q20P@Q0PQ20`@Q00<8@P@Q2480
0PaS0PQ200<48@Q212400P@Q10Q200D<Ha2436<<H`@Q0088@P031248@PQ2
00<8@P031248@PQ200@8@P0436<@Q1BU6<H27>L28@P37>L01B489BTQ2248
9BT012U:0be[0bU:0Re[0RU:00@]Jc6<;F/YBP8U:@04;F/aS36<<H`5;F/0
136<;F/YBRe[0S6<00@e[Be[<H`aS0@YBP03;F/aS36<008aS0L]J`8aS003
=JdicSW>008aS08]J`0;<H`icSW>>Lhe[C6<=JdicSF]>Lhe[@04<H`013W>
?Nlmkcg_0cW>00He[C6<<H`aS3F]?Nl2=Jd0136<=Je243g_0SW>00<mkcF]
=Jd00SF]00<icSF]<H`00cF]0cW>0S6<00<YBS6<=Jd00SW>0S6<0Sg_00<i
cRe[;F/00Re[0c6<00@e[C6<>LhicP8e[@8aS08mk`03@Q0mkcg_00DicP08
=Jdmkd8@@Q0icSF]<H`e[@<icP04=JdaS36<<H`4=Jd0136<=Jde[CF]0S6<
00H]Jc6<>LhicSg_>Lh2=Jd02c6<;F/icSg_BU9BU4Ha?NlicS6<>Lh0136<
0cW>00`aS3F]=JdicS6<;F/aS3F]?NlicSF]<H`2>Lh02d8@>LhicSF]>Lhm
kd8@?NlicSF]<H`00Sg_00E6<D8@?NlmkcW>00<e[@03?NlicSW>008e[@8m
k`=6<@07@Q16<D8@AS5244Ha?Nl00cW>13g_00E243g_AS56<CW>004aS000
00<000@Q12400P@Q00<000@Q12400`@Q00P8@R48?NlYBQS68@PU:B480RDY
0bU:00HQ22DY9BTU:BU:9BT48@P39BT37>L01R489BTQ22DY:DXU:@8Q20<U
:@8Q208Li`036<HQ21cW008U:@<Q208U:@8Q20036<HLib4800<U:@038@PU
:BU:008YBP03;F/YBRU:008U:@038@PYBRU:008U:@067>LHaQcW7>LU:BU:
0bDY00HQ22DY9BTU:BU:9BT28@P27>L01b489BTU:BDY8@PU:BU:00@Q208]
J`09=JdaS2e[;F/aS3W>BU9JeUkg009[FP0;HaQJeU[FHaQBU4Ha9BTLiaBU
48@<H`06248636<724800`aS248<H`0236<010Q21248@P@Q0PQ20PaS00@4
8@Q236<DY@8Q208Li`065:D@Q1BU48@HaQcW0QS61ABU0Q2410Q20PaS0PQ2
00D<H`Q22488@PaS0088@P04124<H`Q236<624803P0048@Lib4848@48@Q2
5:D@Q248?NmBU7>LJeX2Li`2G_L00cF]:DXQ2002:DX00acW48@48@022480
0`aS24848@0224800`aS2488@P072482124324803`@Q2488@PQ236<8@Q24
>LiF]FmkCW<U:B485:D@Q0026<H25:D010Q212448@0010@Q00@8@P@Q2484
8@@8@P031248@PaS00@<H`8@Q00324848@@Q00D48@88@P031248@PQ200H8
@P0736<@Q0aS36<8@PaS24800PaS00@8@P@Q2488@P848@88@P0:36<8@PQ2
36<8@PaS5:D@Q1S65:D27>L00b489BTU:@038@P39BT00bU:9BTU:@03:DX0
0be[<H`aS005;F/3:DX02S6<=JdaS36<;F/YBRe[:DX]JbU:0be[0SW>00@e
[C6<:DXYBP8]J`8aS0<]J`8YBP039BTYBRe[00<e[@04;F/aS3F]=Jd6<H`0
0bU:;F/aS002<H`00be[<H`aS002=Jd2<H`2=Jd2<H`00cF]>LhicP03>Lh2
?Nl5>Lh023F]<H`aS3F]>Lhe[CW>?Nl3@Q02AS400d8@>LhaS002<H`4=Jd0
136<=Jde[C6<0SF]136<0cW>0SF]0SW>136<00He[CW>>LhicSF]>Lh4<H`0
1CW>?Nm244YB?Nl00cW>0Sg_00Xe[Cg_@Q1>Le:DBU9>Ld8@>Lhe[@8aS08]
J`8aS08mk`8icP8aS003=JdaS3F]00<aS007=Jdmkd8@>Lhe[C6<=Jd00cg_
00I244Ha@Q1243W>=Jd2<H`2=Jd2>Lh00cF]>LhaS004<H`3?Nl013W><H`i
cSW>1Sg_00A244Ha@Q0icP8e[@8icP04?Nm2448@?Nl2>Lh00cg_>Lhe[@04
>Lh01Sg_@Q1:DTicBU96<@8mk`=24005?Nm6<D8@@Q0mk`07@Q01?Nl1<H`0
00<48@0300048@@Q00@48@070008@R48>Lh]JaS68@P00RDY00@Q22U::DXU
:@8Q20089BTYBRDY:DXU:B487>LQ208U:@<Q20057>LQ22489BTQ20039BT0
1QcW8@PQ22U:9BTQ208Li`046<HLiacW7>L29BT01b487>LQ22DY:DXU:AcW
008HaP038@PU:BU:00<U:@@YBP8U:@03:DXU:BDY00<U:@05:DXQ21cW7>LQ
20029BT28@P39BT01B489BTQ22U:8@P00QcW00@Q22DY9BTU:@<Q208U:@<Q
200;:DXaS36<<H`]JbU:=JdicTYBF]INm`02JeX02UkgE[EJeV<HDYA24248
7>LHaPaS0PQ200<<H`Q212400PQ20PaS00D8@PaS36<8@PaS00<8@P0336<8
@PQ200@8@P848@0324848@Q200H8@P0348@DYB48008Li`036<HDYABU008D
Y@056<HDYAS65:DHaP045:D01Q2436<8@PQ236<8@PD<H`H8@P0336<8@PQ2
00D8@P0G36<48@@Q48@U:B485:D48@Q26<H@Q248?NmBU7NmJeY_Ng>LG_MJ
eS6<9BTQ2002:DX00aS636<48@0924801@@Q248<H`aS24800`@Q0PQ200<4
8@Q2248010Q200L@Q0Q25:E245[FJeY6<@028@P00aBU48@DY@026<H00aBU
36<48@07124010Q21248@P@Q0PQ200<48@Q236<01PaS00<8@PaS12401@@Q
0PQ200<48@Q224800`Q200@48@Q2124<H`<@Q0<<H`D8@P0636<48@@Q1248
@PaS1@Q200<<Ha245:D00QS60QcW00<U:B488@P012DY00<Q22DY9BT00RU:
00<U:BU::DX01Be[00<YBRe[:DX00bU:0c6<00<]JbDY;F/00Re[0bU:0Re[
00@e[CW>=JdaS08YBP8]J`8aS0<]J`08:DX]JbDY8@P]Jc6<>LhaS08]J`<a
S0<]J`04<H`]Jbe[;F/2=Jd3;F/00cF]>Lhe[@02<H`00be[=Jde[@03=Jd0
13W>=JdicSW>0Sg_00<icSg_?Nl00SW>136<00LicSF]>LhicT8@?Nm24002
AS401T8@>LhaS36<=JdaS08e[@03<H`e[CF]008e[@DaS0@e[@8icP8e[@8a
S004;F/aS36<<H`2>Lh013F]>Lh]Jbe[0S6<00<icT8@@Q000T8@00<icSF]
=Jd00SW>0Sg_00=244YBCW<00Tic00U243W>=JdaS3F]<H`YBRe[<H`00Sg_
0SW>0c6<0SF]0S6<0SF]00<mkd8@>Lh00SF]0Sg_0SW>00Hmkd8@AS4mkcW>
=Jd3<H`00cF]>LhicP03=Jd3<H`013F]>Lhmkcg_1SW>00Xmkd8@>Lhmkd8@
AS4mkcW><H`icP<mk`9240XicP8mk`06AS5>LdYBAS5243g_0T8@0Sg_00@i
cSg_@Q16<@A24004AS52448@?Nl1;F/00005124000@Q1240000612401@Q2
8@Q242e[6<H00b480bDY00DYBRDY9BTQ22DY00<YBP039BTYBRDY008Q2003
9BTQ224800HQ208U:@<Q20059BTYBRU:9BTQ20026<H011cW8@PQ22DY0R48
00<U:B488@P00RDY0acW0R4800@U:B488@PQ20<U:@8YBP8Q20049BTQ2248
9BT28@P012DY7>LLibDY0bU:0bDY0R480RDY00@YBRDY8@PQ20@U:@05:DXU
:B489BTYBP039BT2:DX29BT3:DX01C6<?Nm:DV<HG_L00V]J0V<H00AF]E[F
AS4icP8YBP059BTDY@aS248<H`03248336<00`Q236<8@P0312400`Q21244
8@0324800`@Q2488@P03124324800`@Q2488@P0236<011245:DQ22480QS6
11240QBU00<@Q1BU48@00Q2400<DYAS65:D00`aS00D@Q0aS36<<H`Q2008<
H`0324848@Q20088@P0336<8@PQ200@8@P8<H`03124<H`aS008@Q088@P8@
Q00>9BU245JeMke_Ng_NOomg_F]J@Q0icR485:D<H`88@P@48@0324848@Q2
00@8@P031248@PQ2008<H`88@P@48@88@P848@88@P0836<@Q1cW8@PU:AcW
48@DY@8@Q0045:DHaQ2436<:12400`Q21248@P02124236<0112436<8@PaS
0Q2400<<H`Q236<00PQ20P@Q00D8@P@Q12448@Q200848@88@P@<H`@@Q0@<
H`@8@P071248@PQ224848@Q212400PQ200<@Q1cW7>L00RDY00@LiaS66<HL
i`8YBP@U:@8YBP<U:@8YBP04<H`e[C6<<H`2;F/2<H`01Be[:DX]JbU:;F/0
0S6<00<e[C6<<H`00be[00<aS3F]=Jd022e[0S6<00D]Jc6<;F/aS2e[008Y
BP8U:@04<H`e[CW>>Lh3<H`012e[<H`aS3F]136<00<e[Be[;F/00S6<00De
[C6<=Jde[C6<00<e[@03?NlicT8@00<mk`05>Lhe[CF]<H`mk`02>Lh013g_
@Q0icSW>0S6<00<e[CW>?Nl013W>00E244Ha?Nlmkc6<008e[@04>Lhe[C6<
=Jd2>Lh01CF]<H`aS3W><H`00Re[00XaS3W>>LhicS6<=JdicSg_@Q0icPLe
[@<icP8e[@03>Lhmkd8@00924006>LhmkcW>?Nle[C6<0Sg_0Tic00E6<D8@
>Lhe[CW>008e[@8]J`8aS096<@05@Q0icS6<;F/icP04=Jd2>Lh013g_>Lhi
cSg_0SW>0SF]0SW>00<mkd8@@Q000SW>00@aS3F]>LhicP8mk`@e[@03>Lha
S3F]008icP92400<?NlicSg_>Lhmkd8@AS5243g_>Lhmkd8@1Sg_0SW>00<m
kcW>>Lh00cW>00`e[CW>>LhicSg_@Q1:DU:DCW=:DTHa@Q02AS43@Q001DHa
BU96<DHa@Q000TYB0THa0D8@0Cg_0C6<00000`0012448@0212403P001244
8@@Q00048@Q27>M2436<6<HQ22DY7>L29BT012U:9BTU:B480bDY0RU:00@U
:B488@PLi`8Q208U:@098@PLiacW8@PLib489BTQ22DY008Q200:9BTYBRU:
7>LHaQBU6<HQ21cW9BT28@P00bDY7>LLi`038@P47>L59BT28@P012DY:DXU
:BDY1R4800HU:B488@PQ22DY8@P3:DX28@P00acW8@PYBP039BT48@P99BT3
:DX03RDY8@PU:Be[:DXaS3W>BU9JeV<HJeYW>F<HG_L2F]H00d8@=JdYBP02
9BT00aBU36<8@P0236<2248236<6248312400`Q21248@P02248412432480
0`@Q2488@P0236<00`Q248@DY@027>L26<H648@35:D00a24248@Q0026<H0
1124248<HaBU0PaS00D8@PaS2488@P@Q00D8@P0436<8@PQ2248236<32480
10aS48@@Q0aS0PQ20Q24010U:D8@F]Ig_F]JNmioog>LHaPmkcW>8@PHaPaS
1248@P848@88@P<48@<8@P031248@PQ200@8@P<48@0324848@Q200848@06
24848@aS248<HaS60RDY00<LiaBU48@00Q240QBU0PaS10@Q00D000@Q1244
8@Q200848@D8@P0336<@Q0aS00D<H`06248<H`Q224848@Q210@Q1PQ210aS
0a240`aS1PQ20`@Q0`Q20PaS00<@Q1S68@P00RDY00@LiaS67>LLi`@U:@8Q
208U:@06:DXQ22489BTYBS6<0SF]00<aS2e[;F/01Re[00<YBS6<=Jd00S6<
12e[0S6<0be[00<YBS6<<H`00be[00<aS2e[<H`00be[00DaS2U:9BTQ22DY
008aS08icP04<H`e[C6<;F/2<H`00cF]<H`aS002;F/6<H`013F]<H`aS36<
0cF]00LicSg_?NlmkcW>?NlicP03=Jd2>Lh3?Nl033W>=JdaS36<>LhmkcW>
?NlicSF]>Lhmk`924003>Lhe[C6<00<e[@8aS004>LhmkcW>;F/2<H`4;F/0
0cF]>LhicP02=Jd01CW>?Nlmkcg_=Jd00S6<0SW>00DaS3F]?NlmkcF]008a
S005>Lhmkd8@AS4mk`03>Lh02Cg_>Lhe[CW>@Q1:DTicAS524003>Lh0336<
;F/]Jbe[=JdaS48@BU9243W>:DXaS08icP<e[@TicP8aS00:>Lhmkd8@>Lhe
[CW>=JdaS3F]>Lh2?Nl013W><H`aS36<0SF]00LaS3F]?Nm243g_>Lhmk`02
>Lh4@Q03>Lh2?Nl0148@?Nlmkcg_0cW>0cF]0SW>0cF]00@icSF]@Q1240=>
L`04BU96<Cg_AS43@Q001Sg_@Q16<DHa@Q16<@=:DP03@Q0mkcg_004]J`00
0P@Q00<000@Q12401@@Q00H000Q27>LicRU:8@P3:DX00b489BTU:@02:DX3
9BT02B489BTU:BU:;F/U:B487>LQ20029BT00bU:9BTU:@038@P01QcW8@PQ
22DY7>LQ208YBP049BTLiaS66<H28@P012DY8@PQ22480bDY0R481AcW1248
00@U:B488@PQ208U:@@Q20039BTQ2248008U:@8Q20<YBP059BTQ22DY9BTY
BP029BT00b489BTQ20029BT3:DX01BDY8@PU:B489BT00R4800<Lib489BT0
12DY00HYBRe[:DXaS3g_BU82G_L2IcT2HaP2F]H024YB?Nle[BU:9BTHaQ24
36<5248236<2248512401@Q212448@@Q24800P@Q00<8@P@Q12400P@Q10Q2
00D48@aS248DYA2400@DY@0448@DYABU48@536<448@00`aS248<H`0336<2
24800`@Q24848@021242248536<00a2436<8@P0212403@Q236<8@PQ236<@
Q0aS8@PaS4HaIcUNmg>L009_N`03JeXe[BDY00<<H`88@P031248@PQ200<8
@P848@H8@P8<H`<8@P848@0324848@@Q00848@88@P041248@PQ2248536<0
0a2436<8@P0324851240100012448@Q20P@Q00X8@PaS248@Q1BU6<HDY@aS
248<H`88@P0536<8@PaS36<8@P041244248736<348@336<42486124236<0
11247>LQ22e[0RU:00<Q21S66<H00QcW00@YBRe[:DXU:@8Q208YBP039BTY
BRDY008YBP8e[@8icP8aS003;F/YBRe[00@]J`03<H`]Jc6<008aS003;F/Y
BRe[00<aS0@]J`@YBP8aS008=JdaS36<:DX]JbU:;F/YBP<]J`06>Lhmkcg_
>Lhe[Be[0S6<00XmkcW><H`e[CW>=JdaS2e[<H`e[@8aS005=JdaS36<<H`e
[@03>Lh01Cg_@Q0mkcF]<H`00SF]13W>0Sg_0SW>00Xe[CW>>LhicSg_>Lhe
[C6<;F/aS08icP04<H`e[CW>=Jd2<H`013F]>LhicS6<13F]0S6<0Re[0SF]
00<mkd8@@Q000Sg_0T8@00@icSF]<H`aS08icP92408icP8e[@<mk`=24009
?NlicSW>>Lhe[Cg_@Q1:DT8@00<icP8e[@8aS0<]J`03<H`mkd8@008mk`8e
[@04?Nm244Ha@Q02>Lh00d8@?NlicP03>Lh01CF]<H`YBRe[=Jd00Sg_1SW>
00De[Cg_@Q1243g_00Le[@04>Lhmkcg_?Nl3>Lh01DHaBU9:DT8@>Lh00Sg_
0T8@00A6<Cg_?NlicP8e[@8icP05=JdicSW>>Lhmk`02>Lh02CF]?Nm6<Dic
DYA:DTicBU96<@02@Q000cg_@Q124002AS42BU83AS4014YBAS56<Cg_0Be[
00000`@Q00048@0212400`0012448@0412401AcW>Lh]Jb48:DX00bDY00@Q
22DY9BTYBP8U:@038@PU:BDY00<YBP068@PLib488@PYBRe[0RDY0R4800@L
ib488@PQ208U:@8Q20089BTYBRDY8@PHaQcW8@PLi`@Q20039BTQ2248008Q
20037>LQ21cW00<Li`039BTQ2248008Q20077>LQ22DY:DXU:B487>L01R48
00<LibDY:DX00RU:0RDY00@YBRDY8@PQ208U:@<Q20@YBP8U:@038@PU:B48
00<Q20037>LQ224800<U:@<YBP03<H`icTYB009Nm`04HaQW>F<HHaP2E[D0
1dHa@Q0e[Be[9BTHaQ2400<<H`@8@P0436<8@PQ2000512432484124020Q2
12448@Q21248@P@Q248336<011245:DDYABU1Q241@aS00@@Q1BU48@<H`88
@P8<H`<8@P041248@P@Q24821244248236<0112436<<H`Q20P@Q00<8@PaS
36<00PQ2018<Ha247>Le[DYBIcUS67>LMkeW>Ekg;F/U:A2436<8@P@Q2482
12432482124524801@aS2488@PQ236<010Q210@Q00@8@P@Q12448@88@P8<
H`03248<H`Q200@<H`88@P<48@0400048@@Q124624800`aS248<H`026<H0
0aBU36<<H`0336<01@Q236<<H`aS12400PQ200@48@Q21248@P8<H`88@P@<
H`05248<Ha2436<@Q00336<324802@@Q24848@@Q00048@Q236<DY@027>L0
1Re[:DXQ22486<HLi`8Q20049BT]JbU:9BT28@P00bDY:DXYBP029BT2:DX0
336<=JdicSg_=JdaS2U:9BTYBRe[:DX]J`<aS009;F/aS2e[;F/YBRe[<H`e
[C6<00@]J`04:DXU:BDY;F/2=Jd2;F/00bU:;F/YBP02;F/2:DX2<H`013W>
?NlicSF]0Re[00HaS3W>>Lhe[C6<;F/2=Jd3<H`01CF]<H`e[C6<=Jd00S6<
0SF]00HicSF]>Li243g_>Lh2<H`00cW>=JdicP02>Lh023g_@Q0mkcW>=Jda
S3W>?Nl2>Lh00c6<;F/aS003<H`4=Jd3<H`3>Lh023F]<H`aS3F]<H`]JbU:
;F/2=Jd7?Nl01cW>=JdaS3F]>Lhmkd8@00LicP04?Nm2448@?Nl2>Lh01cg_
>Lhe[CW>@Q16<D8@00<icP8e[@04;F/aS2U::DX2<H`013g_@Q1243g_0SF]
00<icT8@@Q000Sg_00DicSg_?NlicSF]008icP07=JdaS2e[<H`e[CW>?Nl0
0SF]1SW>0cg_00Te[C6<=JdaS3F]>Lhe[CW>?Nl00cW>00<e[Cg_@Q000THa
00I243W>>Li243g_AS42@Q001Cg_=Jde[CW>=Jd01SW>00DmkcF]=Jdmkd8@
009BU005CW=:DTHaAS524002?Nl2@Q000dHaBU96<@07AS41?Nl1;F/00004
00048@@Q000212400`0012448@02124020Q28@PmkbU:7>LYBS6<:DX29BT0
1B489BTYBRe[9BT00R480RDY00<]JbDY9BT00R4812DY00<Q22DY8@P00b48
1BDY00LQ22DY:DX]JbDY8@PHaP038@P022DY:DXQ22487>LQ22DY8@P37>L0
12486<HLibDY0R4800<Lib488@P00bU:00@Q21cW8@PQ20HU:@05:DXU:BDY
8@PU:@03:DX00bDY8@PQ20029BT01B489BTU:BU:9BT00R4800DU:B488@PQ
21cW00@Q20099BTYBRe[:DXU:B489BT]JcF]0096<@0?F]INmf]JIcUS66Li
G_MJeU:DBU9243W>=JdQ21S6008@Q0035:D<H`aS008<H`88@PH48@062484
8@@Q24848@Q20P@Q00<8@P@Q24800P@Q0PQ20PaS0PQ20PaS0a241@aS00<8
@PaS36<00PaS0`Q200@<H`Q21248@P848@03248<H`Q200<48@05248<Ha24
48@DY@026<H01ABU48@8@PQ212400PQ200@48@aS5:DLi`8DY@0<7>LicU:D
DYANmeJe?NlicQS65:D<H`Q20PaS1`Q200<48@Q224800`aS0PQ200<<H`Q2
24800P@Q00L8@P@Q2488@P@Q24848@04248010@Q2488@PaS0PQ200<48@Q2
24800PaS0PQ220@Q0`Q200<48@Q224800Q2400<DYA2448@00PaS11241@Q2
00D48@Q2248<Ha2400@<H`05248<H`Q236<@Q00236<424800`aS24848@02
12401`Q21248@PQ248@DYB48008YBP069BTLiaBU6<HLib4812U:0bDY00@Q
22DY9BTYBP8aS006;F/YBRe[<H`icSF]0be[0bU:00<]Jc6<<H`00S6<0be[
00<YBRe[:DX00RU:00T]Jc6<;F/aS2e[:DXU:BU:;F/00S6<00@e[CW>=Jd]
J`@aS08YBP0;;F/e[CW>>Lhe[C6<;F/aS3W>?NlicP03<H`00cF]<H`aS002
<H`00cF]<H`aS002<H`2=Jd03CW>=Jde[CW>?NlicSF]<H`e[CW>=JdaS3F]
00HicP03?NlicSF]008aS009=Jd]Jc6<<H`icSg_>LhmkcW>008aS003;F/a
S3F]008aS0<e[@03<H`]Jbe[008]J`8aS003>Li244Ha00=24007?NlicSF]
;F/aS48@AS400Tic00DmkcW><H`aS3g_00=24007?NlicSg_>Lhe[Cg_@Q00
0THa0cW>0Sg_00<icS6<<H`00c6<00PYBRe[<H`e[CW>=JdicSg_0T8@00M:
DTicBU9243g_>Lhe[@02?Nl013W><H`]Jbe[0cF]0cW>00<e[CW>>Lh00Sg_
00<icSg_?Nl00Sg_0SW>0cF]00TicSg_@Q0mkcW>=Je244Ha@Q000Sg_00I2
43W>?NlicSg_@Q02?Nl00d8@>LhicP04<H`2>Lh013g_@Q16<Cg_0SW>00@m
kdYBAS5:DP9>L`96<@04?Nm2448@?Nl2@Q002DYBCW=:DTYBAS5:DTicBU8m
k`01:DX000@48@0300048@@Q00<48@060008@R48?NlYBR480bU:00<U:B48
9BT00RU:0RDY0R480bDY00DYBRDY8@PLib48008U:@03:DXQ2248008Q2003
7>LQ2248008U:@8Q20049BTYBRU:9BT38@P29BT28@P2:DX00b487>LQ2002
8@P27>L00b487>LHaP048@P27>L022U:;F/YBRDY8@PLib489BT28@P99BT3
:DX48@P29BT00b48:DXYBP029BT28@P011cW8@PLib480QcW00<Q21cW9BT0
0RU:00PU:B488@PYBS6<=Je244Ha0Ukg0VLi011NmfLiG_MJeU:DBU9243W>
=JdQ21BU36<DYA2436<8@P8<H`0424848@@Q248312400`Q21248@P091243
24800`aS2488@P0436<248@01@aS48@@Q0aS24800`aS0`Q200<<H`Q22480
0`Q200T48@Q21248@P@Q24848@Q212400PQ20Q2400LDYAS66<HDY@aS2484
8@0224804PaS1248@QBU7>L@Q1BU9BTicUJeDYAJeUJe=JdaS1S65:D@Q08<
H`/8@P8<H`88@P0436<8@PaS36<2248010@Q2488@PQ210@Q00<8@P@Q2480
20Q20PaS0PQ200D48@0012448@Q200<48@L8@P@@Q0<<H`<@Q00336<8@PaS
0088@P848@88@P0348@<H`aS00<8@P8<H`03248<H`aS008<H`88@P<<H`08
24848@@Q24848@Q236<8@P8DY@078@PYBRU:9BTQ21BU6<H00QcW12U:0b48
00LU:BU:9BTU:BU:<H`]J`02:DX02c6<=JdaS2U:;F/YBRDY:DX]JbU:;F/0
0S6<0be[00TYBRe[:DXU:BU:9BT]Jc6<=Jd00Re[0RDY0Re[00<aS3F]<H`0
0SF]00DaS2e[:DXe[Be[00<YBP8e[@05>Lhe[Be[;F/aS003>Lh2<H`2=Jd0
0c6<;F/]J`03<H`2=Jd2;F/00c6<>LhicP02=Jd2>Lh013F]<H`e[CW>0S6<
00He[CW>?NlmkcW>=Jd3>Lh00cF];F/aS004<H`00cW>?NlicP02>Lh00c6<
;F/aS003<H`01Be[=Jde[CF]<H`00Re[00LYBRe[;F/e[Cg_>Lhmk`03@Q00
1cg_<H`aS36<>Li244Ha009>L`04?Nle[C6<=Jd4?Nl3>Lh2=Jd013W>?Nm2
448@0cg_0SW>00Pe[C6<<H`aS2e[:DX]Jc6<13F]00DicSg_AS5:DTHa009:
DP03@Q0mkcF]00<icP8e[@04<H`YBS6<=Jd2>Lh00c6<=JdicP02>Lh00cF]
>Lhmk`03>Lh00cg_>LhicP04=Jd3?Nl00cF]>Lhmk`02@Q02?Nl0148@?Nli
cSW>0cg_00@icT8@>Lhe[@8aS006>Lhe[CF]>Li244Ha0Sg_00LicSg_@Q16
<DYBAS5>L`02BU800d8@?Nlmk`02>Lh2@Q04BU801DHaBU9>LdHa>Lh00BDY
00000`001240000812401`Q27>M242e[6<HU:BU:008U:@038@PU:B48008U
:@8YBP049BTQ22489BT2:DX00be[9BTQ20028@P012DY:DXU:B480RDY00<Q
22DY:DX00RDY00HQ22DY;F/]JbU:9BT28@P29BT28@P29BT00b487>LLi`03
8@P00acW6<HLi`039BT48@P39BT2:DX00bDY8@PLi`038@P49BT00b487>LQ
20028@P29BT28@P011cW8@PQ22480RDY00@YBRDY8@PQ20<U:@8Q20047>LQ
21cW7>L29BT2:DX01BDY8@PU:B48:DX00Re[00A244YBF]INm`=W>@0=Kg][
FV<HF]IBU4YB@Q0icS6<;F/Q21S648@00PaS00<8@PaS24800`@Q0PQ22@@Q
00<8@P@Q12400`@Q00H8@P@Q2488@PaS248236<00aBU36<<H`0524800`@Q
2488@P032485124224800`aS248<H`0212400`Q236<@Q0025:D01AS65:DD
YA2424800`@Q0`Q20PaS00P8@Q24:DY:DWNmJeY2436<0aBU00PHaQ242488
@PaS5:D@Q0aS20Q200@<HaBU5:D<H`88@P0436<8@PQ21243248336<00`Q2
1248@P03248236<248@236<02@Q21248@PQ236<8@P@Q24848@0224801`@Q
24848@@Q24848@Q200<<H`03248<H`aS0088@P0548@DYABU48@48@022483
36<010Q236<@Q1240PaS0PQ200<48@Q224800`aS10Q20PaS00L8@P@Q1244
8@aS248@Q0046<H01AcW8@PU:AcW9BT00RU:00<Q22DY:DX00RU:0RDY00H]
JbU:;F/]JbU:;F/2<H`012e[:DXYBRU:0RDY00DYBS6<;F/YBRe[008aS009
;F/YBRDY:DX]Jc6<:DXU:BU:00<]J`03<H`e[C6<008YBP8aS0<]J`03=Jda
S3F]00<aS0<]J`8YBP8]J`07<H`icSW><H`]JbU:=Jd00SW>00Pe[C6<=Jde
[C6<;F/YBS6<0cF]136<0SF]00DicSF]>LhicSF]00<aS08icP03?Nle[C6<
008icP04?NlicS6<>Lh3<H`012e[<H`aS3F]0cW>0S6<00<e[C6<<H`00S6<
0SF]00DicSF]<H`]JcF]008aS004;F/YBS6<=Jd4@Q03>Lh2<H`013W>@Q1>
Ldic0THa0cW>00<mkcW>=Jd00S6<00TicSg_>LhmkdYBAS5243F]>Lh00cg_
0cW>00dmkc6<;F/YBS6<>LhaS3W>?Nm6<Cg_>Lhmk`02AS400dYBAS5:DP02
BU800d8@>Lh]J`05<H`2=Jd2>Lh00cF]>Lhe[@02?Nl01CW>=JdaS36<>Lh0
0THa00M243W>>Lhmkd8@?NlicP03?Nl4>Lh00cg_@Q0mk`03?Nl01cW>@Q16
<D8@?NlicS6<008e[@8mk`8e[@04>Li2448@AS43?Nl2AS400dYBAS56<@03
@Q001Sg_@Q16<DYBCW=:DP96<@04BU96<DHa@Q01:DX000D48@0300048@@Q
00@48@048@PicRDY7>L3:DX00b489BTQ20028@P2:DX29BT28@P01bDY:DXY
BRU:8@PLib4800<U:@038@PU:BDY008U:@8Q20039BTQ22U:008YBP8]J`03
9BTQ2248008U:@DQ208Li`<Q208HaP8Li`8YBP058@PLiacW8@PYBP029BT2
:DX01RDY8@PLib489BTQ20HU:@088@PLib487>LQ22DY8@PLi`<Q20039BTY
BRDY008U:@8Q20039BTQ2248008Li`058@PLib488@PU:@02:DX012DY8@PQ
22DY0RU:00@aS48@BU9Nm`9S609W>@9[FP06IcUJeU:DBU9243W>0Re[00@H
aQBU48@@Q08<H`<8@P051248@P@Q1248@P0712400`Q212448@0212400`Q2
12448@02248010aS248<H`aS0a2400D<H`Q22488@PaS0088@P061248@PQ2
24848@Q21@@Q00@<H`Q236<8@P848@88@P8DY@0548@DYABU5:D@Q0022482
12404PQ21248@PaS48@48A24;F]>LgooHaPicRU:36<@Q1S65:D@Q088@P04
36<@Q1BU36<224800`@Q2488@P03248010aS5:D@Q0aS0PQ20PaS00<8@P@Q
12400PQ200@<Ha24248<H`<48@88@P8@Q0055:D@Q0aS24848@0224801@aS
2488@PQ212400PQ20`@Q00<8@P@Q24800`Q20`aS0Q2400<<H`Q236<00QBU
00<@Q0Q224800PQ21PaS00D@Q0aS24848@Q2008<H`0348@<H`Q200848@88
@P0436<8@P@Q2482124236<03ABU6<HHaQBU6<HLibDY8@PLib489BTYBRDY
008YBP06;F/U:BDY9BTYBRe[12U:0S6<0RU:00<U:BU::DX012U:0Re[00<a
S2e[;F/00RDY00@YBRe[;F/]J`DYBP03;F/e[C6<008]J`05<H`]JbU:;F/a
S002=Jd5<H`2:DX29BT2;F/01cF]>Lhe[C6<:DX]JcF]008icP8e[@<aS005
;F/aS36<=JdicP05<H`00cF]<H`e[@02=Jd00cW><H`e[@03=Jd2>Lh3=Jd3
>Lh00cF]<H`]J`06<H`2>Lh2=Jd5<H`01Re[<H`e[CW>=Jd]J`<aS0<]J`8e
[@0A@Q16<D8@@Q0icSF]>Lh]Jc6<?Nm244icAS5243g_>Lhe[@02>Lh013g_
=Jde[C6<0SW>00De[D8@AS56<Cg_008icP03@Q0icSW>00@icP05<H`]Jbe[
=JdicP02=Jd02Sg_@Q0icSW>?Nm244YBAS5:DTHa0TYB0SW>0Re[1C6<00@e
[CW>>Lhe[@<icP03?NlicSF]008aS004>Li6<DYB?Nl2=Jd00cg_@Q0icP02
>Lh3?Nl00cW>=JdicP05?Nl2>Lh4@Q001CF]<H`e[CF]?Nl00SW>0SF]00Li
cT8@@Q1243g_>Li24003BU800d8@?Nm24002>Lh2@Q02CW<00dYBAS56<@03
AS41?Nl1:DX0000500048@001240000612402@Q28@Pmkbe[6<HQ22U:9BTY
BP029BT022487>LU:BDY:DXU:AcW8@P2:DX00be[:DXYBP029BT02B489BTU
:BDY:DX]JbU:9BTQ20029BT28@P01RDY:DX]JbU:9BTYBP8U:@038@PLiacW
00@Q208Li`038@PYBR48008Li`038@PU:BDY00<U:@8Q2004:DX]Jbe[:DX2
9BT28@P00bDY8@PU:@039BT012487>LQ22480RDY00@Q21cW8@PQ20<Li`03
9BTQ2248008U:@038@PLib48008U:@8Q208U:@048@PLiacW8@P49BT38@P0
0bDY;F/]J`02AS400e[FHaQW>@02JeX2Kg/2JeX015[FE[E>LdYB0Sg_00@U
:AS648@8@P<<H`0424848@@Q1242248412432486124224801@aS248<H`Q2
36<00a2400<<H`Q224801`Q200D48@Q212448@0000848@05248<H`aS248<
H`02124236<248@00aBU48@@Q00236<324821242248030@Q2488@PaS7>LY
BSF]<H`LiaS648@DY@8HaP055:D@Q0aS36<@Q0026<H00a2436<48@072480
0`aS248<H`0436<010Q212448@@Q0Q2400@DYA2436<8@P8<H`0448@<H`Q2
36<324821242248236<010Q21248@P@Q0PQ20P@Q00<8@PaS36<00Q2410aS
00@8@PaS36<@Q0D<H`@8@P8<H`8@Q088@P0436<8@PQ2248336<924800`aS
48@DY@035:D26<H00acW8@PQ20029BT01Be[<H`]JbDY7>L00RDY00@Q22DY
;F/aS0<YBP06;F/e[Be[;F/YBRDY0bU:0Re[0S6<0Re[12U:00<]Jc6<;F/0
0S6<00<]Jc6<<H`00SF]136<1Be[0S6<0Re[00<YBS6<<H`00S6<00@]JbU:
;F/]J`HaS0<]J`07<H`e[C6<=JdicSF]<H`00Re[00<aS3F]>Lh00SF]0S6<
00@]Jc6<=Jde[@<icP8e[@03<H`e[CF]008icP8e[@04>Lhe[C6<<H`2=Jd2
<H`00be[<H`aS003<H`2>Lh2=Jd2;F/2<H`2>Lh01cF]>LhmkcF]<H`]JcF]
008aS003=JdicT8@008mk`924004>Lhe[C6<=Jd2?Nl024HaBU9:DTic@Q0i
cSF]<H`2=Jd00cW>=JdicP02>Lh2?Nl2@Q002Sg_>LhicSg_@Q0mkd8@?Nli
cSg_0SW>00De[C6<=Jde[Cg_008icP04=JdaS3W>>Lh3?Nl00cW>?NlicP02
>Lh2=Jd01S6<;F/]Jc6<=JdicP8e[@06<H`icSF]>Lhe[C6<0SF]0T8@00@m
kcW>>Lhe[@@icP<mk`8icP08?NlicSg_AS5244Ha@Q0mk`8icP03@Q16<Cg_
00<icP<mk`8icP=24004>Lhmkcg_?Nl2@Q03AS400d8@?Nm24002@Q03AS40
0dYBCW=6<@03@Q01?Nl1;F/000T48@0800048@Q28@Pmkbe[7>LQ20<U:@03
:DXU:B48008Q208YBP059BTQ22489BTYBP02;F/00bU:9BTU:@038@P00bDY
;F/YBP02:DX022489BTQ21cW8@PYBRe[:DX49BT28@P011cW8@PLib4811cW
0b480acW0RDY00<Q22DY9BT00RDY12U:1R4800<U:BU:9BT00R4800<Lib48
8@P00R4800<Lib488@P011cW00<Q21cW8@P00RDY0R4800<LibDY9BT01BDY
0R4800<U:B488@P00RDY00@Lib488@PU:@8aS096<@05F]INmfLiKg][FP03
Kg/00f]JG_MBU002BU801Cg_>LhLiaS648@00PQ200H<H`Q22488@P@Q2484
12400`Q21248@P071244248336<011245:D@Q1240PaS0PQ200<48@Q22480
0PQ200<48@Q2124010@Q10Q200<<H`Q224800`Q200<@Q1BU5:D00`aS00@@
Q0aS24848@88@P<48@88@P095:DQ22U:=JdaS1cW5:D<Ha24008HaP0948@<
H`aS248@Q1S67>L@Q0Q200848@0436<8@PQ236<4248236<01A2436<8@PQ2
12400PQ20PaS00<@Q0aS36<010aS00@8@PaS24848@<8@P031248@PQ200D8
@P051248@P@Q248<H`02248010aS48@@Q1240PaS00<8@PaS248010aS00<@
Q0aS12400PQ20PaS00<8@PaS36<00PaS0PQ200H<H`Q236<<H`Q236<92482
48@01QS67>LHaQBU48@DY@8Q20<U:@04;F/aS2U::DX38@P012DY;F/YBRe[
0bU:0be[0RU:0RDY0RU:00<]Jc6<;F/00Re[00HU:Be[;F/YBRe[:DX2;F/3
<H`00be[<H`aS002=Jd00c6<;F/]J`03;F/01BU:<H`aS36<;F/00RU:00@]
Jc6<<H`]J`<YBP<]J`<aS0<]J`@aS004=JdicS6<<H`2;F/2=Jd2>Lh4<H`0
1Be[<H`aS3F]>Lh00SF]0S6<0SF]00<icSF]=Jd00SW>00<e[C6<;F/00c6<
12e[00<aS3F]<H`00cW>00De[Be[:DX]Jc6<00@icP<e[@04<H`]Jc6<<H`2
>Lh00cg_@Q0mk`02@Q000cF]<H`aS003>Lh014HaBU9>LdYB0SW>00De[C6<
>Lhe[CW>00<e[@8icP@mk`03>Lhmkcg_00924003?NlicSg_008icP04=Jdi
cSW><H`2>Lh013g_>LhaS36<2CW>00<aS3F]=Jd00be[00DaS3F]>Lhe[C6<
008e[@8icP04<H`]Jc6<?Nl2@Q000cW>=Jde[@05>Lh3?Nl01CW>=JdicSW>
@Q000THa0T8@0SF]00DmkdHaAS5243F]00<icP92408icP03?Nm243g_008m
k`03>Lhmkcg_00924096<@07?Nm243g_@Q16<Cg_@Q000TYB00=>Ld8@@Q00
0T8@0Cg_0BDY00001`00124000@Q00048@0000<48@060008@R48AS4aS1cW
12DY00DYBRDY9BTLib4800@U:@038@PYBRU:008]J`03:DXU:BDY008U:@04
:DXU:BU::DX2;F/00bU:9BTQ20038@P59BT28@P67>L00b487>LQ20048@P0
0bDY:DXYBP029BT3:DX00bDY8@PQ20028@P2:DX88@P00acW8@PLi`038@P0
0bDY8@PQ20047>L38@P012DY8@PQ224812DY1B480QcW00<Q22DY:DX00RDY
00DQ21cW8@PQ22U:008]J`05?Nm:DU[FIcU[FP02Kg/03g>LKg]_Nf]JHaQJ
eUJeDYA:DSg_:DXLiaBU248<H`0224801`aS2488@PQ21248@P@Q00<8@P84
8@88@PL48@8<H`0748@DYAS67>LQ21BU48@00PQ200<<H`Q224800`Q21P@Q
00<8@PaS24801@Q20PaS00<@Q0aS36<00PQ20PaS00H8@P@Q12448@Q21243
248436<248@01`aS5:DHaQS67>L@Q0aS0088@P<<H`0548@<H`Q224848@08
248436<3248336<01A245:DDYA2436<00a2410Q210@Q00<8@PaS24800`Q2
00H<H`Q22488@P@Q24835:D01A2436<<H`aS24800PaS00<8@PaS36<00Q24
0PaS10Q200T<H`Q236<8@PaS248<H`Q236<00`Q200<48@Q212400PQ200P<
H`Q236<HaQcW9BTHaQBU0QS600<DYAS67>L00RDY00<Q22DY9BT012U:0R48
0RDY00TYBRe[:DXU:BU:;F/aS3F]<H`00Re[0RU:00@]JbU:;F/aS08]J`03
9BTYBRU:008YBP8]J`8aS007>LhmkcW><H`]JbDY:DX00S6<00@e[Be[:DXa
S0@]J`03<H`]JbU:00<]J`8YBP05;F/YBRDY9BTYBP02<H`012e[:DXYBRU:
0Re[00<YBRe[;F/00SF]00@icSF]<H`e[@<aS08e[@03>Lhe[C6<008aS003
=JdicSF]00<e[@8aS0@e[@8icP03?NlicS6<00@aS00:;F/aS36<=JdicSg_
>Lhe[C6<=Jd2;F/2:DX2<H`01CF]?Nm243g_>Lh00c6<00Pe[Cg_>LhicSg_
@Q0mkcF]0SW>0cF]00<icT8@AS400THa13W>00@mkcW>=JdicPDmk`96<@92
4003>Lhmkd8@008mk`<icP8e[@03<H`e[CW>008e[@8aS0<e[@DicP05=Jda
S36<=JdicP02=Jd0136<;F/aS36<1SF]00<aS3F]>Lh00cg_0SW>00@e[CW>
?Nm6<@8mk`04>LhmkdHaAS42@Q001cg_>LhicSg_@Q16<D8@00@icP04@Q0m
kcg_?Nl4@Q002DHa@Q1243g_@Q0mkd8@?NlicP02?Nl2@Q0014Ha?Nlmkcg_
1D8@0THa00=:DT8@@Q000T8@0BU:000;12401@Q28@Q2436<8@P00RDY00DQ
22DY9BTU:AcW008Q20049BTYBRU:8@P29BT00bU:;F/]J`03:DX012DY:DXU
:BDY0RU:00D]JbU::DXYBRDY008Q20037>LQ22DY00<U:@8Li`056<HLib48
7>LHaP057>L012489BTQ22DY0bU:00<U:BU::DX00RU:0b480bDY00<Q21cW
7>L00RDY0acW00@U:AcW7>LQ20<U:@038@PLiacW00DLi`8Q20039BTQ2248
008Q20069BTQ22DY8@PLib480QcW00DQ22DY:DXYBRDY00<Q20<U:@8]J`07
AS5:DU[FIcU[FW>LKg/00W>L00A[FVmkG_MJeP9BU006AS5242DY6<HDY@Q2
0PaS1PQ200D48@Q21248@P@Q0088@PD48@D8@P0436<DYABU6<H27>L011BU
48@8@PaS10Q220@Q0PQ200<48@Q224800`Q210aS1PQ200D48@Q224848@Q2
00848@88@P0336<@Q12400<<H`8DY@037>LHaQ24008<H`03248<H`aS008<
H`D8@P<48@<8@P<<H`0648@<H`Q2248<H`Q20PaS00D@Q0aS48@@Q1BU008@
Q08<H`061248@P@Q1248@P@Q2`Q200<<H`Q248@00QBU00D@Q0aS36<<H`Q2
00<<H`0448@<HaBU5:D2248212401@aS2488@PQ236<010Q20`aS0`Q200<4
8@Q224800PaS0PQ200DHaR488@PLiaBU008HaP8DY@068@PYBRU:9BTQ22DY
12U:00DU:B488@PU:Be[008YBP039BTYBRe[00<aS007;F/YBRU::DX]JbU:
;F/00S6<00@]JbU:8@PU:@8YBP08;F/YBS6<=JdicT8@>Lh]J`8YBP04;F/a
S2e[;F/2<H`:;F/3:DX01Be[9BTU:BU:;F/00S6<00@]JbU:9BTYBP<]J`8Y
BP8e[@8icP@aS08e[@8icP04=JdaS36<<H`2=Jd2>Lh2=Jd3<H`2=Jd00c6<
>LhicP02>Lh2<H`012U:;F/]Jbe[0S6<00@e[CW>>LhicP@aS08]J`05:DXa
S36<>Li24002?Nl00cF];F/]J`02=Jd013W>?Nlmkcg_0cW>0SF]00PaS3F]
>Lhe[D8@AS5243g_1SW>00`e[CW>>LhmkcW>@Q0mkd8@AS5243g_>Lh3?Nl5
>Lh3=Jd01CW>=JdaS2e[<H`02CF]00@aS3F]=Jde[@<aS003:DXaS36<00<e
[@06<H`icSF]=JdaS3F]0SW>00<mkcW>>Lh00SW>00@mkd8@@Q0icP8mk`96
<@924004?Nle[CW>@Q02AS40148@>Lhe[CF]0cg_00DicT8@@Q16<D8@0096
<@04@Q0mkcg_@Q02?Nl00cW>?Nm24002>Lh00d8@AS524003?Nl4@Q02AS43
@Q01AS41?Nl1:DX0000500048@001240000512401P00248U:DHa=JdLi`8Y
BP8U:@038@PU:B4800<Q20<YBP8Q20DU:@<YBP<]J`8YBP03;F/YBRDY008Q
208U:@038@PLib4800<Li`038@PLiacW008DY@048@PU:BDY8@P26<H01248
7>LQ22U:0Re[00DYBRDY:DXYBRDY008Q208Li`058@PU:BDY9BTQ20047>L3
8@P011cW6<HHaR480bDY0b480QcW00LQ21cW8@PLib487>LQ20029BT28@P0
0acW8@PQ20027>L00aS67>LQ20049BT38@P00bDY:DXU:@029BT012e[BU9B
U5kg0V]J16mk015cW7NmKg]_Ne[FDYA:DTHa>LhYBQS6248<H`Q236<8@P@Q
00<8@P<48@0324848@Q200P48@8<H`@DY@056<HYBRU:7>L@Q002248236<0
0`Q212448@0512400`Q236<8@P05124524801@@Q2488@PQ212402PQ20`aS
0QBU0QS60QBU0PQ20P@Q00<8@PaS36<00`Q200D<H`Q224848@Q200<48@T8
@P@<H`0648@DYABU48@DYA240QBU00<<H`Q212400PQ20`@Q00<8@P@Q2480
20Q200H<Ha2448@DYA2436<324800`@Q248DY@026<H00a2436<8@P0236<2
248236<01`Q236<8@PQ21248@PaS0088@P031248@PQ20088@P0436<DYAS6
7>L38@P37>L26<H28@P01BU:9BTU:BDY:DX00R4800@YBRe[;F/YBP8U:@8Y
BP8U:@8]J`04<H`e[CF];F/2:DX00be[<H`aS002;F/0136<:DXYBRDY0RU:
00<]JbU:;F/00Re[00<aS2e[<H`00S6<00<YBRe[;F/00S6<00LYBRe[<H`a
S2e[9BTQ2002;F/2<H`00be[:DXU:@03;F/39BT00c6<;F/aS002:DX01RDY
;F/YBRe[:DX]J`8aS0@e[@8icP05=JdaS36<<H`e[@03<H`01CF]>Lhe[CF]
>Lh00S6<00<]Jc6<<H`00SW>0T8@00Y6<D8@=Jde[C6<;F/aS2e[<H`e[@Hi
cP03=JdaS36<008]J`8YBP03<H`e[Cg_008icP8aS004=JdicSg_=Jd2>Lh0
0cg_>LhicP02=Jd3<H`01CF]@Q16<Cg_>Lh00SF]1Cg_00Pe[C6<=Jde[CW>
?NlicSg_0SF]0SW>0cg_0SW>0SF]136<0SF]136<0SW>00De[Cg_?NlicSF]
008aS005=JdaS36<;F/e[@02<H`012e[<H`aS36<0cF]00<aS3F]>Lh00Sg_
00<icT8@@Q000T8@0cW>00Lmkd8@@Q1244Ha@Q0mk`03>Lh013g_@Q1243g_
0SW>00<mkcW>>Lh00cW>0Sg_0d8@00A6<D8@?Nlmk`=24003?Nle[CW>00Dm
k`04>Lhmkcg_?Nl2AS42BU83@Q02?Nl1:DX000D48@0300048@@Q00<48@05
248U:DYB=JdLi`069BT011cW8@PQ22480RU:00HU:B488@PQ22DY:DX39BT0
0bU:;F/aS002;F/2:DX022e[9BTQ21cW8@PU:B487>L38@P01AcW8@PLiacW
6<H00QBU00HQ22DY9BTQ21S67>L29BT011cW9BTYBRe[0bU:0RDY0b4800HL
ib489BTYBRDY8@P37>L02AS67>LQ22487>LHaQcW8@PU:@038@P27>L01248
7>LHaQcW0R4800<Lib488@P00bDY00<Lib488@P00R480acW0R480RDY0QcW
00`Q22DY:DXYBR487>L]Jc6<BU9BU5[FJeX2Kg/03W>LKg]_Ng>LMke_Nf]J
F]IBU4YBAS4e[BDY5:D624800`@Q24848@0412400`Q212448@0512432482
48@45:D01RDY:DXLia241248@P8<H`88@P0500048@@Q00048@0224800`aS
24848@03124524800`@Q2488@P0624831243248436<248@01QS65:D@Q124
36<8@P848@<8@P0336<8@PQ200<8@P031248@PQ200<48@X8@P8<H`<@Q006
5:D@Q1BU48@DY@aS0PQ200<48@Q2248010@Q0PQ21PaS00T8@Q2448@DYA24
36<8@PaS12400PQ200H<HaBU6<HHaQ24248236<5248010aS2488@PQ20`aS
00<48@Q224800`Q20PaS00H@Q1S66<HQ21cW6<H27>L01AS67>LHaQcW9BT0
0RU:010Q22DY9BTYBRDY:DX]JbU:9BTQ22DY;F/U:BU:9BTYBP8]J`8aS08]
J`8YBP<]J`03<H`]Jbe[00<YBP03;F/aS2e[008YBP03;F/aS36<008]J`03
:DX]Jbe[008YBP06;F/YBS6<=Jd]JbU:0RDY00T]Jc6<=JdaS2e[:DX]JbU:
;F/00bDY00@YBRe[<H`]J`<YBP05;F/YBRU::DX]J`02<H`013F]<H`aS3F]
0SW>00<e[C6<<H`00S6<00Le[C6<<H`e[CW>=JdaS002=Jd2<H`012e[=Jde
[CW>0T8@00@mkd8@=Jde[@8]J`09<H`]Jc6<<H`icSF]>Lhe[CW>008e[@04
<H`e[Be[9BT2:DX01C6<>LhmkcW>=Jd00S6<00De[Cg_>LhicSF]00<icP<e
[@<aS009>Li2448@?NlicS6<=JdmkcW>00<mk`@e[@08?NlicSg_>Lhe[C6<
=JdicP924003?NlicSW>00LaS08e[@<aS008>Lhe[C6<>LhmkcW><H`]J`<e
[@04;F/aS36<;F/3<H`02CF]<H`e[CW>=JdaS3F]>Lhmk`03>Lh2@Q000cg_
>LhicP02?Nl2AS40248@AS4mkcg_>Lhe[CW>?Nl2@Q001Cg_>LhmkcW>?Nl0
13W>00<mkd8@@Q00148@00<mkcW>>Lh00T8@00DmkcW>=JdicSg_009240<i
cP8mk`05@Q16<DHaBU96<@02@Q01?Nl1>Lh1:DX0000300048@0000P48@0:
248Q24Ha<H`Q22U:;F/U:B489BT48@P01BDY:DXYBRU:9BT00QcW0R480bU:
0RDY00<YBS6<<H`00Re[00LYBR488@PLib489BTYBP029BT00b487>LLi`02
8@P47>L28@P00bDY8@PQ20027>L01B489BTQ21cW9BT00RU:00<U:AcW8@P0
0acW0R4800DU:B488@PU:B4800LLi`@Q208U:@038@PU:BDY00HLi`038@PL
ibDY008U:@8Q20037>LQ22DY00@Q20047>LU:B488@P39BT28@P39BT02B48
7>L]JcW>BU9BU5JeG_MW>@02Kg/5Li`02FmkHaQNme:DBU9242U:8@P@Q002
36<00`Q236<<H`03248312400`Q21248@P04124020Q2124@Q1245:D@Q0aS
248236<01Q249BTYBQcW5:D48@8<H`0324848@@Q00@48@<8@PL48@@8@P04
1248@PQ2124224801PaS2488@P@Q24848@88@P<<H`076<HDYAcW7>L@Q0aS
12402@Q200@48@Q21248@PL48@0324848@@Q00D8@P0536<@Q12448@<H`02
48@01ABU6<HDYA2436<00`Q200<48@Q224801@Q20PaS00<@Q0aS36<00PaS
00<8@PaS48@00PaS0P@Q00<8@P@Q24800PaS0Q2400<<Ha2436<00PaS00H@
Q0aS36<<H`Q236<724801`aS48@@Q1S67>LQ22DY008Q208Li`036<HLiacW
008Li`8Q20089BTQ22DY9BTYBRe[:DX]J`@YBP049BTQ22DY:DX2;F/3<H`0
13F]<H`aS2e[0bU:0S6<00@]JbU:;F/YBP@]J`03<H`]Jbe[00<]J`06:DX]
Jbe[;F/YBRe[0RU:0c6<00<]JbDY9BT00Re[0S6<0Re[1bU:0Re[00<aS2e[
;F/00bU:00<]Jc6<<H`0136<00@e[Cg_?Nlmk`PaS08]J`04<H`e[CW>=Jd2
<H`01RU:<H`icSg_CW=:DP9BU005@Q0icRe[;F/aS002;F/0136<>LhicSW>
0S6<00@e[CW>>Lhe[@8aS008;F/YBRe[<H`e[CW>=JdaS08e[@06<H`icSg_
?Nm243W>0SF]00<aS3F]<H`00SF]0SW>0SF]0SW>00He[CW>>Lhmkd8@?Nl2
>Lh00cF]>LhicP04>Lh023g_>Lhe[CF]>LhmkcW>=Jd3<H`01cF]<H`]Jc6<
=JdmkcW>00<e[@<icP03?Nle[C6<00DaS0<e[@8aS004=JdaS3F]?Nl3>Lh3
=Jd01CW>?Nm243g_>Lh00Sg_00=243g_?Nl01Cg_0SW>00@e[CW>>LhicP8m
k`=240@mk`03=JdicSW>0096<@A2408mk`924003?NlicSW>008icP8mk`04
@Q0mkcg_?Nl7@Q000cg_@Q0mk`01;F/000@48@0300048@@Q00848@070004
8@Q29BU6<C6<7>L00bU:00@U:B488@PHaP8Li`038@PYBRDY008U:@@Q2003
9BTYBRU:008U:@8]J`06=JdaS2U::DXQ21cW0R480RDY0b4821cW00@Q22DY
8@PQ20<Li`038@PU:B48008Q208YBP059BTLiacW8@PLi`028@P00bDY8@PQ
20028@P00acW8@PLi`026<H01B487>LLiacW6<H00b480RDY0R481QcW1248
00DU:B487>LLib48008U:@038@PLib48008Q20047>LQ22488@P49BT48@P0
0be[=Je:DP02E[D00f<HIcU_N`02Kg/2Li`02WNmKg]_Nf<HG_MBU4ic?NlY
BR480PaS00<8@PaS36<00`Q21@@Q00D8@P@Q124000@Q00<8@P0636<@Q1BU
5:D<H`Q20PaS00D@Q2DY:DXLiaBU0088@P0336<48@@Q00D48@<8@PD48@<8
@P031248@P@Q0088@P848@88@P0436<8@P@Q24821242248236<00a246<HH
aP026<H236<2124424800`aS2488@P0312400`Q212448@04124224821247
24800`aS48@@Q00348@01ABU6<HHaQBU36<00PQ210@Q1@Q21PaS00<8@PaS
36<00PaS00D8@P@Q2488@PaS00<8@P<@Q0T<H`03248<H`Q200@8@P0536<8
@Q2448@DY@027>L29BT012487>LLiacW0b480QcW124800@U:BU::DX]J`<Y
BP03;F/YBRDY008U:@8YBP04;F/aS2e[=Jd3<H`4:DX01Be[:DX]Jc6<;F/0
0bU:00@]Jc6<<H`]J`<YBP06;F/aS36<:DX]JbU:1Be[00HaS2e[:DXU:BU:
;F/2<H`00be[:DXYBP04:DX012e[:DX]Jc6<0Re[12U:00DU:Be[<H`e[C6<
008]J`06=Jdmkcg_>Lhe[Be[2C6<0SF]0c6<00`]Jc6<=JdmkdicBU9BU4ic
?NlicRe[:DX2;F/0136<=JdaS3W>0SF]00<aS3F]<H`00SW>0S6<0RU:00@]
Jc6<>Lhe[@8aS007=JdaS36<>Lhmkd8@?Nl00SF]0S6<0SF]0c6<13W>00Pe
[C6<=JdicSg_@Q0mkcW>0SF]13W>0SF]00<icSg_=Jd00SF]0SW>00<e[C6<
;F/00c6<00LYBRe[=JdmkcW>=JdaS004>Lh3=Jd3<H`012e[=JdaS3F]136<
00<icSF]>Lh00SW>00DmkcW>>LhicSF]00<icP<mk`05>Lhmkcg_?Nm24002
?Nl6>Lh3?Nl01D8@AS5243g_>Lh00Sg_00LicSF]?Nm244Ha@Q0mk`02@Q00
1cW>?Nlmkd8@?NlicSF]00<icP09@Q0mkd8@?NlicT8@?Nm243g_00E2404i
cP4YBP0000<000@Q12400`@Q00X000@Q12448@00248Q248@<H`Q20<YBP<U
:@067>LQ22488@PU:B480RDY0R4800@U:B489BTU:@8Q20099BTQ22DY;F/e
[CW><H`Q21S6008Q2005;F/U:B487>LQ20047>L28@P01QcW6<HLiacW8@PL
i`8Q20079BTQ22488@PU:BU:9BT00R4811cW1B480RDY0R4800LHaQcW7>LL
ib487>LQ20027>L012489BTU:BDY1b480QcW0R4800<U:BU:9BT00R480bDY
00<Q22DY8@P01B4800TU:AcW8@PQ22DY:DXU:AcW8@P00RDY0S6<00E244YB
CW=JeUkg00=[FP9_N`0>Lia_Ng>LJeYW>F<HE[E>Lcg_>LhU:AcW5:D@Q08<
H`0324848@Q20088@P<48@@8@P<<H`<8@P0<1248@PQ248@LibDY8@PDY@Q2
48@<H`Q21@@Q00P8@P@Q2488@P@Q24848@000P@Q00@8@P@Q12448@88@P84
8@0324848@Q20088@P0536<48@Q2248<H`02248011S68@PU:AS60QBU00<<
H`Q212401PQ200<<H`Q212400`@Q00<8@P@Q12401@@Q00<8@P@Q24800`@Q
00<8@PaS24800`aS0PQ200L<Ha2448@@Q1BU6<H@Q00424800`@Q2488@P05
36<01A2436<<H`Q236<01@Q200@48@Q224848@<8@P<@Q08<H`0648@HaQcW
8@PHaQ241@aS00@8@PaS48@DY@8HaP068@PLib487>LQ22DY0RU:00@U:B48
8@PQ208U:@058@PLib488@PU:@02:DX00be[:DXYBP02;F/2:DX00bDY:DXY
BP03<H`012e[<H`]Jc6<0SW>00@aS2U:9BTU:@@YBP08;F/YBRDY:DX]Jc6<
:DXQ20<U:@03:DXU:BU:008YBP8]J`8aS08e[@<aS003=JdaS3F]00<aS08]
J`8aS003=JdaS2U:00<YBP8aS004;F/YBRU:9BT2;F/3<H`042e[<H`]Jbe[
<H`e[CW><H`]JbU:<H`e[C6<=JdaS3F]0S6<0SW>01DaS2e[;F/icSF]>Li2
44HaCW=F]D8@>Lh]Jc6<=JdaS2e[<H`icSF]>Lh00S6<13W>0S6<00@e[Be[
;F/]J`@aS004=JdicSF]?Nl2AS4013g_=Jde[CW>0S6<00Te[CW>>Lhe[Be[
<H`e[CW>?Nl00cW>00=243g_>Lh013W>0SF]00@icSF]?Nlmk`8icP8e[@8i
cP03=JdaS36<00<aS003;F/aS3F]00<mk`=24004?NlicS6<=Jd2>Lh3<H`0
0cF]>LhicP02>Lh2=Jd00cg_@Q124002>Lh00cg_>LhicP02=Jd01CW>?Nm2
43g_>Lh00T8@0Sg_00<e[CW>=Jd00SF]00PicSg_>LhicS6<=JdicSg_0T8@
00<mkd8@@Q000T8@0Sg_00=244YBAS400cg_0T8@00HmkcW>>LhicSg_>Lh2
=Jd2?Nl00dHa@Q0mk`03@Q0023g_>Lhe[CW>?Nm244Ha?Nl1:DX000061240
00@Q00048@001@@Q00D8@R48@Q0aS24800<YBP039BTQ224800HQ20@U:@07
8@PU:BDY8@PLib48:DX00RDY00D]Jc6<=JdaS248008Li`039BTYBRDY00LL
i`038@PLiacW008Li`<Q20037>LQ224800@Q208U:@8Q20036<HLibDY008Q
20037>LQ224800@Q20HLi`048@PLiacW6<H28@P01BDY8@PLib487>L01248
00LLib487>LQ22DY8@PU:@028@P29BT38@P00bDY8@PQ20058@P011cW9BTU
:BDY0b480RDY00LYBSF]?Nm:DTicF]IS6002IcT6Kg/02F]JIcUS65JeCW<m
kcW>9BTLi`0348@6248010@Q24848@Q20P@Q00@8@PaS48@<H`@8@P8<H`05
248Lib487>L@Q002248236<612400`Q212448@091242248212400`Q21248
@P0224800`aS2488@P02248010aS248<HacW0RDY00@Lia245:D<H`<48@<8
@P0536<8@PQ21248@P0212400`Q212448@0:1246248236<020Q236<<Ha24
5:D@Q1S65:D236<00`@Q2488@P03248336<248@436<00`Q236<8@P052482
1243248336<348@01aBU7>LLiacW5:D<Ha2400<8@P0336<@Q0aS008HaP8L
i`068@PLiacW8@PU:BU:0bDY00<Q22DY8@P00R4800LU:B488@PQ22DY;F/a
S002:DX3;F/4:DX01Be[<H`aS36<;F/00S6<0SW>00<aS2e[8@P012DY00DY
BRe[:DXU:BU:008]J`03:DXU:BDY008YBP@U:@8]J`@aS0De[@8aS08]J`03
<H`]Jbe[008aS08e[@@YBP04<H`e[Be[:DX29BT00bU:=JdaS002<H`2;F/0
1C6<;F/aS3W>=Jd00S6<00<YBRe[;F/01C6<00<e[C6<=Jd00Re[00@aS3F]
>LhicP96<@9BU005@Q0e[Be[<H`icP03<H`2>Lh2=Jd00c6<=JdicP02>Lh2
<H`01Re[:DX]Jc6<=JdaS08]J`04<H`icSF]?Nl2AS40148@=Jde[CW>0c6<
0SW>0c6<0cW>0SF]00DicSg_?NlmkcW>00@e[@8aS003=JdicSg_008icP03
=JdaS3F]00@e[@@aS08e[@03>Lhmkcg_00@mk`05>Lhe[CF]>Lhe[@03<H`0
0cF]>LhicP02>Lh00cF]<H`mk`02@Q0013g_>LhicSg_0SF]0SW>00=243g_
>Lh00cg_00A243g_>LhicP8e[@<icP03?NlicSF]008e[@03?Nm2448@0092
4007?Nm2448@?NlicT8@AS400T8@00LicT8@@Q1243g_>Lhe[@04>Lh00cF]
>Li24002@Q02?Nl00d8@?NlicP02>Lh2?Nl2@Q01?Nl1:DX000`48@068@Pm
kbU:7>LU:BU:0RDY00@Q22DY9BTU:@8Q208Li`058@PU:BU:8@PLi`028@P0
41cW8@PU:BDY:DXU:BU:9BTaS3F];F/Q21S67>LYBRDY0QcW0R480acW00LQ
22DY8@PLiaS67>LU:@048@P29BT2:DX012489BTLiacW1B480QcW00@Q22DY
9BTU:@8Q20<Li`058@PU:B488@PLi`048@P01BDY8@PQ22487>L00R480acW
0R480RDY0bU:0bDY0RU:00DU:B487>LHaQcW008Q20049BTQ22489BT48@P0
3bU:9BTU:BDY;F/aS3F]?Nm6<E:DE[EJeV<HJeY_N`05JeX02fmkJeYW>F<H
BU9243F]<H`U:B4848@00PaS0`Q200D48@Q22488@P@Q0088@P0336<8@P@Q
00<48@04248<H`aS6<H27>L01QBU36<<H`aS248<H`<48@88@P031248@P@Q
00/48@P8@P051248@PQ2124<H`0248@36<H00aBU48@@Q00236<010@Q2488
@P@Q0`Q20`@Q00<8@P@Q12401@@Q00<8@P@Q12400P@Q00P8@P@Q1248@P@Q
248<H`Q20P@Q00<8@PaS36<00PQ200<<Ha2448@00QBU0Q2400@<H`Q22488
@P<<H`T8@P<<H`0324848@Q200@8@P0<124<H`Q2248<H`Q27>LaS3W><H`H
aPaS0a2400<DYA247>L0124800<Lib489BT00RU:00LU:BU:;F/YBRDY8@PU
:@02:DX012DY8@PU:B480bU:0RDY00<YBRe[<H`00be[0c6<0RU:00X]Jc6<
>Lhe[C6<=JdYBRDY8@PU:@8YBP03;F/YBRU:008U:@<YBP039BTQ22DY008U
:@03:DXU:BDY00@YBP8aS003=JdaS3F]008icP03=Jd]JbU:008YBP03;F/a
S3F]008icP03<H`]Jbe[00DaS00:=JdYBRU::DXaS3W>=JdaS3F]<H`4;F/3
<H`3;F/3<H`00be[<H`e[@02>Lh012e[<H`aS36<0SF]00<aS3W>?Nl00Sg_
0SF]136<13F]00<aS3F]>Lh00SF]0S6<0cF]00@aS2e[;F/aS0<e[@05>Lha
S3F]>Li24002>Lh2<H`013F]<H`aS36<0cW>00LaS3F]=JdicSg_>Lhe[@02
?Nl00cW><H`aS002>Lh01SF]<H`aS3F]<H`icP8mk`04@Q0mkcg_>Lh2=Jd0
13W>?NlicSF]0S6<0SW>00<mkd8@@Q000Sg_0SF]00LicSg_?NlmkcW>=Jda
S002=Jd2<H`013F]>Li2448@0THa00<mkd8@@Q000d8@0Sg_00A243g_@Q0m
k`8icP0:?NlicSW><H`e[C6<;F/e[CW>@Q02>Lh013F]?NlmkcW>0Sg_0SW>
0Sg_0T8@00I6<DYBBU96<CW>?Nl2@Q001Cg_=Jdmkd8@?Nl00SW>1Sg_0T8@
00I6<D8@?NlicSF]?Nl2@Q01?Nl1>Lh1:DX0000300048@0000848@0<0004
8@@Q124000@Q248LicW><H`LibDY0R4800<U:B488@P00bDY0QcW00<HaRDY
9BT00RU:0QcW00<Q21cW8@P00RDY0RU:0RDY00L]JcF]:DXQ21BU6<HU:@02
7>L28@P37>L28@P01BDY7>LLiaS67>L01R4800DU:Be[:DXYBRDY008Li`04
8@PLib488@P27>L012487>LQ22DY0R4800<LiaS66<H00QcW0b4811cW00<Q
22DY8@P00QcW00DQ22DY7>LLiaS6008Li`038@PU:BDY008YBP8U:@058@PU
:BU::DXU:@028@P00aS67>LLi`028@P011cW8@PQ22DY0R480RDY00@Q22DY
:DX]J`8e[@07@Q16<E:DDYANmf<HJeX00Vmk16]J00I_Nf]JIcUNmdHa@Q02
<H`012DY7>LDYA240PaS0P@Q2@Q20`@Q00P000Q2248<HaS67>LHaQBU0PQ2
0PaS00<48@Q224803P@Q00@8@P@Q12448@@8@P0336<8@PQ200<48@08248<
H`aS48@HaQBU6<H@Q08<H`/8@P848@88@P/48@0324848@Q200<8@P848@D8
@P8<H`8@Q08DY@0348@<H`Q200@8@P8<H`@8@P041248@PQ2248236<32482
124524802`@Q2488@Q2436<HaS6<=JdaS1S636<0112400TDYAcW7>LQ22DY
8@PLib489BT00RU:0RDY00DYBRDY8@PQ22DY008YBP039BTQ2248008U:@HY
BP<]J`<aS007;F/YBRU:;F/aS3F]<H`00SF]00@U:B488@PQ208YBP039BTY
BRU:008U:@8YBP049BTQ22488@P49BT042U:9BTYBRDY:DX]Jc6<=JdaS3F]
?NlicS6<:DXU:Be[0RU:00@aS3F]=Jde[@DaS08]J`03=JdicRe[008YBP04
<H`e[C6<=Jd2<H`2;F/012U:<H`]JcF]0Re[136<0Re[00DaS3F]>Lhe[C6<
008]J`@aS005>Lhmkcg_>LhaS002=Jd00c6<=JdaS002<H`7=Jd3<H`2=Jd3
;F/01C6<=JdaS3F]<H`00SF]0cg_00HicRe[<H`aS2e[<H`2=Jd2>Lh00cF]
<H`e[@05>Lh013g_<H`aS36<0SW>00De[Be[<H`aS3F]008mk`<icP8mk`04
=JdaS3F]>Lh2=Jd02S6<=JdicSW>?Nm243W>?NlicSF]0cW>00A243g_=Jde
[@8aS006=JdaS36<=JdicT8@0THa148@00=6<D8@?Nl01cg_13W>00<e[C6<
;F/00S6<0Sg_00DicSF]=JdicSg_00<icP04?NlicSW>>Lh3@Q0024HaBU92
43g_>Li244Ha?Nl3>Lh3?Nl2>Lh3?Nl01T8@?Nm6<D8@?NlicP8e[@<mk`52
404icP4YBP0010@Q00<000@Q124010@Q00P8@QcW@Q0]JacW9BTYBRDY0R48
0RDY0bU:0acW00/Q22DY8@PQ21cW8@PLib48:DX]JbU:00<Q208]J`03:DXU
:AcW008Li`048@PU:BU::DX29BT00b487>LYBP02:DX01RDY7>LHaR487>LU
:@8Q208U:@04:DX]Jbe[;F/2:DX022487>LLiacW9BTQ21cW8@P29BT00b48
7>LLi`026<H27>L012DY8@PLib4812DY00<Q22DY8@P00R480QcW00<Q21cW
7>L00R480RDY0bU:1BDY00<Q22DY8@P00QcW00<HaQcW8@P00bDY00<Lib48
9BT00bDY0R480RU:0Re[00<aS3F]>Lh00TYB00EBU5[FF]INmf<H009W>@08
Kg][FWNmMke[FVLiCW=:DP96<@03?NlicRU:008HaP0536<8@PQ2248<H`02
24800`aS1248@P0512402@aS5:DU:BDY5:D<H`@Q248<H`02248010@Q2484
8@Q20`@Q0PQ20P@Q00<8@P@Q12401`@Q1@Q200<<H`Q224800`Q200H<Ha24
48@@Q0aS48@236<5248010@Q24848@Q230@Q00@8@P@Q12448@<8@P848@05
24848@Q224848@05248236<00`Q236<<H`0248@536<424802P@Q2488@P@Q
24848@Q236<@Q0aS0`Q200D<Ha242488@P@Q00<8@P0436<8@QcW;F/2=Jd0
1B485:DDYABU7>L00R4800HLib488@PLibDY;F/2<H`00be[8@PU:@028@P0
12DY8@PU:BDY0bU:0RDY00HYBRe[:DXYBRDY:DX2;F/4<H`012U:;F/YBRDY
0RU:00<aS3F]<H`00be[0RU:0Re[0RU:00<U:BU::DX012DY00<YBRDY9BT0
0RDY00<YBRe[:DX00bU:00@]Jc6<;F/e[@8icP09?NlaS3F];F/YBRe[:DXa
S3F]00<aS08]J`@YBP<]J`8aS08YBP089BTYBSF]=JdaS2e[:DX]J`8e[@8a
S003;F/aS36<008icP8e[@04<H`e[CF]>Lh3=Jd01S6<=JdaS3W>?NlicP8m
k`03>Lhe[C6<00<aS003>Lhe[CF]0092408icP8aS0@icP04=JdaS36<;F/2
>Lh01SF]<H`e[CF]<H`e[@@icP8aS004=JdicSW>>Lh2<H`2=Jd3>Lh00cg_
>Li24002?Nl00cW>?NlicP02=Jd2<H`2=Jd01CW>?Nlmkd8@?Nl00SW>0c6<
0SF]0S6<00<icSg_>Lh00SW>00E243F]=JdaS3F]00@icP04=JdicSF]>Lh3
<H`02CF]>LhmkcW>?Nm244Ha@Q0mk`02>Lh2@Q03>Lh00cg_>Lhe[@04>Lh0
1C6<;F/]Jbe[=Jd00SW>00<e[C6<?Nl00T8@00@mkcF]?Nm240@mk`96<@04
@Q0mkcW>>Lh;@Q001Cg_@Q0icSg_@Q000THa00=:DSg_?Nl013W>00<mkd8@
?Nl00Be[0000100012448@001P@Q00T000Q27>LicRU:7>LU:B489BT00b48
00@U:BU::DXU:@8Li`8Q208U:@@Li`039BTYBRU:008U:@037>LQ22U:008Y
BP069BTLiaS68@PLib480RU:00PU:B487>LQ22U:;F/YBR480QcW124800DU
:B489BT]JbU:008]J`089BTQ21S66<HQ21cW8@PU:@<Q208U:@8Li`8HaP03
7>LQ224800DQ208U:@DQ20047>LQ21cW6<H27>L012DY:DXYBRU:0bDY00DQ
22DY9BTQ22DY00<Q20<Li`HQ20<U:@8Q20039BTYBRU:00<]J`8icP03AS5:
DU:D009JeP=S6008JeY_NfmkLiag_F]JHaQ>L`9:DP06@Q0mkcF]9BTLiaBU
10Q200<<H`Q236<00`Q210@Q00L8@Q246<HQ21cW48@<H`03248212432482
124010Q212448@@Q0PQ20`@Q00<8@P@Q12400`@Q00<8@P@Q24801PQ200H<
H`Q2248<Ha245:D248@436<324800`@Q2488@P03248712400`0012448@03
124010Q21248@PQ20P@Q1PQ20`@Q0PQ200@<H`Q236<<H`8@Q0D<H`88@P04
36<8@P@Q2482124010Q212448@Q20`aS0PQ21@aS10Q20PaS00DHaRU:<H`a
S2DY008DY@8HaP039BTQ21cW00<Li`069BT]Jc6<<H`U:B480bDY0R4800<U
:BU::DX00RU:00DU:BU:9BTYBRe[00<YBP8]J`<aS08]J`04:DXU:BDY:DX2
;F/00c6<;F/]J`03:DX00be[:DXYBP02:DX49BT4:DX01bDY8@PU:BDY;F/Y
BRe[00<YBP<]J`05<H`icSg_>LhaS002;F/2:DX2;F/3<H`012e[:DX]Jbe[
0bU:00<aS2e[;F/00Re[00@YBRDY:DX]J`8e[@04<H`]JbU::DX2<H`2;F/2
<H`00cF]>Lhe[@02=Jd2<H`2=Jd0136<=Jde[C6<0SF]00TicSg_>LhmkcW>
=JdicS6<;F/00S6<0SF]00HicSg_?NlicSF]<H`3=Jd01cW>?Nle[C6<;F/a
S3F]008icP06=JdaS36<<H`icSF]0SW>00Te[Be[;F/e[CW>=JdaS2e[<H`0
0SF]13W>00<mkcW>>Lh00SW>00<e[CW>=Jd00SF]00<aS3F]>Lh00SW>0Sg_
0cW>0S6<00Te[CW><H`]Jc6<>LhmkcW><H`00Sg_00DicS6<;F/aS3W>008m
k`8e[@03>LhmkcF]00<aS0<icP<mk`0<@Q1:DSg_>Lhe[Cg_AS4mkcF]>Lhm
kcW>0SF]0SW>00<e[C6<;F/00Re[00HaS3F]?NlaS3F]>Lh2@Q001Sg_>Lhi
cSW>?Nm2408mk`96<@06?NlicSW>>Lhmkd8@0cg_00=244HaAS400d8@0Sg_
00/icSg_@Q1244YBAS4mkcW>=JdicSg_008icP52404mk`4]J`000P@Q00D0
00@Q12448@0000@48@08248Licg_;F/LibDY8@PLi`<Q20059BTQ22488@PU
:@028@P27>L48@P011cW8@PU:BDY12480bDY00TYBR488@PLib48:DX]JcF]
<H`00Re[0S6<00@]JbDY9BTLi`8HaP037>LU:B48008U:@03:DXaS2e[008]
J`03:DXU:BDY008U:@09:DXU:BU::DXU:B486<HLib4800<Li`036<HLib48
00<Q208U:@8Q20<U:@047>LQ22487>L28@P01bDY8@PQ22DY:DX]JbU:00@U
:@<Q208U:@@Q208U:@048@PLib488@P29BT2:DX00bDY:DXYBP03:DX5;F/2
=Jd2@Q001DYBDYAF]F<HIcT01Vmk0V]J0Ukg00EBU4icAS4]Jb48008@Q0@<
H`88@P@48@06248@Q1BU6<H@Q0aS0`Q200<48@Q2124010@Q00<8@P@Q2480
3P@Q00<8@P@Q36<00PaS00@8@PaS36<<H`<8@P8<H`0548@<H`aS48@<H`02
24800`@Q2488@P03124010Q212448@Q20P@Q00<8@P@Q12401`@Q00<8@P@Q
124010Q200<48@Q224800PQ20P@Q10Q200D48@Q2248<Ha24008<H`04248<
H`aS36<32484124324800`@Q36<8@P0236<00`Q236<8@P0236<4248236<0
11S67>LU:BDY0QcW00/HaQcW8@PLib487>LHaR48:DXaS2e[00DU:@038@PU
:BDY008U:@LYBP8]J`DaS08]J`05:DX]JbU::DX]J`05:DX00be[:DXYBP02
:DX00be[:DXYBP04:DX00bDY:DXYBP02:DX01be[9BTU:BDY:DXaS3F]00<]
J`8YBP8]J`03<H`]Jc6<008aS004;F/YBRe[<H`2;F/01c6<=JdaS2e[:DXU
:BU:008]J`07:DXU:Be[<H`e[C6<;F/00bU:0S6<00H]Jc6<;F/aS2e[:DX4
;F/3<H`4>Lh3<H`00be[<H`aS003<H`023F]>Lhmkd8@>Lhe[C6<;F/2<H`0
0cF]>LhicP02?Nl2>Lh2<H`00cF]<H`e[@02>Lh4<H`3>Lh2=Jd013W>=Jda
S3F]0cW>00@e[C6<=Jde[@8aS006;F/aS3F]=JdicSF]0SW>0T8@00HmkcF]
<H`e[C6<=Jd2<H`023F]<H`icT8@?NlicSF]<H`3>Lh6=Jd02CW><H`icT8@
BU9243W>;F/aS003=Jd5>Lh3=Jd02CW>@Q0icSF]>LhmkdHa@Q0icP02=Jd0
1CW>?NlmkcW>=Jd00SW>00HmkdYBAS4mkcW>:DX3;F/3<H`2=Jd2>Lh2@Q02
?Nl0148@?Nm2448@0THa00E243g_?NlicSg_00924096<@A24005AS5>Le:D
BU924002>Lh2?Nl2AS401Cg_@Q0icSW>?Nl00T8@0DHa0D8@0Be[00000`@Q
00048@0212401@0012448@@Q00000P@Q00LQ23W>:DXHaR489BTLi`028@P3
9BT28@P47>L48@P27>L28@P00bDY8@PLi`028@P00bDY8@PQ20029BT38@P0
1RDY<H`e[C6<;F/YBP<]J`8Q208HaP037>LQ2248008Q20049BTYBRe[<H`2
;F/01RDY:DXU:B489BTQ20<YBP068@PLiacW6<HLib480QS600@LiaS68@PY
BP8U:@048@PLibDY9BT38@P012DY8@PLiaS60QcW00HU:B489BTYBRe[:DX5
9BT012489BTQ22DY0b480QcW00<Q22DY8@P00R480RDY00XYBRDY8@PU:BU:
;F/YBRDY:DXaS08]J`06:DX]JcF]>Li244Ha0Tic00=F]F<HIcT00Vmk00ec
W6mkKg]cW6]JIcUS65[FDYA:DT8@:DXQ200248@00`aS248<H`0236<00`Q2
12448@0212402@Q25:DDYABU48@8@PaS24848@032486124010Q21248@PQ2
2`@Q0PQ200@<H`Q236<8@P<<H`<8@P0336<@Q0aS008@Q08<H`88@P<48@<8
@P031248@P@Q00848@0524848@@Q1240000212400`Q212448@0212462480
1PaS24848@Q21248@P<48@D8@PP<H`0524848@Q21248@P05124224800`aS
48@8@P02248236<5248236<01QBU7>LU:BDY7>LHaPDLi`8HaP069BTYBRe[
;F/Q21cW0b480RU:0bDY1BU:00<]JbU:;F/00Re[0S6<00<]JbU:;F/00Re[
12U:00<U:B489BT00be[1BU:00@]JbU::DXU:@@YBP089BTYBRe[;F/YBR48
9BTYBP<aS003;F/YBRU:00D]J`8aS08]J`03:DX]Jbe[008]J`8aS08]J`03
9BTYBRe[008]J`049BTYBRU:<H`2=Jd2:DX012DY;F/aS36<0be[0RU:00<U
:Be[;F/00S6<00LYBRe[;F/icSg_>Lhe[@04;F/5<H`2=Jd0148@?NlicSW>
0Re[00<aS2e[=Jd00SW>00Dmkd8@>Lhe[Be[00De[@05>LhaS36<;F/e[@02
>Lh00cF]<H`e[@02>Lh01CF]<H`icSg_=Jd00S6<0SF]00<aS2e[<H`00S6<
00<icSF]>Lh00SW>0T8@00HicSF]<H`aS3F]<H`2;F/2<H`013g_>LhicSW>
0c6<00<e[CW>>Lh00SF]00<aS3W>=Jd00S6<00LicT8@AS52436<;F/aS002
=Jd2>Lh2=Jd00cW>=JdicP02=Jd2?Nl00cW>=JdicP03?Nl2>Lh01cF]>Lhi
cSF]>Lhe[CW>008mk`924004>Lhe[Be[;F/2:DX01Be[<H`e[C6<=Jd00SW>
00=243g_@Q000cg_0T8@00@mkd8@@Q0mk`8icPA24096<@92400<?Nm:DU:D
CW=:DT8@=JdicSg_@Q16<D8@1Cg_0SW>0D8@0Cg_0Be[00001@0012448@@Q
00001P@Q00H8@QcW=JdU:AS67>L28@P00acW8@PLi`027>L012489BTYBRDY
0acW0b480QcW12480bDY0QcW00/Q22DY:DXYBRDY8@PU:BU:<H`e[Be[00@a
S08YBP<Li`096<HU:B489BT]Jc6<;F/YBR4800<U:@<Q20049BTYBRe[:DX2
8@P26<H01QcW8@PQ21cW5:DHaP8Q2003:DXU:B48008Q20039BTQ22DY008U
:@06:DXQ22487>LQ22U:0R4800@U:BU::DXU:@8YBP05;F/U:B487>LQ2002
9BT28@P011cW8@PQ21cW0bDY0b480RU:00@]JbU::DXU:@8YBP0@;F/YBR48
9BTYBRe[:DXU:Be[=JdicSg_AS5>LekgHaP2JeX00fmkLiacW002Kg/2Mkd0
26mkG_MBU4YB?NlicR487>L436<224800`aS248<H`0248@00`aS2488@P02
248412400`Q212448@021242248212400`Q212448@051240100012448@Q2
0P@Q00<8@PaS24800`Q200<<H`Q236<00PQ200@DYAcW5:D<H`848@0336<8
@PQ200D48@0324848@Q200H48@0324848@@Q00@48@0724848@Q224848@Q2
36<00PQ200<<H`Q224800PQ200H48@Q21248@P@Q248336<2248436<010Q2
36<48@Q21`@Q0PQ20`aS00H8@PaS48@DYAS65:D248@26<H00bU:;F/YBP03
8@P00bU:9BTHaP026<H00b487>LU:@02:DX01bDY8@PQ22DY:DXU:BU:00@U
:@8YBP0:9BTYBS6<<H`]JbU:;F/aS2e[:DX4;F/29BT00bU:;F/]J`02:DX0
1BDY:DX]Jbe[:DX00RDY00<YBRe[:DX00RU:00<]JbU:;F/01RU:0bDY00DY
BRe[:DXYBRe[008aS0<]J`03:DX]Jbe[008YBP06;F/YBRDY9BTYBS6<0SF]
0S6<00<YBRDY:DX00be[00@YBRe[=JdaS0@]J`08:DX]Jbe[=Jd]JbU:;F/a
S08]J`8e[@@aS0@icP05<H`]Jc6<;F/aS002=Jd0236<;F/aS3W>?NlicSF]
>Lh3<H`00cF]>LhicP03>Lh00cg_>Lhe[@04<H`2=Jd2<H`01Re[=JdicT8@
?NlicP<e[@8icP8e[@8mk`03>LhaS36<00<e[@05<H`]Jc6<=Jdmk`03>Lh7
=Jd2;F/0236<>LhmkcW>=JdaS3F]<H`2=Jd01CW>=JdicSF]?Nl013F]00<i
cSg_>Lh00SW>0SF]00LaS2e[=JdicT8@?Nle[@03>Lh01Cg_>LhicSW>?Nl0
0cW>0Sg_00<icSF]=Jd013W>00@mkcW>>Lhmk`96<@04@Q0icSW>=Jd4<H`4
>Lh00cF]?NlicP02>Lh2?Nl2@Q0013g_>Lhe[Cg_0SW>00@mkd8@BU9:DP<m
k`04@Q1:DTicBU82@Q02>Lh013g_@Q12448@0THa0T8@00Dmkd8@AS5:DT8@
004]J`000`@Q00<000@Q12401@@Q00H8@QS6=JdU:AS67>L28@P01QcW8@PQ
21S67>LQ208U:@068@PHaQS67>LQ22DY0acW0b4800PU:B488@PU:B487>LQ
22DY0RU:00DU:B489BTU:C6<00<e[@8aS005;F/YBRU:8@PLi`026<H28@P0
0bU:;F/]J`02:DX29BT00b489BTQ20028@P01RDY:DX]JbU:9BTLi`8HaP03
7>LQ224800<HaP057>LU:BDY8@PLi`028@P00bDY8@PU:@039BT012487>LL
iacW0RDY00LQ21cW9BTYBRDY:DX]J`029BT28@P39BT28@P00acW8@PQ2002
8@P29BT38@P6:DX012DY:DXYBRDY0R4800<U:BU:9BT00RU:0SF]00<icTHa
CW<00V<H00=W>FmkKg/00W>L00a_Ng>LNmig_FmkG_M>LdYB>Lhe[B487>L5
36<2248010aS48@<H`Q20`aS00<8@P@Q12400P@Q00<8@P@Q12401P@Q00D8
@P@Q12448@0000X48@05248<H`aS24848@0224802`aS2488@P@Q5:DLiaBU
24848@Q236<010Q21P@Q00D8@P@Q12448@Q200L48@0524848@Q224848@05
248010aS2488@PQ20`@Q00<8@P@Q24800PQ20PaS00D8@PaS2488@PaS0088
@P031248@PQ200H48@88@P<<H`88@P0736<DYAS65:D@Q0aS48@00QcW00/Q
22U:;F/Q21S68@PYBRDY7>LDYAcW008Q20039BTYBRU:00<Q20<U:@058@PU
:BDY9BT]J`02:DX012DY:DXYBS6<0Re[00<YBRe[<H`01RU:0RDY0Re[00DY
BRDY9BTU:BU:008]J`8U:@04:DX]Jbe[;F/7:DX01bDY:DX]JbDY8@PU:BU:
008]J`03:DX]Jbe[00@]J`03:DX]JbU:00@YBP059BTYBRDY<H`e[@02<H`0
1be[:DXYBRU:;F/aS2U:008]J`07=JdaS2e[;F/aS2e[:DX01be[00dYBRe[
<H`e[C6<;F/YBRe[>Li243g_=JdYBP04;F/023F]>LhaS2e[<H`e[Cg_>Lh5
<H`00cF]>Lhe[@02=Jd01Cg_>LhicS6<=Jd00Re[1C6<00<]JcF]>Lh00Sg_
00<icSF]<H`00cW>0SF]0Sg_00<e[C6<<H`00SF]0c6<00<e[CW>>Lh00SW>
00<e[CW><H`00S6<0SF]00<aS2e[;F/00SF]00@icSg_=Jde[@<aS08e[@@i
cP@e[@04>LhmkcW>>Lh2<H`01cF]<H`YBSF]?Nm243g_008icP05?NlicSW>
=JdicP02?Nl3>Lh00cg_>LhicP02=Jd00cW>=JdicP04>Lh014Ha@Q12448@
0SW>0c6<00<YBS6<=Jd00SW>00<e[CW>>Lh013W>0T8@0Sg_0SW>00De[CW>
>Lhmkd8@0096<@92408mk`9:DP05AS5243g_=JdicP05?Nl024YBAS4mkcW>
?Nm6<DYB?Nl1<H`0000300048@0000<48@0<00048@@Q124000Q28@PaS248
6<HLibDY0R480acW124811cW00<HaR489BT00RDY00<Q21cW8@P00QcW0b48
00HLib48:DX]Jc6<9BT38@P5:DX01Be[<H`]Jbe[9BT00R4800DLib488@PY
BS6<008]J`03:DXQ2248008Li`048@PLiacW8@P2;F/01BU:9BTU:AS67>L0
0QS600<Lib488@P00R480acW00DQ21cW7>LQ22DY00@YBP038@PU:B48008Q
20047>LQ22DY9BT3:DX59BT28@P012DY8@PQ21cW0R480RDY00DYBR488@PQ
22DY008YBP8U:@@Q20049BTQ22488@P2:DX29BT4;F/022U:<H`mkdYBF]IF
]F<HJeX2Kg/02g>LKg]cW6mkLiag_FmkJeYS63W>;F/00QcW00HQ21BU48@@
Q1BU48@336<4248312400`0012448@0312400`0012448@0212400`Q21244
8@0912400`Q212448@0212401@Q212448@Q212400PQ200<<H`Q224800`Q2
00@48@Q22488@P848@88@Pl48@<8@P848@@8@PD<H`D8@P0336<8@PQ200D8
@P8<H`<8@P848@0324848@@Q00D48@07248<Ha2436<8@PaS48@011BU00HL
ibDY;F/aS2U:9BT28@P01bDY;F/]JbU:8@PHaQcW008Q20@U:@8Q208U:@04
:DXU:B489BT3:DX29BT00bU:;F/]J`029BT01bU:;F/aS36<;F/aS2e[008Y
BP059BT]Jbe[<H`YBP029BT012e[<H`]JbU:0RDY00P]Jc6<:DXYBS6<>Lhe
[Be[0RU:00<U:BU:9BT00bDY00<YBRe[:DX00RU:00<]Jc6<;F/00RU:0Re[
00LYBRDY8@PU:BU:<H`]J`03:DX6;F/2:DX01RDY:DX]JbU:;F/aS08e[@03
;F/YBRU:00D]J`DaS0<]J`8aS08e[@04>LhmkcF]<H`2;F/3=Jd3<H`01CF]
>LhicSW>=Jd00S6<00LicSF]>LhicSg_>Lhe[@03>Lh013F]<H`]Jc6<0SF]
00TaS2e[<H`e[D8@?Nm243g_<H`00cF]00HicS6<=JdicT8@>Lh4=Jd01c6<
=JdaS3F]<H`e[CW>008e[@DaS0<icP8aS005>Li2448@@Q0mk`06>Lh01Cg_
@Q1243g_@Q001CW>00Pmkd8@BU9:DT8@?Nle[Cg_0THa00=244Ha@Q000cg_
00=6<Cg_>Lh00SW>00Hmkd8@?Nm243W>=Jd2>Lh00cg_@Q124003?Nl01T8@
AS5243W>=JdaS08e[@<aS0<icP92408mk`8e[@Hmk`03@Q0icSg_008icP96
<@06@Q0mkcg_@Q16<DYB0cg_13W>0Sg_00A244HaBU96<@924096<@52404]
J`0010@Q00<000@Q12400P@Q00T000@Q248Q23F]9BT@Q1cW9BT00R4811cW
124800@LiaS66<HLi`8Q20039BTQ224800@Q200:7>LQ21cW7>LQ22U:<H`]
Jb487>L38@P29BT2:DX01Be[=JdaS2U:9BT00R4800@HaQcW8@PYBP8aS08Y
BP037>LQ2248008Q20087>LQ22DY:DX]JbU:9BTQ20@HaP8Q20@Li`048@PL
ib487>L38@P012U:;F/]Jbe[0bDY00<Lib487>L00R4800<U:BU::DX00RDY
00LQ22DY8@PQ22DY8@PU:@028@P27>L01R489BTYBRU:8@PLi`8Q2003:DX]
JbDY008U:@057>LQ22488@PU:@038@P00bDY:DXYBP03:DX032e[:DX]Jcg_
BU9F]E[FHaQ[FVmkLia_N`AcW00;MkecW6LiHaPicS6<7>LU:B486<H<H`03
48@336<00`Q212448@02248:12400`Q212448@0712401P0012448@@Q2484
8@88@P031248@PQ200<8@P0336<8@PQ200D8@P<48@@8@Q048@0424848@@Q
124224800`@Q2488@P02248436<324800`aS248<H`05248436<224821240
0`Q212448@0412400`Q21248@P0536<00a245:DDY@025:D01QcW8@PaS3F]
:DXU:@8Li`079BTaS2e[9BTQ21S67>L00R4800HU:BU:9BTQ22DY8@P49BT0
1R489BTYBRe[:DXU:@8YBP04;F/YBRDY9BT2;F/0136<;F/]Jc6<0RU:0RDY
0be[0RDY0RU:0S6<00<YBRDY:DX00be[00HYBRe[<H`e[Be[:DX39BT01BU:
9BTU:B48:DX00Re[0RU:00<]Jc6<:DX00RU:0S6<00DYBRDY9BTYBRe[008Y
BP069BTYBRe[<H`]Jc6<0be[00@YBRDY9BTYBP8aS0<]J`<aS003;F/YBRU:
008]J`03<H`]Jbe[00@aS08]J`8YBP8e[@8icP8aS08]J`8aS005=JdaS2e[
;F/aS002>Lh013F]<H`aS3F]0cW>00Xe[CW>>LhaS3W>@Q0icSF];F/YBP<a
S008;F/aS36<>Li244Ha?NlicP<e[@04>Lhe[CF]=Jd3>Lh013F]<H`icSF]
0c6<1SF]00<aS2e[<H`00S6<00@e[CW>>LhaS08e[@04@Q16<D8@?Nl2>Lh0
0cg_=Jde[@02?Nl00dHa@Q0mk`04>Lh013F]>Lhmkd8@0THa00PmkcW>>Lhm
kd8@AS5244Ha0cg_00A243g_?Nlmk`8icP8mk`9240@e[@8mk`03@Q0mkcW>
00A2408icP03=JdaS36<008]J`8e[@07?NlicSW>@Q0mkcW>=Jd00cW>0Sg_
00@icSg_?Nlmk`8icP04?Nm6<DYB@Q02>Lh00d8@BU924003?Nl2>Lh01CF]
>LhicSW>@Q000dHa0T8@00=6<D8@@Q000BU:00000`0012448@0212400`00
12448@0312401`Q27>LicR486<HLibDY00<Q20<Li`048@PU:BDY8@P57>L2
8@P01bDY8@PQ22DY7>LQ21cW008Q20037>LU:BDY008YBP8U:@<Q20099BTY
BRDY8@PYBRe[<H`]Jb48008U:@0=7>LQ22U:;F/icS6<;F/YBQcW5:DHaQcW
9BT00QcW00<Q22U::DX00RU:00XU:B488@PQ22DY:DX]JbDY:DXQ208Li`03
8@PU:BDY008Li`<U:@8YBP069BTYBRDY8@PLib480RDY00HQ22DY:DXYBRDY
8@P29BT012U:9BTYBRDY12480QcW0R4800<U:B488@P00RDY1R480acW0RDY
0b4800DU:BU::DX]JbU:00<U:@03;F/mkd8@009BU003G_MS66Li009[FP9_
N`=cW005JeYNme[F>LhaS0028@P01bU:;F/YBRDY7>L@Q1BU008<H`032484
8@@Q00L48@0324848@@Q00l48@0324848@@Q00L48@0524848@Q21248@P03
12400`Q212448@05248212400`Q212448@0412400`Q212448@0312400`Q2
36<8@P04248336<01QBU6<HDY@aS24848@<<H`88@P031248@PQ200<<H`88
@P031248@PQ200848@0324848@Q200D8@P0436<@Q1BU6<H25:D00aS67>LL
i`028@P2:DX2;F/012DY7>LLib480be[00DYBRDY9BTQ22DY008YBP039BTY
BRU:008]J`03:DXU:BU:008YBP04;F/YBRU:9BT2:DX4<H`2;F/013F]<H`]
JbU:0be[00<YBRe[;F/00Re[0S6<0RU:00<U:BU:<H`012e[00@YBRe[<H`]
J`8YBP089BT]Jbe[;F/U:BU:8@PU:@8YBP<]J`04:DX]Jbe[;F/2<H`2;F/2
:DX3;F/3:DX01C6<;F/YBRe[<H`00Re[0RDY0be[00<aS2U:;F/01Re[00@Y
BS6<;F/aS0@]J`03:DX]Jbe[008]J`05:DX]Jc6<>Lhe[@07<H`012e[<H`a
S2e[0S6<00@e[Cg_=Jde[@8aS005=JdicSW>=JdicP02=Jd013W>?NlicSF]
0S6<00@e[C6<<H`aS08icP8e[@8aS005;F/e[CF]>LhaS002=Jd3>Lh013F]
<H`aS2e[0S6<0SF]00D]Jc6<<H`aS3F]00@aS008>Lhe[CF]=JdicSg_>Lhm
k`<e[@06<H`icSF]<H`icSg_0T8@00LmkdHa>Lhe[Be[:DXaS002=Jd023g_
>Lhmkcg_>Lhe[CW>?Nl2@Q001Cg_>Lhe[C6<>Lh00Sg_00<icSF]=Jd01SW>
00Pe[CW>?Nlmkd8@>Lhe[CW>0Sg_00De[CW><H`aS3F]00<aS005>Lhmkd8@
@Q0mk`02>Lh013g_>LhicSF]0SW>0cg_0SF]00DmkdHaAS4mkcW>00=2408i
cP05?Nm2448@?Nle[@02>Lh00d8@?Nm24002AS401T8@?Nm2448@AS4mk`4]
J`0000@48@00124000848@0:00048@@Q124000Q28@Pe[BDY5:D28@P022DY
8@PLiacW6<HLib489BT28@P47>L<8@P00acW9BTYBP02;F/012DY7>LLiacW
12DY00<Q22U:;F/00Re[00`Q22DY8@PLib489BTaS3W><H`YBRDY7>L26<H4
7>L00bDY:DX]J`02:DX00bDY8@PQ20028@P012e[:DX]JbU:124800<U:B48
8@P00QcW0RDY0bU:00DU:B488@PU:AcW00<Q208YBP089BTQ22487>LYBRDY
:DXU:@<Q208U:@038@PLib4800@Q208U:@8Li`038@PU:BDY00<Li`038@PU
:BDY00<Q20<YBP8]J`<U:@08:DXmkcg_CW=F]E[FG_MW>@9[FP06Lia_NgNm
Kg]cW6mk0U[F00@icRe[9BTQ20<]J`069BTLiaBU48@<H`Q22P@Q00<8@P@Q
12402@@Q00<000@Q12400P@Q00H8@P@Q12448@Q212422483124224800`@Q
2488@P04124224800`@Q2488@P031242248512400`Q21248@P0312402@Q2
1248@P@Q248<H`Q236<8@P0236<011245:D@Q0aS0PQ200<<H`Q224801@Q2
00<<H`Q236<00`Q200H48@Q22488@P@Q2483124324800`aS48@DY@035:D0
0acW6<HLi`027>L01RU:;F/]JbU:8@PHaP8Q2003:DX]JbDY008YBP049BTQ
22489BT2:DX00bDY:DX]J`02:DX29BT4:DX29BT2:DX4<H`012e[<H`aS2e[
0bU:0Re[0bU:00<]Jc6<<H`00RU:00@]JbDY:DX]J`<aS0<YBP<]J`<U:@03
;F/YBRe[00<U:@8YBP@]J`03:DX]Jbe[008aS00;;F/YBRDY:DX]Jc6<;F/Y
BRDY:DX]J`02<H`2;F/3:DX29BT00bU:<H`]J`02:DX3<H`00be[:DX]J`02
;F/01C6<;F/]Jbe[:DX00Re[0RU:0Re[00<YBRe[<H`00SF]00DaS3F]<H`a
S2e[00@aS08]J`8aS004=JdaS3F]<H`3=Jd01c6<>LhicSW>=JdaS3F]00<i
cP06;F/aS3F]<H`]JcF]0SW>00<e[C6<=Jd00c6<00<icSF]=Jd00SF]0SW>
0SF]00TaS2e[:DXaS3F]>Lhe[C6<;F/0136<00<]Jc6<=Jd00c6<00@e[CW>
?NlicP8e[@06<H`e[CF]=JdaS3F]0SW>0T8@00@mkd8@=JdaS08]J`8aS003
>LhmkcW>008mk`04>LhaS3W>>Lh2@Q001CW>=Jde[CF]>Lh00Sg_00<icSF]
=Jd00SW>13F]0SW>0Sg_1cW>0SF]1C6<00De[Cg_@Q1243g_00@icP8mk`@i
cP04?NlicS6<?Nl2AS42?Nl01T8@AS4mkcF]>Lhmk`92408icP04<H`icSg_
?Nl2@Q0013g_@Q0mkcg_0T8@0Cg_0BU:000412400`0012448@0512401QcW
>LhYBQBU7>LU:@<Q20079BTLiaS67>LQ22U:8@P00RDY00@Q21cW7>LLi`8U
:@<Q20@U:@067>LQ22488@PU:BU:0RDY0b480bU:0RDY12U:0Re[00@YBRDY
9BTYBP<aS004:DXHaQcW7>L28@P37>L012e[<H`]Jc6<0be[00HYBRDY:DXa
S2e[:DX;8@P59BT00bU:9BTYBP049BT2:DX39BT00bU:;F/]J`02:DX012DY
:DXQ224811cW0bDY00HQ21cW7>LLib489BT28@P00aS67>LQ2002:DX01RDY
8@PU:BU:;F/YBP8U:@8Q20069BTYBRe[;F/aS3F]0THa00=>LeJeE[D00Ukg
00=S66LiHaP00Ukg00ES65kgE[EBU5[F009Nm`03BU8icRe[00<YBP038@PH
aQBU0088@P<48@0324848@@Q00@48@0524848@@Q1240000312401`Q21248
@P@Q24848@Q200<48@0324848@@Q00D48@0324848@Q200@48@0324848@Q2
00848@8<H`88@P071248@P@Q24848@Q212400PQ20`@Q0`Q200<<H`Q22480
0PQ200/<HaS67>LYBRe[6<H@Q0Q21248@PaS00<8@P<<H`88@P8<H`88@P<4
8@0>248<H`Q236<8@Q245:DHaQBU48@DYB489BTQ208]J`03:DXQ21cW00<Q
208Li`HQ20<U:@03:DX]Jbe[008YBP069BTYBRU:<H`]JbU:0be[00<YBR48
8@P00RU:136<0SF]00@icS6<;F/YBP8]J`03<H`]JbU:008YBP05;F/aS36<
;F/aS002:DX012e[:DXe[CF]0S6<00<YBRe[;F/00Re[00@YBRe[:DX]J`8Y
BP049BTYBRDY9BT2:DX3<H`00be[<H`aS002=Jd00cW><H`]J`02:DX00be[
:DXYBP02;F/0136<;F/YBRU:0Re[00@aS2e[9BTU:@8YBP05;F/YBRe[;F/Y
BP02;F/01C6<;F/YBRe[:DX01be[00<aS2e[<H`00bU:0be[00daS3F]>Lhm
kcW>=JdaS2U:;F/aS2e[<H`]J`03<H`5=Jd3<H`2=Jd2>Lh4<H`2=Jd013W>
<H`aS36<0SF]00DaS3F]<H`aS3F]008icP8e[@8icP03?Nle[CF]008e[@06
>LhaS3F]>Lhe[C6<0Re[0c6<00H]JcF]=JdaS3W>=Jd2>Lh3<H`2=Jd01C6<
;F/aS3F]@Q001Cg_00@e[Be[;F/]J`<icP8mk`<e[@@icP8mk`8icP04=Jdm
kcW>?Nl2=Jd0136<=JdicSW>0SF]0SW>0Sg_0d8@00@mkcW>=JdicP8e[@03
<H`e[CF]00@e[@04>LhmkcW>=Jd4>Lh00cF]>Lhmk`02>Lh4?Nl01SW>?Nm2
448@AS5:DP8mk`8e[@=2408mk`8icP03?NlicSW>00<icP05?NlicSg_@Q0m
k`01;F/000848@0300048@@Q00H48@06248Q23W>:DXDYAcW124800@LiaS6
7>LLi`<U:@<Q20<Li`039BTQ2248008Li`038@PU:BDY008Q20047>LQ22DY
:DX29BT38@P012DY:DXYBRU:0RDY12U:00<]JbU:9BT00RDY00DYBSF]=Jd]
JbDY008HaP038@PLiacW008Li`038@PYBRe[00<]J`8YBP8U:@<]J`06:DXQ
21cW9BTQ22DY0R480QcW0R4800@U:B488@PU:@8YBPHU:@03:DXU:BDY008U
:@04:DX]JbU:9BT28@P29BT27>L012487>LLib480RDY00@Q21cW7>LLi`@Q
208HaP049BTYBRe[9BT28@P01BU:9BTU:BDY:DX00b4800<U:Be[;F/00SF]
00DmkdHaDYABU5[F009Nm`9S60=Nm`0;IcUNme:DDYAJeV<HG_M:DS6<:DXU
:@02:DX00acW48@DY@02248212400`Q212448@0612400`Q212448@091240
0`Q212448@021242248412442486124324800`aS248<H`03248212402@Q2
12448@Q21248@P@Q24848@0424801PaS2488@PaS248Li`8U:@05:DXDY@aS
36<48@06248236<2248236<010Q212448@@Q10Q200<<H`Q248@00QBU00@@
Q1BU6<HQ208U:@04:DX]JbDY8@P27>L00b487>LLi`078@P29BT00bU:9BTU
:@03:DX012DY:DX]Jc6<0RU:12e[00DU:B489BT]JcF]008aS006;F/aS36<
=JdaS2e[0bU:0Re[00<YBRDY:DX00be[0S6<00H]JbU::DX]Jc6<=Jd2<H`2
:DX00be[:DX]J`02:DX29BT4:DX28@P2:DX00be[<H`aS002;F/01c6<=Jdi
cSF];F/YBRDY00<YBP03;F/YBRe[008]J`<YBP05<H`]JbDY9BTQ2002:DX2
;F/2:DX5;F/012U:9BTYBRe[0S6<0be[00@aS2e[;F/]J`8YBP06;F/aS36<
;F/aS3F]0Sg_00De[C6<;F/]Jc6<00@]J`@aS00@=JdaS3F]<H`e[C6<=Jdi
cSF]>Lhe[C6<=JdaS2e[<H`3=Jd2<H`00cF]<H`aS002;F/0136<=JdicSW>
0SF]13W>00<e[C6<=Jd013F]0S6<0Re[00<aS2U:;F/00S6<0cF]00<icSF]
=Jd00c6<0SF]0c6<00DicSg_>Lhmkd8@008icP@aS003=JdicSW>008mk`8i
cP03<H`e[CF]008icP04?NlicSW>=Jd2>Lh013g_>Lhe[C6<0SF]0SW>13F]
00<icT8@?Nl00T8@00<icSF]=Jd00SW>0c6<00<icSF]>Lh00SF]00<icSg_
>Lh00SF]00<icSg_>Lh00SF]13W>0cg_0SW>00E243g_@Q16<D8@008icP07
<H`mkd8@AS5243W>=Jd00SW>00<e[CW>>Lh013W>00<mkd8@?Nl00BU:0000
1P0012448@00124000@48@060008@QcW>Lh]JaS60acW00@Q22DY8@PHaP8L
i`038@PU:B48008U:@@Q20037>LQ22DY008Q20079BTYBRDY8@PHaQcW8@P0
0RDY00<YBR488@P01B4800@YBRe[<H`]J`8aS004;F/YBRDY9BT2<H`3;F/0
0bU:9BTLi`027>L022489BTQ22487>LU:Be[=Jd5;F/01bDY:DXe[CF]<H`Q
21cW00<Q208U:@048@PLiaS67>L28@P00bDY:DXU:@039BT00be[:DXU:@03
9BT00b48:DX]J`02<H`3:DX29BT00b489BTQ20037>L28@P012DY7>LLiacW
12480acW00<U:BU:;F/012DY0b4800DU:B488@PQ21cW008U:@8YBP8]J`03
>Lhmkd8@0096<@07@Q16<DHaAS5>Le:DCW<00U:D00]F]F<HKg][FUkgCW<a
S2U:7>LQ22DY008Q20037>LHaQS6008@Q00436<8@PQ212432484124010Q2
12448@000`@Q10Q200<48@Q212401P@Q0PQ200<48@Q212400`@Q00<8@P@Q
24800PQ200P<H`Q236<<H`Q21248@P@Q0PQ200@48@Q224848@88@P8<H`03
48@<H`Q20088@P8<H`046<HLiaS65:D2248010aS2488@PQ20PaS00<8@PaS
36<00Q2400<<Ha2436<00PaS00H8@PaS36<DYAS67>L28@P01AcW8@PU:BU:
9BT00R4800<U:BU::DX012480QcW0QS600@LibDY9BTU:@<Q20059BTYBRDY
:DXU:@02:DX01Be[<H`]Jbe[:DX00Re[0bU:00@]JbU::DXYBP<aS004;F/a
S36<<H`3;F/00bU:;F/YBP02:DX00bDY;F/aS002=Jd0136<:DX]Jbe[0S6<
00<]JbU:<H`00Re[00@YBRe[<H`]J`PYBP8]J`<YBPLaS004?NlicSF]<H`2
:DX3;F/2:DX01BDY:DXYBRU:<H`00be[00<U:BU::DX00RU:00H]Jc6<:DXY
BRe[<H`2;F/022U:<H`]JbU:;F/aS3F]<H`2;F/2<H`012e[:DX]Jc6<0Re[
0c6<00@e[C6<<H`aS08]J`04:DX]Jbe[:DX2;F/00c6<=JdicP02<H`2;F/2
=Jd00c6<=JdicP02>Lh3<H`00be[=Jde[@02>Lh00cF]<H`e[@02<H`01SF]
<H`icSg_>LhaS08e[@=2408icP0:<H`e[C6<<H`e[CW>?Nm243W><H`2;F/3
<H`3>Lh7=Jd01cW><H`aS3W>?Nm243g_008icP04?NlicSF]<H`2=Jd00cW>
=Jde[@03>Lh2=Jd00c6<=Jde[@02?Nl02CW>?Nlmkcg_>Lhe[CW>=JdicP04
<H`4=Jd2>Lh023g_@Q0mkdHa@Q0mkcW><H`4=Jd2<H`2=Jd013g_>Lhe[CF]
1CW>0Sg_00DicSg_>Lhmkd8@008mk`8icP03?Nm2448@00=24007AS5243W>
>Lhmkd8@?Nl00SF]00<icSg_?Nl00Sg_0T8@00<mkd8@>Lh00BU:00000`@Q
00048@0612401P001248@R48>LhYBP8HaP047>LQ22DY9BT27>L011S67>LQ
22DY0b480RDY00PQ21cW7>LQ22DY8@PLib480RDY00<Q21cW7>L00R480RDY
0b4800DHaR488@PU:BU:008]J`8aS006=Jd]JbDY9BTYBS6<0be[00<YBRDY
9BT00acW0RDY0b4800@YBRe[;F/]J`8YBP8]J`05:DX]JcF]<H`]J`038@P0
0acW8@PQ20038@P27>L28@P49BT3:DX59BT01B48:DXaS3F]<H`00bU:0RDY
00<Q22DY8@P00acW00<Q22DY8@P00QcW00@HaR488@PU:@@Li`069BTYBRU:
:DXQ22U:0RDY0QcW00DQ21cW8@PLib48008U:@05:DXU:BU:;F/icP02@Q00
0dHa@Q124002@Q000dHaCW=:DP02CW<01e:DF]IS66mkIcUNmdHa008YBP8Q
20049BTQ21cW8@P35:D248@00`aS2488@P02248412400`Q212448@041242
24800`@Q24848@0224800`@Q24848@04124010Q21248@PQ20P@Q00@8@P@Q
2488@P848@88@P8<H`H8@P<48@88@P041248@PQ2248336<2248236<011S6
7>LHaQBU10Q200<<H`Q224800PQ20PaS112400<<H`Q224800PaS0Q2400<L
ib488@P00acW0bDY00<Q21cW9BT00RU:00<U:AcW7>L00acW00@HaQcW7>LQ
20<U:@038@PU:BDY00@U:@03:DXU:Be[00@]J`8YBP069BTYBRU::DX]JbU:
0Re[0c6<00D]Jc6<;F/aS2e[008YBP049BTYBRU::DX4;F/00c6<;F/]J`03
;F/0136<;F/YBRU:1Be[00DYBRe[;F/]JbU:00<U:@03;F/YBRU:00<YBP03
;F/aS36<00<]J`05>Lhmkcg_<H`]J`02:DX00be[:DX]J`02;F/3:DX2;F/0
136<:DXYBRDY12U:00<]Jc6<;F/00bU:00<]JbU:;F/00Re[00@YBRe[<H`e
[@<]J`03=JdaS2e[00@]J`03<H`]Jc6<00@aS0<]J`05<H`]JbU:;F/YBP02
<H`01SF]>LhaS2e[:DX]J`8aS004=JdicSW>=Jd2<H`3=Jd02c6<=Jde[CF]
>LhaS3F];F/e[C6<=Jd013W>00@e[CW>?Nm240<icP05=JdaS36<<H`e[@02
>Lh013g_<H`aS36<0Re[0S6<00DicSF]>LhicSF]00<aS08e[@07<H`]Jc6<
>Li243g_=Jd00cW>00<e[C6<<H`00SF]00LmkcW>=Jde[CW>=JdicP03<H`0
0cF]?NlicP03?Nl2>Lh4=Jd7<H`013F]>LhmkcW>148@0SW>00<e[CW>>Lh0
0c6<00@e[C6<=Jde[@8icP8e[@03>LhmkcW>008e[@04?NlicSW>>Lh2?Nl0
1d8@>Lhe[C6<?Nm243g_00=2400;AS4mkcW>>Lhmkd8@?Nle[C6<>Li24002
?Nl00d8@?NlicP02?Nl1>Lh1:DX000848@0300048@0000L48@076<HicRU:
7>LQ21cW6<H00R4800<U:B488@P00QcW00<Q22DY8@P00QcW1B4800<U:B48
8@P00R480RDY0R4800<Lib489BT012480RDY0R4800<U:C6<<H`00Re[0c6<
00@]Jc6<<H`aS08]J`03<H`]JbDY008Q20039BTQ22DY008Q20049BTYBRU:
;F/4<H`2;F/3=Jd012e[9BTQ22480QcW0b4800<Lib488@P00b481BDY00<Y
BRDY8@P012DY00H]Jc6<?NlmkcF];F/29BT38@P37>L011S68@PQ22480QcW
00<Q22DY9BT00R480acW1RDY0b480QcW0R4800@U:B488@PU:@<YBP039BTY
BRe[008e[@03<H`YBRe[008]J`07<H`e[C6<;F/icSg_CW<00U:D00A>LdHa
=JdaS08U:@048@PU:BU::DX29BT27>L00b487>LHaP027>L011S65:D<H`Q2
0P@Q00@8@P@Q24848@88@P0448@<H`Q21244248712432482124324800`@Q
2488@P0236<00`Q236<<H`04248010aS2488@PQ20P@Q0`Q20`aS00<@Q0aS
24800Q240QBU0`aS0`Q20PaS0`Q200H@Q1BU6<HHaQBU6<H35:D011246<HQ
22DY0S6<0SW>00<e[C6<9BT00RDY0R480bDY0R480QcW0R4800@Lib48:DX]
J`DYBP8U:@8YBP06;F/YBRU:9BT]JbU:0bDY0RU:00<U:Be[:DX00S6<0Re[
12U:12DY12U:00DU:C6<>Lhe[Be[008YBP03<H`]Jbe[008]J`8YBP8U:@07
:DX]Jbe[:DXU:BU:<H`042e[1C6<00<]JbU::DX00be[0RDY00@YBRDY:DX]
J`8aS0<]J`<YBP039BTYBRe[008aS0H]J`<YBP@]J`0>:DX]Jbe[<H`]Jc6<
=JdaS2e[:DX]Jc6<=Jd]J`<YBP03;F/YBRDY00@YBP8]J`8aS00;;F/aS36<
<H`e[C6<;F/e[Cg_@Q0mk`03=Jd01C6<>Lhe[CW>=Jd013W>00<aS3F]=Jd0
0Sg_00LicSF]=JdicT8@>LhaS002=Jd013W>=Jd]Jbe[0SF]00=243g_>Lh0
0SF]00XaS3F]<H`aS3W>@Q0icSF]<H`e[@8icP@aS007>Lhmkcg_?NlicS6<
>Lh00cF]00TicSg_?NlicSF]>Lhe[CW>=Jd00S6<00<icSg_=Jd00SW>00I2
44Ha@Q0icSF]<H`4=Jd013W>=Jde[CF]0cW>00TmkcW>>Lhe[CW>@Q0mkd8@
?Nl013W>0SF]0S6<00<e[CW>>Lh01CW>00<mkd8@@Q000Sg_00<icSF]?Nl0
0T8@00HmkcW>>Lhe[Cg_@Q02AS43@Q03>Lh01Sg_>LhicSF]>Lhmk`8icP8m
k`04AS52448@=Jd1:DX0000300048@@Q00848@0300048@@Q00848@060008
@QcW>Lh]JaS60QcW00<HaQcW7>L00b480QcW00<U:B487>L00QcW0R4800DL
ib488@PU:B48008Li`088@PU:BDY8@PLiaS67>LU:@<Q20<U:@058@PU:BU:
:DXaS002;F/00c6<=JdaS003<H`2;F/0136<;F/YBRDY224800<YBRe[;F/0
0c6<0be[0S6<00H]Jc6<:DXQ21cW6<H38@P01AcW6<HLib489BT00b4800<U
:BU:9BT022DY00X]JcF]>LhicS6<;F/U:B489BTQ20<Li`046<HLib489BT2
8@P27>L38@P011cW8@PQ21cW12DY0R4800@U:AcW8@PLi`<Q20047>LQ22DY
9BT3:DX00bDY:DX]J`02=Jd01S6<;F/]Jbe[<H`e[@8aS008;F/e[Cg_CW=F
]DicBU8icP8aS0049BTQ22DY8@P2:DX00bDY8@PQ20047>L012487>LDYA24
10Q200D48@Q212448@Q2008<H`0324848@@Q00<8@P031248@P@Q00@48@88
@PD48@0324848@@Q0088@P0336<@Q0aS008<H`88@P0436<8@PQ224821243
248010@Q36<<H`aS0PQ20PaS00@@Q1BU48@@Q08<H`<8@P0336<8@PaS008<
H`<@Q0036<HDYAS6008HaP<@Q0056<HQ22DY<H`e[@02>Lh2<H`012U:9BTQ
21cW0R480RDY00@Q21cW7>LQ208Li`038@PU:BU:00<YBP039BTYBRDY00<U
:@HYBP06;F/U:B488@PYBRDY0bU:0S6<00@]JbU:9BTU:@8YBP<U:@8YBP04
9BTQ22U::DX2>Lh0136<;F/YBRU:1Be[2BU:00T]JbU:;F/]JbU:;F/YBRe[
:DX00Re[0c6<0Re[00<aS2e[;F/0136<00@YBRe[:DX]J`<YBP<U:@05:DX]
Jc6<<H`]J`03:DX39BT00bU:;F/aS003<H`5;F/3:DX2;F/2:DX00be[<H`a
S002;F/013F]<H`]Jbe[0c6<00<]JbU::DX022U:0Re[0c6<0Re[00HaS3F]
<H`]JcF]>Lh2?Nl00cF]>Lhe[@04=Jd6>Lh3=Jd2>Lh00c6<=JdicP02>Lh2
=Jd02CW>=Jde[C6<;F/aS3W>?NlicP02=Jd00cW><H`aS002<H`3>Lh00cF]
<H`aS002=Jd01SW><H`aS36<=JdicP8mk`<icP04=JdaS36<>Lh2?Nl2>Lh4
=Jd00be[=JdicP02>Lh01CF]?Nm2448@?Nl013F]0SW>00@e[C6<<H`e[@@i
cP04?NlicSW>>Lh2?Nl01D8@?NlmkcW>?Nl00cF]00@]JcF]<H`e[@8icP<e
[@06>Li2448@?Nm243g_0SW>00@e[Cg_@Q12408mk`8e[@8mk`96<@924007
?NlicSW>>LhmkcW>=Jd00SW>00DmkcW>?NlicSg_0092404mk`4e[@4YBP00
00<48@00124020@Q00L8@QcW>Lh]JacW8@PLi`088@P00acW8@PQ20027>L0
1B487>LLiacW8@P00RDY00HYBR487>LQ22DY:DX29BT00b489BTQ20049BT3
:DX4;F/01c6<=Jde[CF]<H`icSF]008aS004;F/aS2U:9BT28@P02AcW8@PL
iacW8@PLib489BT]J`04=Jd0136<=JdaS36<0RU:0RDY00DQ21cW7>LHaQcW
00<Q20<Li`<U:@038@PU:BDY00<YBP049BTYBRU:9BT2:DX01SF]>LhaS2e[
9BTQ20<U:@8Q208Li`038@PLib4800<Q200:7>LQ2248;F/YBRDY8@PLibDY
:DX59BT28@P39BT3:DX01b489BT]Jbe[9BTQ22U:008aS003;F/U:BDY008]
J`05:DXU:BDY:DX]J`03:DX01Be[:DXYBRDY8@P00acW00@Q22U::DXaS0<e
[@07;F/U:BDY:DX]JbU:8@P00QcW0QS600D@Q0aS48@<Ha2400D<H`04248<
H`aS36<2248010@Q2488@PQ20P@Q00D8@PaS36<8@P@Q0088@P061248@PaS
48@<H`Q20`aS0PQ200<<H`Q212401@Q20PaS0a240PaS0a2410aS00<@Q1BU
5:D00aBU0QS60aBU0acW00PQ21cW7>LLiaS69BT]Jc6<13W>0SF]0Re[00@U
:B487>LQ20@U:@09:DXU:B489BTYBRe[:DXU:BU:00<]J`8YBP039BTYBRU:
008]J`@YBP8U:@04:DX]Jbe[:DX29BT012U:;F/]JbU:0RDY00<YBRDY9BT0
0bDY0RU:00<U:Be[<H`00SF]1Be[00<YBRe[;F/00Re[0bU:0Re[0RU:00<]
JbU:;F/00Re[00@YBRe[:DXYBP8aS08e[@8]J`05:DXU:BU::DX]J`02:DX0
1Be[<H`aS2U:;F/00S6<00<]JbDY9BT00RU:00<]Jc6<<H`0136<00D]JbU:
9BTU:Be[008YBP<]J`04<H`]Jbe[;F/6:DX2;F/01bU:;F/]Jc6<>Lhe[C6<
008]J`<e[@<]J`PYBP8]J`@aS08]J`@aS003=JdicSW>008mk`8icP04=Jdi
cSW><H`2=Jd00cW>=Jde[@02<H`01CF]<H`e[C6<=Jd00SW>0S6<00<e[CW>
>Lh00c6<00<e[C6<>Lh00SW>00<mkcW>>Lh00cF]0cW>00DaS3F]=JdicSg_
00<e[@03<H`icT8@00924003>LhaS3F]008aS007=JdicSg_>Lhe[C6<>Lh0
0SF]00XaS3F]>LhicSF]<H`icSg_AS52408mk`03@Q0e[C6<008aS004>Lhe
[CW>=Jd3>Lh4?Nl4>Lh0148@?Nlmkcg_13W>00@e[CW>=Jde[@<icP0;?Nle
[Cg_@Q16<D8@?NlicT8@?NlicP02@Q001Sg_>Lhe[CF]>Li24096<@924004
?NlicSW>?Nl2>Lh013F]<H`e[C6<0SF]00<icSg_?Nl00T8@0Cg_0Be[0002
12401@00124000@Q00001@@Q00@LicW>;F/Li`8Q20047>LQ21cW7>L38@P6
7>L36<H38@P012DY8@PQ22480RDY00DYBRDY9BTQ21cW00DQ20<YBP<]J`04
:DXaS36<=Jd3<H`00cW>=JdaS002;F/29BT38@P57>L012489BT]JcF]0SW>
0S6<0SF]00<]JbU::DX00RDY11cW0b480acW1B4800<U:BU::DX01BDY0bU:
00L]Jc6<<H`YBRDY8@PU:@038@P01AcW8@PLiacW8@P011cW00HU:AcW8@PU
:Be[9BT27>L00b48:DXU:@028@P00bDY8@PU:@028@P00bDY:DXYBP039BT0
0bU:;F/YBP029BT01BU:;F/]JbU:9BT00be[00LYBR488@PU:Be[:DXU:@04
:DX28@P27>L01R487>LYBRU:<H`e[@8aS003;F/YBRU:008YBP039BTLiacW
008Li`046<H@Q12436<248@536<01PQ236<<H`aS24848@88@P031248@P@Q
0088@P848@88@P0336<8@P@Q0088@P0548@<H`aS36<@Q00236<524800`@Q
24848@02248236<348@636<00`Q236<@Q0025:D00a245:DDY@026<H25:D3
6<H04acW8@PQ21cW5:DHaR48;F/aS3W>=JdicSF]<H`e[Be[9BTQ21cW00<Q
208U:@05:DXU:BDY8@PU:@03:DX02bDY:DX]JbU:9BTYBRe[:DXU:BU:;F/0
0RU:00<U:Be[:DX00RDY00@YBRe[;F/YBP8Q208YBP8]J`039BTYBRDY008U
:@8Q20099BTYBRDY9BTYBS6<=JdaS2U:00<]J`8YBP8]J`03<H`]JbU:00DY
BP05;F/U:BU:;F/YBP03;F/012U:;F/]Jc6<0SF]00<aS2e[9BT00bDY12U:
00@]JbU::DX]J`8aS003;F/U:BDY008YBP03;F/aS2e[00<aS003;F/YBRe[
00<U:@@YBP8]J`03<H`]JbDY008YBP039BTYBRU:008YBP05;F/YBRU:;F/a
S002=Jd4<H`00cF]<H`]J`07:DX00bDY:DX]J`03;F/2<H`01Be[:DX]JcF]
;F/00c6<0SW>0Sg_0SW>00<e[CW>=Jd013F]00<icSF]=Jd00S6<00He[C6<
=JdaS3F]>Lh3<H`2>Lh4<H`3=Jd3>Lh2=Jd0136<=Jde[CF]0S6<00<e[CW>
>Lh00SW>00@aS3F]=Jdmk`92408icP<aS005;F/e[CW>?NlicP02=Jd00cW>
<H`e[@02<H`00cF]>LhicP02=Jd013g_@Q1243W>0Sg_00HicS6<;F/e[C6<
=Jd2>Lh023g_>LhicSg_>LhmkcW>=Jd3>Lh01Sg_@Q1243g_=JdicP@e[@Li
cP04@Q16<D8@?Nl4>Lh4?Nl01cW>=JdicT8@?Nm244Ha008mk`8icP03?Nli
cSW>008e[@03<H`e[CF]008aS006=JdicSg_?Nm6<Cg_0BU:00000`001244
8@0612402`001248@QcW@Q0e[B48:DXU:B487>L0124800@U:B487>LQ208L
i`038@PLiacW00<Li`8Q20039BTQ2248008U:@8]J`04:DX]JbDY9BT38@P0
0bDY8@PQ20039BT2:DX2<H`6=Jd3<H`2;F/00bU:9BTLi`026<H021cW8@PH
aR489BTaS3W>=Jd2<H`03Be[>Lh]JbU:8@PU:BU:9BTQ21S67>LHaQcW008U
:@@Li`DYBP039BTYBRDY00<YBP039BTQ2248008U:@03:DXQ224800<Q2003
9BTQ2248008Q20049BTQ22487>L28@P27>L29BT2<H`012U:9BTLib480RDY
00@Q22DY8@PU:@<Q20049BTYBRe[:DX59BT00bU:9BTYBP03:DX29BT01bU:
;F/U:B487>LQ22DY00<Li`8Q20039BTQ21cW00@HaP8Q2003:DXU:BDY008U
:@048@PU:BDY:DX2;F/02C6<=Jd]JbU:7>LHaQcW6<HLi`036<H011BU6<HD
YABU0a241PaS00<8@PaS36<00Q2400@<H`Q236<<H`8@Q0<<H`06248<H`aS
36<@Q0aS0`Q200<<Ha2436<00Q2400<DYA2448@00Q240aBU00<HaQBU5:D0
0QS600@U:BU:;F/YBP8Q20059BTQ21S66<HLi`028@P00bDY:DXU:@028@P0
11cW8@PQ22480bU:00<]JbDY9BT01BDY00@Q22U::DXYBP@]J`04:DX]JbU:
:DX29BT9:DX4;F/01RU:9BTYBRe[<H`]J`<YBP<U:@03:DX]JbDY008Q208U
:@@YBP03;F/YBRU:00<YBP@]J`<YBP03;F/aS36<008]J`07:DXU:BU::DX]
JbU:;F/00bU:0Re[00<YBS6<=Jd00SF]0Re[00@YBRDY:DXU:@8YBP<]J`06
:DXU:BU:;F/aS2e[0RDY0RU:00D]Jc6<=Jde[C6<008]J`04:DX]JbU::DX2
9BT01BU:;F/aS3F]<H`00be[00<YBRDY:DX00bU:1Be[0SF]136<00<e[C6<
<H`00be[00@YBRe[:DX]J`8U:@03:DX]JcF]008aS004=JdaS36<<H`2:DX0
22e[<H`e[CF]<H`e[C6<=Jd3<H`00be[<H`icP02>Lh01C6<;F/aS3F]>Lh0
0SF]0S6<00<icSF]<H`00S6<13W>00@aS3F]=JdaS0Te[@8icP04=JdaS3F]
>Lh2@Q04>Lh01cg_@Q1243g_>Lhe[C6<008e[@03>Lhe[CF]00De[@8aS0<e
[@05<H`e[CW>>Lhmk`02>Lh02Cg_@Q0icSW><H`]JcF]<H`icP02=Jd01cW>
?NlicSW>?Nm243W>00<e[@8mk`8icP05=Jdmkd8@@Q0mk`03=Jd3>Lh2?Nl0
1d8@AS56<DHa?Nm244Ha00<icP<mk`07>Lhe[C6<>LhmkcW>?Nl00SW>00@m
kcW>>LhicP8e[@04>Lhe[C6<<H`2=Jd3>Lh1@Q01>Lh1;F/000848@030004
8@0000H48@07248Lid8@;F/Q22U:9BT00R4800@Lib488@PU:@<Q20057>LQ
22487>LQ20057>L29BT38@P012U:;F/]JbU:0RDY0b4800<U:B488@P00R48
0RDY0RU:00<]JcF]=Jd013F]00@aS3F];F/YBP8]J`8U:@056<HDYAS66<HQ
20027>L00bDY;F/aS002<H`02Be[=JdaS2e[:DXQ22DY:DXU:@027>L02AS6
7>LLib489BTQ21cW6<HLi`03:DX00bDY8@PU:@02:DX29BT00bU:8@PLi`02
8@P00bU:9BTQ20038@P00bDY8@PLi`028@P29BT011cW8@PLiacW0R4800LU
:B48:DXaS2e[:DXQ20027>L49BT68@P00bDY:DXYBP049BT01RU:9BTU:BU:
;F/YBP<U:@03:DXU:B48008Q208Li`8Q20047>LQ21cW8@P37>L36<H02QcW
8@PU:BDY8@PU:BU:9BTQ22DY0bU:00D]Jc6<:DXU:AS6008Li`<HaP8Li`03
6<H@Q1BU008DY@0348@DYA2400<<H`0348@<H`aS008<H`8@Q08<H`08248<
Ha2448@<H`Q236<8@P@<H`0348@<H`aS0088@P8<H`<@Q0035:D@Q124008@
Q0035:DHaQBU008DY@047>LQ22DY;F/29BT01b489BTU:B487>LHaQcW008Q
208YBP<Q20097>LU:B488@PU:BU:;F/YBRDY008Q208U:@8Q208U:@@YBP8]
J`05:DXU:BDY8@PU:@0;:DX2;F/2:DX00bDY:DX]J`02;F/3:DX00bDY8@PU
:@049BT38@P012DY;F/]Jbe[0bDY00TYBRDY:DX]Jc6<;F/YBRDY:DX00Re[
00@aS2e[;F/]J`LYBP<]J`03:DX]JbU:008aS004=JdaS2U:;F/3:DX00bDY
:DXYBP04:DX01BDY:DXaS36<:DX00R4800<U:BU::DX013F]00<]JbU::DX0
12U:00HQ22U:;F/aS3F]<H`2;F/3:DX012DY:DXU:Be[0RU:0Re[00DaS2e[
=JdicS6<008]J`<aS08YBP<]J`8YBP8U:@8YBP03<H`e[C6<008aS08]J`03
:DX]Jbe[00DaS08e[@<aS003;F/e[CF]008icP03=JdaS36<008e[@HaS008
=JdaS3F]=JdmkcW>=JdaS0<e[@05<H`e[C6<=JdicP03<H`00cF]>Lhmk`02
=Jd2>Lh0148@?NlicSF]0cW>0Sg_00A243g_<H`]J`8aS003>Lhe[CF]008a
S003=JdicS6<008aS005=JdicS6<<H`e[@04>Lh3?Nl01CW>=JdaS3F]<H`0
0SF]00laS3F]>LhmkcF]>Lhmkd8@?NlicS6<=JdicSg_>Lh00SF]00DicT8@
@Q0icSF]008aS006>Lhmkcg_@Q0mkd8@0THa00=243g_@Q000Sg_0SW>0Sg_
00<icSF]=Jd00SF]23W>0SF]00<icSF]<H`00S6<0SF]0cW>0Cg_0CW>0BU:
00000`0012448@031240300012448@@Q0008@RDY?Nl]JaS68@PU:@<Q2004
9BTQ21cW7>L38@P87>L38@P29BT00bU:9BTYBP02:DX012e[:DXU:B480acW
00HU:AcW7>LLib48:DX4<H`00cW><H`]J`02;F/01c6<=Jd]Jbe[<H`YBRDY
00<HaP035:DLib4800<]J`03:DX]Jbe[008]J`05<H`YBR487>LQ20029BT0
1R487>LLiaS67>LU:@8YBP039BTQ22DY008YBP039BTYBRU:00<YBP039BTQ
2248008Li`8Q20059BTQ22487>LQ20039BT28@P01RDY:DXU:BDY8@PU:@8Q
208Li`8U:@8YBP039BTQ2248008Q20049BTYBRDY8@P37>L00b489BTU:@02
9BT012e[<H`]Jbe[0RDY00<YBRDY8@P00RDY00@YBRDY9BTQ20@U:@047>LH
aQS67>L48@P00acW6<HHaP067>L00b489BTU:@028@P27>L012DY8@PYBRU:
0RDY0RU:00<]JbU::DX00RDY0R4800LYBRe[9BTLiaBU6<HQ20047>L36<H2
7>L00b487>LHaP035:D76<H011BU7>LLib480QS60acW00@HaQcW8@PU:@8Y
BP049BTYBRU:8@P37>L02R487>LQ21cW:DX]Jc6<9BTQ21S61b4800TU:AcW
8@P]Jc6<;F/U:B489BT00RU:0bDY00XQ22U:9BTYBRe[<H`YBRDY:DX]J`8a
S08]J`8YBP049BTQ22DY9BT2:DX2;F/00bU:;F/]J`02<H`29BT2:DX00be[
:DXYBP02:DX29BT28@P29BT01BU:9BTQ22489BT01BU:00<]JbU:9BT00RDY
00<YBRDY:DX00c6<0be[0S6<0RU:0RDY0RU:0S6<00HicSF]<H`aS2e[:DX2
;F/3<H`012e[:DXYBRU:0Re[0bU:0Re[0bU:0be[0RDY0RU:00P]JbU::DXe
[CW>=JdaS2U:22e[00XaS3F]:DXYBRDY:DXaS2e[:DX]J`8YBP03;F/aS3W>
008e[@03;F/YBS6<008e[@07<H`]JbU:<H`]Jc6<;F/00RU:00LaS2U:9BTU
:BU:=JdaS002=Jd00c6<=JdaS003;F/3<H`00be[<H`aS003<H`3;F/00c6<
=JdaS006=Jd01C6<=Jde[CF]>Lh00Sg_00@icSF]<H`e[@8icP06=JdaS36<
<H`]Jc6<0SW>00<e[C6<<H`00cW>00He[CW>?NlmkcW>=Jd3?Nl2@Q001THa
@Q0icSW><H`]J`8aS003>Lhe[C6<008e[@8aS004=JdaS3F]<H`2;F/013W>
?NlmkcW>0SF]00`icSg_?NlmkcW>?NlicSF]<H`e[CW>@Q02>Lh2@Q0013g_
>LhaS3F]0SW>00=243g_>Lh00SW>00<mkdHa@Q000Sg_00E243F]=Jde[CW>
008mk`9240<mk`03>LhmkcW>00<icP03?Nm243g_00DicP03=JdicSW>00Di
cP03?Nle[CF]008aS004=JdicT8@@Q02?Nl1>Lh19BT000@48@0300048@@Q
00@48@05248Q23g_:DXHaP029BT012487>LLibDY0acW00<Q22DY7>L00QcW
00HQ21cW7>LLib487>L28@P01BDY8@PQ22489BT01BU:00DU:AcW8@PLib48
00@Li`038@P]Jbe[008e[@@aS08]J`03<H`]Jbe[008aS003:DXU:AS6008H
aP035:DLib4800DYBP05<H`]Jbe[<H`U:@038@P29BT01B487>LLiacW8@P0
0RU:00@U:B488@PU:@8YBP8U:@03:DXU:BDY008YBP069BTQ21cW6<HLib48
0RDY0b480bDY00<Q22DY9BT012DY0R4800@U:B489BTQ208YBP059BTQ2248
8@PLi`029BT2:DX012487>LLiacW0RDY00@Q22DY9BT]J`8aS005:DXQ22DY
;F/U:@028@P39BT38@P29BT01R486<HHaQcW6<HLi`8Q20059BTQ21cW7>LH
aP037>L031S67>LLibDY:DXU:AcW5:DLib489BTYBP8U:@038@PU:BU:00<Y
BP8U:@067>LQ22DY;F/U:AcW0QS60QcW00<HaR488@P00QS60QBU00@Q21cW
6<HHaP8DY@0=7>LHaQS66<HDYAS67>LHaQBU6<HQ22DY8@P00QS600PLiaS6
8@PLib489BTYBRe[0bU:00<Q21cW7>L00b4800LLib48:DXaS2e[:DXQ2002
7>L012487>LQ22480RDY0R4800HU:Be[<H`]JbDY7>L59BT012489BTYBRDY
0RU:0Re[0bU:00@]Jc6<;F/]J`<U:@038@PU:B4800@YBP8]J`04<H`]Jbe[
:DX29BT4:DX022DY:DXU:BU:8@PLib489BT2:DX28@P29BT7:DX39BT00bU:
;F/]J`05;F/2<H`012e[:DXU:BDY0RU:00HaS3F]=Jde[C6<:DX2;F/00bU:
;F/]J`02<H`00be[:DXYBP02;F/4:DX00c6<;F/]J`02:DX2;F/29BT00bU:
;F/YBP02:DX01Be[=Jde[CF]<H`00Re[0S6<00P]JbU::DXYBS6<=JdaS2U:
0RDY00<]Jc6<;F/00RU:00@]JbU:;F/aS08icP03<H`]Jbe[00<aS08]J`04
<H`]Jc6<;F/5:DX00bDY:DX]J`02<H`3=Jd2<H`2;F/3<H`2;F/01BU:<H`a
S36<;F/00RU:136<00<e[C6<<H`01SF]00<icSF]>Lh00Sg_00@icS6<=Jde
[@8icPDaS08icP<aS003>LhmkcF]00PicPE2408icP03;F/YBS6<00<e[@@a
S005=JdaS3F]<H`]J`02<H`01SF]>LhmkcW>=JdaS08icP03@Q0mkcW>00<e
[@03<H`e[CW>008mk`03>Lhmkd8@008icP0:<H`e[CF]>Lhmkd8@>Lhe[CW>
?Nl2AS4013g_>LhicSF]0cW>0cg_00A243g_?NlicP8mk`@icP04?NlicSW>
?Nl3=Jd00c6<>LhicP02>Lh2=Jd00cW>?NlicP02=Jd2<H`013W>?Nm2448@
0SW>0CF]0BDY00000`@Q00048@0212400`0012448@0312401PQ29BU242U:
5:DLi`8U:@088@PU:B488@PLib487>LQ208Li`038@PLiacW008Li`HU:@<Q
208U:@8]J`059BTQ21cW7>LQ20037>L00b489BTQ2002:DX2<H`00cF]<H`Y
BP049BT3;F/00bDY8@PQ20028@P011cW6<HLibDY0Re[0RDY0bU:00HU:B48
9BTYBRDY8@P27>L00bU:9BTU:@028@P012DY:DXYBRDY124800<U:B488@P0
1R4800@Lib487>LLi`8U:@04:DXU:BDY8@P49BT2:DX29BT00be[:DXU:@02
7>L68@P00bDY8@PQ20028@P29BT012486<HLiaS60b4800hYBS6<=JdaS2DY
;F/YBRDY8@PU:BU:8@PLib480RU:00@Q22DY9BTU:@8Li`038@PU:B4800@Q
20039BTQ224800@Li`058@PHaQS67>LQ20027>L28@P39BT00b487>LLi`02
7>L012DY:DXYBRU:0bDY00<YBRDY9BT012U:0bDY00<]JbU::DX00Re[0R48
0QS600<Q22DY8@P00R4800@U:BU::DXYBP8Q20049BT]JcW>=Jd2>Lh2<H`2
:DX2;F/01c6<?Nm2436<;F/Q22U:00<icP0:<H`YBRe[=Jd]JbU:8@PU:B48
9BT57>L38@P01RU:>LhicSF]:DXQ20<U:@05:DXU:BU::DX]J`03:DX2=Jd0
0c6<;F/]J`02;F/2<H`012e[:DXQ22480bDY1BU:0Re[00<YBRDY:DX01BU:
00<Q22DY9BT00RU:00<U:B489BT00RDY00<YBRDY:DX00bU:00@U:BU::DXY
BP8U:@8YBP039BTYBRe[008aS0<]J`05<H`]Jc6<;F/YBP02;F/2<H`01CF]
<H`icSW><H`012e[00<YBRe[;F/00c6<00D]JbU::DXYBRe[00<aS005;F/a
S2e[9BTYBP04;F/01RDY:DX]Jc6<=JdicP8e[@03;F/aS2e[00D]J`8aS003
=JdaS2U:008YBP05<H`]Jbe[<H`]J`02:DX3<H`3;F/0136<;F/]Jbe[0S6<
00Le[C6<;F/]JbU:9BTYBP029BT012U:;F/aS36<0SF]0c6<00<]Jc6<;F/0
0S6<0Re[0c6<0be[0c6<00Le[C6<<H`aS3F]>Lhe[@03<H`022e[=JdicT8@
AS5243g_>Lh2<H`01SF]>Lhe[C6<;F/aS0<e[@8icP03=JdaS3F]008icP<e
[@8mk`=240@mk`8icP<aS003=JdicSF]00@e[@06<H`icSW>=JdaS2e[0cF]
00@aS3F]>LhicPDe[@8icP<e[@03>LhmkcW>00@icP03=JdaS3F]008icP03
?Nm243g_008icP04@Q16<DHa@Q02?Nl3>Lh01Sg_>Lhe[CW>?Nm2408mk`@i
cP<mk`DicP06=JdaS3F]>Li243g_0cW>0Sg_13W>0SF]00DicSg_@Q1243W>
004YBP0000@000@Q124000D48@0900048@Q28@PmkbU:5:DLibDY00<Q2005
9BTLiacW7>LU:@028@P57>L38@P39BT38@P00acW9BTYBP02;F/022DY7>LL
iacW8@PLib486<H27>L01B48:DX]Jbe[<H`00be[0RDY00<Q22DY;F/00Re[
00TYBR487>LLib487>LHaQcW9BT00Re[0RDY0RU:00H]JbDY8@PQ22U:9BT2
7>L00b489BTYBP038@P49BT28@P00bDY8@PQ20048@P00bDY8@PQ20047>L3
8@P00bDY8@PQ20039BT01R489BTYBRDY8@PU:@8YBP049BTQ21cW7>L98@P0
0acW8@PU:@028@P00aS67>LQ20027>L01Be[<H`icS6<:DX00RDY0b4800<U
:B488@P00RDY00DYBRDY8@PU:B4800<Li`8Q20047>LQ22DY9BT38@P37>L0
1RDY7>LHaQS67>LQ20<Li`058@PU:BDY7>LQ20027>L01B487>LQ22DY:DX0
0RDY00@Q22DY:DXU:@<YBP03;F/YBRDY008U:@8YBP079BTYBRe[9BTLiaS6
7>L00R4800/U:B488@PYBS6<;F/U:AcW8@PYBRe[008mk`8icP8aS00=;F/U
:BU:;F/e[Cg_>LhaS2U:9BT]JcF]>Lh00S6<00<YBRe[<H`00Re[0R480RDY
00@Q21cW6<HHaP8Q20089BTQ22DY<H`mkcF]:DXQ20HU:@05;F/aS2U:9BT]
J`02<H`4;F/01bU:;F/aS2e[9BTQ21cW00<U:@@YBP<]J`8YBP059BTYBRU:
9BTYBP049BT01B489BTQ22DY8@P00bDY12U:00<U:BU:9BT00bU:0RDY00@Y
BRDY:DXYBP<]J`03:DX]Jbe[00@]J`04:DXaS36<=Jd2<H`2>Lh00cF]<H`Y
BP05;F/2<H`03be[:DX]JbU:;F/e[C6<=JdaS2U:;F/YBRe[:DXU:@03;F/3
:DX012e[>Lhe[CF]136<00@]JbU:;F/]J`@aS004:DX]JbU::DX5;F/01RU:
;F/]JcF]<H`]J`8YBP8aS004;F/YBRe[<H`2=Jd00be[:DXYBP02:DX29BT2
:DX4<H`013F]<H`]Jbe[0c6<0be[136<0be[00<aS3F]<H`00c6<0cF]00<a
S3F]<H`00S6<00DicT8@@Q1243W>008e[@03<H`e[CF]008aS005;F/aS3F]
<H`e[@02>Lh2<H`013F]>LhicSW>0SF]00<icSg_@Q000T8@00<icSg_>Lh0
0SW>0c6<00Pe[C6<=Jde[CW>=JdicS6<0SF]00<mkcF];F/00S6<00<icS6<
<H`01cF]0SW>0SF]00@aS3F]=Jde[@@icP8e[@8aS08icP03?Nm243W>008i
cP08@Q16<DHa?NlicSg_=JdicP8e[@8icP08?Nm243g_@Q0mkcF]>Lhe[@8m
k`04>Lhe[CW>>Lh2=Jd2>Lh2<H`013W>?NlmkcW>0SF]00@mkcW>>Lhmk`@e
[@8icP03?Nm243W>004YBP000P@Q00D000@Q12448@0000@48@06248Q248@
:DXDYAS60RDY00<YBRDY8@P00QcW00<HaQcW8@P00acW0R480QcW00<Q21cW
8@P00b4800<YBR487>L00R4800@]Jc6<9BTU:@8HaP048@PLib488@P27>L0
1BDY8@PLibDY:DX00Re[12480bDY1B480RDY0R4800<U:Be[9BT00bDY00PY
BRDY:DXU:BU:;F/YBRDY0QcW00DU:BU::DXYBRDY00<Q20049BTQ22487>L2
8@P00acW8@PLi`058@P27>L58@P00bDY:DXU:@039BT2:DX01BDY8@PQ21cW
8@P01AcW0R4800<U:B488@P00QcW12480acW00`Q22DY:DXQ22DY:DX]JbU:
9BTYBRDY7>L28@P03BDY8@PLiacW8@PU:B489BT]Jb487>LHaQcW008U:@<Q
20039BTQ224800@Q208HaPDLi`069BTQ22488@PLibDY0R480QcW00<HaQcW
7>L00acW00<YBRe[:DX00R4800@U:Be[:DXQ20<U:@06;F/YBRU:;F/aS2U:
0RDY00dYBS6<<H`YBR48:DXmkdHa@Q0aS1cW8@PaS002?Nl01RU:>LiBU5kg
E[DaS08YBP088@PYBRU::DXU:BU:9BTQ20HU:@8Q20037>LQ2248008U:@03
8@PU:AcW00<Q208YBP03;F/aS2U:008]J`<U:@<YBP079BTQ22U:<H`e[Cg_
>Lh00SF]0S6<00<]JbU:9BT00RU:00<U:B487>L00R481bU:136<0bU:12DY
0RU:00@U:BU:9BTQ208U:@04:DXU:BDY:DX2;F/2:DX02BDY:DXU:Be[<H`]
JbU:9BT]J`02<H`01BU:9BTU:Be[<H`00SF]00<aS3F]<H`0136<00<YBRe[
:DX00Re[0RU:0RDY00DYBRe[<H`]JbU:008U:@03;F/aS36<008]J`03<H`i
cS6<008U:@04:DX]Jbe[;F/2:DX2;F/3<H`013F]>Lhe[Be[0RU:00<U:Be[
;F/012e[00<YBRe[;F/00be[00<aS2e[<H`00Re[0S6<00He[Be[;F/YBRe[
<H`2;F/3<H`3;F/4:DX5;F/01C6<;F/]Jbe[<H`00SF]136<00@e[C6<=Jda
S0<]J`03<H`]Jc6<00@aS00?=JdaS2e[<H`]JbU:<H`icSg_@Q0mkcW>=Jda
S3F]00<aS007;F/e[CF]>Lhe[C6<>Lh00Sg_00@e[C6<<H`e[@8icP03=Jdi
cT8@0096<@03@Q0mkcg_008icP8e[@@aS08e[@05>LhmkcW><H`]J`02<H`2
=Jd01Re[<H`]Jc6<>Lhe[@<icP8e[@06?Nm243g_=JdaS3F]0Sg_00A244Ha
@Q0mk`8icP03@Q0mkcW>008icP=6<@06@Q16<DHaBU9243g_0SW>0SF]0cg_
00LicSF]=JdmkdHa@Q0mk`02=Jd01D8@?NlicSg_>Lh00Sg_00<icSg_=Jd0
0SF]00<icSg_?Nl00Sg_00M243W>>LhicSg_>Lhe[@02<H`2>Lh00cg_@Q0i
cP01;F/0000300048@@Q00848@0300048@@Q00<48@07248U:Cg_:DXDYAS6
8@P00bU:00<LiaS67>L01AcW00<Q21cW7>L00QcW1B4800<U:B488@P00b48
0Re[00<U:B487>L00acW00<Q21cW7>L00acW00<Q22U::DX00RU:00<U:B48
8@P00R480bDY00TLib487>LU:BU:9BTQ21cW9BT00RU:00<U:B489BT012DY
0RU:00@U:B487>LLi`8U:@03:DXU:B48008Q20049BTQ22487>L48@P01QcW
6<HQ22489BTQ20HLi`8Q208YBPHU:@8Q20037>LQ21cW008Li`066<HQ21cW
8@PU:B480acW124800DLib486<HLib48008U:@038@PU:BDY008YBP8U:@03
8@PLib48008U:@<Li`069BTYBR489BTYBR480aS600TU:B487>LLibDY8@PU
:B487>L00R480QcW00@HaQcW7>LHaP8Li`<Q20037>LQ224800@Li`<HaP8L
i`088@PYBRe[9BTQ21cW9BTYBP8U:@<YBP<U:@03:DX]Jbe[008U:@0=:DX]
Jc6<;F/LibU:>Li:DT8@;F/Lib48;F/00T8@00HYBSF]CW=S65:D<H`2:DX0
0bDY:DXU:@03:DX29BT28@P39BT28@P01acW8@PQ22489BTYBR4800<Li`8Q
20039BT]Jbe[008]J`039BTYBRDY00<U:@0;:DXU:BDY8@PU:Be[>LhmkcW>
=JdaS002;F/00bU:8@PU:@02:DX00bDY8@PLi`029BT4:DX00bDY:DX]J`04
;F/2:DX00bDY8@PYBP039BT2:DX01BDY8@PQ22489BT012U:0be[12DY0be[
0RDY00@]Jc6<<H`YBP8U:@04;F/aS3W>=Jd3;F/2<H`5;F/2:DX00be[:DXU
:@029BT00bU:;F/]J`03:DX3;F/01S6<;F/aS36<;F/YBP8U:@04;F/YBRe[
9BT2:DX4<H`01CF]<H`e[C6<;F/00RU:00H]JbU:;F/]JbU:;F/3:DX022e[
:DX]Jbe[<H`]JbU:;F/4<H`01BU:;F/]Jbe[:DX00Re[00DaS2e[;F/]JbU:
008U:@05:DX]Jbe[9BTYBP02<H`00be[:DXYBP02<H`01CF]<H`]Jbe[<H`0
0cF]00@aS2e[:DX]J`8aS0<]J`<e[@0<;F/aS36<;F/aS2e[<H`e[CW>@Q0m
kcW>0SF]0c6<0Re[00Te[CW>>Lhe[C6<>Li243W>=Jd00S6<00He[C6<>Lhe
[Cg_@Q02AS42?Nl3>Lh7<H`2=Jd00cW>=JdaS002<H`00cF]>LhaS003;F/0
0c6<=JdicP02>Lh01cF]<H`aS3g_@Q0mkcF]008aS08mk`03@Q16<D8@00<i
cP06@Q0icSF]>LhmkdHa0T8@00<mkd8@BU800THa00<icS6<=Jd00SF]1CW>
00De[CW>@Q1243W>008e[@03>Lhmkcg_00DicP05?Nle[C6<=JdicP03?Nl0
0cW>?NlicP03>Lh2=Jd2<H`01CW>?Nlmkd8@>Lh00Be[00001@@Q00048@@Q
00001@@Q00L000Q28@PicRe[5:DLi`028@P00bU:9BTQ20028@P01AS67>LL
ib487>L00b4800HU:AcW8@PQ22DY:DX39BT00b487>LQ20028@P39BT00b48
7>LLi`048@P03AcW8@PQ21cW9BTYBRe[=JdYBR487>LDYB4800@Li`05:DX]
Jc6<:DXQ20029BT28@P012U:;F/]JbDY0RU:00@aS2e[;F/YBP<U:@<Li`08
8@P]JbU:9BTQ21S67>LQ208Li`@Q208Li`<Q208Li`036<HLiacW008Q208U
:@04:DXU:BU:8@P29BT00b489BTU:@029BT00b487>LLi`027>L38@P00bDY
8@PQ20027>L28@P29BT01b489BTU:B489BTQ22U:00<U:@8YBP@U:@048@PU
:B489BT38@P29BT022U:9BTLiacW8@PYBRDY8@P27>L28@P012DY8@PQ2248
0RDY00@Q21cW7>LHaPHQ20057>LQ22DY8@PLi`026<H00acW6<HLi`027>L0
12489BTYBRDY0R480RDY00HYBRDY8@PU:B487>L38@P59BT02R487>LLib48
9BTYBRDY8@PLib480RDY00<YBRDY:DX00Re[00<aS2488@P00R480RDY0QcW
00<HaQcW7>L00bU:00LU:B488@PQ22DY8@PU:@038@P29BT48@P4:DX2;F/2
:DX01BDY:DXYBRU:;F/00RDY00@YBS6<>LhicP<aS08]J`049BTYBRU::DX5
9BT00bU:9BTYBP02:DX00bDY:DX]J`02;F/012U:9BTYBRDY0RU:00<U:BU:
;F/00bU:0bDY0b4800@U:BU::DXYBP8aS009;F/YBRDY:DXaS2e[:DX]JbU:
008]J`<YBP@]J`<aS005;F/YBRU::DXaS003:DX2;F/3:DX29BT::DX022e[
=JdicS6<;F/U:BU:<H`3:DX022e[:DXYBRe[<H`]JbU:;F/2=Jd00c6<;F/]
J`04:DX00be[:DXU:@02:DX2<H`012U:;F/YBRU:0be[0SF]00<aS2e[:DX0
0c6<0be[00@aS2e[;F/]J`8YBP8]J`8YBP04;F/aS3W>=Jd5<H`013F]<H`a
S36<0SW>0T8@00DicSF];F/]JcF]008]J`8aS003>Lhe[CF]00@aS08]J`07
<H`icS6<<H`e[CW>=Jd00c6<00<e[C6<=Jd00Sg_00HicSF]>LhicSg_>Lh3
<H`033F]<H`aS3F]?Nm:DTicAS4mkcW><H`e[@<aS003=JdicSF]008aS005
=JdicSg_>Lhe[@03<H`01cW>=Jd]JbU:;F/aS3F]00<icP05=JdicSW>?Nm2
4006>Lh2?Nl01cF]<H`icT8@AS4mkcW>00<mk`03@Q1:DT8@00<mk`07@Q0i
cSF]=JdicSg_=Jd00Sg_00HicSF]=JdicSg_>Lh2=Jd2>Lh013g_@Q0mkcg_
0SW>00@e[Cg_?Nlmk`<icP9240@icP04?NlicSW>=Jd2<H`013F]>Li243F]
0Be[000212401@0012448@@Q00001@@Q00DLicW>:DXHaQcW00@Q20039BTQ
21cW00<Li`086<HQ21cW8@PU:AcW8@PLi`8Q20049BTQ22DY9BT27>L28@P2
9BT38@P00acW8@PQ20028@P47>L02B48:DX]Jbe[<H`YBR486<HLi`038@P0
11S67>LU:BU:0Re[00LQ22DY9BTLib489BT]J`03:DX3;F/49BT02B486<HL
iacW9BT]JbU:9BTQ20057>L28@P37>L38@P27>L00aS68@PLi`027>L01R48
9BTU:BU:9BTQ20@U:@038@PU:B48008Q20037>LQ21cW008Li`048@PU:B48
9BT28@P00acW8@PQ20028@P00acW8@PQ20028@P69BT012489BTQ22480RDY
0b4800HLib489BTQ22U:9BT28@P00acW8@PQ20028@P27>L28@P29BT28@P2
9BT27>L00aS67>LLi`028@P29BT01B487>LQ22DY8@P00QS600<Lib487>L0
0QS600@LibDY;F/YBP<Li`8YBP049BTQ22488@P39BT01QcW8@PU:B48:DXU
:@<Q208Li`8U:@09:DXQ22487>LQ22DY:DXU:BU:008]J`06:DXU:B488@PL
ib4811cW12480bDY00<Lib487>L00RDY00<Q22DY9BT00RDY00@Q21cW7>LQ
20XYBP06<H`YBRDY8@PU:Be[0SF]00HicS6<<H`aS2e[9BT4:DX012DY8@PQ
22480bDY0RU:0RDY0RU:00<]JbU:9BT022U:00@]JbU:9BTU:@8Q208U:@8Q
208YBP8]J`04<H`]Jbe[9BT2:DX2;F/2:DX012e[<H`]Jbe[0bU:00D]Jc6<
<H`]Jc6<00TYBP06;F/YBRU::DXU:BU:0RDY12U:00D]JbDY9BT]JbU:008e
[@8]J`8YBP8]J`03:DX]JbU:008YBPD]J`8aS003=Jd]JbU:00LYBP039BTY
BRU:008]J`<YBP03<H`]Jbe[008e[@04<H`]Jbe[<H`2;F/012U:;F/aS36<
0be[1RU:00<aS3F]=Jd00S6<00@]Jc6<<H`e[@@aS006=JdicSg_AS4icS6<
0Re[00@aS2e[;F/aS08e[@04>LhaS36<;F/2<H`01BU:;F/aS3W>=Jd00S6<
00Le[CW><H`]Jc6<=JdaS002>Lh013g_=JdaS3F]0SW>00@e[C6<<H`aS08e
[@0:;F/icSg_BU9>Ld8@?Nle[C6<=Jd4<H`2=Jd00c6<=JdicP02>Lh01CF]
<H`aS36<=Jd00c6<0be[00@e[CW>>Lhe[@8icP05?Nm243W>>Lhe[@05>Lh0
13F]<H`e[Cg_0T8@0cg_0T8@0dHa00LmkcW>?Nm243F]<H`e[@04>Lh02Sg_
>Lhe[C6<=JdmkcW>=JdaS3F]0cW>00<mkcW>>Lh00SW>0cg_0cW>13g_1CW>
0c6<00@e[Cg_?Nlmk`4YBP0000@000@Q124000D48@0900048@Q26<HicRU:
7>LU:B48008Li`8Q20037>LHaQcW008Li`@Q20037>LU:B4800@Q2003:DXQ
2248008U:@078@PLib488@PU:BU:8@P00QcW00<Q22DY8@P00b480RDY0RU:
00/]Jc6<:DXQ21cW6<HLib489BTYBRDY008YBP09;F/aS36<<H`]JbU:9BTQ
22DY008YBP05<H`]Jbe[;F/aS002;F/00cF]<H`U:@026<H012489BTU:B48
0acW0b481QcW00DQ21cW9BTU:B4800<Li`038@PLibDY00<U:@03:DXU:BDY
00<U:@<Q20047>LQ22487>L28@P39BT38@P00bDY7>LLi`028@P3:DX39BT2
:DX00b489BTU:@02;F/00bU:9BTLi`038@P01RDY8@PQ21cW8@PU:@8YBP04
9BTQ22488@P39BT01B487>LQ22489BT00R4800PLib489BTU:B487>LQ21cW
0R4800<U:B488@P011cW00@HaQcW7>LLi`8HaP088@PU:BDY8@PLiaS67>LQ
20<U:@<Q20037>LQ2248008Q20059BTQ22488@PLi`028@P00bDY8@PQ2002
8@P021cW8@PQ2248:DXU:B489BT58@P01BDY8@PQ22486<H00QcW00DQ22U:
:DXYBRDY008Li`078@PU:BU::DXU:B489BT00RU:00@U:B488@PU:@HYBP<U
:@04;F/aS2e[9BT28@P2:DX3;F/2<H`2:DX29BT012e[:DX]JbU:0RDY00@Y
BRDY9BTYBP8]J`04:DXU:BDY9BT6:DX29BT012U:;F/YBRe[0bU:0bDY00DY
BR489BTU:Be[008aS0<]J`05:DX]Jbe[<H`]J`07:DX5;F/2<H`00be[9BTU
:@03;F/3:DX2;F/2:DX012489BTYBRe[0bU:0Re[00@YBRDY:DXYBP8]J`04
:DX]JbU:<H`3;F/00c6<:DXYBP02:DX2<H`4>Lh2<H`00be[9BTU:@02:DX2
;F/4:DX00c6<;F/]J`02<H`3;F/2<H`2;F/00c6<=Jde[@03<H`00be[<H`a
S003;F/4:DX01SF]>LhicSW><H`]J`8aS00<=JdicSW><H`]JcF]>Li:DTHa
?NlicS6<0be[00DaS3F]=Jde[C6<00@icP05=JdaS36<;F/e[@03<H`00cF]
<H`e[@02<H`2>Lh00cF]>Lhe[@02>Lh2=Jd0136<=JdaS2e[0S6<0SF]0cW>
00=243W><H`00Re[1C6<1CW>0T8@00<mkcF]<H`01S6<00@e[CW>=Jde[@Di
cP<e[@@aS003>Lhmkcg_00<e[@9240PicP<mk`<icP04<H`e[CF]<H`3>Lh0
13F]<H`e[CF]0S6<00T]JcF]>LhicT8@AS5243W>=Jd01SW>0cg_00A243g_
?Nlmk`@icP06=JdmkcW>>Li243W>0BU:000412400`0012448@0412401@Q2
8@PicRU:6<H00b4811cW00<Q21cW7>L00b480QcW00<Q22DY8@P01B4800@U
:B488@PQ20<Li`038@PYBRDY00<Q20047>LU:BDY9BT28@P29BT02Re[:DXY
BRe[:DXU:AcW6<HLib480RDY00@Q22DY:DXaS08e[@05<H`YBRU::DXQ2003
9BT2;F/2<H`3;F/00cF]:DXQ20026<H01b489BTU:B487>LHaQcW00<Q20LL
i`DQ20047>LHaQcW8@P29BT3:DX00b489BTU:@028@P00bDY8@PQ20047>L3
8@P29BT88@P01BDY:DXU:BDY8@P00bDY00DQ22DY:DX]JbU:00<U:@037>LQ
224800HQ20@U:@048@PU:BDY9BT37>L00b489BTQ20037>L29BT01B487>LL
iacW8@P00RDY0R4800<Lib488@P00QcW0aS611cW00@Q22DY8@PQ208HaP05
8@PU:BDY8@PHaP038@P27>L01B489BTLib489BT00R480QcW00@Q22DY9BTQ
20<Li`<U:@@Q20047>LQ22489BT28@P67>L022DY:DXU:BDY7>LHaR489BT2
:DX38@P01RDY:DXU:B487>LU:@8YBP039BTYBRDY008U:@8YBP8aS004:DXU
:B487>L2:DX01Be[<H`aS36<;F/00RU:0RDY00LYBRe[:DXU:B489BTYBP02
9BT02BU:;F/YBRU:8@PU:BU:9BT]J`04:DX01BDY:DXYBRDY;F/00RU:0RDY
00<YBRDY9BT00R4800@U:BU::DXaS08]J`8YBP03;F/aS36<008]J`DYBP<]
J`05:DX]JbU:;F/aS002;F/01bU:9BTYBRU:;F/YBRDY008YBP8]J`<U:@<Y
BP039BTYBRe[008YBP039BTYBRU:00<]J`04:DX]Jbe[:DX2;F/0236<;F/U
:BDY:DXaS2e[=Jd2?Nl01CW>;F/YBRU:8@P02RU:0be[00@aS2e[;F/]J`8a
S007:DX]Jc6<=Jd]Jc6<=Jd00S6<1Be[0RDY0RU:0cW>00<e[C6<;F/00S6<
00de[CW>>Lhe[C6<>LhmkdHaBU8mkcW>;F/YBP02;F/3<H`01SF]<H`e[CW>
?NlicP8aS006;F/aS36<=JdaS3F]0c6<00He[C6<<H`icSg_>Lh2=Jd01CW>
=Jde[Be[<H`00Re[0S6<0cF]00@icSg_?NlicP8aS003;F/e[C6<00<aS003
>Lhe[Cg_008mk`04@Q0mkcW>=Jd2;F/2<H`01SF]<H`aS3F]>LhaS08e[@03
?NlicSW>00<e[@05>LhaS2e[;F/aS003>Lh02SF]<H`icSg_@Q0mkcF]<H`e
[CW>0Sg_0SW>00DmkcW>>Lhe[CW>00@e[@8icP09=JdaS3F]=JdicS6<;F/a
S3F]008icP05?Nm6<D8@>Lhe[@02>Lh01Cg_>LhicSF]>Lh00Sg_0SW>0Sg_
00<icSF]=Jd00SW>00<e[CW>>Lh00SW>0BU:00000`001240000312400`00
12448@0312401QcW>LhU:AcW8@PU:@<Li`8Q20047>LHaQcW7>L38@P27>L0
0b489BTQ20028@P00acW8@PQ20028@P01RDY8@PQ22DY8@PU:@8YBP078@PU
:B489BTYBRe[:DX00RDY00HYBRe[:DXU:BU:9BT28@P01QcW8@PLiacW:DX]
J`DaS005>LhaS2e[9BTQ20029BT00bU:<H`]J`03=Jd01be[<H`icSF]:DXL
iaS6008Li`038@PLiacW008Li`<Q20<Li`<Q208Li`8U:@03;F/YBRDY008Q
20047>LQ22DY:DX29BT4:DX012487>LLiacW0R4800@U:BU::DXU:@8Q208U
:@8Q208U:@048@PU:BU::DX29BT00b489BTU:@049BT00b489BTYBP029BT2
7>L28@P29BT27>L022489BTU:B489BTQ22DY8@P29BT012489BTLiacW0R48
00@U:B489BTU:@8YBP<U:@8Li`8Q20039BTQ21cW00<Li`048@PLiaS66<H2
7>L01aS67>LLibDY8@PLiaS6008Li`8Q20049BTQ22488@P29BT28@P29BT2
8@P022DY8@PQ22489BTYBRDY8@P39BT27>L01R489BTU:B489BTQ208U:@DQ
20047>LQ22DY:DX29BT011cW8@PQ22DY0RU:1bDY0RU:00<Q22DY9BT012U:
0Re[00DaS2U:;F/U:BU:008U:@8Q20059BTYBRe[<H`YBP049BT00be[:DXY
BP02:DX2;F/29BT01248;F/YBRDY12U:00DQ22DY:DXYBRe[00<U:@8YBP8U
:@<YBP<U:@058@PU:BDY:DXU:@02:DX01Be[:DXYBRe[:DX00S6<00D]JbU:
9BTYBS6<008]J`8YBPD]J`TYBP05;F/YBRU:9BTYBP04;F/5:DX29BT2:DX2
;F/4:DX01Be[:DX]Jbe[<H`00be[00<aS3g_?Nl00T8@00<icS6<;F/00bU:
00D]JbU::DXYBRDY008YBP0;;F/YBS6<>LhmkcW><H`YBRe[:DX]J`02:DX0
0be[<H`e[@03<H`01Re[:DX]Jbe[=Jd]J`8YBP<aS003;F/aS36<008aS004
=JdicSg_?Nl2<H`01Re[<H`mkd8@>Lhe[@8]J`03<H`]Jc6<008aS08]J`05
<H`e[CW>=JdaS002=Jd2<H`012e[<H`aS36<0SF]00<aS3F]<H`00S6<00D]
Jc6<<H`icSF]00<aS00:=JdaS36<;F/aS2e[=JdaS3F]<H`3=Jd2<H`4;F/0
2CF]>Li243g_@Q1>LdYBAS4icP05<H`00cF]>Lhe[@03>Lh2?Nl01SW>=Jda
S3F]>Lhe[@HicP04=JdaS36<<H`4=Jd3>Lh01CF]>LhicSg_>Lh00cF]0SW>
0cF]0cW>00@e[C6<>LhicP8aS003:DXaS3W>008icP04<H`e[CW>?Nl5>Lh0
13g_=JdicSW>0Sg_1CW>00Le[CW>>Lhmkd8@?NlicP01:DX000D48@030004
8@@Q00848@080008@QcW=JdU:AS68@PU:@<Li`048@PHaQcW7>L38@P00acW
6<HLi`028@P01BDY8@PLib487>L01R4800<Lib488@P00RU:0bDY0R4800@Y
BRe[:DXQ208U:@06<H`]JbU::DXU:B480QcW00DQ21cW8@PU:BU:008aS007
=JdaS3F]=JdaS2e[9BT00R4800<U:BU:;F/00Re[00Te[C6<<H`]JcF]<H`Y
BQcW6<H00QcW00@Q21cW6<HLi`<Q20HLi`038@PLib48008U:@04:DXU:B48
9BT38@P49BT28@P2:DX01bDY8@PHaQcW8@PLib48008YBP038@PLiacW008U
:@8Q20@U:@8YBP8Q20049BTYBRU:9BT28@P012DY8@PU:BU:0RDY00DQ21cW
8@PQ22DY00<Q208U:@<Q20049BTQ22DY9BT38@P00acW8@PQ20029BT28@P0
2BDY:DXYBRDY8@PU:AcW8@PLi`038@P00acW8@PLi`027>L01AS67>LLib48
7>L00aS611cW00<HaQcW7>L01B4800DU:B488@PQ22DY008Q20047>LQ22DY
8@P29BT00bU:9BTQ20028@P01acW8@PQ22489BTQ22DY00<Q208U:@<Q208L
i`8Q20039BTYBR4800<Li`089BTYBRU::DXU:B489BTYBPDU:@05:DXU:BDY
:DX]J`02:DX3;F/012U:9BTU:BDY0b4800DU:BU:;F/aS2e[008U:@038@PU
:BU:008YBP8U:@03:DX]JbDY00<U:@05:DXU:BDY;F/YBP039BT3:DX29BT0
0b48:DXU:@039BT3:DX00bDY8@PQ20029BT2:DX29BT012U:;F/YBRU:0Re[
00DaS2e[:DXQ22U:008]J`03:DXU:BU:00<]J`@YBP039BTYBRU:008YBP03
;F/YBRU:008U:@03:DX]Jbe[008]J`@YBP039BTYBRDY008U:@03:DX]JbU:
00HYBP<]J`05:DX]Jc6<<H`icP03@Q02<H`00be[:DXYBP02:DX2;F/2:DX0
1BDY:DXYBRe[<H`00cW>00LaS2U::DXYBRDY:DX]J`04<H`00be[<H`aS002
:DX012e[<H`aS2U:0Re[00<e[C6<;F/00S6<00<]Jc6<=Jd00SW>00<e[C6<
;F/00SF]0T8@0SF]00@]JbU:<H`]J`DaS003=JdaS3F]00@e[@<aS003=Jda
S36<008aS0<e[@8aS003;F/aS3F]008e[@03<H`]Jbe[00<aS003;F/YBS6<
00Le[@8aS007;F/aS2e[:DXaS3F]?Nl00T8@00A:DTHa@Q0e[@<aS007;F/e
[CF]=JdicSF]<H`00SW>00I243W>=Jd]Jc6<=Jd2>Lh2=Jd2>Lh01Cg_<H`]
Jc6<;F/00cF]00<icSF]>Lh00cW>00Le[CW>>Lhe[C6<=JdicP02=Jd2<H`2
=Jd02SW>=JdaS3W>=JdaS2e[:DXaS3F]0SW>0SF]0cW>00De[CW>?NlicSF]
00HicP@e[@8icP@mk`4icP4U:@0000@000@Q124000D48@0900048@Q27>Li
cRU:6<HLib4800LLi`036<HLib48008U:@038@PLiacW00<Q20047>LQ2248
7>L38@P00bDY:DXQ20038@P2;F/00bU:;F/]J`04:DX2;F/00bDY:DXQ2002
8@P011cW8@PLib480RDY00<YBRe[<H`00cF]00@aS3W><H`YBP8U:@8aS005
;F/aS36<>LhaS003;F/4:DX28@P27>L00b489BTQ20038@P59BT38@P01RDY
:DXYBRDY:DXU:@<Q208Li`DU:@048@PU:B489BT28@P37>L28@P29BT00b48
9BTYBP03:DX39BT2;F/00bDY8@PQ20049BT28@P49BT28@P011cW8@PQ2248
12DY00<Q22DY:DX00bU:0R480RDY12480bDY00LYBRe[;F/]JbU:9BTQ2002
7>L00b489BTU:@028@P012DY8@PQ21cW124800HLib487>LLib489BT28@P2
6<H28@P00bU:9BTQ20039BT01AcW9BTYBRe[:DX01B480RDY0RU:0RDY0QcW
00DQ21cW8@PQ21cW008Q20077>LQ22DY:DX]JbU:8@P00QcW00DQ22U::DXU
:B48008Li`08:DXaS3F];F/YBRDY;F/YBP<U:@04:DXU:BDY;F/2<H`2;F/0
0c6<;F/]J`02:DX59BT022489BTU:BDY:DX]JbU:9BT28@P29BT00bU:9BTY
BP03:DX39BT28@P00bDY:DXYBP039BT012U:9BTU:BU:0RDY00<Q22DY8@P0
0bU:00@U:B488@PU:@8Q208YBP069BTQ22DY:DX]JbU:0RDY00L]Jc6<=Jd]
JbU:9BT]J`04:DX012e[<H`]Jbe[0RDY0bU:0be[00<YBRDY9BT00RU:00<]
Jc6<<H`00RU:00@]Jc6<;F/]J`8YBP8U:@<YBP049BTYBRe[<H`3:DX00be[
:DXU:@02:DX2<H`00cF]<H`e[@03>Lh013F]>Lhe[C6<0Re[00DaS2U::DXY
BRe[008aS003;F/e[C6<008aS0<]J`8YBP049BTYBRU:<H`2=Jd01Sg_>Lhe
[Be[:DX]J`HaS0@e[@06<H`icSg_>LhaS2e[0S6<00T]Jc6<>Lhe[Be[:DXe
[Cg_=Jd00RU:0cF]0S6<00@e[CW>@Q16<@<icP03;F/aS3F]008icPDaS004
;F/YBRe[<H`3=Jd00c6<;F/aS002=Jd4<H`013F]<H`aS3F]0cW>00@aS2e[
;F/aS0<e[@8aS003>Lhmkd8@0092408e[@8]J`04=Jdmkcg_>Lh2<H`01Sg_
AS56<CW>=JdicP<mk`06=Jd]JcW>@Q16<CW>0S6<00<icSF]<H`00SF]0SW>
00Le[C6<<H`aS3W>?NlicP02<H`01SF]?NlmkcW>=JdicP<e[@04>LhmkcW>
=Jd2<H`2;F/01CF]>LhicSF]<H`00SF]1SW>00<aS3F]>Lh00cW>00@e[CW>
=JdicP8aS005=Jdmkd8@AS4e[@01:DX00003124000@Q00<48@0300048@@Q
00848@05248Q23W>:DXDY@037>L00b487>LLi`047>L38@P011cW6<HLib48
0RDY0b4800<U:B487>L00R480RDY0b4800<U:BU::DX00be[1BU:00<]JbU:
9BT0124800DLib488@PU:BU:008]J`03<H`e[C6<008aS08e[@03:DXQ22DY
008]J`05<H`]JcF]<H`e[@02<H`4:DX01RDY8@PQ21S67>LQ208U:@<Q208U
:@038@PU:BDY00@Q2008:DXU:BU:9BTQ22DY8@PLi`<Q20<U:@048@PU:B48
8@P27>L28@P37>L01RDY8@PQ22487>LU:@<YBP068@PU:BU:;F/YBRDY0R48
00<U:BU:9BT01B480bDY00<Q22DY9BT00RDY0R4800@U:B489BTU:@<YBP05
9BTQ22488@PLi`028@P00bDY8@PQ20028@P01BU:;F/aS2e[9BT00R4800<L
ib488@P00b4800@U:BU:8@PQ208Li`039BTQ224800@Li`<Q20047>LHaQS6
7>L48@P29BT00b487>LQ2002:DX00bDY8@PU:@028@P01BDY8@PU:BDY:DX0
0RDY00@Q21cW8@PLi`DQ20037>LQ22DY00<YBP047>LHaQcW8@P2;F/01248
7>LQ22480c6<0RU:0RDY0RU:12DY00LYBRe[<H`]JbU:;F/YBP02;F/2:DX0
12489BTU:B483BDY1RU:00DU:B488@PU:B4800<YBP8U:@088@PYBRe[;F/U
:B487>LQ208U:@03:DXU:BDY008U:@038@PU:BDY00DU:@03:DX]JbU:00<Y
BP08;F/aS2e[;F/U:BU:;F/YBP<U:@<]J`@YBP049BT]Jbe[;F/2:DX29BT2
:DX012e[<H`]Jbe[0bU:0Re[0RU:0bDY0RU:00PU:BU:<H`aS2e[9BTYBS6<
0RU:00<U:BU:<H`00c6<0SF]00<icSF]>Lh00SF]00<aS2e[;F/00RU:0bDY
00HaS2e[<H`aS3F]<H`2;F/00c6<:DXYBP029BT02BU:9BTaS3F]>LhmkcW>
=JdaS002;F/00c6<;F/aS003<H`3=Jd01C6<=JdaS3W>=Jd00c6<0Re[00<a
S3F]=Jd00c6<00<e[C6<;F/00Re[00@aS3F]<H`]J`8e[@92408icP04=Jda
S36<<H`2=Jd00c6<;F/]J`05;F/01C6<=Jde[CF];F/00S6<0SF]0c6<00/e
[C6<=JdaS3F]>LhmkcF]<H`YBRe[00@aS08e[@07>Lhmkcg_@Q0mkcF]<H`0
0RU:00LicT8@?Nle[Be[<H`mk`02@Q02>Lh013F]@Q0mkcW>0S6<00@icT8@
@Q0mk`@aS08e[@0:<H`icSW><H`]Jc6<=JdicSg_=Jd2<H`033F]?NlicSF]
<H`icSF];F/e[CW>@Q0mk`<aS003:DXaS36<00@e[@03>LhmkcF]008e[@8i
cP06=JdaS3F]=JdicSg_0SF]00<icSF]=Jd00S6<00De[Cg_@Q16<CW>004Y
BP000P@Q00<000@Q000010@Q00P000@Q124HaSF]:DXLib480acW00DQ21cW
7>LQ21S600<Li`8U:@TQ208Li`8Q2003:DX]JbDY00<Q2003;F/YBRU:00<]
J`059BTYBRe[:DXU:@047>L01B487>LU:B489BT00RU:00T]Jc6<=Jde[CW>
=Jd]Jc6<;F/00RU:00LU:BU:;F/]JcW>=JdaS002:DX00be[<H`]J`029BT0
0bU:8@PQ20028@P29BT2:DX00b487>LU:@03:DX58@P01BDY:DXU:BDY7>L0
0R480QcW00@Q22DY9BTU:@@Q20059BTQ22489BTQ20027>L00aS68@PLi`02
8@P00bDY8@PU:@02:DX012DY8@PQ22DY0RU:0bDY00@Q22DY:DXYBPDU:@DQ
20059BTYBRDY9BTYBP029BT3:DX69BT28@P012DY:DXU:BDY0RU:0S6<0RDY
00DQ21cW8@PU:B4800@U:@@Q208U:@04:DXU:BDY7>L28@P39BT27>L28@P3
:DX29BT012489BTU:B480RDY0RU:00@U:B488@PU:@8YBP8U:@@Q20039BTL
iacW008Li`8Q20039BTYBRDY008U:@8Li`048@PU:BDY:DX28@P00acW8@PY
BP03<H`2:DX00be[:DXU:@029BT2;F/01C6<=JdaS36<;F/00RU:0RDY00<Q
22DY:DX00RU:1BDY0RU:0RDY00DYBR488@PU:BU:008]J`<U:@8YBP8U:@03
7>LU:BU:008]J`04:DXU:BU::DX69BT012U:9BTU:BU:0b4812DY0R4800<Y
BRe[;F/00RDY00DYBRe[:DXU:BU:008aS004;F/YBRDY9BT2:DX01BDY:DXY
BRU:;F/00RU:0Re[00@aS3F]>LhaS08YBP8]J`05:DX]Jc6<<H`]J`02:DX0
12e[<H`]Jbe[0RDY0bU:0RDY00@]Jc6<=Jd]J`8U:@8]J`07:DX]JbU:;F/a
S2e[<H`00Re[00<aS3F]>Lh00Sg_00LicS6<:DX]JbU:9BT]J`04<H`00cW>
=JdaS002:DX2;F/01RU:9BTU:BDY:DX]J`He[@03;F/YBRU:00<aS08]J`08
<H`icSW><H`YBS6<=JdicP8aS00=>LhaS2e[;F/aS3F]>Lhe[C6<;F/aS3F]
<H`00Re[0c6<00LmkdHaAS4mkc6<;F/e[@02<H`2=Jd4<H`00cF]<H`]J`02
;F/00c6<=Jde[@02<H`01cF]>Lhe[CF]<H`YBRe[00<aS08e[@8mk`03>Lhe
[C6<00<]J`04>Lhe[CW>=Jd2>Lh00cg_>LhicP03=Jd01C6<=Jde[CW><H`0
0SW>00E244YB@Q1243W>008aS0<e[@03<H`e[CW>008e[@04;F/aS3W><H`2
=Jd00cW>?Nlmk`03=Jd3>Lh3=Jd6>Lh00cF]<H`aS003?Nl2=Jd01SW><H`a
S36<=Jdmk`8icP8e[@03?NlicSW>008aS0<e[@03>Lhe[CF]00<icP03?Nli
cSW>00<e[@8icP4e[@4YBP0000<000@Q124020@Q00H8@QcW>LhYBQS68@P2
7>L012487>LQ21cW0QS60acW00@U:B488@PQ208Li`8U:@8Li`058@PLiacW
7>LQ2003:DX00bDY7>LQ2004:DX00be[:DX]J`02:DX29BT47>L38@P29BT2
:DX2;F/01cF]>Lhe[CF];F/aS2U:008U:@078@PYBRe[<H`e[C6<;F/00RU:
00<]Jc6<;F/00RDY0R480RDY0R480RDY00LYBRDY8@PQ22U:;F/YBP028@P0
0bDY8@PQ20039BT28@P00bDY8@PLi`027>L29BT00b487>LQ20078@P67>L2
8@P012U:9BTYBRU:12DY00<YBRDY9BT00R480RDY00@YBRDY8@PU:@@Q2003
9BTQ2248008Q20LU:@8YBP069BTQ22489BTYBRDY0R480RDY0RU:00HU:BU:
;F/aS2U:9BT27>L28@P59BT28@P011cW8@PU:BDY1R480bDY0acW00<Q22U:
:DX00bDY0R480bDY00<Q22DY9BT00R480RDY0RU:0RDY12480QcW00HQ21cW
6<HLib489BT2:DX012DY8@PLiacW0RDY00PYBRDY8@PLibDY7>LYBRe[0S6<
00@]JbU::DXYBP8U:@0;:DX]Jbe[<H`e[C6<;F/YBRDY;F/U:@038@P012DY
:DXU:BDY0R480bU:00dU:BU:9BTU:B487>LU:BU:;F/YBRDY8@PU:@02:DX0
12DY8@PU:BDY12U:00@U:BU::DXYBP8U:@<YBPDU:@8Q20@U:@037>LU:BU:
008]J`8U:@8YBP039BTYBRU:00<]J`8U:@03:DX]JbU:00<U:@<YBP0:9BTY
BRe[<H`icS6<;F/YBRDY:DX2;F/2<H`2;F/2:DX00be[:DXaS002:DX29BT0
22U:9BTU:BDY;F/e[C6<;F/29BT3;F/3:DX00be[<H`]J`02;F/2<H`01CF]
?NlmkcF]<H`012U:00<]Jc6<<H`00c6<00DicS6<:DXYBRe[008YBP@U:@8a
S008>Lhe[C6<>Lhe[Be[:DX]J`8aS00=:DX]Jbe[=JdicSF];F/YBRe[>Lhe
[C6<;F/00S6<0be[0cF]0be[0S6<0be[00<aS2e[?Nl00THa00Hmkbe[:DXa
S2e[<H`2>Lh2<H`012e[<H`aS36<0be[00@aS3F]<H`aS0@e[@03;F/aS36<
00<]J`08=JdaS3F]>LhmkcW>=JdYBP<]J`04=JdicSW>>Lh2=Jd3>Lh2=Jd0
0be[<H`aS003=Jd2?Nl01DHa@Q0mkcF]>Lh01C6<00De[C6<=JdaS2e[00Da
S006=JdicSW>?Nle[C6<0SF]0SW>1CF]13W>0S6<0SW>00=243W><H`00SF]
0c6<0cW>0SF]0SW>00He[CW><H`aS3F]<H`5=Jd4>Lh01CF]<H`e[CF]>Lh0
0SF]0BU:00001`@Q00048@@Q00048@0000D48@047>LaS2DY7>L28@P27>L2
8@P47>L012487>LQ22481AcW00<Q22DY8@P00acW0R480RU:00<U:B488@P0
0b4800<U:B489BT00bU:12480acW1B4800DU:BU::DXU:C6<008icP0:=Jd]
Jbe[;F/aS2e[:DXQ22DY;F/2<H`2;F/00c6<;F/YBP02:DX39BT00bU:8@PQ
20028@P00bU:9BTU:@059BT00b487>LLi`028@P49BT37>L48@P29BT28@P0
0bDY8@PQ20037>L00b489BTU:@038@P39BT00acW8@PQ2003:DX39BT00b48
9BTQ20029BT01RU:;F/]JbDY8@PLi`8U:@<Q20039BTQ2248008U:@03:DXU
:AcW00<Q208YBP039BTYBRU:008U:@<Q20059BTYBRDY:DXU:@03:DX29BT2
8@P27>L01bDY:DX]JbU:8@PU:B4800<U:@<YBP039BTYBRDY008U:@0:8@PU
:B488@PLibDY:DX]JbU:8@P39BT02B487>LQ22DY:DXU:B487>LQ20029BT4
8@P02BDY7>LLiacW8@PU:B487>LQ20029BT00b489BTU:@028@P011cW8@PY
BRU:0R4800<Lib48:DX01Re[1RU:00@]Jc6<<H`YBP@U:@<Q20039BTYBRU:
008U:@8]J`03<H`YBRe[00<YBP049BTQ2248:DX29BT00b48:DX]J`02:DX0
1RDY:DXU:BU:9BTQ208YBP8aS003;F/YBRU:00HYBP8U:@8Q20<U:@07:DXU
:B488@P]Jc6<;F/00RDY0RU:0RDY00@YBS6<<H`]J`8YBP039BTYBRU:008U
:@04:DX]Jc6<:DX29BT01be[>Lhe[C6<;F/e[C6<00<]J`8YBP<]J`8U:@03
;F/aS2e[00<YBP<U:@038@PYBRe[008aS08]J`DYBP@]J`09:DX]Jc6<;F/a
S3W>?NlicSF]00<]J`05:DX]Jbe[=JdicP02?Nl00cF]>Lhe[@02;F/012U:
;F/YBRU:0Re[0SF]0c6<00<e[CW><H`00RU:00@]Jc6<;F/YBPD]J`<aS0<e
[@03<H`]Jbe[00<]J`8aS08]J`05<H`e[CF]<H`]J`04<H`2=Jd2<H`032U:
;F/aS3F]>LhaS3F]>Lhe[C6<=JdicP8e[@03<H`]Jc6<008aS004=JdicSW>
>Lh2<H`00be[<H`e[@02<H`2=Jd2<H`3=Jd01C6<;F/]JcF]>Lh00Sg_0SF]
00<aS3F]=Jd013F]13g_00@icSg_>LhicP<e[@05<H`]Jc6<<H`e[@02<H`0
12e[<H`e[CF]0S6<0Re[0S6<13W>13F]00TaS3F]=JdaS3F]>Lhmkd8@?Nl0
23W>0S6<00He[C6<<H`icSg_>Lh2<H`00cg_AS4icP02<H`00cF]>LhicP04
=Jd013W><H`e[CW>0Sg_0c6<0CW>0CF]0BU:000212400`0012448@051240
2P00248LicF]8@PHaR489BTQ21cW0b4800@LiaS67>LLi`<Q20047>LHaQcW
6<H28@P00bDY8@PQ20027>L28@P00bDY:DXQ20038@P29BT00b48:DXYBP02
:DX00b489BTLi`027>L01R487>LLiacW8@PU:@<Q208U:@03:DXe[CW>008e
[@8YBP08;F/aS36<9BTQ22DY<H`e[@<]J`03:DX]JbU:008YBP049BTQ22DY
9BT38@P89BT28@P27>L28@P00bDY8@PQ20028@P37>L38@P00acW8@PU:@03
8@P37>L01B489BTU:B487>L00R480bDY00@Q21cW9BTU:@8YBP039BTQ22DY
008U:@8Q20049BTYBRe[:DX38@P39BT38@P00acW8@PQ20039BT012487>LQ
22DY0RU:00<U:BU::DX00RU:0b4812DY0RU:0RDY00<YBRDY8@P00acW12U:
00@Q21cW9BTQ20DU:@8YBP8U:@038@PU:BDY008Q20037>LU:BU:008YBP03
8@PU:BDY008U:@<Q20039BTYBR48008Q20049BTQ22488@P29BT012487>LL
iacW0R480QcW00<Q22U:9BT00R4800DU:B487>LQ22DY008YBP048@PLib48
9BT2:DX3;F/5:DX00bDY:DX]J`02<H`01bU:9BTYBR489BTQ22DY008Q208U
:@05:DXU:BDY;F/aS002;F/00bU:9BTU:@089BT3:DX79BT2:DX2;F/4:DX0
0be[:DXU:@03:DX01BDY8@PLibDY8@P00bDY00XQ22DY:DXaS2e[:DXU:BU:
9BTQ208U:@04;F/aS2e[:DX29BT00bU:9BTQ2002:DX2;F/29BT00bU:;F/e
[@05<H`00be[:DXYBP03:DX012e[:DXYBRU:0be[12U:00@U:B487>LYBP<a
S003;F/YBRe[00@YBP8]J`<YBP05;F/aS36<<H`icP02?Nl0236<:DXYBRU:
;F/aS2e[<H`3>Lh01CF]>Lhe[C6<:DX00RDY0RU:00<aS3F]<H`00S6<00D]
Jc6<=Jde[C6<008YBP8aS004;F/YBRe[<H`2;F/00bU:;F/]J`02=Jd5<H`0
12e[<H`aS36<0Re[0c6<00<e[C6<<H`00c6<00/e[C6<=Jde[Be[:DX]Jc6<
=JdicS6<00@e[@07<H`e[CF]<H`]Jc6<=Jd00S6<00@e[CW>>LhicP8aS08]
J`8aS08e[@<aS0<e[@03<H`]Jbe[008e[@8icP<e[@8icP04=JdaS3F]>Lh2
@Q001cg_>LhicSW>?NlicSF]00PaS08]J`<aS08]J`04:DX]Jc6<=Jd5>Lh0
13F]<H`aS3F]0c6<00De[CW>@Q1243g_00@icP03=JdicSW>00<e[@<aS008
>LhmkcW><H`e[Cg_@Q0icP8aS0<e[@<aS08e[@03>Lhe[CW>00<e[@04<H`e
[CF]<H`1:DX0000500048@@Q1240000412402P001248@QcW=JdU:AS68@PU
:B4811cW00<Q21cW6<H00QcW0b4800`YBR488@PLiaS68@PYBRe[:DXQ21S6
7>L28@P01BDY8@PLib489BT00R4800<LibDY8@P01R480RDY00<Q21cW7>L0
0R4800<U:AcW7>L00R4800@YBRe[<H`aS08]J`05:DXaS36<;F/YBP02;F/0
13F]<H`]Jbe[0RU:0RDY00DQ22DY8@PQ21cW008Q20039BTQ22DY00<Q208U
:@8Q20@Li`DQ208Li`8Q20<U:@<Q20DU:@DQ20@U:@058@PU:BDY9BTQ2005
9BT01B489BTU:BDY8@P00RDY0RU:0bDY0R480RDY0R4800<HaR488@P00RDY
1B4800PU:B489BTU:BU:;F/YBRDY0R4800HU:B487>LQ22DY:DX29BT2:DX0
0bDY8@PLi`028@P39BT012489BTQ22DY0R480bDY0R482RDY0RU:00<U:B48
9BT00RDY0R480bDY0R4800<Lib489BT00RDY00<Q21cW7>L00QcW00@Q22DY
8@PQ208Li`<U:@DQ208U:@038@PLiacW008Q20PYBP<]J`8aS0@]J`03:DXU
:BDY008Q20039BTQ22DY00@YBP049BTYBRU::DX2;F/01BU:9BTU:BDY8@P0
0RDY0R4812U:00HU:BU::DXU:BU:9BT3:DX2;F/012U:;F/]Jbe[0S6<00@]
JbU:9BTYBP8U:@048@PU:BU::DX29BT01B489BTYBRe[:DX01bDY0bU:00D]
JbDY:DXQ22DY00DYBP039BT]JcW>008icP06<H`YBRe[;F/YBRe[12U:0be[
12U:0be[00<YBRDY9BT00bU:00@aS3W>>Lhe[@<YBP03;F/YBRe[00@YBP05
;F/aS2e[;F/aS005=Jd012e[:DXU:BU:0SF]00DicSg_>Lhe[C6<00DYBP8]
J`04:DX]Jc6<=Jd4<H`4;F/3<H`3;F/00cF]<H`aS002<H`3=Jd2;F/3<H`3
;F/2<H`2;F/00c6<>Lhmk`04=Jd013W><H`aS2e[0RU:00<e[CW><H`00S6<
00PmkcW>=JdaS3F]>LhmkcW>13F]0SW>00<mkcW>>Lh00S6<00<e[C6<<H`0
0S6<00De[C6<<H`e[CW>008aS08]J`8e[@03>Lhe[CW>008e[@8aS08icP<m
k`05@Q0icSF];F/YBP02;F/2<H`01CF]<H`e[C6<=Jd01S6<0Re[00<aS2e[
=Jd00S6<00DicSF]?NlicSF]008aS003=JdicSF]008aS008=JdicSF]>Lhm
kd8@?NlicP@e[@04>Lhe[C6<>Lh2<H`01CF]>LhicSW>=Jd00Sg_0SF]00La
S3W><H`e[CW>?NlicP04=Jd2<H`3=Jd00c6<>Lhe[@019BT000<48@040004
8@@Q0005124011S6<H`Q21S60b480acW0R480QcW00@HaQcW8@PQ208U:@8L
i`036<HLib48008YBP049BTQ21cW7>L38@P37>L28@P011cW8@PQ22DY1248
00@Lib488@PU:@8Q20057>LQ22DY9BTQ20027>L00b48;F/YBP03;F/012U:
;F/]Jc6<0bU:0be[0S6<00L]JbU:8@PLib489BTYBP028@P011cW8@PU:BDY
0R4800<Lib488@P00RDY00DQ21cW7>LLib48008Li`046<HQ22488@P27>L0
1B489BTU:B487>L00R481BDY124812DY0R4800DLib489BTYBRDY008Q2004
9BTQ22DY8@P79BT012U:9BTQ22480bDY00<Q21cW7>L00R4800<U:B488@P0
0QcW0R4800<U:B488@P00bDY00@YBR488@PLi`@Q20069BTYBRDY8@PU:BU:
0R480QcW00HQ22DY:DXU:AcW8@P39BT28@P00acW9BTU:@099BT00bU:9BTU
:@059BT28@P01BDY8@PU:B489BT00R4800HLib488@PYBRDY7>L26<H011cW
9BTU:B480QcW0RDY124800XU:B488@PU:B489BTQ21S67>LQ20TYBP03;F/a
S36<008YBP<]J`05:DXU:B488@PU:@028@P29BT00bU:;F/YBP02:DX00bDY
:DXYBP02:DX01bDY8@PQ22DY:DXU:B48008U:@07;F/YBRDY9BTYBRDY:DX0
0bDY00<YBRDY:DX00RU:00@]Jc6<;F/]J`DYBP8U:@8Q208U:@0;:DXQ22DY
9BTYBRe[:DXU:B489BTQ20029BT00bU:9BTYBP02;F/012U:8@PQ22481BU:
00LU:Be[=JdicSF];F/YBP03;F/6:DX012e[:DX]JbU:12e[00PYBRDY9BTQ
22U:;F/YBRe[0SW>00<aS2U:8@P00RU:00<]JbU::DX012U:0Re[0c6<0SF]
0S6<0RU:00@U:BU:=Jde[@8icP<e[@8YBP8U:@<]J`05:DX]Jbe[<H`e[@02
<H`6;F/01BU:;F/]Jbe[<H`012e[00<aS3W>=Jd00S6<12e[00<YBRe[<H`0
0S6<0Re[00@aS3W>>LhicPDe[@05<H`]JbDY;F/aS002=Jd2<H`2>Lh2=Jd0
1c6<>LhicSg_>Lhe[C6<00@icP03?Nle[C6<008aS005=JdaS2e[<H`e[@03
<H`2=Jd00c6<;F/aS003=Jd013W>=JdicSF]0c6<00<icSg_?Nl00Sg_00<e
[C6<:DX00be[136<00He[C6<<H`aS2e[<H`2=Jd0136<;F/]Jbe[1C6<0cW>
00<e[C6<<H`00cW>0S6<00@icSF]>Lhmk`8icP09?NlicSF]<H`e[CW>=Jda
S3F]00<aS004=JdicSg_=Jd4>Lh013F]<H`aS3F]0cW>0SF]00@aS3F]<H`a
S0<e[@04<H`e[CF]=Jd19BT0000300048@0000P48@07248LicF]9BTHaR48
9BT00QcW124811cW0RDY0RU:00<Q22DY8@P00acW00<Q21cW7>L00QcW0b48
00<U:B488@P00QcW0b480QcW00HQ22DY;F/U:BU:<H`2;F/01BDY8@PU:BDY
:DX00b480bDY0RU:0S6<0be[0RU:0RDY12e[00<Q22DY8@P01B480QcW0b48
00<U:B489BT00R480acW00@Q21S67>LLi`LQ20049BTQ22487>L28@P00bDY
8@PQ20029BT2:DX29BT28@P01BDY7>LQ2248:DX00b480bDY12480RDY00@Q
22DY9BTQ20<U:@038@PU:BDY00<Q20049BTQ22487>L29BT01R489BTQ2248
9BTQ208Li`038@PU:BDY00<YBP8U:@DQ20077>LQ22489BTYBRDY8@P00QcW
00<Q22DY8@P00bDY0R480bDY00@Q22DY8@PU:@8YBP8Q208U:@038@PU:BU:
008YBP@U:@8Q20@U:@047>LQ22DY:DX29BT01R489BTU:BDY8@PLi`8Q2003
9BTQ2248008U:@8Q20039BTQ22DY00<Li`049BTYBRDY9BT27>L28@P012U:
9BTQ22DY12U:00PU:BU:;F/YBRe[:DXU:BU:1BDY00<YBR488@P00R480bU:
00<]JbU::DX02bDY00<Q22DY9BT00bDY0RU:00LQ22U:;F/YBRDY8@PU:@02
:DX00be[9BTYBP03;F/012U:9BTU:BU:0Re[0RU:00H]JbU:9BTQ22DY:DX2
;F/00bU:9BTQ20049BT00b489BT]J`02<H`00bU:9BTYBP039BT00bU:;F/Y
BP02<H`00cW>=JdaS003:DX00be[:DXYBP02:DX2<H`00bU:;F/]J`039BT0
0bU:;F/]J`02;F/3:DX01BDY;F/]Jc6<=Jd00be[00@U:B489BTYBP8]J`03
:DX]Jc6<008icP07<H`YBRe[<H`e[C6<9BT00RU:00DQ22e[<H`icSg_008e
[@03<H`YBRU:008YBP03;F/aS2e[008YBP03=JdicSF]008aS003=Jd]Jbe[
008]J`8aS006;F/YBSF]=JdmkcW>0c6<13F]0Re[0c6<00@]JbU:;F/e[@8a
S005;F/aS3F]>Lhmk`02=Jd013W>=Jde[Be[0S6<0Re[0RU:00D]Jc6<>Lhi
cS6<008e[@03>Lhmkcg_00<icP07=JdicT8@AS5243F]<H`00SF]00@aS2U:
;F/aS0He[@8aS00A=JdicSg_?NlicSg_>Lh]Jc6<;F/e[CW>=Jdmkd8@>Lhe
[@02:DX4;F/00c6<=Jde[@02>Lh01S6<;F/e[CW>?NlicP8]J`@aS08e[@8i
cP03=JdicSF]00<e[@03<H`e[CF]008icP03=JdicSg_008mk`03=JdaS3F]
00<icP03=JdaS3W>008e[@05<H`e[CF]=JdaS004>Lh00cg_>LhaS002=Jd2
>Lh5=Jd00c6<;F/aS002=Jd1>Lh1<H`19BT000D48@0300048@@Q00848@07
0008@R48=JdU:ABU7>L00b4800@Lib488@PQ208Li`066<HLibDY:DX]JbDY
0R4800<U:AcW7>L00b4800DLiaS68@PQ21cW008Q20<Li`@Q208Li`058@PU
:BDY9BT]J`02<H`00bU:8@PU:@03:DX00bDY8@PQ20039BT00bU:;F/]J`02
:DX2;F/01BU:9BTU:BU:;F/00bU:00@U:B488@PLi`DQ208Li`8Q208U:@09
8@PLiacW7>LQ21cW6<HLiaS600@Li`8Q208U:@<Q20047>LQ21cW8@P39BT3
:DX00bDY8@PQ20028@P00bDY8@PU:@0:8@P00acW9BTQ20029BT012489BTU
:BDY0R4800DU:B488@PQ22DY00<Q208Li`8Q208U:@038@PU:B4800<Q2003
:DXU:BU:008YBP039BTQ2248008Q20<Li`058@PU:BDY8@PU:@038@P29BT0
0b489BTU:@029BT28@P012DY8@PQ22480bDY0R4800@Lib489BTU:@<YBP<U
:@03:DXQ2248008Q20<U:@8Q20049BTYBRDY8@P29BT00bU:9BTLi`038@P2
9BT48@P00bDY8@PQ20027>L012487>LU:BU:0RDY00@LiaS67>LQ20@U:@<Y
BP8U:@03:DX]JbU:008YBP<U:@04:DXU:BDY8@P29BT28@P00bDY:DXYBP03
;F/59BT38@P00bDY8@PU:@0;9BT01RU:;F/U:B489BTYBP8U:@<YBP03;F/Y
BRU:008U:@04:DX]Jbe[:DX29BT01bU:8@PQ2248:DX]JbU:00DU:@<Q2003
9BT]Jc6<008YBP8U:@04:DXQ22DY:DX2;F/01RU:<H`e[CF];F/U:@HYBP@]
J`8YBP049BTYBRDY9BT2;F/022U:;F/YBRU:;F/YBRe[<H`2=Jd00be[:DXY
BP029BT2:DX4;F/013F]>Lhe[C6<0Re[0S6<00L]JbU::DXU:B48:DXaS002
>Lh013F]<H`]JbDY12U:0Re[00DYBRe[<H`icSF]00DaS0<]J`8aS08]J`04
=JdicSW>=Jd2<H`3=Jd2<H`02Be[<H`aS2e[:DXaS2e[<H`]J`03<H`2=Jd0
1SW>=Jde[CF]>LhaS0<]J`04:DX]JbU:;F/2<H`2>Lh00cF]<H`e[@02?Nl2
>Lh0136<=Jde[Cg_0T8@00PicSF]<H`icSF]<H`]JbU:0S6<00<e[CW>>Lh0
136<0SF]00HicSg_?NlmkcF]<H`2;F/01c6<=Jde[CW>@Q0icSF]008YBP05
;F/YBRe[;F/aS002>Lh2=Jd01S6<;F/aS3W>?NlicP8]J`05<H`]JcF]<H`]
J`02=Jd2>Lh4=Jd3<H`013F]>Lhe[CF]0SW>00I243W>=JdicSF]>Lh4=Jd0
0cW>=Jde[@02=Jd2<H`00cF]>Lhmk`04>Lh2=Jd01C6<=JdicSW>=Jd00S6<
00De[C6<<H`]Jc6<008icP4e[@4Q200000D000@Q00048@0000H48@08248U
:D8@;F/DYAcW8@PLi`<Q20<U:@098@PHaQS67>LQ22DY8@PLib4800@Li`03
9BTLiaS6008Li`048@PU:B489BT38@P01AcW8@PQ21cW6<H00QcW00<Q22U:
:DX00bU:00@]JbU:;F/aS08]J`8YBP048@PU:BDY8@P3;F/00c6<:DXYBP02
9BT00b487>LLi`039BT00b487>LQ20067>L01B487>LLib487>L00b480acW
0b480acW00<Q22DY8@P00R480bDY0b48014U:B488@PLib48:DXU:Be[:DXQ
22DY8@PLib487>LQ21cW008Q208Li`048@PLib487>L28@P;9BT012489BTU
:BDY0R4800<Lib489BT00bDY0R4800<U:BU:9BT00QcW00<Q22DY9BT00R48
00<U:BU::DX00R480QcW1B4800@U:B489BTU:@<Q20047>LU:BU:9BT28@P0
1RDY:DXYBRDY7>LQ208U:@05:DXU:B487>LQ20039BT2:DX79BT00b489BTQ
20038@P39BT022489BTQ22489BTQ22DY:DX69BT28@P01RDY7>LLiaS67>LU
:@8YBP058@PLiaBU7>LU:@02:DX29BT012U:9BTU:BDY0RU:00LU:BU:;F/]
JbU:9BTQ20049BT48@P01BDY:DXYBRU:9BT00bU:00<U:B489BT00RU:00<U
:B489BT00RDY0R480RDY0RU:00<U:BU::DX00Re[0RDY0R481BU:0bDY0b48
0RU:0Re[0bU:0bDY0RU:00<U:B488@P00bDY00<Q22DY9BT00RU:00DU:BU:
:DXYBRe[008U:@048@PYBRU::DX2;F/00c6<;F/]J`03:DX3;F/2:DX4;F/0
0bU:9BTU:@029BT2;F/00c6<:DXYBP04:DX2;F/2<H`2:DX29BT012U:;F/Y
BRDY0Re[00<e[CW>=Jd00bU:00D]Jc6<;F/YBRe[00<U:@0=:DX]Jc6<=Jdi
cSF]<H`YBRDY:DXaS2e[:DX00Re[00<e[CW>=Jd00be[00Xe[CW>=JdaS2e[
=JdaS2U:;F/e[@8mk`03<H`icSF]00PaS005=JdicSF]=Jd]J`02<H`3;F/0
1S6<=JdaS3F]>LhaS08]J`03<H`e[C6<008]J`<aS009=JdicSg_>Lhe[C6<
=JdicSF]00<aS005=Je2448@@Q0icP03=Jd2;F/00c6<=Jde[@02=Jd2<H`0
13F]<H`aS3F]0SW>00PmkcW>>Lhe[C6<=JdaS3F]0S6<1cF]00DaS2e[:DX]
Jc6<008icP04=Jd]Jbe[>Lh3@Q04<H`01CF]<H`e[CW>?Nl00TYB0Sg_00<e
[C6<>Lh00S6<0cW>00<aS3W>>Lh00Sg_0cF]0SW>00<e[CW>>Lh00SW>13F]
0c6<00<e[CW>>Lh00SF]0S6<00<e[CW>>Lh00SF]00<mkcW>>Lh00c6<0SF]
0CW>0C6<0BDY000912401`001248@R48?NlYBQBU008Q20<Li`048@PU:BDY
9BT37>L01B489BTU:BDY7>L00R480QcW00<Q21cW7>L00acW0bDY0acW00HQ
22DY8@PLib486<H27>L01RDY:DXU:BU:;F/aS0@]J`8aS0049BTQ22489BT3
:DX01Re[<H`]JbU:9BTYBP8U:@058@PLib488@PU:@038@P47>L48@P00acW
6<HLi`048@P27>L38@P00aS67>LQ20028@P27>L00b489BTU:@029BT68@P4
9BT00bU:9BTU:@027>L48@P01AcW8@PQ22487>L0124800<Lib489BT00b48
12DY00<YBRDY9BT00R4800<U:B488@P00R4800@U:B489BTQ20@U:@038@PU
:B4800<Q20DU:@038@PLib48008Q20037>LQ21cW008U:@03:DXQ224800@Q
20039BTYBRDY00<Q208U:@8Q20067>LQ22DY9BTQ21cW0b4800<U:BU::DX0
1BDY0b480RDY0b480bDY224800@U:BU:9BTU:@8YBP<Q20039BTLiaS6008L
i`04;F/YBRDY9BT26<H011cW8@PYBRU:0RDY00<YBRDY9BT00RDY00<YBRDY
:DX00Re[00<YBR488@P00RDY1B480bDY12U:00@U:BU:9BTU:@<YBP069BTQ
22DY9BTQ22DY0R480bU:018U:BU:;F/aS2e[9BTLib489BTYBRe[:DXU:BU:
8@PU:B489BT28@P012DY:DX]Jbe[0bU:12DY00DYBRDY9BTU:B4800@U:@HY
BP039BTYBRDY00<U:@<YBP<aS004;F/YBRU::DX3;F/2:DX2;F/00c6<:DXU
:@039BT00bU:;F/]J`03:DX00bDY:DXYBP06;F/012U:8@PU:BDY12U:00Da
S3F]>LhaS2U:008U:@06:DXe[C6<:DX]Jb480bDY00P]Jc6<<H`e[CW>;F/Y
BRDY0Re[00@YBRe[:DXaS08e[@8aS003:DXaS3F]008e[@8]J`8aS003:DX]
JcF]00<icP8e[@03<H`]Jc6<008aS003;F/aS36<008icP8e[@03<H`]Jc6<
008]J`8aS0@e[@DaS08]J`04:DXaS36<;F/4>Lh3=Jd01S6<=JdaS2e[<H`e
[@924005?NlicSF]>Lhe[@02;F/0136<=JdicSW>0S6<0SF]00LicS6<<H`e
[Cg_>Lhe[@02>Lh3<H`2=Jd2<H`013F]>LhaS36<0SF]00PaS2e[:DXYBSF]
>Lhe[C6<0Re[00DicSg_@Q0mkcF]00@aS008;F/aS3g_AS5:DTHa?NlicP<e
[@03<H`e[CF]008icP09=JdicSg_?NlicS6<=JdicSF]008icP8e[@<icP8e
[@8aS004=JdaS3F]>Lh3=Jd0136<=JdicSW>0cF]00<icSF]>Lh00S6<0cF]
0CW>0C6<0B4800001`00124000@Q00048@0000@48@07248Lid8@;F/LibDY
8@P01AcW00DQ22U::DXU:AcW008HaP8Q208U:@058@PLiacW7>LQ20037>L0
0b48:DXYBP02:DX01b487>LQ21cW8@PU:B4800<Li`058@PYBRDY9BT]J`04
:DX3;F/00bU:9BTU:@039BT01BU:;F/YBRU:8@P00acW00<Q22DY9BT00QcW
0b4821cW00HQ21cW7>LLib489BT28@P27>L38@P00bDY8@PU:@048@P012DY
8@PQ21cW124800<Lib488@P012DY00<YBR488@P01B480acW124800<U:AcW
7>L00R4800<U:B488@P00RDY0R481BDY00<YBRDY8@P00R4812DY0b480bDY
2R4800DU:B487>LQ21cW008Q20049BTQ22488@P29BT68@P29BT01B489BTQ
22DY8@P00bDY0b4800DU:B488@PQ22DY00<YBP@U:@09:DXU:B488@PYBRDY
8@PHaQcW00@Q2003:DXU:BDY008Q208U:@03:DXU:BDY00HU:@087>LHaQBU
7>LU:BU:9BTQ20<Li`038@PU:BU:00<YBP<U:@038@PU:BDY008U:@<YBP03
9BTQ224800<U:@@Q20<U:@03:DXU:B48008U:@<YBP049BTQ22DY8@P5:DX3
9BT2:DX00bDY;F/]J`029BT00b489BTYBP03:DX39BT00bU:9BTU:@029BT0
0b489BTU:@03:DX49BT012U:9BTYBRU:0RDY0R481BDY00<]Jc6<;F/00bDY
0Re[00@YBRe[:DXYBP<]J`06:DXU:BU:;F/aS2e[0RDY00@YBRe[;F/e[@8]
J`08:DXQ2248:DX]Jc6<;F/U:@DYBP0<;F/aS36<;F/YBRe[<H`]JbU:9BTY
BRe[0S6<00<]JbU::DX012U:00@]JcF]=JdYBP<U:@0>:DX]Jc6<>LhmkcF]
<H`YBS6<;F/YBRDY;F/aS08YBP06;F/e[C6<<H`]Jc6<0be[136<00Le[Cg_
AS5243F];F/YBP02<H`01cF]<H`aS36<=JdicSg_00<e[@07<H`e[C6<;F/e
[C6<>Lh00SF]00<icS6<<H`00Re[0c6<00D]Jc6<<H`aS3W>008mk`03>Lha
S36<00@aS0@e[@03<H`icSW>008e[@8]J`04<H`e[CW>>Lh5=Jd00c6<=Jda
S002<H`4=Jd02c6<=Jd]Jbe[<H`e[CW>=Jd]Jc6<=Jd00SW>00<e[C6<<H`0
1C6<00@]Jc6<>Lhe[@8icP05=JdaS36<:DX]J`02<H`01d8@AS5F]EJeDYAF
]D8@008icP03=JdmkcW>008e[@03<H`e[CW>00De[@8aS0<icP03=JdaS3F]
00<icP04=JdaS3F]>Lh2<H`2=Jd00cW>=JdaS002<H`4=Jd00c6<=Jde[@04
=Jd1<H`18@P000P48@0824848@00248Q248@<H`Li`<Q208Li`<Q208U:@@L
i`8Q20039BTQ21cW008Li`046<HLiaS67>L28@P2:DX00bDY8@PQ20028@P2
9BT28@P011cW6<HLib480RDY1bU:0Re[0RDY00HQ22DY9BTU:BU:;F/2:DX2
8@P27>L00b489BTQ20037>L38@P67>L00b487>LLi`027>L01BDY8@PLib48
7>L01R4800<Lib487>L00QcW0R4800@U:B487>LLi`8Q208Li`8Q2004:DXU
:BDY9BT38@P00acW8@PQ20027>L58@P011cW8@PQ21cW0R480RDY0b4800<U
:B489BT01RDY0b480bDY1B480RDY00LQ21cW8@PQ22DY8@PLi`028@P00bDY
8@PQ20027>L28@P012DY8@PLiacW1B4800TLib488@PU:B487>LQ22DY:DX0
0R4800DLibDY8@PQ22DY00@Q20HU:@03:DXU:BDY008U:@DQ20047>LQ2248
7>L38@P00bDY8@PQ20048@P2:DX00bDY8@PQ20038@P021S65:DHaQcW:DXU
:B487>L26<H38@P4:DX29BT28@P00bDY8@PYBP029BT2:DX01bDY8@PQ2248
9BTQ22DY00@Q20<U:@8YBP069BTYBRU::DXU:B480RDY00<Q22DY:DX00RU:
12DY00<Q22U:;F/00RU:00DQ22DY9BTU:BU:008]J`04:DXU:BDY9BT2:DX0
12DY8@PQ22480bDY0bU:00@U:B489BTU:@<YBP8U:@8Q208U:@<YBP8]J`03
:DXU:BDY008YBP05;F/YBRU:;F/YBP03;F/29BT01BU:;F/]Jbe[:DX00RDY
00HYBS6<<H`]JbU:9BT28@P012e[<H`aS2e[12DY0bU:00<]Jc6<;F/00RU:
0Re[00<YBRDY9BT0136<00<YBRDY:DX00RDY0Re[00haS3F];F/YBR489BTa
S2U:;F/icT8@=Jd]JbU:0Re[0RU:00L]Jc6<;F/YBRe[<H`e[@02;F/0136<
;F/]Jbe[0S6<00T]Jc6<>Lhmkd8@>Lhe[C6<;F/01C6<0SF]0cW>0SF]1C6<
13F]136<1Be[00@aS2e[;F/e[@<icP03;F/e[CF]008]J`05<H`e[CF]<H`e
[@02>Lh01CF]<H`e[C6<;F/00S6<00<e[CW>=Jd013F]1S6<1CF]0Re[00@a
S3F]>Lhe[@<aS0<icPHaS0<]J`05<H`icSW>=JdaS002;F/022U:<H`aS36<
@Q1:DUJeF]H2DY@0148@?NlicSF]0SW>00Pe[C6<<H`icSF]>Lhe[C6<0SF]
00DaS3F]>LhmkcW>008aS003=JdicSg_008e[@06<H`e[CF]=Jd]Jc6<0cF]
136<0cF]00<aS3F]>Lh00SF]0c6<0BDY00000`001240000212400`001244
8@0312401PQ27>M6<CW>7>LQ208Li`058@PLiacW8@PU:@048@P57>L00b48
7>LLi`037>L022487>LQ21cW8@PU:BU:9BT38@P01AcW8@PU:BDY8@P00QcW
0RDY0b4800<U:B489BT00bDY00PQ22e[:DXYBR487>LQ22U:0Re[00<YBR48
7>L00acW0bDY0acW00<Q21cW7>L00R4800LHaQcW7>LU:AcW6<HLi`038@P5
7>L01248:DXYBRe[0RDY0bU:00@U:AcW7>LLi`8Q20056<HLib48:DXQ2002
7>L01BDY:DXU:BDY:DX00R480QcW00<U:B487>L00QcW0R4800<U:B487>L0
0b4800LU:BU::DXU:B487>LQ20029BT38@P29BT28@P01BDY:DXU:BU:9BT0
0R4800@U:B488@PQ208U:@<Q20039BTLiacW008Q20<U:@037>LQ2248008Q
20037>LQ22DY008Q208U:@048@PLib488@P69BT38@P29BT58@P011cW8@PU
:BU:0bDY00@YBRDY9BTLi`8Q20069BTYBRDY8@PLib480RDY00DQ22DY7>LU
:B48008U:@<YBP039BTYBRDY008U:@8Q20065:DHaQcW8@PU:BU:0QcW0aS6
00DLibDY:DXYBRe[00<YBP8U:@047>LQ22DY9BT3:DX29BT01R489BTQ22DY
8@PU:@8Q20069BTYBRe[:DXQ22DY1bU:0R4800LU:BU:<H`aS2U:9BTYBP02
9BT3:DX29BT2:DX022DY:DXYBRe[<H`]JbDY8@P29BT00bU:9BTQ20048@P4
9BT28@P01BU:9BTYBRU:9BT00b4812U:00H]JbU:;F/YBRe[:DX39BT2;F/6
:DX00bDY:DXYBP02;F/2:DX2;F/3>Lh00cF]<H`U:@029BT2:DX29BT01Re[
:DXYBR489BT]J`8YBP8U:@8aS004;F/U:BDY9BT4<H`2;F/00c6<;F/]J`02
9BT012e[=Jd]JbU:0RDY00LaS3F]=JdmkcW>=JdaS003:DX29BT3:DX012e[
:DX]Jbe[0c6<12U:00/]Jc6<<H`aS3F]@Q16<Cg_=JdYBRe[008aS007=Jda
S36<=JdicSg_>Lh013F]00DicSF];F/]JcF]008icP03=JdaS36<008aS0<]
J`8aS0<e[@03>Lhe[C6<008aS08icP04=JdicSF]<H`4=Jd4>Lh3<H`00cW>
=Jde[@03<H`00cF]>LhicP02=Jd012e[<H`e[CF]0c6<0Re[0S6<0SF]0c6<
00<]Jc6<<H`00SF]00@aS2e[<H`YBP<]J`8aS08e[@8aS0@]J`03<H`icSW>
009>L`9BU005@Q0mkcW>=JdicP04=Jd00c6<=Jde[@03=Jd3<H`013W>?Nlm
kcW>0S6<00<e[CW>>Lh00SF]13W>00<e[CW>=Jd00cF]00<aS2e[=Jd00cW>
136<00<e[CW><H`00BDY000312400`0012448@0312402`001248@R48AS4a
S1cW9BTQ21cW8@P00acW00<Q22DY8@P01AcW0R4800<U:AcW6<H00QS600DQ
21cW8@PLib4800@U:@LQ208Li`8Q20039BTQ21cW008Q20059BTYBRDY9BTQ
20029BT00bU:9BTU:@028@P4:DX01B486<HHaQcW8@P00RDY00DQ21cW7>LL
ib48008Li`048@PLiacW6<H38@P37>L01b487>LLiacW8@PLib48008U:@08
:DXU:BDY9BTYBRe[:DXU:@PLi`DQ20039BTYBRDY008U:@@Q20@Li`068@PL
iacW8@PLiaS60R480bU:0R4800DLib489BTQ22DY008Q20<U:@8Q20039BTY
BRDY008Q20059BTQ22DY8@PU:@0:8@P29BT28@P00acW8@PU:@048@P00bDY
8@PQ20048@P01QcW8@PU:BDY:DXU:@@Q20<U:@<Q20039BTQ2248008U:@8Q
20049BTYBRU:9BT28@P39BT38@P00bDY8@PQ20048@P39BT01248:DXYBRU:
0R480RDY00@Q21cW6<HHaP8Li`8YBP097>LHaQS65:DQ21cW8@PU:BU:008]
J`03:DXU:B48008U:@8Q208U:@@YBP059BTQ22488@PU:@038@P29BT3:DX2
9BT3:DX29BT01bU:9BTU:BDY:DXaS2e[00@YBPDU:@8YBP059BTYBRU::DXa
S002;F/00bU:9BTU:@049BT28@P01AcW8@PQ22U:9BT00R4812DY00HYBRDY
8@PQ22DY:DX39BT012U:;F/]Jbe[0bDY1bU:00<U:Be[:DX01bU:00XaS2e[
=JdicSg_=JdaS2489BTQ20HYBP<U:@HYBP8]J`04:DXU:BU:<H`3;F/3<H`0
1Be[:DXU:BDY;F/00S6<00<YBR489BT00S6<00De[CW>?Nle[Be[008YBP8U
:@03:DXU:Be[008YBP05;F/YBRe[;F/aS003;F/29BT2;F/3=Jd00cg_AS4i
cP03;F/00c6<=Jde[@03<H`2>Lh2=Jd2<H`00cW>=JdaS003;F/00cF]>Lhe
[@05<H`012U:;F/]Jc6<0cF]00<icS6<<H`00S6<0SF]00@icSF]>Lhe[@8a
S004=JdicSF]=Jd2>Lh3<H`3=Jd4<H`00cW>=Jde[@07<H`00be[<H`aS004
<H`00be[<H`aS002<H`00cF]>LhaS007;F/00c6<;F/aS002<H`00be[:DXY
BP03<H`00cW>?Nm>L`02CW<015:D@Q1243W>13F]0S6<1cF]00H]JcF]>Li2
43g_=Jd3<H`00cF]>Lhe[@02>Lh2?Nl00cW>=JdaS003=Jd4<H`2>Lh013F]
<H`aS3F]0S6<0CF]0C6<0B4800001@0012448@@Q00001@@Q00H000Q28@Q2
436<6<H27>L28@P27>L01QS68@PQ22489BTQ20<Li`056<HQ22489BTQ2004
7>L01QS67>LLib487>LQ20<U:@8Q20039BTQ22DY00<Q20087>LU:BDY9BTQ
21cW8@PU:@<Q2003:DXU:BDY00DU:@04:DXU:BDY9BT48@P01Re[:DXU:B48
7>LQ20<U:@8Q20037>LQ21cW008Li`8Q20037>LQ22DY008U:@@Li`069BTL
ib488@PU:Be[0S6<00@YBR488@PQ208Li`036<HLib48008U:@038@PU:BDY
008U:@03:DXU:B4800HQ208Li`066<HLiacW7>LQ21cW0R4800DYBRDY9BTU
:B48008Li`8Q20039BTQ22DY008U:@8Q20049BTYBRU:9BT38@P012DY8@PQ
22480RU:12DY00LLib487>LLib489BTQ20027>L00b489BTQ20028@P02BDY
8@PQ22489BTQ22DY7>LQ20029BT2:DX01B489BTU:B489BT00R4800<U:BU:
9BT00QcW00<Q22DY8@P00R480bDY00<YBRDY8@P00R480bDY2b4800<U:BU:
:DX012U:00P]JbU:9BTLiaBU6<HLib480RDY0QcW00<HaR489BT00bDY12U:
0RDY00@Q22U::DXYBP<U:@06:DXU:BDY8@PLib4812DY00<YBRe[:DX00bDY
12U:0bDY0RU:0bDY00<YBRe[;F/00RU:00@U:BU::DXYBP8]J`@U:@05:DXe
[C6<=JdYBP029BT01BU:;F/YBRe[9BT00b480RDY0R4800<U:B488@P00RDY
0RU:00<U:BU:9BT00RDY0RU:0RDY0be[00DYBR489BTU:BU:008]J`<YBP8]
J`8aS005:DXU:BU::DX]J`02:DX01Re[<H`mkcg_>LhaS0@U:@05:DXU:BU:
;F/YBP029BT00b48:DXU:@029BT00bU:;F/YBP05:DX2;F/00cF]<H`]J`02
9BT01Re[:DXYBRU:<H`YBP8U:@08:DXe[CF]=JdaS2e[:DX]J`<YBP<U:@04
:DX]JbU::DX3;F/4<H`4;F/2<H`00cF]>Lhe[@02>Lh00be[<H`]J`03<H`0
1CF]<H`aS3F]?Nl01CW>00De[Be[;F/aS2e[00DaS005;F/YBRe[;F/aS002
=Jd00cW>=JdaS002<H`013F]>Lhe[C6<0SF]0cW>0SF]00@aS3F]>LhicP8e
[@<]J`0:<H`e[C6<<H`YBRe[=JdicSg_>Lh2<H`2=Jd013W><H`aS36<0SF]
00<icS6<=Jd00S6<00@e[C6<<H`aS08e[@03<H`]JbU:00<aS003;F/aS36<
008aS08]J`<aS006;F/aS3F]=JdmkcW>0cg_00Le[CW>>LhicSF]<H`e[@02
>Lh4=Jd2<H`2=Jd2>Lh013g_>LhicSW>1CF]00DicSF]>Lhe[C6<008e[@03
>Lhe[CW>008aS08icP92408aS08]J`03=JdicSF]004U:@0000<48@001240
0P@Q00<000@Q12400`@Q00@8@RDYAS4]J`8HaP@Q208Li`8Q20049BTQ2248
6<H37>L01R487>LLib487>LQ20DLi`038@PLibDY008U:@038@PLib48008U
:@8Q20039BTQ21cW008Q208U:@<Q20049BTQ22DY9BT38@P2:DX00bDY8@PU
:@02:DX38@P021cW9BTU:BU:9BTQ21cW8@P29BT38@P37>L38@P011cW8@PQ
22480RDY0acW0b4800<U:B489BT00S6<00@]JbDY7>LQ20DLi`038@PU:BDY
008Q20039BTYBRU:00LQ20037>LHaQcW00LLi`048@PU:BDY:DX38@P011cW
8@PQ22DY124800LU:AcW8@PQ22U:;F/U:@038@P012DY8@PQ22480bDY0b48
11cW0RDY11cW00@U:B488@PQ208U:@@Q20047>LQ21cW8@P3:DX01BDY8@PQ
22489BT00b4800<YBR487>L00QcW00<U:B488@P00bDY00LYBR489BTQ21cW
8@PU:@028@P00acW8@PU:@027>L28@P01BDY8@PQ22489BT01bU:0RDY00<Q
21S66<H00QS60RU:00HQ21cW6<HHaRDY8@P29BT3:DX00bDY:DXU:@029BT2
:DX49BT00bU:9BTQ20048@P49BT00be[:DXU:@029BT2:DX39BT2;F/29BT0
1248:DX]Jbe[12U:0RDY00<YBRe[:DX00bDY00HQ22e[<H`e[C6<;F/28@P0
1RDY:DX]Jbe[8@PU:@8Q20039BTQ22DY008U:@037>LQ224800DU:@<YBP<U
:@8YBP03;F/YBRDY008U:@06;F/YBRU::DX]JbU:0Re[00<aS2e[;F/00Re[
12U:0Re[00Le[CW>?NlicS6<9BTQ20049BT2:DX012e[9BTQ22DY12U:00`U
:BU::DXYBRDY:DX]Jc6<:DX]Jc6<=Jd2;F/00bDY:DXYBP02:DX022e[:DXQ
22DY:DXaS3F]<H`5;F/00bU:9BTYBP029BT00bU:;F/]J`03:DX5<H`012e[
:DXYBRe[13F]00<icSF]<H`01c6<0SF]00HicSF]>Lhe[CW>?Nl2=Jd0136<
;F/]Jbe[136<00D]JbU:;F/YBRe[008aS003>Lhe[CF]00<aS0<e[@8aS08e
[@8icP03=JdaS3F]008e[@04>LhaS36<<H`2;F/0136<=Jde[C6<0Re[00@e
[CW>>LhicP<aS007=JdicS6<<H`]Jc6<>Lh00cF]0c6<0Re[0S6<0SF]0be[
0S6<0Re[0S6<00D]JbU:;F/aS3F]008aS003;F/e[CW>008mk`03>LhmkcW>
00@icP<e[@8icP8e[@07>Lhe[CF]<H`]JcF]>Lh00Sg_00@icSF]=Jde[@<a
S003>Lhe[CF]008e[@03>LhaS3F]00<icP8aS004>Li243g_?Nl2;F/2<H`0
0cF]>Lhe[@018@P000<48@0500048@@Q0008@P0312401@aS:DY:DRe[5:D0
0R4800<Lib487>L00b4800@U:BU:9BTQ20DLi`<Q20069BTQ22487>LHaQcW
0R480QcW00DQ22DY8@PU:B4800@U:@04:DXQ22DY8@P29BT00b487>LLi`02
8@P01BU:;F/]JbU:8@P00bDY00<Q21cW8@P00bDY00@Q22DY9BTYBP@]J`<Y
BP05;F/YBRDY7>LQ20039BT01Re[:DXU:B487>LQ20<U:@048@PLib489BT2
8@P69BT28@P29BT38@P01QcW8@PQ22DY8@PLi`8Q2004:DXU:AcW8@P27>L0
0b487>LQ20027>L00b487>LLi`026<H021cW8@PQ22DY8@PU:B489BT27>L5
8@P00bDY8@PU:@039BT01B489BTQ22489BT00bU:0RDY0bU:00@U:AcW7>LQ
20<Li`048@PU:B487>L28@P39BT01R489BTU:BDY8@PU:@<Q20<U:@<Q20@U
:@068@PU:BDY8@PLiaS61R4800@U:B489BTU:@@Q20049BTQ22DY8@P39BT2
8@P27>L59BT01BU:;F/YBRDY:DX00Re[00DYBQcW6<HLib48008U:@@Li`04
8@PYBRU::DX29BT3:DX022DY8@PU:Be[:DXU:B489BT3:DX02B489BTU:Be[
:DXQ22DY:DX]J`039BT01BU:;F/]Jbe[:DX012DY00@Q22DY9BTQ20<YBP8]
J`8YBP8]J`07=JdicRe[:DXQ22DY;F/00c6<00<]JbU:9BT00RDY00<]JbU:
:DX01BDY00<Q22DY9BT00RU:0b4800<U:Be[;F/00RU:00<U:BU:9BT00RDY
1bU:00<]JbU:9BT00Re[0S6<0Re[00<aS2e[:DX00bU:00@U:BU::DXe[@<a
S08]J`04:DXU:B489BT3:DX28@P29BT02be[9BTU:Be[=Jd]JbU:9BT]Jc6<
;F/00RU:00<U:BU:;F/00RU:0Re[00<YBRDY:DX00Re[00DQ22DY;F/icS6<
008YBP8]J`03<H`]JbU:00DYBP089BTaS3F]=JdicS6<;F/aS0<e[@04<H`]
JbU:<H`2>Lh0136<;F/aS3W>0SF]0Re[00<aS3F]>Lh00Re[00<aS3W>=Jd0
0cF]00DicSF]=Jde[Be[008aS003=JdaS36<008]J`03<H`YBRe[008aS003
=JdaS2e[00<aS004>Lhe[CF]<H`2=Jd01cW>=JdaS2e[<H`e[C6<008icP05
<H`]JbU::DXaS002=Jd01C6<:DXYBS6<>Lh00SF]0SW>00<mkcW>>Lh00S6<
00@e[C6<<H`]J`8aS003=JdaS3F]008]J`8e[@06>LhaS2e[;F/aS3W>0SF]
00<aS2e[<H`00c6<0be[00PaS2e[;F/aS3F]>LhmkcW>0SF]00<aS3F]>Lh0
0cW>0S6<13F]0c6<00<e[CW>=Jd00SF]0Sg_00<icSF]<H`00SW>0SF]00Da
S3F]=JdaS3F]008aS00?=JdicSW><H`e[CW>?NlicSF]<H`e[Be[<H`e[C6<
004YBP000P@Q00<000@Q124010@Q00L000@Q248YBTYB<H`DY@057>L00b48
7>LQ2002:DX00bDY8@PLi`057>L58@P00aS67>LLi`028@P27>L01B48:DXU
:AcW8@P00RDY00TQ22DY9BTU:AcW8@PU:BU:9BT00QcW0R4800HYBRe[;F/Y
BRDY8@P29BT00acW8@PLi`049BT28@P01BDY;F/YBRe[9BT00RU:00@]Jc6<
9BTU:@8Q208U:@04:DX]Jbe[9BT37>L39BT28@P00acW8@PQ20038@P01BDY
:DXU:BDY7>L00b4800<U:B488@P00R480RDY00<Q21cW7>L00RDY00<Q21cW
8@P00R4800LHaQcW7>LLib487>LQ20027>L26<H01AcW8@PQ22487>L00R48
0acW00<Q22DY9BT012480RDY00<Q22DY8@P00R480RDY00<]JbU::DX00R48
0RU:00<U:B487>L00acW1B4812DY00@Q22DY8@PU:@LQ20<U:@037>LQ22DY
00<U:@048@PU:BDY8@P27>L00aS68@PQ20038@P00acW8@PU:@029BT00b48
7>LQ20038@P49BT48@P39BT012489BTYBRU:0RDY00PYBRe[:DXU:AcW6<HL
ib480RDY11cW0RDY00@YBRDY9BTU:@8YBP059BTQ2248:DX]J`02:DX012DY
8@PQ22DY0RU:00<Q22DY9BT01RU:0bDY0Re[0RU:0bDY0RU:0R480RDY1bU:
00DaS3F]>Lh]JbDY008Q2003:DX]Jc6<008]J`8U:@8YBP05;F/YBRU:9BTQ
20029BT00b489BTU:@02:DX49BT02248:DXYBRe[:DXU:B489BT28@P01BDY
:DXYBRU:9BT01RU:00<aS3F]<H`012e[00<YBRDY:DX00bDY00@]Jc6<=Jda
S08]J`03:DX]Jb48008Q20039BT]Jbe[00<Q20059BTYBRDY9BT]J`02<H`0
1BU:9BTYBRe[<H`01BU:00<]JbU::DX00RU:00TU:BU:;F/YBRDY:DX]JcF]
<H`00Re[00HYBRe[;F/]JbU:9BT3:DX01Be[:DX]Jc6<=Jd00S6<00H]Jc6<
<H`e[C6<;F/2:DX04C6<>LhicS6<;F/aS3F]>Lhe[Be[:DX]JcW>=JdaS2e[
=Jd00SW>0S6<13F]0S6<0Re[00@aS3F]<H`YBP8]J`8YBP04<H`e[C6<<H`2
;F/01c6<=JdaS36<=Jd]Jc6<00<icP04<H`YBS6<<H`2=Jd00cW><H`]J`02
:DX00c6<=Jde[@04;F/01C6<=JdicSW>=Jd00SW>0SF]1C6<00@]Jc6<<H`e
[@@aS08e[@04<H`]Jbe[<H`3=Jd0236<;F/]Jc6<;F/YBRe[<H`4;F/02C6<
=JdicSW>=JdicSF]<H`e[@03>Lh013F]<H`aS36<0SF]00@icS6<<H`aS0<e
[@06<H`icSg_?NlicS6<0SF]0SW>00<e[C6<<H`00S6<00De[C6<=Jde[CW>
00<e[@8icP03=JdaS36<008]J`<aS04YBP0000D000@Q12448@0000D48@0:
000<HbU:AS4aS1BU8@PU:B487>L28@P49BT28@P011S67>LHaQS60QcW00DQ
22DY9BTYBRDY00@Q208U:@058@PLiacW8@PYBP029BT00b48:DXYBP02:DX0
0bDY8@PU:@048@P39BT3;F/00bU:8@PQ20027>L00b489BTU:@02:DX03Be[
<H`]Jbe[=JdicSF];F/YBRDY:DX]JbU:00<Q2003:DXU:BDY008U:@8YBP05
8@PLiacW6<HQ20037>L00aS67>LQ20039BT01b489BTU:Be[:DXU:BU:008Q
20047>LHaQcW7>L28@P00acW8@PQ20078@P021cW8@PQ22489BTQ21cW8@P3
7>L00b489BTQ20028@P00bDY8@PQ20028@P49BT38@P011cW8@PLib480RDY
00HYBRDY9BTYBRDY8@P39BT00b487>LLi`078@P59BT00bU:9BTU:@028@P0
0bU:9BTQ20039BT00b487>LLi`038@P00bDY8@PU:@029BT28@P37>L68@P2
7>L00b489BTU:@039BT28@P012DY:DXYBRU:0bDY0b481BDY0bU:00<U:BU:
:DX00b4800LU:BU:9BTLiaS67>LU:@02:DX29BT2:DX29BT00b489BTYBP02
:DX69BT01BU:9BTYBRDY:DX00RDY00PYBRe[:DXYBRDY:DX]JbU:0RDY00<]
JbU::DX00RDY00@Q22DY8@PQ208U:@LYBP04<H`]Jbe[:DX29BT00bU:9BTU
:@02:DX38@P00bDY;F/]J`039BT3:DX01RDY8@PQ22DY;F/U:@8Q20069BTY
BRDY9BTYBRDY0R4800/LibU:;F/]JbU:8@PU:BU:<H`]JbU:008U:@03;F/e
[CF]008aS005;F/aS36<;F/YBP028@P012U:9BT]Jbe[0S6<00<]JbU::DX0
0RU:0bDY00<YBRDY9BT00R480RDY0RU:00@]JbU:9BTYBP8aS006;F/U:BDY
9BTYBRe[0bU:00<]JbU:9BT012DY0RU:00D]Jc6<=Jde[CW>008aS08YBP04
;F/aS2e[;F/29BT00bU:;F/e[@04<H`2=Jd2<H`2:DX01S6<=Jde[C6<:DXa
S08e[@<aS004=JdaS3F]>Lh2=Jd3<H`00cF]>LhicP02<H`013F]<H`]Jbe[
1S6<0Re[00<e[CW>>Lh00Re[00<aS3W><H`00c6<00@e[C6<>LhicP8aS08]
J`DaS08]J`03:DX]JcF]008icP07<H`U:BDY<H`e[Cg_>Lh00SF]0SW>0SF]
0S6<00De[C6<;F/aS3F]008aS005:DX]Jc6<=JdicP02=Jd2<H`2>Lh2?Nl0
2C6<;F/]Jc6<=JdaS2U:;F/aS002:DX00be[<H`e[@02<H`2=Jd00c6<=Jdi
cP02>Lh5<H`013W>=JdicSF]136<00<e[CW>?Nl00Sg_0cW>13F]00PicSF]
=JdaS2e[<H`e[CW>13F]0SW>00De[C6<<H`]Jc6<008e[@4]J`000`@Q00<0
00@Q00001@@Q00D8@RDYBU8]JaS6008Q20047>LQ21cW9BT28@P012DY:DXU
:B480QcW0QS60QcW0RDY00<YBRDY:DX00QcW0R4800<U:BU:7>L00QcW00PU
:Be[:DXQ22DY:DX]JbU:0R4800<Lib488@P00R4800/U:B488@PU:Be[<H`]
JbDY7>LQ21cW008Q20059BTYBRDY9BTYBP03;F/0136<=JdaS36<12U:00HU
:B488@PU:Be[:DX29BT2:DX01RDY8@PQ21S67>LHaPDLi`<Q20039BTQ22DY
008YBP048@PU:BU:9BT27>L011S68@PQ22480acW00<Q22DY8@P00QcW00@Q
21cW8@PLi`<Q20069BTQ22487>LHaQcW1B4811cW0R4800DU:B489BTQ22DY
00DQ20039BTQ22DY00<U:@03:DXQ2248008U:@03:DXU:B48008Li`<Q2004
9BTQ22488@P29BT01BU:9BTQ22DY8@P00bDY00@Q22DY8@PU:@<Q20067>LQ
22489BTLib480bDY00<Q21cW7>L00b480QcW0R480acW00<Q22DY8@P00RDY
00@Q22DY9BTQ20<YBP8Q20047>LU:BDY9BT38@P012DY:DXU:BU:0RDY0RU:
00HU:AcW8@PU:BU:8@P26<H00acW8@P]J`039BT012U:9BTU:B480RDY0RU:
12DY00@Q22U:9BTU:@<YBP8U:@048@PYBRU::DX29BT012U:;F/U:BDY0bU:
0bDY00<Q21cW8@P01BDY1BU:00H]JcF]:DXU:AcW9BT2:DX39BT38@P00bU:
;F/YBP039BT01BU:;F/YBRDY8@P00RDY00<YBRDY8@P00R4800<YBRDY8@P0
0RDY124800HYBRe[:DXU:B48:DX2;F/012U:9BTU:Be[0SF]00<aS2e[;F/0
0S6<00H]JbU:8@PU:BU:9BT2;F/0136<;F/]Jbe[0RU:0bDY0bU:12480RDY
00@]JbU::DXYBP8]J`03<H`]JbDY008U:@LYBP<U:@05:DXU:BDY:DX]J`02
<H`2>Lh013F]<H`YBRDY0RU:00HaS2e[9BTU:BU:;F/3<H`2;F/2>Lh0136<
;F/U:BDY0S6<00De[C6<;F/YBS6<008e[@06<H`]Jc6<=JdicSF]1C6<0SF]
0S6<00@]Jc6<<H`]J`8aS003=JdaS36<008aS005:DX]Jc6<?NlicP03;F/2
=Jd4<H`2=Jd013W>=JdaS2e[136<00Xe[C6<;F/YBRDY;F/e[Cg_=JdaS08U
:@04<H`e[CW>>Lh5=Jd2<H`2=Jd00c6<;F/]J`02<H`2;F/00bU:<H`e[@03
=Jd022e[=JdicSW>?NlicS6<;F/4<H`4;F/01BU:;F/aS3F];F/00S6<0SF]
00HaS3F]>LhicSF]<H`2;F/01S6<=Jde[CF]>Lhe[@8aS003;F/e[CW>008m
k`DicP8aS004=JdaS3F]=Jd5<H`00cF]<H`e[@02=Jd023W><H`e[Be[:DXa
S3F]<H`1:DX00003124000@Q00D48@08248000@Q248YBU:D>LhLi`<U:@@Q
208U:@DQ20@HaP078@PYBRU:;F/U:B487>L00R4800<YBRDY9BT00b4800<U
:B489BT00b4800<U:BU::DX00bDY0b4800PU:AcW8@PaS3W>;F/Q21cW0R48
0acW0RDY00@YBRe[;F/]J`<aS08e[@8]J`<Li`058@PU:BU::DXU:@058@P2
7>L011S65:DHaQS611cW0b480RU:0Re[0RDY00DQ22DY:DXU:AcW008HaP<L
i`048@PLiaS67>L38@P00bDY8@PQ2003:DX01b487>LQ22489BTQ21cW008Q
208U:@8Q20039BTQ2248008Q20@U:@<Q20047>LQ22DY9BT28@P39BT01248
9BTU:BDY0RU:00HU:B488@PQ21cW8@P49BT28@P29BT2:DX39BT00bU:;F/Y
BP048@P011cW8@PQ22480bDY00<Q22DY:DX00RDY00<Lib487>L00acW1b48
0RDY00DYBRDY8@PLibDY00<YBP049BTQ22489BT78@P39BT00bU:9BTU:@03
8@P39BT01B487>LLib48:DX00RDY0b480RDY00<YBRDY:DX00RDY0R4800<U
:Be[:DX00RDY00<YBRe[:DX00bDY00HYBRe[;F/YBRDY8@P39BT5:DX00bDY
:DXU:@029BT02R489BTYBRDY8@PU:B48:DX]JbU:0Re[0RU:00@U:B489BTU
:@<YBP059BTLiacW8@PU:@02:DX00bDY:DX]J`02;F/00bDY8@PU:@028@P4
9BT28@P2:DX012DY:DXU:AcW0R4800DYBRDY8@PU:BU:008]J`8YBP03;F/Y
BRe[00L]J`03:DXU:BU:00<U:@05;F/aS36<:DXU:@02:DX00bDY8@PQ2002
8@P39BT012489BTU:Be[12U:0Re[0RU:0RDY00DYBRDY:DXU:BU:00<aS003
;F/Q22DY008Q20<U:@07:DX]JcW>>Lhe[Be[:DX00Re[0RU:00L]JbU::DXY
BRDY:DXe[@02>Lh2<H`01SW>=Jd]JbDY;F/aS08]J`03<H`e[CF]008e[@03
>Lhe[CF]008aS0@icP06;F/YBS6<<H`icSF]0bU:0be[0S6<0Re[0cF]00H]
Jc6<=Jde[C6<;F/2<H`4=Jd2<H`00cF]<H`aS003<H`00cF]<H`aS003<H`0
1be[:DX]Jbe[<H`e[C6<008]J`03:DX]JcW>008icP04=JdaS36<=Jd2<H`0
0be[<H`aS002=Jd0236<;F/]Jbe[<H`e[CW>?Nl2>Lh2<H`013F]>Li243g_
0S6<00L]Jc6<>Lhe[C6<=JdaS003;F/7<H`3=Jd2<H`02Re[=Jde[CF]<H`]
Jc6<=JdicSF]0S6<00<e[CW>>Lh00cg_00PicSF]<H`aS3W>?NlicSF]0c6<
0Re[0S6<00<e[C6<<H`00SF]00<icSF]<H`00Re[0SF]0Be[00000`001240
000212400`0012448@0312401`aS:DYBU3F]7>LQ22DY00DQ208U:@<Q20<L
i`036<HLiaS6008U:@8YBP039BTQ21cW008Li`<U:@078@PLib488@PU:B48
7>L00R4800<U:BU::DX00RU:0R4800DLib488@PQ22DY008aS004;F/Q21S6
7>L48@P29BT3;F/012U:;F/]Jc6<0SF]0Re[00LQ21cW7>LLibDY:DXU:@02
7>L01R489BTU:B486<HLi`@HaPHLi`038@PU:BU:008]J`039BTQ21cW008U
:@048@PHaQS66<H27>L012486<HHaQcW1R4800PU:BU:;F/U:B487>LQ22DY
0b4800<Lib488@P00R4800<U:B488@P00R4800@U:B488@PQ208U:@038@PL
ib4800@Q20039BTQ22DY008U:@058@PU:BDY9BTQ20029BT38@P39BT38@P0
0acW9BTYBP02:DX022DY8@PQ22DY:DXU:B486<H38@P37>L39BT28@P29BT0
1B487>LLiacW6<H00R4800<U:B488@P00R480QcW00DQ22DY9BTYBRDY008Q
20049BTYBRU:9BT38@P01RDY8@PQ22487>LQ20<U:@8Q20049BTQ22DY8@P3
9BT28@P27>L28@P01RU:9BTU:B489BTQ208U:@03:DXU:BDY00<Q20049BTY
BRU:9BT4:DX29BT012U:;F/YBRU:22DY0bU:0RDY00HQ22DY9BTQ22DY8@P2
9BT01B48:DXYBRU:;F/00RU:00LU:BU:9BTQ22DY8@PU:@02:DX38@P031cW
9BTYBRU:9BTYBRe[<H`YBRDY8@PU:@<Q208U:@8Q20@U:@8Q20037>LQ22DY
008U:@068@PYBRe[;F/YBRDY12U:0be[00<aS2e[;F/012U:00PU:B48:DX]
Jc6<;F/YBRDY0RU:00<U:B488@P00b480RDY0R4800<U:BU::DX00bU:0Re[
00@YBRDY8@PU:@<YBP039BTYBS6<008aS007:DXU:BDY9BTYBRDY8@P00RDY
00<aS3F]=Jd00S6<00@YBRe[:DXYBP8]J`8YBP8U:@06;F/aS3W>>LhaS2e[
0S6<00<]JbU::DX00RU:0S6<0cF]00LaS3F]=JdaS2e[<H`e[@02?Nl023W>
;F/]Jbe[<H`e[C6<;F/2:DX02C6<;F/aS36<;F/YBRe[<H`icP03<H`01CF]
<H`]JbU:;F/00SF]00DicSF]<H`]JcF]008aS08]J`04<H`]Jc6<<H`2=Jd2
;F/3:DX01C6<=Jde[C6<:DX00be[00DaS3F]=Jde[C6<008e[@05<H`]Jc6<
<H`e[@04<H`3;F/013F]>LhicSF]0S6<00<e[CW>>Lh00SW>00@e[Be[;F/]
J`8e[@03<H`]Jc6<008]J`08<H`]Jc6<;F/aS2e[=JdaS0<e[@@aS08e[@<a
S08e[@8aS005;F/e[CW>>Lhmk`02>Lh00cg_>LhaS002<H`2=Jd2<H`013F]
;F/aS2e[0c6<00<e[C6<<H`00cF]00<aS2e[;F/00SF]0Be[000412400`00
12448@0312401P00248U:Dic>LhLi`@U:@8Li`8Q20049BTQ21cW7>L39BT0
1B487>LHaQcW8@P00RDY00@Q21cW7>LLi`@Q20039BTQ22DY00@Q20057>LQ
22489BTYBP029BT27>L28@P01bDY8@PQ22U:;F/YBRDY008HaP087>LQ22DY
7>LHaR48:DXU:@<Q2006:DX]JcF]<H`]JbU:0acW00@Q22DY9BTLi`8Q208L
i`038@PLib48008Li`8HaP055:DLib488@PU:@038@P01AcW8@PQ22DY8@P0
0acW0R4800<LiaS67>L00R480QcW0QS600@Q22DY:DXU:@8Q2005:DX]Jbe[
9BTQ20027>L38@P00bDY:DXU:@029BT00b489BTU:@028@P00bDY8@PU:@03
8@P01BDY8@PQ22489BT00R480bDY00LLib48:DXYBRDY8@PU:@03:DX012DY
8@PQ224812DY0b4800<Lib489BT012DY0bU:0RDY00<Q21cW8@P00b4800@U
:B489BTYBP<U:@<Q20037>LQ224800DU:@<Li`039BTYBRU:008Q20089BTQ
22DY;F/YBRDY7>LQ208U:@038@PLib48008Q20049BTQ22DY9BT58@P00bDY
:DXU:@037>L39BT01BU:9BTQ22489BT00RU:1BDY00<YBS6<<H`00RU:00<U
:BU::DX00RU:00<U:Be[;F/00S6<0bU:0RDY0R4800DU:BU:;F/YBRDY008Y
BP8U:@<Q2003:DXU:BU:008YBP03<H`]Jbe[008YBP<U:@<Q20@U:@048@PU
:BDY9BT3:DX29BT3:DX28@P012DY8@PU:B4822DY0b4800@U:BU:8@PYBP8]
J`08:DXU:BDY;F/YBRe[:DX]J`8e[@05;F/YBRDY:DX]J`02:DX00bDY:DXY
BP02;F/2:DX00be[9BTU:@049BT00b489BTU:@028@P01BDY;F/]JbU:;F/0
0RU:00X]JbU:9BTU:BU:;F/Q22DY:DXe[@8mk`04=JdaS2488@P29BT03BU:
9BTQ22489BTaS3F]>LhaS2e[:DX]JbU:008aS08]J`03:DXU:BDY008YBP<a
S003;F/YBRe[00@YBP8aS0@e[@HaS003=JdaS36<008]J`<aS005;F/YBRU:
9BT]J`03<H`2;F/3<H`2=Jd0236<;F/]Jc6<=JdaS3F]>Lh2?Nl2<H`2;F/9
<H`6;F/00c6<;F/aS004<H`00be[<H`aS003;F/00cF]<H`aS002=Jd013g_
@Q0e[C6<0RU:00TaS2e[=JdicSg_>Lhe[C6<=Jd013W>0Re[00<aS3W>>Lh0
1C6<00<]JbU:;F/01Be[0S6<1SF]00<aS3F]<H`00Re[1C6<00<e[C6<=Jd0
0SW>00E243g_>Lhe[Be[008e[@8aS006?NlicSF];F/U:Be[0S6<0SF]0c6<
00<icSF]<H`00S6<0CF]0BU:000212400`0012448@0612401@Q29BU:DSF]
8@P00bDY00@Q21cW8@PLi`<U:@<Li`<U:@8HaP8Li`8U:@038@PLiacW008L
i`8U:@<Q20037>LQ224800DQ20<YBP049BTLiacW7>L38@P01AcW9BTYBRU:
8@P00QS600@LibDY8@PHaP8Li`049BTYBRU:8@P29BT00bU:=JdaS002:DX0
1b487>LLiacW8@PLib4800<Li`048@PLiacW8@P37>L26<H01QcW8@PU:BDY
8@PLi`8Q20047>LQ22DY7>L26<H00acW9BTQ20067>L00b487>LHaP027>L3
9BT022489BT]Jc6<:DXLiaBU7>L38@P49BT01B489BTQ22489BT01B480RDY
1B4800TU:B489BTU:B487>LQ22DY:DX00R480RDY00<YBRDY8@P00R480bDY
00PQ22DY8@PQ21cW8@PU:B481RDY00@YBRDY8@PLi`HQ20DU:@<Q208Li`04
8@PU:B488@P27>L58@P29BT01BU:9BTQ22489BT00RU:00LU:AcW8@PQ22DY
8@PLi`028@P29BT38@P29BT38@P2:DX012487>LHaQcW0bU:00@U:B488@PU
:@8Q20<U:@038@PU:B48008]J`03<H`]JbDY00@YBP8U:@8]J`8e[@8YBP8Q
20<U:@04:DXU:BU:9BT2:DX29BT38@P29BT01R489BTYBRe[<H`]J`8YBP06
9BTYBRDY8@PLib480bDY00<Q22DY9BT00RU:0RDY0bU:0RDY00@YBR488@PQ
208U:@047>LQ22DY:DX59BT28@P011cW8@PYBRU:0RDY00@YBRe[:DXQ20@Y
BP8aS003=JdaS2U:008U:@03:DX]JbU:00<YBP039BTYBRU:00<YBP04;F/Y
BRDY9BT28@P29BT01BU:8@PU:BDY:DX00Re[0RDY00@YBRe[:DXYBP8U:@09
:DXU:BDY:DXe[D8@>Lhe[Be[008U:@8Q200:9BTQ22DY8@PU:Be[=JdicS6<
:DX2;F/00c6<;F/]J`05:DX00bDY;F/]J`03<H`00be[:DXYBP029BT00bU:
;F/e[@05=Jd2<H`2;F/3=Jd0136<;F/]Jbe[0S6<00PYBRe[9BTU:BU:;F/a
S2e[0RU:0S6<0SF]00TaS2e[<H`]Jc6<=JdaS3F]?Nl00SW>00<aS2e[<H`0
12e[00@aS2e[<H`aS0H]J`03<H`]Jbe[00<aS004=Jd]JbU:;F/2<H`2;F/2
<H`042e[<H`aS3W>@Q0icSF]<H`YBRe[<H`]Jc6<>LhmkcW>0S6<00De[Cg_
>Lhe[C6<008]J`03<H`e[CW>00<aS004=Jd]Jbe[:DX2;F/01c6<;F/]Jbe[
<H`e[C6<008e[@HaS08]J`@aS08e[@03<H`e[CF]008mk`03@Q0icS6<008a
S003=JdaS3F]008icP03<H`]JbU:00@aS003=JdaS36<008aS005=JdaS36<
=JdicP01;F/0000400048@@Q000212400`0012448@0212401PQ28@Q6<CF]
8@PU:@8YBP039BTQ21cW008Li`<Q20086<HU:BU:<H`YBR487>LHaP8Li`03
9BTQ224800<Li`HQ20<U:@038@PU:B4800<Q20059BTYBR488@PLi`058@P0
0bDY8@PLi`027>L012487>LLib480acW0R4812DY00H]Jc6<;F/YBQS67>L4
8@P27>L28@P01AcW8@PLiacW8@P00acW00LHaQcW7>LQ21cW8@PLi`038@P3
7>L00aS68@PQ20038@P37>L01B487>LLib487>L00R4812DY00@Q22DY9BTQ
208Li`046<HLib489BT28@P29BT01BU:9BTU:BDY7>L00R4800LU:B488@PL
ib48:DXU:@048@P00bU:9BTQ20058@P29BT00b48:DXYBP0;9BT01B487>LL
ibDY:DX00RDY00DQ22DY9BTQ22DY008Q20059BTQ22489BTQ2003:DX69BT0
0b489BTQ20028@P39BT58@P011cW8@PQ22480RDY1BU:0R4800<Lib489BT0
1R480RDY00HLib489BTYBRe[:DX38@P29BT01RU:9BTYBRU:9BTYBP8U:@08
:DXU:BDY9BTQ22DY:DX]J`8YBP8]J`03=JdaS2e[008]J`8aS003;F/aS2e[
008YBP038@PU:B4800DYBP039BTYBR48008U:@098@PU:B489BT]JbU:;F/Y
BRDY008YBP03;F/YBRDY008U:@038@PLiacW008Q2004:DXU:BU::DX29BT3
:DX29BT2:DX012DY8@PU:BU:0RDY0R480RU:0RDY00DQ22DY9BTQ22DY008Q
20049BTYBS6<<H`2:DX29BT01bU:8@PU:Be[=JdicS6<008YBP<]J`<YBP04
;F/U:BDY;F/3=Jd022e[<H`YBRU:9BTQ22DY:DX29BT01248:DXYBRe[0RU:
0bDY00@]JbU:9BTYBP<U:@04;F/e[CW>>Lh2<H`2:DX29BT01RU:9BTU:BDY
:DX]J`8YBP04;F/aS2e[=Jd2<H`8:DX2;F/0136<:DX]Jc6<0RU:0RDY0S6<
0SW>0SF]00@icS6<<H`]J`8aS003;F/YBS6<00<aS006;F/aS36<;F/YBRDY
0RU:0S6<0be[00`aS3W>=JdaS2U:;F/aS3F];F/YBRe[<H`5>Lh2=Jd5<H`0
1Re[<H`]Jbe[:DX]J`8aS003=JdaS3F]008icP8aS003=JdaS36<00<]J`8a
S005;F/YBS6<=Jdmk`02>Lh00cF];F/]J`02:DX022e[=JdicSF]<H`e[CW>
?Nl4>Lh013F]<H`]Jc6<0Re[00<aS3F]=Jd00S6<1Be[00<aS2e[<H`00S6<
00@e[CW>>Lhe[@8]J`05:DX]Jc6<<H`icP03=Jd3<H`013F]<H`icSF]0cW>
00<e[CW>=Jd01S6<00<]Jc6<;F/00SF]00<icSF]<H`00SF]00@icS6<<H`]
J`4U:@0000<48@0012400P@Q00D000@Q12448@0000848@048@Q6<C6<8@P3
:DX012DY8@PLiacW0R480acW0RDY0Re[00@Q21cW7>LHaP8Q20049BTLiaS6
7>L29BT28@P29BT38@P29BT98@P00acW8@PQ20038@P00bDY7>LHaP027>L2
8@P67>L02B489BTU:BDY:DX]Jc6<:DXU:@027>L38@P00acW8@PLi`027>L2
8@P47>L00b487>LHaP027>L012487>LHaQcW0R4811cW00DHaR488@PU:B48
008HaP<Li`088@PLiacW7>LU:B489BTYBP<U:@@Q20056<HDYAcW8@PU:@03
8@P39BT28@P012DY8@PU:BDY1B480RDY0b4800<U:B489BT00R480QcW00PU
:BU::DXU:B489BT]JbDY0R4800<U:BU:9BT00RDY0b4800<HaR488@P00RU:
1BDY00<Q22DY8@P00R480bDY00@Q22DY:DXYBPDU:@078@PLib488@PU:B48
9BT00R4811cW00DU:B489BTU:B48008U:@@YBP039BTQ22DY00@Q208Li`0:
8@PU:BDY9BTQ21cW9BTYBRe[:DX48@P2:DX29BT00bU:9BTU:@039BT2:DX0
1RDY8@PU:BU:9BTYBP8]J`8aS08]J`8YBP8]J`8aS08YBP8U:@058@PU:BU:
:DXU:@02:DX29BT012489BTQ22DY0R4800<U:BU:;F/01RU:0RDY0b4800<L
ib488@P00bDY12U:00@U:BU::DXYBPHU:@05:DXU:B487>LQ20059BT38@P2
9BT012489BTYBRe[0bU:00HU:B489BTQ22U:<H`2=Jd01Re[:DXYBRe[<H`]
J`8U:@8]J`08:DXU:BU:<H`icSF]<H`]J`DU:@8YBP<U:@<YBP8U:@8YBP03
9BTYBRDY008YBP068@PU:Be[=JdicS6<0Re[0RU:0RDY00@YBRDY:DXU:@8Y
BPD]J`09<H`e[Be[;F/U:BU:;F/YBRe[008YBP03;F/aS2e[008YBP8]J`03
:DXU:BDY008aS0@icP03<H`]JbU:008aS004;F/YBRU::DX4<H`2;F/00c6<
:DXYBP02:DX00be[=JdaS002;F/0136<>LhaS36<1Re[00<aS3F]>Lh00cW>
0SF]0S6<00D]Jc6<<H`]Jc6<00H]J`03=JdaS3F]00@e[@04<H`e[CF]<H`2
;F/2<H`01Be[:DX]Jc6<=Jd00Sg_01Te[C6<:DXYBRe[:DXaS3F]>Lhe[C6<
=JdicSg_>Lhe[CW>=JdaS2e[<H`]JbU:;F/aS002=Jd2;F/0136<;F/]JbU:
0Re[0c6<00Le[CW>>LhicSF]:DX]J`02:DX2<H`00cF]>Lhe[@03<H`00cF]
<H`aS004>Lh013F]>Lhe[CF]0S6<00<e[C6<<H`00S6<0Re[00<aS3F]=Jd0
0c6<00DicS6<<H`aS2U:004U:@000P@Q00<000@Q12401P@Q00L8@QcW@Q0e
[BDY;F/YBP029BT00b487>LLi`037>L28@P39BT00bU:8@PLi`027>L28@P5
7>L29BT28@P00acW9BTU:@049BT48@P39BT01B487>LQ22DY8@P00acW00<Q
21cW7>L00acW00<U:B488@P00acW0R4800LU:B488@PYBRe[=JdaS0029BT2
7>L01B487>LLib489BT00R480QcW0b4800<LiaS67>L00QS60QcW00<Q21cW
6<H00acW0aS600DQ21cW8@PQ22DY008Q208HaP037>LU:B48008Li`038@PU
:BDY00@Q208U:@038@PLiaS6008Li`<Q20079BTYBRU::DXU:B487>L01248
0acW0R4800<U:B487>L00R480RDY00<Q22DY8@P0124800@U:BU:9BTQ20<U
:@8Q20059BT]Jbe[;F/YBP048@P012U:9BTQ22480RDY00@Q22DY:DXU:@<Q
20049BTQ22DY:DX49BT00b489BTYBP029BT28@P00bDY8@PQ20028@P00acW
8@PLi`038@P29BT012U:9BTQ22480RDY0Re[00PYBRDY:DXU:B487>LQ22DY
0R4800HU:B487>LLib48:DX2;F/38@P00bDY:DXYBP04;F/69BT2:DX00bDY
8@PU:@02:DX00c6<;F/]J`03<H`00be[:DX]J`03:DX012DY:DXU:BU:0RDY
00HYBRe[;F/]JbDY8@P29BT02BU:9BTU:BDY:DXU:BU:;F/YBP039BT2:DX4
9BT48@P29BT2;F/012U:9BTQ22DY0RU:00H]Jc6<<H`aS2e[9BT28@P00acW
9BTQ20028@P39BT28@P02RDY:DXYBRDY:DX]JcF]<H`YBRe[0RDY0R480bU:
0Re[00HYBRe[;F/]JbU:;F/3:DX01RDY:DX]JcW>?Nle[@8icP8]J`038@PU
:BU:00DU:@8YBP@U:@8YBP068@PU:BDY;F/YBRDY0RU:12e[0S6<0Re[00<U
:B489BT00RU:00P]JbU:9BTYBRe[=JdicS6<0Re[00HYBRDY9BTU:BU:;F/5
:DX00be[<H`aS003:DX00cF]<H`]J`04=Jd2;F/00bU:<H`aS003;F/00c6<
=JdaS003<H`01Be[<H`aS2e[9BT00Re[00<e[C6<<H`00S6<00He[C6<=Jda
S2e[<H`2:DX00be[<H`e[@02<H`01CF]>LhicSF]<H`00SW>00@aS3F]=Jde
[@<aS006=JdicSF]=JdaS3F]0SW>00<aS3F]=Jd00SF]0Re[00@YBRe[<H`Y
BPD]J`07=JdicS6<;F/U:BU:<H`00SF]0S6<00<]Jc6<<H`01C6<0Re[1C6<
0cF]00@aS2e[:DX]J`8aS08]J`03<H`e[CW>008mk`07>Lhe[CF]:DX]JbU:
;F/00SF]0cW>0SF]0S6<00Le[CW>@Q0mkcW>=JdaS003=Jd2<H`00cF]<H`e
[@02;F/2<H`2>Lh00cF]<H`aS003=Jd1;F/18@P0000300048@@Q00848@03
00048@@Q00@48@047>Lmkbe[9BT2;F/01BU:8@PLiacW6<H011cW00DQ22DY
9BTYBRDY008Q20037>LHaQcW00<Li`066<HLib488@PU:AcW0b4800<U:B48
9BT012DY00<Lib488@P00RDY0b4800<U:B487>L01AcW00@Q21cW6<HLi`8Q
20<Li`078@PU:BDY9BTQ22U:;F/00S6<00DU:B487>LHaR48008Li`@Q20PL
i`@HaP047>LHaQS66<H87>L38@P00acW6<HLi`038@P27>L00b489BTU:@07
8@P26<H27>L01BDY8@PQ22DY:DX00RDY00<Q22DY7>L02R4800<Lib487>L0
0bDY00<Q21cW8@P00RDY00<Q21cW8@P01BDY12480Re[0RU:0QcW00<Q22DY
9BT012DY0R480RDY00@Q22DY9BTQ208U:@<YBP049BTQ22489BT2:DX00bDY
8@PLi`029BT28@P00acW8@PQ20037>L38@P29BT012489BTQ22DY0bU:00DQ
22DY9BTU:B48008Li`038@PU:B48008Q208Li`069BTYBRe[:DXQ21cW0R48
00<]JbU::DX00Re[00<YBRe[9BT00RDY00<Q22DY9BT00bDY00<Q22DY:DX0
0Re[136<0Re[00<YBRe[:DX00RDY00DYBRDY9BTQ22DY00@YBP049BTQ22DY
8@P29BT00bU:9BTU:@05:DX69BT00bU:9BTQ20027>L02B489BTU:C6<;F/Y
BRDY8@PU:@03;F/3<H`01be[9BTU:AcW8@PLib4800<U:@048@PU:B489BT3
:DX00bDY:DXYBP03;F/012U:9BTU:B480RDY00<YBRe[;F/00Re[00HU:Be[
<H`aS2e[9BT2:DX022489BT]JcF]?Nle[CW>=Jd2;F/01bDY8@PU:BDY:DXU
:B48008U:@048@PU:BDY9BT2:DX59BT2:DX022DY:DXYBRU:;F/YBS6<;F/2
<H`01BDY8@PQ22DY;F/00RU:0RDY00HaS3F]>LhaS2U:;F/2:DX29BT2:DX0
0be[:DXYBP02:DX022e[=JdaS2U:9BT]Jc6<;F/2<H`2>Lh00be[:DXYBP02
<H`2;F/00bU:<H`e[@02<H`01Re[<H`aS36<;F/aS0<YBP03;F/e[CF]00La
S08]J`8U:@03;F/aS3F]008aS003=JdicSF]008aS0<e[@03<H`e[C6<008]
J`06<H`icSF]=JdaS3F]0cW>00@e[C6<=Jde[@<]J`06<H`]JbU::DX]JbU:
0be[00<aS3F]<H`00bU:0SF]0S6<0Re[00DaS3F]=Jd]Jc6<008]J`05<H`]
Jbe[;F/e[@03<H`2=Jd01C6<:DXYBRU:;F/0136<00Te[CW>>LhmkcW>=Jda
S2e[:DX00Re[0cF]00PicSF]>Lhe[C6<;F/e[CW>0Sg_13F]00<icS6<<H`0
136<0Re[00@aS3F]=Jde[@<aS08e[@4aS04]J`4Q200000D48@0012448@00
00@48@0700048@Q26<I2436<9BT00be[00<U:B487>L00acW0b480acW0R48
11cW0QS600<Lib488@P00QcW00HHaR488@PYBRDY8@P29BT48@P4:DX68@P0
0acW8@PQ20028@P01QcW6<HLiacW8@PU:@8Q208Li`038@PU:BU:008U:@8Q
2004;F/aS2U:9BT27>L28@P29BT28@P37>L00b487>LLi`037>L01B487>LH
aQS67>L00QBU00HLibDY8@PLiaBU6<H57>L38@P37>L01B486<HLib489BT0
124800@U:B488@PQ20<Li`8U:@<Q20<U:@058@PU:BDY9BTQ20057>L01B48
9BTU:BDY8@P00RDY00<Q21cW8@P00R4800@Lib488@PU:@@Q20049BTYBRDY
9BT28@P012DY:DXYBRU:0bDY0R4800@LibDY8@PQ20@U:@048@PU:B489BT2
8@P012DY8@PU:BDY0RU:0R4800<YBRDY9BT00R480RDY00HQ22DY9BTLib48
7>L38@P2:DX29BT01B487>LQ21cW8@P00RDY12U:0bDY00<Lib488@P00R48
0QcW00<Q22U::DX00RDY00@HaQcW9BTYBP8]J`@YBP059BTQ22489BTQ2002
9BT01B489BTQ2248:DX00S6<0SW>0S6<00<YBRDY9BT00RU:00@U:B489BTY
BP8U:@DYBP039BTQ22DY008U:@048@PU:BDY9BT4:DX29BT3:DX39BT38@P2
9BT3:DX29BT02B489BTYBRDY;F/aS3F]<H`YBP029BT01B487>LQ22489BT0
0R480bU:0RDY00<]Jc6<<H`00S6<0Re[00HYBRe[9BTQ22DY8@P2:DX00bDY
8@PU:@06:DX29BT01bU:9BTYBRDY:DXaS3W>00924006<H`]Jb488@PYBRDY
0bU:12DY00<YBRDY9BT00RU:0RDY0RU:0RDY00<Q22DY9BT00RU:00<U:Be[
=Jd00SF]00HYBRDY9BTU:Be[:DX29BT02BU:;F/e[CF]<H`YBRe[:DXQ2002
9BT00be[:DXYBP04:DX022e[:DXaS36<;F/aS2e[:DX2;F/2<H`01CF]<H`]
JbU:;F/00S6<0Re[00@aS2U:<H`mk`924003>Lhe[C6<00H]J`<aS0<e[@03
<H`]Jbe[008]J`03:DX]Jc6<008aS08e[@<aS08icP8e[@04<H`e[CW>>Lh2
=Jd00cW>?NlicP02=Jd0136<=Jde[CF]0Re[0c6<00D]JbU:;F/]Jc6<008]
J`8YBP03;F/aS36<008aS003;F/aS36<00De[@8aS003=JdaS2U:008U:@07
:DXaS36<<H`]JbU:<H`00SW>00@e[Be[;F/]J`<aS003;F/aS3W>00<icP05
?NlicS6<;F/YBP02;F/2=Jd00cW>?NlicP02=Jd3;F/0136<>Lhmkcg_0SF]
00DaS3W>>LhicS6<00@e[@8aS0<e[@@aS08e[@4aS04Q20000P@Q00D000@Q
12448@0000D48@057>LicRU:9BTaS002;F/38@P26<H00acW8@PQ20027>L2
8@P00bDY7>LQ20027>L36<H27>L022487>LLiaS67>LQ22DY:DX29BT28@P0
0bDY8@PQ20029BT2:DX00acW8@PLi`078@P57>L48@P00acW6<HQ2002:DX0
12DY7>LQ22DY0S6<00DYBRDY7>LHaRDY008Q208U:@8Q20066<HLiacW8@PL
ib480QcW0QS60QcW0aS60QcW00@Q21cW6<HDY@@Li`038@PLib4800<Li`04
8@PLiacW7>L48@P29BT28@P00acW8@PQ20027>L38@P01BDY8@PU:BDY8@P0
0bDY00<Q21cW7>L011cW0R480RDY00<Q22DY9BT00R4800<Lib488@P01R48
00<Lib488@P00RU:00@U:AcW8@PU:@<YBP039BTYBRDY00@Q20039BTQ22DY
00<U:@048@PLib488@P29BT01B489BTU:BDY:DX012DY00HYBRDY8@PQ22DY
8@P39BT012487>LLiacW0R4812DY00HLib488@PQ22DY8@P29BT2:DX28@P2
9BT01B487>LLib486<H00QcW00@Q22U::DXQ20<Li`PYBP049BTQ22488@P3
9BT28@P29BT01bU:;F/aS3W>=JdaS2e[008YBP<U:@8YBP<U:@8YBP049BTY
BRU::DX39BT012U:9BTU:BDY0RU:32DY12480RDY0RU:00@U:B488@PU:@<Y
BP05;F/aS2e[;F/Q20027>L00b489BTQ20039BT2:DX39BT01BU:<H`aS36<
;F/012U:0RDY00HQ22DY:DXU:B489BT3:DX01Be[:DXYBRU:8@P00RDY12U:
0SF]00E243W><H`]Jb48008U:@8YBP@U:@07:DXU:BDY9BTYBRDY:DX00bDY
00DYBRDY8@PQ22DY00<YBP059BTaS36<>LhaS002:DX29BT3:DX29BT2<H`2
=Jd00be[:DXU:@028@P00bDY:DXYBP029BT00bU:;F/YBP02;F/00c6<;F/]
J`05;F/01S6<=JdaS2e[:DX]J`8aS08]J`8aS009;F/aS3W>@Q16<CW>;F/a
S2e[00<YBP<aS009;F/aS3F]>Lhe[C6<;F/aS2e[008YBP03;F/aS36<008e
[@04>LhaS36<<H`3>Lh2<H`2=Jd00cg_=Jde[@04>Lh2=Jd01C6<=JdaS3F]
<H`012e[00<YBRe[;F/00S6<0RU:00@]Jc6<<H`aS0<]J`8aS0<e[@8aS08e
[@8aS08YBP089BTYBS6<=JdaS2U:;F/aS08icP04=Jd]JbU:;F/2<H`2;F/0
136<=JdicSF]0Sg_0SF]0bU:00DaS3F]>Lhe[CW>00<e[@@aS006>LhmkcW>
=Jd]JcF]0SW>0cF]00@aS3F]<H`]J`HaS003=JdaS36<008aS04U:@0000D0
00@Q12448@0000D48@0:0008@R48>LhYBR48:DXaS2U:9BT48@P27>L02248
7>LQ21cW8@PLib486<H37>L36<H00b487>LLi`026<H27>L39BT38@P29BT2
8@P29BT00b489BTU:@029BT28@P012DY8@PQ22DY11cW00@HaQcW8@PU:@<L
i`8Q20059BTYBRDY9BTQ2003:DX00bDY7>LQ20028@P00bDY7>LQ20037>L2
6<H01QcW9BTQ21cW8@PLi`8HaP@Li`036<HLiaS600<Li`8HaP058@PLiacW
8@PU:@038@P012DY8@PQ224811cW0R4800<U:B488@P00QcW0bDY00<Q21cW
8@P00RU:00<Q21cW8@P00RDY1R480QcW0b4812DY0R480RDY124800@U:B48
8@PLi`8Q208YBP069BTQ22488@PU:B480RDY0RU:00@U:B488@PQ208U:@04
8@PU:BDY9BT38@P01bDY8@PU:BDY:DXQ21cW008Q20<U:@8YBP039BTQ2248
008U:@8Q20049BTLiacW9BT2:DX012DY8@PYBRe[0RDY0b480RDY00DQ22DY
9BTYBRe[008YBP078@PLib486<HLib489BT00RU:00@Q21S67>LLi`8U:@06
8@PYBRU::DXU:B480RDY00DQ22DY:DX]JbU:008U:@06:DXU:Be[;F/e[CW>
0SF]00<aS2U:9BT00RDY00@YBRDY9BTU:@@YBP03;F/YBRU:008U:@8YBP@U
:@8YBP8U:@8YBP8U:@8YBP8U:@03:DXU:B48008Q20<U:@06:DX]JbDY9BTQ
22DY0bU:0bDY00HYBRDY9BTLiaS67>L28@P00bDY8@PU:@049BT2:DX01Be[
:DX]JbDY8@P00RDY00@YBRDY9BTU:@<YBP069BTYBRDY8@PYBRe[0RU:0bDY
0RU:00@U:BU::DXaS08mk`03=JdaS2DY008YBPHU:@038@PU:BDY00<YBP<U
:@08:DXU:BDY9BTQ22DY8@PYBP8U:@07:DX]Jc6<=JdaS2e[9BT00bU:00H]
JbDY:DXYBRe[>Lh2?Nl00cW>:DXU:@029BT01RU:9BTYBS6<=Jd]J`8YBP03
;F/aS36<00<]J`8YBP05<H`e[C6<<H`YBP02;F/00bU:<H`aS002=Jd3;F/0
0cW>?Nlmk`02=Jd00cW>=JdaS002;F/3<H`3;F/2<H`6;F/012U:;F/]Jc6<
0SF]00<icS6<<H`0136<0cF]0Re[0S6<00<icSg_>Lh00SF]1C6<00Le[Be[
:DXYBRDY:DX]J`03<H`2;F/2<H`012e[<H`aS2e[0S6<00@e[C6<<H`e[@8a
S0@]J`06:DX]Jbe[<H`]Jc6<0Re[00@aS3F]=JdaS08YBP08;F/aS3F];F/a
S3F]?NlicP8e[@<icP03;F/aS36<008aS006;F/e[CW>>Lhe[CW>0S6<00T]
JbU:<H`aS3W>?NlicSF]<H`00cW>0cF]00/aS2e[<H`aS3W>=JdaS3F]<H`]
Jc6<008e[@4Q20000`@Q00<000@Q12401@@Q00P8@QcW>LhU:B48;F/aS2e[
0R4800DU:B487>LLib4800DLi`058@PLib487>LHaP037>L00b487>LLi`03
7>L00b487>LQ20039BT011cW8@PU:BDY1R480bDY00DQ21cW8@PQ22DY008Q
20@Li`8U:@067>LQ21cW6<HQ22DY0RU:00@U:B488@PU:@<YBP038@PLiacW
00<Q208Li`038@PLiaS600<Li`<Q20036<HLiacW008HaP<Li`046<HLiacW
7>L26<H37>L38@P02RDY8@PQ21cW8@PU:AcW8@PHaQcW0R4800@U:B488@PL
i`<Q20059BTYBRDY9BTQ20029BT38@P00bDY8@PQ20028@P011cW8@PLiacW
0R480RDY0b480bDY1R4800LU:B488@PU:B489BTYBP029BT38@P39BT01Be[
:DXU:B487>L00R481BDY0b4800@U:B488@PQ208U:@088@PLiacW8@PYBRDY
:DXU:@8Q20059BTQ22488@PU:@048@P00bDY:DXYBP029BT3:DX00b487>LQ
20059BT2:DX01Be[:DXQ21cW8@P011cW00<Q22DY9BT00acW00<Q22DY8@P0
0RDY00<YBRDY9BT01BDY0bU:0RDY00DYBRDY:DX]JcF]008icP03<H`]JbDY
008YBP@U:@03:DX]JbDY00DYBP<U:@038@PU:BDY00<YBP8U:@048@PU:BDY
9BT3:DX00bDY8@PU:@029BT28@P29BT4:DX29BT01b48:DXYBRU:9BTQ22DY
008YBP048@PLib487>L38@P49BT00b489BTYBP02:DX00be[:DXU:@028@P0
1RU:;F/U:B489BTYBP<U:@8YBP8U:@04:DX]JbDY9BT3:DX29BT00bU:;F/a
S002>Lh00c6<;F/U:@02:DX00bDY8@PU:@059BT4:DX28@P00bDY8@PU:@02
9BT28@P02BDY:DXYBRDY:DX]Jc6<=Jd]J`02:DX00bDY;F/]J`02:DX01BDY
:DX]JcW>@Q000SW>12DY0bU:0c6<0be[00<aS2e[:DX01Be[0S6<00@]JbU:
;F/]J`8aS007=JdaS36<<H`YBS6<>Lh00Sg_00He[C6<=JdaS2e[:DX2;F/3
<H`00be[<H`e[@02<H`01Be[:DX]Jc6<;F/00RU:00@]JcF]>LhicP8e[@04
;F/aS36<;F/4<H`01SF]<H`aS36<=Jdmk`8icP03=Jd]Jc6<00<e[@03<H`Y
BRU:008YBP06;F/aS2e[<H`]Jc6<12e[00<aS2e[;F/00S6<00HicSF]=Jda
S3F]<H`3;F/3:DX01Re[<H`aS2e[:DX]J`<aS004;F/YBRU:;F/2<H`2;F/0
0c6<>LhicP02=Jd00cW>=JdaS002;F/0136<;F/e[C6<0cF]00PicS6<<H`a
S2U:;F/aS3F]0cW>0cF]00HicS6<<H`aS3F]<H`2;F/4<H`00cF]<H`]J`03
<H`19BT0000300048@@Q00848@0300048@@Q00<48@0;248U:CW>:DXHaRU:
<H`]JbDY:DXU:@028@P02AcW6<HQ22DY8@PLiaS68@PLi`026<H00aBU6<HH
aP077>L011S67>LQ22480bDY00<Lib487>L00bDY00@Lib488@PQ20<U:@03
8@PLiacW00<U:@8Li`036<HQ224800@Q20<Li`049BTYBRe[:DX38@P012DY
8@PQ22DY2AcW00<HaQcW8@P00R480QcW00<HaQcW7>L00acW11S60R4800HL
iaS66<HHaR489BT38@P39BT48@P47>L28@P012DY8@PU:B480RDY0b480RDY
00DQ21cW7>LU:B48008Li`8Q20037>LQ21cW00<Li`DQ20HU:@038@PLiacW
00@Q20059BTQ22488@PU:@048@P00bDY8@PU:@039BT28@P29BT012489BTU
:BU:0RDY00<YBRe[:DX00R4800@U:AcW6<HLi`<Q20037>LQ22DY008U:@<Q
20<U:@068@PLib488@PYBRDY0RU:00<U:B488@P01R4800<U:B48;F/00c6<
00TU:AcW8@PLib489BTQ22DY8@P00acW00HQ22DY8@PQ22DY:DX28@P011cW
9BTU:BDY0RU:0Re[00<YBRe[:DX00RU:12e[00DYBRe[:DXYBR4800<U:@03
:DXU:BDY00HYBP04;F/YBRDY8@P29BT01bU:;F/YBRU:9BTQ22DY008Q208U
:@8YBP8U:@048@PU:BDY8@P39BT2;F/012U:8@PQ22480RDY00HYBR489BTU
:BU:9BT38@P00bDY8@PU:@079BT2:DX012DY8@PU:BU:0bDY0R4800/U:BU:
<H`]JbU:9BTYBRDY8@PYBRe[008aS0@YBP03;F/YBRe[008]J`0:=JdaS36<
;F/YBRe[:DXU:AcW9BT2:DX012DY8@PQ22DY0RU:00D]JbU:9BTQ22DY00<Y
BP8U:@8Q20049BTYBSF]=Jd2>Lh00be[:DXYBP04:DX29BT2:DX2=Jd01D8@
AS4mkcg_;F/00RU:00<]JcF]?Nl00Sg_00<e[C6<<H`00SF]00DaS2e[;F/Y
BRe[008aS004>Lhe[C6<<H`2:DX013F]?Nm243W>0Re[1C6<00@e[CW><H`a
S08YBP<aS08]J`<aS0@]J`03<H`]JbU:008YBP<aS003>Lhe[CW>00HaS003
=JdaS36<00@aS0<e[@03<H`]Jbe[008e[@03<H`]JbU:008aS005=Jd]Jc6<
;F/e[@02<H`2;F/01S6<=Jde[Be[:DXaS08e[@8]J`<aS008;F/YBRe[<H`e
[C6<:DX]J`<aS08]J`8aS08]J`8YBP03;F/aS36<008e[@05<H`e[Cg_?Nli
cP02<H`2=Jd0136<:DX]JcF]0S6<00@e[CW>=JdaS08]J`03<H`]JcF]00<i
cP05<H`icSW>>LhaS005;F/7<H`00be[=JdaS0018@P000848@0300048@00
00@48@0800048@Q27>LicRDY8@PYBP8]J`049BTYBRDY8@P27>L28@P00bDY
8@PLi`047>L00aS65:DHaP036<H57>L011S67>LQ22480RDY0R4800<Lib48
8@P00RDY0b480bDY00@Q21cW7>LQ208U:@058@PLiacW8@PLi`038@P00acW
8@PQ20038@P012U:;F/YBRDY124800<U:B488@P00QcW00@HaQcW8@PLi`@H
aP8Q208Li`8HaP@Li`8HaP035:DHaQcW00DLi`066<HLib488@PU:B480bDY
00@Lib488@PQ20<Li`038@PU:B48008Q208U:@DQ208U:@8Li`DQ20037>LQ
22DY00@Li`DQ20@U:@038@PU:B4800<Q20039BTQ224800<Q20039BTQ2248
00<Q208U:@8Q20039BTYBRU:00@U:@038@PU:BDY008Q200<9BTYBRU:9BTQ
22DY8@PLiaS67>LQ22DY124800@LibDY8@PU:@LQ2008:DXU:BDY8@PU:BU:
9BTLi`8Q208Li`8Q208U:@04;F/aS36<<H`28@P27>L28@P00bDY8@PQ2003
7>L012489BTQ22480RDY00DQ21cW8@PQ22e[00DYBP03;F/YBRU:00<YBP8]
J`06:DX]Jbe[:DXU:B480RDY00<YBRDY9BT00RDY00<YBRe[:DX012U:12DY
00@YBRe[;F/YBP@U:@038@PU:BU:008YBP8U:@8Q208U:@038@PU:BDY008]
J`8U:@038@PU:BDY008U:@8Q20059BTYBR487>LQ20029BT00b487>LQ2003
9BT28@P89BT28@P39BT4:DX29BT28@P01Be[<H`aS2e[9BT00bU:00L]JbU:
:DXYBRe[<H`e[@02;F/3:DX00b489BTU:@02:DX02bDY7>LQ22U:;F/aS2U:
9BTYBRDY8@P01BDY00@Q22DY:DXYBP<e[@03<H`YBRU:00@YBP@U:@03:DXi
cSW>0096<@8mk`05;F/YBRU:;F/e[@02?Nl01CW>=JdaS3F]<H`012e[0RU:
00@aS3F]>Lhe[@8aS009;F/YBSF]@Q0mkcF]:DX]JcF]008aS006;F/aS3W>
>Lhe[C6<0RU:0S6<0be[00@aS3F]<H`]J`8YBP03<H`]JbU:00<YBP8aS003
=JdicSW>008aS003;F/aS36<00XaS009=JdicS6<:DX]Jc6<=JdaS2U:00<]
J`04<H`]Jbe[;F/3<H`012e[<H`aS36<0Re[00@YBS6<>LhaS08]J`05<H`e
[C6<;F/YBP02;F/2<H`00be[:DXaS002;F/4<H`012U:;F/]JbU:136<0SF]
0SW>00A243W>;F/aS08e[@06;F/YBRU:<H`e[C6<0SF]0S6<00T]Jc6<;F/Y
BS6<>LhmkcW><H`013F]00<YBRe[;F/00be[0S6<00@]Jc6<;F/YBP<aS04U
:@0000<000@Q12400P@Q00<000@Q12400P@Q00T000Q29BTmkbe[6<HU:Be[
:DX00Re[00@U:B488@PLi`8Q208Li`036<HLiacW008Li`096<HLiacW5:DH
aQBU6<HLib48008Li`<HaP037>LQ224800@Q200=9BTQ21cW8@PLib487>LU
:Be[:DXU:AcW8@P00bDY00<Q21cW7>L00QcW00DQ21cW8@PQ22DY00@YBP<]
J`8Q208Li`048@PU:B488@P77>L00b487>LQ20028@P37>L01R487>LLiacW
8@PLi`<HaPDLi`038@PLib4800DQ208U:@038@PU:AcW008Li`8Q20037>LQ
21cW008Q20079BTQ22489BTYBRDY8@P00QcW0R4800<U:B488@P011cW00<Q
21cW7>L00b4800DLib489BTQ22DY00LQ20049BTQ22DY7>L38@P02QcW8@PU
:BDY8@PU:B48:DXU:BU:1BDY1B4800<U:B489BT00R480RDY0R4800lHaQcW
7>LQ22DY7>LQ21cW8@PLib489BTQ22DY8@P00QcW0R4800@YBRDY9BTQ20<U
:@038@PLiaS600@Li`038@PU:BDY00<YBP06<H`]Jb488@PLibDY0RU:0R48
0QcW0RDY0R4800HLib48:DXU:B487>L29BT2:DX022DY:DX]Jc6<;F/U:BU:
;F/2:DX29BT4:DX69BT28@P00bDY8@PU:@02;F/012U:9BTQ22DY1RU:0RDY
00<YBR488@P00R4800@YBRe[:DXYBP8U:@06:DXQ22488@PU:BU:0RDY0RU:
12DY0RU:00<Q22DY8@P00bU:00LQ22DY8@PQ22DY7>LQ2003:DX00bDY8@PQ
20059BT00bU:9BTQ20028@P3:DX2;F/01bU:9BTU:BU:<H`]JbU:00@]J`8Y
BP05;F/aS3W>>LhaS005:DX39BT2:DX01BDY8@PQ22DY;F/00S6<00X]JbDY
8@PU:BU:;F/YBRDY8@PU:@8YBP05>Lhmkcg_>LhYBP039BT01RU:9BTYBR48
9BTYBP<]J`05=JdicT8@AS4icP02;F/012DY<H`icSW>0SF]0S6<0SF]00<a
S2e[;F/00S6<0be[0S6<0bU:00<aS2e[=Jd00c6<00<]JbU:;F/00S6<0SW>
0S6<00<YBRe[;F/00Re[00DaS3F]=Jde[C6<00@]J`<YBPD]J`04<H`e[CF]
=Jd3<H`2=Jd00c6<:DX]J`02<H`00be[<H`aS003;F/2<H`01cF]<H`aS36<
;F/aS3F]008aS005;F/aS36<=JdaS002=Jd2>Lh01SF];F/aS36<>Lhe[@8a
S005=JdaS36<<H`]J`02<H`00cF]<H`aS002;F/01CF]>Lhe[C6<;F/00S6<
00HYBRDY9BTYBS6<=Jd2<H`013F]>LhicSF]1S6<0Re[0S6<00@e[CW>=Jda
S08YBP06<H`]Jbe[<H`e[Cg_0cW>00DmkcW>=Jde[C6<00<]J`03:DXaS36<
008aS08]J`03<H`e[C6<004U:@000`@Q00<000@Q12401@@Q00L8@R48?NlY
BR489BTYBP02;F/00bU:9BTQ20047>L00b487>LLi`027>L012487>LLiaS6
0QBU0aS60QcW0R4800@HaQBU6<HLi`PQ20039BTLiacW008Q208YBP049BTQ
22487>L29BT012487>LLiaS60acW00<U:B488@P00RU:00<U:BU::DX00Re[
00DYBR487>LHaR48008U:@8Li`056<HLiacW7>LHaP057>L38@P01AS67>LQ
21cW6<H00QcW00@HaQBU5:DHaP<Li`8Q20<Li`<Q20039BTQ224800<Q2003
7>LQ21cW00@Li`8Q20059BTQ22DY9BTYBP029BT28@P01AcW8@PU:BDY8@P0
0acW0R4800DLiaS67>LLibDY00@Q20<U:@058@PLib488@PU:@038@P00acW
8@PLi`028@P00bDY8@PQ20038@P01RDY8@PU:BDY:DX]J`@U:@<Q20039BTQ
2248008U:@04:DXU:B488@P27>L00aS68@PQ20028@P021cW8@PQ22487>LQ
22DY8@P27>L00b489BTQ20028@P01BDY:DXU:BDY8@P021cW00<U:BU::DX0
0RU:00H]JbU:9BTLib489BT2:DX29BT37>L012489BTQ22480RDY0R4800<L
ib489BT00RDY00<YBRe[<H`00be[00<U:BU::DX00bU:00<U:BU::DX00bU:
00DU:BU:9BTQ22DY008Q208U:@@]J`049BTQ2248:DX2;F/00bU:9BTU:@02
9BT28@P29BT2;F/00bU:9BTQ2002:DX00b487>LLi`02:DX29BT2:DX01RDY
8@PQ22489BTYBP8U:@058@PU:BDY:DXU:@028@P49BT01B489BTYBRU:9BT0
0b4800@YBR489BTYBP<U:@038@PU:BDY00@YBP039BTYBRe[008]J`03:DX]
Jbe[008]J`069BTYBS6<=JdicSF]0Re[0RU:00@]JbDY9BTU:@8YBP039BTQ
22DY008Q20<aS003;F/U:B48008U:@8YBP079BTQ22DY:DX]JcW>?Nl00SF]
0RDY12U:0RDY0bU:0Re[00HaS3W>?NlmkcF]<H`2:DX0136<=JdicSW>0c6<
00@e[C6<<H`aS0<]J`03:DX]Jc6<008aS005;F/U:BU:;F/aS002=Jd3<H`0
1BU:;F/]JcF]>Lh00c6<0Re[0RU:00<]Jc6<<H`0136<0Re[00<YBRe[:DX0
0Re[0RU:00<]Jc6<<H`00SF]136<00@e[C6<;F/]J`8aS003:DX]JbU:00<a
S004:DX]Jbe[;F/2<H`00be[<H`e[@02<H`00be[<H`]J`02<H`4=Jd01CW>
<H`aS2e[<H`00cF]00@aS2e[<H`aS0<]J`03=JdaS36<008]J`8e[@03>Lha
S36<008aS004;F/YBRDY9BT2<H`013F]<H`aS3F]0SW>00De[Be[;F/aS3W>
008aS004:DX]JcF]<H`3=Jd2;F/3:DX02Re[<H`e[CW>?NlicSg_=JdicSF]
0S6<0Re[00DYBRe[:DX]Jc6<00<]J`<aS04U:@0000D48@0012448@0000@4
8@0900048@Q27>M2436<8@PU:BU:00<]J`039BTQ2248008Li`038@PLib48
008Q208Li`8Q20<Li`<HaP@Li`<HaP035:DLiacW008Q20049BTQ22487>L2
8@P37>L39BT37>L01R489BTQ21cW8@PLi`@Q20039BTYBRe[008]J`<YBP8]
J`039BTLiacW00<Li`8Q20<Li`036<HLib48008U:@058@PLiacW8@PLi`02
8@P00acW8@PLi`037>L26<H011BU6<HHaQcW0R4811cW0RDY12480RDY00HQ
21cW7>LLibDY8@P37>L48@P01BDY:DXQ22487>L00R4800<U:B489BT00b48
11cW00<Q21cW8@P00QcW00LQ22DY8@PLib489BTYBP049BT00bU:9BTQ2002
7>L012489BTU:BDY0R4800<U:BU::DX00RU:0Re[0RU:00<U:B489BT00R48
0QcW0R480RDY00DQ22DY8@PLib4800<Li`8Q20059BTQ22488@PLi`028@P0
1BDY8@PQ22489BT00b4800<LibDY9BT00RU:0RDY0R480QcW1B480RDY00<Y
BRe[9BT00R4800DYBS6<<H`YBR48008Li`036<HQ2248008Q200:7>LU:BU:
9BTLiaS67>LU:Be[<H`3:DX00be[:DXYBP02;F/012U:;F/YBRU:0Re[00<a
S2U:9BT00RU:0bDY1BU:00<U:BU:9BT00RDY0RU:0RDY0RU:00<U:B488@P0
0RDY0R4800<U:Be[=Jd00Re[0R480bDY0QcW0R480bU:00@U:B489BTYBP<U
:@058@PYBRe[;F/YBP029BT28@P49BT38@P29BT012489BTQ22DY0bU:00<U
:AcW8@P012DY0RU:00D]JbDY:DXQ22DY008YBP039BTYBRU:008YBP06;F/a
S36<<H`YBRe[0RDY00HYBRe[;F/YBR489BT2:DX022DY8@PQ22U:;F/e[Cg_
;F/38@P2:DX29BT00b489BTU:@02;F/3:DX012DY:DXYBRe[0RU:0bDY0RU:
00<Q22U:;F/00SW>0c6<0RU:00@]Jc6<=Jde[@8]J`@aS08]J`04<H`]Jbe[
:DX2;F/00c6<:DXYBP02:DX01c6<>LhaS3F];F/YBRe[008aS005=JdaS36<
>LhaS002;F/2<H`4;F/2<H`013F]<H`]Jbe[136<0Re[00DaS2e[<H`aS3F]
008aS08]J`8aS004=JdicS6<;F/2:DX5;F/2=Jd3<H`01Re[<H`aS36<;F/a
S08]J`03<H`e[CF]008aS08e[@8aS0<e[@05<H`]Jc6<<H`e[@08<H`00cF]
<H`aS003<H`02SF];F/]JbU:9BT]Jc6<=JdaS2e[0S6<00<e[C6<<H`00S6<
00<]Jc6<<H`00S6<0Re[0S6<00Te[C6<;F/U:BU:<H`]JcW>=Jd00cW>00He
[CW>>LhmkcW>=Jd2<H`00be[9BT]J`03<H`01BU:;F/aS3F];F/00BU:0000
0`0012448@0212400`0012448@0412403R48?NlaS248:DX]JbU:;F/YBRDY
8@PLiaS67>L38@P37>L00b487>LLi`027>L01AS67>LDYAS67>L00R4800@L
iaBU6<HHaP@Li`8U:@@Q208Li`048@PU:BDY9BT27>L01AS67>LU:BDY8@P0
11cW124800@YBRe[;F/]J`<YBP04<H`YBR487>L26<H27>L38@P47>L39BT7
7>L01B487>LLiacW8@P00QS600@DYAS66<HHaP8Li`048@PLiacW7>L28@P2
9BT37>L00b489BTLi`037>L01B487>LHaQcW8@P00acW0bDY0R4800<U:B48
9BT01B4800HLiaS66<HHaQcW8@P27>L00b489BTU:@038@P39BT28@P00bDY
:DXU:@028@P89BT01248:DXYBRe[0bU:00<]JbDY9BT00R4800@U:B488@PL
i`8Q200<9BTQ22DY8@PU:AcW8@PHaQcW8@PLibDY0b4800DLiaS68@PQ22DY
00@Q20069BTQ22487>LQ22DY0RU:00<U:B488@P00QcW0R4800@U:B487>LL
i`8U:@<YBP8Q20049BT]Jbe[:DX28@P27>L00b489BTU:@038@P01RU:8@PL
iacW8@PU:@<YBP049BT]Jbe[;F/4:DX00be[:DXYBP03;F/3:DX39BT01BU:
9BTYBRDY:DX00bDY0RU:1RDY00<YBRDY9BT00RDY0R4800HU:B48<H`e[C6<
:DX28@P012DY8@PQ21cW0b4800<YBRe[:DX00bDY00@YBRDY9BTQ20@YBP8U
:@038@PU:BU:00<U:@038@PU:BDY008U:@DQ20<YBP<Q20049BTQ22489BT2
:DX79BT2:DX39BT02Be[<H`aS2e[:DX]JbU:9BTYBP02;F/01BU:8@PU:BU:
9BT00b4800lYBRe[>Lhe[BU:9BTQ22DY;F/YBRDY7>LQ22DY:DX00Re[0bU:
00DU:BU:;F/]JbU:00@U:@03:DXU:BDY008]J`04=JdicS6<<H`3:DX00be[
<H`aS003;F/01C6<=JdaS36<;F/00S6<00@]JbU::DXYBP8aS005;F/U:BU:
:DXe[@02<H`2;F/00bU:;F/aS002<H`01be[<H`aS36<;F/YBRe[008aS003
;F/YBRe[00DaS08]J`8aS0@]J`03<H`]Jbe[008aS0<]J`04<H`e[CF]=Jd2
;F/2:DX00be[:DX]J`03<H`2=Jd00be[:DXaS002<H`5;F/2<H`2=Jd00c6<
=JdaS003<H`00cF]<H`aS002;F/2<H`01CF];F/aS36<=Jd00c6<00HicS6<
<H`]Jc6<=Jd2<H`02Re[:DXU:Be[<H`e[C6<;F/aS3W>0S6<0be[1S6<00D]
Jc6<=JdaS2e[008YBP<]J`8e[@8mk`8icP8e[@8icP03=Jd]Jc6<008YBP8]
J`8aS08]J`<aS04YBP000P@Q00<000@Q12401P@Q00D8@QcWAS4e[BDY00@Y
BP06;F/YBR488@PHaR480QcW00DQ22DY8@PQ21S6008Q20<Li`038@PLiaS6
008Li`048@PLiaS66<H27>L00b487>LU:@028@P00bDY8@PLi`037>L01B48
6<HLib489BT00acW00<U:B488@P00R480RU:0RDY0R480bU:00<]Jc6<:DX0
0RDY00<YBRDY8@P011cW0R4800<LiaS66<H00R480RU:0RDY0b480QcW0R48
00@U:B487>LQ20<Li`035:DHaQBU00<Li`8Q20037>LQ22DY00<Q20037>LQ
2248008Q20047>LQ22489BT28@P37>L011S67>LQ22480QcW0b480QcW0b48
11cW124811cW00LQ21cW8@PYBS6<;F/U:@058@P00bDY8@PU:@029BT38@P3
:DX29BT02RU:;F/]JbU:;F/YBRDY8@PLibDY0R4800@Lib489BTU:@@Q20DL
i`8Q20039BTQ224800TQ20059BTLib487>LQ20029BT2:DX00bDY7>LLi`02
7>L00bDY8@PU:@028@P39BT012487>LQ22480Re[00@U:B488@PLi`8Q208L
i`038@PU:BDY00DQ2003:DXU:BDY00/YBP0@9BTaS36<=JdaS2U:9BTQ22DY
:DXU:BU:9BTYBRDY:DX49BT012489BTQ22481BDY00@Q22DY:DX]J`8U:@06
:DX]Jc6<<H`U:B4812DY00<Q22DY9BT00RDY0RU:0RDY1bU:0RDY00DYBRe[
;F/U:B48008U:@<Q20039BTYBRDY008Q208U:@04:DX]JbU:;F/58@P29BT4
:DX01RDY8@PQ22489BTQ208U:@04:DXU:BDY:DX2;F/00bU:9BTU:@02:DX0
1Be[:DXYBRDY:DX00RDY0R4800@YBRDY;F/aS08]J`8U:@048@PU:BDY9BT2
8@P00bDY:DXU:@0<:DX00bDY:DXYBP02:DX01Be[:DX]Jc6<;F/00bU:00@]
Jc6<<H`]J`<YBP0<;F/aS2e[;F/YBRe[<H`YBRDY:DXaS2e[0RDY00<]JcF]
=Jd00c6<0Re[00@YBRe[<H`e[@8icP8aS005;F/YBRe[9BTYBP02;F/2<H`0
1Be[<H`]Jc6<=Jd00c6<0RU:00<]JbU:;F/01C6<00<]Jc6<;F/012e[00@a
S3F]=Jde[@<]J`8aS08e[@07<H`]Jc6<;F/aS3F]<H`00be[00@aS3W>=Jde
[@TaS08]J`8aS004=JdaS2e[<H`3=Jd4;F/2<H`022e[<H`e[C6<:DXU:BU:
=Jd2<H`5;F/01C6<;F/]Jbe[=Jd00S6<00<]Jc6<<H`00S6<12e[136<0SW>
00<mkcW>>Lh00cW>00@aS3F]=JdaS0<]J`03=JdaS36<00@aS04U:@0000D4
8@0012448@0000D48@080008@QcW@Q0aS2DY:DX]J`8U:@03:DX]JbDY008L
i`8Q20047>LQ22488@P37>L28@P00aS67>LQ20027>L26<H01QcW8@PHaQS6
5:DHaP8Q20037>LQ22DY008Q20<Li`068@PLiacW7>LQ22DY0QcW00<Q22DY
9BT00b480RU:00DU:B488@PU:BU:008]J`DYBP<U:@037>LHaQcW00DLi`04
8@PLib488@P2:DX00bDY8@PQ20037>L58@P37>L26<H01ABU6<HHaQcW8@P0
0QcW0R480RDY00@Q21cW7>LLi`<Q208Li`@Q20047>LQ21cW6<H27>L38@P3
7>L68@P57>L00b487>LQ20027>L28@P00bDY8@PYBP02:DX00bDY8@PQ2002
8@P012DY8@PQ22480bDY0R4800@U:BU::DXQ208U:@8aS0<YBP038@PLiacW
008U:@PQ200;7>LQ21cW7>LHaQcW8@PU:B489BTLi`058@P012DY8@PQ2248
0QcW0R4800<Lib489BT00bDY11cW00@Q22DY8@PQ20@U:@8Li`038@PYBRU:
008YBP068@PLiacW7>LQ21cW0R4800<U:B488@P00QcW00<Q22DY9BT00bDY
00<]JbU::DX00RU:0RDY00PYBRe[:DXYBRe[<H`e[C6<0RU:00@U:B489BTU
:@@YBPHU:@048@PU:BDY8@P39BT00b489BTYBP049BT2;F/00c6<;F/U:@02
9BT00b489BTQ20028@P00bDY:DXYBP02:DX39BT01RU:;F/YBRU:9BTYBP8U
:@@YBP038@PU:B4800<Q200?9BTYBRDY8@PLib489BTaS2e[:DXU:B487>LQ
21cW00<Q208YBP03;F/U:B4800<U:@8Q20DU:@@YBP068@PU:BU::DX]JbU:
0RDY00DYBRDY9BTQ22DY008YBP<]J`04:DXU:B488@P29BT28@P29BT2:DX0
12DY:DXU:BDY0RU:00<]JbU::DX00RU:0RDY1BU:0be[0RU:00<U:BU::DX0
0S6<0Re[0RU:0Re[00<aS2e[;F/00Re[00DYBRDY;F/aS2U:008U:@04;F/e
[CF]<H`4;F/012U:;F/aS36<0SW>0S6<00@]JbU::DXYBP8]J`03<H`]Jc6<
008]J`<aS00>=JdaS2e[;F/YBRe[:DX]Jc6<=JdaS2e[:DXaS0@]J`05<H`]
Jc6<<H`e[@02<H`2;F/3<H`01SF];F/aS2e[<H`e[@8aS0@]J`04<H`e[CF]
=Jd2<H`013F]<H`aS3F]0S6<12e[1S6<00<e[C6<;F/00Re[1S6<0bU:00<]
Jc6<<H`00be[00DaS3F]<H`aS2U:008aS006=Jd]Jbe[;F/e[C6<0Re[00<Y
BRe[<H`0136<00PicT8@?NlicS6<=JdmkcW>13F]00<aS2e[;F/00S6<00De
[C6<;F/aS2e[004YBP0000<000@Q12400`@Q00<000@Q12400`@Q00@LicW>
;F/Q20<YBP<]J`08:DXU:AS67>LQ22DY:DXU:@8Q20<Li`096<HLib48:DXU
:AcW6<HLib4800@Li`046<HQ22DY:DX29BT37>L38@P26<H011cW8@PU:B48
0QcW00LU:B487>LQ22DY:DX]J`029BT27>L01bDY:DX]JbU:9BTLib4800@U
:@8Li`046<HQ22DY8@P27>L00b487>LQ20029BT01RU:;F/U:BDY8@PLi`8Q
208U:@@Q20DLi`<Q20047>LQ22488@P29BT00b489BTLi`037>L28@P00acW
8@PU:@029BT011cW6<HLib480RDY11cW00<Q21cW8@P01R4811cW00<HaQcW
7>L01B481RDY0b4800<U:B489BT02BDY0Re[00<YBR488@P00bU:224800<U
:B488@P012480QcW00<Q21cW8@P00R4800@Lib488@PU:@hQ20<U:@078@PU
:AcW7>LQ22U:9BT00R480RDY00<LiaS66<H00R4800@U:Be[;F/Q208Li`05
9BTYBR488@PLi`038@P011S67>LHaR480RDY1RU:0RDY0RU:00<aS2e[;F/0
0RU:0Re[0S6<0RU:00<U:B48:DX00RU:00<]JbDY:DX00RU:0RDY00<YBRDY
8@P00RDY00@YBRDY9BTQ208U:@078@PYBRDY:DX]JbDY:DX01RDY00<Q22DY
9BT00bU:00<aS2e[;F/00RU:00@]JbU:9BTU:@8YBP038@PU:BU:008YBP8Q
20039BTQ22DY00@U:@038@PU:BDY008U:@04:DXU:BU:9BT28@P01AcW8@PQ
22489BT01RU:0RDY00DQ22DY9BTU:B48008U:@@YBP039BTYBRU:008]J`04
:DXU:BDY8@P59BT012U:;F/]Jc6<0RU:00XU:B489BTU:B489BTQ22U:9BT]
J`8YBP04;F/YBRDY9BT4:DX39BT012U:9BTU:BDY0be[00@YBRDY9BTU:@8]
J`07:DXaS3W>=JdYBRDY:DX00S6<00@]JbU:;F/U:@8YBP03;F/aS2U:008]
J`03<H`]Jbe[008e[@8aS08]J`8aS08e[@8icP07<H`]JbU::DX]JbU:;F/0
0c6<0Re[0S6<00<e[Be[;F/00RU:00H]Jc6<<H`]Jc6<;F/2<H`012e[<H`a
S3F]0Re[136<0Re[1C6<0SF]00@]Jc6<<H`aS08]J`05:DX]Jbe[<H`]J`05
<H`2;F/2<H`00cF]<H`aS003<H`3;F/3<H`00be[<H`aS002<H`2;F/01BU:
=JdicSF]<H`00RU:0c6<0be[00DaS2e[;F/]Jc6<008e[@<]J`8e[@06;F/Y
BRU:<H`icSF]0be[00<aS3F]>Lh00SW>0SF]00LicSF]<H`aS3F]<H`e[@03
;F/5<H`1;F/19BT000<48@0300048@0000<48@0700048@Q27>LmkbU:7>L0
0bU:00@U:Be[:DXU:@DQ208U:@8Q200;6<HLiacW5:DLib48:DXU:AcW5:DH
aP027>L00b487>LLi`027>L012489BTU:B481QcW0QS600DLibDY9BTQ21cW
00HQ208YBP059BTQ22488@PU:@04:DX38@P00bDY:DXYBP037>L012489BTU
:AcW0QS60QcW0RDY00dYBRe[9BTU:AcW6<HLib48:DXU:B487>LQ20027>L0
0aS67>LLi`027>L38@P27>L29BT28@P47>L28@P00acW8@PQ20039BT37>L0
0b489BTQ20047>L58@P00acW8@PLi`027>L01AS67>LLib486<H00QcW0RDY
0b480RDY00@Q22DY8@PU:@8Q20057>LQ22488@PYBP029BT012489BTU:B48
0RU:00@]JbU:9BTU:@<YBP@Q20049BTQ22489BT38@P01QcW8@PLib487>LQ
208Li`<Q208Li`<Q20077>LQ22488@PLib487>L00R4811cW0RDY00<Q22DY
8@P00QcW00HQ22U:9BTQ21cW8@P29BT01acW6<HLibDY:DX]JbU:00<Li`03
8@PU:BDY00<Q20<Li`046<HLib48:DX29BT01RU:9BTU:BDY:DX]J`8YBP03
;F/aS2e[00<YBP8aS003;F/aS2U:00<U:@08:DXU:BU::DX]JbU:9BTQ20TU
:@<Q20@U:@8YBP08;F/YBRDY8@PU:B48:DXQ20<U:@05:DXU:Be[;F/aS002
:DX2;F/2:DX01B489BTU:B489BT00RU:00<U:B489BT00RDY0R4812DY0R48
00LLibDY:DXYBRDY8@PU:@028@P011cW8@PQ22DY0bU:00<U:BU:9BT00RU:
0RDY0R4800<U:B48:DX00RU:00DU:BU::DXYBRe[00<YBP069BTQ22DY:DXU
:BU:0R480RU:00<aS2e[:DX00RDY0b4800@U:B489BTU:@`YBPDU:@038@PU
:BU:008]J`DU:@8YBP06=JdicS6<;F/U:BU:0S6<00<]JbU:;F/00RDY12e[
0RU:0c6<0SF]00@aS2e[:DX]J`8aS0<e[@0;>Lhe[Be[9BTYBS6<:DX]Jc6<
=JdaS002;F/00c6<=JdaS003;F/3:DX2<H`3;F/01C6<;F/]JcF]<H`00Re[
00<aS3F]=Jd012e[1c6<0Re[00<aS2e[:DX00RU:136<0Re[0c6<00<]Jc6<
<H`00c6<00<]Jc6<;F/00be[00<aS2e[<H`00Re[0c6<00D]JbU:;F/aS3W>
008aS08YBP04;F/aS36<<H`3;F/00bU:;F/]J`02<H`00cF]<H`]J`02;F/0
1CF];F/]Jbe[<H`00SF]00@aS2U::DXaS08icP8e[@04<H`e[CF]=Jd5<H`2
;F/4<H`3;F/18@P0000300048@0000T48@066<HaS2U:7>LYBRe[0RU:00<U
:BU::DX00RU:1B480QcW00<Q21cW7>L00QcW0R4800@HaQcW6<HLi`<Q2003
9BTQ21cW008HaP048@PU:BDY8@P57>L012487>LLiacW0b480RDY00PLiaS6
7>LQ22U:9BTQ22DY1B480RU:00@U:AcW6<HQ208YBP049BTLiacW7>L39BT2
7>L00aBU7>LQ20029BT38@P01QcW6<HLib48:DXU:@XQ20049BTQ22489BT3
:DX00bDY7>LQ20038@P27>L28@P01AcW8@PYBRU:9BT00QcW00<Q22DY9BT0
12480acW0b481AcW00@HaQcW7>LQ20<Li`@Q20037>LQ22DY008U:@037>LQ
22DY008YBP079BTQ21cW8@PU:BU:9BT00R4800LU:B489BTQ22DY8@PU:@07
8@P29BT28@P29BT58@P00acW8@PQ20078@P011cW8@PQ22480RDY0b4800DU
:B487>LLib4800<U:@068@PU:BDY8@PU:BU:0RDY00PLib487>LHaQcW6<HL
ib480RDY0R4800<LibDY8@P00R4800<Lib488@P00RDY0QcW00<HaQcW:DX0
0Re[00<U:B489BT012U:0be[12U:00<]JbU:;F/012U:12DY0RU:00@]JbU:
:DXYBP8U:@038@PU:BDY008U:@8Q208U:@8Q20047>LU:BU::DX3;F/2:DX2
8@P29BT2:DX29BT012U:;F/aS3F]0Re[0RDY0RU:00<U:B489BT01bDY0R48
00DU:BU::DXQ22DY00<YBP8Q208U:@04:DXQ22487>L39BT01R487>LYBS6<
=Jd]J`8U:@<YBP8U:@038@PU:BDY008YBP8U:@0<:DX]JbU:;F/aS3F]:DXU
:B489BTYBRDY0R4800<U:BU:<H`00S6<0Re[00<U:BU:9BT00RDY00@Q22DY
8@PU:@8YBP8U:@048@PU:BU::DX49BT4:DX39BT4:DX012DY:DX]JbU:0cF]
00<]Jb489BT01BU:0be[00<YBRe[<H`00S6<00<YBRe[<H`00S6<00@]Jc6<
<H`aS08e[@04<H`]Jc6<=Jd2<H`00bU:9BT]J`02;F/3<H`012e[<H`aS36<
12e[0RU:1Re[00DaS3F]=JdaS2U:00@]J`03:DX]Jbe[008aS08]J`8aS007
;F/aS36<>LhaS2e[:DX00Re[1C6<00<e[C6<<H`02S6<0be[12U:0cF]00<a
S2U:;F/00c6<0be[0RU:00<]JbU:<H`00SF]00@aS2e[:DXYBP8aS08e[@03
<H`e[Be[008]J`8YBP04<H`e[CW><H`2;F/2<H`5=Jd00c6<;F/]J`02<H`0
1Be[<H`aS3F]<H`00Re[0c6<0CF]0Be[0AcW000612402P0012448@@Q0008
@QS6=JdU:B480bU:0RDY0bU:0RDY0b480QcW00<Q21cW7>L00QcW00DQ21cW
7>LLiaS6008Li`8Q200:9BTYBR487>LHaQcW8@PU:B487>L26<H28@P01AcW
6<HLib487>L00R4800<U:B488@P00acW00<Q22U:9BT00RDY0R4800<U:B48
8@P00RU:00@U:AcW8@PU:@8YBP088@PLiacW7>LU:BU:9BTQ208Li`038@PU
:B48008Q20@Li`058@PYBRDY9BTQ20027>L38@P27>L00b489BTQ20028@P4
:DX28@P011cW8@PQ22480QcW00HHaR487>LQ22DY:DX28@P01AcW8@PU:B48
9BT00b4800@U:B487>LLi`<Q20037>LQ21cW008HaP8Li`8Q20<Li`LQ2003
9BTQ224800<YBP049BTHaR488@P3:DX38@P39BT00acW8@PQ20038@P29BT0
0acW8@PQ20039BT78@P00bDY8@PLi`027>L28@P47>L00bDY8@PU:@029BT0
1B487>LQ22489BT00R4800<LibDY8@P00bDY00<Q22DY:DX00RDY0R480QcW
11S600LU:BU::DXU:AS67>LQ20029BT28@P011cW8@PU:BDY0QcW00<HaQcW
;F/00Re[00XYBR489BTYBRDY:DX]Jc6<;F/U:@<YBP03;F/YBRe[008YBPHU
:@<YBP069BTYBRDY:DXU:B480RDY00<YBRDY8@P00b4800DU:B488@PU:B48
00<YBP04;F/YBRU:9BT38@P3:DX022DY8@P]Jbe[=JdaS2e[9BT3:DX29BT2
8@P00bDY8@PU:@029BT01BU:9BTQ22489BT00RU:00@U:B489BTYBP8U:@06
8@PU:BU::DXU:AcW0R480RDY0R4800DYBSF]<H`]Jb4800@YBP049BTQ22DY
9BT2:DX032DY:DXU:BDY:DX]Jc6<=Jd]JbU:9BTQ20<U:@8Q20049BTYBS6<
=Jd2;F/00bU:9BTYBP029BT00b489BTU:@049BT01BU:9BTQ22DY8@P00bU:
0RDY0RU:00H]JbU:9BTQ22DY:DX2;F/29BT01bU:;F/YBS6<>LhaS2e[008U
:@DYBP8]J`8YBP06;F/aS36<;F/YBRe[0c6<00D]Jc6<<H`aS3F]00<aS008
=JdaS36<;F/YBRDY:DX]J`8aS003=Jd]Jbe[00@aS003:DX]Jbe[00DYBP<]
J`03<H`e[CF]008aS0L]J`8aS003;F/aS36<00@aS08e[@04<H`YBRU::DX2
<H`01Be[<H`e[CF]<H`00Re[136<00@e[C6<<H`aS0<]J`04:DXU:BU::DX2
<H`013F]<H`aS2U:0be[0S6<00@]JbU::DXYBP<]J`04<H`e[C6<;F/2:DX2
<H`3=Jd2<H`2;F/012U:;F/aS3F]0S6<0RU:0S6<0SW>0c6<00@]Jc6<;F/e
[@8aS004;F/aS2e[<H`3;F/0136<=JdaS2e[0AcW0000100012448@0020@Q
00XHaSF]9BTLibU:;F/U:B489BT]J`8YBP059BTYBRU:9BTLi`028@P00acW
8@PLi`027>L38@P011cW6<HLiacW0R4800<Lib488@P01AcW0R481acW00<Q
21cW7>L0124800@LiaS67>LHaP8Q208U:@<Q20@U:@@Q208U:@8Q20076<HQ
22489BTQ21cW8@P021cW0R4800DU:B489BTU:BU:008U:@067>LQ22DY8@PU
:B4812DY0b4800PU:BU:9BTU:AS67>LHaQcW0b480bDY00<YBR488@P01248
0QcW00@Q22DY9BTQ208Li`049BTQ21cW8@P27>L00b487>LLi`048@P27>L0
1B489BTU:B487>L012DY0R4800@U:B488@PQ20<Li`8Q20039BTQ2248008Q
20039BTQ2248008Q20077>LQ22DY8@PLib489BT00RU:0RDY0R4800<U:B48
8@P01b480RDY124812DY124800HU:BU:8@PQ21cW8@P29BT2:DX29BT03RU:
9BTQ21cW8@PLiaBU6<HDYB489BTYBRDY8@P27>L28@P59BT28@P01AcW8@PQ
21cW9BT012U:00@]Jc6<;F/YBP8]J`@YBP03;F/YBRDY008Q2003:DX]JbU:
00DYBP8U:@<YBP04;F/U:BDY9BT2:DX012489BTU:BU:0RDY00<Q22DY8@P0
0R4800@U:Be[;F/YBPHU:@DYBP<]J`8YBP@U:@06:DXU:B487>LQ22U:0RDY
00@Q22DY9BTYBP8U:@8Li`069BTYBRU:9BTQ22DY0bU:0RDY1R480RU:00<]
Jc6<;F/00RU:00DU:BU:;F/aS2e[008U:@8YBP8U:@03:DX]JbU:00<YBP<U
:@038@PU:BDY008Q208U:@09<H`icSg_?Nle[BU:9BTQ22DY008YBP8Q2006
9BTYBRe[:DXLib4812DY00@Q22DY:DX]J`8YBP8]J`8U:@08:DX]Jbe[:DXU
:B48:DX]J`8aS003:DX]JbU:008YBP049BTYBRU:<H`2;F/01C6<;F/]JbU:
9BT00RU:1Re[00<aS3F]<H`00be[00@aS3F]<H`]J`8YBP@]J`03<H`icSF]
008e[@@]J`05:DX]JbU::DX]J`02:DX3<H`5;F/00c6<;F/]J`04;F/00c6<
;F/aS003<H`4;F/00c6<;F/]J`05<H`00cW>=Jde[@02=Jd5<H`01SW>=Jdi
cSF]<H`]J`8YBP@]J`03<H`]Jbe[00D]J`8YBP8]J`04:DXU:BDY:DX2<H`0
12e[:DXYBRU:0SF]00HaS2e[<H`e[CW>=Jd2;F/3<H`2;F/3<H`2;F/013F]
>Lhe[C6<0Re[0S6<00@e[C6<<H`]J`8aS0@]J`03<H`e[Be[004Q200000<4
8@0012400P@Q00<000@Q124010@Q00LHaS6<:DXQ22e[:DXQ20029BT5:DX0
0bDY8@PLi`047>L01R487>LLiaS67>LQ20<Li`8Q20037>LU:B4800<Li`03
6<HLib48008Q20037>LHaQcW00HLi`8Q20<Li`<HaP037>LQ224800@Q2005
9BTQ22DY:DXU:@028@P27>L2:DX012DY7>LHaQS60R4800@U:B487>LHaP@L
i`056<HLiacW8@PU:@048@P2:DX00bDY8@PQ20027>L00b489BTU:@029BT2
8@P011cW8@PU:BDY0R481AcW0b4800DU:BU:9BTU:B4800<Li`048@PLiacW
7>L29BT02B487>LLiacW8@PLib489BTQ20057>L012487>LLiacW1R480RDY
00LQ21cW8@PQ22DY8@PLi`058@P01AcW8@PQ22489BT00R4800<Lib487>L0
1R481BDY00<Q21cW8@P00R4800DU:B488@PQ21cW008Q208U:@8Q20037>LQ
22DY00<Q20039BTQ224800LQ20049BTYBRU::DX29BT00bU:9BTQ20037>L2
5:D00aS69BTYBP028@P37>L28@P59BT00b487>LLi`027>L00b489BTU:@03
:DX3;F/3:DX01RDY:DXYBRe[:DX]J`8Q208U:@8YBP8U:@03:DXU:BU:00<U
:@03:DX]JbU:00LU:@8Q20039BTQ2248008Q20037>LU:BDY008]J`8YBP06
9BTQ22DY9BTQ22U:0Re[00<YBRDY:DX00RU:0RDY00<YBRDY9BT00bDY0R48
22DY124812DY0R4800@U:BU::DXU:@8Li`8U:@038@PLib48008U:@03<H`]
Jbe[008YBP8U:@03;F/aS2U:008U:@8YBP8U:@03:DXU:BU:00<YBP8U:@03
7>LQ22DY008U:@<Q2009<H`icSg_@Q0e[BU:9BTLib4800<U:@058@PU:Be[
;F/U:@028@P39BT28@P00bDY:DXYBP029BT2:DX28@P01RU:;F/]JbU:8@PU
:@8YBP03<H`]Jbe[008YBP059BTYBRU::DX]J`02<H`2;F/00c6<:DX]J`02
9BT2:DX01C6<;F/]JbU:;F/01C6<00<]Jc6<<H`00S6<0bU:00@U:Be[<H`a
S08e[@03<H`]Jbe[00@]J`@YBP<]J`<aS003:DX]Jbe[00@]J`0::DX]Jbe[
<H`]JbU:<H`icSF]<H`2:DX01c6<;F/]JbU:;F/YBRe[008aS0<e[@07>Lha
S36<<H`]Jc6<;F/013F]00HicS6<<H`U:BU:;F/2:DX00be[<H`]J`04;F/3
:DX2;F/3:DX00bDY;F/]J`02;F/2:DX2;F/4<H`00cF]>LhaS003;F/3<H`2
;F/0236<;F/]Jbe[<H`icSF]<H`2:DX012e[=Jde[C6<0Re[00LaS3F]<H`]
JbU:;F/e[@02<H`17>L000848@0300048@0000D48@090008@QcW=JdYBR48
:DX]JbU:008U:@D]J`03:DXU:B4800@Q20047>LQ21cW8@P97>L38@P01AS6
7>LQ21cW8@P011cW00HQ21cW8@PQ21cW8@P27>L022487>LQ22487>LQ22DY
8@P27>L38@P00acW8@PU:@029BT68@P37>L00aS67>LLi`047>L012487>LL
iaS60QcW00XHaQcW8@PQ21cW8@PU:BU:;F/YBP8Q20037>LQ2248008Q2004
9BTQ22DY8@P27>L01R489BTYBRDY7>LQ208Li`048@PLib488@P49BT00b48
7>LLi`027>L012487>LLiacW0b4800<Lib487>L00R481AcW0b480acW1R48
0RDY00<YBR488@P00QcW0R480acW00<Q22DY9BT00QcW00<HaRDY8@P00RDY
00@Q21cW8@PQ20<U:@038@PU:BU:008]J`04:DXQ22DY9BT78@P00acW9BTU
:@038@P29BT01B489BTQ22DY7>L00b480RDY00HQ22DY9BTU:B489BT3:DX0
12DY8@PU:BDY0R480aBU00@HaQcW9BTU:@8Q20047>LHaR488@P3:DX00be[
:DXU:@028@P00bDY8@PU:@029BT2:DX01C6<;F/YBRe[:DX00RDY00DQ22DY
:DXYBRe[00PU:@<YBP039BTQ22DY008U:@8YBP039BTYBRDY00<U:@08:DX]
JbU:9BTYBRDY:DXU:@8Q20039BTYBRDY008]J`8aS004;F/U:BDY9BT2:DX2
9BT01BU:;F/]JbU:9BT00b4800<U:BU:9BT00R4800DU:B487>LQ22e[008e
[@03:DXU:B48008Q20039BTQ22DY008Q20039BTYBRU:008U:@8Q208U:@DQ
20049BTaS3F]<H`29BT01RU:9BTYBRU:9BTYBP8]J`039BTQ22DY00<YBP05
9BTYBRU:;F/U:@027>L28@P04AcW8@PQ236<>LhmkdHa>Lh]JbDY7>LQ22DY
8@PU:B489BT00R480RDY0R480bDY00<Q22DY9BT00bDY0RU:00@Q22DY9BTY
BP<]J`03:DXU:BU:00DYBP06;F/YBRDY9BTYBRe[0S6<0be[00DaS2U:9BTU
:BU:00@]J`8aS0H]J`06<H`e[C6<;F/aS2e[0S6<12e[00De[CW><H`aS2e[
008YBP03;F/aS2U:008YBP8aS0<]J`8aS004:DX]JbU:;F/2<H`01Be[<H`a
S2e[<H`00bU:0Re[00@YBRDY:DX]J`8aS006;F/YBRe[<H`icSF]0Re[0S6<
00<e[C6<<H`00S6<00@e[CW>>LhicP8aS0@YBP8]J`04<H`YBRU::DX3;F/0
1bU:;F/]Jbe[:DX]JbU:008U:@04:DX]Jbe[;F/2:DX2;F/00c6<;F/aS002
=Jd0136<;F/YBS6<0Re[00<aS2e[<H`00S6<00<YBS6<=Jd00SF]00DaS2e[
;F/YBRe[008aS08icP03=JdaS2e[00@]J`4aS04]J`4Q200000<000@Q1240
1P@Q00L000@Q248HaSW>9BTLi`03;F/29BT02be[<H`]Jc6<:DXU:BU:8@PL
iaS67>L012481AcW0QS60QcW00DQ22DY8@PLib4800<Li`038@PLiacW00<L
i`<Q20@Li`8Q20037>LQ21cW00<Q20<Li`058@PLib488@PU:@028@P01BDY
8@PU:B487>L00b481QcW00DQ21cW7>LLiaS6008Li`036<HLib4800<Li`05
8@PYBRe[;F/U:@048@P01QcW8@PQ22DY:DXU:@<Q208U:@0;:DXU:AcW7>LQ
21cW9BTQ21cW8@PU:@038@P012DY8@PLiaS60QcW00<HaQcW7>L00RDY0b48
1AcW00@Q21cW8@PLi`DQ20<Li`8Q20DU:@<Li`038@PLib48008Li`8Q20@L
i`058@PU:BDY8@PLi`028@P01RDY8@PQ22489BTQ20@YBP<U:@8Q20047>LQ
22DY9BT88@P29BT48@P27>L01b489BTU:BDY8@PU:B4800LU:@<Q20037>LH
aQBU008DY@098@PU:BDY8@PLiaBU7>LU:B48008YBP039BTYBRU:00@Q2004
9BTQ22DY9BT2:DX2;F/2:DX39BT00b489BTU:@03:DX012DY8@PQ22480RDY
0RU:1BDY00DYBRDY:DXU:BU:008U:@048@PU:BDY;F/2:DX01BDY8@PU:BU:
9BT00R4800@U:Be[;F/YBP8]J`05<H`]JbDY:DXU:@02:DX29BT2;F/00bU:
8@PU:@029BT011cW9BTU:BDY0R480RDY00<Lib48;F/00SW>00@YBQcW8@PL
i`8Q20049BTQ22488@P59BT00bU:9BTQ20028@P29BT012487>LU:Be[0S6<
00<YBRDY9BT01BU:00D]JbDY9BTQ22DY00<YBP8U:@05;F/YBRDY8@PHaP04
8@P02bDY<H`e[Cg_@Q0icRe[9BTLib489BT00R4800<U:B489BT00R4800HU
:B489BTU:BU:9BT28@P00bDY:DXU:@02:DX49BT00be[<H`]J`02:DX29BT2
:DX00be[:DXYBP02;F/00bU:;F/YBP03;F/01C6<:DX]Jbe[:DX00RDY00D]
Jc6<<H`YBRe[00<aS0<]J`05:DX]Jbe[;F/aS003;F/012U:;F/aS36<0Re[
00HaS3F]=JdaS2e[:DX4;F/2:DX00be[<H`aS002<H`3;F/01bU:;F/]Jbe[
<H`e[C6<008]J`03:DX]JbU:00<]J`03:DX]JbU:008]J`03<H`]Jbe[008a
S003>Lhe[C6<008]J`@aS00:;F/aS3F]>LhmkcW><H`]JbU:9BT2:DX01Be[
<H`]Jbe[:DX00be[00@YBRDY:DX]J`8aS006;F/U:BDY:DX]JbU:2Be[0SF]
00<aS2e[;F/00Re[00HaS2e[<H`]Jc6<;F/4<H`00cF]<H`]J`03;F/3=Jd0
13W>=Jde[C6<12e[0C6<0Be[0B4800001`@Q00048@@Q00048@0000D48@05
6<HaS2DY7>LU:@02:DX01be[9BTQ22U:;F/aS2e[008YBP8Q20037>LHaR48
00@Q208Li`<Q20036<HLiacW008Li`068@PLiacW8@PLib4811cW0b4812DY
00DQ21cW7>LQ22DY008Q200:9BTQ22DY8@PLiaS67>LHaQcW8@P49BT012U:
8@PLiacW0R4800<LiaS66<H00QcW00<U:B488@P00R480RDY0QcW00<HaQcW
7>L00QcW0R480RDY00DYBRDY8@PQ21cW008Q20037>LQ224800@U:@038@PU
:BDY008U:@8Q20047>LQ22488@P49BT28@P00bDY8@PLi`038@P47>L01B48
9BTLiacW8@P00RDY0acW00@U:B489BTLi`8Q20039BTQ21cW008HaP048@PL
ibDY7>L28@P39BT012487>LLiacW0b4800@U:B488@PQ208Li`058@PU:B48
8@PLi`028@P00bDY8@PQ20029BT00bU:9BTU:@03:DX01BDY8@PU:B487>L0
0b480QcW00LQ22DY8@PU:B489BTQ20029BT78@P012DY8@PQ22480RDY0R48
00TLib488@PU:B487>LQ21S65:D00QS600<LibDY9BT00QcW00hHaQcW9BTY
BRDY7>LQ22DY:DXU:B489BTYBRDY0R480RU:0RDY0RU:12DY00@Q22DY9BTU
:@<YBP049BTQ22DY9BT28@P3:DX89BT2:DX39BT6:DX01Be[9BTQ22489BT0
1Re[00<aS2U:9BT012DY00@YBRDY:DXaS08]J`079BTQ22DY8@PU:B489BT0
0R480QcW00TYBRe[>LhmkcF];F/Q21S68@P00QcW0R480RDY00<Q22DY9BT0
0RDY0bU:00LQ21cW8@PQ21cW:DXU:@02<H`013F]<H`]JbDY0R4800@YBRe[
:DX]J`8YBP039BT]Jc6<008]J`8U:@05:DXQ22488@PLi`048@P2;F/01c6<
>LhaS2e[9BTLibDY00<YBP039BTLiacW00DU:@@YBPTU:@048@PU:BU:;F/2
<H`2;F/29BT00bU:;F/]J`02;F/00bU:9BTYBP02;F/2:DX4;F/2:DX00bDY
:DXYBP04<H`01Be[<H`aS2U:;F/00RU:00<]Jc6<=Jd00SF]00<aS2e[;F/0
1S6<00<]JbU::DX00be[00<YBRe[:DX00Re[136<00De[C6<:DXYBRe[008a
S003:DX]Jbe[008YBP039BTYBRU:00<YBPH]J`05<H`]Jc6<=JdicP02=Jd3
<H`00be[<H`]J`04<H`2=Jd00cW>:DXU:@029BT01Be[:DX]Jbe[<H`00Re[
00HaS2e[;F/YBRe[:DX3<H`00bU:9BTQ2002:DX00be[:DXYBP029BT2;F/5
<H`00be[<H`]J`03<H`00cF]<H`aS006<H`4;F/01S6<=JdicSg_>Lhe[@8a
S005=JdaS3F]=Jd]J`018@P000848@0300048@@Q00D48@070008@QcW=JdY
BQcW9BT00RU:0RDY0RU:0S6<00<]JbU:9BT00R480acW00<U:B488@P00QcW
0b480QcW00@HaQcW7>LQ20<Li`036<HLiacW00DLi`8U:@058@PU:BDY9BTQ
20037>L00b489BTU:@028@P00acW8@PLi`027>L011S68@PLib480RDY0RU:
00<Q21cW7>L00R4800<LiaS66<H00acW00<U:B489BT00b4800DLiaS67>LL
ib48008Li`036<HQ22DY008YBP049BTQ22487>L58@P00bDY:DXYBP029BT0
12489BTU:BDY0R480QcW00DU:B489BTU:BU:00<Q20049BTQ21cW7>L28@P3
7>L01R489BTU:B487>LQ208U:@048@PHaQcW7>L48@P00bDY8@PLi`027>L0
12487>LQ21cW0R4800<U:B488@P00QcW0R4800<Lib487>L012480QcW1248
00<U:B487>L00R4800<U:B488@P00bDY00@YBRe[:DXYBP<U:@8Q20@Li`@Q
20039BTQ224800@U:@<Q20057>LQ22488@PLi`028@P49BT48@P00bDY7>LQ
20035:D01QS68@PU:B487>LHaP8Li`8U:@038@PU:BDY008YBP8Q20039BTY
BRU:008U:@058@PU:BDY:DXU:@02:DX012e[9BTU:B4812DY00@YBRDY:DXU
:@<Q2009:DXU:BDY9BTYBRDY8@PU:B48008YBP039BTYBRDY00<U:@LYBP04
9BTQ22DY9BT2<H`6;F/00bDY8@PU:@049BT01Be[<H`aS2e[:DX00R480RDY
00<YBR488@P00RDY00XLibDY:DXe[D8@=JdYBR487>LQ20<Li`<U:@8Q208U
:@<YBP8U:@048@PLiacW8@P29BT01Be[<H`aS36<:DX012DY00<]Jc6<:DX0
0bU:0c6<00DYBRDY9BTYBRDY008Li`8Q20057>LQ2248:DX]J`02=Jd00c6<
;F/U:@028@P49BT48@P00bDY:DXYBP059BT00b489BTYBP059BT012489BTU
:BU:0S6<00@]JbU:9BTU:@8YBP8aS005;F/U:BDY:DXaS002;F/00bDY:DXY
BP04:DX00bDY;F/aS002<H`8;F/01BU:<H`]JcF]>Lh00S6<0Re[00<aS3F]
<H`0136<12U:1be[136<12e[00He[Be[;F/U:Be[:DX39BT00be[:DXYBP04
;F/01BU:;F/]JbU:<H`00cF]0c6<00<]Jc6<<H`01C6<00PicSF]=Jde[Be[
:DXU:BU:2Be[0S6<00D]Jc6<;F/aS2e[008YBP039BTYBRU:00<YBP8U:@03
:DX]JcF]008aS003;F/aS36<008aS003;F/aS36<00DaS004;F/aS3F]<H`2
;F/012U:<H`e[C6<13W>136<00<e[C6<;F/00B4800001@0012448@@Q0000
1`@Q00DLic6<8@PDYAcW00@U:@<YBP04;F/aS2e[9BT47>L01B487>LQ2248
9BT00b4800LLib489BTQ21cW6<HLi`028@P87>L00b487>LLi`028@P012U:
<H`YBR480QS60R480QcW0R480QcW0aS600DQ21cW7>LQ22DY008]J`079BTQ
21cW7>LQ21cW6<H00acW00<Q21cW8@P00bU:00HU:AcW7>LLib487>L26<H0
0acW9BTYBP029BT00b487>LQ20038@P011cW8@PQ224812DY0R480bU:00<Q
21cW7>L01B4800<U:B488@P01AcW2B480RDY0b4800DLib488@PLiaS6008L
i`039BTQ21cW00@Li`088@PU:BU:9BTQ22DY8@PU:@<Q20067>LQ22489BTQ
21cW0R4800<U:B488@P00b4800@YBQcW7>LYBP8aS0059BTLibDY;F/YBP05
9BT28@P27>L02aS67>LLiacW8@PU:BU:;F/YBRe[:DX00b4800<YBR487>L0
0QcW0RDY00<Q22DY8@P00RDY0R480bDY00LQ21S66<HHaQ245:DHaP038@P0
21cW6<HHaQcW8@PU:B487>L28@P39BT01RU:;F/YBRDY8@PU:@8YBP04;F/Y
BRe[;F/29BT01B489BTU:BDY8@P00RDY00DYBRDY8@PU:B4800<U:@<YBP8U
:@038@PU:BU:008]J`049BTQ22DY9BT3:DX01be[<H`e[Be[:DXU:BU:00<U
:@03:DX]JbU:00<YBP069BTYBRDY:DXU:BU:0RDY00LYBS6<>Lhe[Be[:DXU
:@028@P39BT01B487>LQ22U:;F/00S6<00P]JbDY9BTQ22DY7>LHaR480RDY
0b4800PU:Be[<H`aS2U:9BTQ21cW124800LLibDY:DXYBRe[:DXU:@028@P0
1bDY:DXU:BU:;F/aS3F]008aS008;F/YBRe[;F/aS2U:9BTLi`<Q208Li`05
8@PU:BU:;F/YBP029BT28@P01RDY:DXYBRDY8@PLi`8U:@04:DXQ22489BT2
:DX00bDY8@PU:@049BT2:DX01Re[:DXU:B489BT]J`8aS003:DXU:BDY008Y
BP0:;F/e[C6<<H`YBRDY:DX]JbU:;F/9:DX2;F/00c6<;F/]J`02:DX2;F/3
:DX00be[<H`]J`02;F/3<H`00be[:DX]J`04<H`00be[<H`]J`02;F/3:DX0
1C6<=Jde[C6<;F/01C6<00<]JbU::DX00c6<00<YBRDY:DX00RU:00PU:BU:
:DXYBRe[:DX]JbU:0Re[00<aS3F]>Lh00SF]1C6<00<e[C6<<H`00S6<00Le
[CW>>LhaS2e[:DXU:@02:DX6;F/5<H`012e[<H`aS2U:0bDY00TYBRe[:DXY
BRDY:DXaS2e[<H`00SF]00<icS6<<H`00S6<13F]0S6<00He[Be[<H`]Jc6<
=Jd2<H`2;F/2<H`00cF]<H`icP03>Lh01Be[<H`aS36<;F/00B4800031240
100012448@000`@Q00P000Q27>LaS2DY6<HLib480RDY00HYBRDY9BTYBS6<
;F/2:DX27>L011S67>LLiacW0R480RDY1B4800<LiaS67>L00QcW00<Q21cW
8@P00QcW00DHaQcW7>LLiaS6008Li`8U:@<YBP<Li`8Q20DLi`8HaP@Li`8Q
20069BTYBRe[9BTLiaS621cW0R480RDY0R480QcW00HQ21cW7>LLiaS67>L2
8@P29BT58@P01QcW8@PQ22489BTQ208U:@<Q20<U:@8Q20037>LQ224800@Q
20049BTQ21cW6<H27>L00b487>LLi`027>L38@P39BT28@P27>L00b487>LL
i`026<H27>L38@P011cW8@PLiacW0R4800<YBRDY8@P01B4800<U:B487>L0
124800HLib487>LQ21cW8@P29BT28@P01AcW9BT]Jbe[9BT00R480bU:12DY
0R481QcW00<U:B48:DX00Re[0RU:00<U:B489BT00b480QcW0R4800<U:B48
8@P00bDY0R480RDY00hQ21cW7>LDYA245:DHaR489BTQ21S65:DHaR480RDY
0acW00<U:BU:9BT00RDY0RU:0bDY1BU:0Re[00@YBRDY8@PU:@8Q20@U:@03
8@PU:BDY008U:@@YBP<U:@098@PU:Be[:DXU:AcW8@PYBRDY008YBP06;F/a
S36<;F/YBR481BDY00<YBRe[:DX00RU:22DY00T]JcW>=JdaS2U:9BTYBRDY
8@P01BDY00HQ22DY;F/e[Be[:DX29BT022487>LHaQS67>LQ22DY:DX28@P0
1RDY;F/]Jc6<:DXQ208Li`<Q20047>LQ22DY:DX2;F/012U:9BTQ22480bDY
0RU:00DaS3F]<H`]JbU:008]J`03<H`YBRU:00@Q20037>LQ2248008U:@8Y
BP03;F/U:BDY008Q2006:DX]JbDY8@PLib480RDY00<Q22DY9BT01BDY0b48
0RDY00<YBRe[:DX00RDY0R4800H]Jc6<;F/YBR489BT2:DX00be[<H`aS002
:DX00bDY:DXYBP05:DX012DY:DXU:BU:0Re[00DYBRe[;F/]JbU:008]J`@Y
BP@]J`04:DX]Jc6<<H`2;F/4<H`012e[<H`aS2e[0S6<0Re[00@U:BU:<H`e
[@8aS003;F/aS36<00<]J`06<H`]JbU:;F/aS2e[0bDY00@YBRDY:DXYBP8]
J`07:DX]Jbe[;F/YBRe[<H`00SF]00<aS3F]<H`00c6<00<e[C6<=Jd00S6<
00He[C6<>LhicS6<;F/2:DX2;F/2:DX012e[:DX]Jbe[136<00@]Jc6<<H`]
J`8U:@048@PYBRe[;F/4:DX01C6<=Jde[CF]<H`00SF]00<aS2e[<H`00cF]
00<aS3F]=Jd01C6<00De[C6<<H`]Jc6<008]J`8aS004>LhmkcW>=Jd4<H`1
;F/17>L0000300048@0000T48@056<HaS2DY5:DHaP029BT042U:9BTQ2248
9BTYBRe[<H`]JbDY8@PLiaS67>LHaQcW0b4800@Lib487>LQ20<Li`056<HL
ib488@PU:@028@P27>L00aS67>LLi`047>L01b489BTYBRDY8@PHaQcW008Q
208Li`8Q20@Li`068@PLib488@PLibDY0RU:00@]JbU:7>LLi`8HaPPQ2003
9BTQ224800HLi`048@PLib488@P27>L01R489BTQ22487>LQ208U:@8Li`05
8@PU:BDY8@PLi`059BT28@P01AS67>LQ21cW9BT00b480acW00<HaQcW8@P0
0acW00PQ21cW7>LYBRe[:DXLib480RDY0acW00@Q21S67>LQ208U:@<Q208L
i`8U:@04:DXU:B487>L28@P39BT47>L28@P01AcW8@PLiaS68@P00bDY00<Q
21cW9BT00bDY0b480bDY00@YBRDY8@PQ208Li`038@PU:AcW00<Li`039BT]
JcF]008e[@8icP03;F/U:B48008YBP079BTLiaS66<HQ22DY8@P00QcW0bDY
0R4811cW0aBU00<HaQcW8@P00QcW00<HaQBU6<H01R4800DU:B488@PU:BU:
008]J`8YBP05;F/YBRe[;F/YBP029BT2:DX29BT01248:DXU:BDY0R480RDY
0R480RDY00DYBRe[;F/YBRDY008Q2003:DX]JbU:00<U:@03:DX]JbU:008Y
BP04;F/aS2e[:DX29BT28@P02BDY8@PYBRU:;F/YBRDY8@PYBP049BT2:DX2
;F/3=Jd0136<;F/YBRU:0bDY0b480bDY00@YBRDY9BTU:@<Li`038@PU:B48
008U:@09:DXQ22DY:DXe[CW>=JdYBRDY008Li`059BTQ22DY8@PU:@03;F/0
0bU:8@PU:@028@P29BT01BU:9BT]Jc6<;F/00RU:00H]JcW>@Q0mkc6<;F/2
8@P01RDY8@PQ21cW8@PU:@8YBPDU:@<Q20<U:@048@PLib488@P29BT01B48
9BTU:B489BT00R4800<U:B48;F/00SF]00<aS2DY7>L00RDY00@YBRe[:DXU
:@<YBP8]J`03<H`]JbU:008YBP<]J`03:DXU:B48008]J`8aS08YBP04;F/Y
BRU:9BT2:DX012e[<H`]JbU:0Re[00<YBRe[:DX00S6<00@e[C6<;F/YBP@]
J`05<H`e[CW><H`e[@02;F/01RU:9BTYBRe[<H`e[@HaS0<]J`8aS003;F/Y
BRU:008U:@8YBP06;F/aS2e[;F/YBRDY0be[0S6<00<icSF]=Jd00SF]00<a
S2e[=Jd00SF]00<aS2e[<H`00SF]00@icSF]<H`aS0<]J`<YBP8]J`03:DX]
Jbe[00DaS003>Lhe[C6<008YBPD]J`06:DX]Jbe[<H`e[CW>0cF]136<0be[
00<aS3W>=Jd00SF]00@icSF]<H`aS08]J`03<H`]Jbe[008]J`04=Jdmkcg_
>Lh3;F/1<H`1:DX18@P000D48@0=00048@@Q124000@Q248Lic6<7>LDYAS6
8@P00RDY0R4800<LibDY;F/00be[00<Q22DY7>L00QS600LLib488@PQ21cW
8@PLi`028@P67>L28@P67>L02QS67>LHaQcW9BTQ22DY:DXU:B480QcW00<U
:B487>L00QcW00<Q21cW7>L00acW00DQ21cW6<HQ22DY008YBP049BTQ21cW
6<H57>L28@P00acW8@PLi`037>L00b487>LLi`027>L26<H011cW8@PQ21cW
0b480RDY12480QcW00@Q22DY8@PQ208Li`@U:@<Li`086<HLib488@PU:B48
7>LQ208HaP<Li`8HaP0;7>LQ21cW8@PYBRe[:DXQ21cW8@PU:@028@P37>L5
8@P011cW8@PLiacW12DY1R4800<U:B488@P00acW0R4800<HaQcW7>L00bDY
124800@U:BU:9BTQ208Li`DU:@048@PU:AcW7>L38@P02acW6<HLibU:;F/a
S3W>=JdicS6<;F/01BDY00@LiaS67>LLi`8Q208Li`048@PU:B488@P27>L0
12487>LLiaS60Q2400DHaQcW8@PLiaBU008HaP037>LQ224800@Q20049BTQ
22488@P4:DX00be[:DXYBP02;F/01bU:9BTU:BDY:DXU:B4800DU:@8Q2003
9BTQ2248008U:@03:DX]JbU:008Q208U:@06;F/YBRDY9BTQ22DY1BU:0S6<
00D]JbU:8@PQ22DY008Q208U:@04;F/YBRDY8@P49BT28@P012DY:DX]Jc6<
0SF]0S6<00<]JbU:9BT00RDY0b4800DU:B488@PQ22DY008YBP058@PLiacW
6<HLi`038@P39BT022U:;F/aS3W><H`YBRDY7>L38@P00bDY8@PU:@02;F/0
12U:9BTQ22DY0R4812DY00<YBS6<<H`00RU:00L]JcW>@Q0mkc6<:DXQ2003
9BT01B487>LQ22489BT00RU:0RDY00@Q22DY9BTU:@<Q20059BTQ22DY9BTQ
20049BT00b489BTU:@028@P011cW8@P]JcF]0S6<0b4800<U:BU::DX00RU:
0RDY0RU:00<]JbU:;F/00Re[0RU:00D]JbU:9BTU:BU:00D]J`HYBP<]J`03
:DX]Jc6<008]J`8YBP<aS003;F/YBRU:008YBP069BT]Jc6<>Lhe[C6<0Re[
12U:1C6<00<e[C6<;F/01Be[00XaS2e[:DXYBR489BTYBRDY:DX]J`8aS003
;F/YBRe[008YBP8aS004>LhmkcF]<H`2;F/01cF]>Lhe[CF]<H`]Jc6<008e
[@04>Lhe[C6<<H`3;F/00bU:;F/YBP02:DX00be[<H`aS005<H`01CF]<H`]
Jbe[:DX00Re[00<aS2U::DX00RU:00@e[C6<<H`e[@@aS003=JdaS2e[00<a
S08e[@04<H`e[CW>>Lh2=Jd3<H`2;F/012U:;F/YBSW>0Sg_00<e[Be[;F/0
0S6<0Be[0AcW00001@00124000@Q00001@@Q00L000Q27>LaS2DY48@HaP02
8@P39BT28@P01bU:;F/]JbU:9BTYBR48008Li`086<HQ21cW7>LQ21cW8@PL
i`8Q208Li`8HaP058@PLib489BTQ20026<H011BU6<HLiaS611cW00LQ22DY
:DXQ21cW6<HQ20047>L28@P26<H58@P00acW8@PU:@029BT00b487>LLi`02
7>L01B489BTYBRDY8@P011cW00@Q21cW7>LHaPPLi`038@PLiacW008Li`03
8@PLib48008U:@8Li`038@PYBRU:00<Q20037>LQ224800<Q20057>LHaQS6
7>LQ20027>L38@P00acW6<HLi`037>L28@P00acW8@PU:@039BT01B489BTU
:BDY8@P00acW00HQ21cW8@PU:BU:8@P27>L02R489BTU:B489BTQ21cW8@PL
ibDY0RU:00HU:B487>LLib487>L28@P37>L00b489BTQ20028@P00bDY:DXU
:@028@P00acW8@PQ20049BT38@P00acW8@PQ20027>L012489BTaS2U:0be[
0RU:00@Q22DY:DXYBP8U:@037>LQ21cW008Li`058@PU:B488@PLi`028@P5
7>L011BU48@DYABU0R4800<LiaS66<H00QcW00<U:BU:9BT01b4800<U:BU:
:DX00S6<00@e[C6<;F/YBP@U:@<YBPLU:@8YBP<U:@<YBP078@PLib48:DX]
JbU:9BT00RU:00<U:BU::DX00Re[0RU:0bDY0R4800HLib489BTQ22DY8@P4
9BT01BU:9BTU:BDY:DX00RDY0RU:0S6<00De[Cg_>LhaS2e[00<YBP059BTL
iacW9BTQ2003;F/01bDY8@PLiacW9BTQ22DY008Q208U:@8Q2004:DXaS36<
;F/2:DX01BDY8@PQ22489BT00R4800@U:BU::DXYBPHU:@03:DXU:BDY008]
J`04:DX]JbU:<H`2>Lh00c6<:DXQ20038@P00bDY:DXU:@029BT012489BTU
:BDY0RU:00<U:B488@P00bDY00@Q21cW7>LQ208U:@038@PU:B48008YBP8U
:@0<8@PHaRU:<H`icSF]:DXQ22DY8@PU:BU:0bDY00D]Jc6<=JdaS2U:00<]
J`HYBP<U:@@YBP8U:@03;F/YBRU:008YBPD]J`<YBP06;F/aS36<<H`]JbDY
0bU:13F]00@]Jc6<=Jd]J`8YBP03<H`]Jbe[008aS0@icP08<H`YBRe[<H`e
[C6<;F/YBP<]J`<YBP8]J`8YBP08;F/aS36<;F/YBRe[=JdicP8e[@8aS003
=JdaS3F]00He[@04>LhmkcW>>Lh2<H`01Be[:DXYBRU:;F/00RU:00DaS3F]
<H`aS2e[008aS0<]J`8aS0L]J`03<H`e[CF]00<aS08]J`8e[@03<H`]Jbe[
008aS0De[@8aS08]J`8aS004;F/YBRe[<H`2=Jd5<H`1;F/1:DX18@P000`4
8@077>Le[BDY5:DHaQcW8@P00RDY0b4800<U:BU:;F/00bU:00<Lib486<H0
0QS600@Lib488@PLi`<Q208Li`046<HLiaS67>L28@P01BDY8@PLiaS65:D0
0QS600<LiaS67>L00acW00<U:B488@P00QcW0R481QcW00DHaQcW8@PU:B48
008Li`0?8@PU:BU:9BTQ21cW8@PLiaS68@PU:BU:9BTLiaS600DLi`046<HL
iaS66<H37>L28@P57>L00b487>LQ20028@P00bDY8@PQ20039BT01b487>LL
ib487>LU:B4800<Li`<HaP037>LQ21cW00<Q20HLi`058@PLib489BTQ2006
9BT28@P27>L00aS67>LLi`038@P00bDY7>LLi`038@P012DY8@PQ22480QcW
0bDY0R4800DLibDY7>LQ21cW008Q20036<HLib48008U:@8Q20DU:@038@PL
iacW008Q20079BTQ22DY8@PLib487>L00R4800<LibDY:DX00Re[00@YBRe[
;F/]J`8U:@038@PU:BDY008U:@048@PU:B488@P37>L28@P00bDY7>LQ2003
8@P01ABU6<HDYABU6<H00QcW00<Q21cW6<H00QS600/LibDY9BTU:B487>LQ
22DY8@PLib4800<YBP8aS007=JdaS2U::DXU:B489BT00bU:0RDY0RU:1BDY
00DQ22DY9BTYBRDY008YBP068@PLib489BT]JbU:0RDY22U:1BDY0R4800@L
ib489BTQ208U:@03:DXU:B4800<U:@038@PU:BU:008YBP8aS005=JdicSW>
<H`]J`049BT28@P29BT01BU:;F/]JbDY8@P00QcW0b4800LLib488@PYBR48
9BT]J`02<H`00bU:9BTYBP029BT48@P00bDY8@PYBP03:DX01BDY8@PQ22DY
:DX00RDY0RU:0Re[00<YBRe[=Jd00SW>00@]JbU:7>LQ20<U:@8Q20039BTY
BRDY008Q20049BTYBRU:9BT38@P01BDY8@PQ21cW8@P00RDY00<Q22DY8@P0
0RDY0RU:00DU:B488@PYBRe[008e[@05:DXQ22DY8@PU:@02:DX29BT012U:
;F/aS36<0be[00DYBRe[:DXYBRDY008YBP<U:@04:DX]JbU::DX39BT00bU:
;F/]J`02:DX012e[<H`aS2U:0be[0S6<0be[0bU:00<]Jc6<=Jd00SF]0S6<
0Re[00<YBRe[;F/00Re[00<aS2e[>Lh00Sg_00<e[Be[;F/0136<00<]JbU:
:DX01BU:00XaS2e[:DXU:Be[=JdaS2U:9BTYBP8e[@04>Lhe[C6<<H`2>Lh0
13F]<H`e[C6<0SF]00HaS3F]?NlicSF];F/2<H`00bU:9BTU:@04;F/2<H`0
0be[<H`aS007<H`5;F/4<H`013F]<H`]Jbe[0c6<00<e[Be[;F/00S6<0SF]
00@aS3W>=Jde[@8]J`05<H`]Jc6<<H`]J`02<H`2=Jd2<H`01Be[=JdaS36<
;F/00AcW00001`00124000@Q00048@0000D48@056<He[BDY5:DHaP027>L0
1B487>LU:B489BT00RU:0Re[0RU:0RDY00@LiaS66<HHaP8Li`048@PLiacW
7>L38@P011S67>LQ22480RDY00<Q21cW6<H00QS61QcW0R4800<U:B488@P0
1AcW0R4800DLib487>LLib48008Li`<Q20049BTQ22DY9BT36<H00acW8@PQ
20028@P00bDY7>LLi`038@P00acW6<HLi`037>L48@P00acW8@PLi`028@P2
7>L011S67>LQ22481BDY00@YBR487>LLi`8Q20047>LHaQcW7>L26<H00acW
8@PLi`027>L38@P00aS67>LLi`028@P47>L28@P011cW8@PQ22480RU:0R48
00<Lib488@P00QcW00<Q22DY8@P00QcW00<U:B488@P00R4800<YBRDY8@P0
0RDY00DQ21cW8@PLib4800<Li`8Q20057>LQ22488@PU:@028@P01RDY8@PU
:BDY8@PU:@@Li`058@PLib487>LQ20029BT022486<HLibDY=JdaS2e[9BT2
8@P39BT00b489BTQ20028@P011cW8@PLib480RDY0R4800<Lib488@P00b48
00<U:B487>L00aS600<LiaS67>L00QcW0QS600DLib489BTQ22DY008YBP03
9BTQ21cW008Q20049BTYBRDY:DX2;F/01BU:;F/]Jbe[:DX00RDY0Re[0RU:
00LU:B488@PU:BU:;F/YBP049BT00bU:9BTU:@028@P01BDY:DX]Jc6<:DX0
0bDY00@YBRDY:DXU:@8YBP039BTYBRU:008U:@8Li`<Q20049BTQ22DY9BT2
8@P011cW9BTU:BDY0R480RDY00<YBRe[;F/00S6<010]JbU::DXYBRe[<H`U
:B487>LQ22U:;F/YBRDY8@PLi`8Q20037>LU:BDY008U:@8Q208U:@04;F/Y
BRU::DX49BT012U:9BTQ224812DY00<]Jc6<;F/00bDY00DYBRDY:DX]JbU:
00<U:@05;F/aS36<;F/YBP028@P29BT2;F/2:DX01BDY8@PU:B489BT00RU:
00<U:B489BT00bDY00<Q21cW8@P00bDY0R4800<U:BU::DX0124800<YBRe[
:DX01bDY0bU:00DaS3F]=JdicRe[008YBP059BTYBRU::DX]J`03:DX00bDY
:DX]J`02;F/012U:9BTYBRe[0bDY00<YBS6<;F/00be[00@YBS6<=Jde[@8a
S004;F/aS2e[:DX29BT012e[<H`aS3F]0c6<12U:00@]JbU:;F/aS0<icP05
?NlaS36<<H`]J`02<H`01BU:<H`aS36<;F/00RU:0Re[13F]0be[00<YBRDY
;F/0136<0SF]0cW>0cF]0Re[00Le[CW>?NlicS6<=JdaS002;F/2:DX2;F/2
<H`2=Jd2<H`012e[:DXaS3F]0c6<00D]Jc6<<H`e[C6<008]J`<aS009:DX]
Jbe[<H`e[CW>=JdaS3F]00<aS003=JdicSF]00<e[@03<H`]JbU:008]J`Ha
S006;F/aS36<>Lhe[Be[0BDY0009124020001248@QcW=JdYBQBU6<H27>L4
8@P00bDY:DXYBP02;F/2:DX00b487>LHaP026<H67>L00b487>LLi`047>L0
12489BTU:B480QcW0QS600<LiaS67>L011cW0b480QcW00<Q21cW7>L031cW
00@Q22DY9BTQ20DLi`8Q20<U:@057>LQ21cW7>LQ20027>L36<H012489BTQ
22480acW0R480QcW00@HaQcW8@PQ208U:@8Q20049BTYBRDY8@P47>L01aS6
7>LLiaS65:DHaQcW008Q20047>LQ22488@P27>L28@P37>L00b487>LQ2003
8@P01AcW8@PQ22U:9BT00R4800@LiaS67>LLi`<Q20037>LQ21cW008U:@03
8@PLib48008Q20<U:@8Q20047>LQ22486<H27>L38@P27>L58@P29BT38@P0
1BDY7>LQ21cW8@P00acW0R4800DU:AcW6<HU:BU:008aS0<U:@068@PU:BDY
9BTQ22DY1R4800<Lib488@P00QcW00HQ22DY8@PLib489BT28@P56<H47>L2
6<H27>L00bDY8@PU:@02:DX00bDY7>LLi`028@P29BT00bU:;F/YBP04;F/3
:DX2;F/2:DX49BT012U:9BTYBRe[0RDY00@Q22DY:DXYBP8Q20<U:@<]J`03
:DXQ22DY008YBP8U:@03:DXU:BU:008YBP8U:@<Li`038@PU:AcW008Q20@U
:@038@PU:BDY008U:@8Q20039BTYBS6<008aS004;F/YBRU::DX2;F/012DY
8@PQ22480bU:00@U:B487>LLi`8Q20@U:@8Q20039BTYBRU:00<U:@03:DX]
JbU:008U:@8Q20059BTQ22DY9BTYBP02;F/00bU:9BTQ2002:DX29BT2:DX3
9BT01RU:<H`aS2e[:DXQ20<U:@@YBP8U:@8Q20@U:@8Q2004:DXU:BDY7>L3
8@P00bDY8@PQ20029BT012U:9BTU:BDY0R4800@U:BU::DXYBP8U:@8YBP<U
:@8YBP04<H`e[C6<<H`29BT2:DX012e[:DXYBRU:0Re[1bU:00@U:BU::DXY
BP<U:@03;F/aS2e[008YBP04;F/e[C6<<H`3;F/00c6<;F/YBP02:DX00c6<
;F/aS003<H`00be[:DX]J`02:DX2;F/0136<;F/e[Cg_0SW>00<e[Be[<H`0
0S6<0be[00<aS2e[;F/00RU:0Re[00<aS3F]<H`00S6<0RU:0RDY00<]JcF]
=Jd00c6<13W>00Te[C6<<H`aS2e[=JdicT8@>Lh00c6<0RU:00DU:BU:;F/a
S3F]00DaS08]J`8aS003>LhaS36<008]J`03=JdaS3F]008]J`8aS08]J`05
:DX]JcF]=JdicP08<H`3=Jd00c6<;F/aS004;F/2<H`01Be[<H`aS2e[<H`0
0SW>0CF]0BU:0B4800001@00124000@Q00001@@Q00L000Q28@PicRU:5:DQ
20047>L012489BTU:BU:0RDY0RU:0bDY00DQ21cW6<HHaR4800<Li`8Q20@L
i`8HaP8Q20039BTQ224800LLi`046<HLiacW7>L38@P47>L012DY8@PQ2248
11cW00<Q21cW8@P00acW00@U:BU::DXQ20<Li`8U:@@Q20037>LQ224800@L
i`056<HLiacW8@PU:@038@P012DY8@PQ22480QcW00<HaQcW7>L00R4800<U
:B488@P00b4811cW00<Q21cW7>L01acW12480acW0b480QcW1R4800DLib48
:DXU:B48008HaPDQ208Li`078@PLib487>LQ22DY8@P00QcW0b480acW0b48
00<Lib487>L00R480bDY0R480QcW0R4800<U:B487>L00QcW124800<Lib48
8@P00RDY00DHaRDY<H`e[BU:008Li`04:DXU:BDY:DX29BT012487>LLiacW
0R4800<U:B488@P00R4800@U:AcW7>LQ208U:@086<HLiacW8@PLiaS67>LU
:@8Q20<HaP037>LQ224800<U:@8]J`04:DXQ22DY9BT28@P29BT::DX00be[
:DXYBP079BT58@P29BT3:DX29BT2;F/00bU:9BTQ20029BT012489BTQ2248
0bU:00<U:B489BT00bDY00<Q22DY7>L00b4800<U:B489BT00bU:124800@Y
BRDY9BTYBP8]J`039BTQ2248008YBP049BTQ21cW7>L39BT37>L012DY8@PQ
21cW0R480bDY00XQ22U::DX]Jc6<=JdicS6<:DXQ208U:@<Q20039BTQ22DY
008YBP04;F/YBRU::DX69BT3:DX012DY:DXYBRe[1C6<0SF]00@aS2U:9BTU
:@8Q20037>LQ224800@U:@<Q20039BTQ22DY00<Q20@U:@038@PU:B48008U
:@DYBP069BTQ22489BTYBRDY0Re[0S6<1RU:00<U:BU::DX00bU:0Re[00@a
S2e[;F/]J`<U:@8YBP039BT]Jbe[008]J`03:DX]Jbe[00<]J`04:DX]Jbe[
;F/2:DX2;F/2:DX03C6<=Jde[CF];F/YBRDY:DX]JbU:<H`e[CW>00@e[@8a
S004:DX]Jbe[;F/4<H`4:DX3<H`00be[:DXYBP05:DX00c6<=Jde[@02=Jd0
1cW>?NlmkcW>=JdicSF]008aS003=JdicSW>008e[@06<H`YBRU:;F/aS3F]
0S6<0cF]00@aS2e[;F/aS08e[@<aS004;F/aS3F]=Jd2<H`00be[<H`]J`02
;F/00bU:;F/]J`02=Jd3>Lh00c6<=JdaS003<H`012e[<H`aS2e[0RU:00@a
S3F]<H`aS0<]J`DaS04e[@4aS04U:@001@@Q00<000@Q12400`@Q00D8@QcW
>LhYBQS6008Li`036<HLiacW008U:@8YBP089BTYBRU::DXU:B489BTQ208L
i`046<HLiaS67>L38@P47>L011S67>LLibU:0RDY0acW00DHaQcW7>LLiaS6
00HLi`8Q20<Li`058@PU:BDY8@PLi`028@P27>L012487>LHaQS60R480RU:
00@LiaS66<HLi`8U:@048@PLib487>L48@P27>L011S67>LHaQcW0b4800@L
ib488@PQ20@Li`8HaP067>LQ22DY7>LQ21cW0R480acW00@Q21cW7>LLi`<Q
20<Li`036<HLib48008Q208Li`056<HLiaS68@PLi`028@P00acW8@PQ2004
7>L2:DX012DY8@PHaQS612480acW00<Q22DY8@P00QcW00HQ22DY8@PLib48
9BT28@P031cW8@PLib487>LQ21cW8@PLib489BTQ208U:@HQ20037>LQ2248
008Q208Li`DQ208Li`07;F/e[C6<:DXHaQcW8@P012DY0b4800<Lib487>L0
0R4800<U:B488@P01B4800<U:B488@P00b480QS600<Lib488@P00QcW0aS6
00<Q22DY:DX00RDY0bU:00DQ21cW7>LLib4800@U:@8YBP8]J`049BTYBRe[
;F/4:DX00b489BTU:@029BT28@P012DY8@PU:B480RDY0RU:00<U:BU:9BT0
0Re[00<U:BU:8@P00R480RDY0R4800<U:BU:;F/012DY00@YBRDY9BTLi`<Q
20039BTQ224800<YBP049BTLib489BT2:DX28@P00bU:;F/YBP028@P00bDY
:DX]J`028@P27>L01B489BTQ22487>L00b4800<Lib488@P01RDY0be[00Ha
S3F]<H`]JbDY:DX48@P01BDY8@PU:BU:;F/00RU:1RDY12U:0RDY0bU:0c6<
0Re[00@e[C6<<H`YBP8U:@058@PLib488@PYBP039BT00b489BTQ20058@P0
12DY8@PQ22480bDY00<Q22DY9BT00RDY00<YBRDY:DX012DY00@Q22DY9BT]
J`8aS003;F/YBRDY00<YBP8U:@03:DX]JbU:008U:@03:DXaS36<008]J`03
:DXU:BDY00DU:@03:DX]Jbe[00D]J`08:DX]Jbe[<H`]JbU:9BT]J`8YBP05
;F/aS3F]=JdaS002:DX012DY:DX]Jbe[0S6<00@icSF]=Jde[@8aS08]J`05
<H`]Jbe[<H`]J`02<H`012e[9BTU:Be[0c6<0RU:0RDY0bU:00<]Jc6<<H`0
0SF]1CW>0SF]00<aS2e[=Jd00cW>00@aS3F]<H`]J`8YBP@aS003>Lhe[CF]
008]J`8aS003=JdaS36<00TaS006;F/YBRU:;F/YBRe[0S6<0SW>0cF]1c6<
0be[00@YBRe[<H`e[@8]J`03:DXaS3F]00<aS003=JdaS36<004U:@0000<0
00@Q00001P@Q00L000@Q248Lid8@;F/HaP038@P00acW8@PLi`039BT011cW
8@PU:Be[0RU:00<U:B488@P011cW0b480acW00@Q21cW7>LHaP@Li`8Q20<L
i`8Q20037>LDYAS6008Li`8Q20037>LQ22DY00<Q208U:@038@PLiacW008Q
20<Li`056<HLiacW7>LQ20029BT01b487>LQ22489BTQ22DY008Li`046<HL
iacW9BT38@P00acW8@PQ20038@P00acW6<HQ20027>L28@P27>L26<H27>L3
8@P01QcW8@PQ22487>LQ208Li`059BTQ22DY9BTLi`046<H01BDY8@PQ21cW
6<H00QcW0b4800DLiaS66<HLibDY008Q20037>LHaR4800<U:@<Li`<U:@8L
i`068@PU:B489BTQ21cW0b4811cW0R4800<Lib487>L00acW00@Q22DY7>LL
i`<Q20039BTQ21cW008Li`@Q20047>LQ22487>L48@P29BT01b48:DXaS2e[
:DXHaQcW008Q20<YBP<Q208U:@<Q208Li`8Q20@U:@048@PLiacW7>L38@P0
1AS67>LLiacW8@P00QcW00DDYAS67>LLibDY008YBP8U:@8YBP<U:@058@PU
:BDY9BTYBP029BT2:DX00be[:DXYBP04:DX00bDY:DXYBP03:DX29BT01248
9BTU:BDY0b481RDY00@YBRDY9BTYBP8U:@058@PLib48:DX]J`02:DX00b48
9BTYBP049BT38@P011cW8@PU:Be[0RU:12DY0R480bDY0R480bDY00@Q21cW
7>LLi`8Q20<Li`038@PU:AcW008Li`@Q20039BTQ21cW008Q208YBP06;F/a
S36<;F/YBR480RDY00<Q22DY8@P00R4800<U:B488@P012U:22DY00DYBR48
9BTU:B48008]J`8icP8e[@<YBP8U:@8Q20077>LU:AcW7>LQ22DY:DX012DY
124800<U:B489BT00bDY0R480RDY0bU:0bDY00LYBRDY9BTU:B48:DX]J`02
<H`012e[:DXU:BDY22U:12e[0RU:00DU:BU::DXYBRe[00PYBP<]J`8YBP09
9BTYBRDY;F/aS2e[9BT]JcW>008mk`03<H`]JbU:008YBP03;F/aS2e[008]
J`8aS004=JdaS2e[;F/2:DX4<H`3;F/2<H`::DX00be[:DXaS003=Jd01be[
=JdicSF]<H`e[CW>008e[@04<H`e[CW>>Lh2=Jd00c6<=JdaS003;F/01C6<
=JdaS36<;F/00S6<0SF]136<00<e[C6<;F/00Re[00<aS3W>=Jd00be[00Da
S2U::DXU:Be[008e[@04>LhaS36<>Lh2<H`00be[:DXaS002<H`00be[:DX]
J`03<H`2:DX2;F/00cF]<H`aS002<H`1>Lh1=Jd1:DX000@48@0300048@00
00D48@058@PicRU:5:DQ20027>L01B487>LU:B489BT00R480RDY0RU:0RDY
0acW0QS600@Lib488@PQ20DLi`036<HLiaS6008Li`038@PLib4800XLi`03
8@PLib4800@Q208U:@8Q20037>LQ21cW00PLi`038@PLib4800<Li`8U:@8Q
20077>LHaQcW6<HLib489BT00R480acW00@Q21cW8@PLi`@Q20047>LQ21cW
7>L26<H011cW8@PU:B480QcW00LQ22DY8@PQ21cW8@PLi`038@P00bDY8@PH
aP026<H48@P00acW6<HHaP027>L00b489BTQ20027>L011S68@PQ22480QcW
0R4800@U:B488@PLi`8Q20049BTQ22487>L38@P00acW8@PQ20028@P011cW
8@PQ22DY1AcW0R4800DLib487>LQ22DY00DQ20047>LQ21cW7>L38@P37>L3
8@P031cW8@PQ22DY:DXU:Be[<H`YBR486<HLi`8U:@8YBP049BTQ22487>L2
8@P00bDY7>LQ20027>L28@P39BT00b489BTLi`027>L00b487>LHaP027>L2
9BT00acW6<HLi`026<H27>L29BT2:DX39BT38@P29BT01R489BTU:BU:;F/U
:@<YBP039BTYBRU:00<U:@03:DX]JbU:008YBPDU:@048@PU:B488@P39BT0
1R489BTYBRU:9BTQ208U:@@Q208U:@03:DXU:BDY00DU:@<Q20067>LQ22DY
9BT]JbU:1BDY0b481bDY0R4800<Lib487>L00QcW00<HaR486<H011cW0b48
11cW00<Q22DY:DX00Re[0S6<0RU:0bDY1b4800HU:BU::DX]JbU:9BT28@P0
0bDY:DXU:@059BT01248:DX]Jc6<0cW>00@e[Be[;F/U:@8YBP<Q20067>LQ
22489BTQ22DY0RU:00<U:AcW7>L00RDY0R480bDY0b4812DY12U:00@U:B48
9BTYBP8U:@8YBP8]J`DYBP039BTYBRU:00DYBP8aS08]J`03:DXU:BDY00LY
BP0<;F/YBRU::DX]Jc6<;F/YBR48:DXU:BU:0be[00XU:Be[=Je243g_<H`Y
BRe[9BTYBPD]J`07<H`e[CW><H`]JbU:9BT01be[00<aS2e[:DX00be[0RU:
00@U:BU::DXYBP<]J`HaS003=JdaS36<00He[@03>Lhe[C6<008e[@03;F/a
S2e[008]J`8aS003=JdaS36<00@aS003=JdaS36<008aS08]J`04:DX]JcW>
>Lh2<H`00bU:;F/aS002;F/01BU:;F/aS3F]>Lh01C6<00<]Jc6<<H`00S6<
12e[00HaS2e[:DXYBRe[<H`2=Jd3<H`1=Jd1>Lh19BT0000300048@@Q00L4
8@080008@QcW>Lh]JacW8@PU:@8Q20057>LQ22488@PU:@038@P39BT022U:
8@PLiacW6<HLib487>L2:DX01R487>LHaQcW8@PLi`<HaP8Li`048@PLib48
7>L38@P00acW6<HHaP026<H27>L00b487>LQ20028@P29BT28@P27>L48@P5
7>L28@P57>L48@P01QcW6<HLiacW8@PLi`8U:@<Q20037>LQ21cW008Q20@L
i`8Q208Li`076<HLiacW7>LHaQcW9BT00bU:0acW00LQ22DY8@PQ22DY8@PL
i`026<H37>L01B487>LQ21cW6<H00QcW0b480QcW00<Q21cW7>L00b480QcW
00@Q22DY8@PQ208Li`038@PU:B48008Li`HQ208U:@038@PLib4800<Q20PL
i`038@PLib4800<Li`8Q20037>LQ2248008Q20067>LHaQcW8@PU:B480QcW
00<Q22DY:DX00S6<00LYBRDY7>LHaR487>LQ2003:DX01RDY8@PQ22487>LQ
208Li`@Q20039BTYBRU:008Q20037>LQ21cW008HaP8Li`058@PU:BDY9BTQ
20036<H00acW9BTQ20079BT00b489BTQ20029BT011cW9BTU:Be[0bDY00P]
JbU:;F/]JbU:;F/YBRe[0S6<0RU:00H]JbU:8@PQ22DY:DX29BT28@P00bDY
8@PU:@049BT00b489BTU:@028@P00bDY8@PU:@04:DX012DY:DXU:BU:0b48
00DLib488@PQ22DY00<YBP0:9BT]JbDY8@PLib48:DXU:B489BT2:DX00bDY
8@PQ20028@P00acW8@PLi`027>L28@P26<H01R489BTQ21cW6<HLi`@Q2006
9BTYBRDY9BTQ22DY0bU:1R4800<Lib489BT012U:1RDY00<Q22DY:DX00RDY
00/Q22DY:DXYBSF]?Nle[C6<9BTQ22DY008Q208U:@058@PU:BDY9BTYBP06
9BT38@P00bDY8@PQ20028@P2:DX01bDY8@PQ22489BTYBRe[008YBP038@PU
:BDY008YBP<U:@04:DX]Jbe[;F/3:DX00bDY8@PU:@03;F/3:DX4;F/2:DX2
9BT00bU:;F/YBP06:DX3;F/00bU:9BTU:@03:DX2;F/01RU:<H`e[C6<=Jda
S08YBP039BTYBS6<008aS003;F/YBRU:00@aS003;F/YBRU:008]J`8aS0<]
J`<aS004:DXU:BU::DX2;F/012U:;F/YBRe[0S6<00@]Jc6<<H`e[@8aS08]
J`04<H`icSg_=Jd2<H`00cF]<H`icP03=Jd5<H`01SF]<H`aS36<=JdaS08e
[@8aS003;F/aS3F]00@]J`8aS08]J`04:DX]Jc6<<H`2:DX00be[<H`aS002
=Jd0136<=JdaS2e[0S6<00<e[C6<<H`00RU:00L]Jc6<<H`]JbU:;F/aS002
;F/4<H`1=Jd1<H`1:DX00004124000@Q000212400`0012448@0212401`Q2
7>LicRU:6<HU:B4800@Li`058@PLibDY8@PU:@028@P00bDY:DXYBP028@P2
6<H00acW6<HQ20029BT00b486<HHaP047>L011S67>LLiacW0R480acW00<Q
21cW7>L011S600<Lib487>L01B4800@Lib488@PQ208Li`<Q20DLi`DQ208L
i`@Q208HaP037>LQ224800<Q20079BTQ21cW7>LQ21cW8@P00acW0R4811cW
0QS611cW00DQ22DY:DXU:B4800<Li`@U:@<Li`8HaP<Li`038@PHaQcW00<Q
20049BTQ21cW6<H57>L00b489BTQ20037>L28@P27>L28@P01BDY8@PQ2248
9BT00R4800<Lib488@P0124800LU:B486<HLib489BTQ20057>L01bDY8@PL
iaS67>LQ22DY00@Q20<Li`038@PLib48008Q20067>LQ22DY:DX]JbU:0RDY
11cW00@Q22DY9BTU:@@Q20059BTQ21cW8@PLi`028@P29BT00be[9BTU:@02
8@P27>L011S65:DHaQcW0bDY0R480QS60QcW1BDY00DYBRDY8@PQ21cW00<U
:@<Q200=9BTYBRU:9BTYBRDY:DX]JbU:;F/YBRe[<H`00Re[0bU:0RDY00@Q
22DY:DXU:@8Q208U:@048@PU:BDY9BT38@P02BDY8@PU:B489BTQ22DY8@PU
:@04:DX39BT27>L012489BTQ22480RDY00@]JbU::DX]J`8U:@8Q20039BTQ
224800<YBP059BTLib488@PLi`028@P012DY7>LHaQS60QcW00DHaQcW8@PU
:AcW008HaP038@PLib4800@U:@8Q20059BTYBRU::DXQ20027>L032489BTQ
22487>LU:BU:;F/YBRDY8@PU:@8YBP8U:@048@PU:BU::DX39BT2:DX3>Lh0
1cF]9BTU:BDY8@PU:B48008U:@8Q20<U:@048@PU:BDY9BT48@P00bDY8@PQ
20029BT01bU:9BTQ22489BTQ22U:00<]J`03:DXU:BDY008YBP8U:@048@PU
:BU::DX2;F/00bU:9BTYBP029BT00bU:9BTaS002;F/2:DX3;F/3:DX29BT0
0bU:;F/YBP029BT012U:;F/YBRU:0Re[0RU:00@U:BU:9BTU:@D]J`06<H`e
[CF];F/YBRe[0RDY00<]Jc6<<H`00bU:00@aS3F]=JdaS08YBP03;F/YBRe[
00<aS009:DX]Jc6<<H`]JbU:9BTYBRDY008YBP03;F/YBRU:00@]J`<aS005
=JdaS2U:;F/aS003>Lh3<H`2=Jd01CW>=Jde[CF];F/00S6<0SF]0S6<00@]
Jc6<<H`aS08e[@03;F/aS2e[008aS08YBP03;F/aS36<00<]J`8aS0<YBP8a
S007=JdaS36<<H`e[CW><H`00Re[0c6<0be[00<aS2e[;F/00be[00@YBRe[
<H`e[@@aS04U:@0010@Q00<000@Q12400P@Q00H000@Q248HaSW>;F/68@P0
1QcW6<HLib48:DXU:@<Q208U:@048@PLiacW6<H38@P29BT28@P02AcW6<HQ
22487>LHaQBU6<HQ20057>L011S67>LQ21cW0aS600<LiaS67>L00b4800<L
iaS67>L0124800<LiaS67>L00b480QcW00HU:B488@PQ22DY8@P37>L00bDY
8@PLi`028@P011cW8@PQ21cW0R4800@U:B488@PLi`<Q20LLi`038@PLiacW
008HaP@Q20<U:@048@PLib488@P79BT36<H00acW9BTQ20029BT012489BTQ
21cW0R4800<U:AcW8@P00QcW00<U:B488@P01R4800HHaQcW8@PU:B487>L2
8@P29BT00acW8@PLi`058@P00bDY8@PQ20048@P00acW8@PLi`027>L01QS6
8@PLib487>LQ20<U:@038@PLib48008Q20HLi`036<HU:BU:008]J`8Q2006
6<HQ22DY7>LHaR4812DY00<YBRDY9BT01R4800@U:BU::DXYBP8Q20059BTQ
22486<HDY@026<H01R48:DXU:Be[9BTQ20@Li`<Q20<U:@@Q20049BTQ22DY
8@P:9BT2:DX012e[:DXYBRDY0be[00<YBRDY:DX00RDY0RU:00@]JbU::DXY
BP@Q208U:@DQ20039BTQ22U:00<U:@088@PU:BDY:DXU:AcW6<HLi`@U:@07
8@PYBRe[;F/U:B487>L00b480bDY00LYBS6<<H`YBR486<HLi`048@P00acW
8@PQ20038@P27>L00b487>LQ20047>L28@P00bDY8@PLi`029BT00be[:DXQ
20028@P011cW8@PQ21cW124800LYBRe[:DXU:AcW9BTYBP029BT00b489BTQ
20029BT01bU:;F/YBS6<=Jd]JbU:008U:@03:DXU:B48008U:@03:DXU:B48
008Q20037>LU:BDY00<U:@8YBP8U:@038@PU:BDY00DU:@8Q20039BTYBRe[
008YBP038@PU:BDY00@U:@048@PU:BU::DX3;F/012U:9BTYBRU:0Re[00@a
S2e[;F/U:@8YBP8]J`@YBP<]J`03:DXU:BU:008U:@8YBP04;F/YBRU:9BT2
:DX01BDY;F/e[C6<;F/00RU:0Re[0S6<00@]JbU:9BTYBP<]J`0;:DX]Jc6<
<H`]Jc6<;F/YBRe[:DX]J`02<H`2;F/01c6<=Jde[CF]<H`]JbU:008U:@04
:DX]Jbe[:DX3;F/2:DX01Be[=JdaS36<;F/00S6<00<e[CW>=Jd00S6<00@]
Jc6<>Lhe[@<icP0:<H`]JcF]=JdicS6<;F/aS3F]>Lh2<H`012e[<H`aS36<
12e[00<YBRe[:DX00be[00<aS2e[9BT00RU:00<aS3F]<H`00SF]00<icSF]
<H`0136<00H]Jc6<<H`aS2e[<H`2;F/0236<>LhaS2e[:DXaS3W>=Jd3;F/1
8@P000848@0300048@@Q00L48@066<HicRe[7>LQ21cW0R480QcW00<HaQcW
8@P00RU:00<U:B48:DX00RDY00<Lib487>L00acW0R4800PU:B488@PLib48
7>LQ21cW0aS600<Lib487>L01AcW00<Q21S66<H01AS600<Lib487>L00acW
00@Q22DY8@PQ208HaP8Q20039BTQ224800DQ20039BTQ21cW008Li`038@PU
:B4800<Q20037>LQ21cW00<Q20039BTQ21cW00<Li`038@PLiaS600<Li`<Q
208HaP047>LQ22487>L38@P39BT28@P00bDY:DXYBP048@P00aS65:DHaP02
8@P00acW8@PU:@029BT00acW8@PQ20038@P27>L012489BTU:BDY0QcW00<Q
22DY8@P00QcW00HQ21cW9BTQ21cW8@P29BT28@P27>L01R489BTQ21cW8@PU
:@8Q20047>LQ22488@P47>L48@P011cW8@PU:BDY1b481QcW00<Q22DY:DX0
0Re[00<U:B488@P00acW0R480RDY00HQ22DY9BTU:B487>L29BT28@P29BT0
1BU:9BTU:B489BT00R4800<LiaBU5:D00QS60RDY0RU:00LU:B487>LHaQcW
8@PLi`038@P39BT28@P01BDY8@PU:B489BT00R4800DYBRDY9BTU:BU:00<U
:@05:DX]JbU::DXQ2004:DX29BT5:DX39BT01BU:9BTQ22489BT00R4800<L
ib489BT00R4800DLib488@PU:B48008U:@048@PU:BU:9BT37>L39BT00b48
9BTYBP03:DX27>L00b487>LU:@029BT2:DX2;F/29BT47>L78@P00acW8@PL
i`028@P47>L38@P022DY8@PU:BDY:DX]JbU:8@P27>L00b489BTLi`038@P0
0bDY8@PYBP02:DX01B489BTU:BU:9BT00b480RDY00HQ22DY9BT]Jc6<=Jd2
;F/00b489BTYBP029BT2:DX29BT012487>LQ224812DY00XQ22DY:DXU:B48
9BTYBRDY8@PU:@8YBP049BTQ22489BT2:DX39BT012U:9BTU:BDY0R4800TU
:BU:9BTYBRe[<H`]JbU:9BT00bU:0S6<0Re[0RU:00<]JbU:;F/00bU:0Re[
00<YBRe[:DX00RU:0bDY00@YBRe[;F/]J`@YBP8]J`03<H`]JbU:00H]J`8Y
BP04;F/aS36<;F/2:DX00c6<;F/aS002;F/00bU:;F/YBP02;F/5<H`2=Jd0
12e[:DXYBRDY12U:00LU:Be[<H`aS2U:9BTYBP02<H`3;F/01S6<=JdicSW>
<H`]J`8aS0<e[@03>Lhe[C6<008aS009>Lhe[C6<:DX]JcF]>Lhe[C6<008]
J`8aS003;F/YBRe[008]J`03:DX]Jbe[00<]J`04:DXU:BU:;F/4<H`00cW>
=JdicP02<H`00be[<H`aS002<H`012e[<H`aS36<0Re[00<aS3F]<H`00RU:
00@e[CW>=Jd]J`8YBP4U:@0000H000@Q124000@Q000412401P00248Lic6<
9BTHaP8Q208Li`036<HLiacW00<Q20059BTYBRU:8@PLi`069BT01b489BTQ
22489BTQ21cW008HaP057>LQ21cW6<HDY@027>L28@P47>L28@P01AcW6<HH
aQcW6<H01AcW0R480bDY00TQ21cW7>LLib48:DXU:B489BT00bU:0bDY00<Y
BRDY9BT00R4812U:0RDY00PYBRDY8@PLib489BTQ21cW0R481QcW12480QcW
0R4800@U:AcW8@PLi`<Q20057>LQ22489BTQ20027>L39BT01AcW6<HHaR48
9BT00RU:00HQ21cW8@PQ22DY8@P27>L01RDY8@PQ22DY:DXQ208Li`048@PU
:BDY9BT38@P01AcW8@PQ22487>L01b4811cW00TU:BU:8@PLiaS67>LQ22DY
8@P01AcW0b4800HU:BU:;F/]JbU:9BT38@P27>L011S67>LLib480RDY0RU:
00DQ21cW7>LLibDY008Li`8Q208U:@048@PU:B489BT2:DX012DY7>LLiacW
0RDY00DYBRe[;F/]JbU:008Q208HaP047>LHaRDY9BT2:DX012487>LLiaS6
11cW00<Q22DY9BT012481BDY00@YBRDY:DXYBP8U:@038@PU:BDY008Q2007
:DX]JbDY8@PLibDY;F/00RU:0bDY0RU:0RDY00HQ22U::DXYBRDY8@P29BT2
8@P29BT28@P29BT00bU:9BTYBP029BT02248:DXYBRe[9BTQ21cW9BT2:DX2
;F/29BT012489BTU:B480QcW0R4800<U:BU:9BT00RU:00@]JbU:8@PHaP8L
i`DQ20047>LQ21cW7>L3:DX01BDY7>LLib487>L01B480RDY00<Q22DY8@P0
1B4800<Lib488@P00QcW00DYBRe[;F/YBR4800DU:@048@PLib48:DX2;F/3
:DX01Be[:DX]Jbe[:DX00RDY00PYBRe[:DXU:B489BTQ21cW0R4800<YBRDY
9BT00RDY00<Q22DY9BT00RU:00HU:BU:;F/YBRDY8@P3:DX28@P00bDY:DXY
BP029BT28@P012DY:DXYBRDY0RU:00<aS2e[;F/00Re[00<YBRDY9BT00S6<
00@]JbU::DX]J`<YBP04<H`]JbU::DX3;F/29BT4:DX00be[:DX]J`02;F/0
12U:;F/]Jc6<0Re[0bU:00<]JbU:;F/01bU:0be[00<aS2U::DX00RU:12e[
0S6<0be[00HaS3F]=JdaS2e[:DX6;F/0136<;F/]Jbe[0bU:0be[00<aS2e[
=Jd00SF]00DaS2U:;F/e[C6<008e[@8icP<e[@@aS08]J`03<H`]Jc6<008a
S006;F/YBS6<=JdaS2e[0RU:12e[00DaS2U:9BTYBS6<008]J`05<H`e[CW>
<H`]J`02=Jd00c6<:DX]J`03<H`00be[<H`aS003<H`4;F/4<H`1;F/18@P0
0003124000@Q00<48@0300048@@Q00848@06248Lic6<8@PHaQcW0R4800@H
aQcW7>LLi`8Q20<U:@8Q20039BTQ22DY00DU:@@Q20049BTQ21S66<H27>L0
0aS65:DDY@027>L01R487>LLiaS67>LQ20@Li`056<HDYAS67>LQ20027>L0
0aS67>LQ2002:DX01b489BTLiaS67>LU:BU:008U:@038@PU:BU:008U:@04
:DXU:BU:9BT38@P6:DX29BT012487>LQ21cW0R482QcW00DQ21cW6<HLib48
008Li`<Q20057>LQ22488@PLi`038@P27>L01b48:DXLiaS65:DHaRDY008Y
BP059BTLib488@PU:@068@P011cW9BTU:B480acW00@YBRDY8@PQ208Li`04
8@PLib487>L28@P00bDY8@PQ20027>L58@P00bDY8@PQ20048@P47>L00aS6
8@PQ20038@P012U:;F/]JbU:0bDY00<Q21cW7>L011cW00PHaRDY9BT]JbU:
8@PLiaS60R480acW0RDY0b4800@U:B488@PYBP8U:@8Li`048@PU:BU:;F/2
:DX01Re[8@PLiaBU6<HLi`8Q20049BTYBRU:9BT47>L012487>LLiacW0b48
00DU:B488@PLib48008U:@038@PU:BDY008YBP<U:@@Q208YBP039BTLib48
008YBP039BTQ22U:008YBP@U:@058@PYBRU::DXU:@028@P012DY8@PU:B48
0bDY00@YBRDY9BTYBP8U:@048@PLibDY;F/2:DX27>L01BDY:DXYBRe[9BT0
0RU:0RDY00@Q21cW8@PHaP8Q20039BTYBRU:008YBP049BTYBQcW7>L26<H0
0acW8@PQ20038@P37>L012DY:DXYBR480QcW1R480RDY00<Q22DY8@P00bDY
00DQ21cW7>LQ21cW008Q20097>LYBRe[;F/U:AcW8@PYBRDY008Q20037>LQ
22DY008U:@8aS006;F/YBRDY:DX]JbU:0RDY0RU:00D]JbU:8@PLib4800lU
:@<YBP048@PU:BU:;F/39BT01BU:9BTQ22DY8@P01RDY0RU:0S6<00<]JbU:
:DX00RDY12e[00HYBRe[;F/YBRDY:DX4;F/3:DX012DY:DXYBRDY0bU:0be[
00<aS2e[:DX00Re[0S6<0RDY00<YBRe[<H`00RU:00<U:BU::DX00bU:00<a
S2e[;F/00Re[0bU:00@]JbU::DX]J`8aS08]J`05<H`e[CF];F/aS007;F/0
136<;F/]Jc6<0bU:00<U:Be[;F/0136<00<icS6<<H`00Re[1CF]00HaS3F]
=JdicSF];F/2:DX3<H`2;F/2<H`01be[:DX]Jbe[<H`]JbU:00<]J`03<H`]
JbU:008YBP@]J`08<H`icSW><H`]Jc6<=JdaS0D]J`LaS08]J`DaS04]J`4Q
20000`@Q00<000@Q12400`@Q00T000@Q124Lic6<7>LDYAcW8@P011cW00HH
aQcW7>LLib489BT28@P011cW9BTYBRe[0RU:00<]JbU:9BT00R4800@U:BU:
9BTQ20<HaP8Li`@HaP037>LHaR48008Li`076<HLib488@PLiaS65:D00QcW
00<Q22DY9BT00R480QcW0R480RDY0R4800<U:BU:;F/00Re[12DY0bU:1BDY
12U:00<U:B487>L00R4800@U:AcW7>LLi`<Q20@Li`<Q20059BTQ21cW7>LH
aP048@P011cW6<HLiacW0R4800<U:B488@P0124800<LiaS66<H01248014L
ib48:DXYBRDY8@PLib489BTYBRDY8@PU:B489BTQ21cW008Q20039BTQ22DY
00@U:@03:DXQ21cW00<Li`048@PLiacW7>L28@P00bDY8@PQ20028@P012DY
8@PQ22481AcW00@Q22DY9BTU:@8]J`8aS08YBP8U:@048@PLiacW6<H27>L2
8@P02BDY:DX]JbDY8@PHaQcW9BTLi`026<H48@P01AcW8@PYBRU:9BT00R48
0RDY00DQ21cW8@PU:BU:008]J`088@PLiaS66<HQ21cW8@PU:@8Q20<Li`8Q
20037>LQ21cW00@Q20037>LQ22DY00@U:@03:DX]JbU:008U:@038@PU:BDY
008Q20037>LQ224800<U:@038@PU:B48008Li`068@PU:BDY8@PU:BU:0R48
00HU:Be[;F/YBRDY8@P29BT28@P012U:8@PU:BDY0be[00@U:BU:8@PU:@8]
J`03<H`YBRDY00<Q20039BTYBRU:008U:@04:DXU:BDY8@P37>L012489BTU
:B4812DY0R4800@HaQcW8@PQ208U:@8Li`048@PLiacW:DX2<H`012U:8@PQ
22DY12480RDY00@YBRDY9BTYBP8U:@037>LQ2248008Q208U:@<Q20069BT]
JbU::DXU:B480RDY00@Q22DY7>LQ208U:@03:DXU:BDY00<U:@07;F/aS2e[
;F/Q22DY:DX00RDY0R4800<U:B489BT00bU:0RDY0R4800@U:BU:;F/YBP8U
:@8YBP039BTQ224800<U:@8YBP04;F/YBRDY9BT28@P00bDY:DX]J`02:DX2
;F/2=Jd0136<;F/U:BDY0RU:0S6<00@YBRe[9BTU:@8YBP8]J`04:DX]Jbe[
;F/2:DX29BT2:DX29BT02RU:;F/]Jc6<;F/YBS6<>Lhe[C6<32U:22e[0bU:
00<]JbU:;F/00Re[00<aS3F]<H`01S6<0Re[1S6<0Re[00<YBRe[<H`00S6<
00X]Jc6<;F/aS3F]<H`]JbU:;F/aS08icP04<H`icSW>=Jd2;F/2<H`013F]
<H`aS2U:0Re[0S6<00H]Jc6<<H`e[C6<;F/2:DX00c6<;F/]J`02<H`2;F/0
22U:<H`aS2e[<H`]Jc6<;F/2<H`01cF]<H`]JbU:;F/YBRe[00@aS0<]J`@a
S004;F/e[CF]<H`17>L000848@0300048@0000H48@07248Q236<8@PDYAcW
8@P00QcW00<HaQcW7>L00QcW0R4800LYBR487>LQ22DY;F/YBP03;F/01RU:
9BTQ2248:DXU:@8Q208HaP037>LHaQcW008Li`8HaP037>LQ21cW00@Li`03
9BTLiacW008HaP<Li`<U:@038@PLiaS6008Q2006:DXU:B488@PU:BU:0Re[
00@YBRDY9BTU:@8YBP@U:@038@PU:BDY00<YBP039BTQ2248008Q20039BTQ
224800<Li`8Q20@Li`@Q20DLi`<Q20<Li`078@PLib488@PU:B487>L00R48
1AcW00<Q22DY7>L00R480RU:0R4800@Lib48:DXU:@8Q208U:@8Li`<Q2004
9BTQ22488@P39BT00b489BTQ20037>L012487>LLiacW0R4800<U:B488@P0
0RDY00<Q21cW7>L00QcW00DQ21cW7>LLib4800<U:@8YBP8aS003;F/YBRDY
008U:@048@PHaQcW8@P27>L02BDY8@P]Jbe[9BTLiaS67>LQ20037>L38@P2
7>L49BT00acW8@PU:@028@P01QcW8@PU:BU:;F/YBP8Li`035:DLib48008L
i`8Q20<Li`HQ20037>LQ224800<Q20049BTYBRU:8@P29BT2:DX29BT98@P0
12DY8@PU:BDY12480bDY00DQ22DY8@PQ22U:008]J`06:DXLibDY9BTQ22DY
0RU:0RDY0RU:00X]JbU::DXU:BU:9BTYBS6<;F/YBPDQ208U:@04:DXU:B48
9BT38@P27>L01R489BTU:B489BTQ208U:@067>LHaQcW7>LQ22DY0b4800DL
ib487>LLibU:008aS006;F/Lib488@PU:B480QcW0bDY00<Q22DY9BT00RDY
00<Q21cW8@P00bDY0b480RDY0Re[0RDY00PQ22U::DXU:B487>LU:B480bDY
00DQ22DY9BTU:BU:008aS005;F/U:B48:DXU:@028@P49BT01bU:;F/]JbU:
8@PU:B4800<U:@<YBP04;F/U:BDY8@P49BT00bU:;F/YBP049BT02R489BTU
:BU:9BT]JbU:<H`e[C6<0Re[00PU:BU:;F/YBS6<=Jd]JbU:0RDY0RU:00<a
S2e[:DX00be[00<YBRDY9BT00bU:0bDY00<]JcF]<H`00be[00De[CW><H`Y
BRDY008YBP08;F/YBRU:9BT]JbU:9BTYBP8]J`8YBP8aS003:DXU:BU:008]
J`8YBP8]J`04<H`e[CF]=Jd6<H`00be[<H`]J`02<H`2;F/2<H`00be[:DXY
BP02<H`00be[<H`]J`03<H`033F];F/YBRe[=JdmkcF];F/e[Cg_=JdaS08]
J`06=JdaS36<<H`]JbU:0Re[00<aS2e[;F/00S6<00@]JbU:;F/]J`@aS004
;F/YBRU:;F/2<H`012e[<H`e[C6<0Re[0SF]00HaS2U::DX]JbU:<H`2;F/0
1C6<=JdaS2U:;F/00cF]00DYBRe[<H`e[Be[004Q200000<000@Q12400`@Q
00`000@Q12448@00248Lic6<8@PDYAcW8@P27>L01b487>LLiacW6<HLib48
00<Li`038@PU:BU:00PYBP@Q208Li`085:DHaQS66<HLiaS67>LHaP8Li`03
6<HLib4800<Q20@Li`8Q20@U:@047>LQ22489BT3:DX28@P00bDY:DXYBP03
9BT2:DX01BDY7>LLibDY:DX00b480bDY00@Lib487>LHaP8Q20049BTLib48
9BT2;F/012U:7>LLiacW0R480acW00@Q21cW7>LLi`LQ208Li`DQ20067>LQ
22DY9BTLiaBU0QS600@Q21cW8@PQ208U:@038@PHaQcW00<U:@8Q20<U:@8L
i`038@PLibDY00<YBP@U:@DQ20037>LQ2248008Li`@Q20037>LU:B48008Q
208U:@038@PLiacW008Li`038@PU:BDY008U:@06:DX]JbU::DXU:BU:0R48
00TLiaS67>LHaQcW8@PLibDY;F/00RU:00<Q21S67>L011cW0R480acW00@U
:Be[:DXU:@8Li`099BTYBR487>LQ22DY:DXU:AcW008Q20047>LU:BDY9BT2
8@P36<H28@P27>L00b489BTU:@039BT28@P00bDY:DXU:@029BT2:DX00bDY
:DX]J`02:DX48@P012DY8@PLiacW0R4800@Lib488@PU:@<Q208U:@038@PU
:B4800<U:@@Q20059BTQ22489BTQ20029BT01BU:9BTU:BU:;F/01RU:00<U
:B489BT00bU:00DU:BU:<H`aS2U:00@Q20039BTLib48008U:@078@PU:B48
8@PU:BU:9BT02B4800DLibU:<H`aS2U:008Q2004:DXQ22DY7>L28@P39BT0
32e[>Lhe[CF]9BTQ22DY8@PYBRDY8@PLi`<Q2004:DXaS2e[9BT27>L00bDY
8@PQ20037>L00b489BTU:@029BT01R489BTYBRU:;F/YBP8Q20039BTQ2248
008U:@8Q208U:@8aS08]J`@U:@048@PYBRU::DX38@P01BDY8@PU:B489BT0
0bU:00DU:B489BTU:B48008U:@04:DXaS2e[;F/2:DX01Re[:DXYBRU:9BTY
BP8]J`05:DX]Jc6<=JdaS004:DX3;F/2<H`2:DX49BT3:DX01Be[<H`e[C6<
=Jd00S6<00<]JbU:;F/012e[00<aS2e[:DX00RU:00<]Jc6<;F/00be[00La
S2e[:DX]Jc6<;F/aS002;F/2<H`2=Jd2>Lh0136<=Jde[C6<0SF]136<0SF]
00<aS2U:;F/01C6<00@]Jc6<=JdaS08e[@05;F/YBRe[<H`icP02=Jd01C6<
=Jde[C6<;F/00RU:00<]JcF]<H`00S6<00<]JbU:;F/0136<1Re[00HaS2e[
;F/YBRe[:DX5;F/01C6<;F/aS36<=Jd00be[00<aS2e[:DX00Re[00@aS2e[
;F/]J`<aS0@]J`8aS04Li`0000<48@0012400P@Q00<000@Q12400`@Q00L8
@QcW<H`Q21BU8@PU:@027>L00aS68@PHaP027>L48@P011cW8@PQ22DY1bU:
0bDY0R4800<LiaS66<H00QS600HLiaS67>LHaQcW6<H27>L00b487>LQ2002
8@P37>L38@P39BT012487>LLibDY0bU:00@U:B487>LQ208YBP039BTQ22DY
008YBP049BTLib489BT2:DX00b489BTYBP029BT00b487>LLi`027>L28@P0
0acW8@PU:@02;F/012U:7>LLiaS61b480QcW0b480RDY0R480QcW0R4800<U
:B488@P0124800<HaQcW5:D00acW00HQ22DY8@PLib487>L28@P29BT00acW
9BTU:@029BT011cW6<HQ22480bU:0RDY00<Q22DY9BT00RDY00<Q21cW7>L0
0R480QcW00DQ21cW8@PQ21cW008Q208U:@@Q20047>LHaQcW8@P29BT28@P0
1BDY;F/]Jbe[:DX00bDY00<Q21cW7>L01AcW00DYBRe[;F/YBQS600<Li`06
8@PLiacW7>LU:B480QcW0RU:00<U:AcW7>L00b480QcW00XQ22DY:DXU:B48
7>LQ21cW9BTYBP8Q20036<HDYAcW00@Li`068@PLib488@PU:BU:0R4800@U
:B48:DXYBP<U:@DYBP039BTQ21cW00@Q20047>LQ22DY9BT38@P29BT28@P0
0bDY8@PQ20028@P012DY8@PU:BDY124800<U:BU::DX00bDY00LYBRDY8@PU
:BU:;F/YBP029BT5:DX01bDY:DXYBRDY:DX]JbU:008U:@068@PU:B487>LQ
22DY1R4800<U:BU:9BT00R4800@LibDY8@PQ20@Li`05:DX]Jc6<:DXQ2003
9BT28@P00bDY8@PU:@029BT01C6<=JdicS6<8@P012DY124800<U:B48:DX0
0RU:00<U:AcW7>L00R480RDY0acW00<Q22DY9BT00RDY00<Q22DY:DX00RU:
00@U:B488@PQ20<U:@8Q20039BTYBRe[00<aS003:DXU:BDY008Q20059BT]
JbU:9BTLi`039BT28@P00bDY:DXYBP029BT48@P012DY8@P]Jbe[0S6<00D]
JbU::DXYBRe[00@YBP08;F/YBRU:=JdaS2e[:DXU:@<]J`05<H`]Jc6<;F/Y
BP039BT01BU:9BTU:BDY:DX00S6<0SF]00<aS3F]<H`012e[00<YBRe[;F/0
0Re[00LYBRe[:DX]Jc6<;F/YBP02;F/01C6<;F/YBRU:;F/00S6<0be[00@a
S3F]>LhicP8e[@<aS007=JdaS36<<H`]Jc6<=Jd00c6<0Re[00<e[C6<<H`0
0Re[00TaS3F]=Jde[C6<;F/YBS6<=Jd00SW>00<aS3F]=Jd00S6<0RU:00@]
Jc6<=Jde[@8]J`07:DX]Jbe[;F/aS2e[<H`00Re[00<YBRe[;F/01Be[0RU:
12e[00PaS2e[:DX]Jc6<=JdaS2U:0Re[0bU:0S6<12e[00<aS2e[;F/00RU:
00<aS3F]<H`00B48000312400`0012448@0412401`00248Lic6<9BTDYAcW
008Q208Li`8HaP057>LHaQcW8@PLi`068@P49BT2:DX29BT00b489BTU:@02
8@P01AcW6<HLiacW8@P00RDY00<LiaS66<H00R4800HLib488@PQ22DY8@P2
9BT38@P49BT01B489BT]Jbe[:DX00R4800DU:B488@PLib4800<U:@03:DXQ
22DY008Q20049BTQ22489BT2:DX012487>LLiacW0R4800@Lib488@PYBP8]
J`04<H`]JbDY8@P27>L00bDY7>LLi`077>L01R489BTYBRU:9BTLi`@Q2005
9BTYBRDY8@PLi`028@P011cW6<HDYAS60b4800<Lib488@P012DY00<Q22DY
8@P00R4800DU:AcW8@PLib48008U:@03:DXU:BDY00<YBP039BTQ22DY008Q
208Li`038@PLib4800TQ208U:@038@PLiacW008Li`048@PU:BDY9BT28@P0
1BDY:DXU:BDY:DX00bDY00<HaQcW6<H00acW00HU:Be[<H`YBQcW6<H67>L4
8@P02QcW9BTYBRU:9BTLib489BTQ21cW0R4800DU:B48:DXYBRDY008Q208U
:@8Li`8HaP8Q20049BTQ22489BT48@P012U:;F/YBRU:0bDY1BU:0be[0RU:
00@U:B488@PLi`8Q208U:@8Li`039BTQ21cW008Li`8U:@<Q208U:@048@PL
ib488@P29BT48@P39BT4:DX29BT00bU:9BTYBP04:DX39BT00bU:<H`aS002
;F/00bU:;F/]J`02;F/49BT2:DX29BT3;F/02bU:8@PU:BDY8@PU:B489BTQ
21cW8@P00RDY00HYBRDY8@PQ21cW8@P29BT38@P012DY:DXYBS6<0SF]00<a
S2U:8@P00RDY00HYBRDY8@PLib48:DX2;F/00bU:8@PU:@029BT00b487>LU
:@027>L49BT28@P2:DX012e[:DXU:AcW0R4800LU:B489BTU:B48:DXU:@03
=Jd0136<:DXQ22DY0R480RU:00@U:B488@PQ208U:@038@PU:BDY008YBP03
9BTQ224800<U:@03:DXU:BU:008aS006:DXU:BDY:DX]JbU:12e[0c6<0Re[
00<YBRe[:DX012e[0S6<00<e[BU:9BT00R4800<U:BU::DX00RU:00<]Jc6<
<H`00Re[00@e[C6<<H`YBP8]J`8aS08]J`04:DX]JbU::DX2;F/2<H`01BU:
9BTU:BU:<H`00be[00@YBRe[;F/aS08e[@8aS009=JdicS6<<H`]Jc6<=Jda
S2U:008]J`<aS003:DXaS36<00@]J`DaS007>LhaS36<:DX]JcF]>Lh00SF]
0S6<00le[C6<;F/aS2e[<H`e[C6<:DXU:BU:=JdaS2e[:DX00Re[00<YBRe[
:DX00bU:0Re[00@YBRDY:DX]J`8aS007;F/YBRe[;F/aS3F]<H`00be[00<a
S2e[<H`00S6<00L]JbU:;F/e[C6<;F/YBP02;F/012U:9BT]Jbe[0BDY0000
0`001240000312402P0012448@001248@QS6=JdU:AS60QcW00@Q22DY7>LL
i`8HaP8Li`HQ20059BTQ22489BTQ2002:DX012DY8@PQ22480RDY0R4800@L
iaS67>LLi`<Q20LLi`038@PU:BDY00<U:@038@PLib48008U:@<Q2008:DX]
JbU::DXQ21cW8@PLi`<Q20<U:@8Q20037>LQ22DY008U:@048@PU:BDY9BT2
8@P27>L011S68@PQ22DY0R4800DYBS6<=Jd]JbDY00@Q20037>LHaQcW00DL
i`8Q208YBP039BTQ21cW008Q20037>LQ22DY008U:@8Q20039BTQ21cW008D
Y@036<HLibDY008Q20037>LQ21cW008Q208U:@@Q20037>LQ224800<Q2003
9BTYBRU:00PU:@<Li`8Q208Li`8Q20097>LQ22488@PLibDY:DXU:B48008L
i`<Q20<U:@<Q20049BTYBRU::DX29BT00b487>LLi`037>L01ABU9BT]JcF]
;F/011cW00<Q21cW6<H011cW0R480RU:0RDY00<Q21cW8@P00QcW1BDY00TY
BRDY8@PLib489BTQ21cW5:D00QcW00@Q22DY8@PLi`@Q20049BTYBRDY:DX4
9BT012e[:DXYBRDY0RU:00D]JbU:9BTYBRDY008Q208Li`LQ20047>LQ21cW
8@P29BT38@P39BT28@P00bDY8@PQ20069BT4:DX39BT5:DX00bDY8@PU:@02
:DX4;F/3:DX01C6<;F/YBRDY8@P00RU:0RDY0RU:0Re[00<YBRDY9BT00RDY
124800<LibDY8@P00RDY0R480QcW0R4800<U:B488@P00RDY00@YBRDY;F/e
[@8aS0DU:@8Q20037>LQ22U:008]J`049BTQ22489BT28@P37>L28@P00bU:
9BTU:@028@P012U:;F/YBRU:0b4800lU:B489BTU:B487>LU:BU:=JdicSF]
;F/YBR489BT00R4812DY124812DY00DYBRDY8@PU:B4800@U:@04;F/aS2e[
:DX29BT01Be[:DXYBRe[<H`00Re[0RU:0c6<0bU:00<aS2e[;F/00Re[0S6<
0bDY00<Q22U::DX00bU:136<00<YBRe[;F/01Be[0S6<0Re[12U:0Re[12U:
0Re[0bU:0be[0S6<00De[C6<;F/aS3F]00<aS005=JdaS36<<H`YBP02;F/0
0c6<;F/]J`02;F/2<H`3;F/0136<=Jd]Jc6<0SF]00LaS2e[;F/aS3F]>Lhe
[@04<H`00be[<H`aS002<H`3:DX2;F/2<H`00be[:DXYBP03;F/00bU:9BTY
BP02;F/012U:9BTYBRe[0c6<0Re[00<YBRe[=Jd00S6<0Re[00LaS2e[;F/]
Jc6<;F/YBP02;F/2<H`2:DX01Be[:DX]Jbe[:DX00B48000412400`001244
8@0512401QcW=JdYBQS68@PU:@<Q20057>LHaQcW6<HLi`028@P47>L01b48
9BTU:B489BTQ22DY008Q20039BTQ2248008Q20049BTQ22487>L38@P01AcW
8@PLib486<H00QcW0b480RDY00<Q21cW7>L00QcW00HQ22DY9BTU:B489BT2
:DX022DY8@PU:BDY7>LQ21cW8@P39BT01RU:8@PQ21cW8@PU:@@Q208U:@8Q
20@Li`038@PU:BU:00DYBP049BTLiacW6<H28@P27>L01AS67>LLib487>L0
0R4800<Lib487>L011cW00@Q21cW7>LLi`8Q208Li`038@PLiaS6008HaP8L
i`038@PU:B4800@U:@05:DX]JbU:8@PLi`028@P00acW8@PLi`039BT2:DX0
0bDY8@PU:@039BT48@P00acW8@PQ20067>L29BT28@P37>L01B489BTQ22DY
8@P00bDY12481BU:00<Q21cW6<H00R4800DHaQcW8@PU:BU:008Q20047>LH
aQcW8@P39BT01B489BTLiacW:DX00Re[00LYBQcW8@PQ21cW8@PLi`038@P0
12U:;F/YBRU:0RDY0R4800DLiaS66<HLib48008U:@048@PLiacW7>L29BT0
1Be[:DXU:BDY;F/00RU:00HQ22DY9BTU:B489BT2:DX3;F/01RDY8@PLiacW
8@PLi`8Q20079BTQ22486<HLib489BT00R4800@U:B489BTU:@DQ20087>LQ
22489BTQ21cW8@PYBP8]J`8YBP039BTYBRDY008U:@068@PU:BU:;F/YBRDY
0RU:0SF]00@]JbU:9BTQ208]J`03<H`]Jbe[00<Q20039BTYBRDY00@U:@03
8@PU:BDY008U:@068@PU:BDY9BTQ22DY0R480acW00<Q22DY9BT00b4800@L
ib489BTU:@@YBP038@PU:BU:008]J`059BTQ22488@PYBP029BT012U:9BTY
BRDY1QcW00@Q21cW9BTQ208U:@<YBP8U:@0<8@PU:B489BTQ22DY8@PU:BU:
;F/e[Cg_0SW>00H]Jb488@PU:BU:9BT28@P39BT38@P3:DX012487>LQ22e[
0S6<00<YBRDY:DX00S6<00<]JbU:9BT00bDY00DYBRe[<H`aS2U:008]J`08
=JdicS6<;F/YBRe[=JdicP@aS005;F/YBR488@PU:@02:DX01Re[:DX]JcF]
>LhaS08YBP04;F/aS2e[:DX6;F/2<H`3;F/00bU:<H`aS002;F/2:DX2;F/0
136<;F/]Jbe[0SF]00DaS2e[<H`e[C6<00<]J`06<H`e[CF]<H`]Jc6<0be[
136<0Re[00<YBRe[;F/0136<00De[C6<=JdaS2e[008aS004>Lhe[C6<;F/2
<H`01Be[<H`e[CF]<H`00bU:00<]Jc6<;F/00RU:0Re[0RU:00@U:BU::DX]
J`<YBP03;F/YBS6<00@aS004:DX]Jc6<<H`2=Jd4<H`6;F/00c6<;F/]J`02
<H`3;F/2<H`19BT0000400048@@Q000612401P00248LicF]:DXHaP8Li`<Q
208Li`036<HLiacW008Li`<Q208Li`038@PU:BDY00@Q20047>LQ22DY9BT5
8@P27>L012487>LLiacW0b4800@HaQcW8@PLi`@Q208Li`<Q20DU:@8YBP03
9BTQ2248008Q20057>LQ22489BTQ20039BT00b487>LQ20038@P49BT27>L2
6<H27>L01b489BTYBRe[:DXU:BU:008U:@078@PLiacW8@PLib486<H00acW
1B4811cW0R4800<Lib487>L00R480QcW0R480QcW0QS600HLib489BTQ22DY
8@P39BT012U:9BTU:B480acW0R4800@U:B488@PYBP8U:@<Q20039BTYBR48
00<Q20DLi`038@PLiacW00<Q20039BTLib48008Li`DQ20@U:@057>LQ2248
8@PU:@02:DX00be[:DXU:@027>L28@P27>L00b48:DXYBP027>L26<H01AcW
8@PU:BU:9BT00b4800DLibU::DX]JbU:00<Li`<Q20037>LQ2248008YBP03
;F/U:BDY008U:@038@PLiaS6008Li`058@PU:BDY7>LQ20027>L00b489BTU
:@029BT3:DX00bDY:DXU:@039BT022489BTYBRU:;F/YBRDY8@P27>L28@P0
0bDY8@PQ20038@P00acW8@PU:@028@P00acW8@PQ20078@P00acW8@PQ2002
8@P012U:;F/]JbU:1BDY0R4800@U:BU:;F/]J`<U:@07:DXaS3W><H`]Jb48
9BT00be[00<YBRDY9BT01RDY00<YBRDY8@P00R480RDY00<Q22DY8@P00R48
0bDY00<Q21cW7>L00R4800@YBRDY8@PLi`<Q208U:@04:DX]JbDY8@P29BT0
12U:;F/YBRDY0b4800<YBRDY9BT00bDY0R481QcW0b4800LU:B489BTYBRe[
:DXU:@058@P29BT02248;F/aS3W>?NlicSF]:DX38@P01BDY:DXU:B489BT0
0R4800@U:B489BTU:@8YBP049BTQ2248:DX3<H`3:DX0236<;F/U:BDY8@PY
BRe[:DX5;F/2<H`01cg_=JdYBRDY:DXe[Cg_00<aS08]J`<U:@068@PYBRU:
:DX]Jc6<0SF]00@aS2U::DXYBP<]J`8YBP03;F/aS2e[008]J`8aS006;F/Y
BRU:;F/aS2e[0bU:00<]Jc6<<H`012e[00@aS2e[<H`e[@8aS007:DX]Jbe[
<H`e[C6<=Jd00Re[00<aS2e[;F/00Re[0S6<1Be[0c6<0SF]0S6<0Re[0SF]
0S6<0Re[0S6<0Re[00<icSF];F/00bU:12e[0RU:0Re[0RU:00DU:BU:;F/Y
BRDY008YBP@]J`<aS005:DX]Jc6<>Lhe[@03<H`01bU:;F/aS2e[<H`]JbU:
00@]J`8aS004;F/aS36<<H`18@P000848@0500048@@Q1240000512401aS6
<H`U:AcW9BTYBRDY00<Q20036<HLiacW008Q208Li`8Q208Li`068@PU:BDY
9BTQ22DY0R4800HLib488@PU:B489BT28@P01BDY8@PQ21cW8@P011cW0R48
00@Lib487>LQ20<Li`046<HLiacW7>L29BT00bU:9BTU:@038@P00acW8@PQ
20038@P00bDY8@PQ20059BT00b489BTQ20068@P37>L00aS67>LU:@029BT0
22U:9BTQ21cW9BT]JbDY7>L26<H00b487>LQ20037>L48@P37>L48@P77>L3
8@P37>L78@P022DY:DXYBRDY8@PU:B487>L28@P012DY:DX]JbU:1BDY0b48
0bDY0b4800<U:B488@P00QcW0R4800<U:B488@P01B4800@Lib487>LQ20@U
:@@Q208U:@<YBP<U:@05;F/YBRDY7>LQ20029BT00bU:9BTQ20048@P3:DX0
0bDY8@PYBP03:DX01C6<;F/U:B487>L00b4800DLib489BTU:BU:008]J`04
<H`]JbU:9BT47>L02B489BTU:BDY8@PLib489BTYBP039BT4:DX01be[9BTQ
22487>LU:BU:008aS006;F/YBRU:8@PU:AcW0R480bDY00TQ22DY9BTLiaS6
8@PU:BU:8@P00RDY0bU:00<U:AcW8@P00b4800@Lib488@PU:@8YBP039BTY
BRDY00DU:@LYBP04<H`]JbU::DX28@P00bDY8@PU:@028@P011cW8@PQ2248
0RDY00DYBRDY9BTYBRDY00<Q20049BTYBRU:9BT28@P49BT00acW9BTU:@02
:DX28@P00bDY8@PQ20028@P69BT3:DX01bDY8@PQ22DY:DXU:B4800<U:@<Q
20047>LQ21cW8@P27>L28@P29BT02B489BTU:BDY:DXU:BU:9BTYBP029BT0
12U:;F/aS3F]0SW>0Re[00<YBRDY9BT00R480RDY12U:00<U:BU:9BT00bU:
00DU:B488@PU:BU:008]J`04:DX]Jbe[;F/2:DX01B489BTU:BDY:DX01C6<
00De[CW><H`]JbU:008]J`05<H`icSW>>LhaS002;F/012U:;F/YBRU:0RDY
0be[0S6<0bU:00<]Jc6<<H`00Re[0bU:0S6<00<icSF];F/00Re[0S6<00<e
[Be[:DX00RDY0Re[00<aS2e[;F/00be[0S6<00<e[C6<<H`00Re[00<aS2e[
;F/00Re[00<aS2e[;F/00Re[00@aS3F]<H`YBP8]J`03<H`e[C6<00PaS003
=JdaS36<00PaS006;F/aS36<<H`]Jc6<0Re[0RU:0be[00<YBRDY:DX00Re[
00LYBRe[<H`]Jc6<:DX]J`02:DX01Be[<H`aS36<;F/00S6<00@icSF]<H`]
J`@aS08]J`<aS006;F/aS36<=JdaS2e[0S6<0BDY00001@@Q00048@@Q0000
1`@Q00@HaSF]9BTLi`<U:@038@PLib48008Li`036<HLiacW008Li`8Q2003
7>LQ22DY008U:@078@PU:B487>LHaR487>L00bDY0R480RDY12480acW0R48
0QcW00@Q22DY8@PQ20HLi`078@PU:Be[9BTLib489BT00R4800@Lib487>LU
:@8Q20079BTQ22489BTQ22DY8@P012DY1B4800<U:AcW6<H00QcW0RDY00DY
BRDY9BTLib48008YBP039BTQ21S6008Li`038@PLiacW008Li`038@PLiacW
008Li`078@PLib487>LQ21cW8@P00acW00DQ21cW7>LLibDY008Q20066<HL
ib487>LQ22DY0b480RDY00<YBRDY8@P00R4800DLibDY8@PYBRDY00@YBP8U
:@078@PLiacW8@PU:BU:9BT00b480RDY00<Q21cW7>L00R4800@Lib488@PL
i`<Q208Li`HQ208U:@<Q208U:@<YBP8U:@<YBP049BTQ21cW9BT2:DX28@P0
11cW8@PQ22DY0RU:0RDY00PQ22U::DX]JbU:;F/YBRDY0QcW00<Q22DY8@P0
0R480RDY0be[00LaS2U:9BTU:AcW8@PLi`028@P39BT38@P39BT00b489BTY
BP03:DX01bDY8@PU:BDY8@PU:BU:008aS003:DXU:BU:00<Q20<U:@068@PU
:BDY9BTQ21cW0R4800LU:BU:9BTU:B489BTYBP039BT011cW8@PLibDY0QcW
00HQ22U::DXYBRDY:DX29BT00b489BTU:@029BT2;F/02RU:9BTYBRe[<H`]
JbDY:DXU:AcW0R4800PU:B488@PHaQcW8@PU:BU:0RDY00<YBRDY:DX00RDY
0R4800@U:BU::DXU:@8Q20039BTQ22DY00<Q20039BTYBRDY008Q208U:@03
8@PLib48008U:@8Q20<U:@05:DXU:B487>LU:@02:DX38@P39BT012487>LL
ibDY0R4800<Lib487>L00b4812DY00<Q22DY9BT00RU:00DU:BU::DXYBS6<
00<e[@06;F/YBRU:8@PU:B480RDY00<Q22DY9BT00bU:0bDY0RU:00TU:B48
8@PU:BU:;F/U:BU:;F/00S6<00XYBR489BTQ22U:;F/YBRe[<H`e[@@aS006
=JdaS2e[;F/YBRe[0cW>00<aS2e[;F/00bU:00<U:BU:9BT00RU:00T]Jc6<
<H`YBRDY:DX]JcF]<H`00be[00@YBRe[;F/aS0<e[@8]J`03<H`e[C6<00DY
BPL]J`03:DXaS36<008aS003;F/aS36<00@]J`<aS0<]J`04<H`]Jbe[:DX3
<H`00be[<H`]J`08<H`01Be[<H`e[C6<=Jd00be[136<00<]Jc6<<H`00Re[
00DU:Be[;F/aS2e[008YBP8]J`<YBP04;F/aS2U:;F/2:DX3;F/01C6<;F/a
S36<>Lh00SF]00@]Jc6<;F/e[@8aS004;F/aS2e[<H`2;F/01C6<=JdaS36<
;F/00S6<0BDY00000`0012448@0212401@0012448@@Q00000`@Q00D000@Q
12448@0000<48@0500048@@Q1240000312401@0012448@@Q00000`@Q00D0
00@Q12448@0000<48@0500048@@Q1240000312401@0012448@@Q00000`@Q
00D000@Q12448@0000<48@0500048@@Q1240000312401@0012448@@Q0000
0`@Q00D000@Q12448@0000<48@0500048@@Q1240000312401@0012448@@Q
00000`@Q00D000@Q12448@0000<48@0500048@@Q1240000312401@001244
8@@Q00000`@Q00D000@Q12448@0000<48@0500048@@Q1240000312401@00
12448@@Q00000`@Q00D000@Q12448@0000<48@0500048@@Q124000031240
1@0012448@@Q00000`@Q00D000@Q12448@0000<48@0500048@@Q12400003
12401@0012448@@Q00000`@Q00D000@Q12448@0000<48@0500048@@Q1240
000312401@0012448@@Q00000`@Q00D000@Q12448@0000<48@0500048@@Q
1240000312401@0012448@@Q00000`@Q00D000@Q12448@0000<48@050004
8@@Q1240000312401@0012448@@Q00000`@Q00D000@Q12448@0000<48@05
00048@@Q1240000312401@0012448@@Q00000`@Q00D000@Q12448@0000<4
8@0500048@@Q1240000312401@0012448@@Q00000`@Q00D000@Q12448@00
00<48@0500048@@Q1240000312401@0012448@@Q00000`@Q00D000@Q1244
8@0000<48@0500048@@Q1240000312401@0012448@@Q00000`@Q00D000@Q
12448@0000<48@0500048@@Q1240000312401@0012448@@Q00000`@Q00D0
00@Q12448@0000<48@0500048@@Q1240000312401@0012448@@Q00000`@Q
00D000@Q12448@0000<48@0500048@@Q1240000312401@0012448@@Q0000
0`@Q00D000@Q12448@0000<48@0500048@@Q1240000312401@0012448@@Q
00000`@Q00D000@Q12448@0000<48@0500048@@Q1240000312401@001244
8@@Q00000`@Q00D000@Q12448@0000<48@0500048@@Q1240000312401@00
12448@@Q00000`@Q00D000@Q12448@0000<48@0500048@@Q124000031240
1@0012448@@Q00000`@Q00D000@Q12448@0000<48@0500048@@Q12400003
12401@0012448@@Q00000`@Q00D000@Q12448@0000<48@0500048@@Q1240
000312401@0012448@@Q00000`@Q00D000@Q12448@0000<48@0500048@@Q
1240000312401@0012448@@Q00000`@Q00D000@Q12448@0000<48@050004
8@@Q1240000312401@0012448@@Q00000`@Q0@000@@Q0@@Q000312401@00
12448@@Q00000`@Q00D000@Q12448@0000<48@0500048@@Q124000031240
1@0012448@@Q00000`@Q00D000@Q12448@0000<48@0500048@@Q12400003
12401@0012448@@Q00000`@Q00D000@Q12448@0000<48@0500048@@Q1240
000312401@0012448@@Q00000`@Q00D000@Q12448@0000<48@0500048@@Q
1240000312401@0012448@@Q00000`@Q00D000@Q12448@0000<48@050004
8@@Q1240000312401@0012448@@Q00000`@Q00D000@Q12448@0000<48@05
00048@@Q1240000312401@0012448@@Q00000`@Q00D000@Q12448@0000<4
8@0500048@@Q1240000312401@0012448@@Q00000`@Q00D000@Q12448@00
00<48@0500048@@Q1240000312401@0012448@@Q00000`@Q00D000@Q1244
8@0000<48@0500048@@Q1240000312401@0012448@@Q00000`@Q00D000@Q
12448@0000<48@0500048@@Q1240000312401@0012448@@Q00000`@Q00D0
00@Q12448@0000<48@0500048@@Q1240000312401@0012448@@Q00000`@Q
00D000@Q12448@0000<48@0500048@@Q1240000312401@0012448@@Q0000
0`@Q00D000@Q12448@0000<48@0500048@@Q1240000312401@0012448@@Q
00000`@Q00D000@Q12448@0000<48@0500048@@Q1240000312401@001244
8@@Q00000`@Q00D000@Q12448@0000<48@0500048@@Q1240000312401@00
12448@@Q00000`@Q00D000@Q12448@0000<48@0500048@@Q124000031240
1@0012448@@Q00000`@Q00D000@Q12448@0000<48@0500048@@Q12400003
12401@0012448@@Q00000`@Q00D000@Q12448@0000<48@0500048@@Q1240
000312401@0012448@@Q00000`@Q00D000@Q12448@0000<48@0500048@@Q
1240000312401@0012448@@Q00000`@Q00D000@Q12448@0000<48@050004
8@@Q1240000312401@0012448@@Q00000`@Q00D000@Q12448@0000<48@05
00048@@Q1240000312401@0012448@@Q00000`@Q00D000@Q12448@0000<4
8@0500048@@Q1240000312401@0012448@@Q00000`@Q00D000@Q12448@00
00<48@0500048@@Q1240000312401@0012448@@Q00000`@Q00D000@Q1244
8@0000<48@0500048@@Q1240000312401@0012448@@Q00000`@Q00D000@Q
12448@0000<48@0500048@@Q1240000312401@0012448@@Q00000`@Q00D0
00@Q12448@0000<48@0500048@@Q1240000312401@0012448@@Q00000`@Q
00@000@Q12448@4000000?l000@Q00048@00124000@Q00048@00124000@Q
00048@00124000@Q00048@00124000@Q00048@00124000@Q00048@001240
00@Q00048@00124000@Q00048@00124000@Q00048@00124000@Q00048@00
124000@Q00048@00124000@Q00048@00124000@Q00048@00124000@Q0004
8@00124000@Q00048@00124000@Q00048@00124000@Q00048@00124000@Q
00048@00124000@Q00048@00124000@Q00048@00124000@Q00048@001240
00@Q00048@00124000@Q00048@00124000@Q00048@00124000@Q00048@00
124000@Q00048@00124000@Q00048@00124000@Q00048@00124000@Q0004
8@00124000@Q00048@00124000@Q00048@00124000@Q00048@00124000@Q
00048@00124000@Q00048@00124000@Q00048@00124000@Q00048@001240
00@Q00048@00124000@Q00048@00124000@Q00048@00124000@Q00048@00
124000@Q00048@00124000@Q00048@00124000@Q00000?l000@Q00048@00
124000@Q00048@00124000@Q00048@00124000@Q00048@00124000@Q0004
8@00124000@Q00048@00124000@Q00048@00124000@Q00048@00124000@Q
00048@00124000@Q00048@00124000@Q00048@00124000@Q00048@001240
00@Q00048@00124000@Q00048@00124000@Q00048@00124000@Q00048@00
124000@Q00048@00124000@Q00048@00124000@Q00048@00124000@Q0004
8@00124000@Q00048@00124000@Q00048@00124000@Q00048@00124000@Q
00048@00124000@Q00048@00124000@Q00048@00124000@Q00048@001240
00@Q00048@00124000@Q00048@00124000@Q00048@00124000@Q00048@00
124000@Q00048@00124000@Q00048@00124000@Q00048@00124000@Q0004
8@00124000@Q00048@00124000@Q00048@00124000@Q00048@00124000@Q
00048@00124000@Q00048@00124000@Q00048@00124000@Q00048@001240
00@Q0000084000@Q00048@00124000@Q00048@00124000@Q00048@001240
00@Q00048@00124000@Q00048@00124000@Q00048@00124000@Q00048@00
124000@Q00048@00124000@Q00048@00124000@Q00048@00124000@Q0004
8@00124000@Q00048@00124000@Q00048@00124000@Q00048@00124000@Q
00048@00124000@Q00048@00124000@Q00048@00124000@Q00048@001240
00@Q00048@00124000@Q00048@00124000@Q00048@00124000@Q00000@@Q
0000\
\>"], "Graphics",
  Evaluatable->False,
  ImageSize->{640, 480},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"Macintosh 3.0",
ScreenRectangle->{{0, 1024}, {0, 748}},
WindowToolbars->{"RulerBar", "EditBar"},
WindowSize->{621, 712},
WindowMargins->{{4, Automatic}, {Automatic, 1}},
MacintoshSystemPageSetup->"\<\
00<0001804P000000]P2:?oQon82n@960dL5:0?l0080001804P000000]P2:001
0000I00000400`<300000BL?00400@00000000000000060801T1T000000@0000
00000000004000000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 60, 0, 136, "Title"],
Cell[1794, 53, 108, 4, 36, "Text"],

Cell[CellGroupData[{
Cell[1927, 61, 38, 0, 50, "Section"],

Cell[CellGroupData[{
Cell[1990, 65, 819765, 10124, 512, 819650, 10120, "GraphicsData", 
"Bitmap", "Graphics",
  Evaluatable->False],
Cell[821758, 10191, 771615, 9530, 512, 771500, 9526, "GraphicsData", 
"Bitmap", "Graphics",
  Evaluatable->False]
}, Open  ]],
Cell[1593388, 19724, 110, 4, 36, "Text"],

Cell[CellGroupData[{
Cell[1593523, 19732, 57, 1, 46, "Subsection"],

Cell[CellGroupData[{
Cell[1593605, 19737, 22333, 556, 183, 5181, 338, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[1615941, 20295, 22929, 562, 182, 5183, 338, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[1638931, 20864, 23, 0, 30, "Section"],

Cell[CellGroupData[{
Cell[