(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[   1486661,      34071]*)
(*NotebookOutlinePosition[   1487544,      34099]*)
(*  CellTagsIndexPosition[   1487500,      34095]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Doppler Effect", "Title",
  TextAlignment->Center,
  TextJustification->0],

Cell[CellGroupData[{

Cell["Set Up", "Section"],

Cell[TextData[StyleBox[
"A cart with a oscillator with a frequency of f=2,929.6875Hz is pushed on an \
airtrack. The sound is recorded with a Mac and the cart is tracked with a \
sonic ranger.",
  FontSize->18]], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Data", "Section"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .60938 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 .60938 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .60938 L
0 .60938 L
closepath
clip
newpath
% Start of sampled sound
1 string
22050. 234432 8
{ currentfile 1 index readhexstring pop }
 false 1 sampledsound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pop
% End of sampled sound
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 175.5},
  ImageMargins->{{62, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000[a000`40O003h00Oo`008@0000000`00
Oomoo`3oOolMOol100000003001oo`0001X00?moo`=oo`40000000<007oo00008000o7oo0@000000
0`00Ool0000R0013Ool2002eOol100000003001oo`0002800003Ool007oo009oo`@003Uoo`<009Mo
o`06001oo`00Ool007oo0`001Goo00<007ooOol00goo2@000Goo0@0000000`00Ool0000`0002Ool0
0`00Oomoo`07Ool00`00Oomoo`0UOol30025Ool00`00Ool0000:00000goo0000000O0001Ool10000
0003001oo`0003@000Ioo`D000=oo`03001oogoo01Uoo`05001oo`00001oo`07001:Ool00`00Oomo
o`0@Ool00`00Oomoo`0;Ool01000Ool007oo0P0017oo?0000Goo0@0000000`00Ool0001:00000goo
0000000200000goo00000002Ool00`00Ool0000W00000goo001oo`0200001Woo00000000Ool000=o
o`05001oogooOol00006Ool01000Ool007oo0`001goo00@007oo000000Aoo`05001oo`00001oo`1Y
0001Ool100000003001oo`000?l001`0005oo`40000000<007oo0000o`0070000Goo0@0000000`00
Ool0001B00000goo001oo`0T00000goo00000005000017oo000000002goo00<007ooOol01Woo00<0
07ooOol00P0000Ioo`00000007oo0002Ool400000goo001oo`1^0001Ool100000003001oo`0003@0
00Eoo`H001moo`03001oogoo00L0009oo`03001oogoo05Uoo`80009oo`03001oogoo00]oo`03001o
ogoo00Eooc/0005oo`40000000<007oo0000<00037oo00<007ooOol09Woo0P00QWoo3P0000=oo`00
00007@000Goo0@0000000`00Ool0000T00000goo001oo`02Ool3000hOol00`00Ool0002HOol20000
0goo00000003000;Ool90001Ool100000003001oo`000280049oo`03001oogoo0;Eoo`40000000<0
07oo00008@00ngoo0@0000000`00Ool0000200000goo0000000E001:Ool00`00Oomoo`2eOol10000
0003001oogoo01Eoo`03001oogoo0?moo`Eoo`400000o`008@0000000`00Oomoo`3oOolMOol10000
0003001oo`0006Aoo`800;Ioo`40000000<007ooOol0ogoo7Goo0@0000000`00Oomoo`1UOol00`00
Oomoo`2dOol100000003001oogoo0?mooaeoo`40000000<007ooOol0I7oo00<007ooOol0]Goo0@00
00000`00Oomoo`1TOol00`00Oomoo`2eOol100000003001oogoo0?mooaeoo`40000000<007ooOol0
ogoo7Goo0@0000000`00Oomoo`1TOol2002fOol100000003001oogoo06Aoo`03001oogoo0;Eoo`40
000000<007ooOol0ogoo7Goo0@0000000`00Oomoo`1TOol00`00Oomoo`2eOol100000003001oogoo
0?mooaeoo`40000000<007ooOol0ogoo7Goo0@0000000`00Oomoo`1TOol00`00Oomoo`2eOol10000
0003001oogoo0?mooaeoo`40000000<007ooOol0I7oo0P00]Woo0@0000000`00Oomoo`3oOolMOol1
00000003001oogoo06Eoo`03001oogoo0;Aoo`40000000<007ooOol0I7oo0P00]Woo0@0000000`00
Oomoo`3oOolMOol100000003001oogoo06Eoo`03001oogoo0;Aoo`40000000<007ooOol0IWoo00<0
07ooOol0/goo0@0000000`00Oomoo`0:Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00<007oo
Ool0BWoo00<007ooOol0]Goo0@0000000`00Oomoo`05Ool01000Oomoo`001Woo00<007ooOol0ogoo
2goo0@0000000`00Oomoo`07Ool20002Ool01@00Oomoogoo0000ogoo3Goo0@0000000`00Oomoo`05
Ool01000Ool007oo0`0000=oo`00Ool0100000=oo`00Ool0ogoo1goo0@0000000`00Ool00003Ool<
00000goo00000007001;Ool2002fOol100000004001oo`00OolB00000goo0000000200000goo001o
o`1:Ool00`00Oomoo`2dOol100000003001oo`0000800003Ool0000000/0009oo`D00003Ool007oo
0?moo`=oo`40000000<007oo00006`000Woo0`00A7oo00<007ooOol0]Goo0@0000000`00Oomoo`3o
OolMOol100000003001oo`0000D00003Ool0000000<00005Ool007oo001oo`0;00000goo00000002
003lOol100000003001oogoo01400003Ool0000000`004Eoo`800;Eoo`40000000<007ooOol0ogoo
7Goo0@0000001000Ool007oo8000@goo0P00]Woo0@0000001000Oomoogoo0P0000=oo`0000000P00
0goo0`000Woo00<007ooOol00P0000Aoo`00Oomoo`800004Ool00000Ool20014Ool00`00Oomoo`2d
Ool100000005001oo`00001oo`02000017oo000007oo0`000goo00<007ooOol00`000goo2@00o7oo
0@0000000`00Ool0000600000goo0000000600001Goo00000000Ool00`0000=oo`0000001`00@goo
0`00]Goo0@0000000`00Ool00003Ool3000017oo001oogoo1@000goo00D007oo001oo`00009oo`@0
009oo`03001oogoo049oo`03001oo`000;Eoo`40000000<007oo00000P0000Aoo`00001oo`800003
Ool0000000H0009oo`03001oo`0000@00004Ool00000Ool30013Ool00`00Ool0002eOol100000005
001oogoo001oo`0200000goo00000003Ool20003Ool400000goo000000050003Ool30013Ool00`00
Oomoo`2eOol100000003001oo`0000l00003Ool0000000P00003Ool0000000D004Aoo`03001oogoo
0;=oo`40000000<007ooOol00Woo00@007ooOomoo`800003Ool0000000=oo`800003Ool007oo00Ao
o`D000=oo`8004Aoo`03001oogoo0;Aoo`40000000@007ooOol0009oo`03001oogoo00Qoo`05001o
o`00Ool00003Ool20002Ool00`00Oomoo`020017Ool00`00Oomoo`2cOol100000003001oo`0000L0
0003Ool0000000@00003Ool0000000<00006Ool007ooOol007oo0P0000=oo`00Ool00`00@Woo0`00
]Goo0@0000000`00Ool00004000017oo000000000Woo0`0000Aoo`00000000=oo`800003Ool007oo
00T0049oo`<009ioo`03001oogoo00eoo`07001oogoo001oo`00Ool00@0000001000Ool007oo1@00
00=oo`0000001`0000Eoo`00000007oo00800003Ool007oo00H00005Ool00000Ool00010Ool00`00
Oomoo`2ZOol00`00Oomoo`0200000goo00000002Ool100000007001oo`00Ool007oo000017oo0P00
1Goo0P000Woo00<007oo00000P0000=oo`00Ool00P0000Eoo`00Oomoo`0000Uoo`03001oogoo03Io
o`<009Qoo`03001oogoo00=oo`03001oogoo00Uoo`03001oo`00009oo`03001oo`0000=oo`400000
00<007oo00002@0000=oo`00Ool05`0000=oo`0000000Woo0P00>Woo0`0000Ioo`00Ool007oo002B
Ool7000<Ool90001Ool100000003001oogoo0?mooaeoo`40000000L007ooOol007oo001oo`070000
0goo000000070002Ool400000goo001oo`02Ool600000goo00000003000hOol30005Ool00`00Oomo
o`25Ool00`00Oomoo`07Ool300000goo0000000500000goo00000004Ool;0001Ool100000003001o
o`0000800003Ool007oo00X00003Ool00000009oo``00003Ool0000000T00004Ool00000000dOol0
0`00Ool00002Ool00`00Oomoo`02Ool00`00Oomoo`1nOol01P00Ool00000Ool0009oo`8000Eooa40
0003Ool0000000800003Ool0000000@0005oo`40000000<007ooOol0ogoo7Goo0@0000000`00Ool0
000700000goo0000000200000goo000000050002Ool800000goo0000000?00000goo001oo`0aOol3
000017oo001oo`00Pgoo2`000Woo80000Goo0@0000001`00Ool007oo001oo`0000Moo`80009oo`80
00Aoo`03001oogoo00Aoo`800004Ool00000Ool800002Goo000007oo001oo`00Ool00008Ool00`00
Oomoo`0VOol00`00Ool00028Ool;00001Goo001oo`00Ool00`0000=oo`0000002`0000=oo`000000
20000Goo0@0000001000Ool000000Woo0`0000=oo`00Ool01Woo00@007ooOol000Aoo`800004Ool0
07ooOol600000goo0000000300000goo000000060009Ool00`00Oomoo`0WOol20007Ool00`00Oomo
o`1nOolX00001Goo00000000Ool00@0000000`00Ool000030002Ool00`00Oomoo`04000017oo0000
07oo0P0000Eoo`00000007oo01d000Moo`03001oogoo02Moo`<0009oo`04001oo`00001gOol20003
Ool200000goo0000000/0001Ool100000006001oo`00001oo`0017oo00L007oo000007oo001oo`03
0002Ool20002Ool200000goo001oo`03000017oo001oo`000goo1P0000Aoo`00001oo`@000Ioo`03
001oo`0002Qoo`8000Aoo`03001oogoo07Eoo`03001oo`00008000Aoo`@00003Ool0000000H00003
Ool007oo00@00003Ool0000000800003Ool0000000D00003Ool0000000T00003Ool007oo00400000
00@007ooOomoo`@00005Ool00000001oo`0600000goo000000020002Ool600000goo001oo`0:0000
0goo000000070008Ool2000ROol01000Oomoogoo100000=oo`00Ool00P0000=oo`00Ool0Egoo00<0
07ooOol06Goo100000=oo`0000006P0000=oo`000000400000Eoo`00000007oo0040000000<007oo
00000P0000=oo`00Ool01goo00<007ooOol01goo00<007ooOol017oo00<007oo00000Woo0`0000Eo
o`00000007oo00<00003Ool0000000@000Ioo`<002Moo`03001oo`0000<007Moo`04001oo`00Ool3
000017oo000007oo1P000Woo2@0000=oo`0000000`0000Eoo`00Ool007oo00H000=oo`H00005Ool0
0000001oo`0100000003001oogoo00H00006Ool00000001oo`000Woo100000=oo`00Ool0200000=o
o`00000050000goo0P0000=oo`0000000`007goo0`0000Aoo`00001oo`<00003Ool00000008000=o
o`03001oogoo04moo`03001oogoo00@0009oo`03001oogoo00]oo`03001oogoo00Aoob000003Ool0
000001P0005oo`40000000@007oo001oo`8000Qoo`80009oo`03001oo`0000=oo`<000Ioo`H00003
Ool00000009oo``000Eoo`@0025oo`<0009oo`06001oo`00001oo`000Woo00<007ooOol00goo00<0
07ooOol0CWoo00@007ooOol000Aoo`03001oogoo00Qoo`8000Moo`l00003Ool0000000h00003Ool0
000000<0009oo`03001oo`0000=oo`80009oo`@00003Ool0000000Aoo`40000000<007ooOol00Woo
0P002Goo00<007oo00000`0000=oo`0000001Goo0`0000=oo`0000000`0000Aoo`00001oo`80009o
o`P0009oo`03001oo`0000800003Ool00000009oo`8001]oo`03001oo`0000Eoo`D0009oo`8005Ao
o`04001oogoo0002Ool00`00Oomoo`09Ool00`00Ool00007Ool300000goo0000000@000017oo0000
07oo1@0000Aoo`00001oo`D00005Ool007oo001oo`0700000goo001oo`020002Ool00`00Oomoo`01
00000003001oo`0000<000Ioo`<00004Ool007ooOol50004Ool200000goo000000020002OolD0000
0goo00000006000017oo001oogoo0`0067oo1`0000=oo`0000000P0000=oo`00Ool00P0000Aoo`00
0000009oo`03001oogoo00=oo`03001oogoo03Eoo`8000Ioo`8000Eoo`X000Qoo`L00004Ool007oo
OolG00000goo0000000;00001Goo00000000Ool00P0000=oo`0000003@000Goo0@0000000`00Ool0
000200000goo001oo`0400000goo001oo`030002Ool01P00Oomoogoo001oo`D000Aoo`04001oo`00
Ool:00000goo0000000C0002Ool01@00Oomoogoo00000goo00<007ooOol027oo00<007ooOol04`00
00Eoo`00000007oo00800006Ool007oo001oo`00=Goo1@001Woo00@007ooOomoo`d00003Ool00000
00=oo`P00003Ool0000002P00003Ool0000000@00003Ool0000000800003Ool007oo00@00003Ool0
07oo0040000000D007oo000007oo00<000=oo`@0009oo`<00003Ool0000000<00005Ool007oo001o
o`0:00001Goo00000000Ool0100000=oo`0000003P0000=oo`0000001P0000Eoo`00Oomoo`00009o
o`03001oogoo00Ioo`03001oo`0000P0009ooa<000]oo`03001oogoo01moo`<000Qoo`H00003Ool0
000000@00005Ool00000001oo`0=00000goo0000000300000goo0000000H000017oo000007oo2`00
0Woo3P0000Aoo`00001oo`<00005Ool00000001oo`0100000004001oo`000003Ool01000Ool007oo
0P001Woo0P0017oo0P0000=oo`0000000P000Woo00<007ooOol00Woo00<007oo00000P0000Aoo`00
Ool0009oo`03001oo`0000@00003Ool007oo00X00004Ool007ooOol20004Ool01000Oomoo`001goo
0P0000=oo`00Ool0200000=oo`0000002P000goo0P0000Aoo`00001oo`<000Ioo`03001oogoo01eo
o`8000Eoo`05001oogooOol00002Ool:0002Ool@0003OolK00000goo000000020003Ool200000goo
000000020002Ool2000017oo000000000goo0P0000Aoo`00Oomoo`<0009oo`8000=oo`03001oo`00
0080005oo`40000000@007ooOomoo`800003Ool0000000@00004Ool00000Ool600000goo00000002
Ool`000017oo000007oo10000Woo0P0000=oo`000000:00000=oo`0000000`000Woo00<007ooOol0
1Goo00<007ooOol01goo00@007oo001oo`800004Ool00000Ool60003Oom^0001Ool100000003001o
ogoo0?mooaeoo`40000000@007oo001oo`800003Ool00000009oo`05001oogoo001oo`020002Ool0
1000Ool000001Goo00<007oo00000`000Woo0`000Woo00<007oo0000:@0000=oo`0000003P0000=o
o`0000008`0000Aoo`00001oo`<000Ioo`800003Ool0000006@00003Ool007oo00D00005Ool007oo
001oo`0400000goo0000000500000goo001oo`0100000003001oo`0000P0009oo`@00003Ool00000
00800003Ool007oo00T00003Ool0000000<00003Ool0000003h00003Ool0000002X00003Ool00000
07T0009oo`X0005oo`40000000<007ooOol0ogoo7Goo0@0000000`00Ool0000600000goo001oo`0:
00000goo0000000200001Woo000007oo001oon`00003Ool0000000X00005Ool00000001oo`010000
0003001oogoo00Ioo`04001oo`000004Ool00`00Oomoo`02Ool00`00Ool00002Ool00`00Oomoo`02
Ool01P00Ool007oo001oo`800003Ool0000000D0009oo`80009oo`P00003Ool00000009oo`800003
Ool0000001h000Aoo`@00003Ool0000003X00003Ool0000000P00003Ool0000001400004Ool00000
OolE00000goo00000002Ool400000goo001oo`030002Ool700000goo000000020002Ool200001goo
001oo`00Ool007oo00<00004Ool000000002Ool00`00Ool00003Ool00`00Ool00002Ool100000003
001oogoo00Ioo`03001oo`0000Qoo`06001oo`00001oo`001Goo0P000goo0P0000Eoo`00Ool007oo
0080009oo`<00003Ool0000000800003Ool0000000800004Ool000000002Ool00`00Ool0000L0000
17oo000007oo0P000goo1@0000Aoo`00001oo`800003Ool0000003l00003Ool0000001800003Ool0
000001H0009oo`05001oogoo001oo`0600001Goo00000000Ool00P0000=oo`0000002@001Goo00@0
07oo0000009oo`800003Ool007oo009oo`800003Ool000000080005oo`40000000<007oo00002@00
00=oo`0000002@0000=oo`0000004@0000=oo`000000`P0000=oo`0000003P0000=oo`0000006@00
0Goo0@0000000`00Ool00002Ool00`00Oomoo`06Ool00`00Oomoo`0:Ool01@00Ool00000Ool00P00
17oo0P000goo0`0000=oo`0000000`0000=oo`0000001`0000Ioo`00001oo`00OolI00000goo0000
000300000goo000000030002Ool300000goo0000001500000goo0000000500000goo000000060000
0goo0000000K00000goo00000003Ool30002Ool20005Ool00`00Oomoo`0300000goo001oo`050004
Ool01000Ool007oo2@0000Aoo`000000009oo`80005oo`40000000<007oo00000P0000Eoo`000000
07oo00H000=oo`03001oogoo009oo`800003Ool007oo00<00003Ool0000000800004Ool007ooOol4
000017oo000007oo=P0000=oo`000000F`0000=oo`000000800000=oo`0000003`0000=oo`000000
0`0000=oo`0000000P0000=oo`0000001P0000Eoo`00000007oo00/0005oo`40000000<007ooOol0
0Woo0P001goo00@007oo0000009oo`80009oo`8000Yoo`D00004Ool007ooOol40002Ool700001Woo
000007oo001oob000003Ool0000000@000=oo`800003Ool0000000<00003Ool0000003X00003Ool0
000000X00003Ool0000000L00003Ool0000000H00003Ool000000140009oo`/00004Ool00000Ool2
00000goo001oo`08000017oo001oogoo100000=oo`00000010000Woo00<007oo00001`0000=oo`00
Ool00@0000000`00Oomoo`0300001Goo00000000Ool00`0000=oo`00Ool010000Woo0P0000Aoo`00
001ood/00003Ool000000;<0005oo`40000000<007oo00000Woo1P0000=oo`00Ool017oo00D007oo
Oomoo`00009oo`04001oo`000008Ool4000017oo000007oo0P0000Eoo`00001oo`00009oo`T00003
Ool00000018000=oo`03001oo`0000@00003Ool0000000H00004Ool00000Ool800000goo0000000B
0002Ool30002Ool00`00Oomoo`02Ool00`00Ool00003Ool200000goo0000000?00001Goo00000000
Ool09P0000=oo`00000050000Woo0P0000=oo`0000000goo0`0000Eoo`00Oomoo`00009oo`800004
Ool007oo0002Ool9000017oo001oo`000goo0P000Goo0@0000000`00Oomoo`02Ool00`00Oomoo`03
Ool01000Ool007oo0`000Woo00<007oo00000goo100000=oo`00Ool00Woo00P007oo000007oo001o
o`000goo0P0000=oo`00Ool00`0000=oo`0000001P0000=oo`000000300000=oo`00000010000goo
60000goo3@0000=oo`00Ool01@000Woo00<007ooOol00goo00@007ooOol000=oo`@000Moo`l0009o
obl00003Ool0000000800007Ool00000001oo`00Ool00`0000Moo`00000007oo001oo`050002Ool3
00000goo00000003Ool01@00Ool00000Ool00P0000=oo`000000100000Ioo`00Ool007oo0003Ool1
00000003001oo`0000<00005Ool00000001oo`05000017oo001oogoo1@0017oo40000goo100000=o
o`0000004P0000=oo`000000100000=oo`0000000P0000=oo`00Ool0:`0000Aoo`00001oo`80009o
o`03001oo`0000Aoo`<0009oo`03001oogoo0080009oo`03001oo`00009oo`@00005Ool00000001o
o`0300001Goo00000000Ool0A00000=oo`0000002P0000Aoo`00001oo`@00003Ool007oo00P00003
Ool0000000<0005oo`40000000<007oo00000P0000Aoo`00Oomoo`80009oo`800005Ool00000001o
o`0400001Goo001oogoo00001goo00<007ooOol00`0000=oo`000000100000=oo`000000500000=o
o`0000000`000goo0`001Woo00<007ooOol07`0000Aoo`000000009oo`@0009oo`03001oogoo011o
o`04001oogoo0004Ool00`00Ool00002Ool30002Ool50003Ool600000goo0000000600000goo0000
000/00000goo0000000800000goo001oo`0=00000goo0000000400000goo000000060001Ool10000
0004001oogoo0003Ool2000017oo000007oo100000Eoo`00001oo`00009oo`800003Ool000000080
0003Ool007oo009oo`03001oo`0001400003Ool0000000d00003Ool0000001=oo`T00003Ool00000
00l000Eoo`80009oo`8001Eoo`03001oogoo00Aoo`03001oogoo00Moo`04001oogoo0004Ool01000
Ool007oo1@0000=oo`00Ool00`0000=oo`00Ool03@0017oo7`0000=oo`000000300000Aoo`000000
00=oo`T00004Ool00000Ool500000goo001oo`0100000003001oogoo008000Aoo`03001oogoo009o
o`03001oogoo009oo`08001oogooOol007oo001oo`80009oo`03001oogoo00=oo`800004Ool007oo
0002Ool300000goo00000003000017oo001oogoo2`0000=oo`00Ool00Woo00<007ooOol01Goo00<0
07ooOol01Goo00H007ooOomoo`00Ool<00000goo001oo`02000027oo00000000Ool007oo0002Ool0
0`00Oomoo`0/Ool00`00Oomoo`0:Ool00`00Oomoo`02Ool00`00Oomoo`04Ool700000goo00000003
0003Ool01@00Ool00000Ool01@000Woo00<007oo00004P0000=oo`00Ool00`000Woo0P0000Aoo`00
0000009oo`80009oo`<00003Ool0000000Aoo`03001oogoo00800003Ool0000000<0009oo`400000
00<007oo00000Woo2`0000Eoo`00001oo`00009oob400003Ool007oo00`0015oo`03001oogoo00=o
o`X00003Ool0000000T000Aoo`<002moo`03001oogoo00Qoo`D000=oo`8000=oo`l0009oo`04001o
o`00Ool600000goo001oo`0g00000goo000000040001Ool100000003001oogoo0?mooaeoo`400000
00@007ooOol000=oo`80009oo`800005Ool00000Ool00005Ool01P00Oomoo`00Ool0009oo`04001o
o`00Ool2000017oo000007oo100000Eoo`00000007oo00H0009oo`03001oo`0000@00003Ool00000
01aoo`D00003Ool0000000800003Ool0000000H004Uoo`03001oogoo00Qoo`04001oogoo0002Ool0
0`00Ool00006Ool01@00Oomoogoo000027oo:`0000=oo`0000003@000Goo0@0000000`00Ool00003
0003Ool700000goo0000000?0002OolD0002Ool70002Ool00`00Oomoo`0LOol01000Oomoogoo3000
17oo0`00CWoo0P0000=oo`00000047oo00<007ooOol01Goo=`0000Aoo`00001oo`40000000<007oo
Ool0ogoo7Goo0@0000000`00Ool0000500000goo0000000200001goo00000000Ool007oo00800004
Ool007ooOolN0006Ool3000POol20004Ool200001Woo00000000Ool0009oo`03001oogoo071oo`80
0003Ool0000003D0005oo`40000000<007oo00000Woo0P0017oo00<007ooOol00goo00@007oo001o
o`8000=oo`03001oo`00008000Aoo`@0009oo`h000Moo`8002Ioo`03001oo`0007]oo`04001oo`00
0004Ool00`00Ool00003Ool900000goo0000000500000goo00000002Ool200000goo00000002Ool8
00001Goo001oo`00Ool00P000Goo0@0000000`00Oomoo`05Ool2000017oo000000000Woo0P0017oo
00<007oo00000Woo0`001Goo2P0000=oo`0000000P0000=oo`0000000P00<Goo0P0000=oo`00Ool0
0goo00<007ooOol0M7oo00<007ooOol01Woo3@0000=oo`0000001@0000=oo`0000000P0000=oo`00
00003`000goo0@0000000`00Ool000080002Ool300000goo00000002Ool600000goo001oo`0E0000
17oo000000001goo0P009goo100000Ioo`00Ool007oo001gOol00`00Oomoo`0200000goo001oo`0Z
00001Goo00000000Ool00@0000001@00Ool007oo00001Goo00<007ooOol00Woo00P007ooOol007oo
001oo`000goo00<007ooOol017oo00<007ooOol0200000=oo`0000000`0000Aoo`00000003Eoo`03
001oogoo00Aoo`03001oogoo07aoo`03001oogoo009oo`<0009oo`80009oo`800003Ool0000000T0
0003Ool0000000T0009oo`<0005oo`40000000L007oo000007oo001oo`0600000goo001oo`020000
17oo000000000Woo100000Aoo`00Oomoo`X00003Ool0000000H00003Ool007oo039oo`<008Uoo`<0
0003Ool00000009oo`03001oogoo01400003Ool0000000/0005oo`40000000<007oo00001Goo0P00
0Woo00<007oo00001Goo0P001Goo00<007ooOol00P001Goo10000Woo10000Woo00<007ooOol0=7oo
0P00Rgoo10002Goo0P0000=oo`000000300000=oo`0000000`0000=oo`0000000P000Goo0@000000
0`00Ool000050002Ool00`00Oomoo`030002Ool200000goo000000030002Ool>000017oo00000000
0Woo0`0000=oo`00Ool0<Woo0`0000=oo`00Ool0QWoo0`0000Ioo`00000007oo0004OolM0001Ool1
00000007001oogooOol007oo00000Woo00D007oo000007oo00@00004Ool007ooOol20003Ool20000
17oo001oogoo0P0000=oo`00Ool00Woo0P000goo00<007ooOol0>Goo00<007ooOol0SGoo00<007oo
Ool01Woo1P0000=oo`00Ool00goo0P0017oo2@000Woo0@0000000`00Oomoo`02Ool01000Oomoo`00
0Woo00<007ooOol01Woo1P001Goo0P000Woo0P0000Aoo`00Ool0009oo`<000=oo`03001oogoo03Ao
o`8008]oo`03001oogoo00eoo`D000Yoo`X0005oo`40000000<007oo00000`0000Aoo`00000000=o
o`8000=oo`<00003Ool007oo00@00004Ool000000002Ool30003Ool00`00Oomoo`02Ool00`00Oomo
o`0hOol00`00Oomoo`2FOol01000Oomoo`000Woo0`000Woo00<007ooOol01Goo2P000Goo0@000000
1000Ool000000Woo100000Aoo`00001oo`<00003Ool007oo0080009oo`<00003Ool0000000800003
Ool0000000800004Ool007oo0002Ool00`00Oomoo`0lOol00`00Oomoo`28Ool00`00Oomoo`0;Ool2
00000goo00000002000:Ool400001Goo000007oo00000Woo0@0000001000Oomoo`000Woo0P0000Mo
o`00000007oo001oo`0300000goo001oo`0400001Goo00000000Ool00`000Woo0P001Woo00<007oo
Ool0>Goo0P00WGoo00@007oo000000]oo`8000=oo`05001oo`00001oo`0100000003001oogoo0080
009oo`800003Ool007oo00<00005Ool007ooOol00003Ool01@00Ool007oo00000goo00<007oo0000
0Woo00<007ooOol0@Woo00<007ooOol0ZGoo0P001Goo0P000Goo0@0000000`00Ool0000400000goo
0000000400000goo001oo`0400001Goo00000000Ool02P00@goo00H007ooOol007oo002XOol00`00
Oomoo`05Ool10001Ool100000003001oogoo0?mooaeoo`40000000<007oo00000`0000=oo`000000
100000=oo`0000000`000Woo1@0000=oo`0000000P0000=oo`0000000`00A7oo00<007ooOol0/goo
0@0000000`00Ool0000200000goo001oo`0900000goo0000000900000goo000000050013Ool2002e
Ool100000003001oogoo0?mooaeoo`40000000<007oo00000`000Woo2P0000Eoo`00000007oo00@0
0003Ool0000000<00004Ool000000012Ool2002fOol100000003001oogoo00@000Aoo`03001oo`00
00D00004Ool007oo0003Ool500001Goo001oogoo0000A7oo00<007ooOol0]7oo0@0000000`00Oomo
o`03Ool200001Goo001oogoo00001Goo1@0000Ioo`00Oomoo`00Ool2000017oo001oogoo0P00nWoo
0@0000000`00Ool0000?00000goo0000000?0014Ool3002dOol100000003001oo`0000<0009oo`05
001oogoo001oo`0200000goo001oo`02Ool01000Ool000000Woo0`0000=oo`0000000P00AWoo00<0
07ooOol0]7oo0@0000000`00Oomoo`03000017oo000007oo1@0000=oo`0000000P0000=oo`000000
2P0000=oo`00Ool0ngoo0@0000001000Ool000000Woo0P0000Aoo`00001oo`800006Ool007oo001o
o`000Woo00D007ooOol007oo00D00003Ool007oo0?aoo`40000000<007oo00006`000Woo0`00A7oo
0P00]Woo0@0000000`00Ool0000200001Woo00000000Ool000Aoo`03001oogoo008000=oo`03001o
o`0000D0009oo`8004Ioo`03001oogoo0;=oo`40000000<007oo00002`0000Aoo`000000009oo`80
0003Ool0000000D00003Ool007oo04Moo`03001oogoo0;Aoo`40000000<007oo0000100000=oo`00
00001P000Woo2`0017oo00<007ooOol0ngoo0@0000000`00Ool0000900000goo0000000900001Woo
00000000Ool0009oo`03001oogoo0?aoo`40000000@007ooOomoo`800003Ool0000001@000Eoo`03
001oogoo0?Yoo`40000000H007ooOol007oo0002Ool20003Ool700001Woo00000000Ool00?moo`Io
o`40000000@007ooOomoo`800003Ool007oo00@00003Ool0000000X0009oo`03001oogoo0?moo`5o
o`40000000<007ooOol0ogoo7Goo0@0000000`00Oomoo`08Ool01000Oomoo`0017oo00H007ooOol0
07oo0003Ool00`00Oomoo`3oOol1Ool100000003001oogoo015oo`800003Ool007oo04ioo`03001o
ogoo0;Eoo`40000000<007ooOol0ogoo7Goo0@0000001@00Oomoogoo0000HWoo00<007ooOol0]Goo
0@0000000`00Oomoo`3oOolMOol100000003001oogoo0?mooaeoo`40000000<007ooOol0ogoo7Goo
0@0000000`00Oomoo`3oOolMOol100000003001oogoo0?mooaeoo`40000000<007ooOol0ogoo7Goo
0@0000000`00Oomoo`1TOol00`00Oomoo`2eOol100000003001oogoo0?mooaeoo`40000000<007oo
Ool0I7oo00<007ooOol0]Goo0@0000000`00Oomoo`1TOol00`00Oomoo`2eOol100000003001oogoo
06Eoo`03001oogoo0;Aoo`40000000<007ooOol0I7oo00<007ooOol0]Goo0@0000000`00Oomoo`3o
OolMOol100000003001oogoo06Eoo`03001oogoo0;Aoo`40000000<007ooOol0ogoo7Goo0@000000
0`00Oomoo`1TOol00`00Oomoo`2eOol100000003001oogoo06Eoo`03001oogoo0;Aoo`40000000<0
07ooOol0ogoo7Goo0@0000000`00Oomoo`3oOolMOol100000003001oogoo0?mooaeoo`40000000<0
07ooOol0I7oo0`00]Goo0@0000000`00Oomoo`3oOolMOol100000?l002400000\
\>"],
  ImageRangeCache->{{{0, 287}, {174.5, 0}} -> {-0.00112338, -0, 0.00349215, 
  0.00349215}},
  ImageSoundCache->{{{0, 287}, {174.5, 0}} -> GraphicsData["MacintoshSound", "\<\
00400@050000X001P540000001@0000000>C`5HR000000000000000lWV<l?fJN
b<bXK40gF9Bnbj]aB3A?R;_</Ga9<DIg[<RdPdha?V^T`;V?E3PlJ:31`iUT>cMO
V<36WVa0<e>;_<RVL4<gD82hckB0Cca<OkCCb91I?d]h[m?9Vf<oAg2TbL^PI3`f
G9C0ajA[?cADRKc>[7A3<DUl/<^fOT``A7RYbkj?ESM8LJc>aYiO?41XXlS6Xf/l
>5bGa/R/M4@hDhblbk=nC3I<PKS<^8QC=T5f[<VoS5Pi?6RTal6DFc/iH9S4c:A/
@CQLU<3>/7A8=e29]lV`N4P`A7R/b;J0B2m3L:S;_8iH=cm/Y<S8WUli?66Na<^X
K40hFI6oc;1gASM?R;_<]gm?>4Qn/<blR5@hA76Vb<2@ESQ0JJ?8aYaO>3ILU<37
X6To=5J@_/R/M4@dCh>dckN0CcI8N:k7^8M?<Cm`Y<K0T5Pc>fJLa<6LJ3`hH9S0
bjQa@CMHS;o<[7a8=U66^<^gR50gBGbdbkb<DC@lJJK6`9IN>C]SW/?6WVHk=ebD
`LVYKchdCXJhb:mhA318O[C>^HA?=4Ih[<RlS5Hd@6jQa;bCG34dGiO0`IaT?3AD
S[c9YVm4<4j4^<V_O4ThC82hcl29D3]8Nk7?b9AK?T5d[<c?X6Ho?6JN`lNTK3hh
FI70aj]hASI@R;S8]7a8=4Il/LRgQ4h`?g2Xb;b@F3LlI:3;a9aX?SiSWlc?[718
>ERC`m2^M4@cBgjfc;AnBCI8NKC9_8]<=d1^Z<c6U60k?fRPb<NLHCTgF9?0a:1X
?3=@RKO;[714<d^1]<jfOd`fBGN/bKb<E3A1L:C3`9UP>CaYXlC7X6Lh=UbD`LRT
K3ldDhbnc;=kAcI@R;W@_8Q@=TQn]=76UU`lA7B`d<bLI40lIj38bJA[?3aPTKo9
Z70l<526]/6XM3l_AWb/`kB0C3M4M:c<a91K?4=_ZLo9WfLo?V6K`lNSJ40gE8bl
c:Q^@cA9OkS<[WU8<dMf/<bhQ4`g@6n[bl6?E3PnJ:33a9]O>CaPW/S>Yfi3?5bD
`lnaN4LhChNdb;AlBC18NK?>^8aD=dAa[/o4W650A6b[clnSJ44kHIc4b:1[?31A
Rkc<[g=0<4Qo^<bdOTLcA7Bcc;j;DCQ0L:S;a9AI>CmXW<S9W6Hl>ejDalbXL40h
F8^lc;1gASM?P;SA^hA@>DUn[lc3S5@h@FbWa/2DF3@gHIBk`iUP>31GT;c8Y6lo
<EB;_<jfO4/dChRhe;n9E3M;O;7C`8mI=41/XLS0Ue`g?f>LalBTIc/fEY6lajQ/
@C19Q;C6[7M8=4]l/<bhQ4haA72Wb;j<Dc4iJ:34a9QP=SUSV<S9Y710=UbA`<j_
Md<fChBhbK1hAc14Mj_9^HA?=TQ`Y<W4U5Lg@6ROa<>IGcLhH9C0aZ1X>3=HRko<
[WQ4>E>8_<^hR4lgB7jhc<2CEcm6M;7?b9MS@3][Y/K8XFHo=ebIa<bTLDHfF9?6
dkIlBcm@Q[kC_8=?>4Il/<c0R4lc?V^Qb<2>F3<hIYO1b9iV?3aPU<78Yfll=5J;
_/naNDHfCh>gc;b8D3I7N:k<_Y1I=T5aZ<c7VE`h>F2Lb<JPJchhF933b:Q_?3=?
Q[W8/7Q4<DN0]<bgO4P/?6jVb;R9D2`hI9k4_Y5G<c=IU;c0Vf<l=UJ@`<R/MT@h
DHRlc;J0BCQ<OkC;_hQ@=4=`[<jnU5Tf?6RQb<JHHC`hH9W4b:A/?3QHS/7<[gA4
>5><_<nkPDhiC86dd<><E3M4MZc<`9=L=S]XXLO7W6<l>f>Ka/jWKd<gF8o3d:ah
A3=<P;S;]7m<=TMi/LnnRe@dA76Wc/BHH3Q0J:7>b:1Y?3]QVLS?Yg10=UB9`<V^
N4<aAgbcc;J0C3A8MZc<_X]@>45_Y<S4TeP_=fBI_l6NHcLcFI6oaZ=^?35@R;_<
/GU8=Tj4^MC1S5HiD82de<2CF3A0JJK8`9AK<cANU/33W60g=UNA`lb/N4@cE8jo
c[AnC3Q>QkkD_8QF=4Qh/=C0T5Tg?fVTbLJIGc/kH9_8bjA/@CaITl3?[6m6=U28
^<ndNdLcBgR`c[b7D3I1KjS7_Xa@<3QVWl?4UU`d=5bF`<NTJC/aEY2objid@c1;
PKW</7a8<4Qg]<jlR50h@gB/blBCF3@nIYk6a9aL=3AHU<33XfHh<Dj<_<V`MTHf
CX6gdKR4D3I8O;K>`8mD>d1_[<c4V5`k?VNTbljPI40hG9S8d:Q`@3AFRK_>/7Q3
<4an/LbhQ4`a@g>Xbkn>Dc0lK:?7`iQI=3]TX<_<Z6/l=f2Ia<b^M40dDhRoc[5l
B3Q;P;W>^hI?>4Id[<^hQULc>6VTb<BFFCPkH9_4aiiT>CALT;o?ZgI3=U>7_]2i
Q4`hCWndc;b8D3I4M:c9`8mC=3iVX<S4V5lf>6>GalnTK3`fG934dK=oB3UFR;o@
]XI>=Tak]<blR4li@72/b<2@G3PnK:3<c:1T?3aQVLS?ZF/k=5B<`<b`Md@aD8Bd
c;V1B2m4N:_9^hAA<3m^XLVlTE`c>fBLa/>OI3PdF9Bn`jAY>31AR;S8Z7A4<4b3
^<jhQdhdAWNcc[b<ESQ0L:W>aiUP?SmTX<S8X6@l=ebA_ljYKT4gDh^nc[InAcA<
O[C8]8A7<45d[/_1SeHd>6bWb<>IHCPiHio8bJAX>cAHTL7@[WA7=eB<`MBdQ4`d
CX>le<2<DcU8N;7@`IAK>41/Z<c6VE`h>62Na<JPISP`E8nib:Q^@2m<P;O<[7Q4
;dQl]<^hQd`d@72/bL2AF3@lJ:37b9iT?3QPVL77Xf`n=5N?`<^/M44cChBhdKR1
CSA6NK?>_XaF=T1_[]38V5/k?6RPa/^IHCPdGYO4b:I_?SIHTLCA]7U6=e27_]>l
Q4lgB7bde<N<E3I0L:K?aiAL<CQTW<O4V5hd<5><_lRPJ3/`CXBkc:id@3=>PkO@
_819<DAd[<k3SU@g@G2Xc<RIFC@hH9W0aYiQ=c1HU<3;ZFm0=529_<bdO4PfCX6c
c[V3C310LJW8_91H=3i^Y<c9WVHl@6JLa/VWK3`fF931bj]g@C=@Q;S;/Ga8=4Ql
]<bhR54fA7B/clBAF3I0JIo9aiaN=caPW<O8[6`i>5VA_/bdN4HdCX^lc;J3CSA8
O;K<^8aA<3m_Y/RnSUPg>fRTblRNH3TgGiS7c:A^>c5DR;c9[7=0<Db4_=>iQeLl
D8JlflRDG3a7Ljc>`i1G<35NV;k0Ve`a<56<^KnOJC/_CXRlc:igASA>Q;WC^HA?
=TQg]=6oSe4g@6bXbLBCEc@hHiS3a9UQ=cIITlC<Z713=UJ9_/naOTPgCX2hd;b6
CSA6M:k<`91D<Ca/Y<S8V60g>6RPalbTJCThH9K3c:md@3ADS;k>^819=4V3]lbo
S54dAWB/bl2AF3PoJJC9aYaN=S]PVLK7Y6Pk>ENDa<ndM4@fD8Vld;V1BCA7O;7@
`8Q@<3m`Z<k8UeTf>FRPa/RNHc@gG9C3bJM/?3=DS;_8ZG0n;4R6]/bdO4H/A7B`
c;V8D310L:W>a9AL=SaXWlS<WV@h=f6HalnYL40dF971d:mfB3A?P;CA]81?<4Id
ZLbhRe@cAfnYc<BLGS`nJJ76biiV?35LU[o<Z70n;524^LR[Nd4aB7Vgc[N1C3I1
M:k<`8aD=ci[Y<W3UUli?6>Lal^PI3`dFI>objU`?31?Pk_>]7i8<dV0]m30Re@i
B7N/dLB@G3Q0KjO;bI]O>3QPV<C7XFPh<eN;^l^/L3lcDHRkdKR0BcI<OkC<_8UC
=TMi[<VnT5L`?6RQblBIGcPhGYc6bjIY>c5AS;k;[6ll:dR3]<bfO4@/A7R^d;n8
Cc10Lj_<a9QK<CaYY/o8X6Hl>62Nb=2/Ld<gEi33dKAlBCI<Q[c?^HM>>4Mh]<jo
R5<c?72Xb<2@FC4dH:39a9aT>3MLU<K<Yfa0>526^lb`Ld0cBh2db;R0B3=7OZo<
`8aC<ca/Yl_6W60i>6BPa<RQJ3/fFi?4c:Q`@3ADR;o@/7]7<Dao]]2kQTldAgR_
cl2?E34nK:?8`IQS>3iTVlc;XF/o>5RA`LVYL40aCh2hc;1lAc18N;??_8Q<=45`
[<_4U5Ld?6VSblVPISPhH9c8c:AX>c5DRL3;Zg@l;4n4]/VdP4L`@gbgbkb7C2ll
KZC7^hmD<CaXY<W7XfLl?V>Pb=2/LDHhG9C0dk=hAcA>Rkc@^81<<DAh[<jhQ50^
?72Wc<BCEc4hIZ3<bj1T>3MOUlO<ZG0n=5J?`m2dNdLdCXJndkj8DCQ8N;C?`95H
<ca^Z<c4UU`c=5jKa<6LI3@_EY?3bJI/?2m<Q[k@/7a8=4j0^<jiR4/dAgRdd<>@
E34kK:O8aiaO>3UTWlS<Y6Tl=U^Ga]B`N4PiF8boe;V6BcA?P;S@_8iA=4=d/<_0
T5Lh>fRTblJFG3@dG9C4aj5W=c5DS;k8Z70l;dV0^<R`N44`@gR_bK^3Bc4lKjS8
`i=F<3IVW/?1Ue`a;eRC`<JOJ3T^E8^lcjUc@Bi9O[c@/h17<DQf/=2nRdldA76/
d<JGG3M0JjC<c:5V?c]QW<S?Zg0n=eR@a=6cNdPdChBkd;^4C3A8OkOCa9AI=dAd
[=39Vehg>FNQbL^PIcH`FiC4cZU_?2i<R;W8/7a4=4b0^<bdPDldA7J_c<2>D3M0
Kjc@bIaP>3aXXL_>Z6`i=URDa/R[KchcC8^ib;1fA3=4O;C7/h18<3m`Z<VkR50`
=fJPa/2DFc@gGYS7b:=W>3MGT<7<[710=528_/nhOTPgB7nhd;n7DCQ6O;CCa9AK
>d=/Ylc8W64k=f6La<bTJ3``Dho0d:id@35AQ[c>/H18;TAk[lVhR50`@G2`d<JL
Gca3J:S<b9iP>CQNV<K<Y6Ti<e67`m2/M40cBgjdc;MoA2i4M:k9_8]@<Cm`Z<_4
U5Pc=V6Na/RPI3/fG9S7cZ]cA3UHTlSF^Gi<>528`=JoQe4dA7V`d;n9DC<nJ:K<
`iAI=SAPVL?7W60i<eVF`<nYK3`aEY30d;=iA2i8P;K<^8A<<41d[/k1T5@a?VVT
c<BHG3HkHj38c:I^A41YW/cH]7a7?UN?`M2hO4/fB86fckb4D3=1Mjc@a9AI>3i_
Z<k>Vf@l>EnHb<NNI3@^ChblaZQ[>B]1Ok76/7A4;41k[lbiQU0a@72_cl6@ESHk
I:77aY]I<35ITl7;X6Tl<5>8_<bYLC`/C7nfc;=l@bm3N;3?_hM>;ca`[<o4UeTc
?6BPalJOGSLdFiK0bjIY?31CRkk@]7]8=U>6_mNoS50hC82ie<RDFcm4LJk@b9QL
>CaTW<S9WfLl=ebC`LbXJc`dChVlc[AiASI<PK_@_8I?<dIi]=?4TEHi@F^/cl^L
H3lnI:3<cZA/@3]OV<S@/GA0>528^lb_M4@`AWbdc;R3BC50M:c>`hmH=3U/X<K4
U5`d=5jHa/NPIcPaE8o0bjQ/?c5>RKc@]7]4;dQl]m6iR4h`A7B`dL6DES0lJ:?;
aYaQ=SQLV<O7YV/l=5><_lRYKc``B86lckR0B3A<P;SC`HaD=4Ad/=33TeLa>6BP
b<>GG3@cG9O3b:AX=biASl?>/7I1<Db9`=>hO4``A82hf<2<ESA3L:_@aYAH>3aV
WlW<X6Hh>5nDb<jTJCT`CXRlb:i`@35<PK?>]Wi9<4Ql/m?6TE@dA6n/dlJIG34i
Ij?>d:MV>cAHU<?>[6hl<528_<ncNd<cC82gd;b4C313N:c;`8aA<3][Y/_4UU`a
=V6Kb<RNI3PcEi30ajA/?2a<Q;O;[gI1<4Mn]lnlQTl`@GN/dlBAFcA0KjSDc:1W
>3aWX=3?Z6i0>5VGc=BaN44gDHW1dKQkBCI9P;SA_8M><4=d[<o4TELc>FRPb<JH
GS@dGiS6b:1W>31GT<7<[WI1<e28_=2fO4P`A7^ddKb7D30nL:c?aYAD=3QQWlC3
VE/d<5^DalbTJc`aDhc3d;=kAS=<Q;cA_8I<>4Ql^M70S5@g@gB^dLRHG3HnJJ79
aYaQ=3ALU<C8Y6`h;e2;`<R^Md0^Ah6fb;IoB2i0M[3?_XmC<ci^Y/_8VElh>f>K
a/NQI3PfFiO4cZaa@3AARKk?]7]4;TR0]=2iQ4/^?g2/bkb9D2lhIj38aYAK=cIT
W/C?X6@i<ER?`LjXL40_D8Jhck5lBC=@Q;kKa91H>d]i]=C7Ue/h?VVTblVLH3Hh
GiS8cja[?3IKU<7@/7M3<EB<_]BlPd/aBGjgckV8C2`oL:O8_hUD;S=SW<W4V5lc
=UVGb<jWJC`gFi?6e;=hAcADS;oC_8=8=4Mf/<blQd//>FVTa/2AE30dH9c6`i]P
=SAIU/C<Z6`o=5J@_lndO4HcChRhc;R4C2a4NK7<^h]@<C]`ZlRoTE`g>6BTclbP
J3lhGiW8djic@cIDS/C@]7]4<Db3^M6lQ4`a@gV`cl2<E3<lK:S<`iQL<cQSVlO8
X6@f<5RD`<N[KcP^C8Blbk1h@bm8P;O<^8M><D5c/LnnSU<`>6VXc<RLG3LlHJ7<
bjAY?3MNVLWF/7A7=U69_]2cO4LcB7jfc[b8C3A0MZk;a8iD<cQ/YlW4VElf=V6L
b<bTIcP`Di74cjafA31@RKkD^h5<=TR0]lbnS4hd@gJ_clJFG3@kIjC>aZ1P=35L
VlC8YVLg;4n<_<b/Lch_B86iakAlA2a1M[?@`8]><CU[Z<_4UU/d>6RTc=2XK40l
IZ3<dJia@3QFT<7;[gM3;dR4^LnfP4P_@7B`c;b6D3=0L:W@aiML=SQTXLW9W6Hh
=5bDb<n[Kc`cD8bldkIkB31>PkWD_8M<<45g/L_0S50`>FNTa/6DE3@fH9o4aiiP
=2mCT;k8ZFhi;4b8^LbfNd@aBhBke<6;CcA6N;KAb9UH>3i_[<o<Wf4k>66Nbm2V
JC``E9?1dJi`@2i<Q;c?]7i6;dQn]]2oS50d@GJcdLJHFC<iJ:_<b9iP=S1IV<C6
XFLh<5B?`<nYLD0`D8Jlck=l@bm1N;7;_8M<;3a_Zlc1T5Hd>6JTbLRKHCPdH9W7
cjQY?3MDS<3@]7Q3<Db8^m2kP4Pa@g^cc<2;D3HoLK3@biII>3]XYlc>X64h<5nK
a=6XKSh/DHbkcZagA2i9O;K@]81<;dAh[ljnRE0/>FVSbl6DFBlgHik<bJ1V>CMK
UlO?[Vll<E69_<ndNdL_C86he;V8DC=6N;C@`I5F<cm_ZM79W6<h>F2Pc<^XJc`d
EYC7c:ac@3=>RKo?]Wa7<4R1]m2oQe0d@g^cdLJDFc@nL:S?b9]Q=3INW/S7Wf0c
;52<`lRWKS//B82kc;5i@2m4N;K<`8U>>41c[lk7U5Pg>FNPb<RHGc@fG9C6c:AW
?3MGT<7@]7M0<4n4^<nhPdP`AWbfc/2<D3I0M;3>a9ML>41^Ylo@X6@l=UnIb=6X
L3laEXk0d;1g@C=<Pkc?^7m7;d=f/<nnRDl`?g2^c/RFF3<hI:39aimT<bmFU<78
Z6Th:DV;_<b`N4LaBH>le[V8DC58Nk?A_XU@<C]/Z<W1U5P`>62Hb<VPISTgG9K4
cZa`?S=@Rl3?]Wa6<dao^=BkQ4hd@gJ^cl28Dc@nJjO>b9]L>3aXY<cAYVLn<eRA
_=2XKT0YBGndbjai@bQ4MZc<^85;;T5`ZlboT5Pc>f^Wd<^PIchnGj3Dd:]/?cQD
Tl7<[Vm3=4b8_]>gO4L`AgR`d;b4Bc0iK:_;`HmD<CaTX<c8W60h>6>Kb=2/K3`h
FIC4e;MhA3=DRkcD^H5;<DMk/lboS4l`?Vj[d<NHFc<hIZ3;bIiQ<c=LV<S@[6i0
=56@`=2`N4<dC8BldKb0C3Q4N;3?`8U?<cQ[Y<S7TeP`<e^Hb<^PHcL`F971d:Q^
?31@S<3</gi4<4R1_]JnRe<fAWjhe<JAFcPoLJkAa9AL<CALW<W6WV4h=5NA_lRT
JCh^C8Vkc;1hB314O[KA^8I@=4Id[<k0RE4d?VRPbLBHFc@hI9c4bJ=W=3AHT<C8
[7<o<4b9_/nhP4TcAh6idL2<ESQ6N;?Da9AH<CUWY/c4W6<f<ejLbl^XKS/`D8c1
bja`?2i<PKc@]7m7;dAk^=30Rdld?6n_d<RDF3HiIj3?d9mT>3MOV<SAZfhi<5J9
`M>/M40/B8>kd;UoAS53MkC@_ha@<3a`Z<c4U5Pc>6BOblbPIc`hH9S7c:I/>c1C
Rkk<[WM4<Db1^=2kPD`c@gV`c/2>E30oKZS@aiIL=SAPY<c;X6@g<ERCb<jWL3`_
D8Vod;Ah@Bm4O;C<^8=8<4=d[]33SU<_>6^Tb<BGG30dHik<c:5X>3AHTLK@[WQ0
=5B6_m2hQ4HaB7^dbkj7C3=0M:c<`i=I=3a/ZM3<W60h>FBOc]2VK3TfF974c;5g
?cA?R<3D^7m7<DIn^M2nR4l`?W6[d<NCEc@oI:C?c:1S>3MLV<C?YfLi;e>>_]2`
N44`Ch>fe;j3Cc=4O[OA`8aD<Cm_Zm36TeTd=6>Nbl^KHcH_F9O8cjQ^>2mDS<C@
/7Po<4n0_=>iQ4T^@GN`c/><CS0kKZO8aYMI;cASW<S8X6@f<eRDa<R/LC`cD8W0
c;AkA318O[K;]h59<45d/lnlS5<c?6VYclBFG3@hHIk<c:1T>CULU<O</6ll=56?
_]2hN4@`B8Jldl29D314N;3C`HiF<3U/Ylo8W5lc>62NblNTJ3/fE9?4c:a^@35>
S[o@^81;<4Qo]<niQ4h`?6n/c<2<D2hdI:7;aiUP>3MNW/W@Zfa0>5NAam>cLd0f
D8^odk^4B3A<OkSA`H]@<Ci`[lk3TELc>6BTc<RLGS<aEiS7c:QX>c=@S;c?/7=1
;TV3]=2kOTT^@GR`c/2>CR`lKjS>b9IO=SQYY=3<Z6a0?fBScm2_M44hF934e;Ah
AcI<Q<3F_8A9<4Ih]=71S50_?6nXc/RKF2lgGiS4a9aQ=2mDS[o4Y6`g;4j4_<b`
M40`@gVdckR1B2i0LjW@a8UD<ci[X<W4V5hf?6JLa<JPHc@aE9?1b:a/>2a9Q[O;
/gM4<DR0^=BlQdl`AVnXc[b@Dc0lIZ?8a9aK<cAKW<c<Z6/i<EBDb=6aM44dChW0
e;UlB357P;_D`8Q@<Caa[m74T5@a?6VXe<jNHcHhH9W8d:IW=S1CS<3<[6hh;4V0
]lnfP4@_B7RadLB@DcA0M:oAbiQN=3M/X<S9VF@h>5nHbLbWKc`dE8o4e;MiBCI@
R;_G_8=;<4Ul]=C6T54a@G6_dLVLGcLkJ:C<cj=T=RmHTl3>Z6/l:db<^<b/Ld0/
B8BhckR0B2m0Mk3<^h]?;3a_Zlc8UePd<FBPbLbTJcP`F9C4bJQ[?2];S;c>]7a4
;4R0^MBlRE@dA7Jad<>@F3PoKZSAciiQ>3]SW<oCZf`k>5VDb=BcM40cD8VockMh
A314O;C?_8=<;3ad[m?4U5Pd@6RTclVKH3TiIic<d:M_@3MHTlC?/GI0<dn7_]6g
NdL^@G^cc;R3Bb`gKZ_8_haC<CATX<S6Ue`f=5bLb=2SJC``EiC6ek5a?Rm?Q;_C
]7a6;3md[/bkQ4/[>6bXc<>@E2hdHic7b9iP=31LV<C;Y6`k<eNCb=BhNd@dC8W0
e;b1BC11NkC<`8Q@=3U^Zlc6TEH`=62NalJNI3PfFIK8d:U^@3IAS/?>]7]1<d^0
^=6lQ4T^?gB/bl2?DC0lK:S<b9QL=3QWWl_8X6Pg=5^Da<jXK3l^D8c3ekIkASA@
QkkGa8U<<4Af[/k0S50/=VRWbLBGFc@dH9k8c9mS>31DT;o@[6`l<e69`=>hOd@`
B7bac;R3B310M:k<aY=G=3a^Z<o@XF@h>FJOblnXKSlgFIS9d:mg@C5>Ql3D^7a8
=4J0^=?1Re4d@7JcelRCFc@lJ:3>b9UL<CANUlW<YVTl=eR@a=BcM4LhDhbldkio
B318Ok3>_859:C]`Ylc1Se@/=66NalNNHC@cG9K8d:U_?cMHTlCD]7Q6=4b4^=2i
O4H`@GN`c<2<DC0kKjW<b9QK>3MSY<k<X6Hg;eBA`LVVJCP[D8Rkd;=g@BU4P;S<
^8=8:ci`/=2nS5@a>6jYc<NHFc4dH:3<bj1V>C1HU/K@[74o<529a=RhP4`hCXBo
e/6<DC]9N;KDai=F=SUXYlW8VeTf=5nKa/^PI3H_F931cja`?c5CS/?G^HA8<Dn1
_=C0R4``>fn`c<2CE30gIj39b9IK=2mHU<77WV4c;e29`=2[L3l`CXS3dkR0ARm7
NKSD_Xa>=3mc/Lk;VEHf>fV[c<bPH3PaG9S4c:AX>Bm@T<C@/GQ1<Dj8`=BiP4T`
@gR`cl2;DC=0M;3DbIQL=c]XY<c<Wf0c<5N@`<RTJcP`E8^lbJid?2Q4P;O<]7a4
:Ca`[lbkR54`?W6`e<bPH3U0K:C@e:M[>c5IV<C>[Vll<4j;_lj`M3`WAh2gdK^0
AR`lMk?Aai1C<3i`[=C;Veld=66QbLjQHCPcF974cZQ/>c=@Qko@/gQ4<4R1^=6n
R4``@G>^bk^AE30hIjC7a9UO>CQQVlS?Y6Tn>5R?`<j`M40dD8Rkc[QnAc16O;78
_XQ<<cmg/Lc0TEH_>6bTc/RHGc4`FiO7b:5W>2i@S<3;[70o<d^4_=2hO4LcB7bf
e/><E3A3M;?Cc9mL>3m[[<o@Y6Ln=f>Sc]>YKc`dE937dK5d@31<R;k@^7i8<45k
/LnoQ4`^>6^Vc<>@Ec4fHio9b9]O<c5LU<?>ZF/h<eB;`M>dO4@`C8Jldk^6C2m1
NKOD`I1D<3]/Zm?8U5Ta=VBPd<bPI3@aEiC8d:m`>c=@S<CD^7a8<Db8_=K0Re0`
@gNdd<6>DC0hIjS<a9AI<3AOV<S<Wf<d;eB@a<bYL3PcD8O3dKQlAcA7O[O@^hA<
<41f/<o4U5@a?f^TbLNLGSLgI9o7bJ1V=RiFT<3<[70l<4j8`=BhOTH`B7nkdl29
C30nLJc<aiAF=3iXY=3;W60g=ebGal^WJ3TdDho1cZa`?Ra<Pk_C^7i4<4Ql]=2o
S4`_?g2Xc<>@F34dHJ78b9mP>3MOW<cCZ6i0=5^Gb=JhOT@dDHk0e;j4B2i6Nk?A
`8a@;3Q^Z<W0U5P`=62Na/BLG3@`F9C0bJIW>2m@S;o@/7M4<Db1^=>kP4P_@GVc
d<2<D310KjS>bIQH=SQTY<o?XF<h=5RHaln_K3``ChRkc;1d@2a3P;W@_XM@<d=h
]]S8UeTh@72[d<^GH3PfI:3@d:IY>3QITlS@[g=0=528`=JhO4PdB7nhd;b8BBm0
KjW6^ha@;3QTWlS4U5Lc=5RHa<JSI34aDhk3c:ac?31>R;S<^G]4;T1k]m?1Re0d
@7B`dlVFFc<kJj?<b9aP<3ALV<S9YfTl=eJGb=>gNdPfCh_0e[b0Abi4N;C@_hU<
<3a`[m38U5/c>6RTc/bQI3PaG9W;c:Q_>3=?S<C>/7A0;dR4^M6gOT</A72ackV9
Cb`lK:K<a9AD<CMQX<S;Weld=U^FbM>_LD0gEi31e;IhA2m9PKSA^hA;;dAd/=2l
S50^?6b/e<bPH3Q0IjKCdj]X?caLUlSD[fll<52;_m2fOd@aBh>oe<28CSA1N;?@
`Ha@;cAVY/W1U5P`<62La/RNHcP/E9?4e:U/>bm>Ql?D^7a7<d^0]]2kQ4`/@7N[
c/29DBhgJ:C<a9AL<35OVl_?Y6Pk<eVCa=6`Lch^D8Nid;AnARi8OkC@^hUA;3ia
[/o0TeP_>6BVc<JKHCPdG:3?e:mc@CMITlSD/GPo;4^4^LbcOT4Y?WBab;b7D2lg
L:k?aY5K<3QXWlc8Vf<d<ebIb<bXJcL`D8c0c:ag@2a<QkcC]gm8;T=k^=>nR4h^
?72`d<^IF3@iJ:7;cj5T>3ANVlSD[Vhn<E>?`M6dNd@`C8Joe<>8CSA6O[KDahmF
=3]_ZLo6Ue`a=f6Oc/bTIcPcFIO3d:]/>bi>Qkk?/7Po;4Il]ljhQT`c?76cc/2;
DC<hJ:K@b9MN=cIPW/S<YV<h=5RDa=2^Kd0`D8boe[IiA2i4O;O@^HM><45g/m38
U5Pg?6bXdlRKHCLgH9o<cZMY>CQHTLO?/74o=528_]2dO4@`Ag^dc[b1B2hgL:W8
`8]A:3=SW<O4U5/`;5bHa/bSIcP`E8k1e[Ah@2m?Q[cA^HA9<dQo]]K4T5L`@76/
clNHFcLlJ:C<biiT=c5PU/C?Y6`k;eR>a=6^O44^ChBne;b4Bc51N;SF`Ha@<3i/
Zm34Te<^=5bNa/JPGc<aEYK4c:QY?3AASl7C]7M3<DN0^M2iP4/cA7VddlJAE3@l
KZ_@biQL=SMVXm3@Y6`h<ebDam2/L3`^BHNld;5f@BU4O;3<^7m;;3ig[<bnS5@`
>fbWc/^IG3LhHJ3;d:=W?35KTlCC[gI1=5B<`mBiOdHaBH>lf<68D350M[3Dai5G
=3aXZ<o8W5T`=5^IbM2TIc``EY?8e;1d?S5@Rl3D^ga1;4=l/LbhP4T[>6jWc<2;
DbTcH9k8`IQK<31HUl?;Y6Hh;e2<_lb_M40`CXNhd;aoB2m6O;??`8]D<CmdZm34
U5hc>fRTblRPISPhGik;c:Q`?c=HT<3@/GI1<4b6_=>iQ4P/Agbfe<NCFCM4Mk?K
cj1T?41/ZMCAYVHk>5bGb<n[KST_DH^oc[=g?2a6P;k@_8M4;T1d/m31T5@c>6j/
c/^HFcPfGio9bimT>35HTLC>Z70l;U24_]2aN3l/A7Rab;J0A2PoL:S9`91@<3]/
Y/_8Wf@g>FVTc]2XK3`gF9C7b:M`?2i<Q[c9/7Q0;T1h]<^dPd//?g2^d<2@E3<k
J:S>c:1P>3UQXLc@Z6`o>5RCb=6`M44dChJld;AlA2m6NkC@_8M>;cm`[]34T5Pa
>6BTd<NLI3PhGi_8cjM[@3ACT<?@/7M4<4b4_]JfOTP`AW^ad;j8CS0lK:cAa9AI
;SMWX<k8W60d<eRHb<bXJcLcD8k9e;AkASA?Ql3D`HM;=TMl]m34RD``>FbWc<N@
F3@fI9c3a9]P=3=LTl?<YV`g<528_<^_Md<aB82kd;j7Bc=3NkCDaY1H=3a_Z=C>
V60k>6BPcm2WJcTgG934d:]a?c5@Q[_<]7Po<4Uo^<bhQT/^@7>/bKj?C30lI:O>
bj5N=cIOVlC;X6@d;52>_lRWK3P_BhRic;=gAc14P;SC`HQ<<D1`[mC4TEL`?VjX
dLnSHc/kHio;cjMY?3AHTL7@[W<o;4V3^<ndP4L`B7Vdd<2<C3@oLJk@b9IH<Ca/
Z=3AXF@k=V>ObM6YK3/`E92oc[5d@bm;Qk_@^H=8;4=g/ljlRdl`>fb[bL2CE2h`
H9c4a9]P=31HU<K@Z6hl;U2<`<j`Md0aBH70d;b4Bc=0Njo?`8UD<Ca^Zlc4UeTa
=VBOb<JNHCHdGYS7cji`@3ACT<?@]Wa7<4b4^mBhR4l`A7Nfe<2?ES@lK:c@b9UK
>3aSXM3@XFHi=5JAa<bXK3L/Bh>hbK5d?2PlMjo9^h59;Smd[]C7U5/c?VbWdlbO
I3PlH:3Ad:a_?SiNUlcG]7Q6>5R>a=JiQ4ThCh2ldKn<CRhlL:_<`hmA<3=SX<S6
Ue``<EjHa/^TIcH/DI2lb:]a?2]<R;W@]gi9;TAi]=2iQdl`?g2Yc<>CF3<iI:38
ai]P=35KU/C<YfPn=5>?`MB`N4<`CX2kd;J0AS56O;??`8a@<3m^ZLc4UUPd>6>Q
c]2SIc`iH9S<d:a`?3IDT<?@]gQ4;dV7_=JlQ50c@GjhdlB>Ec0nK:C<`I=H;S=P
W/_8W64g<eRHbM2XK3T_D8S0dk5hAc19Q;cA^854;3a/[/jnR4`^=VJTblRGF3Lh
H:39d:AW?3ALU<OD[W4o<eR?`mNkPDPfC8C3e/><C3=4M[3AaY1D=3QXY<k8V5/d
<ebKb<^PIcTcE931c:m`?S5>R;cD^7i8<Db0]mK1R4`^?fnYc;n<D2hhIjK;bImO
=cIPVLC;Y6@h;56@_m2`Ld0/CXJldkJ0ARa7O;OD`HmA<3md/=3;V5La?6RTc<RO
H3<cFiS6bjMX>2m@Sko</74o;4R1]<jdOdP/A7Rdd;b<D34lL:oAc9QL>3QXY/c?
Wf4h<eVAa<bWK3/_D8^lbk1d@2m8OkK@]81<<4Ah/m74S5<h@6j[clbIG3PiJ:7>
djIY?SQKV<WC[W50=5><`=NiO4PcAgjhd;j4C350N:k<`Ha@;cAYXlS8TeP`;f2I
a<bQI3H^EY33bjah?c1DRLCD^8=6<4R6_]30S4h`?W>`e<B<Ec4dIjC;aiQI<cIP
W/k?Y6Pk<5B@a=6^L3``C8C0d;Il@Ba1N:o8_8=8;cQ/[<_1T5La?6bSd<bPHcPl
Gj3;c:][>CADT<?>[g<n;T^4^LbgP4L_@GVdcl2<D3=0KjO?aiMK<3a/Y<c9Y6@d
>62Lb=2_LD0hF9O7dkQlA2m8Q;K9/ga6:41dZLRdQ4`Y?6bYc/2DFcHiHJ??b9mS
>cQKW<W@[Va4=eB@`=BfMTH`BHBhckb3B354O;?AahaD<Ca^Ym38Ue`d=f>Lc=2S
ISPcFIC4cjU^>c1?R;o?/Ga3;dan^mBhPD`a@gNadlB@E30nK:S?b9UL<cIOVlW9
XfPi<eNDa/jXKch`C8K0dKAkAbi7O[?@_hM><41d/=33TELa>FVWdLbIH3PdH9S4
dJQV>c5FT<3?[7A1;Tn9^M2hNd@/A7bcd;^4C2`kLjc>`hmC:cIXX<c<X6Hh=fBP
d=6_M44kF9C9dkAlBca@R<3H_85@?4ao^=C4Re0d@6jYc<>DEc@iJ9k4b9UO=3=N
V<C<Z6`k<e><`ln_Md4/AgnabK=g@BhoLJc;_XQ?;SQ/Y/W6U5@^=6>La<VLHCP`
FiS4cjQ[>2iDRKo@/7Q1:dMo]=BlP4P[?76_d<2?E30nJjOAb9MK<CITW<_;XF@h
=eRHbM2`LCl`Dhc0e[MnC3A9Q;cC_8Q@<DAd/=78TEPh?6bWd<RIH3@gH9c4b:=V
>3IIUlS@[gM0=5>8_=2dND@_A82fcl67B2m0M:k?`91F;cMYY<W8VElf=5jKblbT
JCTcEXo0d:i`@3=<R;o?^8=;<dQo]]2oR5<d@7J_d<RFF3HkJJC9b9UP=35IU<C8
Y6Hf<4j8_/b^L3l_BHNkc[aoAc53NKKC_XaA<d5a[<c8U5@a>6RTbLVPHC@dG9S8
c:Q_>cADT<KA]7a3=U28_]2lQ4`cAgb`d;j;D30lK:S<a9IH<CIQW/S<XF@i=UbK
bm2/N4HhEYC6e;UlC3U?QkcD`8A<<d=h[m33S5@`?6jVc/RKGS@hI9o9bJ5T<C5G
TL78ZFPg;d^7^lV_Mcl[B7nhd;V7B2`oL:o<_Xi@;cAVZ<_8VE`g<EVKb<VQJ3/a
D8c3c:Q_@319Q;S;/7I3<4Qk/lniPdP^@72^d<2@DC4lJj_>c9iP>CQQXLo?Zfln
=eRDa=2aM44cCXNlckJ0Ac58P;WD_XA<<3mf/M38U5Hd?6bYd<bNGSHcGY_<cjAX
>Ba?S[k@/7A3;Tb1^=2dP4H^AWRdd;b9BblnK:W<`I5D<3QTX<S7Wf0f=5RHa<bX
Jc/_DhbocZmg@31<Q;oA^hA<<dQn]mO6T5Ph@gJ_d<RIG3<nJJC?cjAV>3AKV<S<
Zfli<528_<b_N4</AgnackV4Bb`oLjc@`8aF;SU/Z<o4VE`d=fBPc<bSJCPcFiK8
dJmf@3ADS<SD]h18=4j4_mRoQe0a@gNfe<2<E2`gIjC?`IIL<cILVLc<X6@h;eBA
`ljYKS/^BhBldK=k@Bi9O[??_X57;Saa[<VnT50/>fbTbLVOG3LhHik8d:U_@3IL
V<SG]Wa8=5>8`=>gPDTdBG^dd;j8D30oL:S<a9AG=3aXX<S7Ve`d=ebH`LRVIcPa
EY31ck5d?c=>Q;cD^h1;;dIk/m6oS4l`@72^d<RKG3HnJjK@cZ=T=cAOW<S?Z6`h
<5B>`M2dMT0aBhBle;j3Bc13NK7<`H]@<3a[Y<W3TE@_<ebK`lBIGS4`E931b:Q/
?3A@RkcA]7]6<dj1^=2lQ4P_@7J_b;b>DbllKjO<aiQN>3ATWlK<X60f=5N@a<jY
K3PXC8Rgc[=iA2i<PkcG_hi@=TQk^=O7V5`nA76`dlbPI3`lIZ38c:AY>3=FTlC<
ZgA1<4b7_]2dO4LaA7bfd;R1BBhnKjS<`8]A;SAVX<_8V5/d=5jHb<nVJ3P`E8o0
c:aa?2a8P;_</H18<dMl^=2oQ4`c@72YclBAF3<nK:C<bj5P<CANUlC8Y6/i<5J@
a=2cN4<`C8S0e;b6Bc54NKO@`8]@<c]^ZLW8T5Pd=VJPblRLH3@cFI?4cZAX=c1A
R;k<[gA0<Db6^m6lPDTaAgR`c[b9D2loKZK?a9IH=3]TXLc?Y6Tl>5jLc=6_L3ha
DHc0dK5h@2a7PKS?^H=7;41d/<jnS4l^>6^Xb<>GGSHdI9o;bj=[>3QLU/S>[gI1
=UB<`lngP4PdB82gd;b4CS0lLk3?`8aD<c][Y=38V5lg>6JOc<jVJ3TgEiC8d;1d
@3=@S<7@^H18=4V1_=S4RE4d@GN_d<NAES@lJ:K<b9QL=3MQV<3;XfLi<eR@`<b/
Ld0_BhJnd;=nAbi3N;C@_8A9<3m_ZLc1Se<a>6JOb<RLGS4fH9c;d:a`?3AHTLC?
/7Q4;dR6^LbfO4P`?gJcd;b;E3@nKjc@a9=D<3QTWlc<Wf0h>5bHb<jXK3`cEXo0
d:mh@31;PKc@^858<4Ai]=70SU<g@gBcdL^NH3`oJjK?cj1W>CILUlC;[6hh;4b8
_<R^MT0^A82gc[V0BBhnMk3<_hQ?;c]XY/o3VEh`=f2Lb<bNH3H`F9C4cjU_>c1C
Rkk<]7U1;dR1^<bgQ4`^?7B`c<2<EcLfJjS<b9QP>CMPW<W?XFPo=5RA`Ln[LC``
DHJkd;B1B3A>Pk_D`Ha@=4Ad[]36U5@a>6RTblbOGc@fG9S6bjAW>2mFS[k>Zg<n
<Dj4_=6hP4H`B7Vdd<29CRhlKjW;_i=C<3IQX<S8W64f;e^Ha<RSJ3P^DHo4d;=k
A3A>Q[cA_81<=TQn]]6nS5Lg@7B^c/JFF3LkI:?7aiaO=c=LV<O@Z6a1=UJ@amRi
OTPhCXNkdL27D3I4M;?>`8m?<c]^ZLS6TeL`=6BLb<bPHcPgGik<e[1d@3AHT<7F
]Wa4<Db3^m2lQT`aAWb`c/>>E3@lL:W<b9QN=3ASW<S4W6@d;eB@`<RXK3T_BHBk
bK1hA31<Q;SD`8A9<3m`[<o0Re0_>fVVblNIF3<fGic7cZ=S=bmFTlCC[W11=5B?
`mVlP4/dC8>ie;n;D3I3M;7A`HiD<cMXY/c7V5``<ebFa<RTJCTfEi34d;1f@C=8
Pk_>/ga4;4Ah/<bkQd`^?6jYc<BAES4iJ:C;b9mQ=SMPWlS>Z6hk;e6@`M6aMT@c
BHBld;b7CSA7O;KDa91D<cm`[<k8V5`d>66OblNPISPdFIC4cZA[>c1@RKk9[W@l
<4an]m2fOTL`@GN`c/6>Cc0lK:C<a9=H<CQTWl_7X60d=5NFa/n[KS``E8^ndK5d
@Ba6O;O@^8I><dMk/m?3TEPfA7B`e<^LHCTkHJ3<bjAT?3UHU/WC/G50>5N>`=Jl
P4PhD8Bie;n7CSA4N:k<`i1A<3]XXl_8VEhh>FBOb<nXJ3/dEiC1ck1d@31@Rkc@
]W]7<4Il/ljkP4PX>6VTb;V;CRT`GZ36b9]L=35OV<K>XFPk;eBC`m2`Md@aDHS0
e;V4BC58O;SC_Xa?=3m/[<o4TE<`>fBTblNOHcPdH:3>dja`@3IHU<KA/GQ0;db0
^LbaO4@^A7Rdc[n?D350KjW;`IAH<3=SW/K8W6@d<ERHb=2XKd0_Di30d:mf@Ba8
O[K?]818;41d/<bnS54c?76/dLVHGc@gIZ?>cYmV>31KV<_@Z710=5B<`=2`MTHa
BgjgdKJ0B2i3MZc@`8]>;cmYZ=38X5lf?6BTd=2XJcPaFIK8d:mf@cMAS<CG^H1;
<dJ0^=2kPd`^?g2XbkV9DBlhI:?<a9QL=3MNW<_<YVTk<5B@`Ln_L3h`C8RndKb1
Bc58P;O@^hQ@<Cad]=39V5/g>6VWclbFH3PdGYW;c:1V=c5GSl?A/7<o<Dn9`=Bh
Q4`fC82lel6@ESU4L;3@a9MH=3UVX<S4VF0d<EbHb<^XK3``D8k0d:ia@2]4Q;S>
^7a6;41d/=6lR4l/>6bYb<2DE30fH:39a9aQ<C1HV<C<YVPl<52>`M>cMT@`BhBh
dkQoCRm4O;?F`8mG<4=`Z=?8V5`g?fNSc<bTIcLdG9C4c:Q`?cADT<3A^Ga7=4b0
^=6iPDP/@76Wbl69Cb`dIZ?9aYUL<CIPV<C<Xf@g=5VDb=2/M3`_CXRnc[=i@2a4
O;K<^HA8;41f/=34TE@`?fnXdLRKHcLkJ:3?cjMX>3AHU<O>[70n<Db8_]>gN4@`
AgbfdKb7C34nL:o?aYAD=3]XZ<c<WV0i=62KbM2WJc`aE974dk1g@c5@Q;oF^8A;
=4Mi]m30Se@d@G2/c<2GF3@kI:76aYaN=31KVLC;Yf`l<5NCa=>aN44`C86lckR0
ARi3M;3@`8a<;SQ[Y/K4TePa=VBSb<bTIc/hGi_6c:Q_@31ASl3@/7Q6;TV4^=6h
P4T^AWR`d;b<CR/lJJ?>`iAF;SALW/W8XF0h=5BDa/n[JC/`DHbld;MgA319QkW@
^HA9<4Ak]=C7TEHd?6nYc<RHG3@dGiS7aYaV=S1HT;c<Zf`n<529_=2`O4L`CX>l
e/2;Cc51NKCCaY1K=cm`[]?@X6<l>fRTc]BXK3lgGiS6e:m`?31<Q;_@]7U4:d=k
/<jlPD``?W>[d<>AF30kJ9k;b9QP=3ANUlC9Y6/l=5R@a]B`N4@fE8Voe[UnB3=8
O[OD_h]?<4=d[m74U5/d>6BWblJLH3<aF9C6b:5T=2a<S;c<[WA4;d^7_mJhPD``
@gRcd;j8Cc0iK:W9`I1C<3=SW/C;W60h=5jFa<jWKS/`E8o0d;5iA35?Q[cC^HI<
<D5i/lc0RE4_=V^TblBHG3@dGYk8bJ5Y?3ALV<S@Zg=4=5>@`MNhOd`cCXBke;b8
C2a0LJc>_XaD;cIXZ<k4VEhf>6>PbLbTJ3TcF931cjQ_@31>R;o@]7a8=T^0^=70
Q4lfA7R/d<N@E34lIZ3<a9]N=3IQW<S>Z6Lh=5BC`Lb/Kd0_BhBhd;5iA2a6N;?@
^8M>;d5a[=34U5<d?6NYc<VPGcPdH9o7c:MX?35DT<7@[g0n;Tb3^<ndO4PaB82h
d<>?E3M6Mk3Ab9IN>3QXXl_;W64d=UjIalbXK3``E931d;1hA2m9P;S@^H18<D1d
/<jnQdh`>F^WblB@E2ldI9c6bIiN=35LV<O@[70l=5B?`<ncO4HdD8jne<28D3=6
NKCA`8aA<3Q/Y<_4U5L`=fBLblbPIS/cG9S4dJa`?c5GSl?A]gi4=4b3^=2kQT``
A7Rcc/>@ESHkK:cCcYmS>cUTWlS@Y6Pk<EN@a<b[Lc/_BhNlc;1gA2a1Mk7>^8A<
;cm^ZLk0T5<a?6^Xcl^NG3@hG9W9bJ1V>31@T<7>[Vlo<Dj4^M6fP4PdBG^hd;j;
D3=0Ljk?`iAH=41[Z=38X6<k?62Lb<bVJCTaEi30cjmc@31<Q;S;/Gi4:dIi[lbk
Pd`^>6bYb<2DEc<kIj?<b9]N=SALU<3;XfLh;e>;^lj_M40`CXBid;R0B2m7O[CD
aY=G>4Ig]=C>Wf4h@6nTdm2QISPdG9_;d:]/>c1DT<?D]7M0<4b3_=BhR4h^A7Rd
dkn>DB`iIZO>`IMH<31KVlO8V60d;5B>_lBOJ3</C8>lc[1fA3=;PkO>^817;41f
[/^lRe@`?6jVc/RLH3PnJ:C<d:][@3ULVLK@[W4o<Dn<`<ncO4H`BH6if<>4D3M1
Nk7AbiAL=Sm^ZMC<Xf@g>f2LblbTIcH`E8o0ajQ^=Ra8Q[c8/GQ0:d1n]/jlQTl`
@7Jcf<bIGSa4L:_Dd:=T>3MOUl38X6Hh;eB<`<^YLC/_BH6ic[Mk@Ba0N:o<_8M<
<4=a[=?0TePa>FNSc<bLGcTfG9c9cjI[?35DS<3?[70l;4R1^m2dO4@^@gRdck^6
C30nK:O;`IAG=3UYY/k@Y6/n?62Kc=2/L40dDhc1d;AlA3I<P;W<^HA7;dIh]<o1
Se0d?fj_clRIFCPfI:C<dJIW>CMLU/K<ZFln<4n?_<jcMd@/BHJhd;j7D3=1O;SD
a9=H=41^ZM37V5Td=5jOb<^QHCH`F9K4d;1a?2m<R;o?]ga1;TIn]]2lQTT_@7Ba
c<BADc<iJJ76aYMK<2mKW<O<X6Ll<5B<a]2XLD4cC8Nlc;=k@2m8O[?@`8MA<Cmd
[/k1TePg?6bVb<NKGc@dGiW4b:AX?3=HU<CA[gM4<5>@`MRnPd`aB82gc;n9CS0o
L:_>`I5I<cUXY=??Y6Lh>F2Kb<n[KS`cF933c;1d?2a9P;S<]Wi3:d=h/<boRe0_
?W6^d<NIH3/oK:S?cj5W?3UNUlO<YV/k<528_<V[LClXA7bcc;AkA2hlM:k8_8Q?
;3][Xl_3TE`d>FRTd<jSIcPhFiC8cZQ_?S1@Rk_>/gM4<4Qo/lbfOdP[@7BWbKb>
DbhoJjC<a:1O=T1TX<c<Z6`n>5VHa=2aMd4gEXc4dkMnA3A8P;c@_8]>=4Ik^=?8
U5@a?6jYd<RKHcPfH9k<c:5Y>cADSlC8Y6ln<4^7^l^cN40`AgRdd;J4BBhnK[3<
`95A=SaXY/c8WV0d>f>Lcm2XK3lhG9S;e;Mh?c5?Q;o?]7a1;4Al]lo0S50`?gB^
c<JHFcPlJjS>cZ1T>3MSVlS<Z6ln=5NC`ln^MT0[BHBhck5iARTnM;7;]hI<;3Q/
ZLo3SUP`=66KalNHH3@dFIK6c:IY>bm<R;k<Zg0o<4Io^=2kOTP`@7N_d<B;DC4l
L:W@biUO>Cm/Y=3AXf`n>F2Lc=6aM40hEXc1dk1kAS1;PKK@^hA;<dAh]=C6T5Pd
?fnYd<RKGSPiI9o;bjAW>3=GT<3;YV`l<4j6_lbaN4@aB82hd;QoB2/kLJS8_8]A
;3QXY<c7VEha<F2NblVTK3/fG9S>ekAlB3]IT<SG_XI8=Tb0_=?4T4h`?gB`d<JD
F30hJj_?c:1Q=SALVlW;YV@f;52<^lRXKSLXAh6ic[=nA2]0N;C;_XM<;cQ^Z<^o
SeL`=fBPblNNH3@`EYS1b:=X>2a?RKc<[7A1;TR4^<jhP4/aA7^gdl>?E3@nL:o@
b9UO>C]XYlc9Xf@h=5RF`lVWKc`cE8k1d;1g@b]4P;C7]7i3<3md/<blR5@`?6bT
b<2DES4aGYc4aiaO>3ALV<OCZfa3=5B@`M>gO4PaCXJie;n6C354N;CA`HaA<3a^
ZLo6VEhc>FBPc<^VJ3/hG9K9djmf@3MDRL?D]ga4=4Uo^lo0R4`cA7J`d<BAE3@l
J:_?biaP>3QPWlS<YVLn=UND`m2[L3l^D8bldKQlBC=8PKWH`8QC<D1d[=74SU@f
?6NWc/RKGS@hH9c;cjQ/>3AFTLC?[W0n;4R6^lbcNd4/@7B`c;R0Ab/hK:O9`I1D
<CQTXLO8WV@k=f6La/nYKch`E8k1cjUf@31@Q[cC^H18<4Ai/M2oRe0a?g2XclJG
G34gI:3<b:5V>CQOU/O?Yfhl=5B<`Lb`MTHcBhJldkV3CSM6NKCCa8aA=3m_ZLc6
V5`d>6RTbljTI3TaG9K6cjQa>BmDRL3>/GQ0;dAn^LnkQ4L^?72_c<6?Dc@lK:_>
bIaK=cUTX<o@Y6To>ejLbMBcLD0dE8Vnd;=i@bm7P;C?^gm7:Ca^Z<^lRD`X=VNS
b<JHG3@dHIc<d:U[?3ULU<SC/7A0=528_=2iNd<`A82abKV1Bb`nL:_;_91D;S][
XlS4V5hi>5nPalRPH3P`Dhc0c:M_?Ra9PkW@^81@>4b3^MO4T5LhBgRff<bLG3Q0
K:_DdJAW>cMPV<?;Z6`l<56<_<^/M3lYAX2gb;1n@bQ0M:k;^hQ><3U/Z<S4U5Pf
>fRWdM2VJC/dGio8d:m`@c5@T<CD/gQ6<4R3^=2dOd@Y@G6/c[b8C2/hK:O;a9MD
<3IPWlc8X6@g=5RHb<b/L3``E8^nd;1f@2a9P;S?^hA8;T=g/=71Se<`?6RXc/NK
H3]0IjC@d:AX?cmPV<SC[6`l=528_m2gN40`B7bad;j3AR`lLJ_<`91D;S]XXL_8
Ve/f>66Nb<nVI3TdF9C0d:mc?2iARKW@]7U39d=l[lVgQ4`^@7B_c[nCFCM0Kj_@
bimS?3aTWlc@Y6Pi=5^<`=2_M3haC8Jlc;IlA2i4Nk?@`H]A=41f[=79Te/d?6bQ
d<RLI34fG9S8bJI/>35DS/7>[710<4R0^LjfOdL`AWRad<2<CSA0M;?Dc9QL>3a[
Z<o@Xf@h=UnLbm>[L3hdE934e;MhA3A>Rko@_X58<DAk]=K0S5<`?6nXbl>@Cb`_
FIk6aYaL<bUDT<C@Y6`k:db8_]2`N4@_BGbhdKR3B2hoLjc<`8a?;SaYY<c7Uehd
>66OclRWI34gFIK6bJQ/>2m;Rkk</7I3<4^3^=2lQ4`cAgVddLJCESLoL:c@bi]Q
>CUSW/c<Y6Lk>ebIb=2`LD<aDHVndKQoAbm8O[?<_8Q;;ca`[lc3TE@`>6RSc<RL
GcLiHJ7<c:]Y?3AFU/K@/7<o;Tb6^LjcO4@/Agbgdkb7CS0hKZk;`9=D<3ISWl_8
V60f;e^LbljWK3/aDi36d;=g@c58Q[kC_8I@=T^0^=O8T50gA72/clNHEc4iJ:?<
c:=X>cQPW<SA/6ll<5B<_/b`M3l[AWnickN1Abm0N;?@`hQD=3m`Z<_3U5L`=V6N
b<RLHcLaGY?0bJAX=c1>Qkc</7A0;dQl]<bgP4P^?gN_bl>>Dc<nL:_@b9UP>3AS
XLS;X6@d<5RDa]2YL40aD8_3e;AlA318P;_A_hQ<<41g[m34T5Ld?6bXc/RHF30`
FiO0aj1Q>35HU<OC/7Q4<eR<_mNhP4H`BGjhd;j9C30nL:c<a8mA<3IYY/c9W60f
=6BLb=2VK3hdEiO4c;1dA3I@S<?G^H1@=4^1^=70R5<fA7R`dLRDF3LlK:S?d9aT
>cATVlS?YVTh;eB<`<bYLch/AgndbjmiAbToMZo<^hI<;3U[Ylc0TE4[<f2Ob<RN
Fc0`F9S7c:Q[=2]?S/??[g@l:DJ0^M>gOT@/@7Rdd<6;D30hJjS<`95G;SAQW<W<
X6Ll=5jLbm6_M4@iEXo4e;MkAcA9P;OA^h1;<45f/<k3T50f@6b[clVNH3Q0JjC>
d:M/?SQPV<K>[7<n=569`=2dO4LdC8Jld;b9CcA6NK?@`91H=41^Z=38V60i=VBQ
bljQI3PaE931d:U/?2U;PkS>/7a4<4Il_=2oS54f@GN`e<RDFcQ0K:K@c9UN>3QQ
Vl_?XFPd<5N>`m2[Lcl`C8C0dkR1B3=6NKSC_8]?;ci/Z<c0S5@a=f6Ob<BHFC4a
EYC6c:QY?cIGTLCH]7Q1<E23^LjdO4@_@gNacl2;CS51L:k@b9MG<c]/Z<o@XfHi
>5jIbln[L3/dDho3d;5d@358Q;W;]7]4;3mh/Lo0S54`>fnYblNGG3HgIZ38b9mT
=c=NVlSC[6m0;e2<_]6cN4@`B82kdkb8D354MjoAa91H=3a/YlW3V5`d>F6Ib<RN
I3P`Ei73d:a`?SADRKo@/gQ1;dJ0^=C0Q4`_@gJ`e/6>Eb`hJ:C?a9=H<35IV<S6
X6@c;eBCa<b_LchcCh_0dkMlB318O;K>]hA8;3ic[<k3T5@`>6JQbLJIG3<`G9W6
c:A/?31GT<O<[g@l<dj7_m2gOdPcBhBidl2<DcA3MjoAaYAI>3aXY<_<WV0h=f2L
bm2/L3/aEi?8e;AhA35>RL3D^H1<;dMl]mO0SU0a@g2^d<BFF3@gHio6b9aN<c=H
U<K<Yf/n=5><_/b`M40_B86hd;N0BC=4NkKC`HiD<D1`[<k8V5Pf>6NQbl^NHC@`
F9K4bJIW=2m<R<3?/7A0;TJ0^m6lPdPaA7B`d<2;D3LoL;3DcYiQ>CaXY=?CXf/n
>5^Ca<jXJcP^C8Jic[1g@Bi7P;S@_8Q?<DAh]=K9U5Pg?6^XclRHGc@dH9W7cZ5W
>35HTLC<[7A1<dn8_<baND@`AW^gd;^4CRm0MjoCaY5H=41/ZM?<WV4h>6>LbLjT
ISHdF8o1cZ]_>Bi<Ql3?]7i4;TAk]<biQ4h`@7>^clB@Dc4hJ:?9aYaL<35LVLC>
Y6Pk;eN>`M2^N44`C8Bkc[AlARm1N;3?_XQ@;ca^ZLo3U5Pc=VBPc<VKHCPdFIO8
cjAW>c1AS;o?/7<l;db1^M>iPD`aA7bhd<2CE3=3Lk3DaiIP>3QXY<c<WV0f;URC
a]BYL3h`EY30e;IlAS1<PkcD^hA<<4Ii/m2lT5<^?f^Xbl2DF30`G9k4aimT>35H
TlC@/7A0=eB>`LnhOT@dB7nid;b6C353N;7<`8U@<CIYY/S4TE@_<5bHbl^OJ3Th
GYS;e:mc@cACRl7G]gU4<4Ul]]2hPd</@6b[c;b<C2`dHJK8a9ML<cANVlc<X6Pl
=UBCam2aLD0dCXW0e;UlAS58OkCD`HQ@<41c[<o4U5@_=fBPb<^KH30`G9?1b:AX
=Rm?S<7?[WM0;dn6^M>iOTTcB7jcdKn8Cc0nL:c>b9MI=3]YY<c?Yf@i>f6Ka=2W
J3h_Di2lc[1g@Bm?Qk_@^HI<<4Il]]C3TELd@7>/dLRIH3HlIj7?b9aT=3=KU<c>
ZFhl<e2<`mBaN3l_B7^hckV1B314N;3Cai1D=4A`ZM7;Velh>fNTbljXISThG9W9
djm^>c5@S;o@]WU6;dN4^=2nR50`A7RddL>CF3HlL:c>b9QP=SAPW/O8XFLh<EB@
`<RWKST[CXNic[5kA318P;S>_8M8<41d/m?8U5`i?72Xd=2PI3`kI9c<cjQ^>CAK
TlC@[W=0<4b6_<b_N44[?W>^bkQoA2HiJjO<_i1@:cUTXlS4WUhg=UjPc]2[Kc`f
FIC8e;=kA3MDRlCG_X18<dAl^=33Re0c?72[d<^HGSPnK:O<djIV?c]SW/cDZ70l
<5>8^lj/Lc`^B7bgb;=k?bTlLJ_7_8A9;cA[Y<W3TeP/<F6Ha<>HH30[E9?0ajAW
>2a<QkW<Z74o:4An]/jgO4L/?7B`c[^9D2`lJjC<a9AK=3ANWlS;Xf<f=5BAalj[
L3`cDHW0e;anB3I?QkcHaha@=TQk/m?4UUPc?6bXblRIGSPgI9k;cjQ_?c]PVLWD
]g]6=eN@_]2kPdldChVle;b;E3I6O;SHaYQL>45`/=S>X6@k>FJSdm2WKT0gEY31
b:Ud?S=<Q;c9/7U3;4=h/LbkQ4/_@7J/d<B@E2lhJ:78aYIL<c1IU<?4Y6Tg<5>?
`m>`Ld0dC8>ne;R0BC=4Nk3>_8I>;S]/Y/S0T54^=V2Lb<NHHCHdG9K6b:AX=RmD
R;_>Zfll<4V4_=2fO4T_A7^cdl2;D2`oKjS<a9QK=3MSW<C6Vf0c<5J?`<NTJCP_
D8RibJmg@31<Q;cD_hM<=TIi]=73Se@d@6nXd<bNH3LoJJC@cZQ[?3iSWlc@]W]4
>5VGamRnPD/cC8Bldkb7C310Mjo>`HaC;cIWY<_1U5P^<5^A_lJLHC@YChVlbJ=/
=RA6OkK;Zg0n:d1h/<bkQ4``?g6[c/2@ES<lJJC@c9iT?3mVX<c<Z6/l=eRFa=6^
M4HhE8jodkQnBC57PKO@`8Q@<D=g[]?4T5/d?6VTclRLHcLkH9_<dJ]/?SMHU<3A
/GA4=529^m2iOT`dAgbcd<6;D356LjW?a9AF<c]XY<S8X64f<EjH`<bXJChfEiC1
ckAnASADR;kD_8QC=TR0]m31SU0g@6n/c/NFG3@hJ9o;c:1X>3IPVLW@ZG50=5J>
a<j^N4HaAh6id;AlBBloL:k8^8A9;3QWWlS4U5Ta>66LalNPI3@`F933b:M/>c1<
R;W8/GQ3<4Qo^<jiPe0a@GV^clB@E3@lKZW>bIMN=3IVXLc>Xf@f<5B@`lj/L3h/
D8_0d;AnBC=7P;_A_8A<<D5f/m74Se@a>6bTblVHG3@fH9W8b:5Y>3AKU<O@[7A1
<e28`=BkPd/dC7ngd<2<DcQ4M:c<`i5G=S]VX<S7V60h>5nHa/jWJ3TfF8k1ck1d
?31;P;K8/Ga1;d=d[/^kRDhc?W2^c<JGF3HhIZ37bI]O=35LVlS@Z6hl<5R@`=>a
O4@aD8^ndKV4Bc58NkC@`8]@<3a^ZLc4U5Pc>6BQc<^QI3`hF9O7cja_@3AARkk?
/gM4;dV0]<jhPDP`@gB^c;b<E30nL:O@b9QP>3]WY<S<XfLi=ebDa/bSK40_ChRi
ck5gA2i8O;7?]h1;<41d[/o0S54a?6bXc<NKGcLfI:7<d:QX@3MKV<C@[74o<526
^ljaN4@`Agjdc[b7CS11M:c>`iAG=3]TXlO7VF0f=62Ia/RTJcldF9C0c:ad@Bi?
R;_?]7m9<DQo/LblQ54`?WB[bkj@F30hJ:39b9QQ>3QNW<c@[714>EVDa]2_N4@c
D8Bkd;R0B314NK3<_8]C<Cm_Zlk4UU`g>6>Pb<VPI3/dFIC4b:=[=bi@Qkc<[gPn
;dUo^<bkQ4P`@7Jdbl2@E3U0Lk3?c9]N>CaWW/S8V60h<e^D`LRQJ3LaDHNhbk=h
A3Q@QkS@^hA<<dQl/=30U5Ld@g6[c/RLI3`lJJC?c:Q/?SQIUlS?[751<eB;`=>c
P4LfDGnhd;R8C3A8M:c<`91D<CmXXlC0Ue@^<ebG`LBOI3L_D8bobj]a@2m;Q[S9
/7M1:4=gZLRgQ4`_@76^c;b@Ec0hJ:C8a9aP=3QNW<W;YV`o=eNDa/n_MT@aC8Jl
dKN0BC57NKC@_hiC=TA`[lk4U5/f?VRSb<NPHc`hGYW8cjQ_@3IFT;kA/gQ8=U24
^<nfPD/`B7R_bKn;CS0kJJK9`9=H=3MVXLK;XFHl>ejIb=2`M4@kFiC3ekQnBcUC
R;cD_8I@=TQk/<k0S5<g?VjSalBDEc<hH9S1a9aQ>C=HTkk9Z6m0=5B9`=2`NDLc
C86dd;b4CcA7NJc;_hmA<3mXXlNnTePd=V2L`lJLHcTaEi30b:U^?31;R;_;/7Q7
;TMo/<bhQ4la@GN/bL>?ES4hJj?7a9QP=S=TW/S>Y6`n=5RDam6dN4@gDhRle;b4
CSA@PKS@_haD<DAh[<_0U5/f>fVTb<BHI3PgHIc<c:A^?SADT<3<[7M6<dn4]lbg
OdPgB7jfc;j>F3U4MZo<a9ML>3UYXlO8VFPl=ebDa<NSJ3/cC8RlaZ]a@317Q;S@
^7m?<4An/=70ReHd@6bVc/2CG3@lI:37b9iP>CMIU<79Y6Pl=569_<j/MTHcC7nf
c;R0BcA4NK7>`hmF>3i^ZL_6VF0i>6BLa<RLI3P`EhjnbJA_?c1@Q[k@/h17<dn0
^M2iR4hhAW6cd<2FF3Q0JjW;aYaO>CQQX<O9Y6Po>5^Ha<n_M4HhDH^kc;=lB3=7
O;39]h=@<cia[<VoT5Pa>6RQb<6GGcLfGYW4aj1X?SAGT<?>[7Q7=Tn;_=2gP4hc
A7Rcc;R8CcA3L:W@a9=K=cmXWlO8XF4l?5bH`lRXL3hfE92nc;1hB3=@QkW@]hA<
=dQl^<nnS54f@GB/b<>CEcHkHio6`9]Q=c1LU;o8X6Tn<5>9_<VYN4HdD86kc[N4
C3M6N;C>`HmF?4=`Zlc4U5hh?6NKalROIchoH9?0b:M_?35@QkK6ZgM4;db0]<bg
Pd`aAWJ/c;b@Ec=1K:S>aiaO>3]QW<C6XF@k=URA`Lb[Ld<dChRnc[MlAc=8O[O>
_8QC=d5d[<c3TEPd>fJPb<BGGcPfH9S4aj1X>cIHT<?<[6lo;db6^M2gOdL`B7bd
dkn>EcI7L:S9^hiG=3UVX<O4WV4h?66Lbm2XL4@iG9C7e;AnB3UFR;k@^8A?=TQh
]<biR4ld?fjYa[jAF3PkIYc7aiaV?3QKTko8YVa1>5R?`<n`OdPfDHNkc[N0C3A4
Nk?@_X]F=d1_Z<c4TETc=UnD`LBLHcLdEi2objM^@cAFRk_@]7i;=Tn1]m2lR50g
BGRad;j@E30lJ:C9a9aL>3aQVlC<XfPl=ebC`lV/M3/`D8Bfa[1lAcA8OkK<_XUD
?4Ql/M77U64kAW2Yd<NLI3/hH9W4aYmW?3=@Rkc7Z7=0=Tj0]/V^N4LaB7R`c;R6
Cc51L:S9`9=G=3aTXLS6W6<i>5nG`<JTK3hgF8nlc:mfAcUDR;c?^85;<dUlZlbo
ReLc?6nQa;b>ERhhHiS6`IaT=cMOU/?8YVhl=5>;_<N/M44_B7bcaZilA2m3M:c4
]8A<<Ca[Y<C3TePg?6RPalVPJ3`iHIW4cZUcA3AHT;c9/ga9=T^3]lVhQ50gAWN/
c[j?G3M3LJS8aYaS?41WX<W;YVm0?5jHalb`N4PhDhbkc[AiC3M9P;C<^8=><D=`
Y/blT5Pd?fVTbLNLHcTlI9S4b:A[?cQHT;o9[7Q6>5B8^LbdOT`gBGncbKV9DCI4
LjW9`iAL>CaXXlK6W6Hl=f2D`<bVL4@iF8bnbj]hA3Q@Q;_>]h=>=4Qi/<blSU@h
@g>`d<RLH410J:36a9US?3QOTL7;Z7=1?5V>`M6hP4`iE8Rhc;R3C314M:S4^8M@
;3QXWlBiT5`d=f2Lb<BPJc`iGYS6bJ]a@cQARkc8[7M;=T^1]<bfP4hdAW>/b;R8
DC4lIic4_95N>3aPVLK8Z6a0?5bD_lb`N4PgDhRhbk=oC3I8O;78_8]C=T1aZ<W1
TE/h?VRQa<6LGcLgGYBlaYaX?31IT;_7Z7=1<4n7^L^`P4`cBGVcc[B8E3M4M:k<
`9=K>d1TX<_3W6@l?5bD`<RTJ3hhE8bnb:adA3Q>PK_@^8=?>4Qn]=33T5Hg@g>X
c<JHH3PlIik3a:1W>cMKUl78ZG56>EB@_/bdO4`gBh6aa[N0C3=0M:_8`91G>d1`
Y/C4Uehh=V>L`LJPIc`fFI2lajU`@CADRKO</7m<=4n4^=2nReLiA7R`dL6DFcI0
J:7;`iMP>3MPVl74Y6/l=eN?_lRTL4@cBhRib;=iB3M8O;?<]hQA>4Md[<_1TETk
@6bSal>IHCPlGi?1a:=/?SQHS[_4ZgA6=524]/VaPe0iBgbfc;bCG3m8N:k>aYIP
?45XW/S4W6Hk>ebA^l2TJclfChVia:UhB3I@P;?;]7m>=TMh[<c1SeTh@FnPal6G
H3LlHIS1`j1W?3QISkk7YW=1=e64^<N^N4L`B7nabkN8E3Q6Mjo9_i5I>3m/Y/_1
V6<l?62Ia<NPIS`hEXRiajI`@CUAQkW9]7a<>Dn4^<noTE/lCWV`c/6DG3ToJJC3
`9aS>CQPU/79Y756>En>^L^YMT<hE86hb;20BCA9N:o8]hMC=3i[XlBkS5Ph?6BL
a<6KI3ThGiBob:A/@3IFS[o8/7a8>527]/bgPE4fAWN_bkb>Ec]0KZC8`iAN?3aS
V<C1W6Pi>Eb?_<JXL4<hE8Rib;=oASM>P:k6]X1?=TAf[<JnT5Lg@6nTb<NIHc/o
JIk7bJA_@3MNUkk;[gA8>529^LbcO4haB8BadlB>GSa>OZoFa9MS>D=_Y<W7W6@l
?V2Ga/RTKT4iFI2lb:adA3Q?Q;K;]Wm;=TQgZLBgQ4h`?6RL^;><DblhI9Vn`iaV
?3UPTKc1WV`n=5R;^lJ[MdHfC86cakB3D3A8Njc9`8aG>D1`YlRoUf0i@6RNa/BN
IShiG9O1bj]aAcUFS;_;/H1>=e20/<RhR5@kBgR/c;jDG3a6KjC7`9aT?3aSVL36
X6a0?5jA`<^^N4PgE8Vdb;5nC3I8O;39]8AD=45`YlRhS5/h?fVOa/BHH3`lH9K3
aj5[?SIHRKS8Z7A6=U5o]<VdPD`lC7R`b;R<Ec]8LjK8_i1O>d1XX<?3WV@k?62D
`<RSL4@iEh^lbJmkBCU<Ok78]8=>=4QdZ<NnS5Lh@6bSa<BHGSa0I9_4aYiW@3aP
U/3;[WA6>5>8^=2dO4lhChBdc;^7DcA4LjW;_95L=T1_Y/S4VF0k>F2Ka<RNJ44g
G8nlcj]dB3QCPkS8/7m<>4il[<^gQU4hAW2Va[b@F3Q0J9Rl_YIO>CaPU[o1Y7A6
?5^<]l2[N4hlDhNda[23DCU;MZc8]hQG?4A`Y<O0U5hl@6BHa<6PJ3loG9>nc:aa
B3UHS;O;/Ga7>4ml/<BdQ50fA7NYb<2>F3Q0KZ78aYaV?3aWW/S9Y717?ebG`lb^
MT/lEhRid:mlCcM?OZo>^8ID>4UcYlBhT5Pg@fRNa;bDI40oIY_0a:5_A3UKS[_4
Z7A8>563]<N_P4/dBGR[a;B8E3A4KZC6^iAP?41TWl>oWVI0?5bD_<BTL4<hE8^h
ajmlBCUAQ[O<]8AC>4UkZl^lS5PhA6bPa[jDGcPlHIW0a9iS?cUNU;k9Z7A7=UJ9
^<V/N4PaB7^_a[B8D3];M:k9`91I@4M_Z<S4W60l@62D_<6OJ3`iF8bhaZafAcaF
RkW8]8=??Tj0]lbnSe/oBGb/c/JGH414J9k3_iUQ>c]ITK_1Yfa1>EJ?^lV`N4Ph
C82dbKN0CcM6NJS1^8QA=41aX;niSU/h>FBK_;bHI3/fG9BoaZ=_ASQDR;O7[7];
>564]/^hQ5@iB7BXb;N9G3a4L:C8`IMT@4AWV<C4Xfi3@62C^lBYMdPlEXBgakB4
D41@P;38_8QF>dMaXKnhS5Pk@FbP`L2NIc`kHIJn`:A^@cQDRkS4[7]8=e1l/<B^
OTlgAWBXa;B7DcM3KZ31_9=L>3mVVL2oV6Ho>F2H_/NVLD@lG8c0ck5lC3a@Pk?;
^8IA?4ah[<^lSePi@6RL_[R@G3`oI9S0a9]X@caLT;c3Y714>eB4]l^^O5<hCWj^
b;B7E3Q;L:C4]i1I>D=XX<2lUf0n?62G_[nLJd0lG92ob:ahB3aDQkK8/h1A?e21
]=2nT613DGb^c<BHI4Q>LjC8a9i[A4=QU;o1X6]4?5B<]l>YN4`hDHB`b;B3Dci<
N:c4]haH=d1_XL>hT64l?5nF_[bKJ40nG96l`j=_A3UDQ;C9/7a<>Dik[<BfQe4k
AWBT_k^;Ec]1KZ30aYaXAT=XVL34X6a0>5R<^<B[M4/kEX^gbkB1E3m<NJc7]8QI
?4QcYlBlTe`l@FNP`;bHIT0lGiBg`9m/AcUIS;K8[81@@5b8^lnhS5@lC7R/a[^@
FCi6KZ30_YAS?c]PUkbnVfPn>5V<_<BVM4HhE8Bha:]lC3Q<OkC6]8Q@>dUdZ<Ro
T5a0Ag6TalJOJ4A3JIc6b:=c@caNS[c4Yg=4>E63]/>^O4PlCWb`b;R8F419N:W7
`91K>d1TU;nlUV0h=ej<];nPK44iEhbg`J]hBCQ@P:c4/8=C=TMdY/>dQe4d?6RL
_;R>F3HhGY>h^9AT@3MISkS0Y7=6?5R<_lbaP5=0DhBfc;R8F41>O;??`iAQA4Ud
Y/o9W6a9A6RNalVVM4i6IYC1d:miC3mGQk?6[Wa;=dahZl6`PdlfA72Q`;V?G3a4
Ij33_:1YA4=TVkc6Z7=<@5b>^<B[MTThC7^V^:MkC354Lj?0/hIH?3m[W;jkU5ll
@6>D_;jLJ3hoFHbh`:A`A3M@Q;31[ga<>Db0]/biR5PlAg>Xa;R<ESU1J:76`IQT
?T=TVl34XfU4?5N<];bQKd4gChBca;>0Dci@Pk38^8UK@dah[<_0UfA3C76VblJP
KTQ4J9Roa:I`A3iLS;_7ZGa>?5>0/lNcQU@lCWRW`;R<F3a8LjC0_9AS?3aTU;jh
VFho?5^>^l6XM4Q0FHRfb;60DcmDPJo4^HQC?4McY<6iTF4i@6RH`<2LJDA3GiK0
`JAdAciHRKJkZ7A7>Din/<6/P50kBGR^bK^<G3i9LJC4_YAN@4=WWl30VFQ8@fBG
`<JSLD@oFH^ga:mlBci@Q;?3]8AD?4QiZ<6gR5Tl@FjP_[VAFchoH9Nna:5_Ad1P
TKc8Z718?5R8]<R`Oe<nDH2/a;64E3M8M:C1^91O?dM[Wl?0VFQ3@fBC^l2OJClh
F8Nc`:QgASU@PK?3/HM@?Tah/<6fS5HlA76Va<2GHd14JJ34`J5/AT1SV;c6ZGQ8
@5b?_<bcPE0hC7n``:j0C3A3LJK3]8QH>45[X<2nUV51@fBH_l2NJ3hkFHbg_ZA^
A3]DQ:blY7A4=dak[<2`Q5<lBGNWa;R<G3U0K9k0`9UXATIXU/34XG=7@5^<^<>Y
N4/nDh>/`k>0DCi?O:_6^8aL?TAdYl2nUV0l?VJI`<JTLDa4IYNnc:aiCd5LSko<
]X5@?eN7]ljkR5HkB7R[a;R<F3M0K:?4`9QW@ciTUko0VFPo=eJ7/kbLL40fD86f
`:QlB357Njk4]8IC?4QcZLBlTf53Ag2Ta/BNK4M4I96h_ia/A3aKS;S3Z7I9?UB1
]<>[Od`hB7BX`;B7F418LjC7_iAS@4IVUl2oW6i1@6>A_<J[Mdi1FHbd`JinDca@
P:c8]8QK?TidZLJkTeTlA6JH_kRDH3`lH9RnaZ5Y@CQHS;W6YgA6>560]<^aP50l
CWb`bkV<Ec];LjC4^I1I?TQYW<70V6A1A6NF_<2QK44lEXRc_jQgB3Q@P:c4/81D
?4akZ<BcRE`nAfjP`KNDISm0HiBi^i]XA3aGR;BlX7A8?UN7/lBaPEA1DH2``KJ9
FD18N:S4`9MWA4M`X<30VFM0?5b@^<2PK4<hFHjhbJaiBcaFR;c<]8IC@560^=31
T5a0B7>Ta[b@FCToI9Vl_Y]V?3QSUkk4Y714>5R9^<>WNdThCgja`:ioBcU4L:Nk
/HI@=caXVk^hTf10?VBH^KVLJ40lG92ha:MhD45IRKW4/8=A?U20[/JhR5/nBGRY
a[nDHcm3Jik1^IQT>cQKTKc0WV/o>568^LNXM4LfCh2aa:n1DC]<Nk39]h]I?TAa
Z<JoUV50@6NPa/JPKTQ4H9C0b:I_A3QFR;C7Z7A8=4]h/<VcQe<lC7n_al2@G41<
M:O7_YQV@4=WW<30W6M3?f6C_lRXN4i3G8^lc[>3DD5@NJc0]XI@@4Q`Y<>oT656
A6bK`L6HId11H8ni_Ym[@3iHQ;?4ZGQ8?51kZkb^QdhkC7J[`;R@Fd18L:Bo^iMS
@CmSV;k1Wfm8@62C_/R/O4`lF8bfb;23E41COk36]8MD?TQcXL2dReLd?6JH^kVA
H3`lHiK0aj5cBD1PT;k9[7i>?UB7^<RgQ5A1C7^/a[R8FCa7M:C4_YAO?T5XVl33
Uf<o=e^<^<6PK3lgE8Ja`jIdAcA;OZo7]81?=dQgZLBiSeLg@6VOa;^CGSPgH9Bi
_YQT?cQLT;c7YgA8>5^>_<^`P50nDHBic;R<FD1@O;3<_Y1N@4I/Y<6nV6I1@fJH
_l6LJdPnFhba`:1`ASQ@OZc0[7mA@520[/6cQeLgA7>S`k^DHD58K:C7a:5^BD=W
Uko8YgA9?eb;^lR`PDm0Dh6dbKR8DCa4LJO0^H]H?TAYW<2nU60l?f6D_;nLJ40i
Fi2ha:QfBD1HR;S4[7a<>4alZl>dPE@iAgJYaknAGT=6K:30`9QV@caSU;_4Wg18
?5b;^<V[O4lnE86fc;J6Dci@N:_8_91K?TA_X<2lTf0l?V6C_[bKJD<nFHbg_:1/
@CQ>Pk?0[7Q;>4]h[<6dQe@nAg2Wa;R@G3a0Jj71a9iVA45VW<C;Y6m8?UnA`<n`
NDPnFhbkckb6D3a;OZk6^8I@<D1`X<>nT60o?fbP`<6II40nHi2kaYm/@CIIS;C3
ZgA3>520[<2^OTlgBG^Xa;R;EcQ3KZ74^9=P?41SUk^oX6a8@62A^lBXMdi0E8Ba
a:]hD3U?O:W4]hQH@4UdY<JnTF4nB6jL`<6NK4I4I9C0aZMgASiGR;S8/7i<?4n0
/LBfPDllB7BWakR<FC@nJic1^I1L=c]OUl2lW6Q0?UV?_<6TL4<kEXRib;20Cci@
Q;C8^hUF?U1k[<VoU5m0B7BXb<BKIdA4J9c4`ia/@caPS[S7YWA;@5R6]/6YO4Tl
C7NW_[1oD3Q4L:31]haL?4A/W<71W6U3A6BH_<2TL4PlF8^ha:ikC41<PKC6^8IH
@4UhZ<6hREHf?6NL_;VAHd0lI9Rn`i]V@CQHS;_8YW=8>eB8]lRcOe0iC7b/a;J7
E3Q6MjS8`8iP@DU`Y/W0WVA4@F>I_<>PK4Q0H9BhbJadC3mDQkK4/81A?U20/<Vk
REPnAW6Sa;b@G410J9bn`i]X@CaNTKk4Y7=8=e>4]<JXMTPgC7bdc;N;ESa;MZc;
_i1G=ciVW/2nU5/i=eVA^kjLJ3`hEhbh`JMaA3]CR;S8]7a>?U1o/LVgR5@iB7JX
a;b@FCQ0Jj34`j1YA41QU;c8X719?UR7^<>[NdTnE86_a;>4E3Q7M:O1^8aL@DA^
Y<O1VfU4@FNG_<>LK4<nG8jl`jUfB3]@PK34[ga9<D5dXkjdQ54hAgNXbl>IIT18
L:C9bJ5[A3mPVlK9Zg=7>EN@_/R/MTLgCh2dc;B0CcI8Nk38^HaG?4Qc[<RlSUTi
?6NNa/>KJ413I9S3a:=^A3]HRk?1Z7M8>e60[l2_Q5@lC7BT`KB8FCi1Kj>o^IQX
@D=[Ul36X7M<@5b<^<6SN4`lDh2dak>4E3a<N:W4^8aG@4=/Y/C0UfA4@6ROa<JP
K4@nGhnla:IdA3QCR;S6/Gm<>D]n/LRdQU4gA7>X`kR<F3PoKZ?7_iQP?3mTW<?0
VFLo=UV@_<JPJd0cCh6da:]f@cA<NJc1[Wi<=dMcZ<6hS5@k@fbTa/JLIdQ6KZ76
cZ]dCTQXVL??/7]??eR8/LN`OU4gC7RT_Z^1Bc10Ij2l]95H>caSVkk0W6A4@EnA
_/VWM4`nG8bhc;20CcmCOk77/8=@>4QdYlJhS5Hg@6JP`;RDGS/iGi6k`9UW?cUF
QkS3Z754>eB6/lVgR5@lDh6`a[R<ESU6M:O4`9AP?d1YX<30W6@l>EnD_<>QKd@i
F8biaj]kC3iAQ;O8]8AD@4al[/RnS5a3BgNXbLBKId=6K:36ajIaBD1NU<38Z7I8
>5>3/LBYO4TdB7JX`;63DCQ3KZ31^iAP?TIYXlS3XFM1?enI`LRXL4HlEhblc:ad
ASA6Njc0/7]8<3m`ZLJkReLd?6ROb<BIJ4A0Ij?8bjI^B45PUlC<Z758?5R<_<bf
P50oDhBfc;V8E3U8M:O4_8UD>3mYW<2lU60k>EbA^kjLJ3lfFi2kaj]hBCQAPK38
Zga?=TQfZ<6`Qe4dA6RP`KRDG3/nHibo`j5^AT1SW<C>[gU@A5nC`m2fPe@nDhBf
c;R1Dca6MZW8_8iK>D5/Wl70U5lk>Eb@^L>PJD0hF8Vg`J=`@cA<OZjnYgM9<d]l
[lRfR5<iBG6Wa;R<F3Q4Jj34_iaX?d=TUl74Y6i0>564/;bTL44dBgn`a;>6E3a<
O:c7_8aL>d5_X<C0UfI4AVjQbM2/MT]6HIO0ajQdAcMAQkC4[Wm>?4n0]/VlReTl
AgR[b;j@Gci3Jj38aYiX@dAWV<C4X6Tl=U>4/knPJd0dC7n/`k60D3Q<MjW0]XaD
?TQaYlO0UVI0B76Pb<RPL4<oG8bh_:1_?cUDQ;C1Z7]<>Dan[l>cPdlfA76T`;R>
Fc]0K:34`Ia/@D5XW<C7YgA9A5bA`L^`P510E8Jhb;60DCm<Njc6^8QG?dQaZ<Nn
U5hk?VNH_/2HI3`iG92i`9mY@cUDR;K4Z7Q;>5>0/<RaPe0kBGN^akj@G3i3KZ74
`9QWA4=XVl34XFm8A5j@^lB[LdTkEXRabKB1E3iDQ[?;`9AN?dahZLNkTf0n@6JH
_[bHISlhEXng_YmX?cA?Q;?0Y7A4=dil/<N`P5<iB7NYa;R<E3U1J:34_iAP?T1V
Vl78Yfm7@5n@_lb^O4m3G8^lc;N6Dd1@Ok78^8UF>DIaY<2iSeLf?6>G_kRDG3Hf
E8bf^IaT>CICQ[?4Z7M6=e>6/lBdQe@kBg^^a;B<F3]6KZK4_YASA4AXW<31W6a8
@F2@^lJXM4U0FHRhbk20DCm?OZk4^8aF?d]aYlNoUehnA6bP`L>OId0lH9Bia:A/
ASiKS;O6ZGU8>eB0/<BdOThiBG^Ya;V>FC];Lj70_9AS@D1[WkboWVa1?Un@^<2S
LdLgE8Bca:alBcU>NJc4/8MD=dM`X;jcRE/l@fRN`KnKIT51HIS3aZMfBd1LSkW8
[7U@@EN7^<RdQ5I1D7b_akR8E3a4L:2n_8mQ@4=XVL30W6U4@F2>^<BQM4a0GXVi
b;20D45GPK36]XaI@4adY<6kT5hnAVbPa;bLI3lnFi6g^iiX@caHS;W6Z7Q;?U>0
/LB^P4`iBG>X_Zn8E3a9L:73^i=O@DIXVK_1X6U8A6NH_<N[O5=4H92hb;20DCiC
OZk1/8MG@DmfZ<BiT614AVbP_;^HIT=3I9Nn`:5aAd1KS;O1Z7M9>Dn0/;nYNd`g
AgBS_[24E3U3K9^k]i5O?4=TU;VhVFU3@62@];bTL4HnE8Nd_:]gC41<P:c0/h5D
>d]hX;jgSem1BG6O_l6IK4Q4JIJk`:1dB3iNS;O4ZGU>@EN4/<N`P5@lD7bXa;R;
GT1>Lj71^9AP?dAXUkVkV6M0?5n?^;jTM4]4GXjha:j0D3iDP:^n[X=D?4UdY/2g
Sei0A6bP_[RDJ4M1I9Rn`9maCdALSkNnXGA8?UR0[l2WNdhkBGRW_:j0Dci6L9nl
^8iL@4=YVk^lVFU7@f>D^L2TLda1Ghbha:b1E4QLRkO8^8aLC5R0/<BlT6A;CWJQ
^KNDHd10Ghnc]9I[ASmLS;2kY7A<@5=o[;bWNdhnD7RX_:n7F418M:O0^9=SATQ/
VkjiUfU7A6BD^l2TN5A<Hhnha:n0F4IHP:S0[X1G@DmcX;^`R5a1B6^H^;B@HdA6
I96d^9]/CdMPS[70XgQ@?eb6[;bWOeA0E7RY`:n>GTAAM:Jo^IQXC4a/W[bhVfa;
A6BD][jNL4hlF86[^9miD3m?M:NhYh1H@DidXKbdS6A;C72L_;RHK4U;JiJh^:1d
C4INS;>hX7M@@5N4[;VYPEQ4E7RX`:b8H4I@L9bh/hiOA4UWU;JdUfQ4Af6>];bQ
M518G8Rd_jQoDdMFOjbk[8AHAeAkY[bdSV=8CW2I]kJ@I4I6Hi2a^9]^CTISTkC4
Z7iKBF69/l>/Q5Q6EgjT^k><GTA>M9bd/i1VA4AXT;RhVGQ?C6R@^;NPM4m8FHN[
]Z5hDd=DO:BgZHALAe5gX;R_RfA9BfnH][NDJDa8Hhnc/iQ^BdUOR:^fXg=DBEb4
ZkbXP5Q7E7bS]:b4G4U>LIba[X]VBDQ[U[2cUV];BfJ@/;NNM559H8j`_:QnFdQG
PjRgZhAIAe1fW;R`R6A9D72L^;JGK55@JIBa]9acD4aXTK2hYWaGC5n7];n/QUm?
EgnY_;6<He1DMZ2g/i1SBdaXU:jaU6I8@en>[;BNLe=6G8RX]jAkF4ADOj2fYX1L
AeAgW;B`T6I;DG6H]k>HKda?K9Bd^:1iF4iXT;2lY7mKC5b4ZkBSPEQ3F7BP^:N7
GTQAL9^d[i5TBE1TTk2_V6a>BFB>[;JNMU=;GhJX/J1lE4MHNJ6gZ8IPC5UhXKN`
T6I@EW2K]:nGKU1@Jhn^/ia`DE1TR:RaX7QGC5b4Y;>TQ5a8EWROZjR;G4a@L9V_
[haXCda/T:b`Ug1DD6N<[;6NN5M>I8RW]:J1G4iOQ:JgZHQTCeQiW[B/SVQ?E76H
/:nDL5AAJI>`/iadETaNQ:B`W7QGBEj0Y;6TQUi>Eg^P/:V7H4i?KYJ^[8aXD51^
SZR_U7=FDF^<[;BOOUaAI8BX]:63G4mLNj2`Y8ISCUMlW;6[T6a?Eg6A[ZjHLe5D
JHbYZIadDdaNQ:BYW7UIBeb1XK6QP5m@F7RP/:V<IU5GL9R/Z9A^E5=[SjR^V75I
E6J<Z;2ONeUAI86W/JR0G5=LO9b_Y8AOB5A`Tj^YRFA@DFjD[:^DLEIGK9Bd]:1k
FEATR:RcX7aLD621Y;6TQfACG7bP/:^?J5IIM9R/ZHm^D4mYS:JXV7IDDFN7Y:bL
OV5GI8NX/jB8IeQPO9n^ZHQWE5MfVjb[TfmDEW>A[:bFMUMCJ8VW[9UhFE5PP:>[
WWaODemlW:VPP5i>F7>D[:J8IU1GL9B/Z9A/DeA/T:R[Ug5DC5n4X:bONEa?H82O
/J67I55LMij/Yha[F5UdV:n`U7AIEW2@/;>LN5aHK8n/]:5nGeATP:B^WX5SDeal
W:VTQVQGG7JG[jN?K5AHK8nTYi1/E55WR:6TU7ADD661X:bINEa?G7RGZIj1HE5K
M9BXWXAXD5I`T:VTSfaFE6R>[:bDMeaDIhJT[9QiGU=OO9b^X8AWEV1lW:jTS6UH
G7BH[ZbFLeQHLI6X[9]dFeATS:>YVGaLCfB0Wj^NOemCG7^LZ:66IU=FM9N[Y8a_
E5I^SZRTT7AHF6V<YZRHMV=LJHbT/9n0I5QXQ9b/Y8AWF61oVjjVSW1HH7RAZJB<
LeQHJhRTYY=cG5UVQ:2WVgUNF6B0W:^PPFIGI7nGZJR<JEaON9BTY91aEeQ^RJ>S
SgAHD6N8X:VIN61FHHBS[9n3IeASP:2dY8Q[F61gV:nXS6aHG76?Z:B>KeMHK8^T
ZIUlH5QXQ:2XV81TEVAkWZ^LQfQHGW6CY9n;KeUNL8nWYi5dGUa`SjB[VG]QG6j8
Wj^IO6AHH7bHXi^0HEAPNIJVX8IYF5Q`T:>SRfmIF6b;XJNCLeiHI8BLYi]nH5QX
PIn^XhI[GVAoW:VSRFULHGNHZjR<K5aLL92XZ95`FEQVQ:2VV7AHFFJ0X:RQPFAI
I82LZ:26IeMLMYBPW8Q/F5]`T:6ORfUHEVJ8X:NDNFALKXJL[9aoK5iWPIVSW8IY
G6AdS:>NR71LGW27XJ2>M5iNK8NPXiMfH5]VQibWW7aQF6QoUZNPPfMIH7VDY:B?
KeUNN9>S[9IdH61gT:N/V7aPEfb8X:RLP6AIIh>LZ:24J5QNN9BVX8Q_FE]gTJJP
S7AHG6n?XjBDNF1LK8NNY9IlIf1/QYbXV85YF6AnV:NQR6QNIWbLZjBCM61PMYRW
Y95cHeiXRJ2TTgQPFF1lUYjDM61DF7B@X9QlI5QNLi6TX8QXFf1cSjJWSfmLFFb<
WjRLN6AOJ8JKY9^0J5QWPINTX8U^GVAoV:JSS7APH7VFYZBAM5iLL8bPYYAgHEQY
QYjVV7iQF65lV:BOPf=LHg^GY:J<K5aPMXbPY8]/G5U/QYbTTgMOF6V4UZ2CN6AK
I7jDWYAoIeaWNIBTX8Q^H6IiUZ6TT71TH7B@Y:VHOVQPM8nOZIQlIeQQO9BNU81X
F61hTJRLQg=PI7BCY:6?L65PLHbSY9AkHF1`R9nXUgiVG6V0V:BHPFMKH7JDXI^4
J5aLL8bOWXa`G5aYR:6NT7MPF6R4X:JIPf]SJHRT[ZR8LFAWP9^XXHU/F5a^RInK
QfmHF6j8XJRANF5LK8JPZ9QlI5MTOi>QV7mVFFIiU:>KQVaLI7bCY:6>LEaSN92P
X91aFeQYQiRLTGQSE6>3V:6HP6MHHgjDYZ21JEMHLH^LVhM/EUQ^QY^IRG1HE6B1
UiV<M5mFI82NZ9V4JEiXOibYX8A[FemfT:RVT75PI7J@Z:VHOVATM8jVZ9alI5iX
Q9^TVh5XH6alW:^LR6QLHGbDX:6>KU]PL8jSX91`FEQXQYbQU7IPFfR6VjJLOfQL
I8BLZ:B8L5mTO9B_YhagGUmgTjNVTgMTH769Y:RDN65QK8>N[9QiIeiWO9NWX8=V
GfMhU:JTSW1IH7BAXJ>CL61HJHVLX95dFeMSP9^TUgaSEf63V:6OQ6QLHGbLYin<
M5aLN9NXYhmfI5a/S:BVTGMQG6^4X:bLP6QOK8BLZj23H5QTMiRSWhUYEeihTJBW
Sg=IF6j;Xj>CN5aHJ8BNY9QlI5aTP9bTW7mSF61lV:VSR71LHGRDZ:N@M5iLL8RN
X8mcG5UXQ9^QU7QLEV5lV:2FO61DH7bGY9n7JEaNN9>PXhi/G5acT:JXTgQNEg6@
XjbHNF1FJ8>LYYQnHeQTOiRYWhQ/E65iUj^TT7AIF72>Yj2CNEmLIh>PXIMnHeaT
P9bXWh5XGVJ1W:bSR6mOH7RHZ:><K5UGK8bTY8idHea_T:V_VgaTFFR4W:RINEiD
GgBAWiAnHe5LM8jPV7mTD5A/R9VKRFQCE6R7XjRDNF5GJ8RPZIaoHEIPO9VXWX=X
Ff=hUZBLPfMHF6b<X:28K5aLK8^SYYIgGeQXQ9^XVgiXFFR6W:^TR71PIWjH[ZJ;
L5aSN92Y[9AhGf1cSjNWUWQLEfJ4W:2FN5iFHGnGYin0JEaTPI^XY8iaH6R0X;B`
Vgi_JGbL/;BLO6QPLHRQYiAhH5MVP9RWW81TG6QnVJRTRf]KHgbFXjB@KUUIL92Q
Y95cFeMYR9nTUWQPEf>3X:^LPFQKI7jHZ9n4J5QNLiBTX8QXF5Q_S:6QRG1HEfV4
W:2?L5ACGgbLXiAgGeQPOYVVW85XG5ihU:>PR6mNG76<XJ6;LeaNL8JOY95iH5aY
Q9bTW85VFFJ0VjJLQVUKHgjHZ:>9Kf1ONIRQY91dH5ifT:BXSgQTF6n<Y:^HP6QL
KX>LZ9N1Ie]XO9NTVhAXFF5dU:>KS6aNGVb@W:6AL61IK8RIYi=iI5QYP9VQU8AV
EVAiTj2FP6MIFG6CWj><KV1NMi>SYY1dH5a_S:2VU7QTG6b8X:VHO6AHHg^FXiQn
HE5KMY2SW8=XEUUdTJ2PS6aIEfb6Vj><LeaDJ8JQ[9]lI5UXP9bYV85TFfIlW:RP
R6ULGgJFZ:B>L5aOLHnQY9=fI61`Sj>YW81XH6b7X:^LPFQIJ82IZJ27K5iTO9RX
XhU/F5a/R:2LS6mDFFV7WZJIN61KJhJOY9V3HEMVPJ>_Y8i`HfV0X:bYU7APH7RD
Z:B>LEMIKXRQXHmdGUU^Rj2WV7mXGfb6XJbPR6iQK8BN/:>9K5QSMXnPX8i/Ff1_
RIjLT7AGEfR1UiR?LeaDFgbFW9IlHeQONiVVX8AXG61kV:RTSW=LHGNCYjBALEaH
IXNLW8i_GeQVPiRPT7AOFFJ0V:RPQ6QKIX2IZ:2;LE]OMi6VY8mdGeUaRJ>TT7QQ
G6b7XJBHO6=LIh6LYY]oI5aSOYb/Y8Q`HFMnW:bXU7APHGB@YZJ@L5UDI8JKX9Id
H5m/R:>XW81VG6^3VjBLPfILI7nKY:24J5ULLHnPW8IYF5a`RJ2QT75LH6n<Y:JD
NF=LJ8JLXIQnGUIPMiBSVH5XFemgTj2LR71PH7B<X:>@Mf=PKXNSYYB0If1/PibX
X8A[HFAkUZ>NQVUGGWJ@Y9b<Le]NKh^QX8mfG5QXQj2QTgAIDF1oUj>HN5mAG7VD
XIMlH4mGM92QXHa/Ff1fUZb[U7]SH7NDZ:^HO6=LKY2TZi]kG5QVQ:BXWWmQF5ai
VjNOPfQLHGbHZjB9KUaOM9BXXhi^FEi_T:BWV7QTH6j<XJBGOVINJ8NPZ9n4JEaO
N9BPX8Q/G5adR9bSR6mOG6j8Wj6GO5aIKhJLYib4J5aWQYbXXHa`H6AiV:NST7AL
G7NAY:2<L5]FJ8VOXI=fH5Q[Q9bPTgUNEVAlVj>DN5iAF7BDWiR0HEAIKhbPWXAY
G5U_T:2VU7APG6b9WjRGO6AHJ82IXiMoHEMTNIBTW8M^GVQnV;2[V7aXJGbHZJRL
O6APKXbTZ9R0I5aXQ9bVX8=WG61hU:BPRfmNI7jH[ZbHN6QVMYB[Z9MgH5]XR9bS
UWQPE6AnV:NGOV1@G76DXIV3I5IGM9NWXHa_F5Q^SZBTSW1HEV^9Y:bHNF1IJHRT
[9n1IeUVPib/XHAXFFMnW:jTSVmHGW6?Wi^8J51@HH2LW8UXD4iPOiJNSfaAC5il
Uj2FNea@G7^LZJJ<K5aPN9N/Z8iaGf1hUjn^W7iWIWBC[;BSQ6MKK8BLZ9R0I5QV
Oj2`Y8QYG5mhUjRTRg1NHGNF/:jGNF1PL8^XZ9AfF5AQP9nTV7]KEUmnW:VLOV=?
EW6@X9b8J5MNM9R/Z95cGUiaTJJWTg=LEVB1W:BCN5aFJ8BLZIilH5AIM9BVW8AW
E5adU:VXSg1LG76<Y:NAMUmKKXbW[in4JF1[QinXW81PE5adS9jKP6QFFgB?Y:6?
LEaHJhVPXi5dG5AWQj2XV81YG6b9Y;2QPfMGG7RIZ:27K5iPN9b`ZiAhHF5dT:RV
T75NG6b<Y:RINf=KJHRNZ9ilH5MON9NXX8A/GfAoUjb[Sg1NFg6<W:><L5]FJ8BN
XiAiGUQVPI^SV7]LD5UfTJ2IQ6UDF7J@Y:N>K5aHKXjSYY1dGeM/RjB/W81WGW6<
Y;>TQVQII7nO[:J8K5aPNiJ/Z8UaF5QaRj6TRfaDDfJ4Y:RHNE]KJ8NQ[:1lH5IO
OY^[XHAXEV1nVj^[TFiKG7BDYjN@L5]DK8jTZ95fG51TQZ2VTgAKCUahW:VHOf5G
GWNKZj24I5MGKi2SY8a/F5Q_S:B[U7QSG6b9XjbKPFMLKXRT/:>;JEaWP9n/Xha/
Fe]dTJBPS6mGE6V9X:BDN5mIJhRPZIUlIUMTPINQUgmTF5ilVjNQRFaHEg2@YZB<
L5aLLhbTZ9AhH5i^R:6TVH1OEfAoW:BLQ6QKG7nLY9n7K5QHK8nOVhA[FeA/SZJV
T7MOFFb9Y:nLO6ILIh>NZj64J5aWP9bYWhI/FEmiU:6QR6iLG7>?Y:NCMf1KL8RN
Z9AkI5]/PIbVV8MYG6b3W:VLR6aHH7BDX9b8J5QHJ8VNW8mdG5IVPijWV81XGf^7
X:VPQVUPIWbHZ:26J5QLLi2TWhQ_F5aaRInLRfmHEf>3WYn@Mf1GI82OZ9R0J61T
OijXY8Q/H65hTjRSRG1LHG69Y:JCN61PLHbPY9]kH5aXQ9bTV8=VFFInV:>KQ6]N
GWRCX9j7K5aOL8VOW8]`GV1`R9^QTgILFf^3Vj>HP6QLJhBNZ9j8JE]TN9RVWXU^
G5]fTjBXT7ISGgB<XjNDO6AOKXRQZ9R0JF1[P9bXVHA/G6MoV:RPQg1NHGR@Y:2<
K5aNJhbPX8mfGUQ[OYRTU7aTGfb3W:BOR6]PJ7bDY9b8KU]QMhbSWXU`G5a_R:2O
TGQNG6b4Wj6HO65IHGnGWi]oHeaTN9BQW8I/FemgSYjPR6aIG76;Wj>AMf5PKXNP
YiJ0JF1YP9^SUh1VG6AiTj>HOfIKH7R@X9j9KUaPMi2QYXmaH5i_RJ2TU7]TH6j6
X:RLQ6iWLHRP[:N8KfI/OiJWY91dH6AgT9jPT7APG6n8Vj2CN6=NKhNIXiMoJ5mX
P9RPV81VG6AhT:2GQ6aGH7JCX9b;KUiLL8bPX8afHe][Q9jSU7aPFfIkUY^DP6AK
H7R@W9b4L6MTN9>OV8QdI61aRIbPSWITH6j1VJBDO6mYK8BIXIb4K65WO92PVhAa
H6=hS9jLR75TI7B>XJRGO6QQM8RLZ9R0JF5/P9RTVh=[H6QhT:6KQ6aNI7R<Wj2<
Kf1VM8jPX9=hHEm_R9RNTg]TGV^8WZ2HP6UVKXBKXIV4K61TNi2LW8A[H61dRiNI
Qg=PGg68V9^?N65NK82GW91lIemXO9>LU8A/HFIiU9jIRFmSHg6>W9V8LfALJhBD
VHU`H5UXOi>LTgiYH6]oTIbDPf]NI7R?WYR6Lf5TN96OX91hIfIfS:2QTg]VIW>8
W:>GOVQQJhBHWiR4JEm/P96PVhQaHFQkTj2NSgIWJGB@XJ2DN6AOJhBCW8igIeiX
PiVOU85XGfR0Uj2HPf]LG76<ViR7Kf5QLhVLX8adI61`Qi^SU7aTHFj4VjRQQ7=X
LHNKZJ2>LfAXNi>PWhmgI6MhRibNRG=QGVb4UiJ;Mf1NJgnDVI1nIf1[O8nKV8A^
I6UlUj2NT7QXJg^@Win?N6QSM8bLXiAlJFA^Q9^PUWmVGfQnU9jHPfaPIWR?WYb;
Lf5XN8jQXHiiIVAcS9nNTGUSGfV0UibDOVINJ7bAW920J5aQN8jHV81[GV1cRI^I
RG1NH726W9n@MfIPKXJHW9AnIUm/P9BKU81XGfQlUYbIR6aQI7B<W9b<MV=TM8nL
WYIlJ6M`RijPV81^Ifb7W:>LQ7=XK8BLYj28M6IWO9BSX8ifI61`R9bPSgITH6n6
Vj>FO6QPL8BIY9^4K65YO9JPVhQ/GfAgSijNRg1PH7>8VI^9M5iLK8>HVHagGUaW
O9JOUX5/I6alU:>GQ6UOI7B<WYb7L6AWN92QXiAlJ6]hR:2SU7aTGfR0U9bAO6QQ
JGjGX9V3K65TN92OW8Q`HF=dSj2STGMXI7><W:2FO6IPJhJIWiAnJ5aTO9BNU7mX
G61cTj2IR6mPGg28VIV7KUiOJH6HW8icGeaYO9BOU7aWH6j4V:>LR6aQJh2FY:2;
LfAVN8bOX91cH6AcS9^NT75OF6R4U9bAN6AKJ86HYYb6K5aVOiBSWhUcHfMkUZRS
T7UTI7J@YZNANFAPKXRSYYR3J6=[Q9bWX8I_HFQoV:BORFaNI7B>Wij;Kf1NK8^K
W95iI65`RIbVUgaVG6N0V:2HOfILH7^DWiV3K5iSN8jTXH]dHf1cS9bQSW5PGVb4
WZ2@NF1HJ7jCXIIhIUQNN9>LU81VFF=dS:2IQg1LGg>?XJ>CMfMTM8jTZ9R1K6Ad
S:>/XH]aIW64Wj^KQ6iIH7>>WiJ4JeIHK8NHV8]`F5Q/Q9^PSgIOEfAoV9jCOfAH
HgbHX9R4K5aQN9>QW8I_Gf1fT:6SS71NGW29X:6@Mf1LJH>IY9MkIeaYPIbXW8Q_
H6QnVJRTTGISIgRCYZBFO6AVMi6[Zib0K6IaT:BXX8A/HFj7WZRIPFUHH7N@W9>3
JeQLL8bKUhI/G5iaS:6QTGQSH6j;XJRLQ6]OJ86KYYb1JEUOM8nOUWiXEeQ`S9VG
PfQFF6j8WZ2?LeaLK8NPXIAiHEaXQ9bSUW]TEf1kU:BLP6IHH7J@Xij7K5UOL8^O
W8i/F5QVPiVPU7QQFFJ0V:>LPFQLIWnFXin9LF=XOYN/Z9AlJ6QiTjBWU7ISH729
W:2DMV5HJ8>DY9QnJ5aWOiRTW8I/FfAhTjBLR71KGgJ@XJ6@MV=QLI>XZ9QkIf1^
R:2XVh5YGfR3VjBKQ6QKI7RDWiR4I5QKKXnLV8M/GUU[SYjQU7IQFfR7WjRKP6aS
K8JQ[Z>9K61WO9NTX8I/FeaiU:>SSg5NGW6AY:B@N6ANKXJKY91lHeaTO9bQUX1V
GVAoWjjTS71QJ7^IZ:JCL5mQLhnQY9MdGeUXQibSU7QPEfAoUZ2FO6MDH7VDY9^6
IUQNL92NWXU/FeadSj6/UgQXH7>>Y:^DP6QOL8JT[Yb0JemXOYJVWh1WFf5dS9jI
Q6QFF724V9R7KUMDJ8BHW8idGeQWPiRSV7iWG6^0VJRNR6mQK82LZj6<L6=TMiBT
Y8i`GUmaR9bPSg1KF6B6Vj2LOfINJhBKYij7KUmVP9VWXhmcI6AhUZBQSW1PGVj;
W9b<LEmHJ8BIX9AkIUaVO9VTU7aQE5afT9bHOfIHG7B@X9j7KemLLHnQXHicH5m_
RIbQT75PEfJ1V:BGO65HI7nGY9b1IUQQNINTX8i`GV1dT:JXTgAPH72>Z:jOPfQT
M8nT/:R9L65/RIn[XHa_FF=lUjJORG1KGW>@YYj;L5QHJHRNX8a`GUMTPIRPTgIO
Ef=nV:JLQ6]KH7VDXI^6K5]OMYN[XI1kJFIdUjb[V7aXI6^8XjRHNfMPJH>LZI]l
IUaTOYR[XH=/GV5hU:RQRFaKGg2;WjB;L5aHK8BLXi1kH5][Pj2VVH1QGV=lV:2L
PfMLGgRDXj68K5]LM8bNY8maG5U/QibPTGALE6J1V:2FNF1GH7bGX9UoIUAIMYBS
WXU/G61dTjRXT7QSH7B?Z:bHN6APJhNPYiilH5]TP9jVW85VF61lV:JPR6]OGgBL
ZjB<Kf1LKY2WY91dH5UXRJ6YVGQVFfN1WZVKOVALI7bIYij4JE]SOiRXYha_G61d
T:RWT7MNH7><Y:RDMUiHJ7jGX9AlGUAPN9BNV81QEeadTJ6PR6aNGgB?ZJR@Mf1P
KhRPY9IgH5m/Q:2[WgiTG6J0V:JLP6MGGgRAXin6JEUNM96XY8a`G5a`S:NXT7IN
G6j8XJ^LO61IJHBL[:24I5QSO9^VW8IXF5igTjNTS71OGg>?Y:BDN5mLK8VPY9Ql
I5aTP9jVWX5XG6=oVjVSR6iLGgRGZJB<L5aOLi2WZ95dGUa_R:6VU7UNF6V3WjNI
PF=HHgbKXj26I5UPN9JVWhQ/F5i`T:RTSfmHFfV9XJBFLeaIJ8RPZj20I5MTPij/
Y8U/F61nVJRTSVmLG7RFZjV@M5QIK8VWZ95dG5QYQj2YV7aQF6B1X:RNPfMHH7^H
Z:27J5AHLi2TX8U`E5M^Rj>PT71HF6R7Xj6ANEaDI86NY9alHeQIN9RVWh=VEe]d
UZ^WS71NH7JDZ:^HMUiKKhbTYiQlI5]XR:2XVgaSEV1lV:RLP6ACG7JAXin9K5UL
M8bTY8acFE]^Qj2QT7QNF6V7X:JIOV5KIX2PZij3I5MONiRXXhM/FE]fTJNVS71H
G7>?YjJDN5]HK8^TZ9UoHEIVQZ2^WXAXF65lW:NLR6MDFg2@Y:>8K5UGL8jTZ9If
G5MXQj2VUgaODF5oW:NIP6AFGgNNZib8J5ALM9R[Z91_G5a`SjBYTgANF6b<YZbH
NF1HJhNQ/:21IeUTPj2`YXQ[F61hTj^TRFmGFg6<YjN@L5aLK8bWZIMgG5UWP9jX
VgUOF6MnW:VNQ6AGHGbIZ:N>JEQILi2SY8m`E5M/RJJVU7MIDf>6WjBKN5]@H7nK
Z9j3I51POib/YY1^EeadVJVTT7=IF76CZ:RDM5aHIXRSYYAdGeIOP9jXW7aOEV1i
W;2TR6aKH7^H[:bCLEaLLi2XZ9McF5MYR:BYV7UOF6J4X:VLOfAGHgbIZ9n4I55O
MY6WX8U[DEM_Sj>NSW1HEfV>YjNDM5aFI8>OZ9]kH5IPOYRXW81SEUmfV:^PRFQF
FG2CYZB@L5]HK8bTZ9=dFeIXQZ2XVgiQE6>0WZbNQ6ADH7RI[:B;JeMILI>[Yi1d
FEadU:b/W7]QGVb<YjbLOf5II8BP[Yj0I5ANOYb/Y8QXF5acU:VTRfaLFg2?YZNA
L5]HK8nV[Y]kH5MTPJ2_X81WE620V:bPQ6MDGWRG[ZN>L5QHKi2XY91cFEQ/S:B/
VGUSFfR8YjnPQ6IHI86L[:21J5IPO9B/Y8]/F61fV:nYUWIKG7BC[[2HN5iHJHRV
ZiioGUQTP9bXW7iPD5UhTj6OQ6QGF72@Y:28K5QGJ8BQXhQ/F55PPI^TTg5HE65h
UjRHNEaDH7JGZjB6J5ALMY2TY8m/Eea`SjJVU7ALF6b<Y:VLNF1HI8NNZ9b0HeQT
P9n/XHQ/EUakUjRSRg1GFG6?Z:B@M5QGJ8bTZ9IgGeQXQ:2YUgmTF6IlWZbQRfML
I7RHZjJ<K5QNM92TXhi_FE]`T:JVTgQOG6b8XjRKO61HI8>KZ9j4IUIPNI^XXH][
FEQcU:BTS6mKFG69XjRAMf1LJ8RSYYUkI5aXQinYX8AWFfR0VjbTQV]KH7RCZ:J?
KeQPLhbTXiAfFeAWR9bSU7AOF6J4X:^HN61GHGbKYij3HEAOMYBVX8QYEUU`TJBT
T71HFfj?YZNHN61KJH^PZ9ihHeQPPIbWWX1TF5aiU:BQP6]GF7B@ZJB<LE]LLHNT
[YQhH61aS:2YWgaPFF^4W:RKPfICH7^DYib6J5INLI>VWXm_FEa^T:BVTgQSG6j<
YZRGNfAPK8bT[9j0IU]TN9NWWXIWEUagT9nPRFaLG7>?Xj>CLeiNL8bPYiUnI61`
Qj2XXhQWH6R6WZBSRfiOHGnKYjB<LeaLMi>VXhidG5Q^S:6TTgIKF6^4WZBFN5iD
H7bHX9MoI5AOMiJTVh=XF5]`U:JTSfiLGW2@YjRDMf1LK8VSYYalH5QSQ9bXVgaT
E5akU:BPR6]LGWBDXj6?M61LM8jTY91fH5m^RJ6VTGITG6^7W:NKOf=IJ7jLZ9b7
J5USN9BTXhU/G5adT:>VTGING769Y:NLP6=PK8ROXI]oHeUQO9RNV81TF61fTI^H
PfAHF6b<V9V8K5QGJHVLW8icGeaXR9bQU7QVG6N4WZ>IPfQLI7bHY9b4JE]NM9>T
XHa`H61aT:RXTgMSH76<Y:NHO61LIh6PYij0JF1YPij_YXa_GfMiV:NTT6iKH7B?
Y:B@M5mLK8^OXIAgGUaXQ9bVVGiVG6R0VJJLPfILHgRGX:6@Ke]PMhnPY95dH5a^
R9bLT7QLF6R3VJ2ANFALI7nLYZ26JF1TP9VXY8adH6AlU:RVSgAPFfj;WZ2@M5iF
IX>IX9=iI5AQNi2QUWaSF61gTIjHQ6UHG7B?XI^8LEaLKY2TXi=dI61_RibTU7]W
GfR1VJ6HOfQLI7bHY9j4Jf1VNiBVX8aaGV=hTJ2TTgMPH7>9X:>CN5mIJHBOY9N3
IeQPOY^WWXI_Gf5hUZbTT7IQJ7RAZJRHNFIWM92TZ9MhI5i/R9nVVHAYGfR0W:JI
Q6ULH7VFYYn8JeaOM9>SX8icHF1`S9nTT7ASFfb4VjNHO6ILJ82HX9J0IUISN8bP
Uh1XEea`RijKR6aLH6j;X:2@M5iLJhBLY9IiHeQPO9NOUX1VEUahT9nKPfaIGW><
Xij;LemQL8bSY9AhH61^R9jTUWMTG6J4V:6GNfAIIWbHZ9b4K5aPMYBVY8mcI6Ig
TJBXUWQSGfb7Vj2@MV=IIhBGX91hI5UTOYRTW81WG65hU:RPQfaLHGB@Y:6@M5mQ
L8bPYYIhIVA^R9jVVgaYH6^1UjJLPFQKH7B>WYV4JeaKLHRLX8QcI6AdRj>WV7iT
Hg>8WjRLP6aVL8JOZ9n6KfIYO9JTX8M`Gf1hSj2NR75PHG28WYb;M5mNJH6KY9^0
JFQ`R:6[XHadJFn4Vj^SS75TIgVDYjJ>MVMPM8jTY95hG5a/OiRNSWALEfAiSibC
N6=IH7N@W9V4I5]LLhbGUhM^H61dT:2TU7]/I7B?WjBGO6MNK8NNY9b1JeiTOiBN
TG]TDEIYQYNCP6QHFfn<W9j>Mf=TL8RPX9QlIf=[Qi^TW8=^I6b4V:NNQfaPJ7^@
Xin8KUaPKXbLV8a`Gem_R9^OTGAWHFb4W:BGP6]PKX>HY9j4K5mVO9>QVhQ_G6Ii
TjJTSgAPG7B;Vj2?M5aHJh2HWi1kH5MXP9VVVHIYFfMlV:BLRfmNHg>@W9b?Lf=V
Lh^PXI5kJFQcRj2TUWaXI6b4U9bHO6MLIWjCXIV4KUiSN8nQW8UgI6AhSYjLSWUT
Hg26WZ2@N6IVK7jHW9=nHF1YNi2NW8A`IVQoTInLS7ATJGB;WiR@NFAWLHVLW9Ao
Jf=/QY^LUhA/HfQlU9nIR71SJGbDX9b9LfIVL8bFV8a`H5a/R9RPSgITFFAoU:2F
P6iNI7jCXiR8M5aYN92TW91cH6A`RIVKT7ASHfj;VijCO6=OL8JNX9InI61XP9bP
WXQ/H6AnTinKR71PGg>>W9b;M6IXN9BXZ9]oK6MhS9RTU7aWF6IlSi^AP6ILI7RD
WYB3Je]PLhNHTH=^Gf1^R9VHRg1TGfN0TIB<LF1II7V@XIJ1M6]`Q9bYY8ihJfj0
T:BQSgUXJgR>X:2AO6ITLhBFVhihI5]TNi2HT7aXG6=lTIjHQfmPHgB<W9R8LfAS
Mi2PX8ahJ61cR9bTU7aXH6j0V9nDOfILIW^DWYJ0IeaQLi2LVhQ^H65gSYbPSWAS
Hg><WijDOfIPKXNKWiR6K6=[Q9bPVHQaI6QlU9jIQg1XHGJ@VIR9M6ASL8RKW8mk
J6A`Qi^PT7UXIfV0UY^DOVQPIgR>V9B3JeiQLHNHV8MdIVA`QYNLSgIXI6b3U9bD
O6UQK86DXiR6LF5[P9RWXi5iJ6anUZJTTG]/K7^@YZNDOfaVM8RIX95kIeiWO92H
S7ITFfAhT9V@P6aOHgN;WYN7MfA[NHjPW91kIfQdRInLTGm[I6j0V:6DPG1XKX6H
Xin?M6U_OiJPWXmhI6AgSiVLSgQWGVn8V9b@O6IPJGnIX9AoK6=WO9BLU7mYH6=h
SYRFQ6iPI7>8VIV8LFASL8NHV8idH65[PIBHT7]XH6QlT9RFP6iWIWb>V9N4L65V
MhRHVhQhJ6=iT9^PU7i/Ig>9W:2CPfiSL8BGWYN4L6Q/P9RSW8agJ6alTj6LRGIY
IgN<X:6?NfUTLHRHVI1lHf1XNi>KTGQXGUmhRiN@NFMHGg63UY>0K5aNK8RLUhaf
If5/Q9ROSWU/I6^4V:2GO6mTJH2DY9R3Lf=[O8nTVhQfHF]hS:6KT7QTJ72>WYRC
NFIQKXJGX9AkK6IXO9JNUX1^I6]kSj2LRG=TJgR@Wj2AMVQYN92LX9AhJ65_QiRP
Th1YH6n0UYbGP6aTIg^?ViR4L61QM8RHV8I^Fem`R9RLS7ITHG24Vj2AOVANJH6F
W9R1IemTN92KUXA_Gf1hSibLRgITHG><WZ2COVQTLHJLXIN0K6I_Q9ROV81/HF^0
TIbDQVUOI7NDW9R7M6QSN92OX8mgIfMaRj2PSgQVHfR1UiVFOVQQIWb?VI5lJEaP
MhVHUhA`Hf=dRiVLS7MVI767WYj<O6QQJHJKX9V0KVA/Qi^XXhQfJ6QoV:NQS7AT
J7V?Wj2;Lf1QM8RPY9IlH5m`PiBLUWiSG6R0UYbGQfaPIWjGX9b8L6ATMhnKVhQ`
H6=`QYNGR71QGfb7V9b@N6QPK8>DX9J1K6=YNiJPVHI`IVMhTj>PS7ITJ7R?Y:>A
MfATKXBLX9AkJ5i/Q9RSUX=YH6]kU9nDQ71QHgJ@Wib8LFATM8^NWi1hJ6QdQYbO
TH1TH6aoV9jDO6IOI7bDWiV1Jf1VNi2SXH]dHfQhT:>LU7QSI6n8VibAMf5NIh>H
Vi=iI5aTP9BPV7aWGVAlTJ6ORG1PJ7^@XJ2>MVATMhbLX91gI5i/PiNOT7USGV^0
UZ2KPFUPIgbFY9j8L5mSLHbNWXaaI65`RibQTgUXH6b6U9nCNfMQJgbFWi=nIe]S
O92OW8A/FemiS:2PRGIPH7>9Xj2@O6=TLHRLXiQlJF5/Q9RQUgiXGVQkTJ6DQ6aI
HGB<V9J6JEiNLHjLX8agHem`S:6TV7aTH6V4VJ2DO6QPJ82HX9N1K61XP9BTX8Ug
IfMhS:>LRgQPH6j7V9nDNfQSK82GXIN1K6A/P9JPW8=XH6=hT9^HQVUKG7>;VIb4
Ke]HKXRPXI1hI5iXQ9bTUWUWGfR4VJbLQ6iQK7bCY9j8KfAXNIBQXHidH6AhSZ2Q
SgITH6n6Vj2ANFAIIX2DWY1lJEaSO9BQVhA`H6AfT:BLR71PI72;Xib>MUmPL8^O
XiQkJFA`R9^VW8=/H6b0V:6IQ6UOHGVCW:2<L6AOM8jPWh]lIf1gS:2TUWaXH6^6
W:2DP6QKIWjFX9^3K61PMi2OV8=[G5iaS:2QRG1QGg2<X:>@NfANK8BLY9AoJ5mW
O9RPU7iXGf1kTj2NPfmQI7J?XIb<LF1SLhVOX91gHf5[QibLU7aWHFj3VJBKQ6aT
IgRFWiV4K5iQN92LW8]_H5m_S9jOT7aVG729XjRHQfiTKh^PYin4L6A/Pi^/WXQd
HfQlUZ6PS71QIWN?X9b?M5mNKXRIWiAgHE]TOiJOU7aWFEmiTInFP6]LH7RAWj68
Kf=PN92NX8mcGeQ/Q9>PS7AQF6UnV9n@O6AOJGnHXi^4J5mTNIJQWX]`HfIhTInP
S7ATGfj7VIb9L5mLJh6HW8igH5UVO9JNUgmTG6IkU:>KR71PI7^DY:2>Lf5TMi6T
X95hI65`R9^LSWQSG6QoV9jFP6QPHg^HX9b9L6IXOiRTX8mhI65hU:NSTgaXIWB>
Y:JDO6QSK8BLY9b0J5iWO9>SV81/FfAlT:BLRG1NI7B<X9b;L5iPL8VLWY1hI61/
QibPU7aVH6R0VJ>IP6QLHgV@XIb8KeiTMY2VXi5gI6MdSj2TTGUXGfn7V9^@O6=L
IW^DWYB0IeaQNIBLW8I/H6AgSinLR6iNG72<W9b>M61NK8BKW91fH5]VPIBOVH1[
GfV3VJ6LR71PK82HYj2;M61PM96TY91hH61`R:>TU7UTH6^4WZRLPF]SK82IYin>
L65/NIBSVhQ[Fea/RibKS7=XIg2@X:>DN6MSK8NLXIQlIV1XP9RQVH1XG65hUZ2L
R6QHGg6<Wib9L5iLK8RKW8mcGea/Q9ROU7aVGVR1V:2LRG=VK82HY9^8M5mQMY2P
WX]aGea/QiVLS7QSGVb4W9b<N61HI7^DW95lIeaTNI2OUh1YG61dT9nIR71NI7N<
Win;M61OLhRLWi1lHEi^Q9nTVGmWGfR0VJBNR6UNIg^DY:6<LF1SMhjNX95hH61`
RIjOT7QVGV^6VibAO6AIIX6DXiUnK5iVOi>VWXU`H6QhTJNQSgITI7B9WZ6@N61K
Jh2HW95kH5QTOYVPUh=[H6R0Wj^TS7AYJ82IZ:R?MV=VN92VYY=lHF1aR9bSU7QT
GVV6W:2FP6QNIWnHXiR4Kf=VN9BSW8]_HFIhT:2VU7ASG6b3V9b>Mf5HJ86GWYAn
J5aTNiBTV81^Gf5lUZRSR71SI7J@Z:J@NFASM8bPY95gHEm/PiVPUgmTG6^1Uj2F
OVQLIgjDXIb8L61WNI6QX8a`G65dS9bLS7=PG6b6Uij@O6QPKXRQZ9b7LFI_Q9bY
Y8mdJ6QkV:BOS7=PGVb6ViR7K5aLJH2FW8]dGeAXP9BNTGaQFFAfTj2COVQLH7B?
X9R4JeaQM92NX9=dI6AcQijTTgaTH6j4VJ>IP6QTK82KY9j7K6AXPibSY8adIVAl
Tj6TT7ITGgB8W:2>M65LJH>HX9AiIUaYPIRVV81XFFAnU9nKQ6aLH7N@WYb>Lf1Q
M96TXI=kI65dSj>XVgaYHF^6W:BHOVMLHgRAW91lIUQKK8RHUWmWFea/Qi^LS71P
Gfj9X:BFNfMQK8>IXIMnJ61XOY6LUW]TFfAhT:2LR6aPIWJAY:6>LfATM8jPYYIh
Hei^QiRTV85VGVn4VjBLQfaPI7^GWin7Jf1PM8jPW8QcHEm_R9^PS7APG6j4Vj>C
P6MPKXBLYib8L6A[PIbYXHadIValUZJPSgITIWR@XJ6CN6ATM8^PY9AoJFA`Q9bS
Uh1XH6V0V:2HQVUPJ7jFY9j6KemNL8bNW8UdHEm^Q9^LS7QPGfaoUijCNfALI7RD
W9N3J5aTNIBQW8Q_Gf1fSinLR75OH6n8W9j@MV1PL8NLYYQnIV1YP9VSV81YG6Ak
U:BLR75TJGRGY9n>L61QLHbOXI1`H5iXRIbPU7IPF6MoTJ2HNF1HH7R>W9V3JEaT
N92QXHa`H5mdSibTTg5SGg68W:BCNFALJh6FW9=lI5]QO9>NV7mVFEidT9bHQViI
Gg68X9n<L5mLJh^PX95dGei[Q9jPUg]SG6N1U9bFO6QLI7bDWiV6K61WO9NVXHig
IVMfU:RWV7i/I72>WjJGOVaLJ8BHZ9b0KV5WNIBVWXIaHFIhU:NVT7MWI7N>X:J?
M6APKXJIXI1gHEUVNIBNTGaVGV5dTj>LQ6iPH7R<W:J?LFMWMXVNY9=lI61cQiRP
U7aTH6b3VInDOV=IHgR>VIIlI5aPN8jHV8M_Gf1gS9nPS7QWI7R@XJNGOfQTM8^S
Z9V3JF5/P9RVWXA_I6MlUjJST7QXJ7V@X:>?MVATM8RNWY1fHF1[PiRLT7]TGfV0
Uj2GPfiQIWjFWi^8Kf5WN92QWhafHf=dRIjNSgIQH6b4UijDNfAOJ7nAW9J0J5UT
N92NTh=YGVIhTJ>KR7=PIgN>Wib>MVATLH^OX95lJFAaQi^TVHM`J724X:NPRg1X
JGbAW:28L6=PN8jLX8ahI5adQibSSW]QGfioV9nCOf=LJ7bFW9J0J61PLhbDT81W
G61`R9RIR71OG728V9R<M5mLJHBGW9AlJF1/QYbTVhA`IVR0V:2NRGISJ7bCXib7
Lf=PKhBGUXA_FeQWOYBHSWQQH6^1V:2IQVmTKXBIY9n;LF1TNi2NVhUaHF1aRI^K
RGITH6j4U9R@N6IOJ7nDWY5lJ5iYO9>NUXA[HFMkTj2LRG=VJ7J@X9b?N6UXM8bO
X91kJFA`Q9RPU7]XI6b0UjJHPfaQJG^DWib6KV5TM8^HV8A/H61_QiBIRgQXI7>4
V:2AOVUTKX2IX9N4K6A[OYJTW8MaJ6ahT:2OSg1TJgR>W:>CNfQQM8RGWYIoIV1[
P9BLU81/HFUnU9bIQg1VIgVDWij>M6QVMY2NXi5iJ5m^QYRNSWUWFfMkT9R<P6]O
J7V@VI>4L6AWNHjLVHQgI6IgR9VNSWQ[J767ViV?OVUTL8BDWYAoK6A^PiJPVHUd
I6b0UZ6LSgQYJ7V@VIR>NFQWMXbLVhmkJ6A/PiRLTGm/I6]nTibAP6iSIgV?UiJ3
K6=TMXbGUhQcIVIcQiRLSWQYI724UYbCO6aVKXBDX9^4L6U`P9BPW8QcIVQhS9NI
R75YHGJ>U9^>N6]SL8NIXI60L6A/P9BOU7a^HfIlT9bHP6mPHgB8W9R6MVAVM8^N
W91kJ6M`Q9RKT7i[I6ioTi^AO6aTIWR;Ui1iJEiSM8BFTH1`HFIgRibHRgQWIg27
W:2DNf]WKX6CW9=oK65^OXnIUX=/HFQgS9^GRGMWJGR>W9V?N6QYLhRKW91kJF=[
QYNKU7a/Ifj1UZ6GQg=VKWb?WYb<NFU/NhnLVHmfI6=_QiBGRGMWH6^3TiN@OfiT
J7n@VIAnJf5XNI2OW8QdJFalS9bOS7MYJ7>8V9V?NFQTL82HW95lKVQ/PI6ITh1^
HFQgRiRDQfmSJ7B<V9V<MVQYN8bLW91iI6MaPiNLTH1YI6n1U9NDOfQQJ7b?V9B8
L61YNI2KUhQfJ6AcR9RIR7MXHG26Uib@P6UVM8>HWi>3JFA^O9RPVHUdJ6UlU9nL
SgQ/K7VAX:BAP6m/NHVPXiR3K6adQiRNV85/IVmoSiVFPFaPIgB8U964K5aOK86>
T8AcI5i^P92GS81/IW61U9^@O6aVJ7VAVI63Kf1XO8nNW8]gJfQhTIbOTGQXIg68
X9j?NFIPK8BHWY=hJ61VO8nLTh1^H6MkSi^FQ71TJ7B;ViN8LFAQK8>AVi1gK6A`
QiNPTh1^I7>0U:2HQ6mTJ7V>Vi^7KfAXM8RDUhQdI6AdRIRHTgm`K7R?WjBHR7A[
L82DW9B0JF1VM8VDU8MaIVQiS9^KRGMWIWB;Vib<MVMTL8>FVi1kJ6=/P8jKU81_
Hf]lT9^FQVaPJgR?W9V>MfQ[N8jOX91iJfQaR9bPV81[J6b1V9bDO6QPIgn@ViV4
K6AVN8nHV8I^GemdR9VNQg=NF6b1U9R@Nf1KJgnCV9>0If1VO9BLUXAaHfAlTibL
R7AQGgJ<W9N9Mf1OK8NIWY1lK6I_Q9^QUX5^J764VJ>LQg5WK7nCXjBAN6a_P9BT
Y9=lJFQiS9bLT7mVHFn1V9bDPFaYKWnFW9R1KVAVNhbGV8Q`I6IdR9BDPg5TGg24
U9R9MVAOJGbDVHalIem[Oi2LUh5/H65gT9RDP6]PHgB8VIR4Kf1NK8JGVHi`HF1/
Q9JQV7i^I6j4Uj>FQ71NJ7bCW9R7K6=VMi2LVHUfIVQhRIjPSgQVI7B>WinDNfIP
K8BHWY=oK6A/QijTXHmiKg67W:RXTgm_K82?X:2?Nf=SLhBKW9=lHfA/P9VLV8A[
I6^4UZ6SS7Q/Kh>KY9n?Lf=VLh^KWhiaI61[QYBLSgIWH6V0T9N<N6QOIg^?VI1k
IeUPLHJHT7a/Fea_QY6@QVaLGVR1VIR<N6APK8BHVi5oJF=^P9NNUX5^IfUlTibK
Qg5WJ7^@WYV9N6QVN92OY91lJfIdQY^PTGiWH6UnU9^DOVQOI7bAXj28M6=VN8bP
WhadH6=aQiRHR7ISG6n4Ui^@O6QSJhBHW9B1L6A/PI>TV8=dI6QiT:2KRgAVJ7B7
Win<N6AQLH>GX9=lIfI_PIRNUh1/HF^0Uj2HQVmTJ7VDX9V7LFQVNIBPWXmfIVAc
S9bSTGMYGg26Tj2CNFIPK7nDWYR6KVA/P9JPWX]dIVV0U:BQUX1/K7b@X:>GPFmX
LHRKX9AoK6A^PINPUh5_HFAhT9bFQVmSIWB;W9V<M6AWM8VHW8iaI6=/P9BKS7QT
G6QkSiR>NFAHHGR;UY1oJ5aOL8NGU8A`H6=dR9VKR6aPHFj3UYV<N6APKXBGX9^3
L6I_Q9NTW8UgI6]lTj6KRgMWIg>;VIR<M61PK82DW8ihI5i[PI>KU81XGfanTinG
PFUNHgR?V9R8KV5QLhRFV8Q`Gei_P9BGS7QVHg28X:RPSWUaO9>X[jRDNFmaR9VY
XhilIfb0TJ6PT7MTIg><Wib@NFQPK8>GWi5lJfAXO9BKTGQXH6=hS9RCO6UPIWB;
ViJ3KV1PL8^HW8idIVA`Q9NLT7QXHFb3UZ2DOfUQJGR@W9N1K6ATMh^HV8A_Hf=c
RI^LSWQWI726Vib?N6QTK86FW9InJf1XOXnOV85_H6UhSinHRg=SIgR@X:6FO6aY
Ni2NXiN1KVMfR9^NU7m/IVUoTi^DPFaQJGbAWib9M6QXN8bNVhahIVM`R9VHSg]Y
I6n6UibDO6aTJ82AVHmiK5aQM8bHTGiXH61cS9^GQ6mPGg24V9V8Lf5QL8JHWi1k
IV=_PIVOV81VHfR0UYjLR7AVJ82GXJ>AN6]YO96OY95iIfAdR9bPU85XH760U9nD
P6QPJ7V@Ui64KV=VN92GThA`IV=gT9RHQg5TH769VI^<NFaSK8BHWhikK61YOiBQ
V8AcJFb0UjBORgUYJg^<Win;M6IPK8BHWhigJF5`Q9BNTG]VGVUoTj2GQ71SK82D
WYR7L6AVN92HW8QdI6=aQ9VKRGAXJ7>8V9b@MVISK7nAV9>3K6=/PINSWXaiK721
Uj2NTGi^KWbCX9jAO6QVLHRHV8iiHf1/PINHTH=/H6AlTIJFQ6iSIWV<UiR7M6QT
M8RHVi1lJ6IdR9JLT7aXHF^0U9RDOfaSJ82DX9V4L6AQNHjHU85`G5a`QYRDP7=V
H726V9V8M6=PJgbCW91iJ65[OiJPV8M`IVUkT9nHQ7=TIWN@X9j;MVQVLhJIX8ad
If=`Pi6KT7UTH6alT9VCOfQOIWR;UiR4L6AXN92NVi1hIVQhRIRPT7U/IgB;Wj>G
Q75XM8VLYib6M6=YOiJPUh=[HFAhT:2HQgIQIWR<Wij@NFQWL8NLW91lJfA[P9>K
TgaYH6MoT9jHP71QIWb@W9N8M6=TMXjKUhQdHf=^R9RKS7A/I7B;V:RIPg5YLhBI
Y9R6LFQ^P9>LVhA_Hf5hS9^IRG=PHFb0TiB7LF1LJh2@VI1gIf1[P9BLU8A_I6n0
U9jNRG=WJ7V<VIV9M6ATM8NHVHQhJ6A/OY6GS7QWI6b0U9bDPg1VKX2DWYR4LFAW
N8bIU8M`H61`R9RIRG=TH6b4V9^ANf]TL8BGX9J0Kf1XOY2NV7m[HFAfRibHQgAP
I7N<X9b<NfISN8bOY9R1JfQ`Q9bPUhI`IVj0U9bFPg1TJ7n@Vi^8LfIXN8nNW8ad
Hf5`Pi6HS7ITGfb0UYjDPFiVL8JHX9^9MV]`PiRPV8AdIf]hSinIS7AXJ7B;VIN;
NFQTL86DV8QhJ65YO9>NSWa/H6QkT9bCQVmQJ7B9V9N8M6ATLHRHVHahJ6UdQi^O
U7m/J7>3TibCOfaSJgb@ViB3L61XNhbKUXMaIVAgSYbOT7QVJ7N9Wj2@O6MQKX6D
W9AnJ6A/O92IU8A^I6alT9NDR6mPIWR@W9R>NfQVMhnLWi5nJf=^Q9BKS7m/I6al
U9bDQ6mVJGb?VIB1L6MXN8nKV8alJfalRi^IS7][J728UiR?N6]WK86@V91hJ6=Y
O8bGU85`H6IlRINIR7IXHgB;UYR?Of]TLhRHW920L6I^P9BNTH1`I6ioT9jDQ7=T
K7^?ViR9MVUXN8bFUXQiK6QcQiRISWa`JG24UiV?O71YKgn@Vi5oKfQ/NHjGTHA_
IfihS9RGR7AXJGN8UYb?NFUYM8BFW9>0K6QaP9BLUhA/J6alSiRFPfaVJ7V<UYR<
MVMWN8RDU8mlJ6UdR9BGTH1`Jg24TiB@P6aXJgn@U924LfAYNh^CT8MdJ6IdR92A
RGM^J724TiB<O6mXLHBDVi20L6M/O9>HTHA^IfUhSYNCR7AYJ7R9U9R7M6]TM8RD
V8n3L6UdQ9RITHAaJ6inTIB@P6iXJgR<U9>3M6a/NHbGV8]kKfahR9JHSg]_Jg>6
SiR@O75[Lh6@Vi>3M6]`Oi2HU8MhKVaiR9JFQ7I[J7J8UYR9O71/N8RHVi20Lf]d
Pi2FSWi/If]hRi2<O71XJ7N7U9B4N6]/N8RGU8aoL71kS9NLTh5gL7N7U9R@PG1Y
LGb<V8b0LFQ/NHVDT8AcI6QfQ9>AQgMXJ7>0SY>8NfUXLgj;T8QlKVU`P8nCTHId
K720S9BCQgU`K7b<U9J7O71^N8NFV8UlK6]dP92CRga/J760S9B<OW1XKW^>U928
Mfm`N8nDT8QgL6idR9JFQgUcK7B4T9N<O71YKWb;T8QiJFM^N8N@Rgm`JG1hQXj<
QWMYK7N7TI>8N6a/N8NAU8UlL6U^PI2AT85cL761SYNHRH1hMhBCViR?P7MfPHnG
U8]lLG1iQiBDRg]aKWR7TIB<Og1YKg^9THanM6i^NhbDT8MiL7=lR96AQWM/KgAo
S8b4MfaYKh6>SXQiL6a`O8R@S7idKW1lRI6<P7A`Lg^8TI>7Mfm`NhB@U8aoLg1i
Qi2DSh1dL7N1S9><Q7A[M7b6T8]oM6a/MhJ>Rh=dJFmfPi2@S7a`L7N8T9N<NgQ`
MhN?THb0MVmgQ8bGTHInM7B0RI2@PgU`L7^4SXb3O71^N8>9S8QnLfacOX^?Pg]d
Jg1hQY29PgM_L7N7Ti>8NGAdNhBCUh]nM75lQi6DR7iaKWR3SY2<P71_M7j9SXUo
Mg1dP8R<RH=hKgAlQXb<QgU`L7V6Rhj8OgA`NhJ<ShV3NGAiQ92CS8AoMWR4Qi6<
OgQ`MWb4ShV3MVmaNHB;S8QnM7=kQY2ARgmdM7R1S969OgI`Lgn<Shj8N7AhP8bA
T8QlM7AkQXj@R7]dKgJ0R8b8O7AdMWj8THaoM6i`NhB<R7maK71hQX^9Q7I/K7B0
Rh^4Mg5/LhB8S8QlM7=kQ8jCRh1iLgR4S9>>P7QcLh29T927NgAgP8^DThj3N7^3
SYJDShAlO7b8T8b;OgA`L7b3RHQlMW1aNHB?S8=lL71iP8b;Q7U^KWAoQhR4Ng1^
Lgn8S8AkLFmcO8N@S8AkMWQnR92>Q7QgN828SY27O7AdO829S8IlLgAgP8j<Rh=h
M7N1RHb<PGMdLGb6Rhj3N75cOX>9S8AhKVadOXJ8OgM/Jg=kQ8R4Ng=_Lh28RhQo
N7AgPHb@T8QnNgj8T9NHSX5lO82;UiB>QWUhNhB<Ti24P7ahQhjCSh1lMgMhP8^1
NG5^M7IoRHV1MgIcN8>;ShQlM7MkPHb@SX1dLG60RhV<OgIaL7V3S8n0OWIfP8RA
THN0N7MoQ8b@Q7adLGV0S8b3O6m/M7b8S8MnM6mcOhR?S8AnMgQoQi29PgU`M7V6
SXR4N71`M828RHMkM71aP8R<RgidK6aiP8V8OWM_KgR0S8R0N71cNH28RH=hMW=i
P8R<QWmhM7R1Rhb<Pg]gNGj6T8^0NGAdO8B;S85gM7AhPHR7P7A[KWAkQ8R4NgA`
N828S8R1N7IiP8R8R7afLGAnP8R9P7UcM827RhR6OWAdNhJ>ShR1NGIiQ8^<RH5h
LGAlQ8V8OgidLh28Shn7PGilP8jASXb4O7UoRI2>S8AlNGb8T92<Pg]hN8>>T8b0
MgQgOhR<Sh5lN7N3R8j@R81iN868Si27PgQcO8><ShJ0NgIhOXb@R8AkN7UoRHb>
R7UiNH28Ri26N7A`N824R85hL6mdO867QWadL7AlP8>0N75/M7j0PH5hL6a/MX66
PGihKfikQ8V>RhN0O8>?V9RCSXB3P8RCTi28OgUhP8^@THMlN7QlQhb;QW]cM7V4
Shn7O7MdMh2;RHIkLgAdO8>8PgQ`K71kPHN6O7A_LgV3R8B0N6m`O8B;RhR0N7Qo
QY2DS8R3Nh6;SXn<Q7QhO8>9SXV0O7=dOXB;R81iM7MiQ8R8Q7ahM7aoQhMoO71c
M7V4Q8=iLGAfNHJ9R81hNgb4Rhb@Rh1lO8J9R8j7O7IcO8B<RhJ1N7AhOhN7Q81g
LGIoR8b;Q7]kNGj9Rhb7OWQgP8N<SXMlM7AlQ8bARH1hM7b4R8N4O7IcNH66R85k
L6icMh27PG]cKVmhNhB8OgM`M7UoQhJ3NG1fO7n8S8N4NGN0Qhb?THQkNgb0RHb;
R7akNh2;S8j8Ng]hO8R;RHMlMg1gP8J9Q7ahLGJ0Q8b7OgQaMgb4RhN1NGIhOXJ9
R85lM75nPhR<Qg]fNGb3Rhb6PGQdNH24QXAoMg5dO824PgahLG5hP8N4OWQdLgMl
PhAlNGIdN7b4R8R0NGakOXB;S8IoNgb0R8b<RgmhO7b3QXJ1NGA`Mgj1Qh1hLFmg
OXR?Qh5hMWb0S96@R7alPHJ;T926O7QlO8J8QXAiLg=hPHJ4Q7]dNGR1R8n<PH1h
Nh64R8N1N7IfO8B8RHMoNGn3R8b>RH1nMgj6QhV4PG]gO824QhInN7AdO8>8Q7ii
M7N0R8j;Qh=nP8J>UY><Qh20PHR@TH^0O7n3Ri>DT8InNGn4QXj<P7MaLgb0R8Io
M6idNhJ;R8=hM75iQhR8P7AcL7R3R8b1O7QdNH28RhAlLgAfNhB4QgafMgAoQXb9
PG]dM7V4QXN8OWQdNHJ8S8IlN71cOXB8Q7miM7IhPhb8OW]hN7b6Si28O7QiOX>;
T8AiM7QhO8R;Q7icL7QnPHB0Ng1`M7V4QXB4NgQnQ8V<SXN1Ogj4S92<R85hN7^4
S8R6P7]hN8>9RHJ0NGUgNHN9Qh1lN7V0Qhn<QWagNGQlQ8R0N7QcMgj3R8MoO7Ql
P8B<R81nMWV0Q8V4PGadNGb4R8J0N7MhO7j4R85kMgQoPhN;Q7afMW]oQ8N4P7Id
O868RHB3NGIlP8V>S8QnO7n3R8^9RH1hN7b6R8V9PGmlNhR>SXR3O7IiOhJ9Qh1n
M75lPHB7P7UdM7]nQ8MoOgAdN7^4PH1nL71aO8N4PH1iMgMlQ8R3PH=iNH29S8R7
P7ihO8R<RHR4P7inQXn@R8>0O7]oR8^9P7IhMgb4R8V0MWQdOXB4RH=iMWAlPHB9
OWAcL7QoQXIlNG1[LgV0Q81hL6mfO8N9RhAkNGQnR8^9PGagN828T8j8P7QlP8V?
SXR0NgakQhn;ShQnNgb6R8^<PgmhM7n4QhJ0O7AaNH28QWalM75hP8J7P7M`KgAl
PHJ1O7A_M7UoP7mnM6a_N7n3PGmhM7=kQ8^;QX1lO7j8T928P7]hO827RhIoMWAh
P8b@S8AoNgV1RHb<Q7afN7n8TI27OgUiOhN>T8UnN7IiQ8bDSXJ0Mh24R9B>R7mg
Oh69T8n;NgQlNhR;RhIhMW=gPHB6QWQ^L7=iPHR9PGMdMX27Rhj6O7AdO8B9QX5l
M7AkPhR6Pg]dMWJ1RHN4O7IfO8><SXV0MgQfP8b8Rh1cLg5hQ8J7PGMdM7j;S8j8
OgQdOh^@Th^3NgR0S9BCSXIkMWV1Si28Q7QdM7V7S8R0N7AdN82;Q7ifKgAcP8R3
P7A^Kfn1R8R9O7AcM7n4S8UnM7=gO8B>R81kLGIlQXj<Qg]dN7V6Shb9OgMgO8J9
S8IlN7AhP8R9Q81dL7InR8N8P75cM7b8RHR0N75/MX27R7idKfidPhb<Q7igM7V6
Si><PgaiP8RDV9B<PGinR9>HU8R0MgAoQ8R9OgM`L7R0R8V1N71/Lgj8S8=hLgAf
O8^?T8AhNgj3RI6AQ7MdL7b7Q8V7MW1_N8J8R85fL6UfP8^>PGQ`KWAnS8j4O71^
M7V6S8=iM6m`NHJ>SXMhM7QhR96@Rg]gN7n4SYJ9OgUhO8R@UYB8O7b0Q92CSXMh
L7InR92AQWagLgb;U9>9P7AcN8BASXMoM7AkQ96CS8AhMg^4T9B@Q7QcMX29T8j4
N6m`O8J<S81fLfa`P8V7QWihM7^7T9B?Pg]dOXJ?Thb6N75fO8V>S85dKfmiQ8^<
Q7Q`L7R8T92;OgQhNHR@ThUiL6acO8B;PGI_IfmnRhn;P71^MWb8Thj0MVa`MXB>
S8AhL6ifQ8b?QgQ^K71kQhb8Ng1/LGj8SX^3M6aaNHR>RhAdLG1lRI6DR81iN829
TIJ?P7QhO8NATHanL6a`P8V<RgaaJFmkPhR8OgA/KWb3S8n1Ng1`N86ASXMkK71f
P8nARgicL7R3Ri28OVm/Lgj9SXQoLfaaOXbDT8UnNg^4TINHShAhMX29TiN<P7Qc
N8B@ShUoLFa`OXN<QWicKg1iR8b<P7McKg^7Shn4Mfa`MXB>SXMhK6]dO8R>QgQ`
KW5nR92?PGQaN8B<U9>;O75fP8RCShMnKgAlR92?RH1gMgb;U9RDQWQhN86<TH]n
M6a`OhR>ShAfL7=lQhj<PgQ^KgV1S8b0M6QXLGj8R8AgJF]`O8N;QgacK71oRHj;
PGQaM829U921Nfi`O86>Rh5fKg1dPhj<Qg]dLgR4S8n7O75_M7b<T8V1LG1cO8b?
T85dM75nS96FR7UdLg^6T9B;P7AaO8B?T8alL71dP8N>S7i`KW=nRhj;QWI_Lgn7
S8n8O75`OXR?S8^3M7IoR9B@RhAlMWR;TIBCR7ihNhB?U8n6OgMlPHbGT8IlLgIl
Qhj<QgI[KWJ1Ri28O75/LH>;RHIkLFaaO8N>Q7adKg=lRi6<P7I`L7R7THn1MW1`
N8B@SXQlKg5kQi>HSX1hMWN1TI6<PGAdMh2?T923M71`NHR?SXAdJF]cP8^7PGMY
K75oR8V7O7A`MX>9S8b0M7=fOi2ASXQlMgR3SY6DQWUfL7n;SXb0N71`N8B?ShIh
KfmdP8^?QgQ`KgB3S8n;OgI_L82;TI24N75cO8^FTHQoLG1hOhb>QgQ^K6ahR8j7
Ng5/M82;THn3Mg=gPhVCU8QoMWV0RIB@R7mcLgJ4T8^4O71`M86<S8QlMgAcP92@
R7mfM7IlRhn9P7MgNhB?U966NGAfO8R@S8AhL6afPhb<R81fLgN3T9>?P7QhNHB<
TiB4O7AdP8^@THMnN7AnQi6@Pg]cLgV1S8j6NFm_M7j4R8AkKVacOXJ6Q7acKfig
Q8V7NgA_JgB1Rhb1M71`Mh>?ThIkMW1kQXbCRGadKg^1RI28PGI^LG^9S8N0Mg1c
NhN?RHAnMWAkQi6ARH1gMWR4T9B?Q7aiOXB@THb3NgAhPHb@ShAfM7AkRHn<PGIa
KgR6T9>8OWAdNhBAVI64O7UlPhjAS81gLgIkQ92<Og=_LgV0S8b4N75dO8B<S8Ml
LGAlQ92AS85iNgj8TI6>Pg=dN82<Rhb0M6m/OhN<SXMlLg20S92ARh5fM7b6T928
O71_M7n9ShQlLFU`O8B8Qg]^JfQiQXb<PgQ_KgR0RhQoM6]/M7b4R8=fL6mgP8R<
QWmhM7N4SY2;PgQdN828T8V0MVa/Mh24PG]`JfadOXR8P7M_LgR0Rhb7NG=aMh26
RhUnM71dP8N<RGifL7AiQ8b9P7A_LGV0Ri29Og5fO8JAU926N7QnR9BFTHV0Ngn8
TIRDR81hNh>;TH^4OW=dO8N?ShMlM7=kQi6@R81dMWV0Si6>PGAdMhB@TIB7N7Aa
NH^AShAhL6ikP8b@P7A^KgN0Shn9O71`Lgn8S8UkM71`O8J>SX1fKg5nPhb@Q7Qd
Mh2;T9>;P7AcP8J<THUoLG1gPhR<Rga_Jg=nQ8R7OW1/LG^8S8N0LFmdN8R@RhIl
MW1kS92AS7ahMgN6T9J@Pg]dO8R@V9J9P7MfPhb@ShAhL6miQ92@Q7aaK7>1S969
O7A^Lgn;T8aoLfidOXRDR85dL7R1TIRHSWmhN82?UiJ>O75_MX>;SXQhLFi`P8b@
S7mdL7AoS9><OgMaM7j9U924M6iaNhN<S8=fK6aaO8N;P7I^Jg>1Rhj9Ng5_M7j8
THaoM6adOXB<R81fK6mlQXn@R81`Lgn4T8n6O6i`MX2>S8IlKfa`O8V;Qh1dK7B0
R92@QWQaMh2@V9B<OW5fO8VDShMlL71fQ8j<RG]`KW5oRi27Ng1YL7b;SXUoLFm`
O8R@T8=hL71kPHj@Q7]aL7V3Si26OW1_N86<THb0MW=hQ9BFRhMlL7IoS9J@QWQd
M7R8THj9O75dN8B@T8MlM71dPh^@RGadLGR3SYB@PgM_M7n9THb4MfaaNhR>ShMf
KVQcP8^<PgQ/Jg1nS8b8OVm^M82?Ti21Mg5iQYBITHUlLGR4TINGRgUaM7b<UiN<
OW1`N8JDU8b0KfadP8R@SWmcKW20SY2<Q7M[LGb8THb6M6Q/LHJ@S8QhKV]cQhjC
S7a`K7>3T9>;P7A/K7n@Si21LfaXN8B?S7mhJfQfP8^<Q7I/K7b4SY24O71[MXB@
T8]oKf]aOXb>R7iaJ6j0S9B?P7AYK7b9U9B4Mf]/N8BCU8b0KViiQ8bGSWacJ6ao
S96<PgAXLG^8V9>8N6a/NH^@ThUlL6ihR9>AS8=aKWV4U9R@R7QdMXRHW9R9O7Mh
Q9BKUhUkM7B0T9BDS7]`KW^<U92;OW1/MhJ@ThQiL6a/O8j<R7a^If]kR8j<Og=/
K7R7Thj3N6a[N8VGU8MkK6ihQ9BGS7a/JgAnT9J<Ofa[L7b?T8n6M6U_O8N@T8Ad
JF]fR92@R7Q/J7J7UYR?Q7=/M8B@Ui60Lf]^O8VFTGmgK6alR9BAPGI/Lgb6U9B7
N6mcN8JAUXQiKfifQXjDSgidKgR4T9R@PgA[L82<U966MV]/NhbHU8V0Lg1lSYVH
SWidMgR8V9V@PgQ`MhJ<U91lL6U^O8bAT8AhJFmiQiNCQWa/JgB0S8^4N6Q/L7n@
THUkL6a^P8j?SWi^K6akR92@NfaXK7b7T924M6U^N8B@T8AdJ6QaPi2@RGa/JGB0
SYJ?P75^LGn>U924M6acOhRGU8]lKWAlR9BCS7U^L7R6UYJ<P6m_N8RDUi60LFa`
P8nAS85`J6alR92@P7I/KWN6T8b4MV]/MXN@T8alKVmgPiBHT8=cKW20T9>COg5[
J7b8T923MVQXMXB?ShAhLFigR92AQgQ`K7J4T9J<O71/LH2<U8akLfa`PHbHU8Ag
Kg=oTIbIRh=gMhB@Wib?P7IaN8VDU8]lL6adOY2DS8IdL7J0TINDQgQcL7b<T9>6
Lfa^N8R@T8IgK6A`P8b@Qg]/IW5nRI>8NfiXK7N7Rh]oJfQ/MhJ?T8=aJ6]hPI2A
Q7AWIVinRhb;Mf]YL829T8]lKf]dP8^FT8AfK760SYBFQgQ`Lgb7TiB8O71aOX^G
VI23Mg5lRINHTHAfLgN4TIJAPgI_L7j<TI21LfA/MX>?SX1cK6UdQY>HS7iaL7b8
UYjAOg5`Mh6@V923MfiaP8bIU8=hJfifQ9J>Q7MYKgJ3T969Nfi^Lh>@T8akK6Q`
Oh^AS7i`K71oRi>@PgI`M7n?V9N;O7=fPHbFVH]lLG1iR9BDS7i^JgJ3SY27OW5Y
LGj<U8j1Mf]_N8RCS8AdK6idQY6AQ7Q/K7J0Ti><N6U^L7V8S8]hJF]^P8b?SWi_
IV]kR92@Q7=_KgR<TIB<N6i/O8b@VHaiL6]fQi2DTH5dKWJ4T9RDR7UdM8BDUiV<
O7AdQ96LW8^0L6ilQi2DS7]/K7B4SY29O7=/M8JFW9>9NG5hP92HT8QfKW1lS8j@
QW=^K7J9T927N6UVLhJ>THQlLFQ^Pi2DSWm`J6UfQYB<O6mSIgB6Ti>6Lfa/MhVF
UX]iK6McQ8jDSW]aKW23TiNCPG=/L82<V8n0M6U/N8VDT8A`IfUdQXn@Q75XIWB1
S9B<NfaXM8BAV920M6ifP92KU8MfL7B4TiVKSW]`L7j<U9B8N6aWM8N<T8QiJFI`
OhbCR7a/JGB1U9VDR7QcM82DV9R9M6UXM8J@THMfJfUdQi2FSg]`J766TI><O6mV
KWj8ShakK6IWMhV>SWa_J6IdP8j<OW=TJ721T8n7M6]XL8BAV8alL6acQ96KU7i_
J6akR92>OVaQIgR6TI>1M6QXO8VDV8anLG5hR9bHThA_K7B4U9VAOg1XKgn?ViJ4
MVQYO8bFUhQgJ6UkRINGRga^KWb9V9b>Og5XLhJGVI20KfadPiNLV8IdKfj0TibH
PGM/JGj8U9j7MfUVM8>FVHUhJ6Q`P9>LT7a[IWB1SibGPg1XKX2@ViR<NFmdPiBO
XI1lLGB0SYnPU7m^JG>6U9J@OViWJH2@Ui=nL6QYNHRDSh5dIVafQY2@R71TIg23
U9>8N6QWL8NAUXmhJ65/P9BITH1^HFQlSYNCOfmTGg23T960KVATLhBDV8QgJ6Qi
R9RNT7m^JG>8VI^DQ71YM8>HXIR9NFa^O92LV8QgK6QdRIRDQg=TI6b0T9B8N6QW
Kh2DV9B0K6M`PIBLV8UaJ6ilTIVGRgMXJgR;UYB9N6aYMhbHVI1lK6QfRIVLTH1Y
I6aoU9JAPFaTJ7b@VIB4M6I[O92KUhaaIfUdR9BHRgAWH6b4SYB>N6]SKX6?V95o
L6=/P96LU8IdIfilT9jIS7MXJGR<U9J8M6QTL8bHVI1nKVIfRIRPUXAfK727VJ>O
S7Q[K7jCXIR8MVIXN8VGV8Q`H5i[Ohn@R7QSH6UlS8j8NfQOJ7V?V9>0L6QVMhjI
U8AdIVIfQYNGPg5VI724TiN9M6MTLhBGW8ihJ6A^PINQUhAdK764V:6LRgAYKWV?
W9V4L6MQM8RGVHUfI6A`Q9>HS7UYI720TibAP6]TKWjCViB4LfM[OY2KVhQdIfAg
RiRLRgMVI7B8V9^?O6aXMhbLY9R4L6M/P9JKU81_H6MlRi^DP75TIgR<ViV8N6MX
N8NLVhalJ6MdR9VNU81_Ig1oU:2DPfiSK7b?V9J3K6=TMh^HV8QdI6AcRiRHS7AY
J7J;W:>DOg1YMhVKYY^4LFM^Oi6LUXA_IfQoTIbLR7Q/Jgj@X:2@O6]YMXbLWXmh
JFA_PiBKT7QXHfMlRiR@O6aOIgR;VIB6LfU[N92LVHilK6]hS9bOT7]_IVj6T9N9
M6ANHgN<THMgJF1WN8bKTGm_IVMiS9VHRGAVJgR>W9^AO6UXM8jNW9J0K6Q^QYRO
UX1_I6j4U:2LRG=YK7bAWYb<LFIVM8VDV8UcHf1cQ9BNU7aYI724U9^DOfUQJ7b>
UiB0Jf1SMXVFTh=_H61`R9NGQW1QHg27V9b?NFIQKX2AVI5oK6AXOi>ISga/HFAf
T9VCP71WIgR@X9n<Mf]/N8bLWY1cIfI`PI>OT7a_I764TIbDP6aSJgR?W9J3K6AX
NHbGVhadI6QgQiRHRgUXIW6<V9^FOVm^MX^IX9J3M6I_QYBPU8AaIV]hTibHRgAY
JgR<Vib<MVaXM8bHWYAkK6I`Pi2HT81/I6]nSiRAQ71TK7b?V9B6KVAVM8RHU8Af
I65dR9RLS7I[Ig24V9^@OVUTJGnDVIAnK6A[OY2OVhQdIfQdS9RDRgIXJ7B8UYB8
LfITKXNDV91lK6QaQi^LU8A_JG23V9bFP75YJGj@V967LFA[M8VHUXQgJfQcR9JH
Sga/J724U9>>P6iYKWnCVI24M6iaP9JKVH]hLfakT9NHRGQYK7V9Vib@NFaYLhJG
WiAoK6M/P92LU7i/I6QhRi^FPG1VIgB8V9J7MVUXMh^IV8QhJ6M`Q9^LSWQ/J721
U9b?Nf]QJGJ;U8UoKV1XMhRDTh=_IVMcQ96DR7=THfaoSi28NfQTKWn@U8aiKVQ/
P8nCSh1/IfalS9BFQ75WIgR<UYR<N6U[N8^FVI60LFihRINNU8AgM7R9W:6NRgU_
L8JDVIb;MVaYNHjIW8aiK6QhR9RLS7Q_JGJ9V9nDOg5_NHNDX9B4M6]aPI6HTH5_
IVakR9B@P71VIWB7U9>6MfMTLHBAUXUlJfA/O8bAS7a[HFaiQi69O6aQIWJ4SXb0
LFAXM86@S8AgJF]cR9NDTGa`KW>8UinHPgI/KhB@V9B4MV]cP8^HU8IhK6aiRIJH
RGQ`KgR8UYJ8Ng1YM8RDVi=lKfU_PI2KSgiaIfaiS9B@Pg1YJ7J8TI20M6]/NHND
V8QfL6akR9BOT7m^JgB1SiB<Nf]TK82<Thn0L6QcOhjGT8MaJFacR92?Q7AXI7Ao
RI67M6ATK7R;SXb0L71dQ9JLW8ahLgR4Ti^PT7adM82>V9R@O6a^NHVCUY1lKV]f
R92DSW]/If]oSXb7N6UQJ7^8ThakKVMXM8RCShAdIfahRIBCRgI/K7>8TiN?O71[
KX>@V91iLfU`P8nKT81dJFmgRiVCR7MYKgJ6U9B7MV]/Mh^GV95oM7AiRIRLTH=g
L7N6TIRFQ7A_Kgj;U9>4O71`Oh^HUhaoLgAgQiRDR7a^K7B1S96<Nfa^Kg^>UY64
M6mcP8nGV8]kKg=nRIB@QgMYL7R8TiB<Ng1/LH>@U8alKVadOhnDS81cK760T9JD
QgA/K7N8Ti23LFMYL86CU8UhKVacQiBDT7m_KW20SY>?P6mXK7V8T8ioKfMXLHJ@
Rh5`I6QdQ8n@QWM[JGB4T9B;P71`NH2DV927MWA`OY6@ShAdLFigR96AP75_KWR7
UYR<O75`NHN@Vi63MW5iQi>FTH5fLGN6TibGQWU_LH2<VIN6Nfa_O8NDTHAhKW=h
PiBAR7U/K7>0RIB?NFm/L7n<U8n4M6]cNHRHT8IhK71oRiBGS7Q_L7R;U9B<O6i/
N86<THMiK6Q`OXV@R7iXH6]gQ8V<O6aTI7R6T8b1MVI[NhRDU8QoKV]fQ9BDS7a_
K7B1SiB;Og1YLGn<U8j1LfadOi2FTHIfKg1lS9BDSWU^L7^6T9B9NFi/MXB@U920
Lg1dPi6HUhUiN7b3U9VHRgUaL7b8Si24M6a[MhBAT8b0KW1fQ9JDT85dL761TIB@
PgA/L7b<UiN<NG1`N8^@THalL71hQY2DRg]`Kg>1SXn9O71^LH6>ShUlL6a/N8R?
T7mcL71lR9B@Q7U^K7N1SYB8Mf]/M7j<S8IgJ6I[NhR<Q7]`J6]iRi2<P7A`KWR8
U9B4N7=cN8JATHAhL6acP8V@QWQYJg1hRHb8N6i[KWb8S8alKVQXO8R>T81hK6il
R9>DRgmcKgR9U9R?P7M`N8VDVi64N7AhQ92KU8QhL75kRiB@Q7M`LH2<T9B8NG1`
OXNAUXV0L6ikQY>DS8=aL7V4U9B>Q7I^L82<T8j3MfacOhRAS8IhK71fRI>@Rgia
L7R4TIN<Og5`M86CU8n0L6idOXnGT8=fKVilRiB>PgM/L7R7U9>8O75dNHVHUi63
N7AlR9JOUXUiLgR0SYNCQWI^KWN4Shb3LFQYLH6;S85dJ6A/NhN8Q7MYJ6ahQXR4
MVaWJ7N3R8MhK6U/N8J<Sh1hKfalPi2DR7]`L7^8TiJ<P7I_MhB@THb0M6acPi2F
Sh=fKWB0T9^AQWicMWn9UiB8N7=dNHVCThUkL71dOhb?R7U/JfmnR8j>O71/L82@
U9J8O7AdQ92KVi21N7QoS9RHSX1fLgb7U9N>P7QaNHB?UY24N71dPHbAT8AdJg1l
R96@QWU/JgN4TI26NFaXL7b<SXAkKfQaO8N>Q7Q/J6idQXb8P75`LGb>T9B7Mg5`
O8B@U8AkL71kPI6@RGa/KWB1R8V9N6QXK7b;S8^0Lfa^O8bCTHAiMWAoSYBDRgad
M7^7T9>;Ng=^LH28SXMkL6adP8VCSh5dL71iR8n@Q7A/KgR4SXb6N71/M8B<T8]l
L6idPHnARh5dKgV4S92<OgA^LGb<Thj3N71dP8RDT8AkLG=lS9NDSX1dN7^8V9J>
P7QdNHN@U8ioM71cP8^?S85dK71lRI6<P7I^KWR7SXb6NG1`O8RCUY20Lg1fP92@
S8AhKfmnSi>@PgM`K7^<TI28NG5cNHnHU8]oMg1fR92@RgUcL760SYB8O7A^L7j<
THinLfi_O8J?T8=gL75kQi2?Q7Q_K7R3S8n4Ng1`N82@U8b1Mg1dOh^>Rh1gL7Ao
Ri2>PGQfLGb9Shj0MVi/MXB@T8MkLg1fQ8nDS81hL7R0RiB@Q7A`Mgj7T8j3Mfig
OXN>S8AfK71hPhb@R7]aL7N1Rhj9P7=`M7b;S8QlLFi`NhN<RH1`JfafQ8N6P75Y
K7N3R8V3M6m`M86;RHQnLfifQ8b>R7acK720Ri2;PGA/L7R7S8b1Mg1/NHB<T8Al
M71lR9>AR8=fLGb8U9B9QW]`N8J@U8n8NGQlPI6HU8]lM7IlRi2DS7ifM7b6T928
OWA_MXB;T8QlM71dOXb@SX5hL71kQ92<PGU`LGR4T8n6O75cNHB@ThQlMW=lQi>D
RhAgM7N3S92<O7QaM829THj3O7AkQXnHThb4NGb4S9BDS7mgMgn9THn9O7A`M8><
RHR0M6a`O866Pg]dK6]dP8V4O7A[Jg1lQhN0Mfm[LgV6Rh=lL71gO8V@R8=hM7Qo
S92?QgIaM7n<T8j7O75`O8R@T8MlMg=gPhb?QgmhL7N1QXb;P7AaM7j8S8b4N7A`
OXN8RH1hLFahQ8R;P7I_K7N3S966O7M`Nh>>Uh^1M71hP8bCS8=iL7R3S9B<QgUd
Lgb;SY27NG1^NH2>T8AnLFmiQ92AR7maKgN1SY2?Q7AdN869T8n4O7=fP8V>S85d
Kg=hQ8b<QgahM7R4R8b6O7A/M7b4RHN0Lg=fNhR>RHAgL7AlQ8V?Q7QdM7^6S8n<
PGMgP8R?ThR0N7AiPHb@QgidLgR1RHn;P7MaMgn7T8V0N71gN8NDShQlM7QkQ92@
S81hN7J0SXn<O7AcL7n8S8aoM7AhOhR?T8AiLgB0QXR?QWUfMgb7Shb8O7AfOXV<
THUlM6mhQ92@S8MhLGR4T9>@R7adM7j8SXR0NG1/N8J9RHAhLfmgQ92?Q7adK7J4
SY2;OgA`L7R8S8QiLfi^Mh2;R7mfL6adP8R9P7QcL7QoR8j6O7IdN829S8QnN7Af
PhN<RgifKg1lQ8b>P7UdL7b4RHb3O71`NH29S8R0M7=gPh^<RH1gLgV3T9N@QW]g
N8>>Ti28N71kP8NAS8AnLgQlQ8n;S7a`LGN4R8^8NG1_M7b9ShN0MW5dO8b@S8Ak
M7AkR8j>Qg]dM7R1Rh^3N75`MWb9S8MlM7AdPHV<SX5hMWN0S9><Q7adMW^8S8^4
NgIdNhB<S8AkMW=hQ8nARH5hN824TIR;QWUaNh6@Thn6M7AgOXj<RhAgL6miQ8J8
Og=`KWN3QhV4NGM`NHN<ShN0N7AiOh^?R7miM7N1S92<Q7UgN7^4S8b4NGQdN8N<
SXQlNGAhQ8VAS85kM7N0Qh^9OWAcL7V1R8MnMg1`NH28R7idK6agP8R<Q7QaL7An
Q8V9OgMaN7n7SXR1O7IkPHV?S8AkMWQlQXb8Q7adN7n6S8j4O7QdNhJ>S8MoMg5k
PHb>QgmdM75lR8^;OWQaL7V1RH^4OgIfNH6>SXAoN7MlQ8j?Qg]aMWR0SY2<Q7Qd
N8><T926NgIhOXR<S8QhM7AiQ8N<PGMcL7N1QhR4NFi/M7n4RHMnNGIhQXnCS8An
N7^0Si>@QW]gM7b7S8n4NGMdMhB?S8IhLgAfQ8V<QgadL7=nQXb8O7MdLgV8S8R4
NgMhOX^<SXAhMWQlQhV<Q7QaL7MnQhV6OWAaMh24S8R0N7AlPhbDT8anN821Si2<
RGihN7j7S8b6N71_M826RHMhKf]dOX>8PgafKgAlQ8R7PGMaMWV3R8N4N75`N8>8
S8MlLg1gPhb<RH1hMWR3SXn<PGQfN828T8UlLG1cMh68RHAcKW5gP8R8Q7adL7R1
R8b;O7AcM86>S8V4N7=gP8^;R85hM75lR8b>Q7adMWj;U9B<P7QhP8jDUY24NGAg
Qi2?ShIlLgJ0R927OWQ^L7R1S8QoNG=dN8>@SXInN7R0R8n@RHAhN8>8TiB>RH5l
PHNCUi69NGAhO8B;R81fK75gP8R8Q7I_M7B0RhV8O71cNH6?S8^4N7UhQ92>S7ma
M71iQXR8Ng5`K7V1QXV0Mg1^N828Rh5lLfmhP8R?R85hM7b0RHn<Q7MdMh28S8V3
NgAdO8J?S8AnM7IkPhb>R7]dLGAnQhj7OgM`NGn9THb1NGIhP8R@Rh1hLgMlRHj@
RGQfMgb7Shn8O71cO824RhUlM7AgQ8R6QWa`KW1lQhB3O75/LGj6RHb1NGQdO8R?
ShQoMgIlQhj@RH5gLg^4R8n>PGQdMgb8RhJ1N6m`MhB8Q7mfL71gQ8R8P7AdLgV4
S968NGAaNH27ShMlM6adNh69R81hLGInQ8b<QgidNgj7T92;P7QhOXN<S8QnM71h
P8J8Q7i`KW1kPhJ4O7A`L7b6Rh^4O75aOX>>ShJ0MWMlQ9BARh1hN7^7T9B@Q7Mf
P8B?V927N7AlP8RCShIgL7MlR8b<RGUaMgb8T929P7I`MX69S8UlN7MdPhb<S8Ak
N7b7T9JCQ7]gMhB>Si66N7AdOXB>ShMnM7N0QXb>R7mdL7N0S8R6Og1_M7j6SXb0
O7AfNhB<S85hL71iPHR9OgA/KgIoR8R4O75/M7j4R8AlMW1aNhR<QgmhL75lQY2<
R8AhNgn<UY2<PGQhNHBAT8V0Lg1hP8b?Rh1iMgN0S9>@PgAcM7b8SXb3MVmcO8R<
T8QhM7=kR8b@QgadLgR4S8n9Og=^M7n6RhQnM6m`O8B9R85fK6mlQ8N8OgI`JGR4
RH^0N75/N86<THN0N71hP8b@R7mfL7AlQXn4OWM/L7N1RHR1N71cM829R8QlM7=i
QhjDRh5lM7^4SYN<Q7adOXB>Ui68O7MhPHb@ThR0MWB1R92CRH1dLgb4SY28P7=/
M828S8R0LfidO8B;R7mhKgAlQ8b;PgI^KgR0R8V3M6a[M828S8MlKfQcNhB7PGac
JG1lQX^7PGUcMX2<T9>8OWUgP8bCSXMnL7AlQ92?QgmfL7R7Shn<Pg]hNhRCTI28
O7QiQXbCSX5nLG5lPHb8OgQ^LgV0SXb6O75dNH2;R8AlL6idOhR8Q7aaKg5iR8n<
PgM`M7n<Ti><P7MlPi2DU8alM7=kQi2@SWmfLgN6T9N?PG]fO8J@V923N7=hOhR@
RhAhL7MkQ8b8QW]aLGV6Si2;P7McMgn<T8R3MWAhP8b?S8AkM7B0Rhj>PGQcL7V6
T920N75`Mh2;S85gKfagO8B>QW]`L7R0Ri2<P7M`M82>THb3N6a`O86<S7idJfag
P8^8PGI/KW=lR8J4NFi`M868S8UiM6icPHb@RH5gKgAiQhj8PGM`L7R7T8j6NG5a
MX6<S8InLFmfPhV8RgmfLgAoRHb7P7Q`M7j6Shb0N75fO8N?S8AhLG=kQ8^<R7ad
LGb7T9N;P7A`M7b<S8N0LFa_N8J<R7agL6mkQ92<PgQ`M7N4T8n9NG5dMXB;T91l
MWAgPH^AT8AlN7^8T9JFRh1hN82<U928P7QfP8bDU8n4NGQoS9B@S8AiN7j;U9B@
PgQhNHRFU9>8NGQiPhj@SX5hL6ikR8b9PGQ`KgB1RhIoMW1`M7b8RhAiM75fO8V@
SX1gMWQlS9>AQ7QaLgV1RHR0LF]/M7n4S8=hL6mfPH^9R7U`JG1nQ8^8Og5/L7R1
RhUnMVaaN86<RhMkLgMoQXj@RHAgMX2<T92>QWQgO8BCU8j8O7MlQi2DShQlN7^4
SiB@R7iiN8B@V9N<PG]fOhJ<ShAiLficNhR;P7ihM7R0SY2;PGQdMWn9Thb0Mg5`
MX27RgidLFadO8N7O7A^KgAnQXR4Ng1aMgb9ShV1N75fOhN>R81gL6mfQ8V8P7A_
KgAoRh^4N6m_M7n9ShQlL6icNhB8Q7i`Kg5lRHb<QWQaLgV8SXV0Mg1`O8B>T8Al
MgMnR9BDRh1dN826TiB>PgMhO8N<Rh^3M7=dO8R9Rh1hL6iiQ8b@QgigM7V3Ri27
OWQdN7j9ShQoLfmdNhRAS85hMWQlRI>?R7igN7b8Shb8O7IhNhB>ShQoN7AhPHN9
QW]dLgN0R8R9P7MiNH2;T924O7UiQ8V@U8MoN7=lRHb>RGU_KWR3S924O75^Lh29
RH^0M71aO8J<Q7UdK6ilR8b@QWUfMg^8THb8O7AfN8N<ShAhMfadP8R8PgaaK71g
P8B0NGA`KgR7RHR0MVm`N8>;RGmiL71lQ92@R7mcMWR1U9>>QWahNhB>U926NgQg
O8V<SXAgLg=kPh^<Q7idM7n6Si>;PGafNhbAU969P7n0Q92DShV1Ngj6S92>Q7Qa
LG^0PhV1M71`M82;Qh=lKW1dPHb8R7agM7B4Rhb>P7QdMX69T8n3NgIhP8^@ShQn
N7V0R8b>R7]dLgN3QhR4N7=_M826RHAkM6idOhB7QWidLgAkQhR8QgUfM7b7RHb1
O7QaN868R8AlM7=dO8N9QgagM7N0QXV>Q7UhN7b7SXb6OWAdOXJ<S8IiMWIhQ8b?
R7idL7V0Ri28P7AfO82>Shb4M7IfOXN8Rh=dLgAfQi6?Q7]fM7b7R928MW=dN827
RH=oL6ihPhR;QgUdKg61RH^9QgUdN8><T928P7UgP8^@T8R0N7IlQ8b@Qh1hL7In
P8N3N7=`M7R4S8B3N75fN8><R8=kN7QoRhj@RgahN7V4Ri24OgMaN7j;T8V0MgQk
PHRCSXAhLgR0Q8b>Q7QcM7b4RhV1Ng5fO829RH1iMW1hQ8^<Q7adM7UoQXb6NgAa
M7b8ShR3NG5gO8R>S8QlN7AhQ8b<R7mfLgJ0Rh^8OgAfMh2;S8b4NGIfO8N<S8Ik
M7AlPhV@QWihL7R4R8b8PgahP8B?UXb6OWQlQhbCTH=lMgQoR9>?QWaaM7^3S929
OWQgNhB<Thj1NGQlQhb@S7mhLgB1R8R7OgQ`L7b1RHAlMf]/M7j3P81dKg=dPh^4
P7QdKW20Q8R0MWA`MX28T8QoMWAhO8N<R8AfLgMiQ8R8PGAdM7j4RI26O7=dP8B@
T8R0MWB0QY2CS8IhLGV0RI2>R7adN7j8S8b8O7AgNHN>ShR0N7AlQhn@S8=lN7b9
Si2;P7M`M7n9S8J0N71cO868QWihM7AiQ8V8PGQaM7N1QhR3N7=_M7b4RHAkLG5c
OX^?S8AkM7R0R8j<PGQaM7b4SXb4NG5cN829S8AiKg1hO8J;Pg]aKgAlQhb8P75_
LGR7RHV0Lfi^MhB;RHAlLG1kQhj@Qh1kMgj<TiB@Q7mhO8RAU8^3N7=fOhV?S7ig
L71kQX^<QWmhMh24S8n3NGAfOXB<S8IlMW5hQ8V>ShAhM7J1R8j9P7Q^L7n7Shj4
O7AdP8N@S8B0M7=lPHb<Q7mfMWV3TiB?R7ahO86<SXb3MWMhO8^>S85kMWAnQ8R<
P7QcM7R1T8j8OgAdO8B>T8R0N7UoQY2@RH1dLgQnRHb9PGMdMWR8R8N3MgAcMX27
RGmgL6idO8J6P7M/Jg5kPhV1Mg1YKW^6R8AnLfaaN86<RH5gKg5kPhj@QgacM7b6
T929P7MhOhRAU926NGMnR8nAShIhM7B0SY2@Rh5hNh2<U9>;OgUkOh^?SXb0MWMl
Q8b>Rh1fLG5lQ8J3O75`KWR4R8MoMg1/N8B9RhAgMWAhQ8b<Q7QaLGQoRHb8O7=f
N8B<T921N75dP8^@SXAiM7QnQ92<Pg]dM7b4S8R4M71dMWn8RH5gL6agP8J;Q7Q`
LGAoQhb8OWQdNH>8U8n4O7AhP8J@S8AlLG1gP8b8Q7acN7^6TI2<Q7ahP8R>TI24
O7UiQ8b<S8IgL7AnQXV8Q7acKgj3R8j7PgUhP8RDT8^6NGMlQ8jCRhAlM7R0Ri6<
Pg]dN7j8T8^4N7=dNH28Qh5hKVidOXJ8Q7QdKVmoQhB3O7I/L7V4S8MlN7=dN8B9
QWmfLG1fP8V7P7QdM7V0R8n8O7MiN8J<S8QlMW1dPhV9R85hLGB0Qhj;Q7idLg^8
RhR4NgAdNHB>SXJ0N7MnR8j<R85hM7QoQhR8OWMfLGb4QhR0Mg=gO8>;RH5iM7Qo
QXb<R7afN7b4RH^<PGQhOhN9THb1NgAiPhV?RhAlM7MnR92;PgUdMW^4SXb4O7Mf
NH><ShR4O7IkPH^<QX5hN7QnRHb8PGUiNh68T8j7OWQlOhR>RhQlLgAhP8R8PgA`
MWR0Qhb8P7QfN826RHR0M7=dN824PGaaL7=lP8N6OWQcM7V0R8R3NGAfO8B8RHN0
M7MlQ8V9R81hM7^4RHR7Og]dMX68T8^8Q7UlPHb@S8V0N7QnR8j?RgahLgAoQXb7
P7QcN7b4S8MoNGIfNhB;S8AlMgUoQ8b>QWmaMW^3S8V;OgAgO8B<S8QoN7AhPHR;
RH5kMgN0R8V9PgagM7V3S8b3OW]hNhJ>S8QoO7alPhR<R7ahMgQlQXV8O7QgNgj4
S8^3NgQhP8B8RH5hLgIkOh>4O71/K7AiPH5oO71/Lg^0P85oLg=aNHJ4Q7agMWB0
QhV<Qh1lNh28S8n7O7UgO8N<SXJ0NgMlPHR<R81lN7n4RI27P7]hO7b1R8R3NGMk
OX>8QhIiM7]lP8B3PgUgN7b0P8N7OW]iNh>8R8R4OWQiP869R81lMgQkP8R8Pg]h
Nh24S8R7PgQiO8>?RhV6OWaiPhV7R7ihNgAlQ8R6O7]fN7b1RHJ4O7QoO8>7Q8In
NGinQ8R;S81kO7b4QhR8OgQkN8>4R8V1NgAhOX>8R85iN7MnQXN8PgahN7j1QXJ6
OgQgNGn1QXAlMWAhPhJ;RH20N7R0Q8^8Q81hO824RHV7OgMhP867R8B0N7UlPHR9
QhAnNgb0QXJ4P7UdM7^1Q8B0NgQkO8B<Q8B0O7inQ8R9QWmhN7]nQ8N3O7UhN7b1
QX=nN7QhNgn4Qh1lNGMlP8>7PgigMWaoPhN6Q7afOh66RhR8PganQ8V9S8R0O7n0
Qh^>Qh5nN8>3Q8N1PgMhO7b4PgmlM7=fO863P8=kN7aoQXJ1P7]fN7j1QXB0O7Md
N7n4Q8>1N7QlP8V6PhAnO7b0QXN6PgilO7^4R8=oO7]iPHB8SXB0O7b3Q8b9Q81h
O7b4S8J6P7akNH28RHR0O7alPHB9RHB0O7j4Q8N8Q81hO7j3Q8B3N7QgN860PH5l
N7AiPH>8QX20N7R3Q8R;Q7ihO7b1R8J7P7UgNGn0PgmlMWAhP8>1Q7mgMWQoQ8R6
P7ilNH26R8R3Og]iP864QWaiMWMlO861O7aiN7b4R8b6Ph1lPhR>Thj8P7ioPhR>
S8J0NGUnPHB3PgUcLGAkOX>1N7QdNGn0R8B0O7QnP8>8QX5kMW^0Q8R3P7UgN7^4
Q8J3NgAdN7j3QX5lN7AhOhB;R8J4P7b6S8^<QgmhNgn0QhR1O7QgO821Q85lNGIk
P8>6Q81iM7alP8R4P7UhNgj7QhV1NGQhP8B7R81hM7MiP8R8Ph1kMgj4Q8R8P7al
O8B8S8^0O7]lOhB6Q85lLgQnQXV9S85nO7b8RHR8P7aiN828R8=lN7AiO866PGih
M7MoQhV7Q7igNgj6S8B4NgMhN828PgagMgQiPHB6Q7agN7UoQhR0O7QdMWb4QhAn
N7MdO8B8R85nO7QlP8J8P7]hN7b4RHV7OWUkO86;SXV1O7UlPhR?Rh1nNG^3R92@
QX1hMh26S8b8PGb0PHR>S8J0O7UnPHR9QWmdM7MkQ8N0Ng1/LGR0Q8=oM71fN827
Q8=lMgQlQ8V9Q7iiMgb4R8V6Pg]kOX>8RHR1O7MkP8R>RHAlMWR0Q8b>R81hMgV4
RhR8PGUgO8B<QhN1NGQiP8^;QgmiMgIoQ8B4O7QhNH24RHb4O7UlP8>;ShIoNgQo
Q8R9Q7adLgb0Q8J4OgQdN823QhJ0NGQkP8N8R8AlNgUnR8R8Q7MdM7^0PhR0NgMc
Nh>7RhR1OWQiPhR8R81kMgQnQhb8P7afM7V3R8B0N7AdN7n6Q81hM7IhP8R9PGah
MgUoQ8R6O7UhNGj3RhV1N7QnPHN;S81lN7R0Qhb9R7ifN7b0R8b3OgQfN7n4QXMo
N7UiP8J6R8B0O7^7S92CRhMoOhJ?Thb;QWahOX^>S8R0O7QhP8R8Q7agMgR0R8j<
P7UfN868S8V1O7=dNhJ7QWmfLG1fOhB4OgQ`KWAlQ8IlN7AdN7j7RhMnNgQhOXB;
R85iN7QiPh^9Q7agNgn4SXb8OWMdMh>7QXAlMg=fP8B6PGahM7IlQ8R3O7I`L7R0
R8J0N75gNhB<S8QlN7MlQXR<R81iMWb0QhV7P7MhNh28R8N3O7QiPhR7R8=lMWIl
Q8R6P7QdLgN4QhN4OW]fO8B8SX^4OgQlP8R8Qh1iN7^3RHV9R81iNh2;S8^4Og]h
OXJ8R8B0O7QlQ8V@Qh1nNgj6T92<PgahN824R8MlO7QhOX>8RH1hMWInPHN8OWQ`
LgQnQXR3O7AfN7n7S8V0NGAfOX>6QWmgLgMiP8N4OWIaLgMoQ8V0MgAaM7n4Qh=i
M71fP8N;Q81hMWR0R8b9PgikNh6<Shj8Q7ioPHJ@Sh>0NGQlQ8R9QX1hN7b0RHV8
Q7UiNh><S8b4NgaiP8V7R81gNGMoQ8V<P7ahNH20R8^7NgAkP864R8InMgInPhJ8
Q7igLgQoQ8R4OgQdN7j4R8^8PgalQ8^CTh^4OWaoPhb<QX5lNGb4Rhj8P7ahN7n7
S8B1Ng5gOXJ<Q7mhLgMiQ8b7P7]dLGB0RHR4O7IfMgn7R8=nMWAhO8B6R81gM7=n
Q8N6OWI`LgN0R8AlM7=cMX26Qh5hM7AdO8B8QgUfM7R0Q8n>P7QhO8B;SXj;PGV0
QXb@Shb4O7b3R8b9Qh5lO7j1Q8R6NGMhNGn3PH5kLG5fOWj1QWagLg=kP8N4PGif
Mh24R8V4PGUhO868QXB0N7MhP8R<R820MgV3R8j;Q7miMgb4S8N3O7AfO8>8R81i
MgAlQ8V;QgihN7^4S8b<PGaiNhB7RhR0OgUkP8N8Qh1iMgQoPhR8PgagNH64QXb4
Og]hOhB8R8B0MgIkOXJ8PGmiN7R1Rh^8P7akN7b3R8b4O7QhO7^7Qh1oLgMhO8B8
R81iNgj3R8R8PgQgNhB3QhV0OWQlPhB<S8B0N7b1Q8b>RhAhMgj1R8R8Q7QgN7b6
QhB0MgMgOXR4RHAiN7QoPhJ6PGacM826R8V6O7McN8>6QXAnMW5hOXB4P7iiM7Al
PHB4PGagM7b3QhAoO7MgO8J<R8AlN7QkQ8b>Qh1nN7b3RI68Ph1gNgj4S8J1N7Ah
NH28Q8AnLgAkP8>0P7QdN7V0R8N4OgakO8B<Shb4PGmlQhV>S8J0O7b4S96@R8=n
O824R8R1OWahNh28RhInN7alPH^8R81hN7QnQ8b6O7Q`M7b4QhR3MW5`M7^1Q7id
LFadOX>;Q7QaKgAiP8R3O7=/Lgn1Q8V0N7AcOh>8R8>0MgAnQ8V8Q85hN7b1RHR7
PGahOXB7RhB0N7IhOXR9QX5lMgQnQXb8Q81lO82<THb9Q7moP8R<RhAnN7]oPhR9
QgigMgb0QXR4OgQfN8>7QhJ0N7AfOhN<R85iM7AlPHR8PgahMWN0PhN7NgQgN821
QXJ1Ng=iP8>8QWmiM7InS92<R81kO8>8Shn;Q7moPhR?T8N1O7UoQ8b<Qh1iMW^0
QhV4O7=cLgR3R8UnN7QdN829R8IoN7anQ8n>RH=kN7b4Rhb@PgahMh2<T8b4O7Mh
P8N>S81hMgMlQ8R9Q7UdM7R0Qh^1NgM`MWb3Qh=lM7AiO8B9Qh=lOW^0R8N8PgUk
NH27S8^6OgQhOhB9SXQoMW5dO8B6QX1fLgJ0QXJ8PGUfMgb3QhIoN71dO868R8Al
N7b0RHb<Rh5hO824RHb8OgAaMX69R8R0Mg1aO826PgafKW1lQ8^6PgmgM7R7S8N7
OgAdMX><S8QlN7AcPH^;QgagM7=oRHj<PGmhMhB9T926P7ahP8RAShAoN7AhP8R@
R7ifLGAkQhb8P7MdMW^4SX^3NgAhO8J9RHAhM7MnQ8R<QWadM7UnR8N4OW1^Lgn4
QXIoNG1dOh66Q81kLGQlQX^3PGQcM7V6RhR7N71cN868RHMlMgAhP8B8R7mkN7N4
Qhb7OgmdO8B4S8R3OWIgOhN<S8N0NGR0Qi2@RHAiNgb7SXb<PgUhNh>9RhR0MgAi
P8R>Rh=hM75iQ8V9P7QaL7R0QhR4NGAdOhN>T8R3N7AkQ8j;QhAkN7V3T92;Pg]g
NH28S8^3NgMhO8J<S8AlM7AkQ8V8QWUdMgR1RHb7OWQdM7n6QhMlLg=aN8B8Pgmf
L71gP8J7P7QfLGR0QXR0NgIhOhB<S8MoMWAnPhR<R81hMgUnQXR8PgIcNGn8SXb8
P7UlP8R>S8QnN7b0RHj;R7adMg^8S8b8NgAcL7b4QhIkM75`Nh26RH=lO7b0RI2?
R81kOh28T8n<P7]lO868R8UlMWAdO823Q7icL7AlQ8R9P7UaM7n4R8N4N7=hN828
R8MkMW=hQ8R9QgifL7R1QhR4O7I`M7b6RhN3O7AdOXJ?S8B0NGanQ92@R81kN7b6
S92<P7UiNH29S8MoM71hP8B<QgmdL7UlRHn9Q7M`MWV4S8V7NGAfN829Qh=lL71h
P8R8R7mhN7b3Rhb8Q7]dN8>9SXj1NgIgP8R?R8=lM7MlPhj<QWmfMgb4S8^8P7Qd
N869RhN1N75cO8N;R81gMWAlQhR;Q7QhM7V3Rhb4P7MdO868RhR0N7IiP8V;QX1i
N7R0RHj<PGUgNgb6SX^1NgAgOhN<SXMkM7IkQ8^;PG]gM7R3R8j<OWQhNh68SXUo
NG=hOX>;QX=dL7MhPHR8Q7]dM7b6QXR7O7=fNHB<RHMnLg5hP8R8QgmhM7B0R8V8
P7QdM7b<S8V4NgA`NHB9SXMnN7=hPHR9Q7ihL7QnR8j4P7UdMWj8RHQoNGAhPHN@
S8>0N7MlR8j<RgidM7^0R8R3NGA`M826QhQnN7MfP8V9R81hMWQnQXR<Q7QhN828
R8^3NGIfOhR<S8R3Ng]oQ8j>RhAlOWV3Rh^9Q7ihMWb4QhR1N7UhNhJ8S8AlNGMo
P8V;P7ifMWQnR8R4OWMdN824RHInNGAdO7j6Q7ahLgMnP8R6PGadMgn4RH^4OgQf
O8>9RHB0N7AhQ8b>S8AoNGaoQhb7P7UdMWb3RhR0N75dMWb4Q81hLgAhP8R9Qgmh
N7^4R8^9Og]iN828RhJ0O7QiP8B<R85oNgb0Q8b;Q7aiO7n4R8^4NgQgO7n6RH5n
MWAhO864P85lN7]oQhR8QW]iNh28S8j6P7iiPHR?TH^6O7aoPH^@R81nN7j1QXR7
PGMdN7V1QXAlMW1dN826Q7mfLG=hP8>4P7UhN7b4QhV4PGakO8>7RHIoNGIhO8>9
Q81lM7QlQ928Q7mlNgb8S8b<P820PHN<T8^1OW]nPh^<R81iN7R1QhJ;P7ahN7n1
S8N0OgQgO826Q81iM7QkP8N4PgUdM7QlQ8R4PGMkNgb3QhR0O7alP8B7R8AlNGV0
PHB9P7QhN7anQ8B1OW5hO824Q8AkLgAgOh24Q7miLgR0Q8N6P7ahMWb4QXJ0OWUf
OXB7R8=oNgQlPHb<Q8=lO824Rhj<PGalO8B9RHV0O7UhP8J9R81kMgMlPhR7Q7ag
N7^4RhJ4O7QdN821Q8AoN7MhO8B4PH1kMWQkP8B6P7IdLGN0PhN0NGMfOWn6R8>0
N7=hPHB6R8IhN7]kQXR1O7QhMg^4QhAoMgIgN7b4QX=nN7alQ8^8R7ikOWR4QhB9
P7]hN820QhR0P7ilPHB9RhAoOWn1Q8R8Ph5lN866R8^8Q820Ph68RH^6O7aoPhJ7
RH=lO7b3R8V8Q8AlNH24R8V4OW]hN826R8B0NgUoPHR<R8AoNG^0R8^7P7aiNH24
QhIoO7UlP8N@RhB0NgV0Q8V<P7UfMWQoR8R0P7AaN7^0Q8AlMgIdNh23Q81iMgMl
Q8B4Q7ahMgR0Q8B3O7IdN7n4Q81iNGIaOhB6Q7ikM7QlOhb7P7]gNh26T8b9OWUl
O8J<S8R0O7UnPHR<R8=kO7n0R8R8Q7ahOh>8S8^4O7UhOhB4P7ahL71fNhB4PH5h
Nh21Rhb8Q7alOX69RHR6NgUlO8B9Qh1iN7QlPh64P7IgMWV0QhR6OWUkNh>6QX1h
M75fO8>4Og]dMg]lQ8R7P7QkO7n4QhB4N71fN868Q8J0O7UlR8R7Qh1lNGb4RhV6
PgaiO866S8b1O7anP8R<ShQoO7QoQXR<R85nN7j6R8b8Q7agOX27S8R4P7aoPhJ;
QX1oMg^0PhR8Q7afNg^0R8V6OgQiO826RHQnN7IlPHJ8QhAhMWR0RHV;Q7]cMWn4
R8J0Ng=`N826Q81hM71dOXB4Og]dLGUnQhR6OWQhNh2<R8R4OWanQ8N<R81oN7Ul
QXV7QW]hNGb4QhR3NGQhO8>9RHAiM7AgP8R8Q7]hN7V0QXb7Og]hNh26SXb8PGUl
OXB8QhN0N7QkPHR6Q85iN7^0Q8N4O7QhMWj8QhR1O7QhOXB8R8=kMWAkQhR9Qgii
NGn7Rh^8PG]hOXJ8RhB0OgMhQ8J8Q81iM7QlQ8R6O7QdLGR1Ph60N75dMgb4Pg]h
LFmfNhB6PgadMWUnRi2>Q7alNh>8S926P7alP8R>SXQoO7R1QX^@R85nN868T96<
Q7UhOh2<ShV6O7]lPHV8RH5iNGUoQhb8PgQ`MW^0Q8J0N7A`N820QX1iLfmdN7n1
OWafM7AlPhB6P7UfN7^0Q820NG=gN821PH1hM7=hP8B6P7agM7IoR8B4PGQfMWn4
Ph=nM75`MX26Q7mkNGQlQ8R;PginN7b4RH^6OW]hO8B<ShQnO7UlQ8b@S8^1P866
S92@RHJ3PhN;SXb8PGioP8B9R8=nMWAhO8B4PGacLgIkQ8J4P7QhMh2;Rh^1O7Ui
Nh6;R7ahMWMlPHR9Q7afO7j1Rh^9PgQlPHJ<ShR4OWQlPHb<R85iNgQnR8^<Q7]i
Ngb0Rhj7N7AgO821QhAgL7AhNh24Q7ifLgN1R8N7O7AdMWb6RHIlNgQfQ8J8ShN4
O7aoQXj<S8IoO7j7R8^9Q7ahNhB<Rh^4O7QgPHV;R7mhLg5iPhB1OWUaMWaoRH=n
O7AdN8B6QXInMgQiP8R9QgmkNgR0Rhb8P7]hO7b4RhN3NGMiOhJ8R8=hMgQkOhB8
PgagMWb1PhJ4P7Q`Ngb0R8B0N7AhO8>4P81hM7IhP8J4P7QcM7V0QXB6Og]kNh68
R8=lMgIlP8R8PGadM7QoRHj;PgUlP868Rhj6O7ioQ8V@Thj9Q869Rhj?S8=iO7n1
Q864P7]gO820Ph=kMWAdNh20P81iLgAhOX>0P7iiN7b7R8b;Q8>0OhJ<SXV4Ogao
PhB8R85iN7^0Q8B3P7MaM7V0Q85nN7A`M821PH1hN7AgOh>7P7ahMgQkQ8V3PGah
O7b4QhN7O7]lPHN8SXAoO7R1QXb@RhMoOhB6S8n9Q7]lP8N;RHR0O7QiP8B7PGmi
MW^1R8V8Qh1iO864R8J1O7QgN7n3PH1iLg5dNh63Q7ahMWMlP8B6OgQiN7b4QXN1
NGMhNgn4Ph1kN7AhOX67PGilO7b0R8R4P7mlOXB8S8V4P7ioPHN>RhB0NG]oP8R7
Q81lNgn6R8V8OWalO828R81oMWIiO8B6QX1hN7]nQXN4QWalO7n8Q8R0OWahO863
PGmiN7MhOXB4OWMgLgAnP8J4O7agN824R8R4OgQnP8B9QX=lN7IkPHB7OgMdLGUn
PhR3O7QdNH24QhJ3O7MiOhB8Q81lO820R8V4PgahO7j3Q8J4O7anP8V<S8V1O7j0
Q8R<QhB0Ogn3S8^9Qh20P826QhJ0O7alO7n4Q81kM7IhNgn1P7QdM7AlP8B4Q7ig
OX21R8R4OganOXN8QhN0NGj0P8B8Q81lO7n4Q8B8P7]nO867R8N0O7]kP8B6Qh>0
NGR0P8B4P81iNGj6Qh>4PGUiO868Q8B0O7]lQ8N7QgioO7QoPhN4P7igN7^4QhN0
O7UkO828QhAoNGanPhR9R8>0O824Q8b9Ph1nOX26R8J3OWUoP8>8Qh=lN7]lPh>1
P7alO7aoPh5lNg]iO7ioPhAlMgUnPHJ7R8AoN7V0P8B1Q7ahNGV3QXB4OWUkO8>7
QXB0N7UnP8R9Qh5nN7R3RHj<R820PHB<RhV8OgaoPhN8R85lNGQlP8B3P7UdMgQn
Q8J0NgMcM7]lQ8AlM75dMgj0P81cL7AgO820OWQcLGQoP820NGQgM864Q8N3NgQl
OX68Qh=nN7b3Q8V8R7mlOh29QhJ9P7ahP8N4Qh>3P7QoR8R6Ph5nN7b4R8V4Ph=l
O8>8S8R4PGmlNh64PH1hMgIdNgn1O7AdLGAiOhB1O7UhNgn1Q8B0NGQlPhB7QhAo
N7b1QhV8Q7miNH27R8V8Q7ilO8B7R8AoO7R0QhV<R8InNGb1Q8N6P7mhN7n1R8R6
P7akOXJ;SXR3OgV0PHR9QX=lNGb3R8B7PGahO8>8Rhb9PginOhJ8R8R1NgUnPHN8
Qh=lNg^1QhN3OgUfN7b3Q85lMgQfO8B3Q7afMgMlQ8B6P7UdM7b0Q8>0N7AaN821
Q81hN7QhOXB7Q7ikNgQnQhR8P7ihMh21RHV0OWMhOX28QX5kMWMhOh>3OgUcL7Qk
P8B0NgAdNH67R8^4P7b0R8^<S8R3O7aoP8N3OWQgMgMnPHB0O7UhOh>4R8AoNgQn
Q8R8PH=nN827RHb<R8B0P8^@Th^8QWalOhB8RH=lOW]iP8R8Q81hNGb0PHB4NgQh
M7b0PHAnNgQgO828QX20NgMlPhB8Q7akNGb0R8N3O7QlOh>8RHR1O7]oQ8N8R8=l
NGV0Q8>8PGahM7anPHAlN7=`MgUoP7mlM7AiOhB4Q8AkN7QlQhR8PgiiMWn0QXQl
NGQfN8B8Q81iN7IhP8B8PgmlNH21QX^4PgalO828R8B0NGUkOX>6Qh1lN7R4Qh^>
R85nP8B<U92<Q7mlNhB8RHMlO7QlQ8B9QgmlN7V0Q8N8P7UhN7j0R8InNgIdO86;
RhN4P823PHR<QgmnO7^1Q8J4O7QcMWb0Q8B1O7QhO826QWikN7QlOh24OgafMWmo
Q8MoO7MgNgj6Q820N7IlP8J8Q81kO7j1S8b;RH1oOh26Rhj6P7miPHV;ShR4Ogn6
R8b>RHAlOhB6R8b9PgmgN824Q8>0M71dNh1oPH1hM7AlQXB8P7]hL7b0Q8R0OWQd
NH26Q8>0MWAiO8>4PGihN7IlQ8>3OgQcMgb1Q8>0NgQgN7n6Q85iNGQhPHJ8Qgik
N7QoPhV8PgagNh23QXR4OWQkP8J7R8B1O7R0Q8R9Ph1lMgb1QX^4OWQ`N7b0Qh5l
M75gMh23PH5lMg^1PhR<R8=lO867RHR8Q7UkOhB9RhV4OWUkPhV9QXInNG]lQ8N3
O7]hN7n3QhB3P7QkOX69QWmlMgMiP8V7Q7mgN7QkPH>0NgUhNGn8R8AnNGQhNH24
Q7ihNGUkPhB6P7UhO8>6S8j;Q7n1QhjASXn6Oh20Q8R9R81kO7V4S8N<QWmlOXB3
RHR0PGahO8B4Q85iNGalPHJ8Q7mlNh23Q8R8OgUhN824QX^4O7UkP826Qh>4O7^0
QX^8QXInO7b3Q8B4NGQiMgb3QWmoN71iOh>8QWioNgR0Q8J4PGahNgb0QXJ0OW]i
P8B4QX1kN7AhP8>4Pg]iN7R0Q8V6PH5iN7b0QXN1OWihO864Q7j0NgQoO8J7Pgmi
NgUoQ8B1O7QhN7b6Qh>0N7AgP8J6S8=lOW]nR8b;R81lNh20R8^4P7alOhJ6SX^0
PGj0PhJ9Q8=lN820PHR6P7ihNH>1Q8=nO7AhO7b4P7ikLG5dNH24P7mhMWQlPHB0
OWUhNgb0QX>1O7AhO864PGiiM75gOX1lO7QaL7AoQ8N3OWahNH27RhR4P7b0Q8>9
RhN4Ngb4Q8N8Q81iNgj4R8B1P7QhNGb6Q820NgMlP8N8Q81lOgn0RHb8Pgb0Oh6<
R8N3O7aiOhR8RhAlOWQiPHB6PgmnMgUoQ8N0OWQgNgb4Q8AlN7QkOhB9RHAoOh24
S8b<RH1kO8N;RH^6PgagOhB8RHJ1O7alO8J8Ph1lNgn0P8>3O7QgNGQkP81lLgAh
Nh23R81nN7QoPhV;R8AoO826QhV8Q81lOh68RhN6Oh1oOXR8RhJ0P7j1QXB;Q81o
NGj4PhB0PGiiP8B0QX5lOWMhPHB6PH1kLgQlP8B0O7QcLG]nPh1kN7=cM7^0P7ii
MWMiOX64QWahNg^6QXR8PGmgNH21R8R4OgMnP8>8R8J0O7anQh^8SX^4PHB7RHj<
Ph60O868R8B0OW]lOh>7R81nNgQlOXB4P7adN7n0Q8R6OWakO7n4Q820N7AkO85o
NgidLgUhOh20OgAgMWIoOWinN7QhO823QX=lO7UlP8B8QX1nNGmoQX^4PGQkOWn4
QhN0OgQhPH27QXAoMg]oQhR8QX1kM7b4R8J4Q7ifO8>3Q8B1OWQhO8J6Q8>0O7^0
RH^;Q85lO7n7SX^8PgmlNhB8QhAlNGQhNH>8PHAlN7UkPhJ6PGalO826R8V4OX1o
OXB;R8J4P7n0PhR8Ph1oO7j0QXB3OWUhM7b3Q8AoO7UgOX61Q81nNgAiOgmoO7Uh
M7AkP8B4N7MgMgV0R8J0NGIhOhB6R8AoN7UoQ8R9Q820O828QX^8PHAlP8B7RHB3
O7MlOX2;QX21O820R8b8Qh1lOh24RhN4OgMlO828Q8B0N7UnPhJ1PgmfN7MlQ81o
OgMfNGb1Q8B1O7QhO864Q8=lN7UlPHR3P7ahN7^0R8N1O7QdN828R8^4P7mkQ8V9
R81oN7^3Qh^3P7ihO7n4S8B3P7QlO8>8QXIoNG]oQ8R9R8=kO7b1QXR9Q7mkO8>6
R8R1OgUhOh24Q81kN7QkP864P7]hMWQlPH20OgMgMgj3QXAlNgUhOX64Q7mnNGb0
Q8^8R8AlPh68SXV<PginNhJ8R8^4P7alPHB3QX1lNgR0QXB3OWUiN7V0Q8N3P7]h
OXB9S8V1OWalQXR8RHAnN7b0Q8R6OWUdMW]oQ8AnN7AgNgj6RHR1O7b4QXJ8Q81i
MW^0PH20NgAcMgb0Q85nO7IhP8J7R8AlO7b0Q8R;OgUiN7moQ8R0O7AdO824Q8Al
M75dO821Q7afMg]oPHJ7P7]hNh67Q8J4O7MfOXB4R8AlNgMkQ8J6PgmkO821R8^6
P7alOX68S8b4NgaoP8B8RH=lMgR4QXb?R8AoO8B<T8j9QgilP869R8IoMgMiOX64
PgQ`Kg=kOh64P7McMh26QXR4Og]hP8J;RhB0O7R0Q8N7Q81kM7R3QhR3P7acMWb4
QX1lNGIdNH66QWmiN7QnPHV9Q7mhNGj0RHN7Pg]nP8B9R8V1NgmlPHR8R7ahN7V0
PH^<QX=oPHB8S8n;Ph20P8N8R8MlNGV0PH>4PgacMWUlPh1nN7=`LGR0Q8>0Mg5c
Nh>7RhJ0N7MoPhN;Ph5lN7moQh=oPgQhO7b6QX5nM7IhNhB4QWikNG=lPhJ6P7b0
O7j4S8n8QhB0QhR?T8j6Ph>0Q8R8Q7miMgQhP8B1O7A`M7]oPH1nN75dNGb0Ph1h
M7QkOXJ7PGafMganQXR6PgUiOX67RHb6O7]kOhR9S8b4Ogb0R8^9QhAoNH28Q8R6
P7ihNh>7R8AnO7AfOX68Q7aiMWMnQ8N7PGafNGj0Q8B0N7AdN820Q8=oNgQnP8>;
R7moO7^0Q8R6Q85nOhB7R8J1OgalOh64Q85kNGb0QXR6Q81kN7aoP81nN7UhM7j4
PhIlN7]hP8>7R7ahMWIlO866P7UdM7ioQ8J1OgQfN824Q8J1MgMnPHR8Q81iMgQl
QXR4P7ahMWb4Q8B1MgIhM7j1P7ilMg=lP8>7PginO7b4Q8J4OgmlP8J;T8V6QhB6
QXbCS8R6PhB6Rhn<QX1lOh21S8R3PgikNGj4Q85kN7QkOX24Q7mkN7]iP8J6Pgmh
Nh66QXR8Q7j0PhR?S8b9PGn1RHj@RHJ3O7n8R8V8PgmiNH24QhB0NgQiO826PGmk
MgIhP8B4O7QdM7QhP7mkNGAdM7b1P8=kM7MiOh64QX20O7b4Q8R4P7]dNgn0Q820
NgAgNGj0PH1hN7IhOh24P7akMWj0OhB3P7]iO7b6Q8J6OWalP864QX1lMgIkO8B6
P81lNGb3QXJ3O7UhNgn4QhAlO7UlQ866QX60O823PHV7QhAlPhB3QXB7P7]lOXB4
Q8N6OgaoPhR9S8^6Q8>4Rhb<R8B1Oh24QXJ4P7anOh26QhR1NgmlP8B4Q81iNGV0
PhN3O7ahMgj1Q860NgUkOhJ7PH1iMgUlQ8B3P7QhMWQoQ8>1N7MhN7n4QhAlN7Qk
O821Q7mhM7]nP8>3PGagN7b4Q8>1P7akO8B4Ph5nOWalPh>4Q7n0P824RHR7Q7mk
O7j0R8AoO7QhO860Ph5kN7^0Q8R>RHB6P8>8S8V7Qh1lOh21Ph=nNGQhO820Q81i
O7QlQhB8Q85lNHN4Q8V0PG]gO7n7P821N7QhO8R4PGigNgMlQh>0NGIfLgV3P81l
M7MdNHB1Q7miN7AhOgmoO7IiN7N1QXR1Oh1iOh>4RHB0OgaoPhN;R8>4PH64R8b9
Q81kOX64R8V7PGn0Q8J;ShV4PGmnQ8^9R8B0OX20R8b8Q85oO7j4QXR1O7ikO826
R81oOWN0Q8B<R820OX23QXV8QX=hP820R861N71dM7alNG]dK6mdN7aoOWQdMgAk
PH20O7QdNgalPgmlNGAhN7n4P7mkM7MhOh61P7]dMgMkP7inN7AhN7^4QhB0OX1o
Q8^;SXJ0PH21Q8R8PgiiNgn4R8B4NgAhN7n1Q7mdN7QfOX>4PG]fN7n1QXR9P7n0
OhN;SXj9Q81oPhV;R8R3OWanQ8N8Q81nO8>8QhR7Q861Q8R?T96<R8B8Si6FS8^8
Q8J6SY>>S8B3Q8B9S8V7P7mlO821Q81iMgAhNh21P7]dMWAhOgn0O7QfMgb0QXB1
OgQhNh21Q81kN7MhP864PH1iMgQlPHN4P7iiN7b3QhN0NgQiOX24Q7mlMgMlP866
P7UgM7UnP860O7MfO8>3Q860O7AiP8J8Q8AlN7aoQ8^8Q8AnO828S8N8PginO8B9
QXAlN7]iP8N7Q7]fN7QnPHR8OgQcN7UnQ81nMW=dN826QX5nNGQlQ8R8QgmlN7b4
QhR4P7aiNh66Q85lNgUhOhB4PgihMWQkPHN4PGihM7]oQ8J3OgQhO7n6R8^4Ogin
PHV;R8J0Ngn4R8j>RhN0PhR<T8b9Pg]lP8B8QXQoN7]kQhV8RGmlNg^3R8V6Ogak
N7n1QhMlN7QhNh21Q85hMWAdOX64OgUhLGQoPh^3OWUdNgj7S8J4NgMoOXN@QXB0
N7]nQ8R4Q7ahNgV1R8J4O7QhNGn0Q8AlMWAdNh26PGiiLg]oPHR7PGMdMgN0Q861
N7AhN863Q8AhNGMhP8>8Q81lO7n4RHV6P7alO7j6R8AnNGQhOX69Q7ahLgQlP8R4
PG]dMgj0R8b7PGioP8>>RhN4Ng]nOhR9R8=lO7b0R8^8R81nOh29Rh^8P7b0Q8^@
S8V4OgaoQXR8Q85lN7QoQhN1Q7QfO7R4Q860NGQhO8J4Q8AoN7MkP8>3P7agMW]n
Q8B0O7QdN823PgmnNGQiOhB7QX1kMWQoQ8R6P7ahMgV6R8J3OWUgNhJ;S8MoOW]l
Q8V<R8=oO7b3RHV4OWahN7n3QXInN7QhOX27RHB3O7R0PhJ8QWihNGR0QXN4O7]g
NgioRh^1O7inP8J<S8AlMgQoP8J9PGidM7b1QhR3NgA`Nh26Qh1lM7MkP8R;QX1l
N7n7Qhn>Qh1lP8B8SX^7PgQkP8N<R8J0NgUkQX^4Q7mhMgMnQX60OgakN7j4P81o
NGIfN8>0P85kNgQhPhJ8Q81lNGj4Qhb8PGanPHN<T8j6PGmoQXV;RHIkN7aoQ8B6
P7QgM7b4Q8>0N7=dN827Q85nN7QfP8^8R7ihN75iP8B4NGAaLGMlPHIoN7QhO8B8
R8=lNGQoPhB4OWMcLgIkP861MW1`LGQoQ85iM7=hO8B8QhAlNh26R8R<Q7aiNh27
RhN4O7IhOhB7Rhb0N7]lQ8N8R8=lMgR0Q864OgQhMh67QhR4Pg]lQ8R9R8R0Og]o
RHN8QhB0O8>7S929QX20PhB8Rhb6Ngj0Q8N9S8AnO7b4Rh^<R81lO828SXn9Qh5k
PHR8S8R1OgalP8J7P7mfLgAgNgb0N7AcLGIiPH=nNgAfNgj1QWmhN7MhOXB1OWUh
LgB0PHJ3OgafN7n3QXJ1Og]lPHN;QhB0NG^0Rh^8QgmhMh27Rhj6P7ahP8B9RHB1
NGUnP8^7Ph1nNG^4QhJ7P7UhN7b0P7mlMg5dN7n4OgiiN7QhPHR4PgihN7aoQ8J4
O7QhMgb4Q8B0O7MgO8>7QgmkMgR0Q8V9Ph1kNH26R8R4OgakNGb4Ph1lN7MiPH24
Q7ikN7QkP860O7UkNGb0Q8AlO7]kO7n7Q85nN7]kOXB8QX5kOXB7S8j;R7mlPHB8
QhB0Ng]iPhR8RHInN7QoQ8>4P7mhMgn3QhN4PGalP8N8SX^1OgUoPhN<Rh=oNGj4
PhN7PGmfNH24RHJ4P7UhO8B9R824OgaoQ8^9P81iN820RHb1Og]iOh28RhJ7NgUn
OXR>R8AoNh23QhN6Q7QfO7b0Q8J1NGQdN820Ph1lMgAhOXJ8Ph5lN7UoQXR1Ogah
Ng^4S8B0O7AhNhB8QXMoOWUiPHJ6Ph1nN7QoR8R3P7ahMWb3QhN0N7QgNh66Q7ml
M7MhOX>4P7alN7b1Qh^8Ph20OX>8RHN4OWQlP8B7QWmkMgMlP8J1OWigN7UnQ8An
NGAdNH26PH1lMWQhOXB4P7ahN7QlQXB3P7QiO7b1Ph>1Ogb0Q8R8QhR3P8B4R8R9
R85oO7n4Q8>1OWalOXB9R8J0Oh1lP8N8R81oP8>4Qh^<QhB0Q8N8RHb9P7anPHJ3
P8=lMgMlOh64P7]kN7UoP820NgQiNgUnP7miN7IgO823R8MoOX23R8N8QXInO81o
Q8B0O7QdN7b0PH20N7MhNH20OgahN7UkP8>0O7UlN7j4R8B0OW]lO7j4Ph1kN7Qi
Oh60P7ahN7UlO81nNGUhMgb0Q8AlP7mlP8B8R8B0OWmoP8J7Q7ikP7b1QhR9PH61
P8B4R8b8PH20QXR7S8R6Ph28R8b<R8J0PHJ7QhV3PgihPH>7Q823O7]lP8>0PH5l
N7]oPh60Og]hO864Q8B0OWalP8B4QX>0MgMoOh1lO7]gM7AoP7inNGQfN7j0P7ak
NgIiP8>0OWaiM7UlP8AnO7UhN7InOWmoNG]lN7^0QXB4P81oOh>4R8>0P7ioP8J4
P7mkNgn3R8B3O7QlNh66QhAiO7UhP8B8QWb0O7j3QXV8P81lP8B3R8J0OWaoP8B6
R81lP824PhR<QhJ0OhB0RHb7QgalP867Q8B4OWikO8B4Q81lO7]lP8>1PH1kO824
R8J6P7ahNGn4QXB1P7alOh>4Q860O7anP81lOWalOgj0Q8B3PGmkPhJ4R8>0O820
PhR6Q8B0Oh64Q8J6Q7n1P8><QhN8Q8>0Q8R8QX21PGb0Qh>0OW]kNGn0QXB1PGj0
P8J6Q81oPH1nP8B4Q8B1PhB4PHN4P7ilOWalO7akN7AiNgQiN7QhM7UlOh1lQ81k
OWj3PH23OWalNgilOWaiN7IgNgMhNgQhN7IiO7j0PginOX21Q8N4Ph>0Oh61Q8R4
Q7n1Ph>8QhJ3OWanP864Ph1lO7]lP7moP7alNgb0P85nO7ioP821PH21Ogj1Q8J4
PHB3P820QhB3Q821P824PhB0OWmnOh5oP85nOWmnPhB0Ph20Ogb4Q8B3P7inO7b1
P8>1O7mnP7n1PgaiNg]lP7n0P7alO7ioOX1nO7anOh24PGioOgmnPH>0PGilP7n3
Ph1oO7ilOhB0P85oO7aoQhB4Qh61OgaoPHB0P8=nP81nQXR6QXB3P868QXN6P8>0
P8>3Qh>3PGn0P824Ph20O7mnP81nOWmlOgilP81nO7aoO7j0P81oNGmoOWn0PGmk
OX20P8B4PGmnPH21Ph23O7b0P81nOX1nOWQnPGn1P7b0NGV0P860P81iP8>0Qh60
Q7anOgn1PH60Oh1lOX20Ph20Ogj3P824P7moP860Ph60P7n3PH66Ph21P861Q8J3
Ph1oQX21R8B3P861P8>4Q8B1P8B0PhB1QX>0PH>3Ph60P820NgmoOgmlOgalOh23
QX1lPGinO824O7ikNh1lO85nOg]iO7^0N7^0N7]lOWmoOgaoP7b1Qh24P7n0O820
Q8J0P85lP824QXN4Q8>3PH>8QXJ3P81oPH>1PgiiNGb0O7j1P820PhB4R860P7in
P81oPH1oO7anO820O7iiO821P7n0Og]lOh63Ph>0Oh20Q8R4QXB1P868RHR6Q81o
P823Q8B4PH1oP8>0P7ilO7UlP7anOgalO7mlO81lO7alOWaoP7inNgQnOh1oP81l
O7^0P824PH1lO7j1QhB3PGaiNh1nO81oO7alP8N6PhB1PgmnR8B0Pgj0P827QX>3
PHB4PHN4Q8AnOh5lP8>1Q7inO7n3P8B4P7iiNgj0Ph24P7alO7mnOh60NgalOh1n
OWalNgQoPGalO7]lNGj0P7ihO7ahO824Q81lOWinOhN8P81nOWj0Ph23Og]nNgb1
PhAoO7alOX23Ph1lO81nQ8B4Qh1oOh23Q8R0Ph1oPhB3Q8B0Ngj3PhB4QXAnOWb4
PhB6PH1iN821P7j0P7aoPh24Q863Oh23Q8B3Ph=lP823Q820P81nOh>1P81lNGak
P823PGalNgn1PHR6P7anPhB4R8J4OWalOWj1Q8AoNgUlOh20P7iiN821Q8J4P7il
OhB<S8b6R8J4S8R<S8J4P7n0PhN7P7mlP81oQ8B4OginOX1kPhAnNgb0Oh24P81n
O7alP864Q820OX26R8V9Q8>1PH23QXB1P7n1Q8B6Qh=lP820Q8B4P7]kNgb0PHAo
NGUhOh61Q860O7QlOWj0O7QfM7QkO7inO7UgNG]nPH20OgalP8>4Q8B0N7]lPHB3
P7alN7b1P8=nOWUhO7anP7akM7AgNgmnO81lN7]oP821P7]hMgUoO7]nO7aiOh21
PGmoOWaoQ8V9R8B1PH64R8^8Q8>0P8B7R8J0Og]hO7b1PGikNG]kOh21P7mlO7j1
QXJ4Ph1oP8B8S8N7Ph20PhR9R8>1P824PHN1NGagMgUlPh1lN7MlO7b1PgakN7Ql
OX21O7QhNGalP8>3PGmoPh64QXN3P860PHN8QhR4Ph63Q8J8Q81oO7n4Ph64OWQk
Nh24PhB0O7]gP820Q7mlNgUoPHJ3Ph5iO7j0Q8>4OWaiO8J3Q8>0OgMlO7n6O7ak
MgalPhJ0P7aiP824QXR6Ph21P8B7Qh>0OgioPhB4Pgn0Oh21QXN1Ph1oOh61Q8B0
O7UlP8>7QX20O7j1P8R7PhAlP823RHB4P7alO8B4Q8B0OWaoPhB8Ph1kNGanPH=n
O7IcN7]lOX1nN7AdN824Q8B4O7b0P8J4Q8AnO7n4QXJ4PH1oOhB9RHJ4Q7n0Q8R9
Q81oO7alP860P7]iNGn1PHB1P7]fOWn4Q81oN7QkO8B1P81lNgb1QXB4PH1lNh>4
QhN4Ph1nP8B7Q8B0NGalP8B4PgmnNgUoOh20P7afNGb0P81oN7IgO7j0PgihO7ai
Oh>1P85nP8>0Q8N4OWb0Oh24PhAlN7alOh64QX1nN7^1P824P7aiNGb0Q8>3P7Uh
Oh61R8R4Ph20PhB4Ph5oO826QXN7Ph=nOhB7QXB4Ph21QhR8R8J3P820PhB4Q7ml
Ngj1PH60P7ihO821Q8J3OgalOX64QXB3PGn0Q8B7P7ilN81oP8B1P7]kO7b4QXB0
O7QhO7n1P7ahMgQiO8B4P7UhNganOX>0N7QhNGj0Oh5lO7QhPh63Q823NGR6Q8J4
P81lO826RhR4QhN1Q8N<ShJ4QXN8Qh^8Q8B0Q8B9S8N6P7mnNh64PgmlNgMgO863
O7UiN7AgO7miN7QgN7QhP81kN7MkNg^3Ph20NG]lOh63PGihNGakP8>4Og]hO7in
QhR8Q823Q8B8R8V4P81oPHB7Q81lNGb3Q8>4P7QgMgb0P8=lNGAfO821PgmkN7Qh
Oh5nO7]iN7^0Ph>4P7anP8>4RhR4PH21PhR;RHR0Oh20P8B7R8=nOWj0P8B1Ogah
NGj0QX5oOWQhOh24P821OX21Q8R6P81lNgilQ8=nOWUkO7n4Ph5kN7akOhB7P7ak
N7n0Q8R4PgalPh>7R8J4Ng]lP8B4Q8B0O7n0Q8J4PGakNgioOh20Ng]iO8>3QXB4
OWb3P8B8Q8J0OX24QhR8Qh>0Q867R8J7Pgj0Ngj0PHAlNgQhO821P7ahN7akO7j1
PG]iO7^1QhR7P860P8J4QX=lO7]nOh>7P7ahN7alPhB1O7aiNgn0QhB1OgR0PH>7
Q85iMg]lOh1oP7iiNGn4Q820P7akOX21Ph60O7j0P8>6Q7n0Ogb6R8B7P7ilOX24
S8R0P820Q8J8R8AlOgn0Oh>7PGalO7moP8B4OWaiO7b0QX24OWQnOh24Q8B0O7ak
P8N3PgmkNgmnQ8B0Og]lNH23PhAnNGUhO823P7mhMgQnP8>4P7ahN7alPh20OgMi
Ngn4Ph5oNG]iP8J0Q8=lOg^0R8J9PH63OhB6R8V4Q81lP8R8RHR3Ph24QXR>Q8Al
NGmlQ8J3P7UkO7j4Q8R4O7UiOh21PGmkN7MiP860OgakN7aoP8=lN7UhNgaoQ7ml
NgMnP8>7QhIlO7b0R8N9Qh20OXB8S8b4PH1oOh>7QXAnNGUlP8>4Ph1lO824R8R4
P7ilOh67RHR4P7anP8R9PhB0OW]lQhB4PGahNGanPhInO7]hN7V0PGilN7]nOhB6
Q81iO820Q8B8PgaoO7j3QXR4P81oPHB8SXR8Q824Q8J<R8=lOX60Q8J4P7UiO7io
P860OWQiP8B4Q8N0O7alPHN8Qh1lN7QoP820O7IaM7]oP81lN7=dOX68RhJ4OWn4
Qhj8Q8MlOX24S8J3P7]lO868R8=lN7MhNh23PGigMgAfPH21OgQgM7UlOhAlMgQc
OX21QgmnNG^0P8V8Q8B3QXJ8SY><R8B0QhB7R8B1NgQhN820OgmhM7QlPHN6PGai
N7R1Q8>0O7QdNgn3RhB0O7QhNh>4Q81iO7QlQ8N8PG]iNGb0PhB1O7QhO824R8B4
O7anPhV8R8=oNgj4Q8R7PG]kO7n1PHN4OgQhP7moPh1lM7AlNH23Oh1hN7QlPh21
P7UhNGj1Q85oO7IgO7n7QhB0O7]nPHN8Qh5lNh24R8b8PGaoP8J<S8R4OWb0PhR8
Q81iN7QoQ8B3P7QhO7b7QX=oMgMgNh21PGalO7QkPH23P7akMg^1PHB1P7ihNGb4
R8B7OWaoO8N7QhR1O7QlP867PGilLgAlQ8B0PgihOX23R8B0O7QiOXB8Q81lN7Mo
QXV;PgmnNH28S96;QX60Q8R?T8b6P7anQXR<R8AlNG]lQ8J4PgakN7b3Q8AoN7Uh
O864R85iN7=hQ8B1QX1gMgR3R8R7P7mlN7b4R8B1OgilOhN6QhJ0OWmoPHR8Pgil
O7b0Ph=nO7]hOWioP7mlMWQlOX20P7UgN7V0PhB6PGalO868QXJ6P7alP8J3QhAl
NGMkOX64OgiiLgQoPHB1OgQhNgb1Q8AnNGAfOh26QX20N7^3PhR7Q81hO7j3RhN7
PGiiOXN8RhR1OgUkP8N6Ph1hNGaoQXR8PgmhN7j0Q8N1O7UfN827QhB4OWinPH^8
QX=nOWb0QhV7OWmnNh27RhR6P7j0P8B;R8IoN7UnPhJ4Q7ifMWb1PHB6P7agMh23
Q85nO7QkO827P7ahM7QfOXB4Q7UhNgj4QX^8PGaiOh>4R8N3OWQnPh>8Q820Ngmo
QXV0PGahO7b4QX>0O7UiO826R81kN7MlP8B;R8=iNh61QXV8R820Q8N<S8^<Q863
Qhb<RhInNGUiP8N3PGadM7MlPH60N75dM7QoOh1hM7QgO820PgaiN7R0OhB4O7Qh
Nh23R8R4O7IlOh27RHMoM7UnP8V8R8AhNgj4R8N8P7IcN824QXB3OgIiPHJ<QhR3
N7alQ8N4RgmlO7R4Q8J4NgUdN7moPH1iMWA`NGanPG]hN7IlPHJ7PGmkOXN6RHn8
Q820QhR<S8R8P7]oP8R8Qh5lN7b3QXb8QWahP7n6RhN4NgQkO8R8QhQkN7ioQ8J6
Q7afMgV0P821N7IhMWj4Ph1iN7AgPH23PgalN7QoQXR4Ph1kNh24Q8V4Og]kOh27
R8B1O7QlP8N9QhN0Nh21Q8V8QX1lNgj4QX60OWQiO864QX1oO7QhP8J4PgikO7]o
Q8>1P7ilOX28R8J3OgihOhB4QWmlN7R0Q8N6PgilO7j4RHV4PGalO8>8R8N0P7an
QXj>S8N0Ogn3R8b;Ph5kN7n3R8N6PganO8>9R8B3OginPhN6QWahMg=lP8>0NGQf
M7R0R8B1O7IgN7b7Ph1hM7IdNgmlP7]hMgR0P8>0OW]gN7^0PGiiNGUfNH64Q85l
Oh21Q8R8Ph1lN7]nO860O7ahNgaoPgioNG=lOh>6PH5lNGilPhB4PgakNGb3Q8B1
O7QgNH69RhN0OW]lPHJ8Q7akN7]oPH24PgQhO7b1PhB4O7aiP8N4RHAoO7R0PhR;
Ph1oO820QXJ4Q7alP8>9R8R7O7alP8R6RHMnO7V0QXB4PH1kN824R8N4PGilOX64
Qh61OWQlP8N4PH1kNG]nQ8V3OgmkN7j4R8V0O7UhO826QX=iMgAfOh63PGmdMWb0
PHB4OWQgN820Q8N0OWQfO826PH60MgQnP8V;R8J1PH>8Shj<QhJ4PhR>THn<R8B4
QXR>RhN0O7j0Q8R8Q7ioO7n4R8^1OWQgOW^0QX1oNgQhNh>1OgiiNGIiP864O7Mh
MW]oQ8InO7QkP868RH5nNg]oQ8B8QWakNGn0Q8^7OgQgNGn0Ph5lN7=dOX24PH1l
M7IiOh>3P7ahN7R0Q8B3P7]lO7n8R8N1O7alQ8J7R7mhM7QoOhN4PGidNGj0Q8N3
P7]iO8>8QXJ3N7QkP8N7Qh1iO7MnQXJ9Q7agN7anPhB0O7=cMWj1P85nMW=lQ8J7
Q81nNgV3R8J1OgakNgn4S85iP7alOhB<R85oOgmnPhR7PgakO7b0QhN0OgakP868
S8V0P8B0R8b<S8AlN7UoP8N1OWQ`M7MnPgmnMgAcMWn3Q7anO7UlPHN8Q81lNgin
QXJ4PgQkNh27R8V4Ph1nPHB8RhJ3P827R8b<Qh1nO7R0PhB1O7UdMg]oR8=nO7Uh
O8J9RH=lO7anQXb>R821P8N<Ri6?Q81kOXB8R8AoNGAgOX68Q7aiM7QhOXJ3OWAa
M7AlPh5nN7MhNH64Ph=lN7MhOXN6PgagMgMnQ8B4O7QfN7j0R8AnNgIgOhN8RhJ0
O7^0Qhb9Ph5iMgn1Rhb6PGmlOh67R8N0N7QoPHB8Qh5nNgb1RH^8Qh1lOWj6RhR3
P7UhNgn6QX=iN7AcP861PG]iMWV0QXV6OgakNGn4R8QoOWUkP829QX1lM7MkOXJ4
Pg]dN7QlPhR8PG]lOX28R8R4O7]lP8R8S8IoOWb1R8V<Q7alNh26R8^4OWMgO868
R820MgQnQ8j;QhAiO7R0Sh^<PgV0O828RHR4O7QhN823Q81hMWQhOh>4Q7agMgR4
Qh^;PGigOhB8S8^4O7QhP8J8R8AnMW=fP8B8PG]hMganQ8R4OgQhO827R8N3OW]n
Q8V<R85kO7j0R8b<Qh5oO8><Rhj7PGilOhJ8RHAkN7MhP8B8QgihMWUlP8N4OgMd
Mgj0PH=lMW=cM7n0NG]fKg1cN7j0P7QdN7QoPhB6O7IfN7j3Ph5lLG5dNh24Q7]h
N7N0QXR8PGalNh27Ri28O7akNH27R8AlMgQlOX>8Qg]fN7QoQ8J9P7UhO8B4R8V1
OgAhPhB@S8V4Nh20RHb;S8=lO7^1Rhb9PgahN7n9Shj3O7ikP8B8RH1kN7QoQh^8
Q7]fN7b1QXJ3NgAcM7b4QX=lMWAdOhN6Q7mhMgMnR8R7PG]nNh29Si28OgilP8B7
RHAoNgAiPhJ8R7ihMgb1QhR;P7MhN824QhQoO7IhPHB;S8AnOWj1RI2@RH5oO7n3
R8n6OWUfP8>8SXR4O7b0Q8j@SXMoO824R8n;Q7agN7n7R8B4NG1dMgj3QX1hMW5f
P8B6Q7ihMWR3R8j<PgahO8B8SXR3O7AdNh24PGagLG1dO8>0OgMaLGAoP85oN7M`
LG^3QX1lN7AfNH64Q81hLgAkQ8V8Q81hMWb4S8R3OWQfMh2;R8AiMWMfO8B7Pg]g
LgAlPhJ7OgahN827SX^7P7QlO8B;R8MkMWIhQ8R7Q7aiN7b4R8b;Q7]hNH>9S8Qo
NgQhP8V>R8AlMWQnQXb;Q7]hN7b8Rhb8O7QhO868SXQnN7MhP8R<Rh1kN7j3Qhj8
Q7]dNh27RhV4NgQkNhN<R8IhN7MkQ8N9Q7aaM7anR8N7PGQhO868S8n8PGalQXb<
S8V1NGaoQXj8Q81hO7j4RH^9O7UkO827SXB0Mg=gMh66P7iaM7IhQXJ9Q7QhMWR1
QXAlMg=fN827R8AkMgMhPHN9R81kMg^1R8j8P7agO8B8S8^4NgMhO867Q81lMWIk
P8J7Q7icMWR0R8B4P7QhNhJ8R8^4OgalQh^>S8B0O7V3RHn<Qh=nO7n4S8R7OWAg
M7b4Q8=hMWA`O821P7UdLGAlPhN7OgQaLGb6R8R7OWMhOX>8R85lNGIiQX^4QWmg
MgN3Q8N8O7ihMX>8RhR4O7]iOXR<R81kNGQnPhN9PgahO823Rh^4OgIdO8B6R8Mn
N7AfO866P7]hL7AlPhR4OWQaMWb0R8J0OgAgO7n8Q7mnM7QlQ8b8R7mlP7n6S8V9
Q7aiO8B8S8V1P7MhP8B9R8AlN7]lPhN8Q7miNG^0R8^9Pg]hNh24R8MnO7QiOhJ8
QXAlNGQlQ8n;PH1kM7b0Rhb4O7AfMgR7Qh1lLG1gOhJ8Rh1iOh68SY>DRh5nQ8R<
TI68Q7mlQhV<SXR3OWn3SXb;S81kMh27R9>4Oga`N7n4QgmhLFU_MWb4O7ahL7Al
PhR8PgahNGj8R8R7O7UfNH26R85lN71fOh27P7UhLgAgP8B4OgQfN7b0R8R0P7Mg
PH26RHAoMgMlP8N8Q7mhMgUoR8^8PGMaNgj4RHR3Mg=aMX23Q81fL71gOhB6PGUd
KgAiP8>0O7IfN828R8B0O7UiPHV<R8AnNgb0R8V6P7mhMgb3QhN1O7AfN7n3QX1l
N7AhOhR9Ph1kN824R8n8PH1hOX>8S8R7P7UoQ8R>RHR0O820S92<R8=nO7j1RHb9
P7]iN7j6RHQoN7AgO826R8=kM7QoP8B;Q7acLgV0QhJ6OWA_LGj6QXB0N7AgOXR8
RGmiMWAnQ8b;Q7agN7R1QhR4NGQfNhB4QhAkM7AiOhN8P7ahM7V0R8b9PGUiNgj6
S8^3O7]hP8J<SXAoO823R9BARhAnOX64S8j9P7QiOX27RHJ3O7QlP8R<R8AnNGQn
QXR6P7QhN7b4RHV1OWakOXR?S8MlNGanPh^<Q7inN7b4Qhj8PGaiO7n7S8R6OWUh
NhB6R85kMWAiO866OgMaKWAiQ8R3PGQdN829RHR1NgIdOX>;R7ilM7AlQ8b;QX1h
Ngn4S8b6P7QhO868RhN0NGQkPh^<Q7mlN7QoQ8R4OWIdNGV0R8R0MW1dN8>8R8Mk
M7=hPHJ;QX1lLgN0Q8R8P7]gN7b6RHJ0N7AdMgj4QX5hM7AiP8J8Q7ifM7R1R8R4
O7AcN7j8RH^0MgQgO8B8R8AlMWQoQXV8QX1hNh2;S8b<PginP8R@SXR3NGUnRI6<
S8=iN7V3Rhb8O7A`M7b3QXAnMg=dO8N;RhAoO7UoQ8R;QX20O826R8b6P7QgO827
RhV1NGAhO8>9Qh=iMWQkQ8B4OWA`KgMlPHAoNg=`M7V4RhIlO7IgP8J>R8AoN7b0
S9>?Rh1nP824T8n6P7alO8B;RhQiM7QgOXB7PgQdM7QlQ8V8O7AdMh27Rh^3O7Qh
PH^;S8=lM7AlQ8N4OWM`JgAlQ8IoNgI`MX>6R8QoN7MhP8R>RH60NgR3RHb9Pgai
NGb4R8N0NGQfN8>;RH=nN7AiP8N8QW]dM7B0Q8J8OWQdMgn4S8^7P7alPhR@Thb4
P7b0R8jCRh1lN826R8n8P7QfNH24RhInMg1hO8B<R8IkMWV0Rh^9Q7IdLGN0Q8An
M7A`M7j4R8AnMWAfO8J4QgmhN7N0QXR<Q7agMg^1R8B0Ng=hO8>8RhIlNg]kQ8b>
R81oNGb4SY>9QX1oPH68S8R1MgQlOXJ8R8IiMW]iQ8J6QWQdN7j0Q8R4O7AdN864
QXMlM7AcNhB4PgadM7AkPhJ8P7MdL7B0Q8J0N7MfN827RHAkN7=lPhbARhIkMWb3
Rhn9Q7QdN7n7RhV4OWAhOhR?S8^1N7MnR8b<Qh5kMW^3R8b7PgUgNgn9SXR1N7Qh
OhR<R81lM7MlP8b<Pg]dNG^1S8b9P7UlOh>;RHJ0N7QhP8N7Qh5hM7]nQhR8P7Ii
MWb7R8V0NG=`O8>7RH=lM75kP8R8PGmdLgb3S8n8PGUdN82>RhR4NgMdO8B9R81h
LG5gP8B7P7McLgR0R8J0N71aM827QhIlM7=hP8R>R85kLGQnQ8R6P7UcMg^4SXR8
Og]oOXbATI26OWj0Qh^AS820O7b4R92>Q7aiOhB8T8n6P7QhP8R>SXV0MgMlQ8b>
R8=oNGb8RhN4P7QhN828R8AlNGAhP8J8Qh1hN7MlR8^>R7mlN828SY29QgihOXB9
SXR1O7MgO8B<QX1iMWMiP8N4OgI`M7MlQ8>0M71`Lgb1QXAkL71fO8B6Pga`LGAk
R8J8Q7QgMh27RHanN7AdOXB9QgmiL7AiOhR8Q7agMWb4Rhb8OgAdNH69S8b0MWMi
P8R<ShMnN7V4RHj<R85hN7b7T8b7PgilO8B>S8R0NGUiPhb?Rh1hMWQnR8b8P7Md
LGV1QXAoNG=cMX>7Q81iLg1fO8B8P7QcL7=iPHJ3O7=`LgR1Q8J0M7AdN8B8R8Ak
M7AlPHV;Q7UfM7J0QXB6OWQdN866S8b0N7IdO8J8RH=iM7MoQ8V;Q85kO8B8SXb7
P7UhOhR>SXR1O7MnQ8N;Q7agM7MkQ8B3OgQfN7n0R8QlNgMfO8B<R85lMWQlP8j<
R8=hO826T8n<P7UiNHB<SXn4NG]lP8R>RhAkMg]nR8^<Q7QfMgV4S8R4O7=cN8B8
RHAhLg1dPHR<R7agM7MoR8V8PgMgO8>?T8n4N7QhOhB9RhAfLgAiQ8R9RGidMg^4
Qhb9OWUdMhB4R8V4OgMlQ8R>RhB1N7V4R8b8Qh=hN7b6S8n<OgQfMX69S8R1O7Mi
Q8^@RhMoN7anR8^8QWUhNgn8Shj6OWAdO8B;Rh5hL6a`NH60OWI/K71iP8J4O7Ma
Mh63Rhb0N7=hPhN?SXR1MgR3RHn>R8AnNHB;T967PG]iNh6>RhMlM7AdO863QW]`
K6adP8J8OWM`KgR1QhR0O7MdN7n8S81oN7AlOhR>RH5gM7MoR8R8P7AcM7J0QhN0
N7MdNhB9S8InMW=iPHR<Q7ihKgMoQ8J4PGUcN7b4S8B0Ng=dO8N9Ph=kLgMkQXj;
Qh1hNGb7T8j8P7alO8JAT8n4OWmnQ8jCSX=lN7^0RHb8Q7Q`N7j6S8R0Mg5`M828
Qh5hLgIhPhj>R85kMgj7RI>>PGadMWb4RHAnM6afNH6;R8=hMWalRI2>S8=lOXB9
Si6<P7QlNhB<RHV0NGMkQ8V?RH5fLgMlQhR8Q7IaL7J3QXb6NgQcNH61RHAlMWIk
PHR<QgicK7=iPHN3O71/KWN3RH^4O7AdO8J<S8V0N7QiPHb;R85kMg^4R8b8OgQc
M7V1Q81lLg1cN8J<RH=lN7b1Ri6@S81kOX><U9B>P7IgNHJ<SXUlMW1fPhN<RH=l
M7V0R8n;Q7igM7n8S8j9NgAiO8N@S8QnM7AhOhV6PGadM7AnRH^;P7UiN7n7S8n4
N7AfP8B8S8AkM7MlQ8V9Q7adM7j3RHR3Nfm`M7b4QX=hLFm`N8B7PG]aL75lQ8J8
P7IaM7b3RHb0Ng1`NGn8RH1kL71dO8R8Q7icLGMlR8n9OgQcMhB>TI69OWQgP8V@
S8InM7IhPHb7Q7]fLGN4Rhj8P7]dNGn9T8V4O7QkP8j?S8QiNG^0S92@Rh1kM7j8
RI29NgMgNH67RHMnN75iP8N;Q7ihL7AlQ8R6O7=^L7R1S8R0Mg1`NH>8RHInM7=l
Q8b<R7mdLgN3Rh^4O7I_LH29S8V3NgMiQ8bCT8R0Ng^4S9BDRh=kN8B8T929P7A`
Mh28R8=kLG1dOhb;QgmcLG5lR8R8P7McM7b4S8]oN7IcN8R?SXQlM75hQ8j@RH5h
LGMoRi6>Q7QfN7n8SY23NGMcP8B>ShAoLGAoPHV<QWadLganRI27P7MdNH>>T8b4
N7=gO8J<R8AgKWAhQ8V8Q7UdLGR4RH^4NGAaM829R8AoLg1kOhR<QX1fM7MoRHR8
PG=`M7b8RH^6O7AcNhR<SXMlMg1gPHV<Qh5fM7R1RHb8P7McMgn7S8b1NGIhQ8bA
ShN0M7MnR9B@R7mdMgV7Shb;Og=dN8><T8R1NgMiPi2CRHAiN7R0SiB<PgUdLg^7
S8V0Mg1aM7b8Qh1kKg5hO8^8Q7a`Lg1iQX64OW1`Lgb8R8b0N7I`N827R81iL71h
Q8^;R7ihN7^7S92<P7]dNhB>U927O7AgPhVAS81hM7MnR9>?QgafN7b7T928P7Ih
O86<ShQoMgMhPh^<R7ifLg60Qh^8OWA`LgR4RHJ3NG5dOXB8RhAkN7QkQhb?R7ag
M7j3R8^6O75`MWb7SXUlLFmaO8N;Sh=hL7=lPhb<Q7a`M7b8TI29P7AdNHNCTHn3
N7AhPHb@S85gKgJ0R8b9OgI`LgV8Shb4OWIdOXRCTHb3N7MkQXj<R7mdLgIlRhb4
O7=_LgV4R8R0Lg=gOXB9RH=iLgJ0Qhb<Q7UdLg^4S8b8OgAdNhB9S924NgIgPh^@
ShAlL7AnQhb<Q7adLGN1S8b4Ng1`M7^4Q85fKfi_OhB4Q7Q`K7AlR8b9PgQfMh6>
T927NgQfOXV<T8QkNGQkR8j>QgahM7R4Rhj8OWI`MX28S8QlM71aNhR?R7mgKW1l
QXb<PgQ`L7J4SXb;OWQdMhJ@ThV0NGMhP8bDSh1iLgQlQY>?R7UdN7b8S8b8O75a
Mh68QhAlL75gP8b>QgafLg>0S8R8P7A`LGb4Shj3O7AdNhB<RHAhL71hPh^;Q7ad
Lg^6Si2<PGaiOXB?Thb6NgAhOXbAS8UiMWMoR8b?Q7QcM7V4Shn8NG5cN828S8]i
L71dO8B7PgUaKW1lPhR8OWA`L7b7RHb6OgQhQ8^@SX=lM75hQXj8P7icL7R0RHb8
Ng1aMWn8RhQlM71fOh^<Qh5iLGB0RHj?QgUgMWj8T9B9P7QfNHB<T8QnN7AhP8R?
Rh1dLGMnRHb9P7A`LGb4SY23N7AdO8R@TH]nM7AiPHbARgigMW^7R92>P7I^N8>8
ShR4NG1dOXV>RhAkM7AlR9BAR81dN7V4THb9P7IgMX28S8anN7AfP8V@S81hL7=l
Q92;P7Q`N7UoT8n9NgAkO8R?Thj0MgMnQhb?Rh1dL7N0QX^8P7M^KWV6RHN0MVm`
N82;Rh1hK6mhP8V?R7mcL7^3SXj8PGMdNHB@Thn1NGQgP8j@SXIgLGInQ8n<OgQ`
K7J0R8b4O7A_MWn<S8V1Lg=kOXR@S81hLGAlQ8^9PgM`M7b8S8b8N71cO8R?T8^3
N7AlQi>ARH5dM7N4Si2>OgIcLH>8S8n1N7=hPHR@S85kLG=nQXj<QWm`Mgn8V8n<
QWAfNHB?S8]oL71aO8R9R7]dL6]hQ8R9P7A^KgR0RH^0NgA`N86;SXMlM7AkPhj@
RH5fLGInSY2<PgAcLgV6S8]oM71aN8>8S8AhL71hPHV<R7acLgR3SY2@Q7UhN8R@
T921N75aO8B;R7mfLGAhQ8b>PgMaL7R0RI27NFm^MWj8S8AkLFadOXR<Rh=cL7N0
SY29Q7QcMX2;T924NGAcNHR>ShaiL71dP8J;Q7Q`Jg5nR8V8P75aM82<T8n3NGAc
P8^@T8MlMWN0QiBFRH1fMgn6TiN@PgMhP8VDUY26N7AfP8b@Sh5gL75lR8n?Q7Qa
LgV7Si28N7AaMhN<ShQkL6mfP8V@RgaaL7B0Ri6<Q7Q`M8>AU8j6NgAcO8bAS8Ih
LG1hQi6CQgifL7B3R8n8NG5[L7b9SXR0MgIhPHjAT8AdM7AiQ8j>OgA`L7QoR8b4
NG1/N827SXQlM71iPhbARH1fKWAkQ8^3N7A_L7N6S8AlL6icMXJ?SX=dL6idPHN?
R7QfL7N0R929OWA^M7n8SXb4MficO8V@ShMkL7AlRI>?R7acLGR7TiJ<P7IdN82C
Thb0Lg1fP8j@SX1dLg60T9>AQ7UdM82<U9B6Ng1_O8R@T8QkLfmdPhnAS85gL7J0
SY6>PgIaL7b9T923N75`NhRAT8IiKVihP8j?QWa`Kg>0T8j8O75cN8B?UY21Lfmd
OXbAT8AgKW1lQY2@QgU`M7b9U92;P7IcO8JAT8QoL75fQ96AS8=kM7R4TI^@Q7Uc
M7^8Thb1MVicMhB>SX]kM7MiRI2@TH5hM7V7SY29OWI[Kh28SXQoM6a/M8B;QWaa
J6QdQ8b<PG=`JgR6R924M6]WKgj9ShIhL6QcP8bDSh=dKgR4T9JDRGa`MhB<V9B;
O75dNHRAU8IlL6QhOXbAR7i/JG1hQh^4O71XL7b;THb3MVm`NhN<Rh1dK6acP929
Q7]/KgR4TiB<OWAaMXNDUYB6NgMiQ92CSXIhL75nSi6<Q7UaKg^<UY>6O7A`N8JD
U8UoLG1hQ9>FT81dLG>0SYB?PGM/L7V9U8n4Mg1dNhRCThQfKVifQ8b<Pg=XJ71k
R928NFi[M7j8ShR0L6UcNHV?RH1cK6mlRiBCRG]cLgj<U9B9OW5`NHNCUXioLg=f
Q92CT81fLG>3T96AQ7MaLhB@U9J7O7A`OX^CThQkL71kR92ARgi`KgR7TI><PGA^
M8BATHn4LFa/N8^>R7a`J6QdPHn?P7I/JgB0Si26MfQYLGj<T8QkKVacO8bCRga/
J6]hQ92;O75XKgB3S8b6M6m`MhB>ThalMWIlS9BIThAiLG^8T9R?P7Q`M82@VI66
N6idO8RDU8QdK7=iR96AS7a`K7V;U9B<PGA`N8^DV91nKfadP8n@Rga^IVaiRI28
PG=XL7V8THb3LF]^M8J@S8QgK6mfPhjCSWicL7R3S8n;O71XL7b6Sh]oL6Q/N8N<
SXAfK75lRIB@S7mdMW^@UiNDOgQaN8R@V963NFmfPHbCSXAdK6miR92>P7IYK7R4
T926N71/M8B?U8QnM6ahR9>GSX1dK7B4T9^AQ7M/LGj<U926N6a_O8bHUh^0MWAh
RiVDS7maLGN3TIB9Ofi^M7b?S8]lJFQYNhR<R7]aJFQdQhj9OW1[JGN8T9>8N6m_
N8NDV8ioN75hRiBLUXAhL7IlR9B<OgA/LgR7THj4N6mdO8NCTHQiKg1hPi6DRGma
LGR1T9>@P7McM7n<U921M6i`O8NASh5dJ6ihQ92@RgA[KgJ3SY68NFiXM8B<S8Qn
K6M`OXN;R7iaJFalR8b<P75`K7R7T9>4O71aP8VDTh]oL6mhRINDS81dLgR9U9VD
PgQdM86AUi>4Mg1dP8RDThMlKfmhR92@S7a_KgJ3SY27Ng1YLGn<T8anLFi`OXR?
S81fK6mnS9B@PgaaKWb8U929P6m`N8N@T8UlL6ihPi2?R81dKWJ7T9B@P7I_MX2@
UXb4N6i`NHbFTHQhLg5hRI>@R7aaL7R4Shj8O6i/LGj8SXQlL6U`NHB;QWU^J6Qf
Q8R9Og=YJg=oS8b3M6a/M8><Thj0MW=iQi>IU8anN7^4U9RCRgU`M7j>U927Mg=_
MhV@T8AfLFadP8b?PgI^K760S9>?P7A`MX29Ti24MficOXJ<S7mcJfahQ8j<P7M[
KgR4T968NG5^N8B<Thb0M6mhP8bDS8=fL7=oRi6>Q7Q^L7V8Ti28OWAcNhN@ThUl
M71hPhnAR7a_K7=lR8j;P71`Mgn>U9>7Ng5cOXVATH]nN7N0RIBDRGmaL7b8T9>;
OWI_MXB<U8b1MfiaOXV@RgmdJfmkR92<PgA/JgB4SXb3Ng=`Mh2<T8IhK6UaO8R<
Q7Q/Ig5nR96@QWQcMgj<Thn7N6m_OXb>T8QlMW=lR92CRGagL7R8T9N<P7]fO8VD
W9J7N7AhQ92HT8=gLG5lRIBCQWM`L7V8T923N7A_MXB>T8MiKVmdP8j@R7a_Kg5k
S8j6Og1TK7R3RhB0LfUYLHN<S8QiM71fQ8n@R7adLGR3SY>9P75/Mh2<Ti24MW1a
P8jGV8]nLgAoS9RDS7a`LG^8V9J?Q7AdNhBATHaoL71_OX^;RGi`K6mhQ8^9P75/
KWJ4R8b0MViWM827S8QhKfa`Ohb?RH1dL7J3S92<P7I/Kgj6S8n4N6a/NhB;RhN0
KW1iR9J@S85gL7J7SY6<P7A`Mh2<U8n8N7=kPi2HThUlMWN0T9BCR7A_L7R8T927
N71`MhJCTh]kMWAhQ8bCSW]dLgIoS92>P7A`Kgb6RI1oL6iYMX27SX1dJ6AdP8B;
Qga^J7>1R92;OWI/MX2>Uhj8N6mdP8bAShQlM7AlS96?Q7U`KgB7U9J<OgIaMXB?
TiB3N7AfQ8bDTHIlLGR0S9B@R7]aMWn<TIB9O7=^NHRAT8QlL6aaOh^<R7]`Kfil
Rhb8NG=[JgV0S8QlM6acMXJ@RhMhL7AiR8b@SWafM7V8SY>;OWQaN8N>THb4N6id
O8R<QX1`J6mdQ8R7OWA/JgJ6T926NgIdN8R@U8anM75gPHjDSWacKVikQhn<P7I/
KgV8U927O6i^P8bGV8n1Lg1hQYJAS8AfLgV6Ti>;PGA`Lgn<T8n1NGAdO8^FShMi
L7AhQ8j?QgI`KgR6S92<O6i/M82;SXV0L6QaP8V?RgmcK6agQ8^6OWIYL7R3SXj7
N71aN8J?SXb0M71fQ92ASXAlMWN7TINDR81iN82<U964Ng5aNHR?SXIlL6mhQ92A
R7adL7B3Shj8OW1_Lgn9SXUlMVm`O8R?R7mgL6miQXj<P7Q`LgV4T8b4NgAcN86<
T8QkL6idOhN@RH1`K7IlR8n9Q7A_Lg^;T8j4M71^M8B>SXAhKfmgOhb@R7Q[K7>0
Rhn<Og1YLGn6S8]oM6a`OXR?ShMlM7R4SYBDS7agM7n<TIB9OgIdO8J@THaoMWAg
P8V?R7icL7AlQhn<P7AcLgj;TiB9OWMdO8J>THQkMVmgP8R@Q7aaK7N3SYB<P7Mc
M7j<ThV0LfQ^NH6?S7mdJfmfPi2>RgmaMgb8TiBAPgAcN8N@TI24M71dPHbASh=h
L7B0S9N@R7Q`N7b<U9><NG=cN8V>THakM6mdQ8RASX1hKgN0R9B;P7Q`Lh28Shj7
N75dNh^>RhQlKfmhPh^;PGQ/IVinR8^8O71/LGj;THb3M6idO8^DT8AhL71lR92@
R7Q`KgR8TIJ;OgAcN8B@T8ioL6m`OXb@SXAgK7B0Ri>AR7MaMWV9Ti68Mg1`N8B;
ShQhK6adPH^<S7a/K7R0S96<PGA[L829SY20Lg1`OXbCThV0M7AoS9BGRgadK7N4
SY2;P7A^M8J<THanMfacOhNDRGifJg1hQY6;PGQ_L7b4T928O71fO8JCU8]lL71g
PhV?S7U`K7J0Qhb<P7M_M828Shb7Ng1cOhVAT8=hK6acOhb;Q7Q/K75nRhb8O71/
Lh2>TI24M6i`NhV;SXAaK6QdPH^<Q7Q/K7J3S928O71/MhB@THj1LFmdP8bAS8=i
L7J3S96CS7ahNhBAV9B;O7=cN8RCT8IiL6Q_Phb>RGU`KVilS927Ng5/KgR4SY20
M75`N8R?ShIhLG60S96FRGacLg^9UYB;PG=^MX>@THj0LfmaP8b@T8IiL7J0RiJC
Rga`L7b<Ti><P7M/N8R@T8QnLFiiPHjHRh1gL7N1SYB@PgIaL7j8Ti23Nfm/O8^D
T8QlL71iR9JGQg]`KWR0SiJ<O6mYL7b8U8j0M6iaO8N>T8MgK7=hOhR8PgAWJ71l
QXN4Mf]/M8J<T8b3MW1hQXnCSWidK6mnQX^8OVmTJ7V4R8QkLFMTM82;R81hKfad
PHn@QgadL7B3T9J?P7QcM8>>V921MfUdO8RAShMhK6ahRi>CRGm_Kgb7TiB<P7A_
MhRATi23M6i`P92DS8=gKW1oSi6>R7QaM7j>UiR>P7MdO8RDUhmoMgAhQ8jDS7mf
L7N0S9N?Q7QaMX6@UY23NG5aO8VDTHQlM7QlQY>DR7a`M7V4Ti68O6a_M82<Shao
LFaaOXR<S81^J6agQ8b<PG1[JGB4R8n4M6aXLH69S8UiKfiaQ92CS85iLGR8U9VD
R7QcLgb<V9J8O7IdO8N@THMhJfadP8j@RGQ[JG1nR8j9N6iYL7j4Shb0L6mfPHbF
ThIiL7>0Ri>AR7M_L7V9T92;Nfm/Lgn;ShanM71aP8b?SXAhL75oR96@PgM`LGV7
T8^4N6i_M86<S85cKf]aOh^>Q7]`KW1kSY>9P7AcM7b@UiB6N7IiP8bHU8aiLgAk
S96@R7U_K7V8TIB?P75`N8N@UiB4NG=dPHVAShAhJgAkQ92<QWA^LGR4SXb4MVi_
M8N;ShQhLF]fQhnDRh1dK7B0SiN@QgQaMWb?U8j4N6a^MhB?SX=gL6igQi2ARGmd
KgR8TiB;PGQ`MhB@Ui23N7=lQY2FShAhLgAnRi6>Q7a`M7b4THb3Ng1`M8B?SXQh
Lg=dPhbAS7UcKWB0Ri2<P7=/Lgj8Shj0MW1/O8R>ShAiKfigPi6AS7maKgB4S8j<
Og=`L7j;Shn1LfiaNhJAT8AfKg1iRi2FRgagN7n;U9B<P7=/MXB<ThUlLFifOXbC
S8AdKgAnS9B?Q7M_KW^9THj4N6a/M8BCSXIiL6a`OhV<QWadL7B0S929O6mXK7J3
S8QkLFi`N8B@Rh1gKg1lR92?Q7I`L7N6Si><Ng1`Mh>>U8]iL6U_NhJ@RgiaJG1h
Q92@Q7Q_K7R7T9>7Ng5/NHBAUXR1Mg1kQ9BDS8=dLgB4T9>@P7QaM8><U9B8P7Qh
PhjFThAkL6ihP8^>PgA^K7AlRi64O6m/Mgj9T8aoL6icO8V?SX=hLGB0Ri6@Q7aa
KWb7SXn7NFm/Lgb<S85lLfU`O8V@QWidKW1hS9><QgaaMh6<V9J8OWMdNhNDUXMo
MgAiQ9BHSWmaL7J0S92CPg=gOhRCW9N9OW1fQY6HU8QlKW1kQ8j;PgAXK71lRH^3
M6iYL7j6S8IgKVadOXN@SX1fL7B1S9>AQWagN8>>UiN8OWIcO8B<T8AhK6Q`O8R7
Q7MYJ6aiPhV7O6iXKWV3RHb3Mfi/MhR?RhAhKfidQ96DRGidKgJ4T9B@Q7IcM82@
TI24N7=fOhbDTHR0NGR6TIRHShAnOXB>V9^@Q7aiQ8bDUhb1MW=iQ92FSh1dKg=o
R8n;P7U`Lgb6T8b0M6m_Lgb8RGmfL71hPhn@RGmdLGB0SXn<P7=/L7b8T8n0M71`
O8V<RgifKV]dOhR;P7M_LGR0SXb8N6iaMX><T8ioM75gPHb@RgmfL7=nR8b<OgA/
KgN0S8^3Mfa_Mh>;ShIhLfmdQY2ARGidM7V3TIN@PgUaLh6<UYB4MW1aO8bKV8b0
L71lR96HT7acLG>1Ri2;N75YL864SXQkL6M_NhR>R7maIVahPhR8OgA/JGB4S8j6
NgA`O8R@ShR0LFidOhV<R7icL71kRHn9P7MaLGb8Shb4N7AcOXV@TH^3MgAkQi2@
S81dKg=nS9>8O7A`Kg^8S8R0N71cNhRDT8AiMWUoRiBARGadMW^4T929O7AaM8R@
Ti21N75dOhVDT8=hM7V3S9NCRGmhM7n;U924O6a`Mh6ASXQiLG1aP8nDS7mcK6mk
S9B<PgA_Lgb9T928NG=cOX^ATHj1M7InRiBDS81hLgR7T8n9O75`Kgb9ShUlM6i_
N8^AT8AiMW5nRi2DS7mgMWj7T9J7NGA_MhB>THQlL6QdOXV@QWi`J6adPhb;OfmX
KWB4Shn6N71_N8B8S8AgK6UaOXN<R7U^KWB0Qhj>P7I/MXB7Shj4NG1dP8nFTHUo
MWR0RIBFRGmiMgb7TI6;OWAcN82<T8R0L6idO8R<Rh1`K71hR8b9Pg5^KgN6R8N3
M6a^N8N;SXIfLFmfQXb@RGadKgB4RI>>OWQ`M827Shj1MW1cNhB@T8IiL6ihPhb>
Qg]`KW>0Rhb7O7A_M82<Th^1O7MkPHV@S8IiMWV0Ri2<QgadN824RhV1O7IdNh28
R8N0LG=gOXb<S8AgLg=nQ8R8Q7]aM7N4T8n?Q7QhP8RDU9J9O7QhQXj>T8=kM7N3
RIBAR81hMX6;T8b0MVi/M828Q7adKVahPi6CR85fM7R0S8b7NFaXKWV6SXalMW=`
P8VARH1iJg1hQ8R6P7M`M7b;UiJ>Q7akPI>LVHj4N6idQ92DT8MhN7R1U9N@Q7]d
L7^3R8IlLFUXLGn6R85dK6Q/O8J8PGI`JGB4T9R?QWmgO8^GW9RCQX24S9jQX9J6
P7J0Shn<O6iVH6ahPGa`I5]HI7B0Pga`IVM/Ohb<S7ihKfilPhN0LfmYJgN4SXb0
NGAhOhRDUXV7O7n7TIbITHMhM7b8T9N@QWadM828SX^0Lf]/M8B8Qh1gKg1iQ9>D
S81fM7V4TI><PG1^M7^9Sh]nL6i`Oi2DT8IhLG=lRi2<PgI/KWAnQXAkKfQXM7n8
Sh5dL6aiPi2DS85aL7R0SYB@QWQgNhBAV9j@Q7ioR8jHV8n4NG^3QXj?QgaaL7^4
T968Pg]gNH29RhAhJFIYLgb6Q7a`J6idO8b@R7QaLGN0Q8R6NF]YMX2;Shj4NGIl
RiRHThUnMWR4SY2;O6iTJ7J4T8n6M6MYL7b8S8IhL6adQ8nDS81iLgN3S9B8OWA`
N8>?V969OgIlR96FThQhL6mdPHj8O7I[IgB0S8j7NfiaM7n;RHMhM7=gR9BLX9JD
V:2hb=O@c<Jhb=_[m>SFa<78d=SIb;>LQgifM7M/CR/>110L9a`4000000lT:BPH
0@004b<[70P100011QPK81PL=2hkB3i3=cU;E6M`MX^DY>3ooooooooooooooooo
ok000000000000000000E;_oooooooooolIgAQ00000000005V2Pe?oooooooooo
ooooohm00000000@93aLS<3XooooooK1QT`S2@00000011LcH9C8m_oooooooooo
oooooooooooooooomjJ0B0/00000000000000004?6N4SX1hKfadL61DAc`c@Eak
U:O0jooooooooooooonkL1P000000000000000I7RLKlooogh<R`[ZBDNeU4A669
_ocooooooooooooon9A>0`000000000001M8O:WFkocnm=nlUV]190@0000022Q;
MZC9l?ooooooook/dK6>L5I4>ca0?dQDHg=nR8b<Q7IXF4Q0>30S6ahY>D=8EfMc
O8bQ/;Vh[jNKUiNDRH64R8RCZlOPjNoho?oooooki<naVHV7R7AWGU=GGVI`KVAL
D51AE5Q?Ac``<ci<EeaPGeiYO8nPYjba]<7DiocooooooooooooolmJhW8=YCc<K
40/<51lV9bPd?daLK7QhM71_Kfa/I61HCU5HGVQhO7UfL75aM7A`J5mHDe5HH6MY
J6A/O8BAWjNVXijLY[2`[:RHTI6DX:^d`;ji_<kQk?C^i=kKfmkOelBXRgU`LgI_
H4@/61<H9R`V7Q0841PY=S@`:bP/=4A9BDQ3@d]IJ6a/I5]FFfaoRHj<Q85lR:2Y
[:NPXJ2/`=3DbL2l^;k9dm?9_;>/XIbTX91lKg1dO8R?R7]_IVMTLGmlM6APH65a
Pi>KV9BKXk>l`lJcW8b0P8>4P6U>=2/d?T14A3`h?U1TL7AcHe]SNiJNWYbDVJkA
oooooooooooooooonLVh[jV9H3@8000<82`/82@dD7NHX9=lHeaTN8^4K4ld<4=/
U:VXVhb9UjR`XHMYCdA8D556;Q/H8CaIKW1QDDaGL8NDSgQF@3m@I6a_K6=SKXRQ
^<2l^l3<fNSYg/bi][S0`KRSOfAIEUA@BC<L3`L@8cM8Bd@n?dA<E5]IE5AFHFig
OgMgO8>@V9jKTHnGZkk4a;>ITHbFW9>6Ke];BEMTIV1IDeAON8jHWiN<T9b`a<_9
_:n//<CDfmkDb<?8e=KDajnKT92CS7mXCS0P7bLf>3<T61PP<4A@Cd]3=cQ0CeQH
E4i;CeAWLGMlN82>Y[c>gnSanOooooooooooknOVgm2fT6=0;2P/<CPf<30d@EQX
O8R;TINQ]kbo]jBIUYj[];niZ9^DUjR^Y91_DdM8E6AfL61>Be1OL7j4MfQYL7=o
QX1^EU1HIWN0Og1PGW2>X:n`YiN9S9BPZ:2HT8N9VJJ`]:RKS8>7Rhj0M6MFEUMP
Jfm[I65TKh><S81[GeaTKgn4P7U/JfanS9>FShR;TIbX[jjXWi^LX:6HShAgLgR0
P7QdJ5aOI7V8Rhb4MW1lT9nWZ9n<Nfm`Lg1YG4a0>dIHH6ATH5iLI7B0PGAYH5]S
K7j7PgahO8RHZk2/W8n@T9bWYYb8Ng1`P8^HWYJ>R8nHXJVVWYB8PhB8T8^4NF]/
KgAhM71PE55CGVAWJ61HE5MPKW=cK6=FDF1WKW=/HEUIF6MdNgmdKg5nS:Bh]:RI
R85oP8MnL6]^N7R9ViV9NgmoQYbd]jJKXKW@m?ooooooooooooooonS0/91V>000
0000000000012baDO9RLQV=6>2h[8AP<000011ldD6MfOXRPZj>IS8IhJfi`I5M;
@C@dC6=_O8jHW:C3hNCTg=S?^<2lY8MlQ7I_J7b3K7b8Y[c;l?_ikocooooooooT
c/RWQ6<k9PH0000000070`/T=51QL8=lM7alMemVLFI8=30T:3mPQXjHV8n<SZ>d
/JbTV8nAWjba^;j[Yk6k_;O0a[^oi?oooooT_YN?ZK>[Yj1h?c4nE5aHGU0n;cIC
Ig1`J5mDDg2>SVi@@3]7GW=iJ4`g;3iHM7II?1P66d1TM6aLCd]TS;_;/jBNXK_`
oooooooooooooooiWh1^If=H=00000006cM;A3]0EhBY`<>XRG5aRIbXZ9=fGfR8
VJNTU7QLGg1nPGQC9P`<;T]HL6mPDeN0Y;Ng/J66Oi>W/KN[U8B0TJN/[jJDPhJY
a<W1/IUfGVb;UYBCS7i`NHb?Q71TC3@lD61HB3/d;b/hDEA;D51HI7RL][R/Y;2d
[[2c]jbIU8R0LfmcN7QhO7AXH61VI6i`KVmYKh2>W:V_];S0bLc?akbi];W7c<R^
T7QVHEaHCS@W93AAKhN8N6]SK8VY^;>QQ7R4UZJTT6U<A4]PM7UWBc@/?5AYL5hl
8b=1K8N@Q6]KHhBY`<RdSW5YMi2NZ91TCe1dVJ^`TFU;@e5QP8j6Mf=/OhbFU8U`
F4mDJH6CVI64QiJTZ:NPVIjQY:RdamSWm_ooooooooooo=bfV92@Ti20J4hn?Sm1
ATM0>DAIKganM6MLI7V4PG=F>2HcDGJ>Sh=`H7>P_<S1Y8I[I82T[9R7Je]/TkNl
/95aK7JHa<bgREQ0A6J>X9UlGU5NP;3<b;68KfUdT9B<N5a?C6R<UYB4LFmfRi^L
RF=8A4MPO8^7Ie13@51XOX1iJEmPI75hMViOEUAIHFIXI61SJgMnOgUXDdaDHGJ8
T8QkJ5aSLhROZjRHR7inP8RGWj6PY:JPXjBYY9VPXJ2PXJ6HTi6DVibLV8UdK6][
KgQlMfQKD4Q9DEQIFF=TI71dMg1XJFMXKg=hLF=NI6n6VJ^aZ:>PY[2nc<W7_kJc
^;jn^;Bc/:j^ZjBOUi2<Qh5oNFaVJ7>7S9>LUXV3Qhb@Thn;P7AdMWQdKg5cK6]_
L6QQHfATK6i`LFUXJ6AXJ71dK71dMg]lR92CXJb^ZIVARhJ8T:B[ZJb[Z:R_];B[
Vi2<S8b@SXAgJfITJFiaK61KEf1`MgalL6AOI75lQ81lN6aaOXB8P7alNH24RHQo
M6UXJgAnP7mcJFAPHfIWHeQGEUiXLgn1Q8B9TIRLW9RARhVDV:2TX9B9R8bFVi^H
RGQ_Jg1dLgQdK6AVKWR4S9>@QXbGWj6NVhn6Q8B;Qh1lIeQ?D5iVL7IfKfA/LgR3
Q8B0MWR0R96HW9R>QXN<Shb8Pg]dM7R1P7QfLFmdQ9JLXj2LV9ROZ;>/Y:6OV9^Q
Y9n?OgIfN868PGAYH61WK7MlM6]VJg>4TINKT81lPhjHYjRQW9NIY:^/ZjBDRHb>
T8V1MV5DE61XKg5WG5QCGfa`MW1QFeMKIVQ_K6=NG6Q/LGMcL6aaOi2HVi^@RhV<
U9JDShIoP8VLY:VXU8IhM7]lPH5hK65QHfadLGAdKW1cO820O75aLG1kO7aiLfaY
K7IhNGM_K6U/N7j4P7Q`K6]cNHJ6O7]iPHb<U927P7QlQ8bDSh=iLg=oQhj@Qg]^
KW5fOWmdK6MTK75fN7A[J6aaQ8n@Rh1hM7b4S9>;N6aYJ71oQh=kK61SJG1iOgQ/
I65[Mgj1Q7mdMgb4QhAoN75cNHNGU8n9P824S9RHThQlOX><W:6PUhj9RI2KYjBP
V92CTI^TZ:BNViVDTiRFS8N1PHB4S9B?P7QcL7=hO7M^IV5VJgAlO7QcJf]`M7Mf
LF]YJgB4R8R3Mfi_N8RDV8b0M6acQY>KUXMlMWQoS9RDR7Q^M7n7SXb0KVAXN8J<
ShAdKW1lU:BSW924PhbLY:JGQ7]dN8B<S81gJFQdO8R>Qga`M7R0RHR8OgQlR9bT
X9V<Q8B;W:BSVHQlMWb4S926NFQKGV5[LG1/HF1PIWAhN7I`JfahPHR8P7ahM7j8
S8b8PG=^M7R4Qh1lKVQ/LGj0P7M^JF=`Oh>4Og=/K71kQ85hK61HG6Q_L6iWGV1[
M86<R81oQ96Q/;B_Y9J@U9^WZjBDQ7UlPhV>Rg]YHFA/N820N6m^M8JHX:RQV9>D
Y;Bl`;RXX9^QZk2dZiJ8OWn4R8b4O7A/M7b4RhQoNG=dO821O7=^K7=iPhb7N7A/
JgAlR8QlM6a/M7^4RHAlLg5hPi2DThj3OhB@V9bKTh^4Q8VCUiJ<PgafNh26Q7ag
K6Q[L7MgLG1_K75lPhAlMg1aMgb6R81gKfa^LganN6iVHFQcO8R8OgA_M7V4SXj8
P7V1R9BGUiN8PGn6Shb;O7A_J75lO7ifJ6ASJ71nQ7Q`JfAXL7b4PGA/IV1XL7Aa
KVQPI6agPH5oN71_Kg^3P7mdL75fPhnAQW]hLGAoR8b6N71_Mgb0Rh=gL6a`Mh68
PGiaL7=gQ8b>QWinOhB?UYJ>Pg^0QY>LWib@Qh>4T9NIUhb0Ngj3R8j<Q7QgMg^3
QXB1NgQlQ8R<Rh1gL7J0R8n;Q7acLgb8TI6;PgMdOhB<ShQoM7=kQXR9RH5hM7R3
RhR3P7QdN7n<S8IoM71`NHN<S85fM7AlR8n>QgadM7j6S9><Q7ihP8R<ShMoNGV0
Qhn?R7mcL7=fP8R1N71[KW5kQ7mkLFU`Lg^4PGa_J6Q[N7UkN6]TJ71hPhJ1N6aX
KWb6R8AiL6a/N8>7QgUdKVahOhJ4Ng1/L7J1SXb6NgAkPhjHV921MW^0Ri2CT7ia
K71kQXMnMfQTK7B3RHJ0M71dP8j@S8UnNGj4TIJCS7aiN829Rhj8Lg1fMXB8RH5g
L6ilQ8b?QgUcM7>0RHR8OgAgNh2;T926P7n3T9bPX:2HU9VSZkVf[ZRNVinXZjBN
R7]fLgQiMg1TFe=DGfAWIUaLF5aYM81oNGMfO8VFXJBLVINHXjnd/jJKShVAU9JH
R7]`Jg1hP85oMfi/Lgb4QX1kMWIhR96DU8V4Q8RCW:6HT8J4Ri2KX9b@Ph20R9BA
T8AcK6mfPH>4O71[IVmhOh1hLFm/MWn4QWacK6]_NH67P7A/J6ikQ8^6O7=/KgIo
QX1lM6a`Mh28R8AhLgAhQ8b9PgI_KgAoRHb8OWIdO8V@U928P7b3R96GSh=dLg1d
P85nMf]QIVidO7aaIV1LJ7IiP7I/J6A^N8N;P7adL7b7T9>>Q7alO8JAVI><Q7b1
Qi2FTHQlN7QlR8V6OW1YKgR1R8^1M71aNhJ@U8b4O7b3SiJFU8N4PH>>T9B?Q7ih
P8B;S8AlLfidNHB4PGUaKWAlQ8R8P7=^L7B0Qh=kL6MXKgR0PgacKfadPHb<QWmh
M7V4S92;OgQhOhRAVIB9Q821S9RKV927P8J@V:2LUhn9S92KY9nFR7n0P8R@S8If
L75dO8B6PG5XK6igP820M6]XK7MkP7mdLFa^O866PgQ_J6]aN860M6mPI6acO7Uf
KfAQIWAnOgU`JfQ/N7j3NgA^JFmhQ8N4NG1/JgAkOWmhKVQ[L7R4QWacK6igOXB7
OW5/K7AoQ8QoLFQWL7MoPgicJ6]aO866R7i`K7AoQhb9PGUaM7j8ShInM6a_Lgb6
R81fL7AiQ92<RhAlP8B@WYnPUi>@TJ2XYj>HRHJ1R92;QgIYIf=YK6a^GUQDF65/
M71`JFA/MhR@T924PhB<X:JXZ9^FU9RT[:VPT8V0PH^>U8akLficNHN<QX1dK7An
R92@R81gNhBAW9^DRhB6R9NQWibDS8bAVjBQW8n7QXJDVI^HR8J3RINIY9b@Qgb7
S9BPUXj4N827T9><S7idN7R4QX5oM6a/LGb3P7a`IVM^Mh63O7A/KW=kR8R7O7Af
N868S8b1O7QkPHR<RH=hL6mgO8B8P7IdNh69UiR@PganPHR<T8]lLficN7alN75T
G61[MWMdKf5NH6mgOX1dKVQXM8B<S8AkLg=lQ8^;PGU_KWB1RhV3NG1`M8><S8Ah
L71aP8R<R7adM7B1Si2?QgalOXbFViR<RHB0S9ROW927P827SiRFRGmdLGN0R8Ik
L6AQIW=oO7Q/I6=XM868P7M^L7AkS8n>QWIkOhVFUi^@PH20SY^HV8^0Ogb6S8j<
P7Q`L7b8S8j4OW1aP8V@Shb1N7QlRiBKU8^4OXB@V9bHT8AoOhN@U924O7I`NhB9
QWafL71fOXJ7O7A^KgMkQXQoM6UYK71lOW]`I6ITJGAiNfmXI6A_M7]oN7=_L7R0
S8j9R7ilP8NCTi28P7mlQh^?Rh1hLGAgP8V0Lf]TJ6ihPH1fIV=WKWQnPGMYI6I`
Mgn4NfmWJG=lPhIlKfAXM7n8RhAfKVagQ8b@R7]_K760S8n9O7=_Lgn>U8^1L6]d
O8R@SWmdKVigPhR4P71VJG1nQ8B1M71^Mh>8S8AlMg1iR8b?RH1lN86;U9^DT8N1
S96PZ:BPUY2@Uj2QWiB7O7AiOX1iKf5DE5ILJ6QTFeAHH6igO7UcK6Q`OX^AT8n7
Q92HZ;2`ZIbKWjBd][2XV8j?T9RIV8akMWAhQ8R6P75YJg1nQ8B0M6]XLH67RhR0
N7IlR96FTH^4OhB>UYVDRh1kO8NAUiB8O7QfO8R<SXMhM7IoR8^>Q7mdL7J0QhAo
O75^MWn7SXR0O7]kPHb@S8QnNh>3R9>AR7mnP8J<T9B@Pgb0R8jGViR<Q8B;TIVL
V926PhB<Ti><Q7M^Kg1gNgQ/H61OI6Q_LfQOFf1XL7AdLfMPH6MdNgahK6Q/LH27
RHIhM7QoR92DT8QhNH27TI2ARGaiN7n;R8QlLfmYLgn0Og]`JG1gP8b>Qh1hMh2<
TiNGS8J3R9JLWYbDS8J9TibLUi21Ngb3RHV7Og1/Jg1kO7ihL6QXLgn4PgadK6aa
Oh^>R7iiMgV4SY6<P7aiP8N>Ui21NgIkQ8bDT8=hL7AoQi2>QWUdN7b8Rhb3N75_
Nh>8R7mgKg1hPHj;Q7U^L7J1R8n9Ng=`NHJ@UY29Og^0Ri6HU8V0N7b4T96<R7Qa
M7J4RhJ1MW1`M8J9RhIhM7IlQi6@S81cM7R6T8j;OWAaM8B9Ri20N7QgPH^>RH1g
KgAnQ8N4OW1YKW=lP7mfJFAQIgAgO7AYI6=XKgIgLFiWHfUaN7QdKVQTK7AlP7mk
L6]`Mh24Q7mdL6mfOXB0O7=XK6mgOWikK6UXL7aoP81dKfmcP8>8QgaiLGB3QXV8
P7adNhB<U926P7b0R8jFThb4Oh27T9VLShB0OX69U9B>QWalQ92HWZ2GTI2DXjj`
[:BGTI2FW9^DPGQ`J6UcLfaSE5ACF6Q[KVQLG5i/O868PgaiN8>CWjRPViB@U9j[
[ZNOT8R<T9NHThMhM7AlR8V6O71^KWB4R8AhKfaYLH64Q7m`K6ifOhN;Pg]hNGn>
U9NFS8N3Qi>GWYR<Qgn6SiNLV8b3P8B9TiB@QWI^KgAkOgQ`JF5SJGAhNgQ^Jf]c
Oh>6Q7]dLGV4R8b8PGahOXR?TI24NGAfO8>8Q7idL75iPHV<R7ahM7R4Q8N4LFaW
K7AcN7=YHe]TKgIkN7A/IVUdOhR6P7UcNHB>U9><Q820Q96GUhj4P7j3R92AQgUa
L7UnR8^4O71^Mgj4R8AlLFmhO8J9R8=gLgb4SYBCS81lPh^GVIRDR7n4T9NKVI68
PH28TiVDRhAdL7R1R8R3Mfi`M7b7Qh1hL6acO8B7R7ifLgR3Rhj9Qh1hOhB?UY2<
Q7alP8B>RhAlMWQlQi29Q7mgN7n8T96<Q7mlOhR@Shb3N7QkPHb@R81iM7IlR8b6
PGI`MWV9SXb9NgQhP8jDThb4OWQnRHb@S81dL7AiQ8N0MfiWIVmdO7U^J6=QJgAn
NFm/I6I`N8B4OgQ`L7N3Rhb7P7QiO8RCThj6PGaoQ8V@R81kM7^1R8V7PG=`N7b8
RHQnLG1`N8>6Q7acK6]fQ8N6OgA/K7AoQhQnMW1YLgb1Qh5hL6a`OXR9Q7mhLGR6
SiRDSXR3Ri6OZ:BLTH^9S9^NV9B6NGQhOh21NFUTH6AaN7ilLFa^M7b6S8R0OWb3
S9BHUY21Oh68Si2@QWUdM7UoP7acJ6ASJgAiN75/I6M`O824OgIcLgR0R8b1NG1`
N7j;T8J3O7V3RIRLUY24QXR>WZ2IU8N4Q8RCUiB<OgUiO8N>S8MlLg=gOhB1P7IX
JFacNgiiLF]YJgJ0PH5lMW5aNhJ9R8=hMgV0SYJDRh5nO8>;T9B<Q7alQ8jHV927
Ngj1RiBASX5cL7IlQhJ0N6aXJ6iiOWQaJfQ[L7V1PGUcK7AlPhj<RhN0Q8RCV9NC
R820Q8b?TH^0N7AkO866O7M[IfacNGmlLf]XKWIoQXAoL6adN86?RHAlM7QoS9BH
TH^6QhRAWYbKTHR7R92GV8n4OgQkPHV;QWaaL75gOXB3N75_LGB0Q8AoL71`MXJ8
RH=hMgIoRi2ARH1lN7n<TiB?PgalO8N?T8UnN7AhPhR<R7idLGB0RHj8Q7]`Lgj4
R8QnN75`N8B9R8AlLG1hQ8b<R85iMW^8T96<QWilOh^FUi29P7^0Phb?R85fM7Al
PhJ4Ng5`L7R3RHR1Ng1dOXB<S8IlMWIhP8R8Q7U`L7MnQ8V7OgMaN828S8R4MW5f
O8B8Q7U/JFU/N7n0N6aVJ71gOX1iL6UXLGb3Q81hKfafOXJ;RH=fM7UoS92@R7]i
Nh><T9>7OWUhP8V>S8IlLgAkPhR8PGI_KgAoR8V7P7QhP8bFW9VAS8J<U9VNU8b0
NGb1R8R0M6UQGV=`KfaWG5QHGVQ`Mg1[K6]fPHV?R8IoP8b@WZJPV8^?TiRVY9nG
Q8B6R96@SX1fL7AlPhb8PgUaNGn8Shb7NgAcN8>8R8IlLG=iP8V8PgUcLgV3S8n<
PGakO8RAU9B>Q8B7SYRLVi69Ph2<SiJDS85hMgn4QhMlLF]YLGR3Q7afK6QcNgn4
P7I/JgAlQ8R4N71^L7b7S8MnM71gOhRCShAhN7b4S9>FS7mkOXB8S8n8NG1`Ngn3
QWaaI6A`M7QlMfaPGf]cN7ikMVUXKWR4R8MoN75gP8^ASXV4P86;U9bKShR4O8R>
Ti>8PgUgO8>;S8IlMg5cNhB7OgQcJ6]gP8J4O7AcN7j;T927P7]lQ92GU928P827
T9RDS8AiMgR6S8N4N6iXJGAkO7Q`JfAXLgb4P7Q`Kg1hQ8b;PgQhO829U9J>PGmo
Q8j@U8b0O7V0R92ARh=hN86;TiB@R7akP8VCU928O7QiQ8jCTHR0Ngn7T9RFRgml
OWn7UY69PGQkO8N;S8akLgAhP8>8Q7M`Jg1lOXB1MW1YL7R0Q7mgKVMXLg^0O7Q`
K71hQ8b>Q7ahM7n9Si28P7QhOXR@U963OWn1SY2CSX=kM7R1R8R0OgA^MWj3PGmg
KfaYLh20OWQ/J6]`O8R3NgA/Jg60R8R0MgA`NH6>T8N0N7QlP92DT8IhMW^4T9>A
Rh1lO8B<T8n7OgIgO8B9QX1hK6mfNh63OgA/KgAlQ8>3OWAdN8B<SXn4P821SYRP
W9B@RhbCVibHS81hM7QiO7AXGeIDEf5[K6AHE5QTJgIlMfiXKWN0S8n@Qgj1QiJN
X9nDS8B8TiVLThQlM7MlQh^6Og1/KWB4R8N1MW1aNhJ<ShQiN7MoS8nDSX=oNH>@
UiRARhAlPh^CU8b4P7]lQ8b@ShIoO7b3Ri6CRH5kO869T8n;P7MhOXB<R8AoL71f
P8N6Q7Q`L71nR8J4OWAaM7n9S8V0N7AdPH^@T8IlNGR1SiBDS8=kNhB<UiRARgn0
R92DU926MWAhOXR7PgQ^J6QcN7akL6MOGfUcNGQ`J6IYL7b8RH=lMgMoS9JGT8Io
Oh6<V9VAQh20Q8^CU964NgMhOXB3OW=YHfM`N7aiL6USIW1hOgmgL6]`N8B?RhMo
Mgb0S9BDT85hN7b8S968Ng5aM7j9R8AlKfi`MX66P7I/JFadP8N6O6iYK7B3RHb6
OgUlQhjHVI>7O828T9NHUXb1P8B<UiVCR81nPhbAUiB9O7QkPH^AS8AlM7AkQ8^9
PgUfM7b8SXj8OgMgNh69SXInMW1hP8R8Q7]`Kg1lRH^7P7QcLgn6Rh^0N6m_N7n7
Q7idK6adP8J4P7MfLG^8SY27P7]dP8BAUhj7O7]oQi>FT8QnNGb1S9>?PgUfM7b6
S8b4MW1cMh26QWa`JF]dO8>8OW5^J75nQ8B1Mfm_M7n8Rh=lM6mdP8R8QWihLg=n
Q8N1N75/KWAlQ7ahL6I/Mgn8Qh5iMWQkRI>DU8^4Q8bDXjJOV929Ri6GV8j0L6]/
K7AhM6]GE5UPKWAdLFQSJ7AlQhR4OWAhP8nGU9R<Q8R;V:6PUXb6P8>?Ti6>P7=a
Mgb8RHAlM75dOXJ<S8=hM7AlQhj@R7i`M7b4S928OgMgOh^@Sh^3N7QlQi>ASXIk
O829V9VHSh20Ph^HVIR<P7aiQ92CThQhLg=gP8N8Og=/K6mgOh1lLFQWK7AiPga`
J6Q/MWn4P7QXIVidQ8^7P7AcMgn?Ti><O7UlQ9BHW9N8PH29T9JFSXAhLgR6R8R4
Mg1YK7^3Q7agL6Q/Mgb0O7=`JfaiPhR4O7=_LGV4R8V3NGMdO8R>ShMnNgR0R8b@
R81fLgIkQ8R0N71/L7R0Q8AkKf]/M826Q7idKg>1R92DR81iNHB@ViR@RGmoQ8bD
U8j1N7AhP8J6P7M/J71hP8B0NG1^M7j7S8R0MW1dP8^>SXIoN7V7RIBCRHAiO8B>
VINAQganPhbDThn4NGMlR8j>R81aJg1kQh^8PGI`LGb<TI29OWaiOXR>ShAlMWIl
PhR<QWagMh29T9><Q7QhOhR@ShR0M6iaNh61OgQ^IVMdOX5oM6aYJ71nQ8AlLfi/
M7b4R81fLg1lPhR@Rh1hO8N<U9RDRh1lPHbAU928O7QlQ8b@S8AiM7B1R8b<OgM`
L7R1R8N1Mg1aNH69Rh5oM7J0QY2@SXMoO8>@UiJCR81lOXVCU8j4O7AhP8V@Rh1i
M75kQhb<PGQdL7N0RH^0N71aO8B<U92;Ph>9SiRLUXanO7V0R8AnLF=PGV1/K6UP
F5ADGfU/LFULHf=/O828PGUhN8NCV:2NThb<Ti^SY9jCR8>6Ri2AS7mcL6mhQ8>1
NG1/KWR4R8QoM6m^N827QgmfL71gQ8^<QWiiMWj<T96>PGahOX^@U8j4PGanR8bC
T8InN7b1SYJDSWmnO8>;SY>7O7UdO8B9S8AlMW=kPhb9P7U`KW=iQ8R3Ng=_M7b8
SXR1MgAgO8R<S81dL6mlR8n?RH=hN8>?V9B?Q7alPHbAU8mnN7QiQ8b;R7a`Jg1k
OXB1M6UPI71lOgUfK6AYM824OWM/JFQcPh>3P7IdMWj<UiR?R8B1QhnHV8n1O7Ul
Q8^8Pga/Jf]aOX20M71_K7IoQhMlM7AfNhN<T8V0O7j7S96FSh=kMh68Ri28OgId
N828QhQlKfa^N7n0PGM^J6]gOX26O7=`KgV0Q8IlLfiaMh28QXAkLgAoR8jCSgmh
O7n<UYJDRGihP8VDV9B;PGanQi>AT8]lNgj6Ti>@R7miNHB?U927O7UhO8VAShQl
MWIiQ8b@S7mnN7R4Ri2<PGQdNH24R8IlLfm`O8B7QWmhM7=lR8b8PGUdLGR1Rhb4
O7MfMh>;SXQlN7QhPhb;QWadLgIlR8n8P7adMh26R8AoM6mdMX29QX1hLgInRi2?
Rh5kN7j9Shj8O7AgO8B9S8MkMWAhQ8R7Q7afKgMoQ8V6P7QcNh69TI29PGn0R9NN
W9B8P7n4S9B@R7U_IfQcM7I/H5QDFf5^M71XI6A[Mh><SXJ3P8N?V:2QU92@T9NN
Y9nCR820Q8N;R7aaJF]`MgalN71[J71kP8AoM6i/KWb4R81hLfacO8B<QX1kMg^4
T9BDS8AoP8NAU9B>Q7ikPhbDThR3NGQlQY2?R7ahMWN0R8b8PGQfNhB>UY27Ph20
Q8b@S8AkMWAnQXR6NGA/KW5gQ81hM6Q[LGV0Q8=kL7AkQ9>CSXMoOWn;V9RHTHR4
R8nHViB8P7]lP8R8R7maKVadO7n0Mg1WJG1hOgmlM6aXKgV0Q81hM6m_N86;Q7ik
M7V0Qhn?Q7ihOX29T8j;OWIgO8B7R8N0MW1hP8B4O7A`K6iiP8=oM75_L7^7ShV0
O7QhP8bCTHInN7R6S9BAR7mdM7^4RHV0MW1/Lgb6Qg]dK6adN8J7O7I_KWAlQXV7
O75`MWb<ShR1MW5fOhR;S8AhM7AhQhb9Q7akO86>U9BAQginP8R<S8R0N7QlPhb<
RH5hMg^4RI28PG]fN7n8R8R4MWAkOhJ<RhAlN7QoR8R<R7UgN7b9SX^;P7]gO8N<
ShN0N7AgP8R9PgUhLg5lQ8B1Mg5`M7R0R8AlMWIhOXR>SXV0O7b4RI6DRhAoOXB8
SXn<PG]nOXN9RHMiN7=hPhB8PgagM7V0R8n9PGmlOXR@Ui>8PgahOh64P7U^IfAV
KWIhL6QTH6A_Nh20NgQfNHB>Ti>AS8R<Ti^TXinDS8V<V9^GT8=nNGV6RHB0Lg1/
K7^1Pga`K6a^Mh63P7M/KW5kQhb9Q7UaMX28THn4OgMgPhb@RH5hKW1fP8V4OgI`
M7MnQhR3MW1cN8>8R8AkLGMnQXb<R7mhN7b8T92>PG]hN8>8S8R0MgAgN824P7]d
KWIlPHV<QgikOhRGUiJDR8B0Qi2DT8^4O7QhPHR8P7QcK71gPHAoN6i^Kg1kPGaf
K6a`M7UnOWQaKVafP8J6PH1gN829THn>QWj0P8N?ShV1OW]nQi2AS8R0O8>7Ri2>
R7miOXB8RHR3O7QgNhB8Q8AoM7QoPh^<Q8B1P8>8T9>@RHN8R8^CVHn;Qh>4R8n?
Rh1dM7IlPHR7OgQ`Lg^0QXAnN7AdN8>6Q8AhN7=dOh>8PGakM7QoPHN0Mg=`M7R1
QX1hLfm`N826PgmiMWQlPhN0NGA`LGR1Qh5kN7AcNh26RGmdLG=iP8B8PGUfLgj3
QhR6P7=dMWV3Q8AkM6i_N823PGafKVmdNh21O7M`L7R0QhR4P7]iP8R@THV6P7j4
Rhn>R81iNGUnR8b4PG]hNH27QhAoN7AcO821Q8=lNgUoR8b>RhN4OX67Ri28Og]k
O86<S8N0NgMnQ8V@ShMoOX27S8n?R81nP8J<U929PgalP8N9RHIoN7^1QhV9QWmh
N7^3R8>0NGIaN8B8RHJ0P7]lRi2DT8R4Oh>3S9B;Q7alP829ShV1N75fNh26Q85c
LGAcNgn0P7IaL75kP8B3O7QdN7b3RhAnNgQkP8N>R8J0O820Rhj9Qh1kO867RhR6
OW]iOhJ<S8B0N7InPHR9PGadL7AiP8=oN71`M7b4R8R3O7AhP8J7Qh1iM7=hO8J1
NGI/Kg5lPgilLfa`L7R3Q81gLG5aO8B6Q7UfLgInOX>1OWMhMgj4Q8R0O7QhP8B8
QXAkMg^0R8^<QganNhN@SiB<Q7aiPhN9RhB0N7AkPHJ8PgilM7B1R8J4P7adN8>6
SXV6Q7j1Ri>IVI><R8J6T9JCRh5lM7MhOXAkLf]XLG5kPh1iL7AiNH>8R8MlNH28
SY6@T8B3Qh^HVIBDRHB7R8bCT8QoN7AhP8B4OgQ_K7IhP7mhM6a`M7b8QXB3N7Ah
P8^9R85hM7QlQhR4P7agN869Shj8Q81lPh^>Rh>0N7MlOhV6P7mfMgIhOh1kLg1/
KWAhO7afLg5fNh68QhAnMgb7Ri6AT8R0OXB;Si29Q81lP8B8R8AlM7=gOWmlNg5Y
K71gOgilN71`KWR0NGihM75`P860Q7ahM7N1QX^8P85nO8N@Thb8PGR0PH^@T8Qn
MgIlR8n@Sh1kN7b6Rhj;P7UhNh28RHR0O7MhO826QWahMgV0Qh^8Q81hP8B6T8j;
QWn1Q8^;R8b4NGQoPhR9QXAlMWR1QXJ6P7QhMgR4QXB6OW]lOhB4S8InO7R4R8V>
QhIlO8J6T8^9QgUiO8J<R8InM6m`MW]lN75XJ6]`N7]lMfm^L7N0PhJ0MgQlPhbA
U8b6PHB<T9JHTH^1P8B;S8b8PGA`MWR0PG]fK6a^LG]oO7I`Kg1hP8>4OWQcNh66
T8V4OgQlO8B9R8=iN7MhPhR;Q7ahM7R0R8^4P7ikO7n7S8InMgIhNh28R7mdMW]l
PHR7PGQaN824S8j8PGUhPHR<RHR7Ngb0Q8^7Q85gLGIlQ8B0O7M_KgR4PH1oN7=c
NH68QgiiMgIoQ8b<Q7igNgn4R8N4OgIhOWn6Qh>0N7N0QhV<R8N0NhB8T9B@S81l
P8><T8^4O7AdO867R81hLGAlQ8^9Q7mhO868Ti6<Ph1lP8V;Thb0OW]lP8B9Q7ah
LgQlOhB4OWQdMgj3R8N0O7AhOh29Rh=lMWQkOhJ8QgafMg]oPHB4P7IdN827QhJ1
NGMhP8R8R8B0Ngb6RHj<Q85nO868SXR1OgQhNh>;QX=nN7QkR8V9QWahMg^4QXN8
P7QdNGn7ShR4OWQkPhR9R85kMgR0Qhb;Q7UdMW^3QhQnN7=`M7b1Q85gLg1dO824
PgadKgAhOX1lNg1/L7MnP81hLg1`MWmoP7aaL7AhOX>3NgQdMW^3R8N7OgUnQ8b@
THj6P820S92@THInOgj3R8j9P7idM7alP81hLG1_M7b0P7QgKg1iP8b<QX=oO8B<
U9V@S8B3RhbAV928Ph24QhV>RH=kMgj0PhR6PG]dNH>4R8N3NgAfO8R9R8AlM7Ah
PhR8Q7aiLGR6R8b8P7QfN829SXR4OgQlPhVAS8AlNgj0SY>>QWagO7j4R8V4MWAf
N826QX=nM75hP8N9QWahN7^4Rhb8Q7miP8N;TI28PGilQ8b<SXJ0N7N0QXb9Pg]d
MWR0Q8AlLg1`M7V0PgUaK71`N81oNgA`L7IoQ8N4NGAhO868S8b3Ngb0R8b?S8Qo
M7b0PhR6Pg]hMgR1Q8>1NgAcN7j1Q85kMWAhP8J8Qh5hMgb6Rhb?Q7ilO8V>Si28
PgUlQ8V@S8J1Ng]oQhj;Pg]dM7QlPHIkM7AdNgj0Q7mkLG=lO8B8P81cLgV0QhR;
Qh1kN8B>S92?R8>1RI2CT8b8Q823S8j8Q81iM7=lP7aiM6i/K7InO7]`L6m^OX69
Rh5oNgj7S9JCS8V0PhR<V9><Q7alOX66Ph=kL7AaN81oP7QcLGAoQ8N8O75aMh24
R8QnM75dOX>4Q7miLgV1Q8n<R81hNGj6RH^6N7IgN8B8QX=kLG=iOh>9Q7afLGAi
P8>1O71_L7R0Q8AkN7AdO8B@SXB4O7b7T9RFShR0PHJ>UiR@Qh60Q8V?U8^4NGMo
PHB8Q7adKgAiP7mlN71/KWB0Q81lM75aN827QWiiLG5lP8V;PGadM7QoR8b8PGQd
O8>;T8QnN7=gP8N<QX1dKg=dPHR6OgA`LGR4R8N0N7=cN8>8QX=hL7AhPHJ6Q7]g
NG^0R8R8O7QhNHB;SXV1NGMkP8J8RH=kN7R1Shj>Qh=oO8J;Si24OgUdNH>7R81g
LG1hO8>8OWQaKgMlQ8b8OgmlP8R?U92<Q7j1QhjASXIlN7^0Q8b9OgQdLg^0R8R1
NgAdNH>;S8N0O7R0R8bCT8AlOh64Ri>>Q81hNHB7RhQoNgAgO86;Qh5lMgUnQXj@
S85lP826S8^8OgAgO823Q85dKfiaNGn0OWI_L7IlQ8R6OgQgMh2;S8^4O7aiPHb@
T8MoNgb4RI>>R8AlN7b8R8J4NgA`M7b1Ph5iM75dO8>8Q7]dL7AkPHR8P7MdMgb1
RHR8NgAhO8B9T8J0O7MoQ8R9Q7afMgb1Rhb6OWMaM827RhR0N7=hOhJ;R81hLg5h
Oh>1OWAaLgR1QhB0NgMfNhJ7R8AkN7IkQ8R>Qh5iMh64S92;PgilNhJ<SXb8P7Ml
Q8R>RHAlMWIlR8j;RGihN7^9Shb;PGahOhR<T8V0NGQlP8b@RH1dL7AgOhJ4O7A`
Lgb0R8R0N71dO8J<R8InM7UoQ8b9PgmgMWJ0R8B1O7=`M7n7QXAlMgAhP8b@RH=o
O7b0S92<Q7iiO82<THn8OWUkOXR>SXMkMWIhP8R8PG]`LGIkQ8B4N6i_KWQoP8Il
M7AfO8B7QgmgLGInQh^<Q7ahN86<Shj8PgakPhV@T8J0NGIkQ8R8QgifLgAhP8Ai
M71XL7InQ81kLG1fMX68QX=lNgV1SYNDT8b1Qhn>U9JCR820OXJ8Q8=kMVmcO7b3
Ng1_JFihO7moMW1/M7^1S8R6P7QlPhbAU969Q8R9TiRDThR0Oh6<T8b7OWQcN824
Q81iLg5`NHB1PgafMWIlQXV;PgUiMgj7R8^4O7MdNH66Qh1hM7QoR8^>Rh1lO86<
T92<Q7alP8R<T8b4OgMgP8B8PGafKgMkP8R6OWAcMW^0QXJ0N7=`N829RHB0N7In
PhV9QgmgN7R0QXB1NG1_N7b4R81kKfmaNhR4Qh1cLG1hPhJ8O7A`KWR3QhR4NgAa
N8B8S8QnNGR0R8b@RH5nN7j8S8j;Og]fNh24R8=kNG=dP8>;Q7agL7MiP8R1O7I_
M7MoQhJ4O7AhNh>;RHR3NG^0Q8R8QgidN7R0S8V;Q7QfMgj6RHR6O7AdOXJ7RhAo
NGMlQY2DS8V6P8^AV9RDThB6R8jFUY66NgQhO8B6PGm`Jg1dO81nNg1/Kg1oQhB4
NGQhO8^<T8^1P7b0S92CRhAlO826T8n8P7QhN827R8InO7UnPHR>Rh5hN7alPhR8
PGUfN7j6R8V8OWQdNH>3QX=hM71fNgn7OWafLgaoR8b8QWilP8>9S8R1O7MiMh>8
Q85dM75dP861O7A`LGN0QhR1NgQfNHB8RhR0OWb0R92@QhB1O827S8b;P7MfMgn6
Q8IoN7IdO864PgidLGAgOh5lN7=_KgAkOWinL6a`KWb1P8=kM7AlPhR?ShMlO7n3
S92@S81nO829S8b8O7UdNhJ7RHAlN7IkQ8R;QgahMWR6R8n@Q81lOXB<T8b7P7Ql
Q8J<S8=iN7QlQhb8R7]gNGb8Sh^8P7aiO8^@S8UlMgQgOh>1OgA`L75hO81kM6m[
LGQlR85nNGMlP8R?T8b4Oh>7S9RFThUnP8>8RHb8OWQdN828R8B0M7AlP8R<R85k
Mg^1R8^7Pg]kO86<RhJ1O7MkPHR<Qh1lMWQlQ8b8OgUhN826Shn4P7QhO8>8Qh1l
M7=hOX64P7Q`L7=kP8>0N75[L7MlPH1iMg5dOh27R85nMgR1Q8^<QhAiNh64S8b8
QWUhOh66RhN0N7=kOXB7Q81fM7IlQXJ4OWM`Lg]oQhInMg=fNH28Qh5lMgAhP8N8
Q7ihM7R4S8n8Q7afN867RhV0O7QgP8J9Q81lLgIoPHj7P7agNH29S8V3O7QiO8N@
RHJ0NGb0R8n@S8IlOX28T8n>PgihMh64R8AiM71cN827R7afLG5lQhb<Q7akNH>8
T9N?R8>0QXjCU928P7anQ8^;Qh1hMWInPH>3O7A`M7n3R8R0Og]kQ8bAShR4O7^4
R8n@RHAoN7j0R8R0O7A`Mgb4QhIoMWIiP8b;QhAiMWR0QhB6O7AcL7QlOWiiLfU_
M7UoN7Q`K6m`O7n0O7=aLGIoQ8R6P7UgO8J;RhR1NGIkQ8V<RhAlNGb0QXb9P7]g
NGb1R8R6NGMhO8B8R8MiLgAgOh26QWUfLgR3Q8R8OgUdN8>4S8^0O7QkPHB9R85l
MWMnPhR7Q81hMh26RhN4OWAfNH29PgmnMgAhP8V9R8=lOh26Si2>QX20PhN<T8j3
NgQkOhR>R81dL7AhP821OW5_LGIoQ8B1O7MdOXB<SX^7P7n0RI2DT8R4P826S92<
Q7mlO7j4RHQoN7AdNH24QWmlM7AlQXR6Q7ihMg^4S8j8P7ilOXR<S8V3P7j1R8jC
SXJ0O866RHn;Q7mhO868S8R4OgAfOhB7Q7mdL71aO81nNg5_KgAoP8R3N7QdN824
R8R1NgQnQXR?RhB0NGQoR8V9Q7]gM7UoQ8B0N71cMW^0PGifLg1dOh66PgahLgQl
Q8N4P7MdMgn0PhAlN7=dNh64Q7mhM7IlQ8R7P7ihN7b4S8b4O7IfN828R85lM7Ai
O8B7PGafMgUlQ8B7PgAfN7b4QXR3N7MhOhN8R8AnN7R1R8j@RHAoOX>8TI2?R7mn
P8N@S8b6P7aiP8>3PgQcL75hO7mlM6i[K7AlP7iiMgAgP8R>T8b9Q8R9T9RGTHb8
PhB8S929PGmlNGn0Qh5kMW=hNGn8P7afM7QlQX^8R85lOhN;SXj6PGaiOXB;R8Ai
N7QkPhN9Ph1lN7j1R8j8PH1lOXB;SX^3NgUlPHR?QgmkL7AgNHB0O75YKg1hPGil
M6a`Lgj4Qh=nNgQlQ8^;RH=nP7n7T8n;PG]hO826R8InNGMgOhJ9Qh5iMg^0QX^9
Q7ikN868S8b4O7MhO826Q81hM7=dO864P7QdMWInPhN3O7MfMgj3QXInNGQdO826
Q7aiM7=hOX>3OWMdM7MlQ8R1O7afN864RhR1O7UnPhV<RHAoNGb4R8b<QgihP8B8
RhV7P7]lPHV>S8R3OgaoS929RhB1O7R3Q8R4NgUdM7^0PgidMWAhP8>8QWmlNh27
S9>CR8>1QX^@U9J>QhR8S8b>THR0NgV0P8>1OgUdL7=hOX=nN7I`LgV0Q860Mg5i
NGb7Q81iLGMlQ8J1Q7]dLg^4Q8J4OWUiNh28R8B4O7QlPHV8Q81iO7aoR8R7Q7ai
Ngn6RhR1NG]lO8J9R8AlN7alQhV9QgalNGn7RHn9PgahNH29QhIoN7QhPHB8QWih
MgQlPHB4OWUdMgn3Q8B0MW5hN827Q81hM7IkOX>4OgIgMgN0PhB3NgQcNH20R8Al
O7IiPHJ;Q81iMg]nQ8^8OW]hMh23R8N1O7AlP86<R8V1N7]lQ8R8QgagM7R0Q8J4
P7UhNH68RH^4P7n0RI2>ShR3OX28R8R;PgafMWj0Ph5lMVi^M7^0P7UdKfidN824
OWihMgj4S8j<QhB6R8nFViB?R8B7S9BDT8V4O7b1R8b9PgmhN7R0R8J0MgAfN828
Qh=iM7QiP8V<QgmiMg^0QhV6OWQgM7V4R8AoN7QiO8>7R81hO7V0QhR>QgiiNgn3
R8V1O7QdN7b1PgigLGAcNH61P7]cMWAhP8>4O7QgN7n4R8^6OWakP8R8RHB0O7Ql
Q8N8P7agMW^0QXV1NgQdMh23QXAiM7AgP7n4PGUhL7R1PHJ4P7ahNh67RHR1OWQh
PHR;RH5lMgR0QXj>QhAoOhB>U9B@RHB4Qhb@THR0O7QfNh=nNGI_J6adNgmiMWAc
M7V6RHN4P824Qi2HUiB>Qh^9TiRHU8V1NgV0Q8AnM71YJG1hO7I`K6U/M7j4Pgah
M7IiPH^9PG]dMWb4RhN4OWIdN868Qh1kM75dOXR8QX1iO86<TiBARHB0Q8V<Shb8
OWQoPhR9R8AnN7b4Rh^9QhB0O8B>Shb7P7alPhN8R81lMW=iP81oNgA_KW5gOWai
M6m/K7MoP81iMg=fOhB;RH1oNg^6S9>DSXR0P8B9THn8Q7]lO829QhIoN7aoQ8V<
RH1iNGR0QhN8P7QgN8>6QhR0O7=dO7b0O7QdK6icNH1oO7QfN7n9S8j<QXJ4QXb@
T8b8Q7j0Q8b@R8QoO7anQ8>0NG1`K6mhO7ahLg5^Lgb0Qh=oOWj0Qh^<S8B0O828
S8n<R8AnP8B8S8J0N7=dNh23PGQaJf]cNh20NgMfMWb1RHb3Og]kP8B;RhR0N7an
PHN8Q7UdLGAkO7alM71_M7j1Q860MgAhP8B;RhB0N7R0R8j>R7mlO7j8SY2;PGih
PHJ9T8QoN7MkP8N;R81hMgb0Q8R8Q7ahO8>4Q8J3OWQiPhR9R8AoMgMkP8N1Ogaf
N7R3RHR4NgUgN868RH>0Ng^0Pi2>RHAkOWb0QXR<PginO8B9S8V8OWUkP8B4Q81k
N7MiOX20NGIcL7MnP860N75dO7b7RHJ1NG^0Q8^>S8R0Ngb1QhN6Pg]hNGn6R8N0
NgMdNh67Q7ahLg1aO8B4OgUfMWQlQXb8P7akO8><T8b8P7n0PHV?RHN0Ngj0Q8R4
OgQaLG=nPGmlN7AcM7b4R8IlNGQhPHJ<S8N0Oh67RI2@R8=oPhN<T928OgQiP8B8
QWmgLG5dO864P7AdMWV0Q8R6OWUgO8B9SX^4O7MlQ8R<S8=lMg^0QY2<Qh1iPHB9
TI><PGb0Q8V<RhQlM7MnPhN4PGQ_LGAlQX=oN6i[LGV0P7mhLG5fOXJ;Q81iMgan
RHV7Q7MgN7b8RHb4O7iiP8V;RhB0Ng^0Q8^;PGUdM7UlQ8N3Ng=dN827RHIkN7Id
OX24QW]iMWR3Qh^;Q81nOhB9S8^1OgQhNh26Q7mhMWAhOhB8P7adM7V0R8V4O7Md
M7UoQ8=oNgQhP8J;R81oN7^0Q8V6P7agNGb1RHR8Q7anP8^CT8b8OgioQXn9QWif
MWAhPh5lN6m/KW=lP81lLG5fN869S8V0OX27S92AS8N0PHB9SX^9PGQhO8>7R8Al
MW5dOXN7Q7ihN7V0RHV;P7anO8B<S8^6Ng]nPHR8S85lNgQoQ8J;Q7UiNgn4QhJ4
OWAdN864QXAoNG=gOXB8PGmkMWIhPhR1O7UhMgR1R8B0NGMgNH24R85hN7MhPHR<
R7ilNGn6R92;Q7mhP8N8S8R1NGAlP8N<Qh5nNH24RHn8PGafMgV0QhInMW=gN7b4
Ph1dL7=fOXB7PGafLgR1R8V8Q7aiO7j7R8N1N7QhO828R81lM7UoP8V;R7mhN7j3
QXV7OWQfNh24R8>0NGMlP8V<Q8=lN7n3S8n;R85oP8B>T96?Q863R8bASX^6NGMo
Q8R6P7QcKg1hP7akM71/KWQoP7mgL71aNhR8Qh1lN7J3RHb9Q81kNH29Shb4Pgik
OXB<R85lNgQiP8N9PG]hN7b0Q8R7O7QfN867S8MoO7MhOhJ<RH5lNGb1Q8V9Q7mg
N864R8MoO7IdOX28Q81lM7IkPhV9R7ihN7R0R8R7P7]iOX66RhR0OWakQ8R9S8Qo
N7^0Qh^8Ph1iN7n4RHV4OWUfNh>7R8=oN7AhO8B6P7ihLGQoQ8B3O7AdMWR0Pgmk
MW5dN7n3PgidLFifP8B4P7UaL7=lR8R4OgQhNh28S8InN7IhPHR<Qh1lO821RHn;
Q7agNGj4RHV4NgIlOX69S8MkNgmoQ8R8QWigNh24R8V8P7akOXJ8RHj4OWalPhR;
QXAkLgJ1R8J6OWQ`K7AoPgmkLfm^M828RHIoNG]oQXj>S8MoP8>7T92>R864QhnD
U9>8P7moQXb@S8AlN7aoQXb;R81iOh28SXb9PG]iOXB8R8IlM7IgO864Og]hM7Qo
Ph>1OWA`MW^0Q7mkMW1aM7b3OWadLgIhP8N4PGUfNgb1QhJ3O7MhO8B<S8R3NgQl
Q8b<RH=kNGQoR8V9OgQhN7b1R8J3N7MoP8J?S8QoMgUoQ8N4PgU`LgJ3Q823O7Id
Mgb3Q81nN7=cO823PgafM7AlPhJ7P7UfM7^1R8^1OW]gOhB8S8B3O7MnP8J<QWmh
N7UoQhJ3OWIaN7j3RHN0O7MiPhb@S8V4P8R8TibCTHJ0Q8>>T92<PGaoOhN9RhIl
MW=dOX1oO7M`L7AhOhAoNgAcMW^1Q8B0NGMhO8B6Q81iM7AhO821OWMdM7IlQ8An
O7]kOh>8R85iMWUkOhN8QX5kNGb3Rhb@R85lO8B<SXb8PGanOhR<SXR3P7b0Q8J8
P7ahMgb0R8R3O7AcMgb3QX1nM71cM7^1O7QdL71hP81nP7QcN7V1QhJ3O7UgNHN9
R8UoNGalQXj?Rh>0OX29T9B>Q820PHN>T8b4NGQlP8J7RGmdM7=lQXJ6P7adLgj0
QXR1OgaiP8N>SXR6P7b4Rhj>RHAlNGb0RHR7Q7agNH66QhN0N7QfNhN7R8IlNgQn
QXR;Q7akN828S8b8PGahNh66RHAkN7AhOX>6PG]cL7AlPhN4OgA`MWQoP8>0MgQf
OXJ1R8=iN7AoQ8R<PH=iM7b3R8b7OWQiNh29S8QoN7IhOhB;R85lO7j4Rh^9QW]h
NH29RhV4O7QdOXJ8RhAiM7QkQ8n<QWagM7b8Ri2>Q7UhOXB7SXV4P7]nPHV<R8Il
NGanQhV6P7QgN7N0Q85nLfmdNGj3Q8AnMgQoQXN8QgalN7^8RH^4OgihOXB4RhAl
O7MlP8B;Qh5hMgQkPhJ7P7ahM7b4Q8J0N7QdN7b3R81hM75hOX24P7agLGR0PhR6
P7QdN7j4R8R4O7QkOhJ>QXJ1Ng]oR8V9R7ilO7b4R8^7P7iiOX27S8AoO7MkQ8V<
S8R0Ngj4R8b8Ph1fMgaoQX1hLg5dM7b4Ph1iMWIlP8R9PGmhNh20S8b7PgakO828
R8N3Ng]lP8R7QX1hN7QoQ8N6PGahN7j3R8R1O7QhO826R8AnNgQlP8B8QgifMg^0
PhB4OWQgNHB;RHV4OgQkPHV>R8AoNgV0Qhb<QX1nO7n7S8^4OganOX>8QWihM7Ik
P8J6P7QdM7QlQXB0OWIhO8>8R8QlNGMhPhJ8Q81nMg]nQ8b8PgilO827Rh^6P7ak
NH67QXAiMgIcN7j3PG]dM7AhO7n3NGIfMWaoP8>1N7AgN7n1PHAnN7QlP8>4Pgmh
N7j8R8V7OgQhN828R8J0O7AhPhR<RHAnO7j3SY><Rh>1Q8R?Si6@QX61Q8^;RHMn
O7UlQ8J6QWigLgAlP8N0O7I`N7^4Ph>3MgIfNhB4QX1hM7AiP8B3P7afMgj4R8N7
P7alOXJ<RHB0Ng]nQ8^<QgmoNgb0RHj8PGakOh68R8AlM7AcN823QWahMgAnPh^9
PGmhNGV1R8R6O7QhNh67RHAlMWAhP8J;R81hMgUoQXV6P7M`Mgb1Q8B4NgAhNH>4
P85lLgQnQ8N8PgQhN7R1QXN6P7alPhR;S8V0Ogb0QhV;RHAoO7n1PHR4OWahN7n1
Q8B0N7AiN7n4Q81lMgAiP866PGaiMWQnQ8N3O7QhN7^3Ph5nMgAgNH66Q81hN7]n
Qhb<R81lO7b4QhR8OWakO8B7R8J3NgR0QXN<RH1iN7]nQX^4Q7afNh29R8R8NgQh
O8R8R8=lO7QlQXj;PgmlO868T968P7moOXR>SXQoNg]oPhN;PgaiM7UoPHN0Og]h
O828S8B4OWalOhJ8QhInO7alQ8J6Q7]iN7j6Qh^7P81lPhJ8RH=nM7AlOhR8Q7ad
M7AlQ8B3O7AcNH>8R8MoNGIhOhB<RH=oNgQiPhR4P7UhMgQoQ8B0N7AdM7b0Ph=l
MWAhNgn6Q85lOWj1RHb<R81oP8B8RHV6OW]hO8J7Q8AoNGUkQ8R6Q7iiN7^1QXJ3
P7ahN828R8J3O7MfO8>4Q7mkN7MnQ8^4OgigMgaoQ8R0O7]hN823PhAlN7QhOWn6
Q81lMW^0Q8N8PGalO8B;Rh^4Og]kOhN>RHB0O7b0QXV?R7ikO7b4R8V8P7UhO867
R8N0Og]lPhN9Q7alN7QlPh^4OgahNGb3R8IoN7AhO868RHMkNgn0QXb?R8=iNH24
R8B8P7QhNHB7QXN0NGIiP8B6PgakMWR0Q8V8PGiiN7b1R8N3OWaiP8B8S8IlN7Mk
PHR9Q7agMgQnQXB0O7AhNGb7Q85oMgMdOXN8Rh1nOgb0R8j9P7aiN7b4RhR0MgQf
N7b0QWmgMW=kO824PgidMgUoQ8N9P7alO8N6RHb3P7]oQ8B9R8=kN7]lPhR7PGah
N7]oQ8N3NgIgO827R8AoNGQnPHR>S8IoP8>4S8R7QWilP8>9R8J4O7MhOXR4PhAk
O7]lRHV;R81lNH27RhN1O7]hN7j3Qh5hMgAhOh>6QWmhMWQoPHR8Q81kO8>4R8R3
OWUiO821OgigLG5dO81oNGA`L7=kP7moN7=fMgb4R8R0N7UnQ8J4Qh5hNg^1QhB6
QWihO8>6R8N4PGalPHV<R8R1O7b0Q8V9P863O7j3R8N3OgUkN7b4Q8=lN7QgO7j1
P7IcKg1gO820O7MaN7^0QXJ0O7QhO8B8R8AlNganPHB3P7agNGb0PhB1O7QfO827
RhN6OgaoP8b?R8R0Oh21R8b<Q7inOh28SXb8P7j0P8B?S8J0O7anR8^9Rh1hN7V1
QhV8PG]gN7b4R8R0N7AcNhB7QX5lMgQkQ8b8P81iO8B8TI28Q7b1P8JAT8^0O7mo
OhJ7PgahN7R0Q8R7NgMdMWb0R8AlN71dNgn6Q7iiM7IkO8B3P7]dN7V0QX>0OWMd
Nh24Q8>0N7IkOhB8Q8=nN7b0PhJ6P7QfN7^0Q8B0O7AdNGb4Q81lM7AkP8R7Qh=h
Ngj1QhR4P7akOX69SX^4OWQiP8R9R8AiM7MhPHB3P7]dLGR1R8V4OWalOhJ<S8N0
MgQlO8J8PGikNGV1PhB7PH1lOhB8S8b8Pgb0Q8V>RHJ3O7b6RH^<R81oO7n4R8^1
OWUdO8>6RHInOWUlQXR<Rh1oNGb1PhV8P7adO824R8B0O7QiO8J9RH=iNGanQXb<
QWahNG^0Q8J4O7IgNH61Q8IlN7IhP8>7Q7mkN7^0Q8N9Q7]lO8>7Qhb4O7QgOX27
R8=lMgMlP8B3PgigMWR0QhJ4OgQfNGj6RhIoMgMiO8B7R8AkN7QoPhR<PgihNh23
R8N4OgQhN827Q85nN7QkPhR7PgahMWb3QXb4OWafNh64R8B1O7AkOhB9QhAoN7Uo
Q8b7P7idMgUnQ8B1NGIfMgb6QWmlL7=gNh>4QX1iN7V0P8R7OgagNh24RHR8PG]l
P8R<S8V0O7]nPhN8Q7ahNG^0QhN3OgUiO824Q8B3NgaoOhN8Q7ahNgV1Q8J4P7Ug
OXB9RHR4OWaiPHb>R8B0Ogb0Q8^;Ph>0Oh27SXb8Qh20Q8N<RhR3O7UkPhB4R8=i
NGR0Q8R4P7ifLGR0P85lMgM`M7b1P7ahM71fNH23P7ihMgV0R8R4O7MhNGn8S8R0
O7alOhJ9QWadLGAhOh>0Ng=cMWQlPh>0MgAhN7n4QhJ0Ng^0R8R<S8J0OX27S8b7
P7alO868RhB0O7QhO863Q81hN7AhPHJ6P7iiN7b1Q8R6O7aiO8>4R8N0O7]nPhN8
QhAoN7j3QXn9Q81lNh26R8^3OgalPHR;S8R0OWb3Q8J<QX=nNh24Rhb7Q81iOhB;
RHJ3N7UkP8J3PGihN7R0Q8J3PGafN7n4R8R3O7]gNh61P81kMWAiPHN7O7]hM7^0
Q8R3OW]hN868RHB0O7QlP8>9QgmlMWUnOh>4P7UcMgb1R8=lOW=aN8>8QX=kM7=h
P8J4Pg]gMgMnQXJ3OWQdN7j1R8N0O7MkP8R<RHN0O7]oQhV<R81nN7b6R8b6PG]h
OXB;ShV4O7QlP8R9R8AlNGV3R8V9P7moO869SXR3O7]lOXB4R81hNGQlP8B;PgQi
NGb4R8R4NgakO8>3R8MlNGMlP824PgUcL7=iO863O7QdMgn6R8B6P7QlPHN<R8J1
MgAkP8B4Q81hM7AlR8R8S8AnPHB9RHN4O7QdNGmlNgI`K6a^M7]fL6a/K75lOh5k
MWIfO8B;ShR3P866R92HU928R8b@U9JFRHB0OhR9S8^4O7QhOhB6Q8=nMW5hO7n1
NGAcK7AfN7afM6a/MgAoP7]kLgAhP8N8Qh=lNh27Si>DSX^7QXjAUYB;Qgj0Q8J?
RhQoNG]oR8b>S8B0Ogn;U96?Q7inOh68S8QoNG]hOhN4Q7idMgMlPH>1Ng5`L7Qo
Ph=lMg5aN8B8Qh=hMWAfPHR9QX1kMgb6RH^7PgakP8>8R8AlLGAiP8B4R7mhMgR3
QXR8OgAcLgQlO7mhMW1_MWUoP7agLGAhO864P7aiO7j4S8j>Qh21Q8R@U928Q7al
P8B8QWmhLg5cNgmiNgA_L7AlOX60MgAfMh24Q8^3P7anS8R8S81oN7J1R8R6PGik
N868RHb4OgaiO8B7R85kO7b4R8^<Qh=kNh>8RhV9Pg]nOhR>RhR1O7QlPHR<Q7ak
MWR0Q8R8OgQcM7aoQhR0P7]hOhB<Rh=lNGQlP8B8Q7UcLgQlPhJ3O7AhO867RHb3
O7anQh^8QX1lMgN1Q8R9P7ahN7b1R8R3OgIdO7b7Q81nMWQnQ8b9RhAlNgj4R8b<
QX1nP8>;ShJ4PGanQ8V<RhAkMgQlQ8N4PG]cMWn1QhR1OWMdNh21QX=nNgUoPhR8
Q85hMgaoPH>3O7AdMg^3QhN1O7UhP8B8R8B3O7b0R8b6R8IkOgj0SXR1OWQkMWb8
Q8=kM7MhOh>3QW]cMWAlP827OWQdMWn0Q8MlNgUgO8>4QX1lMWAnOhB7P81iN824
QXR1OgagNh24R8B3P7inQ8V?Rh>0NgR0Q8N6OgahN7j1RhN1P7QgNh>6Q81hN7Mg
OhB3OgUfMWInP8B1N7QgN821RH^4OWaoPhJ<R8J0NGb4QhN8Q7ahN821QXR7PGai
P8R8SXb0NgV0Q8^>S8AlNGn4Q8R8PGQdNGn1Q8B4NgQhO8N8Q8B0O7V0Rh^8R7mk
O7n4RHj7OgUfNH24R8AoMWAgO8B8R8=lN7R3Q8b>Ph1hN7n4S8N0OWQfO868R85k
N7IhOh>3P7IcLgV0PhJ1N7IaMWn1Qh1iMWAhO8J8PGahMgMlQhn9PGmhN7b0R8V0
NGAdNh27R8IlN7UlQXR<RH1lNgn4RHb@QgaiO8N9SXj7P7]iPhR<RH=nN7QlQ8J7
Q7QhO828SXb3O7UiP8VASXN0NGQhPhV8Q7]hN7j3R8b7P7]hPH68S8B3N75lO826
PH1gLGAkP824P7UdLGQlPh=nO7IcN7n4Qh60O7]oP8^>RhQoOX27SY2;QWahNgj6
R8N1NGMgNh24QX5hLgMkQ8R4Q81hN7^3RHR6OgQdMh>4PhIoMWMiP8J8QX1oMgN0
Q8R4PGmgM7^3R8R4P7miO867RhIoNgUnP8N<QWilMgV0PHB4P7QdN7^1Qh=lN7Ad
NGn4PgahLg1fOh24P7MhN7b3R8V1P7QlPhB<S8^4P8>1RHb<T8B3P8><SY2>Qh1l
O824R8R0O7QdNGn1P7]gLGAhNh21P7]dMWalPhB0OgQgOhB8R8IoN7IlPhR9RHAn
N827RHn<QWmiNh66Q8B0NgAfOX23PGaiM7=iOh23O7QdLgQlPginO7A`Mgb4Q85n
N7]kPHN8RHAoO7b0QXV8Q7ihNgn3R8R4PGakO8>8RhV0O7alQ8R;RH1hN7]lQ8R8
PgQfN7n4Q8R3O7MiP8J9R8AnMgIkQ8R6Q81lO827Rh^8Pgn0P8^@S8^4OWiiQ8R4
Q7akNg^0Q8R0Ng]kN7b3PhAlM7AhO7n4PgmgM7AlOh21OWUdMgb0R8R4OgIhO867
R8R1OW]iQ8R8QhInMgV0R8b7PgilN7n;T8j7Q7ilQ8b?RHR3NgQlQ8R;QWmiN7^3
R8^4OWQfMgn6R8=iN7AhOX28QgmfMWQiOX61O7QdM7]oPhB0N7IiNH66Q85hM7Mi
P8N;R7ahOX26RI2<P81nPhR8Shb8P7^0P8>;QXAoM7UlQ8B6R7alNG^6Qh^6Og]f
Ogn0Qh1iM75gN7j3P7]gMgIiQ8B1P7]gMgj6R8IlO7QfO8>;S8InOgj0Qhj<QX=h
O8B6Rh^8PH1oPH^<RhR4Og]oQhV>RH60N7^0Q8^4PgadNGb1QX>4P7QhPHR<S8B1
O7j0Q8b9Q7mnO7n4RhR4OgIgOX67Qh1iMW=gO7n0OgQdLgIlP8>0OWaiO7n4S8b7
P81lP8B8RhAoN7UlOXJ7P7agM7]lP8R4OWMdMW^0Q85lMW5cMh23P7igLGAiOXB8
Q7UgNGj6Rh^9Q7UkQ8R<SXb4OginQhj8R8=lNgV0Q8J7OWQgM7b3Ph5nN7=dN821
QWigN7=iPh>6P7QgM7^1Q8J1O7UdN7n1PgakN7AlP864Q7miNgV0R8V8PG]hO7io
Q8AnNgAkPH27Q8>0Mg^0PhN8Q81hN7n3R8J7QWmnOhB<S8b8PgmlPhJ8R81nMgb0
PHN4OgQdMgV1PH>1NgQhNH24QX1lN7QkOhJ8Q7aiO7b1QhR6P7UiP8B9S8R6P7an
Q8V9R8AlN7anQXR4Q7afO824R8V4OgalOhN<R8N0Mgb0Phb8Q8=kN7V0R8V8PGal
O7n7S8^6PH20PhR<RhB0OX1oQXR6QWUiOW^0PhN6NGMhN7^0Ph1kMgAgP823QWig
MgQlQ8N3P7UgN7V3QhJ3NG]iNhB8RhB0PH23R8R8QgmgN7^0P8B4NgQfN7anP85h
M6maNGb4OgahL7IiOhN7Q7iiNg^3R8R8P7]iNgn8RHJ4O7]nQ8R;R860O7j4RHV6
P7akO7b6S8N1P7anP8J>RhAnO7anQ8R7R7ihNg]oQ8B0O7]kOXN8R8^3P820Q8R;
RHAlOWmnQXB3OWQiNgmoP85lMgMfO7j0P7QgM7QoOXN4P7afN7UkQ860NG5hNGb6
Ph20N7QoQXb;S8MnP7j4RHR8PgUiNh28RHV4P7akQ8V;RHMoNG]lQXV8PGikN7b1
R8V1O7IhO8>8R8J0N7QlQ8J6R81kN7R1Ph>1NgUdMgj1Q8B1O7QhO8B9R8B0NgQg
PHJ4P7alN7]lQ8N0O7]lO7j7RHV0NGQlOX29R8>0N7b1PhR6PGadN7]lQhN1OgQi
Ogn4Q81lM7IiOh60Q81iO7n1S8R3P7mkNH24QhInN7QfN823Q81hMgQnP8B8Pgmk
NH24R8N4PG]gO867QX61OginQ8R9Q81lNgb0R8R4P7ahNGb3R8=oOWalP8>8Qh1l
NgalPHN8QX1iO860R8N6PGUoPHB8R8R4P7mnQhR6R8B1O7j8QhR8P7mhNgb3R863
O7QlOX>6Q81nM7IlOXB3Q7ihNGR0QhB7P7]hNh24Q8=iN7AdO8>8Q85oNGn1R8R7
PGUhMgb1QhB0O7UiO8B8S8IoOgaoQXR<QX20NGn4RI6;Ph1oP867RhN3P7UlPHB8
Q7iiN7QkOhB4PGiiNgb1Q8N1OWUgOh>8R860MgQoOX>4OgUdM7MhP820OWAcMgb0
PhB0O7QiOX64Q8AlN7alQXN4PgmlMW^1P8B1O7QhO7n4Q8B0Ng]oPHN?RH20Ogn4
SXb@R820P867S8^4O7akO8B4R8AiNGQlQ8N8QX5lNgb1QhR1O7QdM7^1PGmhMgId
N7b3P7ilN7ilP8N3PGQiO7b1PH20NGAdNH24Ph=lNGakR8b;Rh61P86;RHR9Q7ml
PHR9S8R3O7QlPh>4Q7iiM7QnOhB3O7adN7b0Q820NgIkNgb1PH1hMgMgOh23P7ah
N7b0P8B3PgiiOh67RhN4Og]kNh66Q8=hNGUlQ8B;QgikMgj0Q8R4Q7]hNgj4PhAo
NGalP8>6Qh5lO7j4RHb?R8B0Ph^>T8b8P7ioP8N8QXAnNGQlQ8>4PGilN7b6QhJ6
Ogn0PHB;S8R4O820P8V4PgmfLGQlP8B1P7MfNgR4PH23N7IlOX24QhAoO7^1QhJ7
Qh=nNgn3QXB0Og]iO7b3Ph1nNGaiOX>0P7agM7QoP820O7MgN7^3Q821O7]lOXJ6
P81iNG]nQ8B3P7iiN7n4RHV4OWalNh>8RHN0NG]lOXR9R8AnOWj4R8^>R85lOX28
R8N7OWMhO7j4R8=oNGQiP8B3Q7mfN7]oPHB1NGMfM7b1PHAoN7MgNgn1P7UhMgQn
PHB6P7mlNgn4S8b6PGmlO86;S8R4Ogn0PHJ9RH1lOgj0P8B6P7UkP8B3Q8N4OWMg
PhJ1Q81kMW=iPH1nNgQfL7MnP81lNgUgNh23Q81lOWUnP8>8QX5lNGb0QXR8Q820
Oh26R8V4PH1oP8B9RHB3O7]nP8J8QX1hN7V0Q8B7QWiiO868S8^6PgikQ8R;R81n
NGIgP8N0N7alMgj3RHR1O7QoOh6;QhIoN7alPhB9QgUiN7R0Q8N6OgagO8B3RhR4
P7R0PHB7Q8AlMW]nPHJ7Q7mlO7n4RHB3Ng=hO8>4QhInNGUiP8N4Ph1hMgQlPHR3
OWUkO7n7R8R0N7alOWn4Q7ahN7R0P8B8OgQhN7j4R8R8P7UoPhB8RhN0OWanQ8R8
R81oN7b1QX^4Qh5lP8>8R8B3OWAfN7n0Og]hM75gOX61OWadM7^0QXB4P7anO8B<
S8j<R821R8R;R7mnOWUiP8=nN7QgM7^0PhInNGIdNgn1Q7]hMg5kP820NG]iM7Qn
PhAoOWiiP828S8B3O7b0P8R8QXB0Ngj4R8b<QX21P828T8j9R863Q8V;RhR1O7ao
PHN<R8B1N826RHb7PgagNgQoQgmlMgAhM7b1Q81gLgQiOX>4P81lO821R8N3OWAh
NGj3Ph5hM7AfO821Q7]hN7QoQXR6O7ihMh20PH5nMgAdN821P7afLG1kO820O7]d
LGAnP81oN7IdMgb1QX=nNgAgP867R8AlNg]lPhR7Q81iNH23QhR0O7aiOh>8R8R4
Oh26S8n?SXV6Q8V@Ti6>RHJ1PhV@SXR8Q7anOh>8PGilMgMiP8B4OgalP823S8R4
Q7aoPH><R8B1NgUkP8B4OgahMWQkPhB3P7anP8B;T8b7P823PhR<RHIlN7aoPHN7
Q7QhOWb1R8IoNgQfNgn0Ph1lN7alPHN8QWahN7UnQ8N6P7QgO7moQXB0NgMlO864
Q81hNganPHB4PG]gMg]oP85oNGAdMWV3P820N7QkP8B9R85nOW]oRHV9R7mlO866
Q8J3O7UhP8B4QWmhN7AlQ8J7PGaiN7^0Q8V4P7mhO826QXB0OX1nOXJ8R7mlO7^0
Q8V9PGihO7n0R8B4OgUnOhB8R8AlNgQhQ8N8QgilNGb0PhB4P7UhN7j4Q8AnN7Qc
Nh23Q7aiN7UlPhR7P7akNGn8S8b8Ph20OhR>SXb8Q820Ri6@THJ0Ogj0Q8j<Q7ml
Ngb3QXN1N7]hO823QX1hMgAlP823O7MdM7QoPH=nNgIfNgj3R8InNGQlP867Qh=l
Ngn4QhV;QhB0P8B7R8B3O7UkNh26PgahL75gNh20O7QdMgUoPh20NGQgNGn4R85o
N7MhO8B4Q7ikN7QoQ8^;PgihO824S8N4OgMgP8J8R8N1O7b1QX^9Q81kN7b3R8N0
O7QhN7n7QXB0MgAgNGn4Q7ikNgUoQ8B8Q7alO826RhR4P7UhO8B6R8IlNgQlP8B8
Q7mlNgQlP8B4O7]hN8>4QhV3O7]kP8B8R8AlMgj1R8b9RhAlOh>9S8R9Pg]lP8R<
R8J0O7QiP8N8PgahMgQlPHJ6Og]lN7b3Q8B0N7QhOh64PgahM7IhP8B7PgaiLgb1
Q8J4OgakNHB9RHR1P7QhP8J6Q7aiMgAiP8J3O7U`LgV0QXR3OgUkOhJ<QhN0Ngao
Q8R8Q7]fM7AlP8=oMg=aM7QoPgilLg=lO8B8R8IlOgn7T8n@ShB3Q8V@T8n9P7]h
O8B7R8AoOWb0R8R9R85lO7b4Q8>0O7MdMWMkP81kN7AcN7b0Q8=iMgQlPhR8QX1i
NG^0RHJ8Q7ilO8N?S8j7Oh20QXj>S8AoNGR0PHB3O7UdMgb4R8B4NGQiO8>7S8Il
NgUlQXN<QWahMWb0Q8N4OWAdNGb4R8AoN7QhNhB4QX1gLgAlPH63OgQdM7N0Ph61
NGaiOXJ6RHAnP7UoQ8b9PgaiMWV1R8b6O7QhO824S8J0NgIlP8B7Q81lMgV0Q8V3
Q7adP7n7S8J7P7aoP8^<S8R0O7anQ8j>R8=lN7^1QXJ8P7UgN7b0Q8B0NgMkO868
R8=lO7b0QX^;QWmlNgV0R8R8P7]kNH27R8IoO7]lQ8R<Qh=nN7n3QhV3O7UhN7n6
QhR1N7IhO8>8Q8=lM7IgP8J3PgQgMWR0PHB3MgAdMh27QhMlN7IgP8B6QWahN7Qo
QXR6O7I`M7MlPhR0NGalQ8R<ShR4O7b4R92?RHR1P826T8j9QWikO7n7QhR4O7]h
O860P7agLG5gO81lO7QaM7b3R8N8PGilOXR;RHQoNGMhP8N8QWilNG]oQ8R7P7]h
N7b4QhN0O7aiOh6;RH5oN7alP8R7PgQfMWAoQ8AnNGM`N7j1R8AnN7QlP8R9R8An
MWR0RH^9R7mlOX>;QhJ3NG]hNHB3PgmgN7AhQ8B6Q7iiN7j1Qhb7OgahN826R8=o
NgQiP8R9RH=lOX26RHn<QWioP8>9SXj6PGmkPhB8R85lM7AhOXB4P7adLGQlP8J1
O7MdOWn8RhB3N7MkP8R8RHIhN7QkP8B6Q7agMWb4R8N7OWMgNH64QhAnN7QiP8B4
QWaiMgN0Q8R4P7]gNGj4R8R1O7aiP8B;S8MnN7QhOhR9RHAnO824QXV<PGaiNH64
QhR1O7QgOhN<R8=nN7R1Q8R8OgUcM7UnQ8B3O7AgNGb6Q7alM7=iP8B4Q81iNGb0
R8N6P7UhN7n8S8R4O7]hOXR;RhJ0Ng]oQXV9Q7ilNGb1QhV3O7QhO7n4Q85iM7Mh
P8B7RGiiNG^4RHn<PgmhNhB4S8^4O7QiP8N9R81hMWQlQ8^6Ph1kOXB6S8j;QWan
PhN;RhV3OWUkQ8^8Q8B0O7b4QhR8P7UhMWV1Ph20O7AdN7b3P7ihN7AgOh>4P7ii
M7AlP8>1N7QgNGb3QX>0NgAiO829R8>0O7j1Q8V9R85iP8>8T8j>QX>0Q8V;SXR3
Ogb0PHN8Q7mhNgn1R8R3OgIaMgb4Q8B1M7MhO8J8Q81lMWMnQhN4P7MfMgN1Q8Ao
M7A_M7aoPGahL71cN8B7Q7aiO7b3R8^7PgaiO827R8R0NGQgO8B7Qh=lN7AhP8R9
PGiiMg^0QhIlOWMdNgn8R8AlN7QhOhN7Q81hN7MlP8B6O7ahN7n0QhB3P7]kOXB6
RHJ0P7b1QXR9Q81lNGb0Q8B4PgakPH68SXR0O7MdO8B4Q7miMWAlP8B4P7QgN7b4
Q8R8OgahOXB6S8R0O7QlPhB<R7alMg^4QXb7P7agOX26R8B0O7UiP8B8RHB0O7j1
Q8^<QX5lO7n1QhR4O7]kNH64R8j3P7j1RHV?S8J7Oh28R8V9Q85oO8B7R8B1P7]l
P8J6Q8AoNgQlPhB4PgihMWV0QXN6PGakNH27R8IoN7=dO8>0P7mgMWMhP8B1OW]f
M7^3PhJ4O7MfO8B<R8AoN7QnPh^?PgakN7j0Rh^6PGQgOgn3R85nN7MkO8B3Ogag
M7MhPHV4OWUdNg^4RHJ8O7QiNh64Rh=kN7=hP8>6R81gN7QlQ8J7P7mhN8>6R8V7
P7QlP8N9R8=lMgAnQhV8Ph5iN7j6S8^4OgQhNh2<RhN0N7QgO8B4Q81iM7QoQ8J7
Q7ahNgj4R8N6OW]hOhR8RhB1O7AoPHB8Ph1fMgR0R8R4PgUfN7^1Q81nN7IdN820
Ph1gN7IhP8J7Q7ihMgb1Q8N1O7ahN829RHJ4OW]nQX^<Rh=nP823S8j;PgmlO8B7
R8IlMgMhNgb4PG]hLgQkOXB4OgQfMgUnQhR4OgQkNh28QXR1O7]nQ8J9RH5lNG^1
QXJ8QWalO8>8QhR4P7QiPHR8RHJ0O7R0R8J6Q7ilM7R0PhR0N7QcMWb0Q8AkMWMi
Oh64Q7mhMgb3Q8R;PgikN824R8QoOW]iOXB8RHAnO7n3QhR>Rh5nO826Qhb9Q7ii
P864RHR4OWAhO820PH5hMWIhPhJ4P7igMgj4QhR3O7QhO8N8QXAnNgUlPHR;Q7il
Nh24RHj7PH1kOXB7RHQoN7QhOXB7Q7ilLgAlOhB0OWafMgQnQX61NgAhMgj4QhAn
N7QiO8B8Qh1lO7V1QhN9Q7ihN824R8b7OgilP8V9S8V3P7QnQ8R8PGikN7V1QXB4
NgIgNH24R8B0O7AiP866Ph1hM7UnQ8R4Pg]gN7b0QXAnO7IdNH23P85nM7QlP8J7
Ph1lMWUoR8R4Q7alNh6<Q8J6Oh5nOhR8RHB0O7N1QXJ9R81nOWj4RhV8Q7ilOhB8
Rh^3OgalPHJ;R8B0Nh21Qh^9QWinP8>;R8b9O7UlOhR8Q8AlN7AkQhJ;QgaoN7V3
QXR6OW]hMgb1Q85hN7=`NgV4Q7MhLgIkO8B1O7]cN7b3QhB0NgAhO827Ph1lMgQk
OX23OWQdLgAlOX1oO7QdMWj0P81lNGQiOX66PH1nNGV0Q8>4P7ilNH24R8J4Q7al
P8B;S8J4PGn0Q8V<R85oOgmnQXR4P7QhNGn0Q8MnN7QiO827Q7ahLgMnO8B7P7Uc
MWQlPh>3O7AfN7V3QXAoMgQhOXB1Qh1hNg^0P8B8P7aiNh24R8R3P7UkPHB<RhN3
Oh63Qhn<R8=kOg^1Qh>6P7alOXB7QXAoNgj0Q8R8R85nNh24R8R8QWUkO828R8V3
Og]hO8>4Q7ikN7MhP8B4QgmhNganPHR8P81lO8B8QhR1OWUkOXB9Q85lMgAhPHJ6
Q7UdMWN0Q8B3NGQdN7n0QX=lNGMiO827PGalMgb0PH^4P7aiO824R8R6PgioQ8R<
R8N3O7b0QXR8QXB0Oh64QhN6Q7ilOhJ6PhB0NgUdOhB4Ph1nN7V0PHB3P7ahNGb0
Q8B4Og]lOXB9QhB0NgQlQ8B1P7agMW]nPh>1NgQgN820QXB0P7b3QXR9QXAoNgb0
QhN6Q7moPHB<S8^8PGn0P8J8RhAnN7IlPHB6Ph1kN7^4QXN4PgalNgn7Q8B0O7]h
P7n4Q7ahN7UiP8B1P7afMgj0Q8N3O7QdO864RHAnNGQlP8R8Q8AkNGmlR8^3Q7al
O829R8R7NgilOXJ4R81nO7V0QXV9Q81hMWaoPhB0NGAdMW^1PGmiM7=fO821P85i
MgaoQ8B6PG]kO867QhJ3Ogj0PhN3Q8AhNGQlQ863PgagMWQnP81lN7QcLg^4QhB0
OWihOhN8Qh20O7QoQ8B7PGn0O7n1R8V3P7akP8B3RHAlO7QlP8B7Ph5nN7b0Q8N4
P7]iNgn0Q8=oO7QhO824Qh5oO7b0PHB8Q8AnOX>4R8R4P7aiN7j1Q8AnO7]lOh64
PgalO7QlQ8R6OgalO7b1RHN3NgQkNH>4Q85iMgMlOh>7QX1iN7aoPhR4PgmkP8B4
QhR7OWQoPHJ6Q8B0O7j4R8V9Q7ilOX23R8R1O7]hP820Q8AkN7]nPHB9R8=hN7an
Q8B4P7ahN823Q8B1O7QlQ8N8RH23Pgj4R8b8OgaiO863RHQnOW]kOh24RHB0O7n1
Q8R;QhAnOh>4R8b8PginP7n4Q8=nN7UiOh>4PGmhM7UkOWioP7QgM7R0OX20NGUf
NHB3R8V4P7b0PhR;R8AnO7b1Q866P7alNh20Ph>0OWUoP861P85nN7UoP864Pgmi
Ngj1Q861OgQfNH24P7mnNGUgOXB4Q81lO7^0QhN7P7moO8B6R8R4P7j0Ph^;S8R0
O7b0Q8R8QgmkNGb4Q8^;Ph=nP8B4R8N1OWalOh21PgmkNGR1Q826P7alNH20Ph=n
O7QfP820Q7mnNGIlPhB3P7igN7b0Ph=oNGQaMgn0P7mlNGUhOX63PhB0O7n3Q8R4
Ph=nO7j0Q860OW]iNh24Ph1kO7]hOhJ1Ph5oO7aoP8R7O7alNGb0QXR4OWaoOh67
RhJ1P824Q8B8Q7mkOgn4Q8B4O7]hNH63RHAoOgUlO8B4Ph5kN7]lPhB3OgaoNgn4
PhB0O7j0Q8V8RhJ1OWR0P8N9PH1lMgUlQXR3P7QhOW^3QhIoN7]iNh67QX1hMgIl
PH67QWUhN7R1PH63OWQgO823Q8=nO7UlQ8B4QhAnP866QhB6Ph20PHN8RHJ3P821
QhR9R8R4P8>4Rhb8Qh1nNgb3Q8B0O7QhN7^0P7inNgMlPH>7PH1nMWb0Ph=oP7Qd
NGb4PgmoN7QhMh24P81lNgQhPh>4PGalNH21R8b4Ph1kOX26Q8J4OWb0Q8V;R8B0
O7aoPhB3O7QkN7b0P81iN7UhOgj0PG]kM7InNHB3O7miNH20R8N4PgalOX6<RHR7
P823QXb?SXV4PH64RHb9Qh=nO8B8R8R7P820PHN;Qh>1NgUnP8R4PgikNgb1Q8N6
P7b1PhB9R8V4OWmlQhB3R81lO7MoP824OX1nN7j0Ph>0OgQiNgb3PGmlNgIhOX60
OWahNGb0R8R6P7ahN7aoP7miM7AfMgb1NgQ`L7AcO7alMfi`L7=hNGalLG5dM7j0
Q8AkMgQhP8>7R7ilMgV0P860OWQfMWV0P860OgahO8B4Q820P7anQ8V8PgakOWb3
QhJ4O7ahN85oQXAlOg^0PhB<R8B4PHB6Qhb8Ph=oP8J4QX5oOWalOh>7Q8>3P8>6
R8b8QhN6QXB9R8R;Q8B4PHB8R8J4Q824QXR;RHN4PH61Q8R6Q81kO7b0Ph5oNgQh
NGn1P81lN7QiO820OWaiN7IhP7n1N7QlMW]lP85hN7QgOWj1PgUkM7UoOhB0PGil
Oh24Qh^7Ph23Q8B<RHB8Ogb1PHR7Q85kO7j1R8B3P7]lN7^1P8=oO7akP824Pgn0
OWaoPHJ4P7akOh21QhB4O7anN7b3Q8=kNGIlOWb4PGikNH20P8B4P7ihOh1oQ820
OganP8B8QhB0O7ilP8N8QgmoO7b3P8R6P7mlOX67Rh^8Ph23R8R9S8N0O7j1PhN4
PGmkN7j3PH>4P7alPHB9RHB4P7^1Qh^;Q8AoMg]lQ8N1P7UiNgb1Q8AnNG]iO8B6
PHB0MgUlOh63O7QkNGR0Q8>0O7]nP8J9RHMoP823R8B7Q7mnN7b0PhQoNg]hN7j0
P7n0O7AlOX67P7iiMgQiOh1lN7QdMgQlQ81lN7IhMWb3P8=nN7mlOXB7QWilO7n1
Phb8P81kOhB4QhV6P7^0P8>;Q8N3NgioP8J4PH1kO7b3R8B0PH>0Q8N8R8N3P821
P8R9Q8>0O7mnP8N4PH1nO7j1PhB3OWaoOgn1Ph20O7anOh>3PH1hN7alNh64PGUn
O7j0P861O7anP864Q8>0O7j0Q8J3PGilN7b3Q8>0O7UhOX23Q8=oOWalOX>3P7ak
NgUlP81lO7UkNGb0QXAnO7UkO827R8B0O7b1Qhb9QX1lNh26QX^8Q820PhB8RhR0
P7]nQ8B8Q85nMWj0PhN3PH1lOWn4RHR7PgmnP8B8RHJ4P820P8R4Ph5kO7n3R8J4
P824P868QXB0O7mnOXB3QX5iO7UiP820OWUhNgmlOhAnN7]hO7ioP7]nMWAlNgj0
O7UdMgakOg]nOgAgO7^3PHB7O7moP8b4R8b3QX61QX28Ph20Mgb3PH>1OW]iO7ao
PH1kNgMhO826QX5lNganPHN7P7ahNGj1Q8N1O7QhNGn1Q81lNgMhP81lOW]iNgR0
P861NgmiNH20Q8AnO7j0P8B7Q81nO7b0OX23OWUhN7aoPhB1P7]nR8^<SXb7Ph68
S8n?SX^7QhR>SXb8Q860P8B4Q8B0OW]hOh60PH20O7R3PH20NgilN7]oQ7mhNGQg
N7UoPG]kN7QhN820P81lO7]lP8B4P7moOX21R8R3OgalO823QXQoO7n0PhN;Q81o
NGb0PhR6PgaiP824R8R6NgR0OhJ9RHAlNganP8B0P7QdN7IoOWanLg1dO8>4Q81l
N7j0Q8V7Q7anP867RH^4OW]kP8>3QXJ0NgalOX21Qh5lOWb4Q8B6PHB3P8R9Rhb8
Q860Q8N7QX=oO7QlPh>7PgmoOX23QhN4Q860P8B7QXB0O7UlO7n0OgahN7UlOh20
P7aiO7^0Q7inO7QfNH21PGaiNganP8N4Og]hNgj3R8J6PGQlP8>6QhJ1Ng]lNh>3
OgihN7QfP81nOWAfMgIlP81oN7QlMgb4PHB1P85lPhJ4R8>1Pgn1QXV8R8B4Q8B8
R8R7Q8>0P8>6QXB1O7j1Q8J4P7mkNgaoQXB1P7]lNgj4QXIoOWaiO821PgmhNg]l
Oh61OWagMgioP860O7QhO864Q864P7b0Q8V8QXAoP861QhR6P7anO827R8R6O7j1
PHB9R8J4Oh20Q8N6PgihN7j1QhIoOgQhO7n4PH1oMgMlO7j0OX1iMg^0Q8B4Pgml
O827Q8=nOWilPHB6Q821O823Q8R4Q81oP7b4Qh>0OWahNh64QX1lNGQlP8B7Q8Al
P8B0QXR4QX1oOhB7QhJ3O7UkO8>4PHB0O7ilPHB4P7QiN7MoOh20O7MgNgn3Q8Ao
NgIhO7n3P7miN7MlPHB0PH1oPH24QXJ4OWaiOX20Ph1hNGUkPH1oP7]fMWUoOh24
P820OhJ6R8V6Q821PhR9QXB1O7anP8B3PGahP7b0R8>3Og]lOXB4QXMoOWUnPh27
Ph1oNh23Q8V7Q85lP8B7Qh>1P7]iOX20P7akN7IlOX20O7iiMgQlPH1lO7UfO7j0
Qh20O7]nO8B4PH=lP7anQ8>6Q8B7R8R8SXb8QX>4Ph>8QXJ4Oh21P8J4Q81lO7b0
Q821OgQnNGj8PhB0O7ikPhB7R85lOWb0Q8J8P7alN7n1Q8R0O7UhP8>8R8R4OWj0
PhB6P820OWn4R8N4P7mhO821R820O7IfN824P7akNGQlPHN3P81hO823RhN6PH23
OXB7Q8J3NgQoPh>4P7akM7IkP81lNgMhN7V0Q8J4Pg]lOgb4Q820NGQhNH20P7ag
NGUkOWj0O7AdNGanO7alN7UkPH60Pgn0OWj4Q8J3PhAlP8N8RhJ0P7ilOh>4Q81k
N7UlO864P7mlO7j1R8B8Pgn0OhJ7R8>0P7QlOh64PGihM7UkP8N4OgakOWn4RhR4
Pgn3PH>8R8J0P864Qh^<RHJ1P864RHV4Q7ilOh24QhB3O7V0OX26PH>0OWioOh>4
P7UgOWUlPh24NgMnOXB4P8B0O7j0QXN8R8>1Ogb3R8R8Q820Oh>4Rh^6QX60Q8B8
R8B0O7anP7n1P7ihNGaoQhB0OWakNh66QXJ4OgUiO820PGakN7MkO8B3O7QhN7Il
Ph61OW]nNg^1PH60NgalNgalOWafN7QlO7ioO7MdNH20Ph=nNgMiO7n1P81nN7]k
Oh20P7alN7V4Ph63O7QgN7n3Q8B3PGalQ8>3Q7mlN7MlOh20OWUhMgioPh>3P7ao
PhR8RHAoP7ioQ8B8R81kO7j0Q8R4PH1lO8B3QhB0P7b0PHB8Q85oNgb3Q8N4P7ik
OX24R8J6PGilP8B6Q85nO7QlP8N7PHAnO7n4RhN6Q8>3OX>9RhN4PH>4QhV9Qh20
Q820Q8B4P7UlOh64R8^4P821Q864Ph5lNh20PH>0P7UiNGR0P821NGUkNH21Ph5n
O7UlOX68QX=nO7b3Q8J7QX5lOh64R8R4P7aiOh>0PhB3O7]nPHN4Ph1nNGUlOX>0
O7QgO7aoP81nNg]lO863Q8=lNGQkP8B1O7ahMgQlP823Og]lNh26QX>0OW]lOhB9
R8B0P820Q8R8R81oP824R8V6Oh1oOXB4QhAoOWb0PH66Ph1lNGanOhB0N7]lO81o
PH1lNGMlP7b0P7]hM7]nOhJ3PGmhOh23R867PGUlNh23Q8B0O7UhO820Ph1hN7Qh
Oh20OW]hNGj0Q8B1Ph20PHB7PHB3OX>0PHJ4QXB0PHB7QhV8Q860PH23Q81oO7]l
PHB4QXAlNgn1Q8B7PGakN7b0P7moO7QlOh60PGmlOgmoP8>3Oh20OX>4R8V4P7n0
OWn4PH1lN7anOh>4QX=nOh20PH23OgUlOX63PHB3OgMlPHB4Q8B1O7]nPH>0PH60
Ogn4R8J8QX23PhB4Q8AnOWanPh61PgmnNGUlO81lO7]dN7]lOX1nNgUhO824P81o
O7ioP8R9QXR4PH64R8V9Qh21Ogn6QXR4OgilOX24Q860O7ilOX23P7akNg]nPGj0
OgUnOX20Ph5lP820Q8B8QhN6Ph60QXV1Ph5nOgb1PHB0Oh5lOX>6QX60O7alO823
OgakNgilP8B0OgaiO7b0Q8AnN7alNGinOgahMgioNgUlNg=dMWMlO7alNGIhO820
OX1lO7^0Q8>8Qh>1P866R8V7Q820P8B7QhJ0OWaoQ8B7QX=lO7ioQ8N3P7agN7Qo
Ph1oN7QhN7b0P85kNGalOX21Q81lO7^0PhB6PH1lO821Q820O7]oOhB6QXN1PGb0
Q8>8Q8>0NGn0PhN4Q8>1Q8B7R8J4PH24R8B4QXB0OX24Q8J6QX1nP863QXJ1Oh1l
OX26Qh1lNgalO824PH1kO820PHJ7PH1oOWn0Ph61NgQlO7anP7mlO7QlOh1lNg]l
NGaoPh1oPGmoP864Q860OX1oQ8R4Q8>4PGn0Q8B3PGanO820OX1nO7UhOh1nOgn0
OWR0PhB6P820NGj3Q8B4Ph1lP860Q8>0Q7aoPH66PhB0O81nPhB0PH1oNgj0P820
OWalOWn4Q8B3P81oPhN6Q820P7b0QhJ7Q7ioOh24Q8J0NgaiNh60Q81lP7b0Qh67
QWinP81oP81lNgUfN81nP8IlOWakPH63PgmoNganOh66Pg]nO81oPHN0OW]iQ8B0
QhB0OWaoPhB1Q7iiNgV0Oh1nN7akNh20OgihN7iiO7b0PgUlO7^1P8>8Q860P8B6
QhV4P820Ph66QX1lO7]lP8B3Oh1lNGn0PhB4P7]nP827QhB0OgalP861Q820O7Qn
OhB3P7miOWaoQ820O7UnO8>4Ph1lO7alP8>4PH1lNganP824P7j0OX>7PHB7P8>1
PhR6S8R6Pgj6QhN9R8B0O864PHJ1P7]fO7anP7mnMgMiMgalO7ihN7UiP7j0Ph21
Ph23Ph5oO7alNgalOgmhN7QlOWj4OgakN7^0PH>0P81oP8B8RhN6Q820Q8N8Qh>0
OWanP8N8QX21OX21Q8R4P7ilO7anOgmnO7anOh61Q81lOWb1PhB8Q8AoOXJ6QhN0
P7ilOh21P7ilN7QnOgn4P7inOh21Q8J3Oh1lP8B3QhB0P7ioPHB8QX=oOWj0P8B1
OWmiO85oP81nNgQkP7n4PH20NgalOhAoOgmhO7j0Ph>0P7ilO7j4R8N3OWiiO820
Q81nO7UnO7j3O81lN7j1Qh61PgilOh23QX64P7n0PHR6Q8=nOWj0Ph20PgmiNh23
PGmoPGilP866P81oOgioQ8B3Q823Oh24Q8B0Q81kOgn0P821P7mlO821OX20Og]k
P7n0PhB0P8>1Q8B0P7j0PH64QXB0OWj0Oh67Q81lNginO860OWinP864Q8AnNGUl
P7j1P7inMgV0P864OgioO824Q8B0PH1oPH23Pgb3P7b1P8J4Ph5lPH21Ph>1O7mk
O820Q8B1Ogb0Q866R864PGb3QhJ1P81kOginQXAlO7mkO824QX20O7aoOh>4P81o
OWaoP860P81nOX20O7n3Ph21Q8B0Oh60Oh20Q8>1P820OX23Q8B3PGmnOh21Ph5o
O7alO7n0OganO7ilOX1oP7aoQ8B4QXR3PH23R8B8QhV4PHN4RHR8S8R8Q8B9QhR<
Q8B1OXB3Q8J3PH20P8>8QhB0NgUlNGn0OW]hN7UiP7ilP7QfNgb0P7mlNGUhNh1n
P81lNgQlP7n3OgalMWQlOX1kO7ilP7j0PGalO7aoOh64P7inP8>0PHN4Pg]nP820
PhAoNgQlOgUnP7mlMgV0O821OgalNH63PHB0PgmoP7n4Q861OWn4PHB1P7mkO7an
O7moO7mkO7inP8=lNg]kOh24QXJ6PHB6QXR9QXB4Ph>8QX61P7ilNg^0PGUlNgQh
Nh1nP7ilP7mlOh1oO7alOh60PH20P7n1P8J3P8N0PhB8QhJ9QXB4QXR8R8N7QXB4
PHB6Ph>1P7alOgioP81lOgb0PGn1P7mnOWmlNg]hNGQdNGQhNgQgN7alOWinP7]i
O7moOh23OgalOX20P7j0NgQlOX5oPH=lOWUlP826Q8J7PhB7QXJ7Q821P827R8B4
Ph21Q8B8RHB1Q821Q861OgUlO7alP860O7mlOX5nOh20P7ioP860OWaoO7b0P8>1
O7anP821PH64PGb1Q824PhB6P8>3Q81oPH20P7j0Ph>1P7inOgn3Q8R8PH21Q8B3
Q8R4O7R0Ph63P820NGb0PH1oOWQhNGR0OWQiN7QlNGilO7QfN7alP85oPH21PhB7
Q8>3Q8>4Q8B3PHAoOX1lP81oP820OX60P81oOgn3OhB8QhN6QXB6RHb>SXb<RhV<
Rhb8Q8J3QXJ6R8B3P7j0P824Q860NGUnOWn0OWmiNGQhO7ahNgUgN7]kO7]kNGQn
OWmoNgikN7aoO7anOganO820P7ioOWalO8>4Q8N6QXB4PHB6QhB4QX20Q8>3PGio
O7^0OX1lNg]gNGalP7alO7UnO7n1OganOgmnPHB3PH21Q8B0QX>1Q827QXB7PhN6
Q8N4QhN3PhB3P820P7b0O81oO81nO7anNgalNGj0O7aoO7]nP8>3Q8=oOh20P85n
OX1oP81oPGahN7UnN7j0OWalNgaoNGb0Ogn0Q821Q864P826Q8B3Q8J0PhB6S8B4
QhB0P821Q8>3P7moOX21P7akO7ikOgilP7]hN7UlO7aoP7inP821P860OX20P8R4
Q8B0Oh63Q8B4P7anOhB6PHAoOg]hO7n0P7anNGQiNgioP7akOWb0P8>3O7ilOh1n
Ph60OgUoOWb0Oh1lO7alP820Ogn0O820P8B1Ph20Ogb0PH1lP8>0Q8B1QX61Ph61
Oh1nOh1lO7alNgikO85oPH>4PhJ8R8R8RhR4QXJ8QhJ8PhJ3Ph>0PH20PH23PH20
Oh23Q8>1PH1oOWn0P7alOWmnOh60OgalO7aiP85oO7R0P826Q8AoN7]nP7mlP7ah
N7MnOgQoO7ahN7alOganOX20OhB6QhB1Ph>0PhB7Q823QXN4Ph>0Oh21PH5lOhAo
P8B4PH1nO7n0OX63PH>1P820Ogj0OgalNg]iO7mnP7alOgalOX1oP8N3Ph21QX>3
Q8J4P8B7PhB3PHR3PHN4P8>0PHJ1PhB0Ph>3PHB6P860Oh=oP85nP7mlOWn0OWao
O7mnOX1lO7^0P7V0O7anOX20O7UkOgilP7alNgalOWn0PGmnO821PH20Oh1oP860
P8>0PH64Q864QhB0PhB3Q8>1OgmlNgn0P81oOgalP820PgioP7anO81oO7mnOWml
Ph>0P820P7n1Oh66P821PH1lO7anOX1lPH5oOWalNg^0Oh21Oh20P81oPHB1P821
Q8B3PH>3Ph>7QXB4P81lNgmnPH5nNganOX21Q860P8>6QXR8Q8B1PHB7R8J7Ph60
Ngn0P820P7alNgb0OWaoO81lP8AoP7aiNgb0Ogj0P7b0P820Ph>0Q85oP7j0PH>6
Q8B1P820PH61P81nOh1iO7QkO7QkO7akO7ilO7iiO7anOWb0P863P864PHN3R8R3
QX>3QhJ;RHR8Q8B3Q8V7R8J3Q7n4QhB3PH1oO7]nP7iiNgmlO7aoP7]lNgalNGan
O7ikO821PGn1P7b1PHB8QXN4PhB3Q860OgalO7]lO7aiO7QgO7anNg]nOX1lOhJ1
Oh24QXJ8RHR4PHB7R8N4Qh5nO7aoNGaoOWanO7mnOWilOgakOg]lOgalOX5nNgn3
P824Q8N8QXN8R8>4R8J3Q8R4R8AoQ7j0P7n3O7QlM7QkN7anOWalO7b0OX1lOX1l
P7]kOWQhM7QiM7UhMgQgO7aiO7QlN7MlO7inNGahMW]gO81lP7alP7j0Q8J6PHJ7
PHB4Q8N1PH21Ph26P7QlO7]lOhB1OWinP820Q8B3Oh24QXB3QXB0P826QhJ6R8^6
Q8R8R8V4Q8B1Q8B8Qh>3OX1oPH>1Q81lOgmoOX61PH20P8>4P8J4PHB1Ph23P827
PHB6PH>3PgmoPH>4QX60P7aoP821OWioOWj0OWn1P81oO7j0Ph21Qh5oOWn4Ph20
P7mlO864PH60P7n0Q8N8QX>8Q828RHR8QXJ0PhB0QX=oQX20PHB6PH60OhB3OXB3
OWalPGioPH21OWUoP7moO81iN7alPGn0QX64Ph24Oh23Nh1lNGakNGUhO7QhO7Mh
NgIhN7IhN7MkNg^0NG]oO7mnP81lP7ioPH64PH21Q8B3Q8B1O7aoP85oO7ilNhB6
R8R1P823PH27Ph1oNgQnOX24PGilOX64QhV9Qh63QX64Q824OWalOWikOX1kNGQi
O7ilOWiiMW]lPH60OgilN7j0O7inO7alOX1oPGmnP863P8>4OWaoP81oOh64PH61
QXB1QXB6QXR7QXJ8Qh>6PHB4P8B4Q7n0PH61P8>1NgUlP81nQ81lO7QoP820NGan
O7n1Q8B0OWn0PHB1PgmnP7alP7n0O7j3Oh20Q8J0PHB1Oh20QXN0Q81nP823Q8>0
P7mnP8B4PhB3P820QhV8Q8B4Q866Q8B0N7alO7mlP7UdN7UnOh21O7ahNh1oP821
NGAiO7n3P7miN7QkP8B3PGikNg^0PHB6P7mnO8B4Q8J0PH63QhV9R8J4Q7b0Pgn0
O7UnNGj0Oh1kO7mhOh20Q7j0Q824QhN8PH60P821QXV4Q8>0P7n1QX20O7alOX1o
P7mlOh60P8B7P7b0P8>4Q8B4QX>4Q8B6R8R4P820P85nPGilO7UiO7alN7MhMg]n
OWikO7QgNG]oOWmnNg]hNh21OgikNg]lO7j1P7alO820PH>1OgalP8>0Q81oPGn0
R8R8R8N4P8>3QXR6Ph60OX>3P8AlO7inP81oOWalO7n3PH20Oh20PhN4R8B3R7n1
R868R8B0OhB3Q8R1Q8AoPhB8RHB4Q860P864PH1oNgUhNgilNgQhMWAiOgalOWai
MgaoP8B1PH20P868QX>1Ph60Q8B6Ph1lNgioPHR7OWmlNgj0Ph60NgUgO7alOgUi
M7QlN861P81gO7mlP7ilOWIhP823P7inO7ioOhB0P81lO820QXB4Pgb1P867Q8Ao
NgakOWakOWahNgUlOWn0Oh1kOWilPh63Ph61PHR8QXR6Q8N4QXR9R820P7b0Ph64
P7ioO824Q861OWakP8>0P820Ogn0Q8B3Ph5nO7b0Q8>0OW]nO7b1PHB0O7mnPHB6
QX=oOgn0PhB4Ph1oOh61Q8B3O7alO8B1PH=hNg]kOh>4PH1oP8B7R8b8QXB3PHJ<
QhB7PHB7Q8R9R8J3PHJ6Q8R4Q81lOWioP7inN7MkN7j1P820O7aoPH64P7alOWan
Q81lOg]iOh20P7mlO7]hP85nPginPGaoPhB4P81lO7ikOhB0Oh1kOX20QX>0OX20
P821Q85oOh20Oh1oO7akN7aoO7ilN7IgO7n0P81nO7j0Q8V9R8AoP7b1PH64OWih
N81nQ81lP7IlOgb6Q820O81oQ8J1Q8>0Q8J7RHR6Q7n0PhB7QXR0OgmlP820P7ai
N7j0Oh63Og]hP7n1Q864OWalO8>0OWaiN7QkP820N7MhNGalPh5lN7QlN7ioP85l
NgUlPhB6R8=oO824Ph>6P7anP8>4Q8B1OgakP8B0Q85oO7]nQ8>3PH20OX64Q8J3
P81nPhJ6R8B4Q823Q8R8PH5oOWn4P8>4P81lOX21Qh64Q7ioPHR<Rh^6P7j0QXN9
Q7mnNh20Q8R3PgmnOWn7R8>0OWalO7j0P7aiO7QiO820O7]hMgUkOX1lOWahNGUl
P81lNg]kO7n4P7moNginPHB1Pgj0Ogn4QXJ1P81nOWj3Ph>3Oh1oPHB0PgmoOW^1
P820O7ioNgn1Q81lP7alP868R85oO8>0Q8b8Q820Q8B8Q8J1O7UlPHB8QX1lN7an
PhJ6Q81nNh66QX^8Q820O824QhB1Og]iO7ioQ7mhNgQnP8>3O7ikMgUlP81nO7ak
O7alP81lNGalP820Ph20OWanPh64Ph61P8>0Q8B1OWn1Oh64Ph=lNgioQ8>1PGml
N7b3Oh1oOgakOX23PGj0O7AkPH>1P81nOgaoQXB4PH60P8>1S8b6Q8B6Q8B7QhJ0
O7j0P824PH>0O7n0PH>0NgalNGj0Ph1oO7]kO7inP7alNGR0P823P7alOXB4QXV4
PGj0QXJ6QXB0P7n1R8J7Q820N7b1O8J3Ng]gNGb0Q820OWIhP824Ph5oNGQlQ8N4
P81nN7^4R8R6Q8AnOh>3PhAlN7]kOh24P7]nNGUnO85oOgihNGalOh1nO7inP8B8
QX5oNgj4QXB4PGilO826Q8B3O7]lPHB1QXAnO7anP861Q81lN7]oOh63PGmnOX24
QXJ9Qh20Q8N6QhJ4PGmnPHB3Q81lOWb1Q8B4Q81iN820OgilNgQdN7n0OgalNgQo
P8>7P820O824Q8J4O7alO7n0QXB0Og]nP8>4Q8B3OWn4PHB4Q81kOX24Q8>0Og]i
Ngb0OganN7MhO860P7ahO7^0Q8B4P81lOXB4QhB0OgUlP867Q820NgioQ8^4Ph1o
NGb4Q8B0OWakO827R8AnOX1oPHJ8Q8>0O820Q8B4Q861Oh63PH5oOgikOh63Pgmn
O7]lOX>0OWaiO823QhR6P7aoP824QXB0OWalQ8R4QhB1P7n6R8b6PhIoO827RHB1
OgakOX68Q820O7QiOhJ4P7iiN7QnP820OWakNGb6R820P7alOh>1PH1iNh1nQ8N3
Q7alQ824QhB4OWalOX60Ph5hN7UlO821PH1lO7n4PhB4OgahNh1oP85oO7QiNg^0
OX1nN7]lNginO7aiNGUnQ85lP7alOgn4Ph20O7j0P8J8PhAnOhB3RHR7QhB3P8>6
Q8B0OWalO824Ph1oOgn0PHB4PGahNgaoOh20NGQgN7n1Q85oOW]lOX24OgiiN7an
P8B1OWUlOgb4Q864O7b0Oh>4Q8=oO7]oQ8J6Qh5oOgj4QhB4PH1nOhB6QXB6PGmo
OhB4PhB4PH20QXB0Q8B0PH>8R8B4P8>3OXJ8Q860O7]oPHB4Ph>0P863Qh>3P7io
O827QXB3OWanP8N7QXJ0P7n0R8R<R821OX60PHR1Og]gNg]nOgaoMgMhNGanOgMf
N7MlOWj0O7QhNGilP8>0O7QnPH23Ph63Oh1oPHN4Q85nP7n3Q8B1OWalO7n0P81l
NgUhOX1oP7ioO7V0Q8R4OgmkNgn6R8J3P7anP828R8>1P7n0Q8R;R85nP7j0Q8R6
P7ilOgioQ8B0O7QlP7j1PH1lN7alO81oOgagN7aoP821OWQiO7n4Ph1nO7mnQ8B1
Q85lOgj0QhB4QX1oO866PHB1P85lPHB4Q7ilO7n0Q8V6Q81lP7b3Q8B3NgQhMgj0
P81oNgQhO7j1OWahMg]kO820Og]hO7b0QX60NGQoO8>6OhAoO7ilPHB7Q820Oh>4
Qh^;Q8B3P866R8N3P7b0PH64Q8=nNGmoP8>1PGagN7V0PH20O7QgNHB4P8J4O7]h
P8N0PH1lNGV1QhB7P7inN826Q8B0OW]hP8>6QWn0Ogb3Q8N6Q85nOgn1RHN4Q7il
OX66R8N1P8=nP8R4QhAoPH24Q8B6OgakNh20PhAnO7]kP823QX1oOgj1PH>1O81h
MWanP820O7QlNgj1Q8B0Ogb1Q8B8RH>0O7b3PhR6Q8=kO826RHR4Q7ilOhB6QhB1
NganP860OgahM7N0P81oOgafN7j3Ph21P7ahOh60PH1iNGQgOh20Og]iMW]lP81l
NgagNh64PH1oO7V0PhJ8P7aoNgn0P8J3OWmoOh27R8N3NgUlOh21Q7mlNgb1QhJ6
QX20Ogn4Q8J4P7alO824PHAoOgikPHJ9R8B4P864QhR<Q864PHN7RHN4QgmoPH>6
Q8>0P7V0Q8>4P81hN7akPhAoO7aiNGmnOWmlO7]kOX66P7inN7anOhB3P7ilN7^0
PHB0P7alOX26Q8B6OWb0OXB4QXAnPGalQ8B3OWanNgj1PhJ1Ng]iN7aoP7]hO7Ql
O7b1O7UhO7alQ860P7aoP821Q8B0NgaoPHJ6Qh5nOWn1QhJ8QgmnOhB6QXR4PGn0
Ph27R8B1OWmoP8>3PgahNGalOhB4P7alP7moPHB0O7UnQXB3QX=nO7b0Ph63P7ai
N7j1PhB3NG]lP8B4Q8InN7b0Q860Ph1lNH24Q8>0OgmiO866QX20OgQlPH63P81o
Ngb0Q8B3P7alOh21Q8N4Q81lPHB6Q8B3OgilP8J4P861OX1oQ8J0OgalPH26PhB3
O7alP8J6QhAnOWb0PHB4PGmkO7n4QhN8P7]nO824PH=nNgUhPgn1PganN7QnPH1o
Og]hMWb0Ph1nP7ihOX>4Q81oO7ilOhB6P7alNG]lO85nN7MfN7UnP7anN7UnOhJ8
R8J4Q8B8RHj<R8R3PhB7R8J6OgQoOWj0OWakMWIhOh>3PgilN7R0PH1oO7akMh21
PHJ0PgakOgb4Pgj3O7QlP8>0Ph1nP7anQ8J1P85oP8B4QhN3P861Q8R6QXInNGR0
Ph23OgaiN7aoP81nNgaiO81oPH1kOWUkP7n4Ogb0O7moPh>0PGaiP7n4Q8B4P7b0
PHB8R8V4Q8>4Rh^<R8J3P8>4Q8R6PGaiOh20Q85oN7QkO8=oO7afN7UiOganNgIg
N7UnOWilN7UhOhJ4Q81nO7UnPH>4P7aiN7b0QhJ4OginNH26QhB1P7b1PH>4Q8B0
OX20Q8J4PGb0P7j6QhB4PH20P86;R8N3OX1oQ8B4Q7alO7^1QXB1PGaiO867R8J0
O7alO821P7aiN7MlOh>0O7]oOgn6R8J4Ph>6Q8B;S8R4Ph>4QhR;QhIoOX>0PhB3
P7ikO7n0PH20NGIhN7j0PHAoOWaoQ8J9Qh=oO824QhR4P7ioP8>4QXN0O7akP8>0
P7ahM7^0P8B3OgakN7b4PH23OWQhOh60PgilOWQlPGn1PH1oO824Q8J0Oh1nP863
Q85lOginQXB6Qh5nO820PhN4OWmkNG]lP85oO7]nNgb0Oh1hO7ahP824P7j0N7j1
P8B0O7UiO824Qh>0Ng]kO8>3PH1lOWb1R8N;Ph1oO821PhN0P7ihP824R861P7b0
PHJ4Ph1kO7j0PhB0P81lOX24Q8>1O7inPhJ4R8B0PGmnPhB6PgmoO7alOX1nO7]i
O7j0P81nO7moP8>3Q820O7n0PHB6PGmoNGb0P8AnOWUgO7]nPgilO7QiP8>0P7]k
O7anP8B1O7mkNh60Q8AkO7MhPH21P7ahMWUlO8>4OX1oOXB6R8V4PH21Q8J9S8^9
QXJ<S92@S8R0PHB4R8J4Q81lO864PhB4P821PhR9RHR4Q824Q8B8R8>3Ph20QX=l
OWikNGn0P8=lNGikO81lO7ahN7QoOh20O7aiN7b0PH>0OWmkNh27Qh5oOW^1P867
OgUlN7]kO81oO7MgO7alPh1lNgIhOWaoPGmhN7UoOh21P85lOhB4Q8B0P7mlQ8N8
R8B1P7n3QXB7Q81lO7moP863P7UhOh1oPh20OWalOXB0Q8J0PGmoQX64QgmoOWb0
OX>1NG]kO8>3PH>0OWalQ8J4QX1oOgUoPHB4O7]kMWMkP7ilO7QiO7ioP7ihNGal
PHB3P7UfN7inP8B0O7UiO860P860P7b1QhB7Q8>4Oh64Q8J3PH60P8>4P821Oh20
P8J4Q81oOgb0Q8>7PganNh23Q8b8Q81nP7n4RhB7PGb0Oh63P8AnO7mkOh1lOWil
Ngj0P821OX20OX24Q8B1PH23Q864QXB3PGn0Ph21P7mlNgioP860P7ahO7mnQ7ml
P7QiOX21OhB0P81oPhJ1Ph1lNG^1Q8AnNGinOWn1QX60P7n1PHJ8Ph>1PhB4QhB0
OganO864P8B4PH>1QXR8RHB4Q868R8N7PhB4P8B1Oh1lOgmlOh1oOWQgN7QkOWn0
NgQiN7aoOgmlOWikNGb6P7moOh1lP8>4PGalMgj0PHR1OgalPGn8RHN8P7ioOXJ0
P85hNGQkOgj4O7aoO7anP8AlO7alOWn1Q8>0O820PHB3Qh=lOgn0Ph67PGn0OhB3
PHJ3Q81lP8>3Q8B1Oh20PH>1PH1nNgb3P823OX1lNgmoPh1lP7]iP8B4Ph=nO7j1
PH>3O81nOWj3QXAoOginOX63Q81lO7alOh24P85oO8=oP8R4Q8AoPGn1Q867PH23
O821P861PH60Q8N7PGn4Q8B7QXR6P820PH>4R8>0PGaoPh67Q7n0O7alOXAlO7Qh
O7aoP7mnNgalNh26Ph1lO7mlO7inO7MhN7UiNGalO7]iNGUhNg]iM7UlO7ioOWak
N7^1Oh20Ph1lOh64P7ioO7alOh=oO7akNgaoOX21OWioO8>6PhB8QX64R8N9R8N8
R8J8S8n<R8N7QXJ7SXV7R8R4Q8V;QhV7Q8B4Q8B6P860OWmlP7j0OWb0NgalN7al
O7]hN7QgN7UiNgUiOWb0OganNGanO7mhO7aiNGUoOWb1P7]oOgj0O7ifN7ihP863
PH21Oh20PHB3Q8>6Ph21P7mnNgioN7j0Oh1nOWb0P824PH1oPh>4R8J3P7anP861
QhInP820Ph>6QXB0PHB7QhB8PH1oO85nPH=nP7QiP824Ogn0N7alNh1nOgmnOgj0
PhB1O7anOh20Q860OW]oO7n0OWilNg]hOWanP7anO7]oP861OX20P8B3Q8=nPGio
P821PGmoOX21Ph^8Q8B3Q8>4R8R6Ph21P7j3Q81lOWanOgmoO7akNgioP7n0OWao
Ogn1P7j1P821PhJ3PhN0PHB0Qh>4Q824P824PhB0OWmlOh63PGmlOganQ8>3P823
O8>4Q8B0PH1oO824P7inPH20Ph>8PGn3P81nPHJ0P7moP7ioPh20O824Oh>7Q8B0
P8>4QXJ4QX5oP821Ph>0PH20P7ioPH61OX20OX20Ph>0Ph23P821OWinO7moP860
PH1lOWakOX5lNgikN7]nO7akN7QlO7j1P81lOgb0P7n3PH5oP8J4R8R6R824Q8>6
P85lO7ilP7inO7]kNGalOgalO7QlOhAoPHB0PHB7QhJ6P821NH68Q8AlOgiiP7b0
OWaoO7b0PHB0PH20PHB4R8B0PGj0O7aoOWmkNGQhN7UlP7alO7UlOWalO7alNGb0
P81nO7aiP820Ph60O7n0P8J4P81lOX23QX63Ph24P823P8>0P81nP823PH1oP81l
PH60Q820Ph>4Q8J3Oh1nOX1oP7mlN7aoOgmoPh20P7n1O7b0O7mkN7ioO7]oP863
P8R9QXB7R8N8S8N8QXB4Q821Q8>1OWn0OgmnP7alO7]lP7mnPGmoOgb1Ph>6QX1o
PH20Ph23P7ilO81lP8AnOh1oPh=oP860O7b1PH20PH=nOX60PgmlP820PHJ6Ph61
Q8J3PhB1OgmoP7n0P860O7b1P820Q81oOgaoOgn1PGikN7alP81oP7anO7^0Oh20
P81oPh61QXB1PhB3QhJ4Q81oP8>1P8B4P863P81nOWmlNgUiO7]lOWakNg^1Ogj1
Oh21P8>3PH60Ph20PHB4Q8B1Q8J7R8B1Q861Ph24Ph63OX>4Oh1oPgmkO7b0Ogao
OWaiNh1nO81oO7aiO7ikO7j0P7aoO7UoO863Oh>0P860PhB1PH20OWj0P7alNgal
NGaoP7mnP81nP7b0Q864R8R4Ph61Q8N6QhJ1Q8B3QhB3Ph1nO7n4Q860PH20P824
R861Q8B0PH21Q860P85oOX1nOX1lO7inPGmlO7akNgn0P7aiO7akP861P7ilO81o
P81lO7]lOgj0Q81oOWanO821P7mlNg]oP820PH20O7]oP7n0OgalP820QX5oPh1o
P81nOWmlOWikO7]lOgmnOX20OWn0PH1oPh23Q820Ph>4QhJ6Q8N4Q8>0R8R4Q8>1
P821Q8B0Oh5oP860Q7mnO7b0O861O7mlO7n0PGmnP7QkNgQlO7]lO7]kOX1nO81o
P81oPhJ1QXB0QXB6QX60Oh23PH64Q81nOWaoOh21P81oPh21Q8>3Ph>1PhJ1Q8>1
P824P864Q8N4QhB8QhJ8RhN7R8R8R8R7Q860PGmoP7anOW]lOWaoO7alO7anOX=o
OgikP7ilP7alNginOX1lNgaiOgalP7inO7anNgj3P81lOX20OWn0O7alOWmlP7al
O7UnP821Ph60P860OWioO81nOX5oP820Ph60OhB4Q8B6QXB8Qhb<Q8J8PGn0P821
OWj0O7ioO7n0P7j0Ph21O7alNg]lOgmoP7mnP7n0Pgn4Ogb0P81oO81lO7aiPGml
OgioO7UoP7j1P7moNg]lO81oO7afN7UkOW]lO7MkO7]nO7n0O7alOgmnOX1oP81n
PH1nQ8B1Pgn3PH24Q8J3OX60PhB7QhR7QhR7R8V;QXJ6Q8V6QXJ4PGn4Q8>1OWmn
NGUlOWikO7]lOWj1OWalOX1lOX1oOWb0Ph63PhB4Ph23Q8B6QXB4Ph61P81oP7il
P820PGmoPH20PhB4P820P820PH60O7j1P821Q860Oh21P8>1PgmiOgj0P7b3P7al
OX61P81lNgagO8=oOWmlO7UlOgioOWioNgmoNgmlNh1oPHB6Q863Q8>4R8N7Q861
OWn0P860P7moNg^0OWanP8B4QhJ7Qh60PH20P81lNGmiNGakO7UlN7^0NgioOX1n
P8B6QhB4R8J3R8R9QhJ<QhB6QXR3Q8J4Q821Q820P7mnO7j0Pgn0R8B3QXB3PH63
P8=nOhAnOX5oOWanO7b0P823Ogb0O824OWilO7inOh20PGUlP7b0Oh>4P7alOWii
NGalNgalO7inOW]lP823Q8>4Pgn4QXB8QXJ3P8>7Q8B1Q8N1PHB3PH21P7j0Oh1o
OX1oOWikNGalO7]kOWilO81oOWilOWanOWj3P7ioOWb0Q860Ph1kO7ioPH20PH=l
Nh20P8=oPh>4P8B4P8B4Q8B6Q8>3Ph>4Ph26P7n0Oh20Q8B0O823P8>1Ph1hP7in
Ogb0P7aiNh60P8>0P7ilP7aoPH20O7alOX20P7mlNgilNh20Pgn0Q864QXN7Q8B3
Q8>4Oh24Oh1oOX5oOh63Q860Q8B4Q8B8Q8>6Ph20Oh60P7n0PGj0P7n0P820P820
Og]kOWmlO7mlO7alP81lNganO7b0P81kNGaoOX24P7ioP821QX60PGb0P7j1Q861
P820Q8AoQ8B0Ph21P7mlNginO7inO7UkNganPHB3OgmnO7anP864PH61PH61Q7mo
PGn0P7j1PGmlNh1lOX>0P7ioPh64Q8>6P7UlOh20PhB0OWj0PhB6QhR4PHB6R8R6
Qh>0Pgn0Q860OgalO821P81kNgahMganOWahNgalOh>4P7n1P7n3PH64PH5oQ85o
P81lOgioP820O7UiNGb0P821O7aoOWioPh1nOh21Pgj1Q81nO7b0PGn0Q820P821
PH1nP81lNgaoOX1oOWmkOWanP8>1P821Q8>4Ph>3Q8N6QWn1PGn1PhJ4Ph1oP81n
P8>4Q81nOh20P863O7]lNgaoO7ikNGQiOW]oOgb0OWn0P866QX60Q8J3Q8B1P7an
PH20PHB4OWj0P863P8=oOX1oP81nP820Ph67Q826P827QXV8Q8J0P81nQ8>1Q7mk
OWj0Ph64P7inOX5nP8B0OganO7inOWakN7UlO7]lOg]iNgj0P7n0PH=oPHB4Q8J0
P860Q8B3PgmhNH20NgioO7ihN7ioNgQkNGIhO7ilNG]kOginP820Oh66Q8J6RHR4
R8J8RhR;RHR4Q8J3Q8B7Ph21PH60Ph5nOWalO7n3PH20Oh21P8B8PGalO820PH23
PGUlP8>3P81oP7mkP8B0Oh20O7^0P823O7akNg]kP81hNgahNGUlP7ihNg]kOWb0
PGmkN7ihOXB1Qh1lP7n1Q863P820O8B6QXV1Q8V7Rhj@SXR<RHV<S8b;RHB3PH>7
QXB0OWmlOh21PGinNgmnOX5nP7]hNGb0OWj0O7UhO7mlO7alOWilPhB4Qh24Q863
Q8N4OWalOgmnO81lN7QlP7ioOgaiNGaiP820OWUkNGMlO7mlN7QhNganP81lOWil
OgioP7mkNH60OhB4P8=lO864Q8B8Ph>4QhR8R8N0Ogn0Ph20P7ioOX24Ph20OgUh
OWn0P7ilOgikOX1oO7alO7anOh21OWb0Ogn4Q8B4Q823PGn3Q8B0Ph5nOh60Ph1l
O7anP823PH5nOWj1P8B1Oh1oPh24Qh1nOX20Ph>0P7]iO823OX1nMWUlP861Pgik
P7b0Q864PGmnOWj0P7moNGUhNGinQhB0Q7n0QhJ4Q8>3Ogj1Q8B3Ph1oP824QXJ1
Oh=nPHB4Qh>0O7anNgn3PGinNG^0P863O7QkO7b0Ph60PGaoOh20P8IoP81nQ860
PH21Ogn1Q8J4Ph>4Q8>4QhB1PH60PhJ3PH5lO864QXJ6Q8B7Q8R?RHb<R8R8RhR8
R8AoP7moPH>4OX1oNGanOh20O7UiN7UlOWilNGQhNGanOgmlNg]lP7aoO7anN7b3
PH=oO7]hNGaoOgQlO7QkNgb1OginP860Q8B1Ph>0OX>6QhN4QX5oQ8J6QX64Q8B4
PHJ4OgmlO7aiO7mlN7]hNgahOX1lNGUiNG]nP861Ngj0PH20PH1nOWn1PH20Ogal
PHN3Q81nO7]lOXB3P7moNg^1P8>6P7ilOX63Q860OgUlPH>4Q81oO7n1Ph=oPh20
Oh67R8N7QX>4PhB4R8R4PH60PhB3PHJ3O824Q8B1P81lNGanP7UkNgUiN81oO7]k
O7QlOh21PH5nOX20PH=oP7mlP8>6Q8>0OWioP8J7Q8B3P821PHB6P81oOh1oQ8B1
P7alOgn1Q8=nN7anNgioOgilO7b0OgioO7]kOh1nOh1lNg]lQ7n0R85lNgb4Q8N4
P81iNH>1P861P7alOhB3P821P7j0Q8J7PH>3Ogj1QX>1P81oNH20Ph>0Q8B0PhB4
Q8>4Ph23Q8R6Ph1oP821QhMoO7alP7n1PhAnNGioOh20P7ioNgj3Ogn0OWmhN8Ao
Oh5nP7UnQ863P7ioO7b4Q8B4P85nOh20PhB1Q81lP7moOgmlO7UlOWmoOh1iNGan
PH20Q7ahNgb0P7n3P7inO866Q8N4Q8B3QhR4Q8J4P823Q8J3O7mlO7n0PH21P7n0
P861P81lO7mkOhB3Ph20P7b0OX20OgakOWilP8=nO7ikO81oPH60P821NGn0Oh5n
OWioOg]oP7]oP820OWmoOX21PhB0Ph20Q8B8R8^8QXJ1PhR8Rhb7QhJ3Qh^9QhV7
Q8J8Q8^8QXAoP824Ph24O7ikO8>4Q7ikNgUkO821NGQgMWaiOgmiN7AhNGR0N7Ul
LGQiNgiiNgahN7^0Ph21Og]lO7n0Ogb0O7UiNgioP81lO7QhOWioOgalO7n4QhJ4
Ph21QXV;R8R8Qh>4S8^8QXR4P824R8R0P85lOgmnPGakN7akN7moO7akNG]lOWn1
PH20OWj0PH>4P8B3OX>0Q8J0PGj1P7j3Q85nO7anO7ilO7ahO860Q8B0OWinO8>3
PhB3OWb0P8>7QX60P823Q8R8Q7n0Q8B;S8R8P7n1Q8B1Q85kN7UkNgn1O7UiNgal
OWilO7QhOh20P7j0O7UlP8>4Ph60Ogn0Q8R3PGmhO7n0P823P7aoOX61PHJ1PH23
Q8>6P81oNganP8>0PgihOgj0Q820O7UlNgj4Ph1oNH20PHB7R81nPH63Ph>3P7ai
O824Q8B4Ph1nPhJ4Q8>1Ngj0P861PGilO7b0P820OWalOh21Q860NgaoP820P85l
O7ioPGn0P7aoO824QXB0P81nPHB4QhAlP7j0Q8B8Ph20P8B4Q8B4P7j0Ph>4Q8B0
O7b0PhB1PH1lO820PhB3PgaoP824PHB1Oh1nPHB7QhB3PH64Ph66P7alNh1oP7mn
O7QdN7aoOgUkN7QiO821OgilO7b0Ph60OgQlO7^3PhB4Nh1oO8>1Q81hP7UhPH21
Ph20O7j1PhB1P81nOX23PHB0PH60PH64Q820P863PHB1PGmlO7j1P7mlO7QiO864
PH=nO7ilPGn0P7aiO7]oP7mlNgalOhB4PhB6PH20Q8>4QX63P7^0Ph=oP85kNh1o
PH>0OWalNh24PhAoOWaiOX21PH1oN7b3Ph63OginO7j3Ph1oP81nOh24Ph20Ngmo
P863Q81lOWilP85oP7alOWb0Oh1lNg]hO7ilO7agNGUkP861OWmlO8J9R8^8Q8J6
R8b@T8b9Qh>8S8R;RhV3P8B6RHJ1P820Oh>6Q7mlP7]iP7n0O7UkN7ilNh1lN7Qh
NG]kOgmoOgalOgn0Oh24Oh63Oh24Q81nO7QlOWn1P7ikO7b0Ph63Q81oP8>8QhB7
Q860PHB4P81lOgj0QhB0P7ilOX24Q8=oP81nPhB7PGUkNgalOhAoNGagO7]gO81n
NGQlP7n4Q85oN7aoPH>7Q81lO7n0Q8B4PgakP8>4Q8B4Oh20Q8R4Q81lO7ioP81o
O7aoO7j4P821Oh1oP8J3PGmoP7j1Q8N4P7mnOg^0Q863OWilOX>0Q8J0OWj0P867
P81kN7]nOWn1OgmlO821Q827Q7n3Ph68QhB4Q8>1Q8R6Qh5hP81oQ8>4P7alNh63
PhV4O7ioP81nPGalNGIlO7ilNG]hM7alP81lOgQiOgb1PGmoNgilOhV4R8MlPhB1
QX>4PgmlNh20OWilN7QhMgj0O7mlNGahP861Og^0O7alP8=lNgUkNgV0QX1lOh23
PhB7Q8AoOXN3PhJ4QX21PhN9QhN6P860Q8N4Q8J1Ogj0PH>3P7mnO7j0PHB0P820
P826QXB7Q860P820OgikO7QfNGQiMgMkM7MnOh5lO7alO7b4QX61P820P8>6QhR7
QXN7RHb9RHN4R8V<SXb9Q8B4PH>7Q8>0Ng]kO823PgahNGalP81oOgUhO7V0OWao
Ng]hNGakO7QlNgUlO7ihNginP7n4QX>0P8>1P8B4Ph>0P823Q823OWUlO7j0Oh1l
OgahOh>0Q8>3Q8B4QhR8QXN6Q8B4Q8R6PH60P8B3Q85oOWQkPH24PH1lN7inPhV7
Q820PH64Q8R4OgakPGb0Q7moM7MiNGn0P7]gN7QkP860OgQgN7QlP820N7MgN81n
P85hNgUiPhB7PGn0OgioPh>0O7]oOX21Q8N1O821P8B8R8B3Q8>6R8B6PGUlP820
Q8AoO7alOXB4P8=oNgmnPH>0PGinNG^0OX23P7ilO7n0PH20OgilOh60PH1lO7Qn
Oh23O7moO820QXR0Q8>0Q8N9RHR;QX>6R8V9R8J4Ph>1PH60P7alOWUhO7ahNg]h
Ng]kP7ilN7b0O7n0P7mkO7ioP81oO7]lNgj1P820Ngj0PH>3Qh1oP7n3Ph>3P7ik
P8B7Rhb;Q8>3Q8R9R8>3PH64QXR8Ph20P7n3QXJ1O7b4PH24Q85kNgmnOh21Pgai
N7b0O821O7ahNgioP7moOgV0P7n3OX60OX1lP7moQ821PGn3P861O7ilO81lPH=l
O7QkOg]oQ7anMg]nO8>0P7mlOX21Q8B0PH60Q8B3Q860O7R0Oh24QXInO7mnQ823
Q820P8>6PhAoP81nPh23Q81lN7ilO8B0P7miO7j4Q8B8Q820P861P81oNgQkOWao
OWUkN7ilOhB3PGn0PHB8P8R8Q8N6QhV8Q864P824Q8N4OgioPH63Ph1lO7UlP820
Oh5nNginP8>0Oh1oNGb0P820PgmlNgb4PhB7PhB0P8B3Q81oOWj0P821Q7akOWQl
OWanN7QiN7ikNgmfN7]iOWn0O7QkNgn0PHJ3OWUiO7j0Q8J4OWb0Q8B4Q8B3P824
QhR4Ph5oOWb3QX64P7aoO8>6R8V7Q8N8R92?S8n8R8N8Shj?R8>7Ph27QXB1O7ml
O7ioOgahN7QiNgaoOW]iO7anPH>4OWb0P860P8AlO7ilOgQlOWQhMWQhN7QhN7Ag
M7]lNGmnOWMhPGn4Q820OX60Q8J1Q8>0PHN8QXV6Og]iN7b0OX60OgalP864QhJ7
Q8B4QXR9RHR0PH>3Q8B4Q81nOgn3PgioNgIgNgalOgagNGQkP7alO7]gNG]lPh60
OgilNG]nP81nO7mlO820P81nO827Q8J9Q8>0PHR4Q8B3PganPHB4P820NGaoP8>0
PGmkO7b0PHB0O7akP8>3PH1lO7ilP8>4O7b0Oh20PhAnP7j1Q824PhB4PHB4QXR4
Q820P7b3PhB1O81oO821Q863P7ioOWb1Q823P7anP8>1Q81nOX24Q863OgQlO824
Q8>0PGanO7j1Ph1lOWiiP7mnP7UkOganOh>3OWmkNh1lOh1lO7QkO7j4P81nOX60
PHB4Q7n0P820PhB4O7n1Q8N4QhQoOX21Q820PGn0O824Q821Ph1nOX>4PhN3P7io
Ph23R8B0P823Q8=oP81lOh21PH1nO81nO8>4P81oO7j0Oh20OgUkNGb0OX20O7al
P8B3Q8B0OWb0P821PgaiN7j1P8B3OWmhNh20Q8>0OgQiOWj3Ph21O7b0Q8B4PhB3
P863R8N4Q860Oh>4Ph1oOh1oP8>3Q8B1P7j0Q820P7n0Oh24P8>0O81iNginP7ik
N7QiMgaoNGj0O7aoPHB1P81oPh21R8R8Q824Q8N8QhR6P8>4QXR3Ph5lO7b3PH61
OWanP8>6Ph>3OWn0P8B4QX1lOgb0Ph23O7UkNh20Oh1oO7UiNg]nOh1lNG]lP860
P7UhO7QnP864P7ioO824QXJ4P7n0Q8J7R8=oO7moQ85oQ81oOgb0P7n0OW]hN7]l
OWmlNGQhO7akO7akN7anQ8B0Ph1oOh26R8N4P824Q8R8R8R0PH>4R8R<QXB0PH>4
R8R6Pgn0Oh23Q8MnNgb0Ph24Qh61O7b3P8B8QhB0P8>4R8B1P7akO81nOWaiMgQk
O81oNgIgMgQnO7alMgAhOX20PH1lO7UkPH63PginO7moO8B1NgalO7UlP8>4OgUo
Ogb0PGmnNgj0P8>0Q81nP8>4Q8J8P7b0PH24Q863P7j0PhJ1QXR4Ph21QXB4Q85o
O7b0Oh60O7aiN863P8=lN7IhOh20P7QiN7V1Q8b7P8=iNh24Q863O7UnOhB6Q863
P7n4Q8R4Q8>0OWj4R8B1Q7ilPH>7R8>3OganP8B3Ph1nO7^0P85oO7iiNGn0PGml
O7mlP8>4Q7ilO7^0PhB3OWmkNGmoPhAoOgakOX23Q8B0OgmoP8B7Q820OWn6Q8N7
Q820P8>7Q8B1OWalP860Q85nO7]oP861OW]iO7j3Ph20OWalP8>4R8J0P81nP8J8
R8B1P824R8b<Q8J4P8J6RHR4OgalOX61P8=iN7IgP7b0P7QkN7QoO8>4OganP8>4
Q820Ng]lP81oP7ikO7]lP7moO7]hN820P81nO7UiOX24Q8B1OX20Q8V7Q81nOWn4
QXN7PgilO824Q8B0O7UhP8>4QWioNGV1P8B3O7agMgj0PH1kNgQcN824Q820O7ao
P8V;PH60P823QhN7R7mlOh21Q8J0NgilO8>4Q8=lO7j0QXJ7Qh1oOh66PhB8OgUl
OhB4Q8J0O7QlOh23Ph5nN7aoO81oOW]dMWQlOganOW]hO8B3P7mlNGQnP863Ogai
MgUnQ8>3Ph1kNhJ8Q8B4Q820Q8R4QhB1P7^0PH20O7aiMgaoP7mlNgQhMgn7Q85l
OWalQ8J;Qh23PH24R8b8Q85nPhB7S8^7Q824Q8B6Q8AlNGakP820Og]hN7^0PH64
OgQiN823Ph=lOWUhOh23Q7inO7b1Q8B0NgmkNh21Q8J1O7inOhB8Q8B4P820Q8B4
PgakN7R0Ph>4O7b0O824R8B0P7j4R8J8RhB0OWn6QXR8Q8B0OXB4Qh>4Pgb0OWin
OWilMgIiOgn0Ph1lO7b3Q8B6Q8=nNH64QXR1PGalPhJ7QhR6P7n0QXR8QX5oOWn3
Q8N4P81oP8B8QXN1OWikP8B4P7]hNGUlO7j0N7AhN7b0Q8IoN7QiOgn4R8>0O820
OhJ4QX1lO7b0P824O7]gMh1nP8>0OWAfO7b1OgilM7MhOWmnOgahMWanP85lNgMd
N7b0O7akN7QhP8B3PGinO7n1Q8N3OganP8B7Q8>0O7b0PHB9QX20Ogj0P8B4QXAl
Oh20R8R4Pgn0PHB8R8B3OX21OhR4Ph1lP7n3QhR8Q81oP8B7Q8B3NGalO820Ph1h
N7QnQ821PG]kN7b4Q8N8Ph20PhR8RHV0P7mnQ8>4Q85oNGQoQ8J1OWmkNGioPh1i
N7QgM7b4OgikMWAfP8>3Q7aoOWb4Qh^9P820P8>7S8R4P7alOgn4R81iN7AhOh21
OWQhM7QkO81iN7AdNGn0P81lN7alP8J7Ph1kNGV0Q821P7QlNgn4Q8IlO7ahOh20
P7igMgQhP8B1OgUhM7UnP8>0NgaiO868RhR1Ogj0PhB9R8=oOh24R8J8Q8=oPHR8
SXR6Q823PHR<RhR6Q7b0QX^<QhJ3QhN4R8R4P7n0PH64R8R4Oh20P821Qh1lO7ao
P8>4Q7miO7inP85oO7]hNGj0Q85lO7MkOWn1OWahMWalOX60O7QhP826QX60O7Qh
Ogj0PG]hM7MlO7n1OWahN823R8J0Og]kOX24Q8AnN7]oOX>4P81lNGj0Q8J6Q7il
OX69QhB4OgahOhN7RHB0P7aoQhN8Q860Ngn0Q8N0P7]hNgb0Q81lNG]iO860Ogmh
MW]oPHJ7Q81nP864R8R8Ph61PHR9R8N1Ogn1QhV8R8R0P863R8b8Ph1nOX>6R8B1
OWj0OX64PgmlO7anP863P7ifMW]iP81lOWMfMgb1Oh1lNGQhOhB4PgmoOgn8R8V8
OgmnO860PH=nOWUiO7j4Q7ilMWQkO820OW]iNgb1Q8J3O7mnOX67R8B3P7b0P8B8
PgikNgb0Q8B7P7akO7ioQ8B0P7QiPHB7QhB0O7anPHB3Q81lO7b0PhB4OWalO823
PhB0NGaoP8J4P85lNgQnQ8B6PganO7b3QXJ1OX1oO8B8Qgn0Ogb0P8>0O7ahNG^0
Ph20OgUkNGn3PHAoO7alPHB8R8B4PGn3QXJ7QX20P866R8B4P7UhOh>3Q860O7Qn
PHJ3QX=lNG^0PH>4P7agMWb0PH60O7]iNh23Q7mlNG]oP8J4P7ikO7j4QXJ4Ng]h
O864R8J1Og]oQ8J<R8>0O7j4QXN7PgilOX24QX>1NGQiO8B4Q81lO7^0PHB7Q7mn
O7n1QXN4OWakO7mnPh=iN7QlP824P7ilN7b0PhN3Ph1kO824R8N4OW^0P8B;R8Ao
OWQlPh>7PGikMganP8B0PGahOX20Q8B0OW]lP8B6Q8AnN7b0O8>1P7adNGioPh>1
OW]lP826R8N4Ogb0P8B7Ph1iN7ioPhN3P7]iNgV0QX>0OW]kNhB8Q8AoNGalOhB7
P7iiNGV0QhJ7PGn0Nh>6Q8R4Ogj0PHB8QhB0Og^0QhB7Q7ioOX23Qh=nP7]iP824
Q81oNgUiO8>1OWiiN7V0Q8B1O7UfN7b0Q863NgQkO8J6Q8AkMgQkPH63PgmkMh24
Q8N0PgalP8N>S8b?R8B8SY2CT8n;QXR<T92<SXR4OhB<Q8B3P7mhO864P7]hN7Mh
OX20O7MaLGAlP7aiN7=`LgQlO7QgM7=`N820OgalOWb0Q8N8Ph20Oh24QhR4P7an
Oh64Ph1lOW]hP7ioOg]kNG]oOX5nNGagMWb0Q860OWaoO868QXB0OWb1PhN7Q85n
P824RHR7PGmoOh24Ph1lN7UkPHB7Qh5nO820Qh^6P7alNh24QXR3O7UkP824R8B4
O7j1P8^8P8B1Oh23R8N7Qgj0PH66Q8B4NgalOhJ0P7ahN7IiP81lO7QhN7V0QX1o
OgilNh26Q81iMgmlNh21OWQdNgalO7ioNgIhOX24Q821OgaoPHB8R85nO861R8b9
Rh1oP864QX^6PgmkPhB4QX=oN7QlOX23P81lMg]oQ8>0PgiiN7b7Q8=oNg]gOX23
Q7inN7aoOhN4P7mkO826R8>0N7IhO7n4Q81lNGMhP8N4Ph1iO7b0R8R6P7alNgn7
R8V0OWiiP8>8RHB3N7b3Q8V7R8=oO828R8N8PH20P868Qh60N7IiO8B4Q7mhNG^0
Q8B7PgakO866QXR4O7UlOXB7Q8J0NGb0Q8R7R8AnO7b4R8B4PH1lNH21PH>0Ogai
O7moOWahN7]lOh20O7QlNGb4P820NGQhO8B4Qh5oOgQlP8>4P7]gNgn4RHR7P7]h
O7n4Qh=lN7MhNgn0PgmgN7MiOh64P7mlN7b0PhB0P7UhO7j4Q85oNGQlP864PG]k
N7UlPHR0Ph=kPhB6RhJ4PH20P8V9R8B3P7n1PHR4P7alOgaoPh>4NgQnO866S8^3
PH21Q8B8R8N0OWn3R8^>R823P8B4Qhb9QXB0Q8B3R8B1P7]nPHB7Q85nNGj0PhR4
P81lO823Qh61OgMiNgb3Ph1oNgUlPH60PgQhMWQoOhAnNGadN7j0PH1nN7QiNh21
Og]hNG]lP8B8P7b1PhB6RHj9PhB1PhJ4QXN1OWUnP7n1O7QlN7QlP8AnOW]iNgV3
Qh1nNGIhO820P7UfM7IhO8B4P7iiNgj1Q8B3OWUoPHJ4Q8N1PHB6S8^;R8>4P867
R8R7Q820P863QXAoN7UlOh24PgmnNGaoP8B0P7ihOX23R8J7PGj1Q8R9R8R4PHB4
S8b7R81nO7j3QXN4OgaiN7b1Q8B0P7]lOX64Ph1lMgMlN7j4OgaiO864QXB1P7mk
OX>6Q8>0OgakPH61PGUhMgMkNh1nNGQdN7]lP7ihMgAcO820Q7iiN7R1P8B7Oh5l
NGn0QXB3P7inP8>6R8R6Q8B1QhV;S8V6PHJ4QX^8QX1lO8>7Q8R6P7QlOgb0Ogan
MW5gOgn1PGihMh1nOXAnOgUdNgb3Ph21NGQlP8B7Q8J0OX23Q8N9Ph20P8>4RHR4
Pgn4Q869Q8B0Nh63Q8J7PgilO820PhB3P7UkOgmoP81lNgUhOX20P7mlN7QnOhB0
O7ihM7QkP85nN7QgMg^0PGmlN7IkNh64Q81hN7UkP8J4Ph1kOWj3QhB4PH20O8B9
QXB3P820QhR8R81oOg^0QXB4OgQiNgj1QXAkN7MiOh>8PGilMWUnP8B4OgUhNgn3
QXR4PG]lP8>4Q81oN7MlPh20P7ilN7j0Q8R3Q81nPH>6QXB1O7b0Oh21PH1kN7b0
P8B4O7iiN824QhB1P7UiO7j7Q820N7mnOh20Q7ihNgQlP821Og]lO824QhB0PGio
P8B9R81kO7]kPHB8P7akNh23QhV4PGn0Q8R9T8R6Pgn4R8R<R8B0Ngn0OXN4Q85n
OWj7R823P7]iO8>4Q8=nP85oP8J8Ph60P823QXN3P7mlOWn1Pgn0O7MkP824P7ak
N7QlPhAoP7ahO7b0Q81oNgMhNg^0PgakMgMlO866Q85lN7n0OhN7QWmlPH>8R8R4
OW]iOX64Q81nMgQlOX20O7]hN7QlPGaoNgMhN7alO7alO7]nQ8J7R8J4PhB7S92<
R8B1P8B8Qh^9Ph1nQ8^9RHN4O7]oPhR4Q7n0P7b4Q8J3O7ihO81oPH1iN7QkO821
OWmhMgUnP860Oh1lNgb4Q820OWakO8>1P7mkN7QhP820Q7ilNgn6Q8N8Q81lO8>4
PhB0OWIhP820OWUhM7InQ8J6Q7mnNh>;Rhb;R8B3QXR8Rh>0Ogn3Q8V;QhAnP861
QhR7P7moO7b0Ph=nNGQlO7V1Q7ahN7QiNGj0Og]fN7QiNh20NGQgNGUnPH1oN7Ui
Oh>0PGmkNGUlP861NgalNgn1Q81lO7aiP8B4PGalO7aoPHB4OgalNginPHN3P820
P824R8V1P860Oh26P81nNGn0Oh23P7UhNG]oP863O7UlOh64Q8B3Oh64R8R9S8B3
PHB9QhJ7Q81oP8B6PHB1O7n0PHB4Q8B0PH66R8B6P820NhB6Q8B0Pg]nP866Pgmo
O7ilP8J1P81lP824QhJ7PH1lOXB3QhJ3P7]lP828QXB0N7b0P7moPGahOWj0Q7mn
O7MdN81nP7akO7AfOh60Ph1nP7j1QhV4Oh1lO7b3Q8>0Ogn1P8B6Qh=nO7j8QXR<
PHB0O8B7R8^6QX5nPh67Qgn0NGV0P8B6Qh=lOgj4Q8B4OgmkNgn3Ph20O7UoOh64
Q81lO81oP8N4PgmhO7UlPh1oNgUhMWb0Ph=iMgQhO7n0PgahN7UkP8>4PGakO824
QXV6P81lP8B6R8R1Og^0P827Q81nNGj1PH>4P7mhO821Q860Og]nPHB8Q821O7V0
Q8B1O7QhNgaoQ81nO7AdN7n3P860OWanPhV9Q8B0P821QhV9Q821P7n6QhJ4P7ao
Oh67Q8>0O7ioQ8=nPGUiNGR4Q8B1N7QiN823R8QlNgakP823Ph1lN823PHB6PGmn
O8B3Q8B0PH1oPHR7QXAoOWanP866OgalNgalPh60P7]iO821Q8>0OgakP8B3Pgml
NgQlOhB3O7akNg]oPh=lN7QhNgaoP7akO7]lOh61OgahO7alPhB4OWaoO864QXJ4
Ph20R8^;S8^4Ph68Shj>QX>0O7n4QXR3OWUhO8>4Q8B0O7QoQ8B;RH=lO7ioPHB0
OgUhN7V1Oh1lM7MdMg]nO7QiMWIhO821OgalOWaoQ8B3P7b0P821P8=lO820PHB4
PGmkO820PH21O7MgNGn0P81oNgUgO8B0Q7inNGN0P8B4O81iNgalPH1nOWUhO824
Q8>3O7^0Q8N8QX>3Ogb1Q8B1P7mlN81oOhAlOW]lQ8>8QhB1PH64R8R;R8B3Ogn0
PhB1O7QdMgioP81lNgQhOh>3P7mlOWn3QhN8Ph23Q8^9S8b4Q8B1R8R8R8J1O7n3
Q8R7Q81oO820PhB4P7akNgb0Ph5oO7MlOWn0PH1lNGV0P821P7alN7n4Q8N0PHAo
PHB7Q820OWb0P8B4P81kO7mlP860P7]iO864PH60P7anQ8R8Ph5nNgb0Q8R8Q860
O7b1PhB4OgmnOgn0QXB1P7inP823QWilOX24Q8N8P81kOXJ4QhN4PGb0Q8>4Q81n
NGQlOX20O7UhMW^0OX60OWaiP826R864PH1iP8J3Q81lO7alPHB3OW]lO821QXR6
Ph60Ph>4Q8=oOWanPH61Q81kNgUoQhJ4Q81lO823Q8=oO820Oh64QX1kNginP8>4
PGQgN7b4P8N1NgQdOX>4QXAoO7UoQXB6PHB3Nh64QX1nO7]kNg^1PGioO7]oPHB6
Ph20NGb0PhAoP7UdNGUoQ8AoO7agO821Q81hMgIhO821Og]gLgMlOX64OWUhMgV0
P8B0NGQfO7]lP7QkN7AiO860OgikO820QhN3Q7moP8B8QXN0OX64Q8^>RHN4PHR<
Rhj8RH5lP7j6QXB7O7alO8>1Ph=nNG]lO866PH1lO864R8R7PGUkOgn1Q81oMWMl
O860OWikO7b0R8J1P7mlP8B7RhR0Ogn0P8>8R85oO7ioP8>4PgmnNGb0P820OWad
NGn0Q81lNgIhO867Q81oO7aoPHB7QWmhN7n0P8R4Q7miOWn6Q8B4OWioP8B3Q8B0
Oh24Rhb9RHB3Q8B8RhR4P7aoP8>9Qh=oN7UhP824P7QhMWQkOh5oO7UhO821Ph5n
N7QlP8>6Ph1lNGb1RHb;QX21OhB<S8^6PH1nPhB6QWilN7]lOhB1P7ahOWb3Qhb8
P7moP8>4QhB3OWaoO7n1P85lO7aoP7ioP7aiP866R8B4OW]kO860Oh1lMgIgO823
O7QiN7R0Q8N6PH60Oh27RHV4OWinP864Qh20Oh24PhJ6Q7mlOX>6R8N3PgilPhJ8
R8>0Ng]nNh23OWafMWQhO7inO7AdNG^0Ph>1OWQhO8B4OX5nNG]iPHB4P7aiNgb0
R8R1P7]lO828Q85iN7QhP8>6PGalNG]nQ8R8PGalO864RHb6PGilP8>4QhAoNgQn
PHB4Q85iNGn0RH^6PgalO7n7QXB0NgalPHJ6Q820OX23Qhb9Q820P823Q8>0N7Qk
NgioP81hN7QkP8>1PGagNGj3Q8J7OX1oP8B4Q861OWQkP823Ph5lN7]kP861Pgai
N7n6Q8B3Q81lOXN8QhAlP7aiOh66Pg]hN7QnP8B6O7UiN7j0PHAoN7QhOX64QhAl
O7]oQ8N<QgilNGb3Rhb4Pg]gNgn4PH1oMWMgN8B0Q8=nNgR0PhB4OgmnNgn1Q81n
O7MiO824Q85kO7]oQXN8Q81oNGn0Phb4OgmnOh28R8J4O7ilP8>4Q7ilMWR0OhJ6
PGihN7^0Q8J4PgahOX24Q8AoNgQlPHB;R8B1OX24R8j9QXB0PhR;Shb7Q7n4PH><
Q8B1O7inP8B6PG]hNGUnP8B7P7anP8>7RHB0O7QoPhB8Q7idN7alQ8>0P7McMWQn
P81oN7MdMgj0PgmnMgQlO820PGihNgQnPgj0O7QkN7b0P85lMgQgO820QWihN7In
Q8B4Q81hO8>0QXR0Og]hO866QXB1Ogj0Q8R6Oh1hMWaoQ8B4PGb0O827QXB1OWak
P8N8R8B0P7j0R8^9QX20P826RHb8Q81nOh66R8InNGQlP8>8Q7ahMg]oQ8B7P7]i
N8>6Q8N3Og]kPH68R8=oO7b0PhR9QXAlN821Q8N4OgmkO820Qh60OW^0O864P7al
MgQoP8B1OWahOgj0Qh61O7UlO824PH1oN7QnP8B4PH1hNGanR8>3PGaiN824QhN3
NgQlP8B4Q81hO7]nQ864O7agM7j0Q8B1OgUlPHN8R8N0P824RH^<Qh1nNgb1QhV7
PgahO7j4Q8J4N7]nOXB3R8=nO7R0Q8J7P7ilMgn4Q8R1OW]hOWn4Qh=nNGaoQ8J<
R81oNh27Q8^8PgmgNhB4R8N4OWQhOXR;QhJ3NgQnQ8R7Q85oNg^1QhR4OWihNgn1
RhB0O7R0OX68Q85kMWQnPhB6P7QhN7b1Q8B1OgAgOh27R85lN7MiP8J4P7ifM7]i
Q8J3P7MhO827Q8B0N7QlO824PGmlN7QlP8B3Q7icO7mlQ8J1NgQdNHB3PHAoN7Mn
PhN<QhB0NH27S8b;RhB0Q8^@U8j>Rh>4R92AS8^6PGinP8b8Ph=lO7]oQX=lN7A`
M7QlOgikM7AfMX27OWilMWMlP8J4P7QiNgMnPh60NGAfNgb0Ph1lN7QlP864Q81k
NgaoQ8>0P7QhNgb4QXN6OW]gO8B3Q85nOWalP8N6P7ahN7QoQ8B0NgMgO7n4Qh=l
N7UoPHR9R8AlO824R8V8Q7ikOh>7QhJ0N7QiO8J4PGiiMgAiP8B1OWahN7b1Q8J4
NgQhNh26QhJ1N7]nP8N6QX1hO7R1RhB8P7alMh61R8R0P7QhOh24Q8AoNgaoPhJ8
QWinO7b3Q8R7O7]iNh21QhQnN7UkOWn4Q7mlMg^1P8R8QX5lP864S8^8Ph1oPhV<
S8R0P7b6RHb@S8J0Oh>6Qh^;Q81kOX>4R8B3O7IlP8>6PH1hMWQhPH5nO7QdM7R0
QXB3Ng]hMh20Q81hMW1dO821Pg]fLGAkOhJ4O7QfMgb1QhR3O7UlPHJ8R8AoMgR0
Q8R7Q81kOh23QXB4O7]lNhB4Q8AlN7AhP824PGalMgb3Q8R8Q7]iN7j6R8^8PGml
P8R8Rhb3PGb0QXB8Q7inO7b3QXN6Og]kNH24QhJ3O7UlPHB7R8=lO7UnQ8J8Qh1l
N7b4PHN4O7QdO823QX1lNgQlPHN8Qh1lOWj7S8j8Q81iNH26RHN0O7QhNh28Q81l
N7QhOh61PGaiN7R0P8>1NGQfNGn4QgmiN75dOWn3P7ihLGUnPHR7PgaiOX26SXb8
Pg]lP8J7Q8J0O7b0Q8N8QX1lOWj0R8N9PgQkO8>6QhR0NGQhO864Q7ihLgAlOX64
Q7ifNGb4Q8N7P7UfOhB4RHAnO7QlPhR8QX1lN7j6RH^6PGagNh27R8B3O7QlP8J9
R8B0O7QlR8V7Ph1kN7b1R8R3O7]hNH26R8AnN7QhOXR9Q8=nNgj0R8^8Q7ihO826
R8R4OWanOXJ8R85lO7QlPhB7P7]fMgUlQ8R7Og]kNh24R8QnN7QiOX26R81iMgQn
P828PGUhM7b0Q8B0O7AfO7n6QX5lM7AhOhB6Q7mgN7^0R8R8P7UkNh>7R8IoNGMl
P8B<RH=lMgUnQ8N6PGQhNgb7QhR6O7QhOhB4QhIoNgAlPhB7Q7moO7b1RHb9QX1n
OXJ;S8j7P7n0PhB8RHAoNgUnQ8J7QgihNGb4R8B4P7QfN824Q8AlN7AcO821P7Uf
M7MnR8V8QWinP8B8S8b7PGakP8N9RHR0NGUnQ8N4PgmgMWQoQ8J1O7QfMgb4QXB1
O7akO8N8Qh=kNGR0P8B8Og]gN7^0Q8B3NgMiO8>6QhIlNGMhP8B4Q7miMgQlP864
OWUgM7b1Q8>1OgQlOhB;RhAlNg]lQ8N7QWiiN7b4QhN1OWahO8>8R8=kNGIgOXJ9
Q7ahMgUiPHB3NgQdMWb0Q85lN7AdNGj3PH1iMgQoPhB7PGmlNgb1R8R8PGalP8J9
Shn7Q7j0RH^?SX^3OX24RH^9QX5nNh28RHV4O7QhNhB6Q8IlN7^0Ph^8P7adM7n3
QXB6OWAfMh66R8^4P7QoQ8B<Q8B1N7b1R8V4Q7ilO7j4RhN4PGQkO8>7QXQoNGQf
OX64QgikN7AlP8>6Og]dM7mnQ8R0O7AgO7n6R85kN7MlQ8R7Ph1hMgj0R8V4PGal
Nh68QhJ0O7UlOX66PgmgN7UlPH20O7IcMgn3Q820N71dNH24P7mkMWIlQ8J3P7Ui
NGb3R8V4OW]iOhB7S8b4P824QXj@S8V0Oh66Rhj?Qh5nNH68RHR4O7QnOh27Q7il
M7InO864PgaaM7QlQ820OWAcMW^3Ph20O7UiO8J8Ph=lNgUiQ8J6PG]hNGV1Q8>3
O7UhNh64R8>0O7UoQ8N<R85lN7^0Q8J6P7UiNgn3QhB0O7QgOXJ6RHQoOWV0QXR8
OgahLgaoQXR0P7QfO7n8RHB3OWilPH^8R8AlO7InQXN7OgilN7^0R8R3P7alOhB<
RHB0P7]kPHJ6PgmlMgMnOXJ0N7ahOXB8T8R6Q7b3Q8R?R8AoO824RHb9Q7ioOgn4
RHJ4OgQnO7j6Q8AlM7MhPhB1Pg]dM7AlPh>4NgQgMW^3Q85nMgIdNH>1P7mhLg1f
O823OWMdM7N0PH5nN7IcMgb4Q81nNgQlOhR<R8IoO7moR8^8Q7inO7j7RHR4P7ao
Q8R<RhN0Ogj1QhR7QX5lO7n3Q8B4OWUiNH>7RhQoO7alP8B8R7ikN7R0OhR6P7af
M7]nPHN0N7IdN7n3Q85lM7AlP8B8Q81oNgj4S8b<R821PHB;RhR6P7alP8B8RH5o
O7^0QXN6Qh1kO7b4QXN4O7ahO8J8ShR3QWj0QhV@RhB0O820Q8b8Q7iiN7b3Q8J1
NGQfO8>4Q8=oM7AlPH68Q81lMWQlPhJ4PgmkNGj3Q8>1OWUkOhJ7P81oNG]nQXR6
PGahMgR1Q860N7IhM7b1Q85kO7MlPhB8Q7ihN7]nPH60O7QfMgn1Q8AnO7MiOWn6
PH1lN7UlPhB4Q7ahO868Rh^8Q81oP8R>S8^4OWb0Q8V<Q7mhN7MiOh20NGAdM7Al
Ph1nMgAhO824Q81hMWMiPHB7Q7alMgb3QXb8Pg]gNh67R8J3OW=hOhJ;Q81iM7Qo
QXV8Ph1hN82;S8^8PGikOXB<S8R3N7aoPHV8Qh1lNg^0Q8R;Q7inOX>4RHb0O7ak
P867QXAnN7b0Q8R9QgmiO827R8R6O7QiNh68RHAlNGQlOX24PGadMgUkPhJ4O7Mg
M7V3QXB0N7MhNh21Q7afMWIhO820OgihNh24R8J3O7QlOXB8QXInNG]lPhB6R8=n
O7b1PhB8PgUhNGb0QhJ3O7QhO864QhB0NgaoQ8J6S85hNH24Q8N4P7UiO86<RhN3
P820Qhb<RhAnNgj1QXN7P7]hN7j0R8V1P7]iP8>9R8B4N7IlP8R;QWiiN7V0Q8R6
P7QgO7j0R85nNgIkO8B8QX=kN7V0R8V8QX5nNh27RHN3O7AhOXB9R8IlN7alPhR8
PgakN7b4RHR6PGakP8>8R8R4O7]nP8J9Q85lN7UnPhB4PgalN7^0Q860O7QkN7n4
Q8=nNgUkOhN7PGmkNg]lQ8B4OgQiM7QnOhB0O7inP864Qh1oOWb0Ph67Q7mhNH21
Q8J1OgahN820PhAoN7AhO7n4PGikMWMnPhN6P81hNh24R8B4P7]kPHR;R8R4O7n3
S8n<S8J0P8B;Shn9P7iiNhB8QXB0O7]nPHB6QX60O7QlP821OWQhM7IlOWalN7Ah
NGmoP8=oNGQnQ8B6P7mnMW^1P8N0OWmiNGb3QXB0NGQhNgn4Q7igM7IkOX20Og]h
NGj1QhJ7P7alOXJ;RhR4P8>1PhN<S81oOWj0Q8R;QWikO7n3QXR4O7MhPHB6R8J0
NGMlPHJ6OgaiMgV0QXB0O7MgNh24Q8AoNgQlPhB<RHB8P827Rhn9Q81nP824RhR3
P7]lP7j4R8B0N7QiP81oOW]dL7QnPH5oP7UdNGn4Q8=lN7QfP8B4QWiiN7QlO8>3
O7]hMg]lP8=oNgQiP824QX>0O7UoPHB7PH1iMWaoPhB4Q7akO7b1P81nO7mkOXB6
QhB1O7b0QXR8QhAoP864RhB4OgahMh20PGadN7IhOhJ7P7mkNh>4S92;R8>1PhR@
T8n<PhB4QX^<S8J3P7^0PhR9Q7ioO7b3QhV4PgihNgn0Ph5kO7IgO828P7mlM7]i
O8B0O7UgN7b0Ph>0OWakPHN8Q7inM7R0P8R0OgagN7N0Rh>4Q7anOX2;S8B0OWal
P8^8Ph1iNGUiPHAoOgMdMWN0PHAnN7mnOX24Q7ilMWR0OX>6Q7mgNGalPH64P7Ql
Nh21Ph=lO7QhP863Ph5lNgaoPhJ3PGilO7j0Q8J1NgilOhB3QXIlNgmlP8B4PH20
NhB7QXR7QX1lQ8B;S8B9PGb3PHN9Q8B0OW]nQ8J4Q81lOX20QXJ7Q7ioP8>8PhB0
NGMfOX60P7adM7AkP863NgQgM7b3Q8J0NgQiOXJ8RH=oO7]lOhN4O7QgN7alQ8R4
OWQkO821QhR0O7^0PHB;Q8J0NH21Q8R8Q7]lP864QXJ4NgUnP8B8R81oO7j1Q8J3
PgaiNG^0PhB0O7]iOX24QhB0O7ioQ8B7QgmlNGj3Qhb8Q85lO824QhJ7PGn0PhB7
Qh>0NgalPHJ1Og]gLgAkOh1lNgIaL7AlP81lNg]gN8>7Q81lO7UhP8B0P7alO7b0
RHR6PgaoO8>8Q8AlNganPHB4P85lMWb0QXR6P7UlNGb6Q860OWUkPHJ7QhAoO824
R8j;R8B0P824QhV4OWihNh64Q8AnN7QkOX24QX1iNgn3Q8R9Ph>0NHB7RhR4Q7n0
Q8R;R8N1O7]lQ8J6Q7akNgMlP8=oNGaiO7moPhB1NG]lOX24QX>0N7^4Q8R8R81k
N7aoQ8B1Q7UhOWj1Ph5nMgUlOX>0P7adMgV0Q8>0O7QfNh61Q8=kMWMfMWb0P7ii
N7anPhR9Q7n0OhB8Qhb7P7alP8>6R8B0O7AhP824PH1lMWInQ8B4Q7iiNGanQ8J0
P7alP8>8Q81lNg]lP8J6PH>0Oh66R8b8P81lPHB8S860NGIlOX20P7mhMgMlOh20
OgmkNgn3Q8B1O7akO824Q8=oNGAfN7n3OWQgLGAhP8B0OWQkNG^1QhR0O7akP8N8
Qh>0O7b3Q867P7alOX63R8R4PG]lQ8N7RhR3O7]lOhJ4Q8AoOX24QhJ3P7alOWn4
QX21OWalOXB1Q81hNg]nPhB8PGakNH20QXR4OW]iNh24Q8AlN7QkOh26P7mkN7b0
Q8J8Q823PHN<SXn7PH>0Q8N9RhAlN7V0PhJ8Ph1iN7inP8>1OgQkPHJ<R8R7P7b4
QXj;RH^0PH21RhR8Qh21P7n8Q827OWahOXN4R8=oOgQiQ8B0P7]hMgIhOh5nN7Md
MWanP8AlNGakO866PGioNGQoP8>6PGalO7]oQ8>0O7]lOh64QX>1OWn1Qhj;R8Al
O7b0Q8J1OW]kO7b1Q81nNgMgN7aoOgilNGQhP8B1R7ilP7^3QX>1NgalNH24P7ah
MgQhO8J0OgafMgUlQ8R3OgahO8>6QXN0O7]lP8>8R8N0Nh24QhR9R820PHB9S8n<
Q820QXR<T8b4N7R0P8J4P81hM7QnQX>7PG]iMWb4Q7mlN7MgO827RhAoOgaoPHJ9
R8=lNgaoQ8N1P7UdOWn0Q7j0NgMgMh20O7]dLFm`O820NgIfL7InPHR0OW]fNh24
Q8AnMgUlP8>4PG]hM7N1P8>1Ng]fN7b6R861N7MlOhN9QXB0OganQXN6Q81lN7b1
Q8N4NGaiNGn3QhB0OgaoPh>9RHB3Nh66RHb9Qh1lNh>6R8N8QWalP8B9R8J4P7]l
P8N7OWahNGalQ85nO7QiO7b0Q85oNGUnP8J6Q81lO7b3QhR9Ph>0OXR;T8b4Q820
PhR?SXN3O7b1Q8b>RHIoOX64R8R4P7alO7n3QgmnMgAkN7aoNgagLgUkOhB0PGQh
Ng^1PH63NgUhO820Q81nOWUoQ8N8Qh5lP7n3RhV8P7mnOX>3QhR0O7^0Q8N<RhN0
Oh21R8V<Qh5nO7b3R8R6O7n0OXB7R8V0O7akP820Q7ifL75kP823O7MgMW^3Q8N1
O7adP8B4T8B0O7N1P8J9Q8AlNGn0RHR3Q7ahO7n7QXAoNgakPHJ7QgmkO7QhP8>7
Pg]nOX24Rh^4PGmoP8>8R8InM7alO8>4PgadN7UoPH63NgAdN7R3Ph20MgQhO8J3
Qh1gN7]lP864P7aiN7n0PhB0O7MgOXJ9R8R1Oh20QXN<Qh1nNGn0PhV8P7]hO7n1
QXB3NgAkNh24Qh5hN7IkPhJ4P7mhNGV0R8N3P7alO8>8R8AoO7inQ8R4R81iNGUo
QXR;Q7alNH24Q8V4OW]iP8>4S8IoN7QoPh>4PgakM7^0Q8R0O7QcN7n0PGiiN7Ah
Oh28R860O7V3QXV;QhB0PhR8S8b4PH1lQ8>7SXB1O7ioOhN8Q81hMg]kP8B3P7Qf
NGanQ8=lN7IgN7n3Q85gMg]nPHB6OgUfMWb0Q8AoNG=fNGb1Ph1iM7=hP8B8PGml
N7b0RH^7PgalP868S8N0OWMiO8>6QXAhN7QhQ8R8Qh=oO867RHb8Q7mnOh67Q8Ao
N7QkO8>6Q7ihN7R0Q8B7PG]iO823Q8R4Og]kPHN9S8V4OWb0QXV;R8AnO7b4QhJ1
NgUdN7UoPgmkM7AdN8>3P7]cLg1gOh20O7IfMgV0QXJ0OW]lP8N>SXN1Ogb0QXR8
Q81iN7^0R8R7Ph5oPhJ8S8R4Og]oPhR8R8AlNGQnQ8R9PgihMgUoQhR4O7QfN7j0
R8=lNgIlOXB8RH5lO7^0PhB4PgagMWb4QhB0NgQgOhR8S8B0P7b1Phb;Q81fN820
Q8B0NGAgMWn4PHAlN7IfO827P7QiNGUnPhR6OWUhNgn3QhB0O7QhO7n6Q85hLgIh
OXB7Q7agNG]lPhR8P7QdNh21QhR6OgQkPHB6RHb3O7b4R8V;R8AnO867S8b;RH1h
OXB4QhB3O7UlP8R8QhAoNh24Qhj9PgilOh28RHR4O7]lOh>4Q85hMWQhOh66R7in
O7n8QXR4P7ihOh23Ph20O7R0Q8N7Qh5lNg^4R8^9P7mhMX24S8R1P7IfN829Q81l
M7=dNh>4PGagN7QkQXR4P7QhN7n6R8J0NgMhNhB8R85hO7QkPhJ4OgQgMganQ8=k
N7MdN7n1Q8=kMgUnQ8^9S8QkO866Shn>Q7mnNhB<S8b6P7aiOXB8Q81lNGQnQ8B8
Q7ahN7^3R8R4OgmiO8B7R8AnNGQhOXJ7Q81iN7^0Q8N9P7akNhB8R8R3OWUdO8>4
QWiiMW1gNh24OWmhM7b0Q8V4PgikQ8N<SXN9Q7QnQ8V;QXB0N7MkQ8InNgMcL7Ao
Ph=lM7=cMh24Qh=nNG]oQ8b;RHAnOWj4S8b8OgQkM7^0Q8MlNGMfO866RH5lN7Ml
OhN<Q7mnO824QXb8P7ikP8J7SXR1O7V0P8B;Q81hLgUlP8>1O7A`M7QnP81nN71d
Nh23PHB0NgUlQXV8PgmkO7j3R8^8P7alOX>6S8R0NGQkP8N7Qh5hN7^0Q8N7QX1h
N7b0Q8B0NgQhN8>6QXV1O7alQhR9R85nNGb4R8^8Q7iiNh28RhV3OgalP8R<Qh>0
NgR0Q8J8Q7agNGV0R8J1NgMdMh24QXAnM7AfN8>1P7UcKg5kOX23O7MdMWb3QhR4
O7UiPHN8ShN1O7R1R8R<R8AlN8B8S8b6Q7UhOh>;RH>3NGMiP8V8R8AlNGQnQXR7
Q81lNh27RhN3OWQiO8>8QXAnN7]nPhR8QX1hMWUnQ8B4P7MdMWb4Ph=nMWAcN867
Q81iMWIlQ8R9QgmiNgb4R8N3O7MfMWb3QX1hN75gOX>;Q81iMgUnPH^8PGahO7n4
Rh^4O7b0PhR@T8b4P8B3Rhb>Rh1kO7n6S8^7P7UhOXJ8S8V0N7MkPHR8Q81hLgMl
P8J1OgUcLgN0Qh>1NgAfN8B;Qh5kMgQkP8R8Q7QaLgR0R8R4P7UiOX>9S8^4O7Ih
P8R9RHAkMgMoQ8R;P7UdLGR0Q8AnNgA`NG^1QWilN7MgOhR8Q7mkNh21R92<Qh5l
P8J;S8V7PGanQhV<S8J0O7b0R8j7PgmgN7b1R8V1MWMdN7j3RHIlN7AiOhN9R85g
M7QnQXR8P7MdMWb1QXAnN7AdN824Q7mgMWMlQ8R8R7ihNGn4RHn<Q81lP8B7RHR0
NGMhOXN9R81gMWQhP8J6PGQcLgAoQ8N4O7MgNGn4R8R1NGUlPHR8QXAlMgV3QhJ8
Og]kMgn4R8B0OgQhP8R8R8=oO7R1R8b>Qh5oOXB9S8V7QWmnQXb@T8^7PGb1S8j;
QXAlNgn6S8V4P7Q`Mgb4Qh1lM7A`N8B0QWidM71iOXB6P7]`LG^1R8^7PGahO8B9
RHR4O7IkPhV<R8IoO7n6SXj8PgalNH2<R8b3MgUhO8B7RH1hM71kPh>7P7afLgj3
Q8R3O7]hOXB7R85lN7IhOX>6PGQfM7AkQ8R8QW]hNgj3R8^4O7MdN7b0P7miL71a
N7inP7Q`LG1hOWj0NGM`L820Ph5kN7=cNh64Q7]hLg=oPHJ8PGahM7j4RH^4Og]h
O866R8InNGIhQXR<RhJ1NH23S967Rh5kOhB9S8j6O7QhN864OgmhLg=kOh66O7Qd
M7UoR8B3NgAhN8B8S8b0P824RiBITi2<QhJ8TIRDRH>0O7n4S8R0NgAgN828S8Il
O7]lP8N<Rh1iP7n1S8n9QWahOX67Rh^0NGQgNh>6Ph1hMgQkPhR<QX=oO827R8b8
OWahO826S8B0M75hNhB6PGmhM7QnP8AoNGA/LgMoPh1lLg1dMgj3P7]cL7=cNh1n
NgAdL75lOh21LgAgMWj0R8AhMWQiO8J<S8QnNh24QXV?QgmlOX>6RhV7P7QlP8>9
R8>0MgMlPH^;R85gN7UnQXJ7PGQfMgj4Q8J0N7MhPHR<RhN0O823Ri2@S8B6Q8V@
U9B?Qh63Q8R?T8b4OWj4R8b;Qh1fMgQoR8R4P7UgN828RhR3N7UiO8R<S8QlNgal
PhR8PGQdM7^1Q8B1NgA`N7n4Qh1iM7AhO8B8PgagLGAkP8J0P7ahO7n7R8N3O7al
P8B;RHB1NgQkP8J8Q81lO820R8V3P7QhNg^4RhIoN7]hNHB7Q81hM7]hO8N7OgUg
N7j6R8V;OWQoP8>8R8J0MWQlP8J6QX1gMWQnR8N3P7QfNGj3QXJ0N7alOXN8RHB0
N7^1Q8^<QgmfNH>9SXb9QWanPHN<RhR4NgalQ8b;R8=iN7b4Rh^8P7UiNh28R8R0
O7MiOh28Q7mkLg=gOX61OgQfM7R0QhB0NgMgMWj3QX=kO7QgO8>7P7ahMgUkPhIo
O7QgN7b3QhB0O7UlOhJ8R8MlN7MiP8J7PGafMgMnQhB1OW]fMh24R8MoN7MiOXB8
Q7ihLgIkPH>4P7QdLgb4Q8N3P7adN824QhB0O7inPhb;RhAoOgn4RHR8R85lN866
Q8MoP7ihP8N9Rh=oO7MoQ8b8OgmlNG^0RH^4O7QhNGn8S8R1NGalP8R;R85lO7b1
RHb<R7akNh64Rhb8Q7ioQX^<S8R0O7V3QhR9Q81dLgV0Q8B4OWQcN864QhAnNGIi
PHJ;Ph1nM7V0QXV4PG]hNgb6RhR4NgQiNH23P81dM7=`NGb3P7MgM7AlP8N7O7]h
Nh24RHV1NgQhO867Qh=lN7V0PhJ8PgadM7b1Q8N1O7AdNH27Ph61N7AiP8N8PH1k
NGV0RHb8PgmoOX67S8^1O7UlPh>9Rh1kMg^0PHB6Q7mgM7^0QXB1P7MfNh23Q8An
N7MhPhR;RhN4OX>8S96?RhB0QXR<T8j6P7n0P8N8S8InO7QlP8B3P7mfM7b0QhN3
OgUfMh26QhInNGQiOh>8Qh1lMWUoQ8R7Qh1iNh24R8R7PGahO8B6QhB0N7UkO861
Og]fM7IhOh>4O7UhM7b0PHB0NgIhNgj4Q81nMWQnOh>4P7]dMgQlQ860NGQgOX63
Rh=oNGIiOX>7PH1kM7aoQ8N1OWaiO7n3Qh>0O7QhNHN8RhN0O7n3QXb<R8>0OhB;
Rhb7P7mnOhN?S8V1O7ahP8B7QX1lNGUoP8N4OWmhNh21R8B4NGQlN8>4Ph=gMgIg
OWn4OgQhM7AlPhB0NgMhN7b3QhIlN7MhO8B7QXAiN7MhP8B4Pg]fMWMnP8B3O7ak
Nh21QXAlO7QhPH23PGihM7]oQ8J0OgalO827RHJ4OW^4Q8R<Rh^0P8>4S8b;ShAl
PHN;RHN8P7akOXN7QXJ0OgalPhR8Q8=nO823QhV<PG]kO7j3Q8B1O7AhNh27Qh>0
NgIoPHB8Q81hNgioR8^4P7aiNH28R8R3N7akP8R8Q81kMg]oPHV8PGikN7b3Q8B0
NGAhNgj4Q81kMgQhO8B3PH5kNG]nPhB4P7UlNGb8QXN3O7alP8N8RH5lNgN0Q8B7
OgahNGioQhN4OgUlOh>7QhB0OgilQ8R6R8=lOgn4R8N;Q821P8B8S8V3PGmnQXR<
S8B0Ngj3Q8N8Ph1lNGn3QhJ1Og]kOX66Q8>0O7alOh24PGagM7MlPh20O7UgN7j1
Q85iMWIdN7]nOgahM7IhOX64O7UkMWaoPH>1OgUhNGb4Q81nNGQiO8>3P7miMg]n
PH=oOWQhMg^4QX1nNGQkNhB4Q85kOWj0Q8R9R8=oPH28RHR8PgalPHB8Q8N1NGah
P8B4RhB0P7n1Q8V9QX1lOWn3PhN7O7QiNgmoP8AlN7UiPh20PGiiM7V4Q8B1OX1i
NH>4QX=nOWanQ8V;QX1oO7anQ8R4Og]gN7ioPhB0NgQiN7b4Q7mlNgUiPHB4Qgmk
NGn4R8V;R85nP8B8R8R6P7mkOXR8RhR1O7V0QXN7PgmhMgb1Q8AoO7]iOX>8QX20
NGQnP8J8P7mlNGb1QhR7QWmnP824R81oNGAlOX24PH1kMgb0QXN3PGmiN7n4S8V4
Q7mnP86<S8R3P7mlO8J6QX=lN7QkOX64P7alOg^4Q8B4OWmnO8>4RHV0PGalPhJ8
P7ikN7]oPH>1O7UhNgb3R8N4PH21P8B6Q85kNg]nQ820O7QgMgj1PH>0O7QfO823
QX21NgV0P8R8Q8MnO861QXN4P7]iOgj4QX>3N7MhNHB1PhAhMgUnP824P7ihMW]l
PH21P7UlNh24Q8N0P81oPhJ8QX=nOgmlPhJ4P7j0OX>7R8V8PH>1P8R6Q8=nP7Qn
Ph64Q81lOW]oPh20OWUhNganPH21O7^3QXN4Q85lO7inPH1lO7AcM7QlN7]iLG=d
M7ioP7ioNGR0QXN>RhB7Oh68R8^8Q81oPhR>T8n7PH20PhR9S8B0O7QnPhN8Qh1i
O7j4Q8R1NgafNGilP7ilMgQhO81lO7agMgMkO7alM7=gLGQoOX1kN7MhP7n1Pgmo
O7QoP820P7mhN7alQ85nP7ikO7b0P7alN7QkO820OgmkNgj0Q8J4Ph1oO8B7QhB6
QWn0P863P8AlO7aiP8>1P7]iNGb0PHB4P7moPHR8S8b8Q827R8R<S8V8QXB8S8b<
S8^7Q8R8S8^7Q7mnP866R85lOgmoPhN8PGmkNGn4Q8>4P7QiO7n1Q8=lOWUgO7n1
P7aiMgMhN7ioO7QfN7QiOWioNgQhNgaoP81nO7]lOh64P8=lNGmlQ8>0PGmlO826
QhJ6Oh>1P8R7Qh=nNgaoPhB0PgilOWj4QhN3O7aoOhB9S8B0P7b0PhN8Q81lO7j0
QhB3Og]hO8>4RHN1P7aoP8R8R8N1Ogb0Q8J6P7mlN7n1Q8J4OgakOX60Ph>0O7Un
P8B6Ph1lM7UlO8AnOh1lNgb0PH1nO7UlP7j4PgmoOgn0Q8N3Q7ilP868RhV;P7ao
P8R8RHR3PganQ8B<RH60Ngb1PhJ4OgakNGaoPGilOg]kOgb1Q860P7moP8>1P81k
Ng]oP8>1P7]fNgmnP8=nN7QgOgj3OgQlM7QoO860OWiiO7moQ8N0OganP824Q820
O7]oP8J6PH5nOhB3Rhb9QhB1PHR8RHR4PH63PhB7QhAnPH20Q860NGUgN81lO81h
MgIcN7j0Og]lMW=hO860P7ahN7^1QXB8Q7anO826QhAoOW]gO8B3Ph1gN7aoPHJ6
Q820PH>7Q8J7OgmlO8>6Q8B3O7b0Oh>6Ph1iNGUlP821P7alNgn6Q8>0OgmnP8B4
R8J0PGn0Q8N6Q8=oOh24Q8B0OWakOX20Q8AoO7QnPH>6P8>0N7n4QXB0P85nOXB8
Q820O7alNH>4PHJ4P8B4Q8N<Q864OWb0P7n0OgahN7alP7ikO7MgOWn1Ph60N7Ul
O8>0P7ihO7^3Q823OgahOhB4R85oP7QiP8B8Ph>0OX20Q8B0O7akNGmoP8=lNgai
OX64Q8=nNgQlPH>7P7ioN7b3Q8R6P7mlP867RhB4O7^1P8>4Q7aiOWUnQ820OW]h
NH20PH5nN7UhN821P81lOWalP8R9P7j0O7aoQ8>3OWUoOWn6R8B3P7b1Q8B7Qh=k
O7inPHB1Q81nO8B8R8V9Q7n0P8J<QXN1P7mlP85nOg]gO7b3QhB6Og]lOh>7Qh>1
O7UkOh>6Q81kNGaiPHJ0PgmnP827R8R4OXAoP8N4Q8AnO7ilOX24PGanNGb0O8B0
O7QhP7V1R8>1NGIlP8>3Q81hN7QgP864PgUhNGb3Q8V9Q81kP8N6QhB1Ng]lQ8N0
PganN7AlP8AlNgaaMWb1Q8AoN7aiO8J6R8J0Pgj3R8bARh^7QhV8S8b9Q8=lOhN4
Q85oO7MhO821P7UhLGIoP8R4P7ilO827RhR6Q81kP8R<RHR4OginQ8R8QWinO7j0
Phb4OWmhOX>4R8B1OWUlNGb4P7ikMWIiOXB0OgmhMgR0PH>0OWihOX20P7UlN7Ak
OX61P7ilNG]oPhAoNgQhNGb0PGn0Og]lP8N7QXR3Q8B4S8j>R8B3P8B9Rhb8P81o
P8B4RhAlNGQoP826PGaiN7n0PH>3OgMgO823PhAlN7alQ8J8Q7mlNG]lP85oNgId
N7UnOg]iM7QhNh61Ph5lOWUlQXB8Pgn0N7aiP8R0OgUlO7^1Q8AoNGUnP826Q8Ao
O821Q8^8QX=lOX21QhR6PGUiNGj6Q8J0MgaiO7j4R7ilN7anO820O7UfMWn0P8B0
P7QlP828QX20NgQlP8B3P81hN7alQ8=lOWahNG^1PH20O7anOXN8Ph61P864RH^6
Ph60Q8>6R8N1OWaoOX64Qh=oNGUnOh68Q85lNgn1Q8J4P7UiN7b3Q81oO7UnP8B6
P81kMWAkR8J4PG]lM7b4QXJ0OWilO8><SXB3OgmoP8V8Qh1nO7b0PHJ4P7]hNGb0
Q85oOh1oP8B4PH20OWn0Q8N4PGmoP826QXN7P7b1Q8J9R8b4O820QXB4R81lMW^3
OXB7P81kNh24R8R8Q7n3PhB8S8B3PGb0PhB4P81hMg]kP8=nO7UdN7]nPh1oNGQh
NGn0P7]gN7QoPHB1OWadMgb0Q7b0O7AiNh66Q8AkNGQkQXN8Q7mlMgQlQ8B1PGak
O7b4QhJ1OgmnOhB7Q81nNGalP8R8PG]iNGR0Q8N4OWalOh24R8B0O7b0PHR9RHIl
O826R8J8QX1lP8B8RhB3Og]kOX>8Q7mlNGQoQ8J7PGakO7n3R8R4P7alOh26R8An
NG]lP8>7R8=nNH24Q8R4Q7mkO824QhB0OgaiOX66QWikNgQkOX>6OgahO820Q8J0
O7UgOX20QX1nN7AiNh20OgigM7UkPH>0OWaiNGn4R8N1O7MhP824R85lN7anP8J8
Q81lN7b0Q8R3P7agNgb1Q8J0O7akP868QX>0NG]lQ8J7Qh5lN824R8b6PgiiNh26
R8R3NgQhOXJ7Q8=oN7]nQ8B3P7ikN7b4QhB1OgmnO8J9R8AoO7ilPhR;R81nOWn6
R8V;PgilNh26RhV0OWQhOWn4Q7ahMgMlOX64P7afN7n1Q8J4P7UlP8>4Ph1nN7Ih
P8B0Q81dMgV4Q8J9PGmlO8J7RHB1Og]lPHR;QhN0N7UlPhB4PG]hN7V1Q8B0OWQh
Mh26PhAoNGQiPHB8QgilO7b4Rh^9PgmlO821R8R4P7aoP8N>RhMoOWb1R8V>Qh1l
O864RHb8PgakPHB;S8N6O7QlO8N8R85nOgb0Q8>4P7QfNGalP7mlNGAdNgb0Pgmh
MgAgOX20PGUfMgMkOhB1NGQfO820R8IoO7UnP8N7QXMlN7b0Ph>9Q7ilMgb4P8Ao
OWQdOX26Q820NGUoPhN6Ph1lP7n6QhJ9P7inO821P81nMgAhOgmoP7ahMWJ0P867
Q85nOX>4RHb7QX5oPHB;Sh^4P7mnP8B4QXAkMW]nQ8J6P7ahMg^0QhB1OgMiO826
Qh=lNGUnPHJ7Q7mgMWUoQ8B1Pg]iO7n4Q8B0O7MiP8B9Q81lNH20PhR8QWmiNh24
QXN4P7anP8R9R8N3PGaoQ8N6PGmhN7QlPHB1O7UgMgn1Q8AlN7MfOX>4Q7iiM7An
OhB3O7UdM7UnQ8>0NgQiN824QX5kMWAhO823OgQdM7IlP8B0O7]hNgb4R8R4Ogak
P8J<SXN4Oh23Q8j<QXAnOh24R8N7P7QhNgn4Qh>0NGIkPHN8QX>0O7]oQX^7Qgil
OX26R8R1O7UhNgj4Q81kMgQiP8B3Q7agN7b4RHV9PG]kO8J7RHMoN7IgO8J4Pgmf
N7QiP8J6PgalNGj7QhR7OWilOhB7QhAlNgUlQ8B7P7aiN7n7R8^8OgQkOh68QhR4
Ng]kP8B8RH60NgV1Q8R9QWmhNgb1QXB7OgQhO8N9RhN3Ogb0QhN7R81hNGb0QXR3
PH1kO868Q8>0N7MhOh66PH1oN7AkPHJ1OgafMWQnR8J1O7UgN827RHR4OWQlP8R<
RHJ1O7V3R8V8Qh5nO7b6RhR1O7]iN7j4R8AkNgQkP864Pg]hMWUiP8J0OWQdN7]o
Q8=nMgMhNH64P81iM7R0Q8R9PgikO7n6R8N4P7]iOhB9RhB1O7]nPhJ8QWmlNG^0
QhR1P7UdNh24R8>0O7QiOhR8R8J0Ngj3Qhb9QhAoO8B6S8j7Q7akO828QhB0NgUl
P8N7Q81gN7alQ8J8PGanNH>6PhR0O7]iPH20QX5oN7R0Oh>6P81lN7j0P8B0PGig
Nh27Qh>3P7alPhB7Q81nO7aoPhR4OgQkOWb1QhB0NgQlOX24Q81gMgIhOgn0PgUd
MgIlPH64P7ahNH23R8^4PGilP8R<R8R0OX20R8N6PgahMgb3Q8J0O7]fO8B8R8B4
P7aoPHb;R8AnOg^0QhR;QWmlO8>4R8J3OW]lNhB8QXAhN7QhPHN7Q7iiNgb6R8R<
P7aoNh>6Q8AlOW]gP8B4QWmlN7b0P8R7OWagNGb0QhB3O7QgNh24R8=nN7IkP8B6
QX1kN7AlPH20Ng]fM7inP81iN7=cNGb4Q7ilN7UlP8J6P7mkNGj1RHR4P7UlOX68
QXB0NganPhR9R820O7^4Q8J6P7ikO7j4Q820NGMhN7n0P7akMg=kOh21O7ahNG^0
R8B3O7QkOX21Qh1lNGQkO8B3P7mlN7UoPHB3OWUhNh21QhB1OgUoP8>9QXB0OWn3
R8V9QX1lO861RHR4P7QhOhB8R8N0Ng]nPHR8Q8AlNGUnPHB3OWahNG]nQ81lNGMh
N7j4Q81lMgUlPHR9RHAnO824R8j;Qh5oP8B9SX^6P7b0PhR<R8MoNGanQ8B6Q7ak
NGn0PhB1O7QkO8B8Q8AoN7MlPH68Q7alNg^3R8V8QX1iOh23SXR1OgUkOh>4Q81h
MWQhOhB4P7UfMgn3Q8N6P7QkOX>4QXMoOW]nQ8N>QXB0N7b1QXR6P7ahN7R0QX21
OgakO864Q7akN7QiOh>0Q7ahOX23Rhb8Q85oP8R<S8V6OgalPHR8S8IhN7QkP8N8
Q81hMganP8B3O7IfN7b3Q8=lMWQhOhB3Q81hMgR0Q8J4OgQdN7j1QhJ0NgQgOhN8
RhAoO7b4R8R;QX1nOX64R8^4OgUlOXB8R8=lNGIiPhB4Ph1lNGb0Qhb8Q8AnOX>7
R8N4P7QhP866PgmnN7IhP85nOW]kMgV1QXB3P7ilO828R8B1Ogj0Q8R;Qh5oO7j0
QXN6PGUhN824R8R1P7anPHJ>RhB1O7aoP8J4P81hN7aoP7anNGAfMgV1PGilN7Ik
O864Q81hN7UiPhN8R81kO824Q8R7OWilO8J8QXB0N7MiPHB3PgmlMgMoQXB0NgQf
MWV0Q7mkN7AgO8>8Qh5lNGUlPhN6P7QgM7IoOX5lMgagO866R85nN7AkO8>9Q81h
MWQiP8J4P7MdMgb3Q8N3O7QiO8>6Q85nOg]nPhB9Q7ilNGj0Q8V4OWUkO7b0QhIn
O7QkQX>3R8AnNGb3Q8N1P7mhN7^3QhR4OgalP8N;S8V3P7j0QXR<R8=oO8>8RHV4
Q85iOhB7S8R6P7b0QXR<QX63N7b3QXV4OgQgNGb3Q860NGQiOXN8RH^4Q826Si2D
SXR8P827S929Q7moOWn9S8N0NGAdMgb0P7U_LG1cNgj0O7MdN7QlQ8R3O7ahN827
R8b4P81nP8B;R85lO7]lQ8R<P7akNh20Q8^1O7UiP826R8N1N7]oP8J8QhAnN7b1
PHB3OWUdMgb0PGmlN7QkO8B8PgmkM7QnPH63OgIfM7R1Ph>0OgaiOXB7Q81lN7Mn
Q8J4PgihN7b0QXN6Q7ahO8>4QXB1P7QlP8J8Ph5lN7UkPhN3OWUgNgb0QXJ0NGQl
OhB6Q8>0MgUoP8J6Q7ilO7V0QXB4PG]iO7b4R85lN7QgNH1nPh1fM7IhP8B1P7mi
MWR0Qh=nNgQhM7j6QXAiMWQiPHN8RhAlOh28S92AS8B3P8V@S96;QWmiQXR;S8B0
NgQkOhR8Q7mlO7j4RHb9PgmlP8R7RHR1OgQnPhJ8Q8AlMg]nPHJ0P7ahMWQoPgil
MgAdM7b3P85hMgQhOhB6Q7alNG^0Q8R8QX5oO866R8b6OW]kP8B6RhN3O7QnPhJ7
Q81nN7b4Q8N6OgiiOXJ8S8B0OgQnP8J;Q81kOWioR8R4P7ahNgn1Q8J3NgQkOhB6
PgihMgQoPhB7P7akN7n0PHN1O7QiO7b6QXB0O7]oPHJ7QhAlNgj1QhR8Q7mlO866
R8N4P7akOhB7QXJ3NgUlOhJ1OgagMWInPGioO7QfN7b3QWilO7QhP8R8R8B0O7b1
Rhj6PGmhMg^1QhN1OgUiN828QXB0NgQkOhJ8Q8=nP820QhJ4PGMdNh27QhN0O7Md
O8>1P7ahN7IoQ8>4OgaiNH20QhR3PGUhOWj4Qh>0MgQlNH63P7mhO7j3R8R;Q7ml
O8N;S8b6PH1lPhJ8R820Og^3QXR9P7mlN8>0QhR0PgUiP7b3Q7alMgIlOXB4PH=k
MgalPH1oP7]fMg^0P7mlO7QhNh24P81nO7QhOX64Oh1iMganQXJ3P7]iNgj6R8=n
N7IhO823P7UfLGAhO8B4P7aiNGb3QhN4P7V1Ph6;RHR4P8B0Q8R;Rh1iP7n4R8R8
Q7ilPHB<S8R6PH1oQ8B8Qh5lN7anPhN4Q7agN823QXN0NGAhNgj6QXAkN7QkPh>8
QWiiM7IlP8N4OWUgN7j3PH63O7IdO821Q7mlNGQkPHR7Q81iNh24R8V7PgaoP8B8
Q8J1O7aoPhN7Qh=lO7aoQhN7P7moN826Q8J0O7j0Q8>6R81nO7^3Q8J8Q7ilO826
R8V6Q81iP8J8S8R3OW]kP8N9S8AoO7j4Qhb>Q81nNhB8R8^6PgmkPHJ8R85nNgV0
PHB8Q7akNgUoQ8B3P7UhO8>0P8IlNGQdOWaoP7QlM7AhO8>0O7QfLgMlOh5iNgId
O7^3Q820N7QlPHJ4Q81lOh24R8^8QX1lP8J8R8B4O7QhO8B4Q8=kM7MkOh>4P7ai
NGV3QXR7PGQdNh27R8B0NgQhP8N4QX=lN7b1Q8R6OW]kN7b8R8B0O7UkOh><R85o
O7UoPhB8Pg]hN7anQXR1O7QhOXB8R8N0O7]nP8B8Q7inNgb3PhV8P7UfOWj0QhJ1
NgMdO823Q7iiN7IhP8B7PH1hN7]lPhV4OgahO7n4RhR4OgilP8^;RHInNgb0Q8R4
Q7ihNgb4QXB0MgMfNh64R8AkMgMkQ8R8QWmhMg^4QhR8P7aiN867RHJ0O7MlP864
QX=lNGb0QXV8Q81hNgn4QXR1N7QfNhB7RHMnNgMhP8J8RH5oOX28Rhn?Ph=nP8R6
S8J1PGAkOh28Ph1lM7MiPHR1Q7igN7V1Q8N6P7aiO8J8R8R0O7QhPhR;Qh1lN7R0
QhR8P7ikN866R8R3OWUhO866QWmlNGAlOX27P7QfM7QkPHJ1OWMdP820R8B0NGMl
OXN9Ph5kN7QlPHJ6P7ahNginQhIoN7MkO7n6RH=lNG^1Q8B9Qh1iNh>0QhV6PGMh
O7j1Q8AoN7AgO867PH1iM7UnQ8R4Q7ahN7^4QhR1NG]hNhB8RHInNgQlPHN<Q7ik
MWV1Q8R4OgQfNH23QXB0O7MhP8B8Qh5oNgQoQ8V9PgmkN7j4R8V6P7]hOhB8SXV4
OgQlQ8R8Q8InM7]nPhR4PgahNgn7R8J8OWaoP8R<RhR6O7^4RI2?R8N0NGn6T8b7
Q7UhO829R8B0N7QgOhB4PGagM7IhOh1kN7MdKgInOgmiM7IdN824QX1nO7QnQ8^;
Q7mnO7j4R8R6OgUgNh23RHAlNGIfNh24PgakM7IkP8J4PGilNGj3QXb4OWaiPhN<
ShN3OWR0Q8J>R81iM7aoPhV4OgQgN7b4Q8B0MW=dO824Q7mlMWIkQX^;Q7ahNgj3
R8V6OgUlOhB;QhR4O7UiQ8R4Ph1oNgQlPh61PGQfNgb4QXAoO7]gO8R8R8=kN7Ul
PHR;Q7miMgV0Q8J4O7IdM7b4QXN0NGIgOhJ8RH5kMW1iPHB6P7igN7n3RHN1OWQh
OXB9RHAnNGUlP8^;Q81hN7b0RhV8PgMgNH28R8R1N7QhOhV8QhIlNgb3QXR<Q7an
O7n8RhV8OgQiO8B8S8V0OgioQ8R9R81hMgb0Q8V8P7afNh23R8J3O7UiOXN8Ph=l
N7b0QXV7P7QhN7]oQ8B3OWIiOX>9RHR4OWb1Q8^>RHAlNgQoR8N8P7MhNH67RI28
O7]kOhN<RhAnO7InQhB<QWihMgb0QXJ0OgQcMgb3QX1hM7AdN8>7PH1gM7IiPhB8
P7MgN7j1QXV1NGAcN7n3R8AkM71hOh27QWafLgN0Q8R8P7QdMh28R8R0N7MhPHN<
SXJ0OX24S9><R8AkNh24R8V7P7QhO8B9R8N3N7IiP8R6PgmgM7MoQXN4Og]kOXB<
T8b8OWQkOh^<QhAkMgMkQ8V7Q7afM7AoQXB1NgA`M827R8UnMgAfOhN7Q8=lM7Mo
QhN8PGQgLgV6RHN0MgAdM826R8QkM7QhP8R9QX5iM7R3Q8B7OWQfMX>9SX^3P7Ak
QhbCS8N0MgQnQh^8Q7]hNg^4RHJ4Og]iP8B8RHAoN7QoQ8V9R85iN7b1R8b9Pgmi
Nh69T8b4OgQkP8B<R81hLgAhOXN4Og]`LgN0RHB4O7AfMh68QXAlN7IhPHR8Pgah
MgQnQhb8PGUiOX27R8^4M7AgOhJ6Rh5iM75oQhV8R8=iN7n<TiB@R8AkOXR?ShR3
O7UiOXR@R81gM7=hQXN8Og=`KgJ0QXR0MW5^M7UoQ7adLg1dP8J8QgaiN7^0QhR7
OWMdMh24RH]lNgIhP8B<RhAlN7n6RHb<R7adN7n6S8V4P7MgO828RHAlMW5fP8R4
QX1iMWIoQXR7P7ahNGb8RhJ0O7]kPHR<RhN0O7aoR8b?RgalNGb3QhR0O7QdNH>4
Q8AlMWAfP8R9QgadLGQoQXR4OWI_LG]oQ8B0N7AfNh28Q8=iLgMkP8V;Q7aiMWb6
R8b8P7ahO8B<U8b6OgUlPHj?RhUkN7aoQ8V<Q7]fLg^4RH^4O7MgO8B9S8AlMgIk
P8R<R81iNgb4Rhb9PgahNGn1QhR0M75dNH28Qh1lLgAiP8N8QgafMg^6RhV9P7]h
O8B9S8R0O7IlQ8B9R8=lN7UnR8V3P7QcN7b0QXAnMg5dNhB;Q81gLGAiQ8V9Q7]d
M7^4SXj9PgahO8J<T8j3NgMhP8V<QgmfLG=lPhR6O7I`M7j1R8N1NgAdO828S820
O7QoQi2@RH=kNGb4SY2;PGafNH68T8n1OgahP8^DT8R1N7anP8b?QWagN7n7S8j7
P7IdO8><R8J3MgQkPHb;Q81kMWV4S8j8Q7IdN7R3R8AlL71cM7n4Q7ifLg1dPHB4
Q7MdM7IlPHAlMgI^Mgn0R8AlLg=kOhR<Q85hLGUoQ8R4PGA_MgV6RH^8O7UhO8R8
RhQlMg1hQ8^@S8=hM7N4RH^<PgUfM867RhQnNg5aOXB9QWihL7=lR9>>QX5lNH28
TIB;PgUlOh><SXIlM7AiP8R8QgmfM7R1QXV;OgQdM7j6RhR4NG5hOh>8QhAlM7Ak
Q8R3PGadLGR3R8V3O7QdN8B@ShR1N7QhOhb?S81hN7R0QX^9P7MdLgb7QXR4Mg=d
N828QgilM7AlP8R;PgUcMgV0S8j8P7QiOX>;SX^0N7QhP8R;R85iM7AnPhN8Q7]d
N7n8SX^4OWMhP8R?SX^0N7MlR8b@S8AlMgb8SY2>QWmlP8RCV927O7QhPHb?SXAl
LG1hP8V7PGiaLgV1Shb7PGQhO8B?T8QoM7=iP8V9QWm`L7AiQXR4OgA`M7b4QhR4
M71dN8B9RH=hM6miQ8>7Q7]dL7AlPhR6NG=`M7n7RHQnM71dP8N<S8IlN7b4RI6?
R7idMh2;SX^6Ng1aN86<S8AhMg5fPhV<Q7ifLGQoRHn8O7AcM7j8RhMlLg1fO8B9
Q7ahKg=kPhR7P7A`M7N1R8R0M7AdNh>8S8MlN7MlQ8b@SX1hMg^4RiB@R7mfNgn7
T8V8OgIhO8N9R8IhLGAiPhR7Q7aaKWR3R8b9P7IhNH>AT8V4O7IhQ8bCT85hN7V0
S92?QWMcM7j;SXb6NGAcO8N9RhAiM75iQ8^;Q7QdLgV0R8n6O7A_MWb3RhV3M75h
O8R<RhAiMWAlQhR9Q7QdLgV;T8n9OgQgO8V@ThUnNG=hR92@RH=hMgj0SY><PgIg
Mgb8RhR0Mg5dO864P7adK71hQ8b9Pg]aL7R0S8R4O7=aMh2>S8V0MW=gPhN<S81k
M7R1R8j4OWQ_M7b7S8V4N75fO8V@T8V0MgUoR8n<RH1gMW^4RHR7O75aL7^8QhQo
M7AdOhR;RhAnMgJ0RI2@R81hN7b8Shb4O7M`MX>7S8=hLfifOhR9OgQdJFakPhJ0
MW1XK7IoS8AlNG1gOXNDS8V3NGb1SiBCRH1hN7b7Thj6O7MgNHN@T8b0NgAhQX^@
S8=hLGR0Qhb9P7]dM7b6ShR3OgAdN8>>QhAlMWAhQ8R;PgMdLgR0R8b4O75^Lgb8
SXb3MW1dOhR;S8=iM7MoRI2;QgmgN828Sh^6O7AdNHJ;S8QlMW=lQ8R@R7mhLGR1
R8R3O7A`M7j8R8MlMgMfOXB9Q7]gL7=oQXj8OgQ`M7b4SXb4Mg=cN8B;S8AoN7Ak
Q8n?S8=hN7V3S8n9P7]dN868SXj4N7AgPH^CT8R1N7R1RI6@RGmhLgb8T928PGMc
NH69S8R3N7=hOXV<Q81gKg5iPhV6P7A_M7^4RhV6N7=cMXB@SXQiLFicOhR<QW]d
LgJ0S8j9PGQhO86<T8j0NGQfOhN;Q7idKW1hP8B6P7A_L7QlQhR0N6m`N8B>ShR3
N7=lPHb@QX5dKWQhR8b4P7A`MWb9T8j8O7AgO8R>S8QiLG1fPhR7Pg]aKWB1R8^6
OgMaN8><ShR0MgAkQ8nAS8=iM7V3Ri6>Q7ahN82<T928O7IgPhRAUX^3NGV1RIBD
Rh1hN7b4SXV4Nfi/M7j6RHAlLg1dOhN8Q7adKg1kQ8R8PGafLgb7S8b3O7MgO8J?
S8MoN7IkPh^<S8AlN7^4Rhn>QWadNgn8T8b4O7McNhN8R81fLG=hQ8^8P7Q_KWN1
R8b4NgAfN82>T8^1N7IiPhV>Sh=hMWV3RHb9Q7QcMX28RHb7O7IdPHV>S8AnLg=l
QXb;Q7UgLGN4Rh^6O7IcMX24S8QkN7IdOhN<R7agM7R0QXb;P7UhN8>7S8n6O7Mh
PhN<Rh=kLg5iP8R;Q7adLgB0R8R8Ng=aLgj6RHb1M7=cO8R<S8=gLgAlQXj@R7Ud
LGb8T9B<OgA`Mh>;SXioM7AfQ8V?S85iL7R1R928P7Q`L7R6S8R0MVm`NhR<RhAl
Mg1gQi2<R7afM7J6Shn8O7QdMhB<Ti1oP7akQi2GU8N0NG^4R92@Q7aaM7j4SXb4
NGAfN8B>SX5kM75kPHb?RGifMWb4Ri2>P7IcN86<Ti27NG1gOhJ>RH1dKg1dQ8N4
P7I_KWN1Rh^1O7AgO8N@THaoNgQiQ8^<Rh1cL7B0Qh^8P7I_L7R4QhAlLfi`M827
Q7aaK6mdP8B4Og=`Kg=oQXJ1N6i_M828R85kM6ifNHJ9PgaaLgAiR8V9P7IfM7b6
Rhb0Mg1cO8>8SXIlLg5lQ8j@RhAfLG^4Si6<Q7aiO82>TH^3MWAgP8^@ShAiLGAl
QXb<R7ahN7j;T926P7UdOXJ>ShUoMWAdOhb<QgigLg=lRH^8P7MaM7n<SXb3O7Ug
P8^DThR1Ngn3S9JAS7mdNH26TIB<P7QgO8N?T8b4M7AoQ92DS8UiM7b1SY2<QgQ`
M7b9S8R4NGAcNHR<ShMiMW5hP8N;Q7a`L7MkQ8R4O7AcM7b7R8R0Lg=dNhJ9R7ag
Lg5hPhR9P7AdL7R6RHb6O75cO869S8IhLg5hQ8^?SX1dLgN1Rh^;P7=`M827RhQl
LG1_N8R9R8AdKg=nQ8b<PGQ`Kgj8S8b4OWIfO8RCT8V3NGMnQXnDSXAlNGb3T9J@
Q7]hN82;TI26NG=hOXN<RHAhLg=iPhJ8Q7]cMgN0RhR4O7QfMh><T8b1N7MhOXN?
S8AlN7V0RHn?QWQgN7R4Rhb4LG5aN868SXIiMg1hQ8J<R7U`KWAkQ8V4OWIcMX6;
Shj4O7AhPHV@ShQnM7IkQ8b<Q7afLgR4RhV4N71_M824RH1hLfmgP8R;Q7U`L7In
QXj6OWIaN829S8^4M7AhO8R<R8=iLGR1QXb?Q81fM7j3Shn9PgQhOXN@THb1N7=h
P8^<QX1gM7MnR8n9OgA_LgJ1RHB0M71fN8>8RHAhM71fQX^;R81iM7N3Rhb6P7Uf
N7n8Sh]nN7QfOXV@Rh1kM7IlQ8j>QWQ`M7b4SY24N71`N828RhIiL6mgQ8R<R7md
KgR3RHV8Q7MgMh2<SX^1NgQfPHR<T8AnN7MlQY>@R8AhNgn4Rhb;O7AfNh>7S8Il
N71lPh^@QXAiL7V0RI2<Q7QaM7^8SXR4NG5gN8><R8AiLg=gPh^>R7adM7=lS8b6
OWIdMgj<T8j6O7QkPhb@SX5kMgQlQ8b;PGMaMWR1RH^1N7AaMh27R85kKfmgNhJ9
QWmdM7R0Rhj<Pg]hO868S8b4NGIiP8R8RHAhL7AhPhR8Q7UgMWV4QhN3N7MaN8>7
S8IlMgAhOhR;QgadL7AnR8b6O7A`Lgn7S8b1Mg1`O8B<RH1kL6mkPhjCRH1iMWb3
S8b6PgAdO829RHMnLGAfPHj<S8=hM7N3S92>QW]dLg^7S8b4N71aO8J@T8R1MWUo
QYNFSh1hNGR8T92>OW5`Mgn8RhR0M75cOX^>SXIlM7B0Ri2@R8=hN7n7T8b7OgAd
NH2>RH=nL75cO8^6Q7U_LgAlR8R8O75`Lgb;S8b4NGUgPHj?T8InN7R3R9>DRH1h
N7n4S8j8OWAdO868RhAoM71fP8N9R7]^JfagQ8R3P7A_L7V4R8n6NgA`N8J;RHIi
Lg1fQXb>R7mhLgR6S8b7OWQcM7n8SXIiM7AgO8J@R7mdKWIkQ8^8PGQ`LgR3RHR4
NG5dN8J@S8R0M71gPh^?R7miM7=nRh^8P7IdM7j;Si23NGMgP8^@SXAhMgUnR92A
R7ihN86<TI><P7IfOXBDTHR0N7=dP8N8QWadL7AnQ8V7Og1`Mgb7S8R1N6mcO8>8
R8AkLgAkQ8^;QWafM7R4Rhb9P7MdNHB;Sh^0N7AhPHV;SXAgNGQnRHb>Q7agMh26
RHb4NgAcNh69Rh=lM7=iPhN8Q7]cKgJ1R8N4P7QfN8>;Shb1O7QgP8V<R81iM7Ak
Q8b<PGUfL7R3R8b4O7IaN82;RhAnM7IhQXn@S8AoMgb4R92;PG]fN827RhB0O7=f
OhB<R85lM7QkQ8n8Q7mfNGb6S8b9O7MhN8B;S8]lMWAhPHB<R7idKgR0Q8b9P7Mc
N868Sh^4OWAdOXB9R8=kLGAiQ8b8PgaaM7b3S8b6O7MaMX>;S8R3N7=iP8j@R8Mn
N7R0RHj<Q7ihN7j4S8^1P7IgO82<R8MnLGQhO8N8QWafM7R0RHV8P7AaMgn8R8^1
N6mdO8B9R8AiLgAkQhR;Qg]fM7n8S8j4OgIdNhB;R8J0M7AhP8j?Qh5iMWQoRHn<
PGMhN7b9SXb4O7IhOXJ<RHIhM7]nR96@R7]fMgV6SXn;O7MhNhB8ShMkN7AiPhV<
R7mhM7R1R8b8OgM`M7^1S8N0NGAdO8N<R81lMW=iPHb;Q7ahN7R0Rhb8OgMdM7b4
R8IlM6mcN827PgidL7=kQ8R8PGQcMWb4R8R6NG=cO8J9Rh=hLg5hQ8b?R7mdM7V6
SXb@Q7QgN8B9S8QlN71`P8B<S8=hM7AlQhV9Q7]dM7b3S8b6OgQdN8B9RHIhMW5h
QXR<Qg]gMWR0RHb8OWUgLgj4RhaoNGIfO8B>S8AlNGIiQ8R<QWagN828Si28PGaf
O8J<Shb1O7UiQXb@ShInMg^4RH^7P7UdM7b4RHR0NGIcN8B?SXAnMg]oR9>?S7mg
MWJ4R8^7NGM`Lh67RhIlN75gP8R@Rh>0N7V0R92>R7mfMWR1RHB3N71cLg^0P7id
L6mdO8>9QW]fLGMoQX^8P7McMX24RhV4OWQlQX^AShR4O7V3Rhn9QgihN7R6RhR0
N7AaMgj6R81hL7=hO8R<Qh1gMgR1RHb>PGUhN7n8SXb8O7MhO8R?ShQlMWAgP8N8
Q7QcM7N0Q8V4NgIdN7j7RhN0N75hP8B;QgigLgIlQ8R8Q7Q`MWn4S8b7O7AdOhJ7
QhMoN7AiP8N8PgigLGR0QXR4OgUcN829Rh>0Ng5gP8V<R81hM7IiQhb7Q7ihN7j8
S8j7PgalP8N?S8QnN7akPHb>QgmhN7n3S92<Q7]fNHB8S8V3N7IhO8B8R8AnMg^0
RI6<R81hO828S8b8OgQfNHB9S8MlM75gOhB7PgQ`KW5hPHN4OWIaLgj8RhV1N7Ag
O8B;R8AhM7AhQ8N6Q7UdM7R4QXR7OgUhOXB9RHJ0O7QgPHb8PGmkMWR0RHV4OWIf
N7^8S8^0NGQhP8V@T8QlN7]lQ8j>R81gM7b4R8j;P7QfN7b7RhN0M7AkOXN<S8Ah
M7IoQ8N9QWQcMgb8RH^9OWUhOXR>Thb4OWR0QXV@RHAnMgj3S8b4PG]gNGn8RHIn
N75dN869Q81cKgAgPH^9Q7UdM7R1R8^3NgIdN7n6Qh5nLgAhN8R;Q81dM7IkR8R4
Og=`MWb6QhR3N7IdNHJ8QXAlM7IkQ8^9Q81hM7R8ShV;PgUdMX2<R860NgIaNHB8
R7ikN7AlPhR8OgaiNGj1S8V0N7=gO8B<S8AiM7MiQXn@S85kN7b4RHb<QWalP8J@
S8QnNGQdOhR9QWQaKVmiP8R7NgM_LGb4SXb7OWUkPH^AU8b6OWQlPhn>RHIlN7V0
QXR7O7UdLgb4R8R0N71dNh29R8>0MWQnQXR7QW]fM7R4R8V4P7]hO8J>Sh]oNgUn
R8j@S8=lN7j8R8^<Pg]fN864R8R0O7=aNgb4P7ahL6iaNH63OWQ`L7=hPHB3N7Mh
Mh28S8^1OW]oQ8V<S8AkN7R0R8V;P7McM7V0R8=nMVi`M7j4Q85gLg1hP8R9Q7id
M7QnR8V1N7AdNH>8S8b4N7QlPHR>RhInN7b3RHj;Q7adMgb3RhV4O7QiP8V<S8b0
MgQkQ8n@R8=hMWV0QhV8OgQhMh64QhMoN75hOXN<R8IkMgQiQ8R>Q7QgM7J0QhR0
N7AaN823RHMlMWAgQX^@ShAnN7b8Si2>QWmhN8N<Si24P7QdO8^@SXR1OWb0R96F
Rh=lO7n4S8b9P7QhN828RhIlNGAfP8N7QgihMgR1Qh^<P7]hN7j4RHR0N7=dO7n4
Rh5lM7InOXN9Q7aaMWUnQhR4O7AdN866Rh^3N7IlPHJ<RHIiLgQkQ8N8QgQcM7V0
Q8J0Ng=`N824R8AlM7=iQ8N8QgmhM7N3R8R4P7QdMh26QhIoNgQdP8b<R85nNgN0
R8n?Q7inOWj4TI26P7akO8B;S8^0MWUnQ8N<Rh5hLGR0Q8^7P7Q`N7n6S8N3NG5d
NHB<Q81iL7AlQ8V8QWihN7^3RhV6OgQhNH68RhInM7AiP8B8R81hN7QoQ8B4OgQh
M7b6Q8N1N7AaNHB6RHAiN7AiOX>6OgUfM7MlQXR3OgAfN7j8R8MlMgQdOhR;RGif
LFmhQhj>Pg]dM7R0Rh^4OW=dNH6<SX^3N7MlPhb>S85hN7V4SXj<R7ikNhB<S8V4
O7=dOXJ;R8=lM7AhPHb;Q7ihN7V3Rhj8P7]hNh><ShMoNGMhOh^?RHAkMWMlQhb8
P7]hN7n6RhV4OgIiP8J?RhQoN7^0RI2>R7mhMgb;S8j<P7]gNHB;S8^0N7=fO8B9
RH1dLG1gPHN<Q7ahM7b4QXR1NgIgNhB;RhQnMWAgQ8R<R81kLgR1Q8J4P7Q`M7R3
Qh5nN71`MX60P81hLG1gQ8N7PGMdL7N4Q8R4O7]gO8J9S8IoOWQkPh^<R81lNGan
Q8b4P7QdN7V4R8J0Mg=aMX26Qh=gM7AkQ8N<R81kM7n7Ri27Q7ihPhN<SX^8P7n4
RI2AS8QoN824Rhj9Q7ahNh68S8V4O7QiP8N;S8MnN7AhPhJ8Q7]hM7R0R8R3Pg]f
Mgn8S8N0NgQgO8R<QWmgM7MiP8J4O7AcM7IoQ8B1M71cN7b6QX5hL71fOX68R7id
L7R0RHR8Q7MfN829RHb6N7A`O8R6S8AhM7AhQ8N9R7mgMWj8T92<Q7ikOhbCT8j4
OginS92DT8=oN7^7RHj<PGQdN826S8V4OWQfO8B8R8=hM7AfO8J9P7QfM7QoQXR4
NgAdN7n8S8QoM71gOh^@S8AlMWQlPhb8P7QdN7^4RHR6NG=hNh27Q8AhL7AcOhB3
PGahM7R4R8V8P7UiNhN?Shj8PG]lQXV?ShMlN7b4Rhj<Q7icLgb4R8R4O7A`Lgb3
Og]gL6a`N8>8PGQaKg=hP8R4Og=/MWb4RHb1NgQfOh^>S8MnM7QlP8V8Q7idMg^4
S8b7OWUhOXB9ShQoN7QnPHb@S8AfMWb3Rh^?QW]dM828RHb4OWIhP8N<RHB0M7J0
Qhn>Qh1hMgb1S8V3P7IaN7j9RhB1N7MhO8b>Qh=kMWMlRHb;Q7]hN7j6Shj8Pgj1
Q8^FTHb4OX1nRI6?SX5hNGQlQhb8O7IdM7R3R8MnLfm_N864PgU`K6adOXN7P7Q_
M7MoR8R6O71`N7n4RhMnM7=hP8V8Q7idL75lPhJ4N7=^L7V0QXIoN7=hOh>;Rh1h
LgAhPhR7P7McLGJ1R8B3Ng=dNH>7RhQlN7QhQ8b<S8AoO7b7S8j?QWagN824S8j4
O7IgO868RhAhLg=kQ8V<RH5kNh68T9>@R7mkOXJ;RhV1N7AiPhb?RhQkM7QkQXR6
Q7UdLgV4QhR0NGAcMgn;S8AlM7=hP8b;R81dMW^3S92>PgQdN828Shn7N75gNhR>
S8b1O7QlR8b?R7iiN7b3R928OWQdO8>;RhQoM7=hPHR<R7miM7V1Rhb7Pg]cMWj7
R8QnN7A`O8B9R81hL7=iP8R8P7MdM7R3Qh^8OWA_Mh24RhQnMW5dO8N8R85iM71l
R8^;Q7agLgV1RHV0NgMcMh29Rh1hM6agOhR?Q81dLGQnSY6;QgUcN82>THb4N7Ag
O8V?SXQnN7V4RiJGS8IlO8><T92<Q7akP8R@SX^3M7AiOhB8QW]dLGAnQ8N4P75^
MW^7QhB4N7=dOhJ8S8AiMgAlR8^<Q7]dL7R1Rhj8PgUdO8B<S8b4MgIiPHb>Rh=l
MgR1R8j<Q7igN7j8S8^4OgagN828R8=lMWAfOhN8P7Q`Kg5lPHB4N71`L7J4R85n
Mg=dO8R9RHAhMgAlR8V9P7]fM7^4S8b6O7MhMh28RhAiMWAfO8N8P7QcLGR0QXV8
NFm^L7V1QhIlLfa`N823Qh=hLG5lQXb;Q7mdMWV4SX^7OgQgN8J;RhIkMgAfQ8b>
S7mhO7^4SiBDRHAkOXR@U9J<Pg]hPHV@T8R0MgAkP8N>R7agM7^4S929OgMcNHB<
T8QnMg5dOXB<QgidL7IlR8^7PGMcN828Sh^4NgAfNhR<S8QlM75hQ8V<R81fLgb0
SiB<Q7aiNh>@U96;OWalPhV@T8MoMgUnR9B<R85hN7b<Thj;NgAdMh69RhQhLG1c
OhJ8QgigM7J0S8b8PGQdMX26S8]oN7AdO8N<R81hM75hP8N<PgQgM7b1RHb7P7Ad
Ngn8Qh5lL75dNh>6Q7a_KW1gPH>8PgMdL7b7S8b3O7AcOhV8S8UlMg1nRHb@R81i
M7b6SY28P7agNhB?Thb4OWQhQX^>S81iLgJ0Qhb9PgU`Lgb4S8n9OWMhNHJ@T8Ql
MW1fP8J;Q7]cKW=lQ8R4O7=/L7^3R8R0Ng5cOXN>SXJ0M7=kPhn<PGmdL7V0QhV6
Ng5aMh27RhAkMVidOhB8Q7adKW1lQ8V7O7Q^LG^1RHJ0O7AdN8J<R8MlMgIhQ8j@
Rh5kN7V0R8b8Og]iO8><Shj4N7AhQ8V<ShIkN7B0Rhj>QW]gM7b6Rhj0N7A[M827
RhAiLG1gOhV9QX1dKgN1S8n9PGQdM7n@T8b3N7AgOh^ATHQkMg^0S96DRG]gMWb8
Si2<OWQgO8V<THinN7MlQ8R<RgQfM7B1Q8N8O7AaM7j1R8InN75dP8N;S85iM7Ml
Q8j;PGQcM7V4RHV6O7AcNHB<T8b1NGMhPh^?RH1iM7J0R8b7P7]`L7^8S8R4NgAc
N8B;R8AlM7AiPHV<QgahN7QnQhR4OgAdOWn8Ti27OW]lP8b<S8QlMgV0Qhb?R7if
LGV7R8^7NgA`N82;Rh=kMW=gPhR;QgQdL7InQ8j6NgA/M7n4S8MlM71gNHB>R81f
L7=hPhR9Q7Q`LGV3Rhj9P7UhO8R>TI28O7]nQ8j@S8AhLgAoR8^7PgQcM7V6R8B0
MW5aM829S81gM75hOhR<QWU`LGMlQhR6O71_MX2;Thb0NgAhPHb?SXQiNGQnS8n@
R7akLg^8S924N7McN7n8Rh1lN7=lPhR@RH1hMW^0Rhb7PGMfMgj7S8V0N7IfP8R?
SXQkM7MlQ8b<QgQfM7J4ShN4Ng5`Lgn7R8QhM7IaP8R9RgafLgAnRI2<PgUdMWj7
SY24O7QfP8R;ShAhKg1kP8j<Q81fM7b7SXb8P7QfN828ShQoN7AiP8R>R8AlMWb1
RHj<Q7ihNHB<Thn8PGQiP8R@S8MoM7QlPHb8QgmdLGB4R8^9OgM`Mh28S8R1N7Ag
OXR<RgihLg1lQhV8Q7]`LgV4RhJ0N7=`Lh29RH5hM75dPHb<RGiaM7AoRhV8P7Qg
MX28R8b0NgagPhb>T8R0Ngb0R8jAR7ikM7b4QXb7O7McN827RhR0MW1gP868R81l
L7=oQXR4P7]cLgR0RHAnNG1`MXB<R8AlM75gPHb<Q7acL7InR8b6O7AfN7n<S8R0
M75hO8V@S81fM7MlR92?Q7UfMg^7T928O7MhO8B;ShQoMgAkPhjAS8AlN7b7S92?
PGIdMWn7RH^4O7AiQhb@T8MoNgV0RHj>QWagM828R8R3N7I`O8>4S85hM71hOXB8
P7QdL71nPhB8OWAaLgn4R8b0M7AcNhB9SX5hMW=kQ8b@R81hM7j7SY64PGQ`O8><
T8R0M71gOXR;Q81gM7IlR8b;Q7UfN7n7SX^3NG=dNHB;QhAlM7AlQ8R<Q7miMWV0
RH^4P7MdM7b4S8R0NgIgO8N>S8MlNGaoQi2<R81hMgj3R8b6O7QfO8J<S8V4NgMh
Q8b>Rh5kM7R4RHb;OgIaLg^3QXMlM6a`NH26R8=dL71lR8^>QWmdL7b8S926NgIf
O8B>SXQlM7AdPHR>Rg]fLgR0QY2>PGadN828Sh^0NG1aNh>;Q8=kKg=iP8V9PGQd
L7B4R8V8OWMaN827RHB1Ng=hOhR>QX1hMWMlR8b;QWQdN7b4RhV4O7AdNh6<RhMl
MWIhPHV;RH1hN7V0Rhb<Pg]hN827RHR0N7AdOXJ;R81hLg=hQ8^<Pg]fM7V4SY29
Q7QhP8B@U8j8N7MkPHb<S8AhM7N0RH^8Q7M_M7b6RhR4NG5cNhJ;S8MiL75hP8N8
PGQ_K75kQ8N4NgAaLh28S8b0NgQkPhVASXAkM7R1Rhb<QgahN7j9T928OgMgNHJ@
SXUkM7IhPHR9R7ifN7R0QhN6O7A`MWn4RHV0MW1dOXN9R85gKW1hOhN8PG]cLGb6
T9>>Q7ahO8R@T8R4O7IiPH^<QX1hLg=lQh^9PGQ`MWj7T8n8O7QhOXR<SXInMWAl
PhV8P7Q`KgIlPhR4NGI`N7n8S8AnLg1fO8J;RH1dL7IlR8V9P7QdLh27Shj4O7Ak
PHVAS8QoM7QoRI>@S7mhNgb;Ti>@Q7]kNhB<T8QoNgAfPHR8QgmfMWAkQ8R8P7mi
Nh67S8b4O7QfOX67R8AiLg5dNhB8P7QdKWAlQ8V4O7=aN82;SXb1MWIgP8N?S8=k
LGQoQ8j;R7adN7b9SX^9OW]iNHN<S8MlNGIhP8V<QgafMWR0Qhb;P7IaMgb4R8Mn
MW5fNH>8Qh1hM7AlPHR9P7UaL7QnR8V4OWIcNH28T8N1O75iP8N>R8IgLgUkR8^6
Q7QdMWR6QhN0MWIdNHB9S8AlN7]oR8b<R81fN7b3Rhn;PGUhNH>>S8^4N7=hP8R@
SXMlMgQnRHj<R7]cMgb4S8b7NGIdN8B8R8IkM71dP8B;QgafM7MnQXV6P7MdMWb4
R8MoN7AfOhB9R85iM7AlQ8^9PgQaM7J0S8N1NGIdMX>;S8R0NgQlP8B;RGakN7Qo
Qi29PgadMgb4RhR4O7MhOhR>T8]oN7^1R8n@Rh1hMgj6S8b8PgQhOh^?T8n3O7Ah
P8V<QgidKW1hPHR4NgAdLGN7S8V3NgIfOhB>T8IlN7MhP8R<QWafLGN0QX^8P7Ug
NH68RHR1MW5fO8N9R81hLG1hPhN8PGQfLgN1R8R1O7QfNhB8RHQoN7QkPhN;RGih
LgJ0Q8R6O7QaMX24R8IlMW5hOX>8Q7ahL7AoPHb9PGafMWn8SXb<PgaiOhV<ShV4
OWUiPhb>RhB0O7j4RHj9Q7ihNgn7S8V6OWMhO8B<Rh=lMWAlQhj?R85hM7b4RHb7
PgUgO829S8B0NGMhP8j?R8AlN7QoQhj9P7UcM7V1R8R0N75cMh28Qh1hL6mcNH>8
P7Q`K75fQ8N6Og5dM7^4R8QoN7MfO8B;Qh1hL7AhQ8V8PgMfM7R1Qhj8P7]gO8><
T8b4O7QkPHV<Qh5iM7R1R8^;PGQhN8><S8^3O7QgP8R@SX5nN7InQXj<QWmfM7V0
R8R4P7QdNh>9RHN1Ng]iQY2@S8J0Ngj4RI2>Q7adN824RhR0N71dNGn8R81hLgAh
Q8V8R7acMWV3R92<P7QgO8>8RhV0MWMhP8R<R8AkMgQnQXR;PgQfN824R8R4N71d
O8B8QhAkLgAdP8B4PgQfLgN4RHb8OgQgNH29ShR1O7MkP8N>ShIiM7QnQXb<R81h
NGn4RH^4OgQdNhB8QhAoMgAiPhN9Qh5gLG^0Qh^9Q7]hNH>8S8^4OWMgOXB8RH=n
MW>0Q8V@QX5kLgb1R8aoO7IcN7R3QWmlLgAiOXB8R81hMgUnR8^8Q7agN7n8S8^4
NGQdN8>8RH5kM75gO8J7P7UaLgIoQ8R4Mg=`M7b3QhAnM71gO8B<R85kN7R0Rhb?
R7mlO866Shj7PgQkOXB;RHR0M7IhP8V<Rh1gM7N0Rhb<Pg]gM868SXV3O7AhOXR<
S8IlN7MlQ8V9P7ahN7b3R8b6NgMgOX>6RhQoMWQkQ8^;RH1fLgIoQXR8P7MdL7V6
R8R0NgAdOX>8Qh=kL7AkP8V;QgmhN7b4Rh^7P7UdN8>8S8R0NGAkP8^?Rh1hN7Qn
RI2;P7]fN8>8SXj4O7MhO8B9Qh1hM7InQ8V<QWmiNH23S8n4PGQdO82;S8V6N7Ig
NhB7Q81dLGIhP8R6P7QaLgR0PHJ3NG=dMWn4QX1kM75lQ8b@RHB0Ogn8TI2<Qgil
P8B<T924Og]kQ8b>THQlN7R3R8b>P7idLGb6S8^6O7=dNh2<SXN1N7QnP8bAS8Al
NGQnR8V4P7I/LGJ0QXAnLg1`M827QX1hLg=fOXB1P7MaMWR0Q8B4O7=cN8>6QXAi
Lg1aNGn4Q7igM7AlQ8R8R85hN828Rhb9PG]hNH6;R8B0N7QkPHR9R7agO7R4Shb<
QW]kO8B<S926O7afP8b;S85iMgIkP8R8O7MdM7b4Qhb4NgMhP86;RHAoM7MkP8R8
QWmhMWMoPHB1O7=`LgN0Ph5kM71`NHJ;Qh5kLgAlPHV9PGifM7]oRHR4OWMhN82<
RHV3NGQiPHN7QgmhN7J0R8J8P7QgM7n4RHQoNgIcO8B9S8=lN7IoR92?R8=lNH27
Si28P7QfN828RhN3OW]lPHb>RhAkN7MnQXb8Q7ihN7b4RH^7P7ahOhV;S8V0NgQo
R8n<RHAiN7V1RhN4OWQdMh68QhInMWIdOhJ7QgagLG5lPHR7P7UcM7b4R8R4O7=g
OXB<RHN0MgJ0R8b<Qh1gN7b4SXb8Pg]dN824RHIoNg1gO8J;Q8AlN7UlR8R<R7al
Ngn6S8j4PGagOX28S8R0MWAiOXJ7Q7mcLG=iQ8B4O7AaLG^1R8V1NGMfP8V<RhR0
N7QoQXb?Pg]hMWV1R8V4O7=cN7n7S8N0MWAfOhR<RGmlMgR1R8b8Pg]hO828T927
O7MfO867ShQlLG1hNh67Q7acKWAnQ8J3OW1/M7b6R8InMWAaP8n;S8AhM75oQXV;
O7QgLG^4R8QoMWMcO8B7S81lO7AoPH^?Ph1fMgb0Rhj<PGaiO826THR3O7IoOXJ@
SXQoNGj0R8n<S81iOWj<TIB@P7mnPhV<TH^0NgQlR8j@S8AkMW^3R8b9PgadLgb6
R8B1N7=dMX>8Ph1hLG1cO8B8P7ahM7QnQh^4P7UhNh6<T8j6P7ilR8nCU8^4OW^4
RHj<Q7igM7b1S8MlNG1dN7R4Q7adK6i`N860OgI/Jg1kPHAoN71`MWb1PH5iKfa`
OXB4R81hLgJ0Q8J6P7QdMWb4R8R1O7MdO8N;R8AlMgIkQ8^>Q7aiMWb1Rhn9PGQh
Ngn8S8V1N7AdNhJ<RhAiM75hQ8R;Q7alNG^4SXn8Q7QdNh28S8QlM7AhP8N8R85h
MWb6Ri2?Q85iNHB9S8b4NGMhOXN<RhJ0N7V0R8V>R7ihMWb1R8b6PGQhO8B<S8b4
O7alQ8nAT8QnNg^1S8n>QgaiMg^4RHb4O7AdNgn8Rh=iM7IhOXB7PgUcLGAlPhR6
N7AaM7^3R8AnM71hOhB9S8AiLgAnQ8R9R8AkO8>9S8^;OgilOXN8RhB0O75hP824
PgihLgR0R8^8PgUdM7b6R8R1NGAfO868QgikMW=kQ8V4PH1fM7V4R8R0O7QgOXB<
S8B0NGQkPhn<Q85iN7QoRH^7OgUdN829S8R3N7AfP8V<S8AlN7R0Qhn<Q8=gM7b3
R8R4OWAdN7j7R81kLG1dN8>8Q7mdLgAnR8b9QWahNH28SXb7OgMgNHJ>RHIkMgQh
Q8R9QgUhLGR0Q8b4OgQ`MWj8RHN1MWAcNhJ4R81hM7AnQ8b9P7]dMgb4R8R4OWQh
O8N>S8R3O7V0R8j?S8AlNG^4SXn;PGahMgj6S8V3NGAgO8B9RhQiMWMlQ8R8P7Qg
LgR1PhR3N7MdNH68S8IoNGMkPhR<R7ikMgIoQ8^9PgahNh68S8^7OWAgO866Qh=l
M7=iQ8R8Q7mfM7R3RhR4Q7QaN86;S8N4OgQhP8V<R81iM7QnQXj<PGUfM7b4R8V4
Ng5`NH>8RhAkLfmgP8N8Q7a`L7MnR8R6OgI^LH28S8B1NgAcNhR;QX=iL7AlQXb8
Qg]cM7R4RHR9PG]fO8^>T8j8PG]nQhnCRhB0N7R0R8b6P7]cMgb4S8QoMW5dN86;
R8=hL7AnPhN;R81dLG^1S8V6Q7]iOXB<S8b7OWmnQ96@S8R0P827T8nARH1oO868
T8b0O7MgO8B<R85hKW5hO8B6P7aaKW5lQXB0NgAaM7^6RHAlMgAfNhR<QWigMWMi
P8R8OWA`M7b0Q8V3Ng5aNH><R8=oM7AhOhR9Q7ahMgb4R8j9P7QgNgn8R8R4O7Qi
OhR?S8AkNG]oRhb?Rh1lO8>;T9B<Q7agO8J<Shb1N75gP8>8Q7idKgMlR8V8Q7]h
M7b6RHQoN7=cO8B8S8=gLg=lPhR<QWahM7j6Rhn9PgUgOX>;ShR1NGAhO8R;Q85h
MgQlR8b4OgA^LGR0QXMoLfm^Mh26Q85kKg1hP8R8QWacM7R3RhR7OgQfN8J?SXV4
NG=gP8R<S8=lN7QnQhb8Q81gNGj7T8b7OgQiO8N<R8MlM7MiPHN7Q7QdLG=nQXN6
P7IaMWn7S8b3O7QlQ8VAU8^0N7b0R92?Qh1fM7j4R8^6N7=dNHB;S8InM7AhP8R;
RHAiM7R3RhV9P7MdM7^4S8R4O7AdO8B<RHAkM7AhPhb9Q7adM7J0RHV6OWAdM7^7
R8AkLG=cN8B9R7agMgR0R8j<Q7UdNH>6S8b3N71`O827RH5oLg=oPH^8PGmdMg^1
Rh^8P7QcO8>9ShR4NGAhOhV;Qh5iLgAlR8n?R85kN7j6Shb4O7=dMh2<RhAkMW=f
Ohj>R7mfM7N0Rhn8O7QgN829Shj0MgAhO8J>SXIoNG^3S92@S8AoNh28SXn8PGak
OhRAT928OWaiQ8^<R7mhL71iQ8N3OWA_L7R8S8R0N75`N8B>R85kMWMgPhR8QWQc
LgJ0QXR3N7A`MX28S8MoMg1cOXR8Q7idKW=nQXb9PGQaMWb8SXV4N7=`N824S8Mh
LG5gOhB7P7QaKW>0QhR7O7QfN86<ShV6O7AhP8V;R8AgM7=fQXR8Q7QhL7R8Qhb4
N7MaM7n4Qh1kM71fO8B;QgmlMgV4S8j?QgalO8>?S928O7]fOhR;SXB0N7AnQ8b<
PgicLGR0RHb4O7AcMgn9RhAlLg1fO8N<R81gKgAnR92<R7adM7R7R8V4MW=aLh6<
S8IlMgAiQ8b@S7mhMgb6Si2<Q7QdNHB9Shj3O7MgPHb@T8MnNG^3RHj>Q7]dM7^7
R8V1NGI`N8>8RhAlN7IlRI2@S8=oN7V6S968OWUaM824Rh^1N7AfNhR?RHAlM7Ml
R8^8P7Q`LgV4S8b6OWI`M868S8R3O7AkPH^>R8IlN7^3Si2>R7ahO8B<U8j7OgQi
O8B<S8QiN7UhQ8N8Q7AgLgJ0QXj3N7A`LgV4RHAiM75dOX69R7ihL7R0P8j;P7Ud
N7b4ShN4Ng1fN829R85gLg=hQ8R8R7idMWj0QhV6O71`Lgn6R8AlMg1`O8R;R8Ai
LGAlQhj>PG]hM7b8T927P7]fO8R@U8b4OWQnQXnDSXAnN7b4Ri2<Q7adNGn8U8j6
OgAgO8B<RHIiLgIiQ8V7PgU`L7IoR8b4NGA_M829S8MnLFmcN8B8Q7aaKVmgP8B6
PGQ`LGV4S8UnMgAcNHN?S8InLGAlPhj?R7mdM7n7S8j<OgAgO8R?T8n7O7QiPi2A
RhAiMWb1Qhn>QWahN7j7S8j7OWQfO8B;ShMlM7IkPhb<Rh1gM7MlQX^6O7IcN7j7
S8QoLFmcMXB8R8AfM7=hQXR8Q7IaL7R1R8b4NGAcN7n8RhAhL71hP8R<R7agL7B0
RH^<Q7QfMWn9SXb3Ng=`NH69S8IhLg5dP8J<QWUfLGJ4RHn8OgU`N8J9T8]oN6md
O8R>RhIiMWIlR92>QgikO86<TiB@Qh61Q8jAThb1O7IoQhVARh1nNGb4S8j6P7Uc
O827RhR0Lg1hO8B<R8IhLGMlQhV9Q7UaLgR6S8b6O7IcMh>8S8MlM7=fNhR8PGQa
K71kPhJ7NG1^JgR1QXR0N6mcN86<R8=oM71lQh^;Qh1iMgb7Shb8Q7UgN86<RhQn
N7AfP8V?R81iMWUnRI6?Q7QgNgb<Shn8NGMhOhR<THQhM7AiPHb@RgmdLgb3R8b;
P7QdO8N<TH^6OgAgP8V?RHAkLgQhPhb9Qg]dLgV7S927O7QdO8B>T8B0M71hOXN8
QX1`LGQoRHb4O7AdM7n>S8b4N7QlQ8bDT8QiM7AlR8V>QWacLgj4S8j4Ng=_MX28
S8AhL6Q_Nh>8Qga`L7=iQhj>Q7ahN828SXb6NG5cNHB;S8AiLg5hPH^>RH1iMWV3
S8b9PGQaMX27R8N0MW5fOXR<R81hM7AlR8V8P7A_L7J1R8R3Mfm/Lh69SXAlMVmf
P8^?R81iLGR0S96<QgahO82>U8^1NgIkOXJ@Rh=hLgIiQXV;Q7IcLGR0R8V4OWA`
Nh>9S8AoM75lP8bAS8=fMW^0SY2>PgMfMgb4S8j3Mg1`Nh68R8AkKVmhPh^9QWac
L7B1R8b6OWagMh><ShR0O7QkQ8R@R7agN7^0RiB?P7aiO8><UY>;P7MlQ8V@TH^0
NgV0RI6DS81hM7V4SY2;P7ahNHB<U924NgAiQ8V@S8AiKgAnQh^<PGMaKgb6S923
NG1`N828S8=gLFmfOXJ8PG]dL7R1QhV4Ng5/Kg^7RhInM6]_N828R7]dK71hP8^8
OgQ/L7R3RHR4O7AaMXB;SXMlMW1dOXR@R81hLGAkQ8b<Q7UaM7R4R8b4Mg5`NhJ9
S8R0MW1lQhb@R81iM7V4T9J?Q7afO8J>U8b4O7AfP8^<S81gLG5nR92AR7mhMh69
T8n6Og5aNH><S8N0N7AhPhb;R81dMWV3S8b8P7IdM7n<Sh^1N7AdOXN?Sh5oMgAo
Q8^>Q7mcL7N0R8N0M6m_LgV3Q81hKVmdNHB7Q7]cL7=nQ8b9OgA_M7j6R8R3N7=f
OhR<RhIlMgV0RiBCRHAlOh69U96<QW]lOhB@T8^3NGUhQXnASh5nN7^3S96?R7]h
N7b8T8j4NGMcNhJ<S85hMW=iP8^<P7U`KgInR8b3N75`LGb;RHAkLG1/N8J8QgUa
K6akPh^>OWI`LGR4SXb4O75`N86<S8AlLG1`OX^<RGifLgMlQhb9Og=`LgV7S8^0
Lfi_N8B;SX=kM75kQ8b?R7ifMg^4S928O7=`Mh27S8QhMWAdPhV>Rh1hLGN0R92?
QWidN8B<THj8PGAhP8VCShV0NG]nRi>@R7ikN7j9S8n;OgMcNH68S8V0LGAhO8bA
SX=lNGN6T9BFR7aiNH6>U9B;Pg]lQ8^DThj1O7alQhn?RgmiMWR3QhR6O7A`LGb7
RhMnM6i_N8>6Q7adKW5lQ8^9OgM_KWR3Rh^7O71dO8>?S8IoLG1fOhJ4Q7UcKgAl
Q8V8OgA`Lgb4R8UoMfm_MhB;Q81hKg1fP8R8PGQ`L7N0S8V3OW5dM7j9RHQnLg5a
O8B7R7mdLG5nR8b;Q7]dM7n7S8R4NgIcO8N<SXAhLG5iPHb>R7a`M7V0S8n;P71`
Mh28S8^0M6mcOhR;RhAgL75kRHn<R7mgLGj>T967OWQdO8JCU8R3O7QkQi2CSh1i
Mg^4S92>QgUfNH69T924NgIdOhN;RhAkL71iPHV8P7Q_L7^0RHb7O7=cMgn8R8=l
L6mdOhJ6QgQ`JfmnQ8b8OgA_L7^6RHb3N7=cO8B?ShIoM7MiPi2@RH5iN7b4TI2<
PGUkOXR?TI24NgUoR92DU8b0NGn8S9RFS8AiO8>?V9>@Q7QhOhjATH]lLfmhPh^<
R7iaJg5iPh^1N71XKgR3S8IoN6a`NHB<SXAdJ6a`OhV4P7=/KWB4S8b6NGIaN8N@
ThV0Mg1gOX^@R7acL7AhR8n8OgI`MX28TI27O7AfOhN<SXIiLgAiP8N8P7A^JgB0
QXB1MfaYL7b4S8MnMV]aP8^CT8IiM7AnR92;PGQ_LG^6S8b7NG1fP8N>RH=nLgAi
PHn<QWmcLgR4SXn<PgIdN86<Shb3Mg5fP8bASXMlMWMoRi2>R7]fM82<T92;P7Ad
OXN?S8QlL7AfOhj;PGmdM7R0S8n9O75dM7b9S8b3M75fP8b?ShAgLgAoS96@Rgmh
M7^7RHn7NgIdN8B<SXR3O7MkQ8bAS81hLGAoQXj8P7I`LGb7S8j8P7QdPhjAUY26
O7R4Ri2@RH5hMg^3S8j8OgQfO8>9T8^0L71gOXB7R7mdKgAoPhN7PgI/K7J1PH21
M6a[LH24Q8=iM6adQ8b>RgmlN7R7SYB>PgacM7n7S8QnMg1`O8R8S85dL6agP8^<
NgU_JGQoRHV1M6i`MX2;S8AkLFiiPhR@S81hLGV6SiB?QgafNh><Ti2;O7QhOhj@
T8UoN7J0SXj@S7mhM7b;Si28P7UgO8R@Th^0NGAiQ8b@S8AiM7J0R8b<P7UcLGR1
RHR1N71_M7b3PGifK6]`NH23OWM`K75nQh^9OgQaLgn8S8J3NG1gO8N@RH1gLG=h
Qhb<QgQdLgR6S8b7O71cO8N@THaoMg5hRi6AShAiM7R6T9B<P7UaM8><T8b1M75d
O8^CT8AdKg=lR8b?R7QaL7^9SY>;O7A`MhB<SXQlMg1gPHbAR81hLgAlS92;P7]d
N86<T964MgIgNhV@S8IhM75hQ8b<PgadL7^4RHb7OgAcMh29RH=iM6m_O8R8Q7Q_
KVmiQi2;P7McM7b7S8]oLFm^M868S8AhL71dP8^<RG]`L7B0R8j9OgQ/Lg^3S8N3
Mg1dN8J<S8AgM7AnQhj@QgUcMX>9TIB<Q7]lPHbFU928NgMlQhj@Rh5hLgJ0RH^7
OWAcMWb8ShUoN7=fOXR<S85fLgJ0R8j@Q7ifM828T9><P7IhO8N@Thj3O7QlR92D
T8AkM7^1SYB?Q7adMWj8Shb6O7AdO8R>RH5iL71fP8b;Q7]aM7AoS8^8Og1aLgj8
RH]oL6acOhV<SXAdLg=lR8j<PGA_KWB1R8N0Lfa`M86<Sh=fLg1gPh^?R7adM7N3
S8j8OWAaN8><S8R0LFmdO8R<RH=gLgAlQhR8Q7Q_Lg^6RHb;P7MaN8J<S8V0N7Ai
Qhb>RgmgL7R3S92<Q7Q`M7j6S8V4N7=dOX^;S8MkMgIkQY>AR81fMWb7S8n<P7Mc
MX6<SXV4N7AdP8b<S8AhLg1lQhj9PGUdM7b7S8b4NgAdOXN@T8AnMWAlR9B@R81g
MWR1TI>6P7QfN82<THanLG1cNH><S7maKW1hP8R8OW=XK7R1RHb6O7AdO8R@T8b4
N7InR92ASX5hLgN4RHn;P7Q_LG^6S8V1N71aNHJ@RhAkLg1gQ92@QWQ`L7B0SXb6
O75aMh6;RhIkKfacO8R9QWiaK71nS96<PGQhLGn?Ti>7O7IfO8N@T8MlMgAiQ8^<
Qg]`L7N1Rhj7NG1_M86<T8]nM6mdOXV?R7idKg=lR92<PgM`LgV4SXj6N71cNHR@
ShQnM7AkR92ASX=iMgV8TiN>Q7adN8><T8UoMViaNhB>RGmdK71hPH^8Q7Q/L7R0
S8R1Nfm^N8>>SXQoL6mgP8j?S8AfLgR0S96@Q7QcM7n7T8b7O71dOXR<S8IhLgAh
Phb<QWQ_LgV0S8b8Og=dO8B?SXb1Lg=hPhb<RhAhLGB0RHb8P7AaM7V8S8^6O7Qc
OXbCU8b0NgUoS9BHSWifM7b4S9><P7A_NH6<T8R0LFadOhV<S85cK71lQ92>QgQ_
Lg^4S8V4N6a^M829R8AhKVaaOXR8R7aaKg5lQh^<O7I`L7b6SXb3O75dOhJ@S8An
KgAlQ8b9Q7QaM7V8Thb8O75`Mh6;T8UlN7AhQ8b<S8AhLG^0RI><Q7QfMgb;T8n6
NgIgOhJ@T8QlMWV0S9BDSWmfM7b6T9><P75`NH2<T8R0L6aaO8^>S8=cKW1lR929
P7Q`L7b;RhN0NFi/MhB>Qh1hLG=gPh^8PgM`K71lQXb3N71/MWj8ShV1MVmgOhb?
RHMhL7AoS92<Q7a`LGb8S8b8NG=fMhB?SXR0M7IkQ92ASX=fLGV8TiN?Q7QdMgj?
Ti27N7=dOX^@U8QiM71kR8nAR7afLGR4T928Ng=`M82;T8UiM71hQ8jDSX1`Jg=k
Q8j8OW1YKgB0RhQnMVi^N8B<ShAhLgIlQ92@Qgm`Lgb1Shn4O71_M7b;RhMoN71f
PhR>S81dL7=lR8j<PGmfM8B?UYB;Og]kP8bDUhUlN7AkQ8bAR7mhLgj4Ri>;Q7Q`
MWb8T8b6NgAgO8V@ShAiLg5hQXn9PGQ/KWJ0RHn8Mg=hMh2?T8aoM7AlR92FU8Mh
LGR0R92<OgM_LGb8SXb4N71^MX29R81fJF]dP8V<P7Q^JgAnR8V0MViYKWb0RHMh
KV]aO8N<QgiaJG1oQhn?Q7adM82;TI2<P7MkP8bDT8anMWMlQhb?RG]cL7J4S92<
O7QaM8B<T8j3N6idOhRAS7mgL71gPhj;PGU`L7V3S8n8Ng5dNh><THalLg1hQ8bD
SX1`Jg5lQ8V9OfmXL7V4RHB0M6a`O8R>S8AhKg=lRIBAR7ifM7b;UYJ@P7QdNHNC
Ui23NGMiQi2CT8=lLgV4RiJ?Q7M_M7n<THb4N6a`NhRAShMiKg1hSYRDT81fMWV8
Ti>>OgA`Lh28RhQoM6icNhR;QWicL71kR8^<QWM`Lgb;T8n4N75_N8B8S8=hKVQd
OXB;PgQ_I6miPh^4OW1WKgb8Sh^4N6i`O8bASXMkLG1lR96DQWQ`L7V7TiB8O71a
N8BDV921N7AhPhnDT8IhMgj7SiRDQ7QcN86<Ti27N71cP8^@S8AiLG1lR9>AR81d
L7R6THn8O75`Lh><S8MhL6]_O8B<QgUcK75kQY29P7M/Lgb4T924MW1dNhRCT8Ih
L6miQ8b>Qga^K7B1S8b6O6iTKWn8RHQoM6a`O8^CS85lKfmnRI2@Q7M`LGV8T8j4
NFmaO8B?THQlL71hQhj?S7maK7B1SXn9Q7A[Lgb;T8b4NGAdOY2@S8QlM75lR8jA
R7]cM7R7U929O7I`NHR<THUnM75kQ8bAS85fLGR3T9B>PgI_Lgj;T8b1MW1`O8J<
T8AkM7AlRINCRh1cLg^6T92?P7IcM8R@SX^3N71dPhb@S81hLG5lQhn<Q7Q_LGV7
T9>8O7A`NHRAT8QlM7AiQ8bDRgQcK7=nR8j6O6mXM7b3R8AlK6Q^N8J6Qh1`Kfag
PHR8PGM^KWR3RHn8NgA`NHR<THV4NG1lQiBHS8MlMgb8U9R?Q7UcN7n<U8j4NGAf
Oh^CT8MdKg=gQ8b?QgM`L7N3S8j9P6m^Nh28T8alL6adOXb>RH=`K7AlRi>@R7]`
MWb;T92<Og=dOXbCU8n0N7=iRI6@R7mdKWB1SY26Ng5/L7b;ShMhKV]_MhN<R81c
K6iiRhb>PG1/K7N4S8j3Mfm/MXB>T8^0L71hQ92@Sh=cL7B0S8n<P7A_K7b8S8b0
Mfm`NHN?S81gKVaoR96CQgU_K7R6S8n4O7=/Mh2<T8V0MgAhPi2CS8AhM7b3Si>A
QgQfN7n;T8j7OWAhO8V@S8QlM7AfQXj<Q7QcL7B6T9><O7IdMXR?Ti1oMfiaP8R@
SX1gKValRHj<PGQ^KgV6T8n4NG1/N8J<T8IhLfmgQ8VAR7agL7V6T969P7MaMh><
U8b1N6mfO8N@R8=dJfmhR8j<Pg=^L7N0S8j4NFm`Nh><T8UnL6idPHb<RH1`Jfml
R8j9P7I/KW^8T8b4N71_O8VAT8QnM75hQhj@R7QaL7N6Rhj8O7A`N8B>THb0MgAg
QhnDSh1hL7J0RiB?PGM`M7n8Shb1MfmdOhbDT8IlL71nS9BARGmdM7V7TI><OWAa
N8N?TI20M75dP8bASX1hK71oQhn?PGQ`KWJ0Rhb1NG1/Mh>;Sh5hLFihO8RAQWa`
L7^0S9>@QWMfO8>@UiB8O7MgP8b@U8QkM7B0QXb?Q7Q^K7J1RhV6O75^Mh><ShUn
M6ifPHR?R7mdK71hQ8R7O75_L7V7S8^0M6]/Mh>?Sh=fKVacP8V>Q7I/JgB0SXn9
OW1`MXN@TI1lLg1dPHjDT8IiL7B4T9BCQ7QaLgb<U926MfiaNHV@ThUhMW1iQi2G
RGm`KgV0S8j8P7=`N8B@T926Mg=dO8V@Sh5dKg1hQ8R<Q7I`L7V4Rhn8O7AcO8J<
THV1Mg=lQhnCRh1dKgJ1S92<P7A^L7j;T8b4M6aaN8N@T8QkLg1hQXjARGQaL7R7
T9><OW1^MhB?U920M6mdPhbASX5gL7MnQiB?PgQ`L7b4THn4O71dO8NAT8QiLgAi
Qi2CS85dL7R4SXn8Og1XL82<Shb1M6]_NHR@R81dKVmhR92@Q7aaKgn<T927NgAa
NHJDT8AlLG1kQ8n@PgQ_Jg=lR8j8Og5`N7b;THV4MVigMhR@RHAdL71gQhb;Q7Qc
Lgb6SiB<O7IfO8BAU8aoM71lPhVARh1_JgQoRI28PgI[Lgb>TH^8N71cN8bDRHMi
L71cP92?R7U`L7B0S8j;Nf]`Lh2?SXaoM6a`OhR<S8=gK7>0RiB<QWa`M7b8U8b3
NgAfOhR?T8QlM7N3S9BHTHQiMh>6T9R@QW]fNhB>U968NGAlPHnDS8=hLGAkRhn<
R7M/LgB4U928N6m_MX><ShQhKfa/O8J9QgU[IfihQ8^7O75YL7b4S8^3M6aaNhN>
Rh=dKVihQXV>QWQ_K7N3RHj7Ng=/LGj9T8QlM6ifP8bCS85cK75oR92<OW=XJgN7
U924Nfi`N8B?T8IgK75kQ9>CRgm`KWB1SXb7O6a/M7b<T8QoLg1cOhb>Sh=gN7Ao
T9B@R7mhNhN>UiN9PgUgP8VDT8UlM7=hR92DS81kM7R8SiB@PgacMh29Ui21O7Id
Ph^CT8AhKg1lQY2@QgacL7^7U9B9OgA`N8>@ThQnLg1gOhj@R81`KW=iRHn8Og1/
L7V9T8b3M6m`N8B>S8=fK6agQ8^@QWI`K7J3S8b1O6aXLG^;S8QlL6U`O8R@S8Ad
L7AiRHR;Qg=cM7V<SXj8O7A^N8J8S85iM7=iP8V@RGacLgN0Ri2<PgMdO8B@U9>;
P7R0RiBIV8moNGb4T9BDS7mfM7b;U927O7=cNhRAThUlLfiaP8bAR7adKg1nRhb8
O6iVJ7>1R81iKfITLH>8RGi`JFQdQ8b>QWa`K7R1SXb4O75_MX6>S8R1L71fP96@
S8AiM7>3Si2?Q7Q`L7b9T8n4NFm/O8V@T8MhKfadQ92@Qh1cJg>4T9>;PG1^M7j>
T8j4LG1dP8bDSh=dKg=kR96<PGA^L7R8T8j4N71`N8J@T8MiKW5kR9BFT8=dM7R7
U9B@QWMaMX2?THj4MW1_O8^?S81gKfahPhb@Q7McKgJ3S927O7A_NHB9T8V0Mg1i
Q92ARhMfK7B0S8j8OW5YK7N4S8V0Lf]XM8>8SXAhLFmiQ8j@Q7adL7^0S927O75`
Mgj;T8j0N7AlQi6HUXb0MWn9TIRFS7maN82;Ui6<O75dMh^?Sh]iLFadQXj?Rgi`
KWB0S8j9O7=^L82<T8R3M6a`O8R@Rh1gKVmhQXj8PgA[K764SX^4N7=^MXJ?ThQn
MW5kQ9>GT8=gM7N4SY6<P7QaM82;T8UoM71dNhN@T8IgL7AiQ8n<QWQ`L7B6Shb;
O6m`Lh6<T8anMW1fPi2HTHAhLGN1T9VFQgQaL7b9T9B7Ng1aO8RCShAhL6igQ8j>
R7]`KWJ3RI><O7QdMXB<Thn4NgMlQ8bHTHQnMgR1S9>@RGadM7b8SXj4N7A/M8B<
SXAhK6acP8^?R7]`K720RI2<Og5/KW^9Rh]lLfUYN7n;S7acJf]gOXR;OgIXJgB0
T8b6Ng1cN8N@U8b0MW1dOhj?RgiaKgB0SYN<P7Q/L7^;UXj4N6mdNhRDTHQhKW5h
Q8j@QgU^K7R0S8n7P7I_M8B@Shn4M71cP8V>Sh1iL6moRI6<P7UYKWR4T8^4NFm[
Lh6>S8IhL7=hQiBDS7mhMWV6TIR@QWahOXB?U8n3M75dO8V@Rh1fK6mkQi>DR7I`
L7J6TI><OWAdO8JAUi24N7MlQ9>CS81_KgAnRI2>PGA`Lgj;Shn8MW1gNHVDT8Mf
M7=hR8^?RgM^KgN4Ri2;O7=`Nh><U8ioN6mdPhVAS81fKgB0Rhj?Q7QcL7^8S8j3
MW1_N82;Sh5hK6QfOX^>P7Q/Jg>0S929O7A`MX2<UXb4MfidP8nDUX]lM7AlR9>@
QWU_L7V7Shj8N6m/MXRCU8]nMW5hQ9>AR7i`K7B1T9B@Q7]fN8BAU928NgAhPHbF
THMlLgAnQ92@QWU_LGV0R8b7N6][MX68R8QkK6]dOXB<Q7Q`I6akPHN1NfmXK7J4
SXR0MW1dOhnDUhalN7AnSiJGSgigM7R6TiB>P7QdNHN<V9B4NG1hPHbARH5fKg5l
Ri27Og5[K7>6SXb1Lfm/M86<T8AiL6mfPHb<R7acK720R8b8Og1^LG^;T8b1MWAd
OhbATHQiLG>0TIJDRgmgLgb<U9B7NGIfNHRCTHalLG=hQ8b?RgU`KW61R8^9O7I^
LH2;T8n3NG5dO8NCRh1hKW=lR9>@R7QaLG>3Rhj8O71/M7j9S8MkL6M/O8N?Rgma
K6igPhb>PGQ_KW^6S8n4M6i^N8B?T8AlM75lPhnDRgiaL7R0T9RAQ7MdNh>@U926
MW5hOh^@SXAgJg1gQY69R7Q_K7N7RHb8N75_M8J@T8b0MgAhR96GTH1lMWN8U9RD
Qg]dMh>>U8n0Mg1_P8^DThIlLg1nSYJDR7UdL7J7T967O7A[M82;SXQlKVaaNh^>
Qgm`K6iiRHj9Og5[K7R6R8MlKVQ[MXB9Rh=hK6]hQ8j@Qgi`K7B0S8n8OW=dMh6D
U968NgQkQi6FThAnMWJ3Ri6@QWM_LgN4RhV4N6m/MXB7S8IgLFadQ8b@R7acK7N0
R8n8OW1XLGb4Shb3Mfa`OX^@ShUiKgAnSibHT8IlNh2AWibDP7MgN8RAU8anM6ig
Phb?RGa`Kg>0S96;P7A/L7b8S8j0LFa/N8B?RhAhKg5hQ8j>QWM`K7J3S926NG1X
M7j<ThQlL6mcO8b@S81`K7>3Ri6@Q7Q^LGb7Shb4N6U/N8R?S8QhL6mdQ92DR7ad
L7>0S92<Og5aN86<TI64MW=hQ8bAShAkLGB4S8n?Q7]aLGb8Ti64Og=`NH>@THQn
L71iP92CRh1dLGR3T9B>Q7U`Mh2<U8n4N7=fO8VAT8QhLgAkRI2DS7adL7V6T9J<
OW=^M7j;TH]nKfacNhN>R7mdJ6alQ8^<P7A/KWR6T8b3MfiaO8RCTHQnLG1iQhjA
RGQ_K7AnRHb7Ofm_MX2<S8j0M71`Q8b>S81hL7=nS9><Q7Q_LgV;T8R8O7=cN8R@
T8UkLg=dPI2@R7m`Kg=kQhb7O6m/LgV8S8n4Lg1cOh^?ShIiL7=lRI2@RGM`M7^;
Ti>?P7I^N8R@T8V0LfmfP8jDS81kKVn0S96>Q7M_LGV8U924NG=dN8B@ShQgL71d
PHbCRh1fLgj7T9B?Q7A`M82?ShQoLG1aP92>S85dKVakR8n?PG=_KWN7THj4N6i/
N8B?T8IiL6mgQ9>@RH1`L7J3T9><OgA`Mgn8T8QoL6Q`MhB8Q81_J6mdPhb;PgM`
L7V9T8j8O7=_MXJ>T8QhM6i`P8bARgadKg=kR8j8OW1_L7b8Shj3N7AaO8^DThMk
M7AlQ9>CRgm`Lgb7TIBAP7=dMXJ@U961M7=fQ8nCT85gKW60Ri>AQ7I^L7j;Ti>;
OgIfPHjDU8alL71iQi2CRGadL7R7T9>?Pg=fN8B@UY1lM71aP8VAT8AcKWMnQhn@
P7AcKWn8T9B9P75aN8>>S8IlL6acOhN<R7]cK71nQXV7O75/M7b7T8QoMVicOXbC
SX1dKVigR96@Q7A`L7R9TIB9NG1_Mh>>TH]oL6idOXV?RGa/IVagQXV8P75/K7V7
S8j4MV]_NhR;RHMkL71hR9BAR85kN7b<Ti>@PgUdN8B>T8b1M71dP8nAThIhL71o
Ri2?QWQ/K7R8T8j1Ng=[M8J@U8MlMW=lQY2HRgmgL7R7TiB?PGQdN8B9T8j0M6a`
O8^CS8=fK6afQ8j9PgA_L7J8T8n;O75`N8J@U8]lM6UaQ92AS8=gLG=nT9B?R7af
NH6@U968N7AdP8^9RhAgK6mgQ8j8PGA/JG>6R8b7Mg1YM86;SXQkLfa`OhR?QWQ`
K7AnR92>Q7U^N8J<UY28Ng1dNhR@S8QlKg5hQ8j@R7a`KW>3T9BCPgAdMh2>THj4
MfmaOhR;Rgi`K6miR8b<PgA`L7b8SY26NG1_N8><T8UlLFacP8N<R7U`JG5lQ8b8
NG1^Kgb7S8V0NFmcOhJ?SX5hL75lR8jAR7adLGb3S923OW5^N82<SX^0L71iPhnA
T8AhLgJ1SiB@Q7QdMX28TI23MfmaNHJ?ShQiKgAiQ92CSXAiM7R8Ti>AQgahNH>A
U8n7N7AhP8nCThQkMWR0RIBDR7UgM7b;TiB;Ng=dO8J?T8QiLFihPhR@QgQ`K7N0
S8j9P6m^LGj8S8QoL6M/N8>9Rh1aK6idQ8b<QWI/KWJ0Rhb4N6i_NH6;T8UoKg1k
Q9>@S85aKgB0RHb9P7A/KgR8SXV4Mg1`N8VDThQlMWIlQY2FT81iM7R0S927OgA/
Mh2;U8n0MW=hPHbAShQiLgR6SiJ@Qh1dLGj;Thj4OW1`O8BCU8UoMW=hQ8j@R7a`
L7R0T929Og5_L828ShilL6a_N8NCRh5dK6mhR8j?Q75`KWV8Si>8P7A`P8R>T8N0
MV]dQ8n<QWmcKVihRHj4Ng=^KWR8ShanL6a^MhJ?SXAhL6mkQY2AQWUaKgN3S9><
O7A`MhB>Thb3Mg5gP8^@S81hKg5oR92>PGIcM7b9T8b4O71_N86?T8QhM7AhQ8jA
S7a`KgR3S928Og5/L7^8THV4MfagOhbDShQhM7IlRi2@R7Q`LGV8T968O75`N8N@
THb0N75hR92GTHIiM7R0S8b9Og5^L7b6Rh]lLF]/MX28R7idJfiiPhj?QWacLGb8
T929Og=dOhRDUY26MgIlQi2AShAgLgAoS9>;PGQ`L7j;Rh^3M71`MX6>Rh1gKfmd
P8n<Q7A[KVmiQhV4M6U[LGb7T8]oLFmcOh^>SXIdL7R0Si>AR7acL7n9Rhj;OWId
NhR?ShQlM6mgQ8b@R7mdL7B0S8n;P7MaM86@Ti24O7AfPhbATH=iLg=nRI6?R7id
Mgb;U9J<P7QgOh^@U8anM6idP8^@R7idK71kQ8V4Ng1YKgR7S8QoLfi`O8b@SXAh
Lg5iRIJFR7QaL763S8n8N71^Lgj8S8UoMVmdP8V<S7maL75lQhb;PGQ_M828T8n7
N75fNHV?S8UlLFmhQX^<R7idLGR4SiB?Q7MaNHR@U928MW1hP8b@S8QhKg1lR8b<
OWA`J7J7SXioMfaXL7j;SX1fKfiaOXbAS7a`L7AlQXj<P7MaMXB<UY67O7AhPH^D
T8AhKW5lPhj<Q7Q^L7R3Shj8O71`M8>;S8anM6agPHRCSXAiKgJ3Ri2?QW]aM82;
T8j4O6m`NhB?S8=hLG1hQ92ARH1gMgb8T9>>OgQfO8N@U8j6M71gPHnATH=dMWAn
S92?Q7A`KgV9S9>8NGMcO8b@TH]lMg1hR8nDRh1hKgR4Ri2<O7=^LGb8T8UkLF]_
NHJ?S8AgK71kR8j<QWQ`LGV7T9><P7MfNhRCT8b0M75dPhb?SWmcKgB3Ri2?QWUa
LGb;Shj6N71`NHN;S8IgLFagQXV>QgafK7N4Rhb6O75/L7n8S8MiL6U_N8N?RH1a
Kg=lR8n;PgUcLg^;Thn8O71aMXJ>ShQhL71dPHb@Rh1dLgN4T9>@PgQfMh>>Thn0
N7=dP8R@T8AhM7=iQ92>Q7]`Lh28T968O71`N86;S8]oM71hPh^@S7adLGN0RHj?
Q7A_M827S8j1Mg1cO8bCTHQlM71lRI2AQgmfLGV4Ti68P7I`NHB?ThanM6i_Oh^>
QWU`J6]hQ8R6N6aYJG>0RhQlL6a`MXB<T8MhM7B0RI2DSX1fM7b7S92<P7QdN8N>
Ti23MgAhQ8bDSXAlK7AnQXn<Q7M`LGN6SXR4O71`O8N<THUnM7AhQ8j<RGi`L7B4
SY2<P7A^M8>;THQoMVmaO8R<Rh=aJFagP8^<PGM`KgR4S927O75aNhB@U8j1N7Ak
Q92AShAlM7R6S9J?P7Q`Lg^8Ti23M6i`O8J@T8MhJg1fPhn>Qg]cL7R4THn7O75d
Mh><SX]hLG1aOXR>S7idK7B0R92?Qg]cN7n8THj4NFicN829Qh=hL75gPh^9QWQc
LGB0RHj9O7A`M827S8V0M71dO8R?RHIkLG=kQhj>QgQfM7b<T9B9P7QdP8N>ShAl
L6mcOhV>QW]dL7B1S92<O7I_Mh>9U968Mg1dNh^?ShMlM71nR8n?Q7a_KWR4S8n8
NG5cMh>@Sh]nM71aP8VDSh1kL7B1RiB@R7adMgn;THb7OWIdP8bAT8QoN7N0RiB@
QWiaKgB0SXb4Ng1`LGb9S8IlLg5cNhN>R7adL6mhQ8^<PGQ_LGb4Shb6Ng1aNhN@
ShIhL6mdPHb<QgadLGR3S92?PGIdN7j<T8R0Mg1`NhB;RGaaKg1hPHb;Pg]_LGV0
S8^4NGAdN8B<S8QoMg5gQXbCS7mfL7=kR8n9PGA/L7R6T8j4N6iaO8J?T8MkL75k
Phb@RGicL7^6SXj8P7A`O8J?U8UoN75hQ8jCSX=hM7R3RiB@PgagNHB<Ti27NgAh
P8RDU8b0MgQkPhn@RgmhMgV1S9JCPG]iO86<T8b0N75aNH>7QWU`JFahP8R<OgA^
L7^4Shj6O71`NHB<T8MnM6afPHb@R7]aKW5lQ8^8OW=[L7b4S8aoMg1^NhB;RH1g
L71lPhb<Pg]dL7V4S968O7AaNh><T8QlMW1hPhR@S81fKg=hP8^8O7I^L7QoRhR1
N75cO8R<T8]nMWR0RI>CR81gLgR6Si>8O7McM7n<Th^0N75hPHRCS8AhKgQlR8j;
QWUaM7b6Shb4OgMdN86;S8N0NGQoR92DShMhMh64SXn9PgAdMWn>RHQnL6i_NhN<
SWidLgB0R92AQWacMWj;U9B?P7UfNhN>T8R0N75gP8R<R7adL71iPhR8P7I`M7R3
QhR4MW1`NHB6R8=kKfidP8V7Q7afLgJ3S8V7P7IgMXB@S8n0N7MgPHR?S85lMWR1
RI2?Q7aaN7n8T8j8OWIhOXV@S8QnLGAiQi>@RgmfM7N6S8n<O7=aM7n9ShQlLg1c
O8N;RgmdLGAlQ8b<P7Q`LGV3S8j4Ng1cN82<T8R0M7AlPhb?RgmdLgJ3SY>AQWaf
N828Shb0Mg1fOXB;R81dKg1gQ8R8PgQ/KWR1R8R4NG=`N8>9SX^1MgAhQi2@S8Al
LGJ0RI29PG]dMh2<SX^4NgAaN8J<Qh=hLg5gQ8b<QgQ`LgAoR927MgA`LGb7S8V0
M71dOXR@Sh5hMWB4SiBDRH1hM7j6Si26O7I`NH28S7miM6mfO8J8P7]`K7AhQ8j6
OgAcMgj8S8^0N7AfP8R>SX=fL7IiQ8b;PgIcLgV4RHb3N71`NhJ<RhMnM71kP8N<
R81fM7R4Si2<R7mdN86<Shn9P7QfOXR?S8B0M7AkPhn;Q7acM7R4RHR4MgA`Lgn7
S8AlM71fOhN;R7adM7B0RHb<OgQcLH28Shn3NGAfP8NDT8R1MWQoQi2ARh1fN7b0
S8b9P7IhNHB<T924NgUkQ8nCThUlOWn3SYNCQh=iMWn7T8b8O71cNh>>ShQnMWAh
P8V;QgadLgN0Qh^8O7IdN826S8b6O71hOhB<S8AiM7=iQ8^9P7Q`KgQnRhR0O6a^
M828QX=kL71dP8n<S8InN7N3S92<Q7UcLgn7S8V1N71aMh><RHAlM7AiPhR>Qg]`
KgAlQ8R8P7AdMh27RhQoN7AdOhR9RH5hN7R0RH^<PgQgMX28RHb1N7AdNhB>S8Ai
LG=hQ8b>S81fMWj8T96<PgQfN8><S8R1N7AiP8R>Rh1hM71kQ8b<P7]cL7^0RHb0
N75aNH><T8R0N7AnP8^@R8IgL7QhQ8J1OW5/LGR4R8IoM71cN8R?R8=iM7QlR8n?
R7agMgb6S8b<P7MhNhB8S8UlMWAgPhR;R7adL760QXV;OgUaL7b7RhR4N71dO8J<
ShAhMW=iQ8b>RH1iMgn8SiJ@QWakOhR@TI28P7]lPh^>S8=kMgQoR8^8PgIdM7V7
RHV0Mg5`NH>8Rh=lLG1hPHR9QgacM7R0R8b8O7MdMgn4S8R0N7AhO8N;R8AiMWR0
QX^<Q7agMh28S928OWIcO867RH5hL6mfO8B;Qg]cL7IlPhR4OWIcNhB;RHR4O7Uh
P8^9R8AlN7QlQXN;R7ahM7V1R8b8P7QdP8B9S8V3N7AdOX^;Qh1hLG=lQ8R7OgIa
L7B4R8N1M71`MhB<Rh=lLgAlQ8^<R7igMg^4S8n8PGakO8><S8b3N7alP8R;RH1g
MW^1Q8R;PgQdMgb4R8N4N71dO8B9ShQhMgQkQXb@S81fLgR3Ri2<Q7QcN869T8V4
O7AhO8J?RHAhM7MgQ8b;R7afM7n8Ri28OgQhP8J>S8V3M7=iPHR6QXAdLGIiQh>1
P7AcL7V6PHAnLG5_N8R8R8=hMg=iQ8R8PgagKgJ1R8^6OgMdN8B?Shb1O7QhQ8bC
T8IlMgV1R8j;Q7UdMgb4RhV4O7QkOXB4QX1fM7AhP8R6PG]cLgN0Q8R3NgMdN828
RHJ3N7AiPhV<Rh=hMgMoQhb;PGahMh68S8^8PgQfOXN>RhN0O7alQhj<QgmiNGV3
Rhb8OgQfN826S8V1NGQlOhN?RhUoN7]lQXR8QgahMgV0R8b3O7QcN828QXAiLG1d
NHB9PgacL7AnQh^;PGUdMWb4S8j7O7MfO8B8SXAlN7AnQ8R<Q7mgMg^0Rh^6OWMd
N828Rhb0M7MhP8N<Rh1oM7J3R8b<Q7]hO7n6S8b6P7QhO8J8R81iMgAhOhN6PG]f
LGN0Ph^6O7QcN866RHB0NG=kP8J<R8AlN7QkQ8R8PgalN7b3R8^6P7QgNH68S8Qo
NGMiOhB6QgmgN7R0Q8R<P7UcM7b0QXB3Ng5dO8J<R8=lMgAkQhb9Q7mlN7j7Si>7
OgalP8>?SXQoL7AhOhR;R7mdL7MoPhR6O7A`LgR4RHN1MgAfN8B7QX1hMWMlPhN9
QX1kO824SXb9Q7mkO8B8R8IoNgQiPHR8Q81hN7V1Rh^9Pg]iN828RhV3OgQdOhB7
R81lM7AhOhV9QX1fM7R3R8b9P7UdM7n4R8N0O71dO8>8Q8B0M7MoPH^8OgafL7R4
R8B0N75dN7j7PGahL71gO8B8P7afLGN0QhR6OWUhN824S8N4O7=iOh><R8AlMgUl
Q8b;S81lOWn7RhR7OgQhOhJ7RhAkM7AiPH^;QgmfM7QlQ8R4P7QdM7j4QX^0O7Qh
PhR<RhR3NGaoQX^9QWiiN7R4RHV8O7QdM827S8V0MgAfO8J9RH=kMgR0QX^<QX1l
O8B8SXb9Q7^0QhR>S8^1NgmoR8j9R7igNG^3RHV7O7=dMX26Q8MnM7AdOhB8R7mk
MWAoQhR8P7UhN7^4S8b4O7IdO827R8AlMWMkP8R7Q7mhN7N1QXN9P7]gN7n0QhAn
NG1cN827Qh1hLg=cP8^7Q7mhNg^0QhV8NgQiNHJ8Qhb1MWUlQ8V;Rh=nN7b4Rhb;
Q7ihN8>7R8R3OgQgOXR9QX60NGUkPhn;Q7ihNgb3RHb7P7]lOhB9RhN0N7UlP8R8
Qh5hN7b1RhV9PGUhMh27RhV4O7QhN8B4Qh5hMgIhP8N8Q7adMW^0QhR7OgAcMgb4
R8>0MgAhOhR7Q7igLfmhPHB3OWQ`LGQlQ8AnMg=dN828S8B0NgalQXn;R81hMg^4
R8b9Q7ikOXB<SX^8P7aoPhV<R8AlN7MlQXR6PG]hMW^3R8R0N7AdN866R8IiM71f
P8B9Qh5lMW^0Qi28Q7mgNH24Rhb4OgQhP8B8R8AnMWQlPhJ7Q7ahM7b4Q8b6OWah
OhJ7Rh]oNG]nPHV?RhIoO7j4R8V9P7QhN7b0QhB0N71gOh>8R8=hMgQiQ8^8PGUf
LGN0QXR0N7=`M7^4R8N1N7QlP8R>R81iMgQoQ8V<Q7ahN7^0QXN3O7QgO866RHMn
M7IhO8B9P7afKg=kP8J7PG]gO867S8V6OgQkPHR;RHR3NGb0QXj;Qh5iN7n4RI29
Q7ihOXN>RhJ0NgQlQ8b?Rh5nN7b3R8b9P7]kO827RhJ3O7MhO8B8QhAkN7]nQXN9
QW]fM7]oPhB3N7=_M7anQ8=lM71dNh64Qh=kN7V0Qh^;QgadN7n4QhN3O7AcO8B8
R8B0MgAkPHJ6P81iMWQoR8R4P7QhN7b6RhJ0NgMhO8B7Q81gMWUlR8V8Q7QhMgb8
S8b4Ng]gNhR;S8IiN7AiOXB;P7ahM7]nQ8R4OgQhNgn8S8R0NGIiP8B<RH1lN7Ql
Q8V;Q7ifN7n1R8^3O7]dO8R<S8J1N7AiP8^@R81lM7R1Rhn;Q7ahNH28S8R4O7Ml
OhJ?SXQnO7]nQXV8QgmfM7^0QhR4P7IdNH29S8MoM7AdO8J4QWigMgR0Q8V9P7]g
N7b1R8J0OgQhO8>9R8=lN7QlPHV8QX1gMW]oQ8R6P7QhO8>9Rhb4OgaiP8R8RHAl
MWMkP8J4P7ahM7N1QXAnN7=`N7b1R8=lN7MhP8B6Qh1dLGInR8^8PgagMgn9S8R4
NgUhNhJ;RH5kMWAnQ8R;QX1kNGb7S8^6OWMdNH69SXMoO7UhP8R>RH1lNGV0R92<
Pg]iO7j6RhV3NGIhO8>8R85iMgMoQXR;Q7igN7j4RhR3P7QhO8N<S8QoNGUgOXN9
Q7miMWR0Qhb;PG]fMgb4R8N3NgQhOXR<S8N0NgQlQhb?RH=lN7^3R8^3O7M`MWj4
RhB1O7MhO8B8QgmiM71hP8J4OgQfM7^1RHQnNgAcO8B8R8B0MgAlPHV9QX1hMWV0
R8^6PgadNGn3RhN1NgIhNhB7Q81hMWMlPhR6P7UcM7AiQ8B0NGAaM7V1Q81nN7Mf
OhR<RH5kN7QnQh^8Q7aiO8>8Shb8OWalOXR<ShQlN7UnPhR<Qg]dM7aoPHR4NgAc
N824QXR3O7MlQ8R<RhJ0N7b3R8b6Q81hO86<U8b<Pgb0PHbCTHb3O7b0Ri6?Rh1l
NGb4S928QX1hN7b3R8AlN7QhNh21O7I`KVidNgn0MgAcLGQlQ8=lMgAfNGn4R85f
M7QkP8R<R7ifLgb0Q8b<PG]iO864S8j6P7]lP8B<RhMlMWanPhN;R7iiNgj7RHV8
NgQfMh64QhAnN7AhP8R8QX5fM7AiQ8B4OgUgM7b4R8R4N7MfN868R85nN7MiP8R7
P7QfM7MnQhV4NGAgN7b7RHN0N7IhOXJ<R81hN7V0R8n<QgagO7n1Rhb8OWQhO8B;
R8R1MgQkPHj>Rh=lNGb4Shj;Q7aiN7n8QhJ1N7AhOXJ9S8AnO7V1QXb;QWihNGb6
RHb8OgIhP8B7RHMlM7=hP8B7Q7agLgJ0Q8B6O7A_M7b0Q8>0O7AhOXB8QXAkLgAi
Q8^7PGUcLGMlQXAoO7IdN828R8R1N7anQ92@RhAlNgV0Rh^9PGahMgn8RhV6OgQg
OhJ>S8IoN7QlQXb;QgahMW^0Q8b8O7MdNgj8RhR3N7IlPHJ<RHIoMgR1RHb<R7ih
NGn6SX^8P7MgN868Q8AiM7AaOhB4PgQgM7AnQ8R4O7UdNH26SXV8P7IlP8R@RHR0
MgQoQXb<RH1kNgj8T9>;PG]hO8><S8QnMgMhP8B7P7MdKgJ0Q8V4O7IdMgn8RHJ0
NGIgO868Q7ilN7=gP8V8PGUfMWJ0S8b4P7UcNH68SXR0O7QlOhRARhAlNgj1SYB?
R85lOXJ;T969OWUkNhJ<SXUoO7QlQ8R@Q7]hLGAlQ8B1O71`L7V1Ph=kM71`O864
Q7]fM75lQ8R6Og]`M7aoQXB1N7=dOXN8S8N0NGAnQh^<Q81iMWn3Rhj7PgUhNgj;
ShV4O7QiOXJ9R85kM7QlPhV9Q7ahMgj3R8b4OWMgN7n8R8=kMWIfO8N;R81iMg^1
R92?QWahNGn7S8^6O7=fOXJ9S8R0N7MiQhb8Q7ahM7R3Q8b6OWQaN7j8RHN3NGAi
Q8R>S8AlM7^0RI2;Q7adN829T8j;PGQkOXR<SXQnNGMiQ8V9QgahLgN0QXN1O7Mc
LgV4R8AkN7AdNhJ<R81gLgAkQ8b9OgQaLGMoR8R4NGAdMX27R8IkMW=hQ8R;R7mg
MWV0QXb7P7UdNh68S8V4O7AiPHR?R8AlLG=hP8J4P7Q`LgJ0RHN6P7QgN86;R8N0
NgIgP8V<R81hM7QoR8b<Q7]hN868S8j4O7IgOXJ;RhAiM75kQhR7QWadM7V3RHR1
O7I/M7j8RhMoMgMfO8J;RGmhM7IkQ8b8PG]hNh29T8j;P7UlP8R@ShR0NgQnQ8j@
S8=iMgb4R8b;P7QdMWn4Q8IkM75cNH28R7mkN7AlQhb<Q7adMWb0RH^3N7AdNH26
R8MlLG5gO8B8Q7adKWAlPhB6P7IaM7b4R8N3O7UhPHj@T8R0O7V1R8n>R81hO7n9
S8V8NgQfMXB6QXMlN7AcOhB8R7]fM7B1QXb>Q7ifNH29ShV7O7AfNHJ;S8MlN7Il
R8b?R7agM7V0Qh^3NGA`M7j3QXAlM71dNhJ9QgihMgN3RHb<P7UgN828T8b4OWIc
N868RH5gMW=dP8V;R81hMgV0RHb7OWQgMWn4RhQlNGMhP8R>S8AnM7R0Qhn>QWUc
MWb7S92;PGahP8b@U926Og^1R8jCShIkN7QoQ8b8P7acMWb4RhR4NgQiO8N<S8Al
M7AiPHB7Q7U`L7AlQ8B3O75`Mgn6Q8=lM6maO8B6Q7adLG5hQ8R7OWQaL7V3Rh^4
PGQdNhN@SXR0N7AkQ8b>Q7]aKgAlQ8b8OgQ`MWb6S8N0N75fNHN>Q8=lNGalSY6<
S81lOX>@UY><Q820PH^@T8b0N7alQ8j<R81gLgN0QXb9PgI`Mgj6RHAoN71aN824
Q7mhL71hP8b9Q81cMW^0RHb8PGQfN7b;S8R3MgIhP8N9S85fNG^4T96DRH1fMhJ9
SXn4O7AaNHJ8R8=dL6mhO86;P7I/KgJ0QhR8OWI`M8>6R8QlNG5hPhR@R8=kLGUn
R92<QgifN82<Shn<OgUgOXN<S8AoN7IiP8N8P7]gLGAoQXB1O7MdM7b8SXAlM71c
O8N>S8AhLG1gPhV8Q7]dKWAoQ8V3N7MaNh68T8AnMg5kOhR@RH5hMW^4RI><Q7U`
NGn6Thb7NGMhO8R>SXAnMgQlPhb<R7ifN7R1QXN6MVmaMWn6RhAhL71gOhJ8RHAg
M7QoRhnAS7miNh><TIRARhAlQY6GV8n;P7^0Q92@R81hMWN0Rhb8PgI`M7b4R8=h
KV]^N8B8Q81aK6adP8B1O7A^K7B0QhJ0M6maMX6;S8QlMgAhQ8V?Sh=lMgV0Qhn6
OgM_Lgb3QhR3NgAdN8J<R8IoMgQnQ8^;PgafL7N0S8R1Ng1aMWj;S8QnM7AfOhN;
RH1dL7AiQ8b9P7adN828T8j6O7IiO8B<THIlN7QlQ8b<RH1dN7j3S9><Q7QdN8B>
T8b1MgIhP8^?Rh5iMWQnR8n;P7UgMWb6S8n3N7IdNH>;T8QnM7N1Q8jDSX=fMg^6
T8b<Q7UfMX28RHN1MW1aOhN8S81gM71gQ8b9PGQcL7R0Rhj7O7MgN8>9S8]lLg1d
O8B8QWidKg=lQh^9PGQdMX2<TI27O7QhOh^@SXUoN7InQhb<Q7adLGN1RhR3O7Mf
Mgb8R8AkM7AaNhB9R7mdK7AnP8V8P7UaL7b7R8R4N71`N869RhAlM6mhPHR>R8Ah
M7n6Si2<R7ahNHB?T8b4O7AhOhJ<RHIhLgIiQXj>R7adM7N0R8^8NgAfN8B?T8ao
N7IkQXb@SX1gLg5lR8R8OgA`LGV4RhR1N75aNhB4RHAhN7IkQ8nDR81lMh28T9B<
P7MaN7j9S8AoM6adOhR<RH5fLGIoRi2<PgidMh28Shb4Og=cNhB@SXV0MgIiQ8j?
R7mfLGJ1RH^6O7I`LgV7S8IlMg5`N869R7agLg=hPHj<Q7igM7R4T8n9P7QkP8^F
UY63NGQlQY2DShAiMW^3Si2>Q7QfN82>TI24NGAcNhB;Rh5hL75iQ8b<Q7I_KgB3
R8b7NG5`MWb4S8AhM6mdP8J8Qg]`K71lQ8V8PGa`LGn8T8n6O7IgO8B?S8QhMWAh
PhN;Pg]`K7QoQh^6O7AaN8B9S8b1N7IfP8V<QWagL75kQhb7P7AaLgR4S8V0N7=a
O8><SXAlM7QlR9B@RGmgN7V4S8b8O7AdMgb4S8R0MgAhO8R?S8MiM7MlQhnARGih
Mh26S969PGAdOX>>S8R0LGIfP8b<Rh5gLg60R8^@Q7QdM7n<Ti6;O7=dOXR@T8Ql
LfmgQ8j?Q7idL7AnR8j6O7M`MWn;Th^4N7MlQ8jCSh=hM7R3S92>PGA`Kgb3RHR1
NG=dO8R;S8MlN7=lPhb?Q7igMW^3SXb7OW1`M82;SXalL6i`NhN>RH1gL7AkQ8b;
P7]`L7b4S8V3NG1dNh2<ShQlMWAkQhb?S85dLGJ0R8^8P7I_M828RHV3MficOhB;
RhIlLGAhQ8n9Q7U_L7MnQXR8N6i`M828R8QnM75gPhR>RH5fLGQoS8n<Q7MdMX29
T8j4O6i`O8B>Rh=hKW1fPHR>QgUaL7^4RHb6P7AaN86<S8J1N75dOXR9R7adLg=k
R8n<QgafN7n;TI28O7QhO8R?T8UlM71lQ8bCQgmdM7R0S92;P7A`Mh29SXV3N75f
P8V@SXMlMg^0S9>AS81lNh>?TiN?PGahOhR@T8]lMWAgPh^;QgaaKWB0Qhb8OWI`
M7j9ShV4N7=gOhV@S81hL71fPHj;Q7M^LGJ0RHb4Mg1_M8B<Shb0NGIhQXbCTH5h
L7N1Qi6>PGUcM7R6S8V4MViaN8B<SXMlM6mlQ8R>QWadLgR3S8V4P7QcM86;S8b0
NGQgP8V?Rh1kM7B0Q8n@P7agMX2;Ui69OgMhNHJ?ShQiLg5hPhR@RGacKgB1S8j<
P7=/LGb6S8UlMg1/NHB7QgidJfahQi2?Q7afLgb8TiB9P7McN8B@ThR0N71dOh^A
S8AiMgQnRI2>PgMfM7b8T8n6O7AhOhJ9S8AiLfmhQ8b@Rh5dLgR4T92<PGQdM7n<
T8b0MgI`N8R;Rh1fLg1kPhV;OWA^K7B0RHV1MVi/M7j8R8MnL71gPHR9R7ifL7J6
S8j;O7A`Lh2;T8R0N7=hP8^ARhAhL7QlR8j9PgA`LGJ4Rhb3N71/M8><RhIhL75d
PhR>R7]gLGJ6RHn>PG]aMXB;SXj4N71aOXJ;RGmdJfaaO8N4OgA/KW60R8R6N71a
N8B@T8b4MgAhQXn@SXAiM7=lR8b9PgQdMX29Si>8NgAcO8B8RhAiL71fP8N8QWQg
LGR4Ri>8O7]dN828T8]oN75hP8J@S8=kL7J1R8b>R7]`LGb8TI29P7AfOX>@SXQn
LG=hQhb<SXAiM7R4S8b9Q7adMhB<Shj4OWAdOXV>RhAlM75kRHn?QWidLG^4T8b7
QWUhO8>@ShUoN7MdPH^<R81hLGQnQi2;P7QfN82<T926MWAgO8R?ShIhM7=iR8b>
R7i`KWb8S8n;O7=[KWb7Rh=kLfa_Nh^@ShAhMgR1T9NFR7ahN829S8n7NGA`N868
Rh1hL75kQ8j?R7agMgb8Si28O7AaL7b4RhUlLFa`O8B<Qh1gL75lQXb9PgQ^L7R1
S8b4NG5`N86>S8N0M7IhPhj@S7mhM7V4R8n9P7A^MWb6S8R1Mg=gP8V>S8]oN7^0
S92@R7mhMWj8T8n8P7IdN8><SXUkM75dOXV<R81dKgAiQhb;Q7M`LG^4SY27OWIa
O8B>T8R0M75hPhn@Rh1gL7R6TIB>Qg]gMgj<U8b0MW5`N8B8QgmaL71hQ8R9PGA_
M7^4S8b7O7AaMhB;RhQkKW1dOhR<RgaaL7R4SiB?Q7QaMh29SXb0L6U/NhN8RH=f
LFaiQhR<PGM`KWN0R924N7A`NHJ8S8N0M6akQ8V<S81hLG>0RI6<Q7m`M7j6T8b4
O7=fNhR@SXR0N7N0Ri2DR85hM7j4T9B8OgAcM7b<S8B0Mg1dOXV<S7mdM7AnR96<
PgidM7V4T8b4Ng1cN869R8=dKfaaP8V9QgaaLgR0T9J>Q7ihO8RFV9N?OWR0Phj@
T8]hMWN0ShV<RGagM86?TIB<PgQdP8bDT8R1Lg1cO8b9QWUaL6mnQhR8O7=/K7b4
QhMnMVU[N869RgihKVadO8V9P7Q/KWB0R8^6P71aN7j>ShN4M7AlPhn?SXAfM7J0
Ri2@P7QcL7b4SXj4N75fO8R>T8QlM7MlQ8V>QW]aL7R1RHb6Nfm[Lh6;Rh^0Lg1g
P8^>QX5dKW1lRhb9PgM_K7J7S8R3Mfi[MX><S8AnLg1hPhb@RGmdM7j4T96>QW]i
O8NAU926NgAdOhR?S8=fL71fPHR4PGA_L7IlR8V0M6m`M82;SXb0N71lR8bCSXAl
M7V0RI6>Q7adM869Th^4P75hOhJAS8AgL7=fQ9>>R7a`LgR1Si6;O75`Mh><SXj1
MW=gPhj@T8QnN7V4SY6>QgacLgb8SXb3N7=_MX>8S8=hLg1dOhR<QWacKW1nQhR8
O71[L7b3R8QnM6mcP8^AT8AlLgJ0S9>AR7mdM7n9U9B9P7IdNHR@T8anN7QhQY2A
Rh5hM7^1S9JAPGIfM7b9ShQlLficN86;R7maKfifPHR<P7A/KgMoS928O75`MhB8
S8]nL6adP8V<R7idL7IlR929Og1`LgV9Sh^8N75hO8VATh]oMgQlR92?RG]`LGR1
S8b6OWIcMX>>T8b1N7QhPHVCU8MlLgIoR92@QgadLgb4Shb4NfmaMX6@RHIhK71d
Phb>R7QcKW5nRHn9Og=aM82<T8b0MfiaOhJ<Rh1hM7B0R92@QWU_Lh24T9B9Og=`
N8J?Shb0N7AiQhbAS7mhLGB3R92;O7M_Lgb8S8R3Mg5dO8B9R7adKVmdP8V6P7M`
LGR3Rhb8O7UhOhR@U8b4NGAlPHnCS8=fL7AlR8^9P7=dM7R7Rhn6Mg=aN8>8T8Qk
M6mkQ8bAQgafL7N3SYB?OgQdMh>;Thj1NgIiPHVDTH1kMgR0Qi6CR81hMWn4SY23
NGA`N7n;T8AlLFahNHB<QWaaKgAlQXR7O75/LGb6RhQnM71cNhJ<R7mgK6mhQi2>
RGa`MW^6S9><OWQ^N8N?T8V0L6]dOXR<QgicJfmlQXN9OW5/L7j8SXQoMVi`NhR@
ShQlM7N0SYBFS7ihN7j9TIB<OgQdNhR@V9>8PgQkR9BGThUnN7QoRi6<P7A`L7R8
SXb3M6m/Lh26RhAgL6idP8R<R7adLgN1R92;OWI_M829T8j4MW1aO8B9RH1gKg5h
P8V6P7M`LGR6S8^8OWAdNhJ>ShQoN7AiQi2CSh1hLGB3Ri6<P7IdN82?U9>8NgAi
Ph^?T8UlM7MoR92<R7aaM7V7S8j7O71^M7j;T8]nLg=fO8R@RH1cJg5hPhb7OW5/
L7V6S8R0LFQ[MX6<R8=fK6acPhR8Qg]fKgN6T9B9PgU`O8B@V926OWQgQY2DThAk
MWQoR92?QgQ`M7^1S8b6Mg1`MXB8S8IhL6afP8R?RGafKgB0Qhn9O7I`MX26T8R0
MfidOXJ?S8QlLgR0R9>ARh1hN86;U9B?PgUgOXN?T8V0Lg1fOhV>RH1aL75nRHb<
PGIcM7b8S8anMW1^NH66QgidJ6UgP8N8Q7]_K7>0R8N6Og=^L7n<T8=lN6mcNHV@
R8AhLgIlRi2@RgahNh6CUYJ@PgUiPHjDTH]oMgMkQhj>QgacK71lQhb4NGA^LGb6
S8MnM71aN8J>SX1gM7N0RI2@R7aaN868TI>;P7AcO8R>ShQlL71gP8j>R7idL7B4
Ri2<P7M`Mh24S8R0M6a_O8N<S8IlLg5nRI2@S81gM7b9Si6<O7M`M8B<T8aoNg5d
PhV>Sh=hLGJ0R8j<PGM`Lgb9S8j4MWM`N8R8S8AgKfUcP8N;Q7M`K720R8b8NGM^
LH>8SX^0N6mdP8RARh1hKg=kQhj;PgM^L7N1Rh]oMg=_NHB<ShIkLG=hQ96CRH5f
LgB0S92>PGQaMh><U964Ng=fQ8jDU8UlMgV0S9NDSh=gN7b8SY2<OWAdMX68R8Qk
M7=dQXV9RgifLg5oQhV7O71/K7J4QhIoM71aNhN<RhAhLfmgQhb@R7ihLG^6SYB8
P7M`N82@UX^0MW5hP8jFTHAhLgQnS9N@R7UcM7n<TI67NgA`N8V>Sh]nM71lR9BH
T8N0N7^6S96>O7M`M868ShQnM6UdO868QWiaK71hQXb<Q7U`M7^3RhV7Ng5aM8J<
S8QlL6acNhJ8P7U`K6ahPh>4N6aYJgB4QXAoKfi`NHJ<S8=iLg5lS96AS7adLgR4
T9B9OgQ`Mh28T8QlLfacMXB8PGiaK71gQX^6P7Q/L7j7SXj6NgAaNH^CShN0MW1k
Qhn@R7adM7b8T9N?Q7Q`NHB>THb3N7=aP8nDSX=kL75oR9BCQgifMgn<UYB;P7Ih
OXJ@T8MiLg1fPhR<Q7QaL7J0S969P7M`N8B<UY26O6mdP8VDTHQnM7=lQi2@Q7ad
M7^4T8n8OW5`MX2>ShQlLg1dO8^CSX=gMgb6T9BDR7]dN82>U96<OWAhOX^@T8Ml
M7=kPHb<Q7a_KgIoR8R6NG5cMX6;SXV0Mg5dP8bASh=gL7AnQXb<Q7Q/KWR1QhN0
M6UYLgj8R81hL6UcOhJ<PGIaK7B4Ri28P7I^N7n;THV1MgAhP8b?S8MlMgN0Ri6@
Q81hM7b9Shj8N7=dMhBAT8AhL6acO8R>R7iaK7=oS96<OgAdMh>?UYB7N75fP8VF
U8QoM7B0R9BAQgidM7b3T928O71dN869RHQgL6i`OhN>QgmdK7AnRi6>Q7M^MWb7
S8b3M71`N8B<S8AhL6mgPhb>R81dKgB0Ri6<OgMcMX28T8]nMg5dOX^@ShAlLgAn
S92?RGifM82<T9>9P7QcO8RAT8MlLg1aOXV>QWU^Jg1lR8b8N6m^Lgb8T8b0L6ac
Nh>?SX5hL7AlQXjARGQ`L7^8S928OWA`N869SXIlL71iQ8j?Rh1dLGB0Si2?QWQd
M8>?S9J6O7QcPH^?ShAiLfaiQ8V<PGQdL7R8SY28OWM`N8J;ShUkM71cOhVAR81h
L7B0S92?Q7UaLGb7T8j6N7=aMhB9S8QhLgAgPhj?RGadM7R4Rhn8NGA`MX><U8V0
M6acNhN<R7i`KfihQhj?Q7U`KWV3S927O75aN8>>THb3N7AnQY2DSXAiM7>1SXj;
Q7acLh6<THb1N75`NHR@Sh=gK6mgPi6<PGM^KWB3SXb8NG5cM8B>T8QlMg1fOhB@
RGmhL7MoR9B@R7]cMWn8T8n6NgAfOhR@TH]nM7InQY>DSWmhM7N4SX^8P71^M7V9
RhAiKVa/N866RGicL71lQ8n@P7UdM7n<V9><Q7IgNHB>SXalM7=dQ8^<R7ihM7N3
SYB;P7afNhJ<U8n6O7AgOhb@S85dK6mhPhb9P7A[Jg1nQ8R0M71YM8>8SXIhLfic
P8VARgmfLGR0RI6@Q7]dLhB<S8n7Og5dP8RAT8AkM71kRI>@R7mfLgn6SiB<Q7ag
OhR@T8V1M71dNhR8Q7]_KW5hR8b9PgA`LGV7Si28O7A`N8R?T8UiM71dQh^@S7]d
L7J1R96<OWA/LH2<Thj3NFiaP8V@T8AgL71lR92<PGU_L7R3Rh^4N71`LH2<RHQo
Lg=dOhR>RGQcL761S92@PgMcMX6>Thn7O71dP8R?ShAhM75hR8n<Q7M`KgAoRHV0
M6i[LH>9ShQnM75hQ92FShIlM7N3S9B@Qg]dN82<Ti26NgMdN8R<RhAhL6ahQ8b@
QgadL7B3Rhj8OWA_M82;S8R0M75fP8b@S8=gLgJ0S92@RgagN7n>TI29NgAcNHN>
THMlN7=hPH^@R81fK7B0RHb9Q7A/LGb4S8QlM6a^MhJ<QX1fK6idQ8b>Q7UcLgV4
T967OgQgN8N@U8n0NG5kPHVFS81gL7R0Q8n>P7I_M7n4S8b6N6Q`O7n<S8AlKg=l
Qhn@S8=hM7^4Ri2;PG=_Mgb<S8>0LfidOhb<S8AhMgB0S92@Q7ahM7j;Si24N7=/
MhB>ShAkLFmgP8b@R7idKgR1RI6<OWA_N7n8U8j4Mg1hO8R@S8AdKg=iQ8j<P7Q/
KWMoRhR0N6a^MX2;S8MhK71gPHn>RGm^Jg>0RHb8PGI_Lgb<SXR1MW5cNH^AT8Ak
Lg1oRI2ARH1aLGJ1T8j8OgA^M8>?T8b3N7IhPi6DU8AiMgB4S96DQ7]aM7^6S8b4
N7=`Nh>>ShAkM7=kQ8j@Rh1iM7V8TIJ@PgUgO8B<Ti20M71dOh^?S8AhKfmlRI>?
Q7]aKgN3S8j4N71^M82<S8AkKVacNhN9QgicLgAoS8j<PgMdN829SXb4N7A`OhV;
T8AiLg5kQXn<PgUaLGV4S8b8O7IdN8J;S8UlM71fQ8V?R7mgKgAnR8b<P7MdLG^8
T8^0O71aOXJ@THV0MWQkQ96CR7igM7j8SYB<PGMcNH28S8R1M71fP8R<S85hL7>0
S92<QWUdLg^<T8b8NFa^NHR<RhIfL6a`P8b;PgQaK761R8j9O7=/M7j8Shb0M71a
OXR@T860MW>3R8j@Qg]_L7R6S8R4O71/MWn8R81hL6aaP8V<R7mgKgR3SY6@Rgmh
NHBCV9B9P7alQ92IU8AnNGAoRHb@R7acM7b3SXj6OW5cN828Sh^0M71aO8R<R81h
Lg5oR8R8P7A`K7J4RhQiMfiYM7j9S8=iKVadO8R<R7m`L7QnR8b9PGI_MX2<T8V3
M71aMh^?Rh1fL71hP8V9P7I_LGB0S8b3N7AdNHN>T8b0MgInQi2DRH1gLgR4SY26
OgA/L7j9SXb1O7QfP8bFT8MnN7QnS92AR7agMWn6S9>;NgAaMX2<S8AkL6Q`O8B<
RG]_K6ihQXb<PgA/L7^4R8b1N75^NhR?T8V0NGQoRIBFS8InN7n<Ui^GQWmoQ8nF
W9J9P7R0Qi2HT8IhKW=iPhV8Q7A[L7V6RH^7Ng1_N8B<SXMhM71cP8V;QgadLGJ1
S8n;P7QcM828SXUnN6m_N8B<R7ifL6ahPHb<P7UdL7^4S8n4N7=aN82;T8QiLg1c
PHR;RgacKgJ4RI2@Q7Q`LGj6Shb3O71_N829R8AhKVmhP8^<QWicL7R1T8n7Pg=a
MhBCT923MgAgPH^DSX1hM7B0Ri2@PGI`M7b6SXb3N6m/N8B8S8=hLFihPH^<Pgac
L7R1R8b8OWQ`MhB8S8R0N6idP8^@R81kKW1kQ96@Q7agMWb8U9B;P7QhP8jFUi24
MgAiQ8j@R7adL7J3Ri28P7MgNGb<SXR1M71fOXN<T8MlNGR0Ri>HR7iiMW^3SY28
P7IhO8>>T8alKfaaOhB9R7a_JFmhQ8^7P7A/L7R8Shb8Mg1dNhR>T8MhM7=iQhjA
RH1hM7^6TiJ<PgIdNh2@T8QnL6maN8B;R7i^K6igRHj9PgIaK7R4Qhb0M7A/M7n4
SXAhLFafOhB?QWi`JGN0Q8b9Og=_Lgj4Rh^6N71dP8R>T8QnMWB0S96AS81hM7j8
TIB8P7QdO8>@T8J3MgMnPi6DShAhN7R3Si>@QWUcMh68T8b7Ng1dN8R<R8MhL71d
PHj;PGU^L7N0RHR8O6m`M828Rhj0M75gP8N<Rh5gK75lR8n<QgQaLG^8S8n7O7Ad
NhRAShMlMgAhQhj@QWUfLgR3RI29OWA`MWn8S8QoN71cP8R;R85iM7=kQi2<Q7md
M7V3Shb7O7QfN8B;SXQlLg1hP8V>R81cKgJ0R8V9P7I`Lgn9S8V1MW1aO8J>RH1l
L75kQXn<Q7]`M7J1THn;P7QgNhB>T8]oMW5fPH^>R7ifL7N0Ri2;PgQgNGn>U924
N7QhOXV@U8b0Ngb3R8n@QWmhM7V4S8b7P7M`Mh6>ShN4N7AkOhjARh5gM7AlR8j<
Q7M`L7R4RHV1N6m/M82<S8AhL6mcP8R<QW]dLgIoR92;PGQaN7n6RH^3Mg5`N8B7
R7mfLg1kQX^<P7QgM7b4T926NgAcM829SXQgLFmdOhR@Rh1dKWMnQXn<QWQcN7j9
Shb6NgAcO8B;ShIlMgAkPI2ARh1hN7b7T92?P7McMh66SXQnMfmcOhN<R7icK71i
Phb8P7Q`MX28THn8Og=dO8R<SXMlN7InR92@R85iN7j4T8j8OWAdN82;THb1Ng=f
PHbAShQiMWQlR8n<Q7Q_LGV1S8R0N71_M7n8Q81iLG5gP8^<Q7]fM7N3S8n8P7Qa
NH2;S8V0Mg1aO8B<S8=hLGMoR92@RH1hMWn8Si26O7AdNGj8Rh5kL71gP8R8R7i`
K71lR8N7O7AcLgb8Sh^0O7AdNHJ>S8=iMgMiPHb>QgihMW^3S92<P7QdN8B;T8n0
NGQiP8R>RHAiLGIlQ8V9PGQ`Kgb8S8V3Ng=`NhB>T8B0N75iQ8j@RhAhMg^0Rhn8
P7AcN86;S8b4N7QgPHV;T8AiMWN1RHb>Q7UdLGb4QhJ3N71`N827R8=iLFadP8N<
RH1gLgInRi28PGadMWj8SX^1NGMfOXR?SXAkLG5fP8b?R7igLGR0R8j4OWAaMgn9
S8R3MgMlP8n@ShMiN7R4SY6?QgQ`MWn9S8j6N7IaN8B8RhAhLfmhP8N<QWmdLgQn
R8R8P7AdMWn8QhN0M71aOhR7R85hM6mnS8j;OgadLgb4T8j1O7IfO8B<S8QkMgUl
Qhb?QgahM7R4QXR7OWQcN828SXN1N7=hOXR;RHIhLgIlQ8V8QW]aLgR4R8J3N71`
Lgn4Ph=hMW=dPHR>Rh1lO7j1S9B?R7ihO8B8S8n6O7IfO8J;Rh5hL75iQ8^>QWag
M7b8SY2<PGQhN869RhQnMW5gP8B;QgifM7MlQ8^8OgMdMgj6S8V4NgAhOXR;SX]n
NgQoRhj@RhAnM7j7S96<QX1hO8N@THn6P7IfP8B?S81lM7B0Q8^<PgacM7b1Rhb7
OW5/Mgj7R8AnM7=gPH^<R7igM7N1RHb9O7AcLgn6R8QlMW1dP8B8R7icKW1dO8J4
OgA`L7R3R8b3OWQfOXN?T8QoMgQkQ8j@S7mfLgJ0Qhb;OgI`LGb3RHR1OgAhOX6<
R85kM7AfPhR8R7adMW^0QhV7OgQdO8B8RhR1NgQhP8b>S8IkN7R0RHn>Q7ahNH2;
S8n6N7AcNh>9RhAiLG1hP8N8PGQaL7R0S8b8PgQfN86@Rhb3MWIgOhR8RGidLg1i
Q8R6P7UaL7R4R8R3O7AaN7j7RHAlMgAhP8R<R8=iNGb1Rhn;PgQdN7b6S8R3NgId
OXR<S8=lMW5lQXb<Qh1hM7^6S927O7QdN8><T8R3Ng^0PhjCR7mhM7V1R8^8O7=a
LgV8S8R0MfmaNh67RH5gL6mhPHN7PGUdL7MnQh^4OgQcNH68S8b0N7AhPHb@RhAl
LgMlQ8b>R7mgMg^7RhR9OWQhO8V<S8UoNgIlRHV>S85lMgb7Ri2;Q7mgO8>;TH^3
OWQhP8b@S8QnNGUlR92@S7ihN7b4S8j7O7MdNh>8R8=lMgAiPHV8QW]`L7AoQhR8
NG1`Lgb1QhIlLFaaO8B8R81gKg=lQ8R8Q7UdLGR1R8R3OgQdN828RHMoNgMkPhb?
R8=hMWR0R8^8OgQdN827S8V4O7AgOXJ8R8AlN7MoQXV<QgmhMg^1S8j8PGQdNH68
SXV0N7=dNhJ;RH=hL7AkPhV8PG]dM7j3R8b4NG5cNh29RhInLGAhP8b>S7mhMgR3
R8b;PgQgNh2<SXn9O7QkPHR<S8IlMWAoQhN7PGaaLgj3R8UoO7QdNhR<R8IkM75g
OhB8O7QfKW1lQXR4P7QcM828ShQoO7MgO8R@RHB0N7MlR8n?R81kNH27S96;PG]i
O8>;RHR0NG5fPHJ8R81hL7InQ8b;QWigN7j9T8b6PGQfOXJ<ShAnN7AhO8B8PGac
LgQiQ8R0OWAdNGj6QX=lM75gO8J8Q81gKgAlPhV7P7]`M7R0R8b7OW]hO8B<RHJ0
M7AlPHB6PG]aL7IlQXN1O75dM7^<S8R1NgIfPhV@THJ0O7V1R8n<QWafN7b4R8^7
NgAcNHB9S8^1N7AkQXR>R81lMWQnS928Q7ahN828S8^6NgIhOXR>S8MkNGalR8j<
QW]hN7j8T9><PGUfOh^<T8b0M75iOXR>R85hM7J0Qh^8PGadMWj6R8J4N7=gN8>9
R8MlMWIiR8b9RH1dMWb4R8R6OgAaM868QhAhM6m`N827QX1hMWMnR8b;Q7afMWj6
RHV1N7IfNh24RHAfLg1aNGn7PgQ`Jg5nQXV?Q7ahNHB9Ti67P7IfP8R>SXAlMWAl
R8V<QWagLgn6RhV3O7AcNH67Q81fKVa`P8N4OgM`JfmhPhR3O7I`LG^7S8b7P7Qh
P8^@ShQoMgQlQ8j<Q7adM7B0R8N4NGIdN868R85kM75hP8R<R7mhN7B0RHj>Pgif
MWj4Shb4OWUiO8R@T8b4Oh24R8nCSh5kN7R7S8b;P7QdMX27QhIkMW5dOhJ8QWmh
M7B0Q8J6OWQdMW^4RhR1N7AdO8^@THV0O7InQhj<R8=kN7V3S929PgafN7b8S8R3
NGIhO8B;Q85nMWQkPhV6PGM`M7MnR8J4OWUiO8b@Shb4Og]nRI6CSh=nO7j;Si2>
Q7UgNh2;T8^1N7=dO8J8R81hM7AlPHV9P7UcLgR1R8V7NG=cMh26R8AhL6aaNhB8
QWmgL7QlPhb<Q7]dM7R0QXB1Mfi^M7j8RHAgL71gP8V<S7mfMWR1RHb9O7MaM828
RHV0MgAdP8N?T8=oNGV4Ri>DQ81iNh>8SXb8O7AfOXR<T8UoN71hQ8R<R7ihL7J0
Qhb4OWUaN86;T8^4O7=iP8R@RHIlM7QoQhb<QWagMWb8Shb6P7QhOXB<S8J0MgMh
O8R<R7mhM7MlPhR8P7QdMgb3RHR0N71dN8B;R8AiLFmhPHR8P7QdLGN1RHR6O7Uh
N82<T8b4OW]lPhV>Sh=lNG^1R8b>Q7UfMWj8RHb4O7McO8J8R8MlMgQkQX^>R7af
M7R3R8j9OW]dN8J8T8R0N7AkO8J;R81fM7MnQ8R8PGQ_LGb0RHQlNG5_N828RhAh
L7=fOhV;QgifLgb1QXj8Q7mdMXB;T8b8P7IkPHR@RhIlLGIhP8b4O7Q_Kg5lQhB1
Mg1aLH>9RHV0N7]lQY2@RH5nOWb7Shj<Q7UgN7n6RHIlMW5`O8N8QX=hM7=hPHR;
P7]dLGR0R8b8PGQhOXJ>TI><PgaoR8j@S8R0NGV1QhV8O7U`L7]lRhAoO75cMh29
Q85hL7AfO8V8R8=hNG^4T9>DS7ilOhJ?T8^4NG5cNgn1QWM^K6UcNH63NG1YJgIl
Q8QoMW1`N826S8QkMWAdP8N9QWadKgAiQXn8PG]cN7b3SXAlNG1dNhR<R85hM7Ai
Q8b<PgafM7b6SXj9P7UkOXbDU8j3OWIlQ8RFS81lLgR0R8j7PgMdNGb8Shj8O7Id
OhJ<S8MoN7R0R8b?R85kO8><THn<QWmhNhB<ShV4OWQkQi2DT8N0O7]oRI><R7ii
O7j4T8j6O7IhN8B<RHQiLg=dOXB4PGM`JFikPH=lM71XK7J3RH5lM6iaN869QX1h
LGIhPHb7Q7mcN868S8R4NG1dMX2<QhIkM71cQ8^<QWmiKg>1R929PG]`Mgb9U8^7
Ng5hO8B@S8MlM7UnR8j;QgU`M7R0Rh^3O71_Nh2;THj1MWQhPi2?S8AhN7R4Si>@
QWikN86;SX^0N7=cN7n6R7ifL6mdNhN>PG]gM7R1R8b9OWMcN869T8b1N7=fOhN9
Rh1iN7B0R8b<Qh1hM827RI28OgMfOX><SX=nM71fP8^<Qh=iMWb7S92>QWafN8B<
T8b4O7MkOh^AS8IiMW5kQ8R;PGQ`K7=kQ8B0N71aMX2<RhMlM7=dPH^<S7igLGAo
R8b;PGQfM7n8S8UnMVi/Mgn3QWmdL6ihP8R<Q7acL7R3S8j8P7IaN86>ShV4MgIh
P8j<R81gM7AlQ8R4O7AdM7^8RHR1N7AfNh>;RHIkM7QlQXb?Rh1kN7j8T9B?Qgmh
NhB>Ti28OgQlPHR>RhAiM7QnRHj;P7IcL7N4RhV3NG5aMgn8S8QnM7AhPHb?S7mg
M7J0R92<P7IaNgj8S8N0Mg5dNhN8RHMgM7AiQXV8Q7agM7^7Rhj>PgahO8J<T8b3
OWQlRI2ARHAlMgV1Rhb4P7UcMWb8RHMlM7A^MhB7R81gKVmfOXV@PGafL7V0Ri2;
P7MdN8B@U8j4NGAfOX^@S8=fL7AlQXb<Q7UaMgb7Shn<OgQiNhR@T8UlM7AhQ8^@
S7ahM7>1Rh^7O7I^L7V4RHMiL6i`N869R7icKg1iQ8b;P7IdLGn;T9B6OWIaO8N@
T8QoLg5dOXb?QWQcL7AnQY28NGIdMgj8SX^4M6ihO8J<R8=fK71iOhR7OWQ_L7B3
S8R7NFa`N8>;Sh^0N7=gPh^AT8IiLgAnRI28Og]`L7b3R8^3N75dNHR@RhQnM7Al
RHj@Rh5lMWb<U9BAQ7alNhNCU967OWQgP8^?SX=lLg5oQhV<P7QcKWV4RHR3Ng1`
MWn9R81iL6a`OX^8Q7]dLGAlS927PGM`MWR8T8^0M7AgNhR?S8QfL7=fQX^<QWUh
M7b8T928O7MfOhN?T8QnLg1dPhj>S81iL7B4S96<P7QdM7n9SX^1N71cO8V@Rh1d
L71iR8jCRg]fM7V6TIR@Q7mlP8bCUYN8O7UlQhb@T8AlMgN0Qhb9OgM_L7j3Rhb3
M6U`Lgn8Qh5dK6]^OXN8QWQ`Jg24S92@R7ahO8J@U8b4N7=aNhN;S85cM71hQ8J8
P7A^JgR0QhV3NFi^N8B?ShQlLFmcPH^?RGadL71iQXb9PgA`M7b6Si68O7AgP8VD
THR1MWN1RiBCSh1fNgj8Ti29P7AaMhB@TI24N7IkRiNCT8QhM7AnS8^7O75_Kg^6
S8QoM6i`MhB;Q85dL7AdR8b9QWahM7^9T96<OWQhMh6@U8j0NG5dOhR<R81cKg=h
Q8V8P7A`L7R0QhQnMVi/LGV4R8AhL71`OXN<RGafL7N3RiB@Q7UdN8B<T9B8O7Qh
P8R@TH=iLG=lQ8b<Q7Q/M7j8Ti28O7AdNhV@SXalKg5hPHb@R7aaKW1oQhV7O71/
LG^8SXQoM6m`NHB<RhMnM7AkR8b<Q7UfL7B1SY28PGQgNH><U8n3NgAlQ8bDShAd
LGAkR8b;PG=`LGb8S8b0N6i`O8RDU8anM75kR9>DSX5fM7R6TIB<PGQ`MXB<T8b3
M75dP8bAS81iLG5oRI>@PgQcLG^4SXaoM6i^M826RH1dKVa`O8R;R7mdLgR4TIR@
Q7adN829U8b0M71aNHB?S8IlLgAnQhnCR7]`LgJ0S8b7NFi`MWn;T8]nLgAgP8b<
R7icL760Qhb9NG1[KWB4SXIlL6U_N82<S81fLG1hR92AS7adM7^3T928O7AcMhB8
T8alM71hP8R@QX=hKgAnRi29Q7I/Lgb7T8b7Mg5dN8V@S8QlL71gQ92<R7iaKgB0
R8j<OgAdMX2@THj4MgAdPH^AU8AiLGAnRi>AR7idLh29Si29P7A`N8N@ShInM6af
Q96ARGmdLgN6U9NAQWUaMhB<U9B6N7=gOhbCS8MlL71kR92>R7]cL7R8SXn8P71/
M7b8RHAlM6U/N867Q7U^Jg1hQ8b4O71YKgR4SXaoM6i^MhB?S8]oLGIhR92@S7ag
L7N6S96<OWA_L7j4S8MiL6Q`NHNASXAgL7R0SYJDRGQaLgV6SY27NFi/MhJATHb4
M75iQ9BFS81dLGR1SiB>PG=dMgn@THj6M71fP8^?T8IgL71nS92<QWUaL7b>TiB;
O7A`N8N@T8R1M6mgPHjCS7mdL7AoS92;Q7M`MX2<T8n3M71`NhN<S8AhK6ihQXb<
Q7M/K7=oR8N7N6a/L829SXUlN75hQhbATHIiM7R4T9JAQ7UcN86@ViR?PGUfP9BH
Vi60O7AlR9>KS7adK7QoR969PGA/M86<T8b1Mg1aO8nDSXUlM75lRIBAQgifLgV8
T927NG5_M7n8T8IhKVM`Nh>8PGIXI6iiPhV8OW5/LGn9THn4N6a^N8B<Rh=cJfad
Ph^<Q7Q_Jg>1Rhn8OWI^M7n?UX]nLfi`NhN<S7mcK6mhQi6;P7Q_L7^8Shb4N6m^
M8BAShV0L75iQi6ASWigMWN8T96<PgQdNHB>Ti1nL6m_OXN@T7mdKVmlQ8j?PG5Y
L7R3T8j4N6a/MhB<RhQhL71cQ8R<RgU`KWJ1S9B>P7U`LhN@U968O7=gOhjGU8Un
MgAlS92CRg]gL7R;T969Ng5/Mh>;ThMlL6afQ8bCT81dLGR4T9BAR7QaM7n?UYJ;
NgMdP8VHV8]oL71hQ92ARgU/JGB1S96<P7=_M7n>ThanL6Q[NhR?SWi_JFUhQ8j9
O7A[K7V4Si21MVm^N8B>T8AkLfilQ8j@Q7i`K7AlR8^6O71^M8><T8j1Mg5fOhV@
S85dKVmlQXj@QgU`LGn8SiB<OgQhPi2GV9B6O7^3SYNHSh=dKWJ0SY6<O6mXK7R8
S8V0LFM/N86;Rh1dJfadQYB<Q7]^L7N8V9N@PgQhNHRHVI61Lg5`NhjAS7adKfil
Q8b<OgA_Lgj7SXn0M6i`O8B?Sh5hKfmkQi2CRh1`K7N0S929OWA_Lgj<ThioM6ma
O8RAS85cJG1lRi2AQ7A_KWR6T924N6i/MhB<THQhKfihQ8bAS7a`KgN0R929P7=_
Mh2<U927O71dPHjGTHQiKW1lR96@QgQ`L7R7T92;OgA_MX><ThMhM6ihQ8nHSX1c
LGMnSY6@Pg=^L828U9B6NG1`NhRDTHQhJFigPHj@Q7]`KgB1T96<P75cMXBCTi21
Mg=dPhnFT7igLGB1RIB@P7A/Kg^4T8n4Mfa`NHN?ThUnLg1lQi6FS85cKgR4T9B<
Q75[M8>?U9>7N71dP8nDTHIfL6ikRi2@Q7I/K7B4S8j1MVm/M8B@U8QiL6]cP8bC
S7a^K7=kR928Og1XLGb;T8b4L6m_N8V@S8=gK71lRIBCRgadLG^<Ui><O6mYLH2;
T8QhKVaaOhnDT81aKW1lS9BAPgM`L7b8TI>4Mfi/LH6CThMhKVmdQ92CSWmdLGN6
TI6>P71/Kh6?SXaoL6a/O8b<S7a`JfQfQ8n<O7AYJgV4T969N6mcNHN@ThakLfaf
Q8jAS7]^Jg>3S9>?OW1/MhB?Ui>4MfaaPHbCT8IhJg1nRI>?R7Q/KgR;U9>8O71[
M8N@T8]oLfifPi>KT81gL7N4SYR@P7A^M7^8T8b3Mfi`NhNCT8QlL7AlRIBAT7ad
N7^8TiJ@Og=`M8>;T8alL6U`PH^>S8IgK7N3SiN@QWU_KW^>U8j8Mfa/M8VCTHAf
KVQ`PHb@QW=[J6b0RH^4Mf]XKgj9SXalL71aP8j@THAgLGJ0S96DQ7]dL7b8TiJ<
PG=cO8BDV8n0M6mdQY>FT8AdKW1oT968P7AXK7b;T8j1Lfa/LhRCRh5dJFUdQXn@
QWM/LG^9UiJ<O75`NHRDUXj0L6mgQ96DT8=aK720Si2CQgA^K7R8THn1Mfi_NHJA
T8AdK6aaPhb>Rg]^KgAnS9>;O6m[L7j9T8moL6m`NhR>SX=dKW1nRHb?PgM`L7V7
T9B8O7A`O8B>Th]lL71hQY6FSh5fL7R7T9R?Q7A[Lh2@Ti27M6a_N8RASh=fK6ag
Q8b<Q75XK7B4T968NG1_Mh>@Thj0L6]`P8nCSX1`KVmiRhn;OW1^L7V8T964MW5a
P8nHVhalLGB0SYVNTH=gLGj<UYVAPG5/N8>@UXb1L6adOhnASX1/J6]gR8^;P71Y
JGR8S926Mfa[N8VCU8QhK6adOhn?R7MXJ6b0S8b>Og1/LH68SY24N71cQ8bCU8Ai
LG60S9RFQgmcLGj8UYJ<OW1^N86?UX]oL6adPHn?R7i_IfahS8n8P71XK7b<U9>6
M6i`NhRGUhMhKVidQ92CRGQ[KWMnS9B;O75`NHB@UYB7M71iR9BHU8UkL761U9RD
R7adLGj@V9R9Ng=_NHRDUhQhKVihQ9BGRgi/J721T96>OVaXL7n<Uhn3M6UcP8bI
ThQhL7IlS9RDRG]^Lgb7Thn3M6IWLgn;Rh1fIVM`Ohn>R7U^JFalRHj8O6iXKWV4
SX]oL6Q/MhR?S8AdJf]gR8n>R7I_L7R9TI6;O7=_MhNAUhmlL6UaQ96DRgm`Jfal
Rhn@PG1/KW^<V9J<O75dOi2IVI1nN7InSiRFS7i/KgB3U9B9N6QWK82>T8mkKVQ/
PHVAT81fJG5lRIR@Q7M`MWn@UY26M6i/MhRCUXIiKVihPI6AQWa_KgR4U9R@PgQc
N8JAU966Lg1gOY2KTHAdKW1oRiBCQ7AXJGB3T8n8M6QXLhVAU8mnL6UdQ8nAQgU_
J720Si>@P71/LGb9UY24MV]`O8^DThQlKW1lRINDRg]^L7V7U9B<OVi`Lh2ATHai
JFQ`O8RCR7Q[IfQhRi2>Og5YK7V9VI>8NFaaO8RGV8aiL71kS9NFS7]^K7N;V9R@
PGA_M8BAV9J4LfaaP8jFTh=dJ6UhR8n?P71YJ7B7T926M6]/MhJCUhQhKf]cRI>F
T7Q^J7B3SiV@OgA[LH6?UY64M6acP8bDT85dKW1lS9BFRGa`L7b;UYN?P71/NHR@
V920LfU`OXb@R81^IfahRHj8PG5WKh6;T921Lf][Mh^CS8IfJFafQi>CRGU_J724
TiJ>OW1/LH6@V8mlL6UaOhbDRGa/IVUgQi2APG5[K7R9V9B7NG1^NhbDUhahKVQa
Q96GRg]cJg>1S9R@P7IaMX6CV9>6M6ihQ8bHV8AgLg5lS9NCQWA/KWV8TIN8Mfi[
N8R@VHakJfIcPi>HT8AcJ6n0T9NAPG=XK7b9THn1KfQYMXR?S81cJFMfQ8nAR7Q_
KgR8U9RAQ7MaMhBCU8j0LfmcOXjGT81dKg1lSiJ@Q75YKgV;U9>7N6m[MXRCT8Ii
KVihR9RHSgUcL7B8V9^@PGM`N8BCW920MW1cO8^GU8=dJg1hQYRDQW=XKWR3T9B8
MVMXM86@T8UhJ6I`P8^ARGa_J6]lS8j;OfiXL7j<Ui20LFU^O8jHUXQdK6ahRIBD
QgA[J7R8U9R@PG1/N8BAV963L6acP8nDT7i_J6UhQ8j<Og1WK7b;U8n4L6Q/MXRC
THQhJf]hRIJFSWi_K7B7UiR@OW1^L82AUXinKf]cPi2LU8AfK763Ti^KSW]aL7n>
ViR<PG1`NH^HU8UiLFadR92@R7Q/K71nSiB9NFUVL7b9UY1nK6Q[MhRATh5/HFQd
Phb@QWATIWR6SYB;O6UTLhB@U8^0L6QdQiRIT8=cKWB4UYjHR7QaM8BCViR;NFa`
OhV@ThAgK6QgQ92@R7aYJG21T9J;O71XKWn@U8n0L6a`OXnGT8=aK6mkRiBDPg=[
JGR7T923M6MVM8BCU8IdJfMcQ9>LRg]_J723T9N@O6iXL82@Vi60LFQ`OhjHTH1a
JF]iS9N@Pg=XJgR;UiJ9N6]/M8NDT8UiJfQ`P96DS7mcL7B7U9NCQ7IcMhBGW9J8
M6i`P8bGThAdJ6ilSYVGSWa_L7b<UYN@P6m^NhVFV9>3M6mdQ9>HS8AhJGB1T9R?
Q75YLGN;UXb3L6AVLhB@TH=cJ6QdQ9RISX5^KgR4Vi^DPf]YK7nAU960K6AWMh^@
SX1_HfQlS9NFS7i_M82DXIR>PG5`NhnKUXikK71dQ9^HS7a`K6n0S9J<N6UVJgJ8
ShilJfM/N8BDTHAdIValR9>DR7=WIg>3S8j6L65WKh2@ShQgJ6M`QhnDTH1`K761
TIN?Pg=VJ7b<U9B3LfUXMhNDT8AgI6QdQ9>@R7MXJFj1U96<NF]YM8NFV9>0LFic
QYNLUXAdK6mlT9^DRGA/Lgj@V9R9Mfa_NHbDU8afJf]aQiBFSWa`K7B7U9VDPg5`
L8>CTI61Kf][OhnDThAgJf]kSY>AQ75YI7B8U9B7O6aXN8RHVHmnK6]`PIRHTH=`
JG20TiRGQW1`KgjGW9^7M6m_OhnFUhM`IVM`Q9>DQgAYJgB7U9R@NFa[Lh>@V8ah
LFQcRI6HUXAdJG20SiB?Q7AYL7b@ViJ8Mfm/NI2FUXagJF]hQ9BGR7QYHFj1T96;
N6]VK7j?UhmnLFQ`P92KU85dK6ilRI>CPFmXJ7J6Si61MVQTMhRDU8aiJFA`OhnD
Qga_J760T9J@OW5/M86>W9N9O6acQ92IV8aiJ6]hQiBFRG][IW66U9N<NfaXM86D
VhilKVQ`PI6GT7m`J6aoS9BAP71WJgJ9U8j0M6QWMXRDThQiL6adRiRHR7Q/Ig64
TiV<O6aWLgn@UY23L6aaPiJKV8]gLG>0U9bLS7I[J7R6T9B3LfISLHB@THIdIfId
QYBFSg]/JG>8UibHQ7=XL86@V9B1L6QYNh^DU81aJf]hS9>DQ71YJg^8U9j<N71/
N8RAV91lK6UcP8nFSWm^J6j0T9B@Q71YL82@UY66L6A[O8VCT8=dJ6MiRiJFRG]/
JgN8V9V@P71/MhBDV91oL6Q^PI2GTh5aI6ioS9RDQ7Q[K7b<Ui>6N6U^MXVFU8]k
L6UfR9BGR7Q/J75oT9B7MfQTJ7R>U8b0KfM/N8VCT8AaJ6]gR9BDQ7AXIgB7U9R9
MfUXMXRFV91lKfagQiBIT7a`JGB8U9^DPgA[Lh6AWYB8N6aaP96LVH]gJfalSYVL
S7U/JgB6U9>8Nf]XLH2AUhalK6A^OXjDSgiXI6ilT9R@QWAXK86AWYN9OVmaO92T
WY63MWAkSYjLT7Q/K7J6UibCP6mXLgn@VI>1KVQ_Oi2HU8I`IV]hS9JDR7=WJ7N8
U9N;Mf][MhRCUXUdHf=aPI2CS7QVHfb0T96?P6QOIg^>T8]lK6=XNhjFT8A_K6Ud
SiBDQg5XIgB4Si27LfQTL8N@UhmlKVMaPi2LTh=aJ71lT9NAQ7=/L7nCViR9M6]/
NHRGV8UhK6agRi6AS7UXHg24T9J<OW1YL86DWiJ4MVidPi>LUXIcIfilRiBCPfmV
IWR9T921LF=TN8VFU8QiIVAaPI6DR7ITHFilT9J<P6]WL82DUYB6LFQ_OhnLUhQk
KW20T9bKRgQ^JgR<UYb?O71^NhRHW9=oKf]dQYBLU8AcJG>3TiNAQ7=XKX2<UY20
M6AXMXRGSX=dIfQfRIJGS7a^KW^<V9R>OfiXM8B@ThQlJfA[O8n@S7a[I6MlSiRA
P7=XJG^9V9N4LfM/N8VIVHmhJ6]dR9JLSWU_IgB6UY^CQ71/M8NGWYN7M6a^Ni2H
Th1`J6IhR92@P6mTI764TI20LFASL8>FUXUiJfMcR9BKT7a`Jg66UYbDP75YK7j<
V9B0LFQ/NHbGU8QdK6ahSYRHR7M_K7J8UY^>N6a[M8>AW8mlK6MaP92HSh1/IW1l
TIbDQg1WK7b@UYJ8L6IXN8jHUXMcIfAaR9BDQgIWHfn4U9J?NFQXL8NGVIB4L6M^
P9BIUhAdJFb3U:2KR7U/K7j@VI^<LfQ/MX^HV8]hKf]gSi^NSga_Ig>4TiVCNF]X
K7nAVI=lK6A/O8bHTh1_IfQhS9NDR7MYK7R9W9b>O71_NHbHVI60LfQdQ96HS7i/
I6mlS9R@P6aWK7R<UY24K6AXM8^DU8]`J6IgS9BKSga[I7B7UYV<OViWLhJDUXml
K6M/OXjDT7m/I6UkS9>CQWAYK7b?ViR<O6m_NHjGUhakL6ahS9RKT7i/J6ioT9B<
OVaXL86?ViJ4M6I[Oi2HU8=/I6QdQ9B@P71TJ767U8n8M6=QK8NAU8agJ6=/PIBH
S7QYHfQoT9N@P6mTJGj>UY60M6Q/O8bLVH]kKg1nTInLT7]_L7J<W9^AOViYM8RD
V91oKfQ^P96GT81^IfinTIbHR7A/M7nCViV<N6i^O92HUhihJfQdQ92HR7I[HG20
RI>8Mf=NJg^<U8alJF5/Oi2LU8QgJG21Uj2GSgUXKgj@ViB;MVQ^M8VKUXahK6ad
RiRITGiXJ6ilSYB?NfUTJgV;U921K6IXM8^DT8=`IfQhRINDQgIWJGB7V9N<MfQX
L8NHW91lK6I`Q9>HT81/I6j0T9VDP71YKgn@W9B3M6QXMhVFUXIaH6AgQYBHRGQX
Ig64U9R>O6UVL8BAUhmlL6M`QiBLTHAdJ761T9jDQ7MXK7b<VIB8MVI[L8NKU91n
J6adRIRNV81`K7B8VIbDQg=^MXNFW9R7N6adPI6LUXQaJ6U`R9BDR6mTI724S968
LfQQK86@U8akJ6M`Pi>HT7i/J763V9jFQW1YL82CVIV;Mfa_Oi2HVhahJfQhRiRH
T81^JGB8UYR@OVaVK86AUi1lJfU`Q9JPW8IfKW24U9bIS7AYKgb?ViR<N6mYN8bG
UhUhK6acQiRDRGQTI6inS92;M6=TJ7R9TH]hI5iWMhR<S7mYH6QgQY>@Pg=YJGR<
U9B;M6QTLHB?U8QgIei/Oh^DR7QXH6]iSi6<P6UQJ7V;T8n0L6QXN8nHU8]kK6in
T9jOSgU^KWR;W:2@O6a/M8BDV91kJ6M_P8nHTG]/I6b0S9RDP7=XJgj@V9B6M6QX
NhbGUXAcJ6MdQY2FRgQ/JG>4TIJ;OViXM8BDViB4M7=gQiRPW8QhL7J6U9VLS7aa
LH6@VIN<O6i`NhbKVhilKV]aQ9BHT7]YJ7>4TiRCP71YK82AV960L6A/NI6LU8Q`
J6QdSYBDQgAXJ7>6V9V;N6QWLhBGUXmoJ6A^PINGSga/IfQlT9R?P6iSJ7R?Ui>4
LFIYO92PVHUkJfmkTInHSgU^KWR>Wj2CNfi/LhBHWY5nK6I^Pi6DT81[I6QhRIJC
OW1XJgN8V9>8LfM/N8^HVhiiJfQdQ92FT7][JG>0SYB9NFmQK7j<UhaoK6=^NhbI
UXQdJ75nT9^HS7M/L7nDW9V>O71aP92QXiAoL71hQi^HSgiXI71lSiN?NfQTI7B8
T91nK6QWNHjGUXAdIfQhQiNHQ7=WI7>4U9R<N6QWL86CUXalJfA`OhbGS7i[H6]h
S9N@Q75TK7R<Ui66L6IXM8^FU8UfJ6]hSj2LTGa`L7R@W:2DOg5[LH2@V91iK6I[
OXbFU81`J6]kS9BAP71XJgb<W9R7N6Q[M8RIVHmhJFUdQi6ITga[J71oTiVAQ6mW
L86DVIR7KVQ/OiBHUX]gIfIhRiBDQgIXHG26TIB8MfISL7n@U8QhJfM[NhbCRGQX
I6MhRIBAO6mTJ7V6VI^7MV]aOXjKW8ikJfmkR9NGSg][K7B;TiN@N6a/M8NDViB0
L6UdQ9BOUhAaIfalT9^KQgA[JgR8UiN6M6IXN8RGVH]gJ6QcP92HRG]/IWB4TiN?
PFmWLGnCWYJ4M6]`Pi>GUhQdK720T9RGRGI[L7R8W9R;NfaVLhN@V8]dJfA_PI6I
S7a/IgB0TIV@PG1TJgV<V9>8LFA^MhVHUhUgJfUdR9NCRGITJ6n4Ti>@NFQWK8>D
ViJ0Kf]aQiRHV8QaJ720U9^FQWA[KWb@ViR8Mfa/NH^HV8]gJ6afR9JFS7a[Ig>6
U9R@OVa[M8JDW9V6M6]aPI2NV8IdK6mlT9VDR7AYK7N>V9R<N6iXMXRDVHahJ6=/
OXnCS7U[I6QnRi>@NfaSJ7V<U8mlKf1PMhB?T81`I6A_Pi6<PGAVIg21TiR8N6aX
M8RFV9J4KVahQiNLUXMdJg21UYbGR7AYJG^@UY64L6IXM8VDU8MaJfQgS9BFRgQ/
IW24TiJ<NFaTKh6@V8inL6QXOY6AT81^JfQiSYVAP75WJ7N<V9R7MVa/N8bLVhil
Kf]dR9^KSga/JFj0U9^?Og1/LH6DViB3L6Q/O8jKU8A`I6]hRibHSWMWJGJ8U9B<
O6QVLHRGU920JfQfRibLVHUgL767V9VDR7IXJgV<Ti21KfAXN8RCSXMhJfmgRiB@
R7A[J6n3T8n4MVMSKgb?UX]kK6Q/OY2DThAdL7>0SiVHQ7I[K7b<UYB8MfQYN8RG
U8QfJ6aaQ9RGSWQXI724U9bDP75/M8JGW9R7LfadQ9JNVHQiKVn0Ti^HRgU/K7b@
V9R;N6]XMXRFVHalJF5_Oi2FRGa[I6anSY6<OfaSJ7^;ThanKf]^Ni6IU8AcJ6il
SYVFQW=XIg>9UYB;N6UYMhNHW8moKVMaQ9BIT7m_J6mlT9bDQWI/LGn?W9R8MfU_
NH^FUXAcI6IdQ9NHS7]WJ760TI><NfMVL7nAV920L6Q_Pi2FTHA_I6ahS9B>QW=T
J7N<V9J8M6]XLhbHV8alKf]gRibNTH1`KWB4Uj2FQWI/L7n@V9>0L6A/O8bDT8I`
IfaiT9RCR7AYJ7R<ViR9NfaYMhVHV95kJF]`Q9JFSgi_Hfb0S9N>OViTJGR@Thb1
K6ATLHRASh1aIfAdQYNHRGa/K7V8Vi^>PG1_MhBHVi20KVUdP9JLU8=_J6aiT9ND
R75XJGR;UYB8MfIXM8NDU8QgJFQdQiVGRgmXIg20U9R@O6UWK7j@V91nKVMYO8bD
T81aIVQhRiR@Q7M/KW^<W9^;Nfa_NHRKVI1lKg5hRIVLTgi/KW>1TiVCOfiWKWjA
VIB8L6Q/MhbHU8IcIVMfR9BFR7IYIgB6TiB9NFQXLH6@U8alK6A_P92HS81`J71o
U9VDQgA[L82AW9N8MfU/MhjLU8alJFahRi^ISWaaK7>;UYN>O6iWL82CVHUlKfMY
Oi6HT7i/I6MfRiR@Q7=XJ7B7TiB9N6a_Mh^GV8ahK6adR9JHS7U/IgB8U9N@P6aX
L82FViJ8M71aP9BKV8QhKfalSiVFQgQ/J7R8U9B8N6]XLH6AUXMdK6I/P92FRgMX
I6alQi><NF]QJ7^8THn3LFAYNHRCU8QcJ6QgRiBAR7U/K7R9VI^>O6]YM8JFVI1o
KVQ`PI>IU81`J6ilSYNDQ71WKgV;U924L6AXMhbAThMdJ6MdRiJDRGQYIW>4U9V@
OW1YL8NDW9J1L6U^OXnLVHAcJF]gR9BDQW=XJGN6U9B8MVUYLHRDV91hL6]gR9BO
T7maJ7B4TiR@P6aTKWj?VIB4LFAYNI2HU8QdJ6QhS9RHRGQ^K7R<Vib@O75/LHND
V91lKf]aPi6KT7i`J6mnT9VAPgAXK7R;UiB4M6U^O8bHUhQgJ6ahR9NFS7UXK7B8
UiB?NFa[L8BAUhmlKVM`PI2FT81`J6b0T9>APFmVJ7b8TI5nLFIVMhRHUhahJ6]c
QYBHS7Q/I721TIR>O6aXKWb?V960L6Q[O8bDUXIfK6ilS9RHR7U[K7b9W9V<P6i^
NH^KW9B1KVa`Q9NGT81/I6j0S9J@P6aTJgV<U920KfI[O92PVHaiK6alSYbNSWU/
K7J9V9R>Nfa[MXBFV8ioKfQ`P96HU8=`Ifb0S9BAPG1TJ7R<U8n1L6ITLHVCU8Mh
K6QfR9NHS7a_K7N4UYb>OW1YM8JDW960KVIaP96KUXMdJFmnSiNFR7=XJgR;V9J7
M6QVLHB@UX]hIfA_OhnDSWa/Hfb0SYB@P71XK7b@W9B6M6]^O92HV8Q`K6mgRi>D
QgAYK7V8U9N8MfUXM8>@UXaiK6Q`P8jHSX1/I75kRiJ@PFmTJ7V;U9>8MfQ[NI2L
UhaiKV]iSi^LSWa/JGB4U9V@O71[M8>@V8alK6AcO92GShI^J71lSiBCQ75[K7b@
UiN;MVi_NhbLW8anK6UgPIBGS7i/Jg21UYNFQW1`LH>DV9B3KfQ[NhbDTh5`JFQh
Ri2AQg=XIWJ6U9R6MfUXM8>DV8alK6UdPiBGSh1/Ig20T9RDPFmXLGj?Ui>6LFA[
NhVCUXQ`J6ahRiBFS7a/KWb9V9N?O6QYN8JAV91nKfQaPI2GT8=`JFinTIJCPFaV
J7R8TiB6M6UXMX^@U8ifJ6QdQ96HSgi/IWB7TiRAP75XLHBCW9B6MVacP9>HTHQd
J6igS9N<QWATIWB8Si26L6QWL8RDUhakKVMcQ9NKS7]`J723U9VCP71WK7j<UY60
L6Q[O8bFU8AfJfakR9RFQWU/JgJ4TIB8MVa[Lh>DUhQfJ6=/O8bHT7m^J71nTIR@
P71VK7b<UiB6M6QXNhbDV8QfK6QhR9BGR7]XIgJ4TiR>O6aVL8BAVHn0M6QaPi2K
ThAfK720TIbGQgQ/Kgb9UiB8MVa_N8RAU8QhL6ahRI2GRG]dJgN8U9b@PGA/M82A
Vhn0LFQ`OXbIU8AgKW1lT9bHRgQ^Lgb?W9^?NFm[N8^HV8alJFIaPi6GR7]cJ6n0
TiB<P6iWJgR;ThaoL6AWM8NDT85_JF]`Qi>DQfmVIfn0T9B8MVMTL86?U9=hK6a`
Q92HTH1cJ6n0SiBAP71/Kgn>V9R8N6maP92KWY61LfioS9VPSgi`IgJ4U9b>Of]T
L7bAV8n3L6UaP96HThIdK6moT9RDQWAVJGR;UY26MVIVM8RGUXQiK6Q`QYRHR7i_
J6anTIN<NFaVJ7^@UY21L6Q/O8jKV8McJ6agS9NFRgQ/JGB;V9R?NfiXKh6@V91k
L6M_Q8nHT7m`J6n0T9R@Og5XJgb?V9B1L6Q/N8VHUXQfJfadR9RKSWU/JGJ4T9V<
O6aWM82CV966KVacOY>HT8A`I71nSiRAQW5WJgJ8T8n8M6UXM8BCU8IiK6IgQ9BK
Sh1aJgB0U9^AQ75^M7nDX9R7MVUcP8bLUhM`I6ikS9^GR7AXK7R8V9N<N6U[MXRD
V8ikK6QdPI2HS7a/I6moS9JAPfiSL7j<V9B7LFAWNhbFUhUdIfAdR9BFQgQYI766
U9N<N6QQK82<Uh]hJfA/OXjGT81/IVmnT9RFR7AXK7n@V9R9Mfa/O8bHV8akJFUf
Q9BFRGa[Ig24U9R>Ofa[L8BGUi>3LF]^P96IU8AdJfb0T9bHRGMYJgR9Ui^?N6aX
M8B@U8QhIf1^O92DRGQXI721TIVCQ71/M86GWYR7Lfa^O8nIV8I`J6UaR9BAS7IV
JgB8Ti>;MfaYL8VDUi1lL6adQ9BHSWm`JfaoT9^DP7=XK7b9V923LFA/MXNDTH=a
J6MgRiRKSWa^K7J6V9V@PFaXLh2CViB0L6i`Pi>KUhIdK7>6U9RHQg=XJ7V9V9N6
MVQWLHJCThQdJ6A_Q8nARgQ/J724T9V@Q7I/M8RHWYJ4Mf]`P92ITh=`JFUgRiR@
P75SIW>0T966Lf=QK7b?THQfI6I`P96GT81^JG>3U9RDQ6mXL7nDW9R;Mg1`P9>L
WXUgK6alS9JISWMVIWJ7T9B>NfaWL8B@Ti1nK65[NhRARGa^I6QkRiB@Q75YKg^>
ViR;OW1/O8VGV8UhJf]cQ9JFS7]/J761U9^@OViYL82FVI>1KV]^OY6HV8=_J6Ul
RiRHQ7AXK7^;U9N8MVUVM8JCV8alK6QhR9NLTGm^Ig61SYN@P6mWK7jCVIJ4L6QY
O8nHUhM`J6QhRiNGQ75WI767TI28Mf=TL86DV91lLFU/QYJHTH5dK760TI^@Og1X
Kgb<Ui>4M6Q/N8NDTHMhJf]dR9BCS7]/K7B4UYbAPGA`MhRIW9R4L6aaPi6NV8Aa
J6alSiRDQWAXJgj<V9V9MfQXMhRHVhahJ6MfQYRHRgUXHfn4T9V@NFiTKgn?VHn3
L6A_O9>KThAaJF]hSYRGQg=YJ7N8TI26M6ITM8J@U8AdJ6A`Q9NGSX=`JGB1U9bC
Pg5^KgbDW9J8M6a`O8jKV8UhK6agRIJDR75PI724U9B9M6UTKXBFV8mlJfQ_PI2F
TGa^If]lSYJ>Og1WIg^;U9J6N6i/NhbHUhMiK6UdR9JGS7]_Ig24UYb@O6mXK82@
Ui1lK6Q[NhbFU81_IfMkRiNDQ7QTK7b8Vi68NFI/M8JHU91kJ6]dQYBGTGmYIg21
TIJAPfiWKWnDW9R6LfU/OXnIU8McIfQiSYVHR7QXIWN8V9J9NF]/LhJHVI1lK6Q_
P9>IT7mXIfUlTIVDQ7=XK7b@WYR7M6a^N8bLW8ahJF]hRIVLT7]_K7R;V9b@OVm[
LhBDW9>0LfU`PI2HU8A`IVahS9J@PfmTJGJ7U9B3L6ATLhRDU8MdHF=`PIBHSga/
JgJ6V9bDPg1XKXJGW9R4LFU[Oi2KU81dI6QhQiJAPgAVJGN<W9^;M6UWM8NFU8Uh
I65`P9BHSWaXJ6aoSiBDOf]WL82AV9B6MV]/P9>HV8QdJfQhRiJDQgAXIW24TIJ9
MVQTK7jAUh]lK6M`P8nHT7i`IfUkS9J@PFmVJGN;U9B9MVUVMXbGVhaiKf]dQiNI
R7U/JgJ7V9bDQ6m/M8BHX9R8NG1dPiBPVHQgK75nSY^DR7=WK7J;U9>7MVUXMhVG
V8iiJFUdQiNITh5`KWB6V9^DPfmYKgnDUYN1L6MXO8VDTHAaIfUdRI>CR7AYJ7B;
U9V<M6]XL8BDVHmhK6Q`Pi>LTh5aJ6alT9RDP71[K7b;UY20LfAXMXNGU8QhK6ah
RIRKS7U`KWV9U9J<N6]WM8RDW9>0L6QaQ9BKUXAcIfUlSYJ?PG5TJGR8V9B4M6IW
LhJ@ThafIfA/PI>GSWa_Ig28TIbHP7=/Kh>AW9R4M6A/O8bKUXAgJf]lRIJDQW=Q
IW>6V9J<MVMWMXbKX960KVQgRijTUhIaJ7B8Uj2IQ71WK7nAVIB4LF5TMh^DSX1d
HF1cQ92@Q7=TH6^0T924KV5PJgb<UXahJFA_PI>IThA`Jg>4U9bLR7A[K7n@W9b;
N6]/NHbLVHalK6]gRIRLT7aaKWB7U9V@O71XL82@U8ilK6AYO8bFTh5aJ6UkSYRD
Q7IXJ7V7TiR3LfUTMXRDUhUiK6QfQYBHS7a/J6n0TibDOfmXK82@VIJ4L6A/NHjH
U8AdJ6IhRI6GQ71/JGN8V9R4NfUSMXJDVhanK6=`Oi2FS81^IW1lT9b?QWAYL7bA
V926KfI/N92HV8ikKfalT9RPU7QaK7B8U9^<O6]QKgn;U8akJF1[O8jKV85`K6n0
TIRGRgMXKgn?W9N6M6QXMh^GV8]dIVQdQ9NHR7IXI723SiJ>NfUQJGb<U8mnKf=X
N8RDT7maI6anS9^HRgQYK7V@WiV<O6a/N8jQXI>1L6aaQYRNUWm[If]nTIVFQ71X
K7jCViR7LFQXNHbHVHQdJ6QhRIBGRGIVHG>4U9R?O6QVKhBDVI1kJ6=XNhjGT7a_
IfanRIRDPG1TJgb7U923LfAXMXVDTHMgJFMdRINFRgQYJ6n4U9B?N6QXK82@U91l
K6AXPHjHTga`I6IiRiVDPG1TJ7R8VIV7MVQYMhRHV91lKVagRINLU8A`JGB<W:2H
R7I/LH>GX9J7M6a[N8nLVhUdK6adSYbLT7a_K7R9U9R;M6MTL8>AUhUiJf5[Oi2H
T81/If]lSiJ@O71QI7V7Ui>0LFIXN8NHU8MhJfalSijPSgm^K7^;W:2FPg1_MhJI
WYB6L6Q_PI>HTh1/I6QiSYRCQ7=SIWV<V9N7MfAXN8NHU8UgI6QaQiNDS7MXI6b4
TiRCO6iYKhBHWiR7MV]dQiNOVh]iLFioUYbNS7Q^Kgj>W9b<N6m[MXRFV8UhJf=`
Oi2DR7QXHFIhS92;NfAPI728ThaoK6ISM8VCV8M`Jf]hS9RKS7IXJGR8V9b@N6QT
KhJDV95oJfI^Oi6HUX=`J6QnSYNHQ7AVJ7R<UiB4LfASLhRAU8QcJ6AaQi>IS7Q/
J7B8V9^AOfa[L86GX9B4M6adPIRPV8Q`JFihSiVFQ71TI7>8Ui>4M6=WMXRKWY5n
K6UfRIbOUhI`K7J6UY^CPgAXL8NDWYR4M6Q^OY>NThQdIValSiVFRgATIg28Ti>;
LfQTL8B?V8agJ6=_P8nDSWaXH6QkS9B<O6UOJ7R;ViJ7M6Q[N8bHU8]hIfagR9JF
S7AXIg28U9R@O6]VKgn@V8alK6A[NhjDSh1/I6]gRiB>P6aTJGJ8U9J8KfMXM8VD
W8idJfAcQ8nHRGUYHg24TIbAP71XL82DWYN8MVU`Q9>LVHagK71oU9nOS7]^Jg^?
WibAOVa^N8bLWiAkKVQ`QYBKSgQXH6UoTiVAPG1XLHBGX9b<N6]/NHbHU8AcJ6Qg
R9JGR7MWJGJ9VIV<N6ISLhBFWY1oK6IaPIROUXM/J760V9jGRgAXKWbDW9R9LfU[
NHnIVHakKVaiS9VLT7aYI6j0T9J9N6USJ82AV8iiJF=XMXVGSWaYGfMdR9BCQ6mT
HG68UYN;N6][MXRIVh]hJfU_Q9NHT7UXIfn0S9JAP71XL8BAUiJ8LfMXNHbGU8Md
IfMfRiRHRGQXIWB4U9R<N6UVLhBFW8mlJfQ`PIJHT7aYI71oTi^DPFmYJGbCVIN4
L6IYNi2LV8acIVQdRiRIS7ITHFn4V9R@O6aXKXBFW9B0LF]dQ9NPVhQdKVaoTiVG
Q71SIWN8U964Lf=TLhNFV8QaJ6QcR9RLT7i_JGV<Vj2GPFiXL8>HViIoK6AXNHjF
T7i/HfMhRiRHQ71WK7R<ViR<N6IXLh>DU8UhJFQaQ9NLT81^Jg61V9nFQ71VK7j<
VIB4M6M[NhnHUXUfJfahSYVHRgUYJ7J8V9V@O6UXLHBFVi=lJFQ[O96ISWm/H6Ag
S9RDP6aTJGJ;WYR8M6M[OY>OX91oKValRibLT7mXJG64U9>>NfQTJGn@ThilJf=T
NHnFS7a/HF1dSYRAOVaTI7B9V9^<N6a[Nh^IWi1kL6agRiRPTgm_J7>0Tib?NFQP
JGN8UY1oK65XO8bLVhMdI6]dRIJDR7=SI764U9B4LfAPK8JFV8ilJfIaQYVPT81a
I724U:2CPg1QK7^CW9N9LFUYNi>NW8ikK6mlSYbLT7Q[J7B<V9b?OViWM8BHXIJ3
LfQaPiJPV8A^HfQiT9^GQ71XJ7jCX9j;N6QXMXVLVhafIfAdQYJLT7MVIg>4U9b@
O6IQL82DWYR1K6AYOi6IV8I^H6QhR9JDPFiPI7B8UYJ9Lf=TLhRDUXmkJ6A_QiBG
Tga/HfV0T9b?OfaQJgR<V960L6IYNi6QVhahK6aiSijOSga/J766UYR9M6QVL86C
W8mkL6Q`Q9BLUXIaJ71lTJ2GQ75XK7^CW9^8LFAYN8VKUXQaGf5/Q92FRGAWGfn1
TiN<O6]XL8>AV8mlK65[O8nLUX5/J6iiTIbLSgI[K7bAV:2CN6a^NhjKW95lKVQc
S9JKTGU^IVb1U9^CP6aTKX2?V9N8LF]_OYBOV8]cI6IgSYRGQ6mQGVn4U9V7LFAP
K7j@UXUgI5i[P96KTGaYH6aoT9^CO6UQJ7R<V9B0Jf5VMhRHVHMdIVUiS9^KSW]V
J7B7V9R@PG1[M8RIWY>1LFQdQiRPUXIaJ6j0U9bHQW5WJgN>V9B9Lf=WM8RDV8ag
K6QaRiRLT7m/IW>1Uib@P6]TK86DVIB1JFI/Ni>IV8IdJ6]lT9nKRGQXIgB<Ui>8
LFASKhRDU8UcI61^Q96KSgU[H6b0U9bFP6aTJ7bCWYN4LF=VN92LV8QfJfQlT:2P
S7a/J7N9W9b<O6aXMXBGWi1oK6QcPiBLU8=_Ifn0U9^DQg=VK7b<VIB3M6IXNHVI
VHQgJ6UdR9bHT7aTJGB8VI^CNfUTJH>@UY1lK61WNi2IT81[HFAgS9RKPFaWIWN8
VIj9N6ISM8NHV8akIVMfQ9JNTgi_JgJ9W:BIQWI/M8JFX9N4L6A^O8jIT8=/H65f
S9JFQ7AVHg67UYR8M6APKXBDVHafIf1/Oi2LT7aXGV]nSi^AP6iTK82DW9J8M6U[
Oi>LVh]hJ6QhRI^KS7QWIW>7UYJ<M6]WLHBCV8aiJF5/OY2HSgm^IVn1UYnLR7I/
L82CX9j?NFa^NHnPXi1iK6aiS9bQU7m/J7J6VJ2COVUPK82DVI=oIf1XNHnITH5^
H6QlTi^IS71TI76<V9J8L6=PK8JDV8acHeiYOi6HSgUYH6R4UYbIQ7IXKhBFX9V8
Mf]^OYJPW8MgK6QlTIbPS7Q/J7B6Uib9MfAPL7n@V8miIfA[P9BKTH1`HfMkT9bD
PFiTJ7N<VI^4L6QXO8jIVh]hI6MhR9^HS7INHfj4Ti6<MVAPJHRFVIR3L6Q/PiNK
U8M`H6IkSYVDOfaLG7>9V9J6LF1PLhJNWi1lJ6QdR9VLTgi[Ig>1U9b@O6]VK82D
VIB1KVQ/P9>KVhMdJf]nSYNNR7A/J7N;VIR7M6AOLH>DVhUiJF5^OiBLSgiXH6al
U9^COfaTJ7bAViR4Kf=XO8nKVhafJfQhT9^LT7a/IWJ9V9b?Nf]XM8NHWYJ0L6M_
PiBKUX1/HFUkSi^FQWAWIWN<Ui61L6ITLHRFV8A`Hf5`PiJISWQXI7>8W:2FQ71[
M8VLXi^4L6M^PIBPVHQcJ6alUZ2KRGASI7R<W9V9LfASL8RHWX]iJF5`QYRNT81Y
I6n0V:2GQ6mXJgjDWiR4LFQ[O8jIV8A`I6IfR9NDR7AVJ767UiR8MfMSL8>FV8ak
IV=YOiJKT7m_HfInU9R@P6mTI7^?UiN0L6AVNHbPVHUlIfMhSYbPTGa/Ig68Vib?
P6mTKh>DVi5nJF5VN92HT7i/H6AhRINGPFiTI7R@W9b<MVQWMh^KW8iiJ6IgRIbP
TgmXHfn4W9^HRfaWL8BKXij7LFQYOYBLW8Q^I6=hSiRIS7QXIWR@VI^>N6QSL8RG
VI1hJ61XOXnCRGQQG6b0Ti^DP6iPI7jCV9J8KfAVMhnLWXQfJF1aSY^LS7AXHFj6
Uib>M6QOJhJAW9=hJ6=`Q9RTUhAdIg26VJ>OT7Q/KX2FX9j;LfITLhbKUhI`I61^
QYBFR7ATH6b0U9b@O6QNIgj@Vi1oL5mXO8nLU8=_I6QhSinLRGIXJGV<W9^;N6]X
M8RDW8agJF=`P9JNTGi/Ig>7U:2DP6aQKh2DW9N8KVM/P96LVhUdIVQhSi^KS7QY
J7N<WYj@O6]WL8NHWY=lK6A`O96PU81XI71lU9^DQV]LH7J<U9J1JeiNKhRIUhIa
H61`Q9RKR7ISH721UiVAO6MSJh2FW95lJf1[O92PU81_HfUkT9nHR7IWK86AW9b<
Mf]/O92QXI1oL6IhS9NPU81`J7R8W:NGQgATM8BFY9N4L6=/OiBQVhUaIfaiTJ>O
SgMWIWB;Vi^8M5mOL8BHVhafGUaYOYJKT7mTG6MlTIRCP6]SIgbAVIR7LFAXMhjK
UXUcHfAdRiNGRGIXI6n6V9j<NFUSJh2CVHmlJfM`P9RPUhA_J6anTibLQViWI7J<
Vib8LFIPMhbKX8UgIf1cQiROSgMSGV^0V9j<NFILJH6HX9R4K65[OYBPU85[GVAd
SYjFQW1TJ7B@WYV>MVMXMXjPX91hJFMaRJ2QUWaVI6alUYb@NfAPIWVDV9>0J61X
NHnHThI_HfIfSiNDS71SIgB?W9b?MfQTL8^HVhmnJ5i/P9JLUWmXH6AkTInKQW1T
J7bCXJ2<NFMWNhnOWi=hJ6MaS9bLTGi[I768W:2DP6]SKhRKXiR1K6A/P9RPUX1Y
HFAhSijHQ6aPI7NCXIb;M6IVLhVNWhigJFAdRIbVUh5^IgB4W9jDPF]TK82DW9B1
K5mVNHbKUXAaHF=aS9VHS7=PI728W9^<N6IPL8RHVI1iIfA/PiJLTGaVG6AkT9bC
P6UNJ7RAW9R>M6A[O9BPWhmgIfMhT9bLT7UWHGB9V9b;NfUNK86DVhmlIeUVO92I
Sh1^GVR0UZ2KR75SJ7RAY9^8Lf1QL8VHVHacHEm/Q9ROT7QWHFb0UYnCOfMSJgnD
W9N3K65XP9BKU8A/H6AhTIbHQg1QHGB>X9j<N6QXM8VLWi1hJ6A/Q9VPT7a[H6^0
U9nCO6QLI7^AW9R4J6=XNi^VXhafIfAlT:6SS7MTJ7B9WinAN6AQL8NHVI=kI61X
P9>HT7QWGfJ0TibHPfmPIWbCX9b;MVAXMhbPWXagJ6MdR9bOT7]WI761V:2COfQP
L8>GWiN4K6A/PINPVH=XH6AhT9bLQ6aPGgR?W9n8M6=PM8VLX8afH5a_QibNT7UT
FfN0UYj@OfMLJGbGX9B4K65WNiBSV8Q`HFIgT9jPT7UWJ7R<Y:BFO6QYM8ROY9Al
JfIaR9^PUh1XHF^0Uj2HQ71TK7nCWiR4Kf1WN92LV8Q_F61cR9bIS7APH6n8WZ2D
OVUSKXNLXIN0Jf=YP9BOVGaXG61iTj2IQ6aLI7N>XJ2<M6ITLi2PVhifH5mXPiNL
S7ISG6QoU9bCNfAPJ7bDW9J3JEmVNi>LUhA/GeidSY^GQW1PI72;WYj<LF5NKhRI
XIAkIV1[QY^SV81[I724VJBGPFaLI82DWYR8LEmWOiBTWXagIVUiTjBPSWU[K7bD
Z:>DO6QXLhbLWYAhIV5YP9BHUgaTH6V0UZ6LQ6mSJH>HX:2;L6IXN92QWhagH5mf
T9bQTGQSGVb3Vj2@O6QKIWbDV8akI5QSN8nKU7iXGf=hU:>LR75SIgV?Wij8Lf1T
MXVLW8mcH6A`QibPT7]VH724V:6GP6QPJH2HX9B6Jf5[NiJQVHQ`I6MhTIjKRG1Q
I7>;ViV<Lf1OK8RHWXmhIUm/Q9RPV7mXG6QoT:2HQ6aKHgR@WYR9K5]PLI2NV8Ud
H5i`RIbLR7=QG6V4Vi^@NEmQK8BKWiQoJ61XOiNOU7mXHFUoUj2IR6mVJGbHY:2@
MVAXNi6SXI1fI6=^RIbLT7IXH728WZNCP6aPKX6KZ9N4KfA_O9RVW8U`J6mlUj>N
SW1VJ7J>W9^7LF=LKhVKWi=fI6I/R9jSUgm_I6^8VJJNPG5XK82FXin6L6AVN8bK
W8A/GUicQiRIS7MQGVj7V9bCO6IQKXNPX9N4J6AYP9^OV8=^H6B0Uj2LPfiPI7VA
X9b7L5aQLhRIV8QcGea`Ri^LT7MSG6b4VJ2@NfMOJH6DX9=iIeaXN8nNUX1[FFAg
RinGQfmNI7B<Vij;L6=PM8ROXhmkHea/Q9RNSWaTG6b0V:6GQVaPK7nHXiR8L65Y
O9^XW8ahI6AhTj2QSWQWJ7J<Y9n@O6APK86NX8akI5aYOiRKTGaNFfIiUinHR6aQ
IgRFX9b;KV1VMXnNW8U/H61^R9JKS6mPFFb4U9nAMVALJ8>IXIAnIeUTP9BTW7aX
Ff1kSj6IQ71LI7R<X9b8L5aOL8NLX8mdI65dS:2WV85[IWN8X:RKQ6aPKXRNYZ2;
K61XO9JSWXQaHfAgTjJPSWMSJ7J>X9^?LEiQJHJLW91aG5QTP9JNTGQWG65lU9nH
P6aSJ7bFXIj6K61TN92QXHadI6=hS:2TT7QQH727W:2?M61HJ7nAW9AhI5UXOi>Q
UWmYG6IlTJ2OR6mTJ7jCX:>@N6ISO96LX8ifH61`R9bOS7QTH729Wj>HOfQOIh6H
WiV4Jf5WOYNQW8I[H6AhU:2PRg=TH7N@XJ2<MVAXLh^QX9AgI6A^R9jSVg]WH6b7
VJJLP6iQIh>HXIb6KUaSNHnPWhA_H6=gT:2NS71KFfj6V9b<M6=LJH>HX9>0J61[
Q9bTVH5/HfAlV:>IQ6iPI7VDX9j8KV=SN8jLWhU`Hf1fT:2TTGQYI7B<X:RHNfaS
K8BDXIQlJ5aTO92OV81/FfAlSZ2PRg5NI72;WiR6L5aLK8JHVHacI61/S9bQV7aY
I728VjRIP6mTK8JIYYn6KUmXNhjPW8Q/G61`RibLRg5QGg6<Wj>@N6IPKhJLXIAn
IV1`QYbVVH=WGfUnV:6HQ6UKHGJ@X9J7K5QNKX^LV8a/G61/R9RHS71LF6^7V9jA
MV=LJhJIWiAnJ5mWPI^PVhA^H6AoU:>LQ6aLHGJCX9j<LF5PM8^LWh]dIf1`RinS
U7aTGf^3V9nCOVQNJ7jHX9R3K65WO9RQW8M^H6=hSinIQ6]KGVj8Vij;K5aLKXRK
XIAhH61`RInTVH1VGf^6W:>HOfMHHG^CX9V4J5mTO9RTYi1hI6AlT:JSSgUTI76>
XJ6FN6=PJhRHWiIlJ5UTP9BLTgmYG65kUZ6IR7=SIW^FXij>LF=QLHbNWha`HF=`
RjBWV7aXHg2>X:JIOfIPJH6LXiR0J5]TO9NTX8MYH6=fUj2PS6]LGW29Vij<L5mN
K8RLX91fH5UXP9RPTGINF6=lU:2HOVQKI7nDXIb3KUmTP9V[Y8miHfQoUjn[U7aY
J7JAZ:NHNf=SKXBLX9=gI5iXPIBNT7QPFfIlUZ6LPFQNI7bDXIn<K5aTN9>SY95g
HF1hSinPTgQQGfb8Vi^@N61HJ82HWi1hI5USOiBQUgaVF65hU:BHQ6aLH7J?X9j8
L61NKXVPWhmfH61/QijPTgQSH6V0V:2FNfAPJ82HY9b3JEiWOYBTX8mdI6QkU:RT
T7IPI7J@Xj6DMV1PK8JNX95hHemYPIJLU7aXGfMoUZ2HP6MIHGR@W9R6JeaPMY>T
X8adHei`SZ2NT7MQHG29WZ>DNFQOJHJKY9V0K6A[QYbTWhQ^IVaoV:>LQfiNGgB>
Wj67L61LM8bPY8]dHf1cQZ2ST7UNG6R0W9jDNf=LHgjHXiR0Jf1XOYRYWhI`HFQi
TjBLRFaOHG>@Wj2@Lf1LKh^OXI1fGeQXPiRPTGMQFFAlV:2FOV=HH7R@WiR0J5]P
N9BSX8acH6=kTJ>TTGMPH7><X:BANf=KK8VNXIQlIUi/R9bWVH5YGVR0V:JNQ6UL
GWJ@X9b9K5aPLi2OWXmcGemcS:2ST7QQFfV4W9n@Nf5LIX2LWiIlI5aVOibXXH]d
IVR0U:NTRg5TI7B@Y:>>M5iQL8bPXIAhI61^QiVSU7QTG6J1W:6IQ6QOIgjFXiV3
K5]QMi2QW8M^G61cSYjNS6iKG72;WjBDN6=SLhbTZiR0I5a^QibSVH5VG6B0V:6L
Q6aNHGRDXIb8LF5QM92OWXa`GUiaRIbST7APGVb7W:NLQ6aQLH^LZj28LF1[PIRV
WXA/H6AhT:BIQ6mOI7N>Win8K5mPKXRLWXU`G5Q[P9NPT7MLF6AkUZ2FOVANJ82H
WiR4JeiTO9JTWXQ^GfAhU:BPS7APH76<XJ2>Lf5OKhRKWi5gH5UXPiRQTgQVFFB0
V:>NQ6QOJ7jHZ:6<M6ATO9JQY8mdGemaS:BPSgUPG726WZ2?NfAPJHBLXIMlI5mV
P9VXW7mYG6IkT:2KQ6QLI7V@Y:2<Le]PM8VPX95hH6=dS:>TW8A[IgB@YZNPRfmV
L8^PZ:24K61XNiNQVH1XH5mhTinNQ6aKGW67Win<L5UOLhRLXI1aFeAXP9JOT7QN
E65lU9jFO5mGH7N@X9b4JeiTNi>QXhadI65iU:BST7MSHG2;XJ>AN6=LJhBHX9Mk
H5USO9RLTGiSEUmgSYjKPFQLH7N@X9b8KeiQMXnQXi1dHF1^Ri^LTgIPH6R4W:2F
NFINJ8JKY9b0JF5YPI^XX8A_H6=nU:BOQg1NH72<WiV8KUaNL8RLXI5fIV1/QibV
UWaXGf^8W:BHP6MNJGbDY9^4KV5WMiBTW8a`I6IgTJ6PSg1PG6b7V9b?M65LJ8JH
WYIlIf1YQ9bTVh=^H6N4W:RPQ6iQJ7jDYin8L5mWMi2XY9AgHF=`SZ2NU7QQGfR7
UijFMVIPJ8NGX9QnIeiVPINNUh1YF5ilTj6NRg=TI7RHX:6>L6QPKhbTY8alJ5i`
S9bVVGaVI6j1W:JFO6ILJ7bDY9QlHEIPN9>QVHU/F65dT:6PS71QHG>?X:BDNFAP
L8bNXI=hHeaYQ9bTU7]QEf1lUZ>HOfIHH7N@X9^4JEMSMhnQVH]_F65`Sj6PT7=S
H6j<WZBHNFIPL8RNYiQoK6=[Q9VTW85XGfAiUZ2OQ6]PHGJ>W9^3K5mOLhVNXhif
HEicRIbPT7QPGfb4W:2DOVIPK8NLXib4K65WPINPVh5[Ff5iTjBLR6mPHGJAXJ6<
LEmOL8JLX91hGe]/P9VOTGaSGVR0V9nHPFANIgjHX9b4J5]LMhnOX8M/G61dSZBO
T7]TI76>X:>DNFISL8RNYYV0JEmXPI^SV81TFfAiTjBORFULHGRDXin<L5mPLHnQ
X95hHF5[RijPUgI[I6j@X:NIOVMLK8BHYY^0JemWPIRTVhM^G6AkU:>KR6mLGW6<
W9N7KUULJ8RNVhmcIV5^R9VTUga[H727Wj^PR75YLHbQ[:6;M65WOiBSWXUaHF=d
S9^LSgAPGfj8V9b@N6MNK8RHWY1hIUaXP9NLT7USFF1lTijHOfUOIW^@Y9n6KUaI
KhROW8U_FE]^R9jPT7UPG728X:NFO6MPK8BPYYR0I5aVNiRPU7aVFeidSYbHP6QL
H7B@X:B?M6UVNIBSYiMlI61cQYRTS7ATF6R3U:2DP6AHIgR@WiN0J5]SNi>OVhA/
G61dSj2LRg=PHgBAY:BAN6IQLhbQYYMkI6=/Qj2TV7mVH6R1VjBLOfMNHGnHYZ68
KUiXO9>XY8idHf5hU:BTU7QSHg>?Y:6FN6ANJ8NNYYanIeaYPiJSV7aVG6=iU:2H
P6IHGgBAX9j;JEaSLi2TY8idI61`S9jPTgMOGVV3W:>GOfMNJHBLZ9V4JEaQNIJO
Uh1SF5a_R9JDP6AFF6b7UiN7Je]IJ8BHWXifGe]YQ9^PUW]SG6AnUj2IQ6iQJH6H
Yin;Lf=/O9JTXHmaHfIiUjRXU7UWJ7RDYjRHOVQPKh^OYiQoJf5`QinXW8IYHFb1
VJJHPFaLHgR?VIN4IUIOKX^LV8Q/Fe][QiVPSW1SFFV4V:2DNf=KK8BKZ9R0K61/
PIbYX8Q[GVIhTj2NRg1LHgR@X9n@M61PKXRKW8mhIV1_S9bQUW]XGV^4V:6AO6II
J82FXIB0J5UPNi>PVH1/FeidRj2QRg=QI728XJ>@N6APL8BLYYIlIV1_Q9NQUgaW
GV^0V:6FPFQII7^DY9j8K5iTMY2SWha`Gf=dT:>SUWUVHg6@Z:^NPfiXM92T/:67
L6=_QZ2XXHa_HfQlTJ2HPF]LGg6?W9N6K5aIJ8JHUhQdH5a/QibPT7ITFf5lUYb@
N5iGH7NAWYN0J5]SO9>OW8AXG61fTj2IR71KG72<XJ2?MV=PJHRTXi5kIV1XP9RP
Tg]TH6V0V:BKQ6]VJH2LZ:B>MfAYO9JVXHa_H61dS9jPS7IPFg2;X:6?OVISLHRP
XiAlI5m/P9RTUWmXH6MlUj2LQ6ULIWRAY9n>MV5SLhnQWhmfHf5`QibPU7QSH6N4
WYjIO6AOIh2GX9V0JF1TO9NNVH=YG61hSibLR6aLG76<X:2<Mf=PL8nWZ9MoJ6=_
Q9jVUWaXG6R0UjBFP6QNJgjFY9R8KeiVMi6PV8M/Gf1aSY^HS6iLH6^6VIb<KeaI
J8>GVi5hH5aTO9BLTg]TG65hT9bHP6MLH7RDWYn<KV1QN92QY8miH61iT:2SU7iX
Hg><YZNIR6aTKhbPXib4K6=XOiNTV7i/H6=kTjBLPfmOI7R>X9j<Lf=XN8^PZ9=f
I61`R9jWUWiWH767WjNKQ6UOJhBKY9j8KeiTNiNSWhU/Hf=gUYnLR71NG727Vib8
Kf1LIXBLX8mgHEa/P9RQUgaSG6AlUZ2HP6AIHGBCXIb9KV1QL92OX9=dIV=cT9bP
S7=VGg29X:RCO6UQL8NQZ9R4K5m[Q9bVW8I^HFQlUjBKR71QI7B@WYb8K5iTLHVL
Vha`H61_Q9RNS7=QG6B0V9V@NFAPHgbFWiQoK5mTOY2PW8A^GfIiT:>QS7AOI7J<
YZ2@N6=VKh^OWY=fHemWPiRPUWQTG6MnU:>IOfQPJ7^FXIn8J5mSN92NW8A[G5a^
RIVIR6iKG6b3VIn@MfIQKhbLYimoK6QfS:2[WXA_HG28VjRQRFmPIWVDX9R7JeMK
KhJIVHA`G5U/QiNISg=PH6R3W:2>NFMOJ82IWYV1JFAWOiBPW8=^H6MoUZRSS7MS
Igb@Y:2@N6ATM8bOY91iIf1`RijQU7]SGVV0UZ2FO6QLI7jGX9^1JEmQNiBNVhQc
HFAlTj6ST7QVI7J@Y:6DNfISKXNLXi=kI5a[PIRPV7mTG6AkU9nGPF]NIgjFXJ2;
L61PMY2OWha`H61`S9bPSgATHgB<XJJFOVMPKh>LY9N1J6=YP9VQVhA_I6aoTJRP
Qg1OI7J8X:>;L5mPM8RNXi5hHF1aR9bTV81VGfb1V:2GQ6aQJgbIX9N6K5mSNI6K
W8=XG5afT9nPS71OH7NAXjB@MVAOL8bLXI5kI5m_QiVQU7aXGfR3VJ>GPF]OIgbD
X9V3KU]PMhbTWXQaH61`Rj2PS7ITGg23W:2;M5iOJGbGW91lI5aXOi6LU7aSF6Ag
T9bGQ6aOI7^CX9b>M65VMY6QX91gIV5aS:2OTGaVHFn4V:2@N6ILIgnLXIR3If1T
O9RPW8=YGUadSY^KPfULFfb8Vi^7L5QIL8NLYYIiHem^RInTV7aVH6b4W:RLQ6mL
J8>KYYj;KemYO9BSW8Q^Gf1fT9jLRFmOHG2<Xin@N61LK8^LWiAhI5aYPiBQTgaX
FFAlTinFQ6QLI7RDWi^;L6=SNI6LWhQaH5idRj6QT7QVIW6<Y:BDOVQSLHBIY9N0
I65[N9ROUh=TGV5gUYbIR6]PHgJ@Wj6<L6AVM8bTZ9=hJ6=cS:2TV7iTH724V:>H
P6UPIh2HX9^1K5iVNI2OV8A^Gf=hT9VKR6mTI7R?X:29M6AQLH^NX91hIfA`Qi^T
UWaVGfUnUZBHPFQLIWN@Wib6JF5QLHjOWXU_G5maQiROS71PG728VJ2FN61LJ82D
WYAkHEQSNi2NUgmXG6IlU:6LR71TIgVGXj6@M6AWN92OX8idHEa_RibPTGISGVb8
W:>HO6]PK8RIYij0Kf1XP9JPVHQ^H6AfT:2IQ71SHGN?Wj6?MfMSM8VLXiAkIf1/
PiJKSgUTF6AiT9RAO6ALHGN>WYR3KUaXN8nTW8icHFMcU:>PU7ATI72@Y:BFNfQL
KXbLZ9V0Kf=_QinYVhA^H6MlVjNORFiNHgR@Wij8KfATM8jNWh]cIfAaS9bSTGMX
H728VjBFOfMPK8BHX9InI5aSNI>KUX5XFf1gSibIQfiNHgR@Wj2?MVAQMXnNWi=k
I5aYQ9NOSWQTEVB0TInDOV]KI82IYYV;MV5XO9BTVhAaHF5dSj6IRG1OHg2;X9n;
M6IPKXNHWXafI5aYPIRPV7mYIf^1VJ2HP6aQJ82CY9j4L5mQN8jNVhM^Gf1_QiVL
RGAQGW26Uj2DN6AQKhJGWYR3Jf=^Q9VSWXQ_IV^0U:2LRGITIX2CX9n<MVATN8nN
W8ihHem`RJ2PTGUVG6V7V:2DO6MIIWb@X91hIUQQM8bNU7mWG65gSYjOS71PIW2@
XJ6FNFUTMi2NY9AfIUmXQ9JLU7iXGfb3UinDOVMLIgbFXib7K5mQMi2LVhQaH6Ai
Tj6OTgaXIgNCXJBIO6QPJHRHWi=hIU]WO92OTgi[GfQlTInHPfmPJGb@X9b9Kf1W
M8^LUhQ`H6=_Q9RKSWASH6b8VinGOVQVK82GW9B3JF5/P9RQWhU`IfV0UZBPRgAS
IgbCY:6?M61QLhbOW91kI61_Q9RHT7aSHfV4W9bHPfaTK8BLY9j6KfMXP9^SX8]a
I6AiSYbLR71LGVn8VI^<LF1LKXJHW91hHeaXOYROTgaTH6QnVJ2IP6ISJ7VAX9b4
K61QM8^LW8Q`GUi`R9VLS7ISFg66UYn?N65LJ7nDX91kJf1XP9RVW8afIW>3UZRQ
SWAXJ7V@Wj6@N6ATNhbLXI=lIf5cRibNU7aTH6n6V9nCNfQLIX2GX9B0JeUQNi6N
U81/Gf5dT9nHQW1LH767VIb<Lf5QL8JKXI=iI61/PiRNU7iXH6^3U:>LQ6aQKXBH
Yj69LFIXO9>SX8adIVIgS9bLR7=QH7B9X:>@OVITL8>LVi5lHF1WO96GTGQTG61h
SYRFPFiNH7J8V9V8LF5QLh^IWXagIV5dR9^PSWQTH6n8Vj>DO6aPKXJDX9AlI5iW
O9RQV85YGfAiTj2KQ6iLH7B<X9j9L61PKhRKX95hIUm/Q9RQTg]TG6V0V9bAOV=L
I7RFWiN3L6I/OiJXY8adK6UiUZ6WTgQXI7R<WZNANfQSM8BHX9=hHeiYP9BOT7aY
GWB4UZBHQV]OJgbFX9N8K5aSLi2NW8adIfMhT:BVTgaXIWB;X:BHO6QTKh>HY9V1
K61XOY>LV8=`GfAiSibKQW1QH7R@X:>?N6MTN8bPZ8mlJ61aQ9VPTGaTH6inUYV>
NfALIgb?V9=kJ5aXN92OUXQ[G6=fS9RHQfiLGW>8V9R<MV5OL8RHWi1hJ5m/Q9BL
T7QTF6AhRi^<N6QHHGR@WiN8LfAYOiJWXi=nJF]lV:NQU7UVI76<W:6CN6QQL8JI
Y9AnIf=^Pi^TUh=^HFb0U9nHP6aPIgbAY9n8M6AXNi2TX8mlIVAhS9nXU7iYIgB6
WZ2CP6MPKh6GWiB0I5aWN92IT81XGfAhU:>LQW=QH7J?Wib9LEiPJ7nKW8acG5QX
OY2KT7MPFfUlT9bCOfQLJGjCXIR7L65WO9RPWXafHfMhSj2LRg1THFj<Vib@N6AO
L8RIX9IlJf=`QiNPU7i[GVb0U:6HP6aLIWR>W9R7KUaQM8bLV8UdHFAhS9nQTGiY
JGR?X:BLPfaWLHJIX9B0J65/P9NPU8=/H6UnTj2KQg1SIWR@Wib9L6=TM8jPX8mi
J6IdR9jSU7aYI726V9jDOVIPJ7nFWiB1L6=[P9>SVhI_HFQgS9jHR75OH766V9N6
L5aKJ82FUh]dH5aXOiRLU7aTHf^3V:JPQ71TJh2HXJ2;L6AVN8nNW8MaHf=dS9bO
SgATJ7N;W:B@N6=PM8VHWiAlH5]/P9NNTH5XG6IlTIbHQ6iPIWV@VIR8KemTMXjL
W8idHF=fSYbPTGUTGfb4UiR@O6IPJH2?Vi=kJf1XOi6KUh1YHFAhSiVGQg1PI7N;
VJ2>M6QWN92PXiAiIfQdR9ROU7a[Hfb4V9nDP6UTK82GWiR4L6MXOiJQWXadI6Id
S:2LR71OG6n7U9V8LF1KK8BIXi=nJF5cQYVTUX5[Hg1nUj2HQ6mQJgbCWY^9KVI[
NIBLWhaaIf=gSijQSg]YI7J9VJ>CN6IPL8>HXiB0J5i/OiJPUXA/Gf=kSiVDQW=P
IWJ<X9R7LfAQLhjPX8ifJ6Q`R9^NSgATG6QnT9jAO6aPJH2DX9R4Jf5YO9JPV8A^
G61hT9bLRfmQH6b7V9J4L61LK8>DVHigIV1[QYVLT7a[HF^3V:2GNfQOHgbAX9^4
L6AVN8jLVhQaI6QkSinPSWMSHgR9W:2?O6IPL8JKUhb1J6=/P9RKT7aYH6N0V:6L
R7AXKWjCXIj<M6AWMhjLVhagJ65dRIbTT7UXI6j4VJ2DOVaPK7nAWiAnJEiXMhRI
TH1XF61cR9RDQ6QPI76?Wib>LFASM8bLX9=lKfUkT9nWUX=aK7R9W:JGPfmTK82D
X9J4L61XO92PV8QaI6QgSYnKRGAVI769VIbCN6QSM8RKX91oJF=_QYVLT7aVGVMl
T9^@NfILIWRAX9V;Kf5YO96PX91dIfAgTInTU7a/IgN?X:BHOVmXL8RLXiAlKVI_
QYVTVhQ`IW21V:BLQViTJ7V@V9R4K61QLH^FV8Q[G5a[Oi2IR7=TGVj4TibANfQN
K82DX9J3Kf1/Oi>PV8IdHfAkTIbGQg=SIWB<Wi^<Mf=QL8JHV8adI65YPiNLU81X
I6ioU9bDPFmTJ7^?VIR6Kf5TN8bGV8MaI61aRIVHRgQTIWB;W:2CN6UTL8VIX9J0
J5i/PIBOU7i/H6=lTINDO6QLH7N;W9J1M65TNI6PWY1hJF]iT:JSTGm[Ig29VijC
NfQPJh>HW9B3KV=XOiRPV8AaJ6QkTj2LQW1QI7N9WYj;MV5TM8JKW8idH65/Pi^O
T7QTH6b0Ti^@N6MOJ7j@W9AnJEiXNhnNU81^GV5hR9RFQ75PH7R>WZ2?NFUXMXVO
YiJ0LFQgRIbVV8MaIg64UZ2HQg1TK7R@W9>4KV1PM8^FV8I/H61_R9bKT7ASI769
W:2FNf]PK8RDW9AlJ5aXOi6HTGiXHFQkTIbKR71WJh6GXJ2<MVIXNI2PWi1gH61`
RiVLU7UXH6^4U9^?NFQLJ7b@VhakJEaQMi2KU8=/I6MgSj2LR71TI768VIb>MVAV
LHVHW9=hIfA_Qi^PTG]YI6R1VinHP6aTJ7nDX9^6Lf=^OYBTX8adIfQiT:2PSgQX
JGR?WYnCNFQWLhBIWi1lI61YOiBLTGaTGVQiSiRDP6MOI7R<V9J0JemSNH^HWX]d
Hf=aRiRHT7]YI7J<WZ6GQ71VKXVLWYR4LFa`R:2TWhQhL6j3V:2LQ7=TIWR<WYR9
M65TLHRHV8U`I5m_Q9BLSWQWH6j0U9b@NfQNIW^@V91oJ5iWNHnLVHI/HfQiS9bO
S7AVIWN;W9j@O6U[NHVOX9AnIfA_R9RKTgUXGfN0V9bCP6]NI7b@W9B3Kf1TM8^I
V8=^H61`Qi6DQfmOG6b4TIJ8MVAOJgnCV8afHE]WNhbKT7iXGVQhTj2HQg1VJG^D
Y:2AOfm`PIRVZ9b6L720T:BWUhA/JGJ8WZ2CQ6QPK7jGVi1lIf1TN92FTGmVGV5d
SYRDQ6mPH7B@VI^<M6APL8RKVHahIf1WP9BGRgITGVAoU9bDO6aQJ7jAX9R4KVA/
NI6VWh]fIfaoU:BST7UYJ7V<WZ2@NFQXMX^NY9R0KVahS:2XX8QaK7>7Vj6NR71V
J7jAW9R3KV5TM8RHU8I^Gf1_Q9BHR7=TI728V9VANfQVL8BGWY=lJ6=/O96LU85/
HfR0U9nNQ6mTI7N;V9N6Lf1SLhBHVhUgIVI`Q9RKT7MQGf^0SYN>MfAKIWb>VI>0
JEmXMhnIUXQ_I6IgT9RHQg1TH768V9R8M6MTL8VLW8]kJ6MdQYjTU7a[JG>7VjBL
PfiXK7nDXIj8M6QYO8jOW8ahIfanT9jLT7QWIWJ7V9R9N61TL8>IW8iiJ5mXQ9RO
VHA_J6QoV:2LR7AYK82HY:2@O6]VNIJOW91gJ6IcRijQSWQXH728W:BGO6]VKhBI
Xib6L6A_PIRVW8QcIVakU:>NR71TI7B<VIR9L5aNKXJHV8Q`GU]/P9BHS7IPHFQn
U9R@OVUPIgb@V95nJ61VM8VDTGm/Gf5dR9RFR7APHg24U9R<MfQQKhJDWiAlJfMa
QinSVH5[Ig23U:2HP6aPI7^<UiB0JeQSM8NIU8QcHf5cSiVHSWAQGfb1U9R8MVIO
K8BFVI=kJfQYO9RNU8A_HFV0TJ2NQgA[JGVCX9n?Mf][O92QXI1lJFQdRibOU7aY
Hfb1UYjAO6aVJGnDX9MoKVIXO96SX8QdJFinT9bKRG5QI7B8V9R9N6APLHBDV8mh
IfA`QiRKT7aXI6b4V9jCOVaSJH2FWiJ3KV5WN92PW8QfJ6UkT9nOT7QXJgN8W9j@
NfASL8JFV9AnIVI^PiRNUhA_I6]nUibGQfiTHgB@W9^4L6QTM8bKWhafJFMdQYRN
S7UYI723U9b@NfQPK82FWiJ4L6A_OiBPUhM_H6QgS9jGR71PIWB8W9V;M61SLHNL
Wi1kIfIaR9jSUX1XH6j0V9nDQ6iTK7jAW9B1K6AXO92LVHIaIfMiTinNSgQVIgJ8
V9R8MVATKhJHVI1kJ65[PIBLU7UYI6MoT9bDOViPI7V9V95oL65TMXRLV8IdI6Uh
R9jLSWQSHg66V9V>N6AQK8BFW9N3K6I^PINPVHQdJG21UYjHQg1WIgRAWYb;MVQT
LhRKVhahIV=^PiRKS7aXHFaoUijAOVQSKWnAVI20IV1XN96LU85_HFMhSibIS75W
K7R@ViV<LF=QL8RDV8aaIV1XPIBIS7UXH6mnUZ2DP6UTJ7bDWib4K6=TMhjIVhI^
H61dR9RKQg=PG7B6V9j?N6ITL8NLX9AoK6A`QiROUh1_I6^1U9jHPfmSIgb@Wib8
N6QXNHnPVhQfJ6QfRiRPSgQ^IW64Uj2?NfIPK7jDVIB0J65XO9>IUh5/HFAkT9bL
Q7ATHgR>WYj8M6MTLHRLX8mkJfQgQibQT81[I7B4VJ2DPF]VKgbHW9B7K6I[O92K
W8M`J6MhS9RLS7MXJG^>W:6COVmYN8nNY9R0K6UgQ9NSU81/H6aoSYRAOfMNJGN<
VI67K5iXNhnHVHQfIVIhS9bHSgQTI766V9V<NFAOJH2DU8aiI61XNi2HT7iXGVMh
S9RDPfiTIgR?V9R6KVATL8VHV8QaIV=^Q9JLS7U/I7B8V:BFP6iTKh6GXIR3KfA[
OYJQW8QdJ6QkT9bLS7AQIgJ8WYR8N6QTL8NGW8ihJFQ`QYjQV8=[J6n4V9^GP6aT
JH2FWiV7LFIXO96IVhI`J6=dS9VLR7ITI7N7W9n?NfITLh6FWY1kJFA/Q9NKU81X
I6n0U9nGQ75TJgb@Wi^8LfMXM8bIV8QaI6Q`R9RLS7MWHGB9VJ2HO6UVKXNIX9V6
L61/Q9NSW8IdJFb0Tj2HQWAPIWR<W9J7L65SL8JHX8adJ61_QYJLSgQXH6aiT9^?
OfQNJG^@ViN3JF1VN9>LUXA^H6AfS9^HQW1SH728V9b>M6APKhJHWXmhI5m/P9BL
TgiWGVAhS9NAOVQOIWR>ViJ6L61XNHjLWY1fIfIgSibLSg][J7V?X9nCOfUXM8^N
WiQlK6M^R9bPVH5`I6]oTj>KR7AWJ7RDWi^<M6IWM8RHW8M`Hf1`Q9VKSgUWK7J8
Vj6FOVaPKXBDWi>1KV1[O9BTUhIcIVUiTInHQg1SIW>;W9b<M65QL8JHWY1fI61Y
Q9JIT7aVFfQlS9R@O6QLIW^@V9B7KV=YNiBSW8ikJFQkU:2OSgQXI7B<WYj@NFMT
KhBHX91iJ65/PIBLUh1/Hfb3U9jAOfiLH7N;VI>3L61TMXjNUhMdH65`QYRHT7IT
I6j4V9b?O6QPK86HVI1nJ61SNi>KUX5/HfQoTinKR7=TIW^DY:2<M6QWM92OWXih
JFAaR9^PT7QXHfj0V9nFPfQVKWjDVi=oJF=/OiBPW8Q^IVQlT9RLRgAXI7N@VIR<
MfANKXVHV8aiIea[PIJPTG][HfR0UZ2IPG1VJgb?XiR0L6A[NhbPWX]cHfUdRIjN
TGMVJ7J>Vj2FNfQQK8JHW960JeaXOY6LTh1YH6IkU9bGQfiTIWVAW9V8MfATNHjN
WhahJFI`RJ6NTGiYIg26W:>HP6aWK86NY9R4JfA/OY6NVhQ/I6UhU:6IRgAWIgN>
VIb<M6QQKXNFUh]gHea_Q9JNTGQXHF^4V9bFP6]QJh2FWYN6KV=YOYBQWXQaJ6Ih
Tj2LRg5THg69W:2?MfMSLHRIX9=lIea[P9BKT7]TG6AhT9NAOfQQIWN<U9J4Kf=P
MhnHV8M`Hf=fRi^LSWQXI7>9W:2DNFMPK86FW95hIeaTNi2LU7m[G6IiT9jFQ6iO
I7R>WYR9LF1TL8ROX8mdIV1^R9RHTgQTI6j6UibDOVUPIh2@U9N0IV1VO96NW8A_
HF1iSibOR7IWIgV<Wj2?O6U/NHbPXiJ0K6QcR9VKUWmYHfb0TijHQ71TJGjCX9j;
M6I/O9BWX95lJ6]iT:2PU7aWJ7B?WYbDNfQSK8NKX9AlJ5mWOY>LU81[HFIiTibI
QViPI7N<W9R1JeaOL8JHW8I^H5m/PIRHRgMPG6b4Uj2@NfUQK86HX9J4KfA`PibX
VhQcIV]kU:BNR71SJ7B<Wij<M6MXMXRNWi5iI65[Q9BFSW=QG6R0U9^AO6APIWVD
W9N3J61TNi6LW8M_HfAgRibIR71OH7>>X:6DOfaVM8^OYYMoJF1[P9NPU7aVGfQn
TIjGQ6mPJ7b@ViR6L6AWN92PX91lJfQgRibQT7QXH6^3U9V?Mf=LJ7b@Vi1iJ5mV
P9BPUh1/G6QoTJJLQW=PI7V?Xij9N65SM8VNWhmkIV=cR9jLSgQPG6R0V9bAO6IP
Jh2HXij4L6Q[P9RTX8adIVQkTinKSgAOH729VI^8LF1PKhJNWhmkI6=_PiVSUWmX
HFb0V:2IPfiSJHBHY9b6LfI/OYRQX91dIVIgS9^KRG=PG6R1U9R<M61KIgnCW9Mk
I65[P9RPV85XH6MkT:2KQ6iSIWVAX9b<LF=XNHnOY95fJ6MfSYjTUWaXHFj8V9jC
N6ALJGnAWY>0J5aXO96KUXIYFf5hTIbHRg1NG76>ViR>M5iLK8RLW91hI5aXR9bN
T7aWHFb1W:>HP6mYJhBKY9n4K65XOY2QWhQdH65gSj2LRGAPH6n9Wj2AO6UTLHJP
Y9B0J65[PIVLUhI/I6UlV:6LQg5VIWbAWib8KfIXN9BPWhicHf=aRIVIS7APGfV1
UiJ;MV=LHgnCW9AkJf1VO92PUX1`H6QlS:2IQVmLJ7R<X9b;LF1QLhbLW91gHFId
R9bQTGQVIg2<X:6LPfQSKhJKYYn8LFA[P9RXXH]dI6AgT:>NQfiOHgB;X9n<LEmO
K82FW91dGUiWO9NITG]TH6AlUYnHQ6mQJ82HXJ2<MfQXO9NTX8mfIVAcR9^NRGAS
G729VibANFAOK8RLY9IlL65YQ9VVUX5`H6R1UjJSRgAXJH2CY:B<MfISMhbNWXUd
GUa/PibKS7AOG6R0U9bDN65LJ7nGY9b3K5mXPiJTXhU^G6AhR9RGQVaIH729V9R;
LF=NKhNHW8UhHem`R9bQU7aWGfQlUYjCOfQPHgBAWiR3Kf1PMhjLVHA[H6=`S:2L
Rg=PGg68W:>?M6ALJhJLY9R0Jf=cQYbXW8I[HfaoV:BIPfaPHGbDWin8KeaSMh^N
WhafH5i`Rj2OTGITH6^6W:2DNfUQKXBLZ9b3JFA/PIjXXHaaI6R1W:RTTGIVIWbH
YZJ?MfAQM8bPWXacH5i/QYbNT7]PFFQlU9b>NfALHgbFW9AoJ5mVN9BOV8IYG65f
S9bKQVmNGfn;W9R;L5mQL8RLX9AhI5m[PINPUWiVH6QoU:2KP6aOI7VCXib;Lf5X
NI>SX8ahJ6AhS:2QSgQTH6n4VJ2@Mf=OJh2KXiJ3J61/P9VSW8A[HFb0V:BPS71S
IWVDXJ2<LF1QLhRLVHacFeU/Q9JKSWISFfR4VIb@NfIIJ82HWi5nIeiVP9^TWhM_
I6InUZBTSgASHGV@X:2<MVAQM8bPY9MhI6AaR9bSUgiVG6b0V:2COV5HHGRAWYV4
K61TNiNSXhaaIfMhTjBQT7QTI768W:2ALf=PJ8BHXiAhHe]XOY>KTgaTG6AlTJ6K
P6ULI7^CYZ2;L61XN9BTX8iaHF1aS:2QT7MTGVb7W:2CNF=LIWjKXIQoIeiSN9>P
W81XG5igT9jORFmLGgJ@XJ>AM61OL8bNY91fHe]_R9^VU7aTFF^1V:>IQ6AKI7bD
XIV3K5iTNiBVWhA_H6AfSZ6PR71OH7B9WZB?M65PL8VOY9MoI5i/Pi^SUX1XH6Qk
V:>HPFAKH7RDXij9L65XNiBTY8idI5mfTj>VTGUTH769WjBANfANJh>HWiAnHeaX
P9bTW8I/GfAlUZ>PQVaOH7B?Wib;Kf1LL8bKWha`G5UYPIRNSWAPFFN0V:2DN6AL
J86HYiV1J5aXO9JTVhAYF61gTJ6PQVaLF6j<X:B@M6APL8jPYiQlJ5aaSibYV81^
Gfn4X:VFPf]KJgnHZ9j7K5mXO9^YXI1dHfQiTJBTT7ATI7B<XJBDNF5IK8>LXiB0
I5]VOi^SVH1TG61fTibDOV1DF729VI^0IUQGK8^PWhmaGf1`Rj2STgISGVj;X:NH
O6MPJH>LZ9QoJeaVOYRWWhM/GVAhU:>NR6aLGgB@WYn>LfATMXnPXHmhHEa_RIbL
TgQPG6N1UYjFNf=HHGbCWYQoJ5QLN8nPVHA/G5acT:2QRg5QH7><XjNAMfANL8bQ
ZiAkHeQ/PI^QU7aQE6AlU:BHP6UII7RDYYb9L61WNiRXYiMfI6QgUZ^YV7aVHg>@
XjJKNFAPJHNIWYQoIUaXQ9NVX85[F5iiTJ>LQ6aHG76@X9b;K61OL92SY91dI5m`
Rj2VTGUTG6n6W:RHO6ALJH2KYYb3J5QTO9BTWX=YG61hT:BPQW5HFG6<Y:6?M61O
L8NQZ9=iHem_QjB/WXAXH6b1WZNPRF]PJGnHY9b4JeQLLHjPW8]_Fei_T:6OT71L
FFV9WjBAN6=HIhBKWiAkIUUTOiNPU7aXFf=nV:>KP6UOHGVDXj68Lf1OMXjTZ8ag
HF1aQj2PS7MPG6R1V:2DMfILJ82KYiV0Ie]VN9BTV8AXF61dTJ>LR6iLGW6@Xj>C
N6AQMY2TYYAiH5][QijSTGUQF6B0VJ2DP6ULIh6KZj24K5iQO9VYY91fI6QkTj^X
T7MTHGB@Y:NDN65PL8VPY9QnI5]WPIbQUgiVF6AoUZ6KQ6QHH7RCY9j8JEQNL8bI
Vh]YEeU/RInOSWAKE6R4VJ2ANF5HIhBIXIQoJ5aWPIbXWhM_G6B0VJRPRFaNI7RI
[:J@M5aNLHjTZiAcH61`SZBXV7QNF6R4V:2HNf1DI86LYY]oIUQON9VTW8Q/GV1d
U:6QR6aIF729Wj6<M5]HJ8NPY9AkI5aYQ9bYVGaTG6N0VJBIP6=DHGRAXi^6JEQO
M9>PX8adH5mgUjJSTgAPGfn<XJ>AN6=NJ8RPZ9QlIUaTQ9bVWX5XG6J1VjVOQ6iL
H7VDYZ6<L5aQMY6XYi1cHEm/SZBTUWIPGVV7W:RDMfIIIX6LZ9b1JeiXPI^/Y8]`
HF^1W:bXTG=TI7bFZ:R@MV1PM92TY9IhG5][QYnSU7QOE5mlUj2HOf=HHGbFY9b4
JEQNMhnPW85TEeQ^R9bIQg1HFFb8X:2@MeaNK8RTY9MkH5UQOiVQUgiSF6=kUjJN
P6QLGgVDYZ2<M5mPN9>VXH]dI5a`SZBSS7MPGfb7WjBDM61LJ8BLY9UlI5]VOYNV
X8=XG61hU:NPR6aKH7NDYjJ@LEmSMY2SXI=gGUa_Rj2VUgQPF6R6Vj>FN5aDHGbH
Y9MoIUANO9JVX8Q[E5adSZ2OS71HFg29Win<L5iIJHRPY9AhGeQYQijXV7aSF6B0
W:VLPfUFIWjDYYn8K5aPN9JWXHa`G5mcSZ>SSgANGW6;X:BDMf=QKhbSZ9ioJ61/
R9b/XhA^H6V0W:RPRfaLI7RCXin<K5QLL92PWXmdGe]/S:6STGQSG6R1X:VGO6AN
IWjLYiIoIU]XNiNYWhQXFfAdUZBPTfmLHGB@Y:J@L61LKhVIXIAdGUU/Q9^STgmT
Efb4X:RNQVQOIgbNZ:29JeaQN9B/Z8acGUigU:NXU7ILF6n7XjN?N5aHJhBOXIQl
GeMQO9NPU7UPE5]gTj2GOVIGF7>@X:28KeaLM8bTX8QdG5a/RJJSU7QPG6N7XJRI
N65HHh>HYYakHeQTNiBVVH1XF6AnVj^XT7=QJ7bGZ:><L5]NM96TYiAfHFQhTJj`
Wh1XI6j9X:RNOfAHHgnFY9b3IeILM92QV85VDEI/RIbKRf]DEfj;WZJDM5aIK8BL
XI5dFE5SP9VTV7iPEV=lUZNLP6IIH7RFYYn8K5QKM92TY8a`G5adT:JXUWUNGW2;
XjNDNemIJhJPZ9QnHeUWP9bXW8AXG6AkVjJOR6]LH7BCZ:><KeaPM9>VY9AdH5a/
S:2SU7UPF6b8X:JKP6MQJ8>T[:B6KV1TP9VXY8A[G5agTjRTS71LGW6>XjJ@LF1O
LHjTYiQlI6A`RjB_Wh1XG6V4WZRPPfAII7bLYib8JEQON9BQXHU[FEQ`T9bKS6mN
F6^;X:6?Mf=FI8JIWi5gGUAPOYNVVgaTF61lV:>OR6]LHGjHZJB>L5mNN9RVZI5d
H5Q`Rj2XTGMPFF^4W:RGMeiGHGbGX9^0HeQTNIBQVGmWF5ahTj6PQVQGFg>>Y:ND
M5aNLhbV[9]nHe]/R:B/W81QF6B4X:BLPfAHGWbDXIb3JEQLN9BSWXI/FeidT:NP
S75OH7BAYj^FN6=NK8ROYYMgG5ISP9bTWX1TEf>0UZRPQVQLI7VHYjB?K5iQN9RX
ZIAcGf1dT:VYUgQPGfj>YZRGMf1HI86KXiAhHEION9JSV7aQF5ifU:6PPfIIFgB?
Y:B8K5aNLhbW[9AiGeaaRj2YW7mVGV^7WZNLP6=IHgbIY9b8J5IPN9JTX8AXFEQ`
TjBQRfiLG6n<X:6?L5aKJhbQYYMdH5aXQZ2YV7QQEf1nVjBLOfAIGgJDY9b4JEQP
MY2VXHa_Gf1cU:NYUWASGfn<Y:VHO61KK8BNY9UnG5QQNibSV7mQE5UiV:BPRFiK
H7RHZ:B@L61PKhjTY91cG5a/RJ6WUWMPFfR8WjRLOf5LK8BLZin1I5QTOYRSW8IT
F61fU:6LR6]KGgB?X:>@Lf1QL8bTWiAaF5]XR9^PU75OE620Uj2LP65FGWjGYj20
JEQLNIBXX8]_G61dT:NWT7ANG76<Y:JDN61NK8NQY9QnH5mYQ:2VWh1SFf1nWZRP
R6aOHGVKZ:6<Kf1PM96SY8]^GU]/RJ6VT75OFFR7W:JFMf1CI82IYY^0IUMSOib/
Y8a`G6AlUZbWS6mKGgBAY:B@L5]HK92QY9AcG5I[R:2WU7QQEfJ4XJbPQ6mSK8BP
/:N8K61WOiR/Z8U^FeaaT:NQS6mHFFb<Y:BCM5aHJHRQYYQlHemXPibWVgmTF6Il
V:JKP6=HG7>FWiR4I5AHLHbKW8=TDEAXR9bKRfmFDFB1VijCN5aHI8RQYj23J5mV
R:2XYh]aI6V6WjbTT7MPI7^DY:26JeQGK8^LWXQ/Ee=XQ9bTSgQQE6b7WjVLQ6QK
J8BS[Z28KUaTO9^/XHQWEeadU:>PRfaKFfj?Xib@LEUKJHROXI5cGUUVQYjTUgUS
G6B1X:bPR6aPJH6N[:J<K5mQN9JTXHa/G5]_Sj2QTG5IF6V9XjNHMf1LK8RP[9j0
IUa[Pj2XW8MXH6MoX:NQRFaNIWbIZ:>@L5iOLi>TYY1aG5U/Rj6QU7QLG6V6X:BH
P61DI7jLYYR0H5ILM9JSX8=VF5ahU:BWT71LH7NDZjjFN6ANLi6X[i]hH5U[Qj2V
V7aLE6R4WjbPOf5KI7jKZ9n7J5]SNIBWXHM/G61dSjJSS6aKFfb;X:B>L5aDIXBP
Z9IgFeAQO9NVVGaPD5ihTjBLQ6MFH7BCY9j8IUIHK8jPX8i^F5]/S:NXU7MNGVb<
XjRLNF1LIXBPZIn0I5]TOYjYXha/GfAlVjNSRFmNG76DY:6>L5aLL8bVZ9=hH5a`
RJ2XV7]OG6N3XJRLOf1HH7bKY9QoH5AKMi>TWX1WF5Q_T:NTSg1HG728XJRCLeaH
K8RO[9QlH5MYPj2YVH1TF6N0VJNLQVQHIX2IZJ2;KUQNNIRXYY1fH5mfU:j/TgQN
GVb7Xj6CMf1GIXBKX9AiH5=PNiRXUWiWE5mgV:RNQV]KH7BCZ:><KUQKKh^QY95f
H5]^RJ6VU7QOFfR4X:RKOV=KI82LYj20HEQOM9BVWXATEeiaSZBQRFQHF6b>WjBA
KeaHK8VQ[9QhI5a/R:2/VGaSFF^0W:bLPFMII82IZ:B8KUaTNI>[Yi1dG6=iTjRX
Tg=PH72@YjRHN61KK8^PZiioIUaTQYj[X81VE5mkU:NPQ6QHGgNAY:B;KUULM92V
Yi=gG5icRj>VUWUOF6N4W9bCMe]CGgbIX9QlH5MNN9NTW81WF5idU:BNR6aKG72@
Yj6;KUQIKXRTZ9AgG5Q[R:B/Vg]PG6N1Y:VPPFINI82KZjR8K5mTOiR/[Y1cH61l
Vjn/U7ILG7B?YZRAM5aCIhRPYYMiH5ITPj2XV81TE6=kUZRKOfADFgBDYYj6J5AH
L92SX8UYEeI/R9bTTg5IF6R6Wj2DMeaGI8BLYYQlHEAPO9VYX8AWEf1iUZVWSVaK
GgBCZ:BCLeiLL9>SZ9IdH5U/Rj6[WW]PFFR4X:^PPf5HH7nNZJB7JEaPO9b[Z8a/
FeahUZbYT7ANFg2?YZRDMeiIJHJQYiMlGeQVP9jXVgiQFfMlUZBOQ6IHHGjIZJ6;
K5QSN9BYZ91cG5aaT:RXU7QNG6b8Z:^HNf1IIX>NZ9]oHeMTO9bWW8ATF65iW:RT
RfQLG7BGYjB6JeaKL8nPX8U/F5M[QYjVT7=LE6B0V:>DNEmGI7nS[j28J5]VP9na
Zhi^G6=hUZRXU71LG76@X:N@M5UGK8NPY95fG5ATQ9jXUgQOF6=oW:JLOfAHH7bI
Z:67J5QLN9BXZ8maG5acSj>TU7APFFn?Y:NDN61GIhBLY9QhH5QVPI^[Wh1WF6Al
V:VLQfQFGgRDXJ28J5IIKXbTX8U`EeM/RJ>VUWMPG6R8X:BHN61HI86LZi^0I5QT
O9b/WXA[F61gV:bSS6UHGW2@Z:J@L5aIL8bTY9AdF5QXQj2TUg=HDfB4VJROO6=D
HhBKZJB8JeUPN9V[XhaaG5miU:JWSW1IEfj;YZVAMeaHKXVW[9ioHE]XPij/WX1T
FFAiV:RQR6MHHgRGYj28JeUPM8nSXi1`Fem`Sj>YV7USH72>Z:nLOfMIK8NL[9n0
IUMTNiV/W8=TE5idU:JPR6QFG7BAY:B<K5QIL92SZ9=`FeMYQYjXUWUPEV^4WjRG
O6=FHh2KZi^3IeASN9RWVhMTE5a`TJ>LR6UDEVj<YjB>M5aHJ8RTYiIkH5a[QZN/
W81WG6R0WjbPPfIHI7VDZ:61I5AIL8jTXhUXDeQ/RJ2SU71HF6b9Y:^KNf1LJhRT
[:23Ie]TQ:2/XHQVF61lVjRSQf]IFGNDZ:6;KU]LL92TYXm`G5Q^R:BXTGQPF6b7
Y:RIO65HHh2NZ9b0I5AOO9R[X8U_F61hUjNWTg1LFg2@Y:RAM5aAJ8RLYY=dG51V
PI^XT7QODfJ0WZVNQVAHHgjNZJB8J5]QO9NYZ8]/FEifTjNVS7AKEg2;X:BDN5QI
JHRSZ9mnI5UTQ9VWX8=VG6AoUjRPQ6]GFgRDY:2<KUQHL92SY8m`GeQXRJ>WUWAN
F6N6W:RKN65FI8>LZ9n0H5MONiNTXHATE5QdTjBPRFUFEg6CY:N@L5iIL92WYi=h
HEQ/S:J/Vg]OEfN4WjRNPFAHHH2LZ:24J5QINIRVXHQ[F5]cSj>SRFaLF72@Y:B@
M5UGKhbYZiQlGeUSPJ6XW7iOEf5lX:VTRFQLHGbHZ:N<K5QLM9R[Z9McFEa^TJNT
UWALF6R<X:NKM61HHhNS[j>0He]TP9bYXhIWE5akTjRSR6]DF76AYZ2;K5ADK8bT
Y9=dFeU[QinTU7ILE6B4X:VIOVAIJ8NQ[jN8JeaVQ:2`Z8i/G6=iW:jYTfaHF72@
YZJ<L5QDJ8NPY9=dG5U/QZ2[V7aTEfR4VJVNPF1FH7BGXiV6I5=LLi6TXHa/F5]a
Tj>XTgALFg2<Y:NHNEiIIhVVZialI5AOOYRXVGaSEemcU:NOR6MGG7BCY:J<JeUI
L9BXZ9IdGeU/U:R_W7QQEV>7Xj^HO6MHI82N[YanIUQPNibYXHMWFEmhV:RQRFQG
Ffb<Xj6<K5ICIXRLX9=aF5=TQ:2WW7]QFfB8XJVSOfIHH7jFZJ20I55KM8jTY8QY
F5aaT:b_Ug]PH7J@Z:bKO61HJ8NPYYQhFeAPP9bVVH1VF6>0W:VPQ6iKG7bL[jN<
L5QOM96^Y91hG5mdU:bYV7MPG6R8XJNHO61HJh>LZib0I5QONIVTWh=PE5]fT:BQ
QfQ@Eg2?YZB>KUIFJ8^TY9MdG5QWRj6/VgQPE660W:VKP65DI7^H[:>8J5QPNIRX
Yha/F5idTJRXSViGEg6>Y:VHN5]HKh^W[Y]kGU=WPj2XVH1PD5alW:NKPfA@F7RH
Z:>8JEMLM9N^YY1dG5i^T:VTUWALF6N7X:BDMf1HJ8BNZi]lHEIWP9n^X8QXF6Ak
V:RSS6UGGgRH[:B@KeQKK8nTXi=cH5aXRJ2WV7UTFfj>XkBVPfmSKhbY^k2CM65/
RjBd[i5aG6AiU[2XT7ALGg6>YjB?KeMFIh>OY91`EU5POY^QTgMLDeilV:>KOV1D
G7RHY9b0GdiDLi2SWhAXD5A/S:JST6mGF6R7Y:RGN5iKJhVT[:1oHEQTOY^VWX=P
E5UdU:2IP6=@Dfj>XIb4IU=CK8nTYY1_FE5XRJ6XTG=NCfB6XjbGP61AHgbL[9b0
I5ALN9^XX8QVF5ahUZRVS6aHG7>DZ:VDLEaKKhbV[9UiH5a_RJB/Vh1PE6N4WZVP
PFAHHgnOZJ26IUMNN9R[X8QYFEa`TJVVS71LGW6@[[6KNf=PKh^V[j20H5UXQ:6Y
WX=PF65lWjVTR6QLGWNDX:27IUQHKhbOXhaXEU1XQibTTgQLF72@ZJjPPfMPKhn[
/jB8JeiXPin/XH=VF5QdTj>LQVMAF72?Y:>8JEIAK8^PY8a`EeAYR:N^UgMLE6Io
X:jIPF5HJ82Q[ZB9J5aTO9^/Z8U^FeahUZVXSVmLGWB@YjRDN5iHKXRTZiIiG5AV
P9nXV7aNE61lV:BLO5iDGgNDZ9n4J55HM9>YY8a/DeM`SZVXU7AKG6b;Z:bLOUmH
J8JPZimlHEIPP9j^YXQXFF1kVJ^PR6QFGWBAZ:B9J5MDJi2TY9AdFEU`TJj`X8=W
H6n@ZK6TPfQLJH^T[jB9JE]TOi^XXHMWDeMdU:BQQfUDDf^<Y:><K5IDIXNQYi5a
Fe=VQ9nXUWQOE660VJROPF5DH7^IZj26J5QKM9>TX8MTDeA[RjBPRFmFEVj;Y:RF
M5aHJ8NTZI]lGUAOOY^VVgaPE5mnVjjWRFaHHGRI[jJ>K5UPLI6XZ9=aGUU_T:JX
V7QNFFV9X:RHMemCH7nLYianI5QPOib/Y8I[FF1lV:bXS6]FFFn@Z:J?KUMFJhbV
ZIAfG5IXQZBYVGQLE61lWZ^INemDGWbKZJ24H5ANMYBYYX]XF5a`U:VXTFiKFg6C
YjbDLf1GJ8ROYY=dFeAVPIjYW7iQF620W:^TPFAHG7RLZ:R<KV1PNiV^/9AgH61d
Tjj`V7QPG6b<Y:jLNF5HJHRP[:20HEMSP9bYWh=XF5ihVJNLQfMDF6b@Y:2<K5MH
K8bSY95aGea/SZB[WgaQG6R8XJ^OP6=DHh2LZin0IUILN9B[X8MXDEUaSZBTS6UF
F6n;YZRCMUaHL8jX[9aoGeQ[R:N^W81QE6B1WjjPPfADG7NHZJ>9J5IKMi6VYX][
EUM[Rj2SSVmHE6b8X:VCMeaDJ8JPZ9ioH5QTP9b/Xh5VFf5lW:jWSfaHH7RGZj^@
LeiIM9R[Z9AdG5U/S:RYUWMQEfN8XJjHNf1DI82LZIn3I5MPO9RYY8Q/F5adUZRS
SW1HFg2?YjR@L5aHJhbVZIAgFeA[QZ2[V7QLDF1lVJBHO5]>G7NFY9b4I5=LM9JV
XH]XFEa`T:NXSg1LG7>?Z:jGM5iGJ8jT/:1lGeAVQ:2/X8A[F6B8Y;2YSVmIHh2L
[jR>KUQHL8nSXha/EUIYS:2TTG1HDfN6X:BCMUa@H8BLYYUiGTmLNINXV81VD5Ud
TjJNQ6MGGWBDZJN>KeQIL8nXZIMfFeI_RjN`VGUPGVR8YjnVQVQII8BN[:68JeMO
N9JXXhU[F5a`SjBTSg1IE6b<XJBGN5iNKh^V[9UnH5MVQ9jXVGaOD5QhV:>IOf1@
EWJDXin3IeQHM9B[Z91`FF1dU;2`VGQNFfb<Y:VHM5UDHh>NZ9UkFdiQO9^/WXAT
D5aiVJRQRFQDG7JH[:B>JeQIKY>XZ9AcFeM/SjR/V7UOE6^8Y:jKPfADIh6O[:24
HeQNMY^WWhIVDeUcT:BQR6QFF7>DZ:RDMUiHKi2[[YUoI5]XRJRaX8AYH6b9Yk>Y
RFaTK8NS/J^?JeaQNIRXZHa/F5QdTjRWT71GE6^8XJRFMUaFHh2NYYQlH5QPOYRT
W7mQE5ikV:JNQ6QHFgRFZ:>6K5MKLI2XY8m/EeIYS:2ST7=HDFR7X:B@Mea@HH6P
[9AhH55NMibYW8AXF5mlVJbXS6aIG76>Y:B?KUMHK8RVYi1hGUMYQj>TUgUOF6B0
WjBHNEmGH7RGYYn1I5AKN9BXY8Q[E5QaTJbYTG5GF6^8Z:bFMeaGJ8NTZIakFeQT
PIjXWWmOE61lW:VPQ6IGGWnHZ:B;JeALLi2VWXi`EUM_T:BSTG=KE6V;Xj^FN5mH
JHJW[j23I5QVQ:2/XhAYFF1lW:jTRfmKG7JDZ:J;K5QHKhnVYi5`FEQ[R:6[V7IN
E624X:bPP6AHI82O[jB6JEUSOYRYY8Q/F5ahU:RTSViIFG2AYZNDMUaHK8bT[9Qh
HEAYQinXW7mQEVB1W:ROQ6QFH82LZ:B9KUaONiVXXha`FeQaT:JTS75IE6R;Y:ND
Mf1GIhNPZI]lIUaTPj2/WX1TFF5lV:bSQVUIH7RDYj>;K5MHKXnWXHi^EUM[R:BV
U71KFFN6XJRLOf5GI8BO[:>4J5]PNiJXWhIWEf=cTJRPSVaIGg2@XJBAL5aLLHnT
YiQfG5][R9nVWgaOEfB1W:NKOfIIH82NY:20I5aHMYJXY8A/FeQdSjRWS71KG6j;
Yj>@M5]FJ8VSYiQhH5QWPIjYW7iSE61oVJRPR6aOJ82O/JVCM5iQN9NXZIAaGei_
T:JXUg]SF6b8X:NHN61GI86LYi=iHeMPNIRTV7aOD5Q`TJJPQ6QDEfj<Y:B<KeQI
K8NQY9AdF5UXQj2VV7QOE6>1W:>HP5mCH7jLZ9n6IUMNO9b^[Xi`Gf5lU;2aUgQN
I7RD[:bLN5aLK8bQY9IiGUMXPibTTgiPEVAnWZBLQ6AHH7^KZj68J5UNM9BXXh]Y
E5M_SjNVT75HF6b9YZJHNE]LIXNWZj20I5aTQ9nXWgmQEeilUZJQQ6MDFGJ@Y:28
JE=FK8RPXHa`EeASPijST7=KDF>1W:JHOf5HI82NZib4J5QSNIRXX8QXF5adT:JS
RfmHEfb>YZRDM5mKK8nWZ9QkHEaYRjJ_X7mYGVN8Y:bSR6]NJ86K[ZJ8K5QONIRQ
WhQXEUI^T:BPR6aHE6^?Y:RDN6=HKX^S/9]nHeQWO9n/W8=VEf1kUjVQRfaIIgVH
[ZRHMeiTNI>XZi=dHE]cTJNYV7aOFFb9Y:VHNf1CHH2LXIQlH5APOYNXY8M[F5af
SinLPfI@EVR9WiV8JeAGJhJLWha/F5AVQ9bTTGINEfV0VJRLPfALJ82NYj28I5MN
N9JSXHQXF5I/TjBTT75KEVn<Y:^DM5aIJhNOZ9QiG5ATP9RTW7aOEV=nW:VLQ6QG
H7VIYin8K5UKM9NWXha^F5U_S:NVT7AOF6R9X:RHN6=HIhNP[9n0J5iYQ:>`YXaa
I6R3WjbXRfiOH7JFZjJ;K5UKKhbSY9=aF5a[Q:BXV7aQG6R7WjRLOfAKI8BLY9b0
I5ATO9VYX8a/G61hVjbXT71NFg6DY:>@M5aIKY6TZ9MdI5aYRj>/W81WF6V8Xk2Q
QfQII7nI[:B8K5aNN9RWY8iaG5acSjBPS7AKF6j<YZRFMemHJ8BTZ9R0HEQWO9bW
W85SFFAnVJJOR6UHGgJAY:><L5aLM8nTZ91cG5]_Rj>TUWQLF6N1WZ>HNEmGI7nF
X9QnHEAOO9NSW8IYFemiU:NOR71IG7B@YZNCM5iKK8NSZ9AhG5IXPI^TU7QKDf1k
V9jGOf1GGgRDXIb4J5]LMiJPX8a`H61hUj^[TGQVH7B>Y:^DMf5LK8JPY9AlHEQV
P9RPV7iPE5aiUj2IQ6AHGW^HYZ>;L5aKM92TY91hH5]`SZJVU7QOF6R6X:NDO61G
HGbLYYUnGeIPO9NWX8QWF61fT:JSRFaIGWBDY9n<KUIHK8NPXi1`FEAVPibSTGQN
EVN3XJRIQ6QLJ86P[Z>8K61TOY^/Yi1cHFAhV:bYU7APH7B>XjJ@LemKKX^PXi1c
F55TOiRTUgUTG6R6XJbTR6aPIWbLZJ69KeUNMi2TX8QYFEU[SYnTT71OG6b;YjRI
OfILJh^LYiihHeaTPIbXXH=XF660UZBQQVaFF7B@Y9n8KUAFKhROX8aaFeQXQinS
U7IPG6^7WjRHOV5GIWjGXiR0HeQSNIRTW8a/Ff5gUjRSSgASGg>@Y:>@LEaLJ8RP
Y9=cGUQTPIbSU7USEf>0VjRLQ6QKI82LZJB>LfAXP9b`ZI=gI6MiV:^XU7IPGW2>
XjRDM5mLJhNNYYAhH5ITP9VTV7mSE5mhU:6HP6ADG7BAWib8J5QLKY6SX95cH61c
T:2XUgMVGVV9X:RIOVQNJhBIZ9b3J5aTNiVXXhacI6R0W:bXSW=OGg>;Xj>>L5QL
KXRLXHa_FEASP9VPTGINEf=lUj6HNemGHgbDY9inI5QPMiBSW8Q/FeahTjBWSW5O
G72;XjRDM61IJhNPZ9UkH5]YPibWW85TFfR0UZBOQ6QLI7^GY9^8K5]NMiBTY8ia
H5icT:BTT7QPFg6>Y:^GOV=NJhBQY9AnH5QSP9^PUgiSF61lV:NLPfQNH7NG[:J;
K5aNL8jTZ91`GeidS:B/W7]OGVj4X:NKOV=PJ82KY:24J5]SO9NXX8QYF61gU:>S
T6iLGVn>Y:JDMf1LKXjQY9QiH5a/R9jWV7aSFFB0V:6IPFMHGWRFX9^3J5MGL92P
WXU/EeI[S9nPRg1OFFb8X:RDNFALKhBNZ9MlH5]WOYjTV85TEV1iU:>OQVMHGWNA
Y:J>L61SN9B[Z9AiH61dS:J[V81XH769XJRGOV=LIh2LZ9^0I5]QO9RVW8I/Feah
U:BQRfaKGW2<X:2<L5mKK8RIX91dGU]YQ9bQU7UPF6B0W:RLQ6QLJ7jNZJ68JemQ
MY>XYY1`G6AgTJVTUWMNHG2>X:6DM61HIXJNX9AiHEaTPinTVGmSFfIlVjNOQ6AH
H7NDXIj8KUULM92TXI1`Gem/S:>PUWQPG6b8VjJIN6AIJ8RLY9^0I5][PIbXX8Q/
GfAlV:NQRFiKH7BCY:2<K5UIK8nPX91`FEQ[R9RPTgIPEfN3V:2HP6INI8BHY9n3
K61WO9JWWXU_FemdTj6OS6mLFfj>WZ2AM61IJ8BOZIUlI5iXP9bYVGiTF6IoV:JL
Q6QLI7bHY9b8KUmSMiBVX8mcGUmaSjBSTgQQGfn>Y:BINf1LJ86LWi1kIUUSO9JT
W8AYG6IkU:BNR6aIHgB<Y:6?LE]NL8nSY9AgH5a/R:2VUgiTFfJ1VJBGO6=DH7^G
XiR0IeANN92QVHAVEemaSj2LR6iLH7B@Y9n;Lf1LKhbSXi=iI61/R:2XW7aTGf^0
W:RKPfQNI7jLY9b4JeiPN9BWX8I/G5maS:6TS75OG6n;X:BGN61PKhbT[9j0J5a[
Q9b[W8A[G6AlU9nKQ6IHG7>?XIb9KeaLLhjNWhaaGUa^RJ6TV7]TH6j;WjNIO6IN
JhRNYYn0J5iVPi^XWXI`H6AlTjJPQ6mNH7>?Win9K5iKK8RLXhicHE]/Q9^WUWaS
G6V4W:NKOf=IHGbFXiV0IUQLNiBTX8Q`FEadS:2QS71KFG2<X:6@M5iLJhBOXiIl
HEaXQYbXXHI_Hf^7X:nWRg=PJ8>L[:N;L65NM9>TX8U_G5Q^QinPQfmLEVJ4X:2>
L5UGI7bHYiQiHEQSPiRTW81[F6B0UZbTS7IOIWRCZ:>CMVASMY>TZ9IiI65cS:>X
U7aWH6n7VjBGOV=KJ86KYib6JEQTOYVXX8]^GV=cU:VPS6mNGVn<X:2<KUUGJHRH
XiAhI5aXQ9bWW8AYH724WjbQQf]NIWjGY:2;K5QPMY2PX8a/G5maSj>XTgITG729
VjJDNfAGJ82HW8ahGeAPO9>LT7MQE5afT9nDOVADFFn<W9V4IUQHK8RHW8a`FEU/
QiRPU7QQFFb8WjBHPF]LJ8BNYij8K5iTO9^WWhQYGV1dT:6NRG1LGW2<X:2?L5mO
KXNLY95dHEi/R9jTVh1XGfj7W:bNR6iOJ7jLZ9j8JeiPN9RTXHQ/Gf1gU:JXT7IT
H7N?Y:RCN65NK8bPXi=dH5MSP9VTUgQQFF1kUZBLPfQNI7VDX:2<K61PM92TZ8mc
H5ihSj6XU7ALF6R7W9n@MeaCHGjDX9IkI5aWOibVVhM/G6MnUjNPS7=QHgB@XJ2;
KeaPLHjTY9=dGUa/R9jWV7UWH6b8WjVNP6MLI82DXi]nIUIONI2PWXA/F5UgT:>P
S7ASI7JDZ:BFO6ITLhjTZIQlJ5m^Rj6WVH1TG6R0W:NKOfQKHGbKZIn6K5mQMiBW
XH]^G5a_S:>TT7AOG6^7W:2DN6ALJ8BKXi=lIeUTP9RSV81XGf5iV:RNQW1PI7^D
Y:B>Kf1PLHbSY91dG5Q/R9^TTgUPFfj4WjNIQ6ILIh2KXI^0J5mQNINTW8A[G61i
U:JTSW1QHgN@X:JAM5mLLH^NXI5hG5QWPIbPU7iTF6N4VjBLQ6]OIWjHY9b4JeaP
MiBSWXU/GUiaSj6QSg=PG6n<X:>CMf1KJ8BOYYAhHeMVOYBTUgmTEf1iU:6HPFQK
H7BDXib9K5]PM92QWXa`FE]`RIjPT75LG6^8WZ>GNF5HIh2LY9R3I5QQO9RVW8A/
G65hUjJPSfaLHFj>XJ6CMVMSM9>SZialIV=dRJ6XV7aTGVR6WjVTQfaWK8RT/:V<
KV=XPIbXYXa`Gf1iTj6SQfiNG728X:2<LEQHK8BLXIAgGUISOYNOTG]TF61lV:BH
QV]HH7B@Xi^4IUQIJhVLVHQ/EeQ[PIRNSfmLFfV6W:6HN65NKhROZIaoJ5ISOYBL
U85XFFIkV:JHRg5OI7VIZjBDN6IWMi>WYY1hHf1_RjBVV7UQG6N7X:JHP6AGJ7jH
YiQnI5MSO9JSW8AVF5acSZ>LPFmHG7B7X9n>LeQOKX^TY9QhI61/Rj6YW81YGfb8
X:VQRFmPI82KZJ26KV1QN96TXhQ_Ge]aSZ>SSWAPGW>9Y:RFNF=TK8JQZ9]lI5i[
Q9bWW81WFFAkUj6KQ6AHGg>@W9R1J5AHJHRPWhU/FE][R9nTUgQOG6b6W:NLP6AL
JHBNZ9j1JeaTOiRVWXI/Ff5hU:BORFmKGW>>YZ><MV1NL8jTYiQiHei/R:6YW7mX
GfR4X:BIPFMPIh2OZ:24K61TOYNVY8U^GV1hTJBSSW5NG72;W:2<L5aDIh>IXi5f
GeITOiNQTGaQDf=iVjBFQ6IKH7BFWin4Ie]HLhnLX8M_FEU`R:6SSg5IG6b4WjBD
MemLJ86LY9QlHE]VO9VTWhAXGfAlUZJPR6mOI7VDZ:B@M61SMY2TY95hHf1^R:6X
U7]TGVn4X:VLQ6MSJh2KXib4IUaPMiBLVhQXG61gTj>TT7IQG76>WZ6AM65NL8^P
YiUoIUa^RInTW81TFfB1W:BIP6QIGg^HYZ26K5aLM8nVXhQ/Fei`S:BVT7ANG6b4
WZ>@M5]FJH>LXIQnG5MTOibWWX=XG61oV:BQQfaLH7RDY:>@LeiOM92QXHi`H5a`
SZ6VTGQQG6j8X:6DOf1IJ8>OYYR3J61WO9bWW8AYG61fUjBTSfiPGg2CXJJALeaK
K8RLXIIhI5aXQYnVUh1VGVb6WjNNP6QPIgbHYYn9K5iVO9NVX8]^G5i`Rj6SRG1K
Ffn4Vin;KeMFI82IVi=gG5AQPIJPUgaPE61lUZBIP6QKHGRFYYj7K5aPM92TXhma
H61cT:>VU7MPGfn;Y:NFNFALK8BLZ9j3IV1/QZN_Yi1aHfQoV:VXT75QI7VHZ:>@
LeaNL8nPX8m`G5ITP9NOS7=IE6AlVJ>FOV5GIgjHY9b7J5aVNIRVXhQYG5ahT:BW
S7APGW>@Y:B@MV1LL8bSZ9IhHe]/R:2/WWmVFfJ0W:JKQ6QKI7nHYj67KUaPNIBT
XH]/Gf5hU:RXU7MTHG2<YjVHO6ALJ8>KY9QlI5QTOiNWW7aTE5miTjNLQ6QHH7BD
Z:6<L5iNM8nQYha_GUQYQY^PS7=KDf=kV:6?Lea>G7R@W9=kH5AON9>PVh5[F5ic
U:^QS6mPH72FZ:RCM6APM96VZiAgHEa/QinTTgQOF6QoV:NHP6QNIgjOZJ6<KV5X
O9R^YXa`H6=`T:BTTgAPH7B>XjRGNFANKhVPYiR0Iem^R:2XX8AYH6R0V:BIP6QN
HGRDX9b1I5AHK8JLVHAYDeQ/QZ6VTGQSGg2<Y:RDNf5LIh6LXIQlH5UQO9^VW8=X
G65lV:RQQ6UKH7B@Y:2<L5QIKXRLWXU^G5QXQYbQT7MSFFR1VJ>FOfMKIX6LY9b4
KUmXO9RXWXU/G6AhU:NVT7IQH7JAX:BCM65NL8bQYY=hH5Q[Q9b[W81VFfMnVJNL
PFMHH7VFY:29JeaPM8jNXh][Fe]`R9bPS7=LEfb7W:2DNeaHJH6KXiMlIUaVP9bX
X8A_Hf^0W;2XSg=SIW^FYjB<LEaQM8nXXI1dGUa`Rj>ST7QNF6N1WZ2AN5mHH7bH
WYAhH5MNM9BSVH5TF61hUjNTS71PH7NHZJRDMf=PL8nVZiIfI5a/S9nWV7QQE6N3
VjNHPFUHHgnGXi^1JEQPN9BVX8U`GV5dTJJST7APGW2<XjRDN6ALK8NOYiQoI5aY
PIbXVHAYGVMhW:RKQVUKH7J@Y:28KU]TM8nSX91aFem`S9nTU7IPFFV8W:>DN5mH
Ih2HY9QlHEMTOi^YX8M/G61hU:BOQ6QHG7><Y:B<LEiOLHjTXi=hG5i^RJ>WU7UP
F6R4WjVHOf=LK7nOZIb8JeaWOiRTWhAYG5mdT:2NR6iLGW29X:2<M61LKh^NXIIl
HEa[PinWV81XG6R3W:JKR6iIH7NDY9b6K5mLLi2TWhI`G5a`RjBTT7MPGW26WjVH
Nf5PL8NSZIb0IUaXP9jXW8AXFFIlV:NPR6MKH7RFY:B@L5aQMY6TY9=dGU]/Rj>W
U7QOF6b9WZNIN61HIX2NY9J1IUUTO9JTW8=YFf1hU:BLRfiKGW2;X9j;L5mOLI2T
YiQhGea[R:BXVGQVGVB0W:RNPFQLHgbHZ9n3Je]QN92TXhQ/G61dT:JTS7=LG728
W:2<LEQHJh6IX9IkH5QXPIJSV7iSEf5kU9jFPFUHG7J@Wib6JEiSM9>WY8icH5ic
T:6TU7MOFfb8W:>CMf1KJ8>OY9R0IUaYOiRXWhA[GVB0V:NTRFaLHG^GZ:N?Lf1L
M8jSXhifG5a/Q9nQTGQPF6R0W:BDO6AGHGbGY9^3J5QPMiJVX8Q`GemfT:JTS7AP
H7B@Y:NAN65PM8VTZI=hGem`Q9jWVgmTH6j7WjRKPfQLIgjFY9V3I5ILLi2PW8IY
F5U`SZ6OT75OG6n?X:JDN6INK8RNY9IlI5UTOYNPUWmTF6=hU:6HP6AKIg^FY:><
J5aPLI2OXI1cH5Q/RI^TT7=PG6R4VjJDNfALJ82IZ9b0J5mWP9RYXHM^FF1iTjBQ
S6mLH7J@YZRFN65NM8nTZ9QnHf5`S:BSVGiWGVN6WjNLP6QLI7nLZ9n3JEaON96N
X8]^Gf1kTjNWSgIPGW>@XJ>DNFALL8RPYYIhH5aWPIbVWWiWFF1oV:NOQVaLI7bH
YZ68KemOM8nPXH]`H5a^SZ2QSWAPF6^4VJ2@M5mHJ86HXiIiJ5aSP9NOVH1XGf1h
U:6KQ6]IG7B>W9n6JeaHJHVQY8mdHE]/QZ2VTgMNEfV4WZNFOVAPJ7nL[9b4JEaT
NiBSWXMWF5maT:2PS6mPG76?XjJFMf1PL8VQZ9UlI5iXQ9bTVh1XGfR3UjBPPfUO
IWnHZJB<LF5XP9BVYhidHF5kU:BTT7IIG768X:>ANF1LJhJNY9QkIf1XQZ2/WhI^
H6b3Vj^OQ6aLI7JDY9b8K5]OLI2PXI1dHEi_RInSTgQPF6V3UZ>GN5iFHg^GWiR0
I5QPNiBQW8I/FF5kU:2LR6aIG72;WYR4K5QDJ8RNW8UdG5IXQ:2SU7aPG6R0VjBH
O65HH7^HX9V1IUUPN9BQW8M^H6AfT:JTS71QG6b7W:6@MeaIJh>LY9AnIei[Q9jW
VH5VG6V0W:^OQ6]PIWbNZ:J?K61SN96XZ8iaH5i`Rj2TTgASH6n4VjNHNFANJhBL
Z:24Jf5[P9NPW8A/Gf=lU:BOS7ANGgJAWj2<L61LL8^PY8mhH5]/Q9jTTgUTF6Mn
UjJDNfAHIWnFY9^3J5QTNI>TVhA`HFAnUjJTS7=PHGJ<XJB?MV5NL8RLX91iHe]/
Q9VPTg]QEfAoV:BHPFQNHgbOYib<K5mSN9JSWhU/GUidTjBQT7APG76@XJ>AMV5H
J8BIXi=kIeUXQ9bWV8A[G6AkVJRLQW1OGgJAYYn7KUmPKhnSX8a`GUm/QYjTT7=P
FfN3Vj6FNfMOJ8>NZ9j6Kf5XOiJXX8QaHFMhT:JQS71PH76?Wj2@Lf1NL8bLX8md
Hea/QibQTgQQG6QnV:>DP6QLJGnFXiR6JeaSMY2OVHU^GV=cT:2LS7=PG6b;X:6@
MVALK8RNYYAlJ5maQYbXVGmVGVAlV:BIP6QIHGNAY9b7KUiTN9BTXHmfHF5fSZ2S
T7IPFFj4W:2@MeaHIh2HWiInIeaTOYRQVHI_H6AoUjBPQg1PH7R@Xj>>Mf5QMi2T
YiAiH65cQj2XUW]VG6b6Vj2GOV1IIWbFXIMnIUQQN92SW8M/Ff1gU:NPSWALGgBA
Yj>DMf1PKXbQXiIgIf=YS:BVVGiVGfb6WZRNP6aSJH>KZJB;L6AXNiRXXHmcH6A`
RJ2QS71QGVR3VJ2CN6APJH6FWiIiI5aVNi>PV85XGfQlTJBLQ6aLH7bAXJ28JeQO
L8JLWXQ^E5IVP9RLT7ILEVN0Tib?NfAHJ7nGX9B0IUaVO9JSW8AYG6IiT:6QS71P
H7R@WYnCLE]LKXRGW8maHEU[QiRTUgi[GVj8W:RLQ6UPJ82KYZ6<LFAXOiJTX8Qa
GUmgT:2NRg5IFfn;Win@N6APKhVQYiIoJ5iYPIbVV81[HFV0WjRORfaSIgJFY9j;
LFITNI>SY91dHfQdS:>TUWQSI729W9nFMV5NJ8BGX9AlI5UTO96NUh1XFf5dSinL
R6aNH7B@X:BCMV=TL8bPX9AhIf5^RIRLT7MOF6R0TinDN6AIHh2GWiR0J5iTO9BT
WhQ^G61hSZ2PS75OH7B?WYn@Mf1KK8BLW8ahH5]XPi^PUgaXHFN0VJ2LQ6UOI7VC
XIb4JeaLL8bLVhA[GUa_RijSS75PH7>9XJJDO6MSLHNOYianHf5/Q9RTX8Q^I6b4
VJNSSgMXJH2KZ:B>M6=TN92SWXUdHei/Qi^NSWQQG6b8W:JHP6UQKX6NYiR4IeaT
O9BNW85TFf=gT:2LQfUHFg2<W9b9K5QGJHNLX9AhHea/RJ>WVH1YHFb8XJROQfaQ
IgjIYYj4LEmPOY2QX8Q^GV1cS:2LRGAOGWB;X:BDO6IQL8^PY9B0Jf5/QijQV85Y
GfIlU9bHPFQOH7B<VIR7K5]PLHRIUhM_FeU_R9VNSgIPG6R3VibDO65LI7nGX9Mk
I5aSO9BTWX5[GV=kT:2IQ6aKH7B<XIn;Mf1PLH^QXi5fHf1`R9nTU7UTGf^3V:BL
P6aPJhBKYYb9L5iXO92SWX]aHfQdSibKS7APHG68X9n?MUaPK8>IW91gG5UTP9VN
V7iTG6B0V:2KP6iOH82CX:>6L6=SO9JVY8mkIfN0TJR[U8=[JGb?ZjbPR6i[M8bQ
Z9n8KVMcQi^PVHAWG6AhT9bFQ6UKH7B>W9V9KUULK8RLVHacGUaWPiBDRfmNEfAl
SiR9LEiDH7N@Vi1lIUQPNI>OW8A/GVAhTjBPRgAQI7JAXJ2@L6=SL8jQYY1gHeU/
Q9VTUWaQG6V0Uj2HOVAKHgjDX9n4J61TO9JTXhifHFQkU:RWTgQSGg6<X:>FN6=N
JhRLX9MkI5UTO96LTgmWF6IkTJ>HQ6aOI7RFY9^8Kf5PLhjPX8mfH61cRIjPSWIP
GVj4W:JGP6MSL8NPZ:2;L6I^PijXWhU`HfQlUjRPS71TIWNCY:J@LfITMXbOYiAg
HF1`PIRPTG]PF6R0UYjFO6AHI7^DWiR3IeiSN96OWXI/HF5gT9nOS7AQHG27W9b>
M61NK8BHX9IhI65XPibSV85YG6N4UZ2PQVmQJHBIZJB<MUmTO9>VY8idH5iaS:2T
TgaVGW6;X:NHOVMQK8ROZ9V4KV1/QYbYWXA^HFQoV:BKR6mNHG><WYN4K5aOKXBH
V8UcH5aYPI6HS75PFfMnU9n@NfQNI7bFWYQoJ61QN8nPUgm[FEm`RInGQ6aKGVR6
ViN<KemSK8RIX91`HEm[Q9NLTGINEfAlU9nHP6MLHGbDWY^0J5aPNI2SWhU`G61d
SZ6QS75PGWB>WZBDO6IPLHbQZ9^4KfAcR:2[WhQ/H6b4WZVQR71QJGnGYYb>L5iT
M92QVha^G5][Q9VNSg5LF6MnU9nAM5mKHgbHWiQoIf1[PIRTX8I^I6=nUjBQQfiO
GgB<Vij;K5iNKXNKX8mdHea[PiBNTGQTGVV1Uj2KQ6UQKh>GXib3KfATO9BOWhaa
GV=kSZ2TS7AQG72<Wj6AN65OLHVNY9AoIUa/PIbVV8AXHFb1X:BPS6mXK8JLZ:R@
MfATO9RVXi=kIV=dTJRTU7]THfj8Y:6HO6APIhJLXiUlI5aTOYVPV81QE5igTJ2I
PfQIG76?Wij<Kf1PL8^SYY1gHem_R9jTU7aTGVV0Vj6HP6QQJH6IY9b3K61TO96T
XHA/H6AdS:2QSg5NI7N;X:>@MemLK8NHW91hH5aXP9JNT7iWG6b3V:JLQg1QJh2K
XiR6JeUPM8nPV8M/FF1cSYjPSgAQGVb7W:2>MV1HIh2IXIAkI5UXOiRTVh=/G65l
TJBNQVaHG7N>X:>;LeiPM8VOXI1hHf1cRinTU7UQG6j4W:>GO61LK86IXiAnIUUT
O9JOV8=XF5idTJ6KQViOH7N?Y:J?M6APLH^SXiAlHEm`R9nQU7UTGfV4X:BKPfQN
Ih2KYj27Kf1VO9RXY8icHF1dT:>TT7MQH729WZ2AN6=OK86HXi=iHeaYOiJOUX1X
G6QoU:6KQ6QLI7RDY9n<L5mTN9>TXHmcH65aTJBQUgQSH72;WZ>GN6QOIhJHY9ao
JF5/PIRQVGmWG65kU9nLPfUKGgJAYZ>;M6AOMXjTYi1dH5m/Q9bPTgQPF6AlUYbD
Nf=GH7bDWiJ0Jf1TO9JQVhA/Gf1gTJ2SSg5QHG28W9b<M61PK8JKX91gH5]XPiRL
T7USFf1lUZ2GP6ULHgbCXj2<L61TN9BTX8aaH5mdS9nPS71NFf^6W:6@M61GI82G
X9QiHeaTO9JTW8=^GfIoU:JPRFmNIWVAXj2?MVAWNI>XZ9QlJ6UgT:RXW85XJ7B>
X:ROPFUTKXNNYij6L6=[Q9NTWXM_G61kT9bLQVQIF6b7W9n9Ke]LKhNNX9=iHeQ[
R9bTUh1WGV^1V:6GOfMKI7jHWYR4J5aSO9>TW8A/F5UaSYbPS71LF6V8W9V?M5mG
I8BHWi1gI5mYQ:2WVhAXH6B0VJBPQVaPH7NCWib4Je]HLHbLW8]aGV1`S:NVU7mX
I72<Y:JGO6MOIX2IX9MoHf1WO9>PWhAXGf1hTijHQ6UHH7J?XJ2<L5mPLhnTY9Ah
Gea/RjBXVgaWH6b8WjNLPfAHIX>KYin4K5iWP9bWW8U`GemgUjBNR6mNFF^9W9n<
Lf1HJhJNXi5hHEa[Q9bVVH1XG6AoUj2LPFQKH7^@YZ29LemTNiBWXhmfH6AgT:VS
TgQPHg2;Y:RGNfALIh>KX95hGeMSO9RSV7mTG65hUZ2NRFaOHgN@X:29KeaLLh^L
WhifH5iaS:2TUh1XHg6<YjbLQfaWKXBQY9j4If1XP9NQW81SF5afT9bOR6]KFg2<
XJ6?MUmKKX^PY9AdHeaXQYbWVGmYH6b3W:bLP6]LIgjGZ9j;KUaSM9BXWha/G61a
SjBTS6iLFFV8X9n?M5]HI8>KXiAgH5ASP9RXX8I[GVN0W:ROR71OH7RAXIb6JeQN
KXbPWXa`G5]/R9VPT75LE6J3V:6@M5iHI7nGX9R0I5MTOYBTWXM[F6=lVjRTT71P
H7BDYjB@M61NLhjSYiAhHEi`Rj6YVgmXG6n8W:^IPFMGHgjIYYb9K5QTNINXXHi_
GUadU:BTSW1LG6b<Y:JAN61KK8BTYY=oHEQXOibVU7mQF6IkV:BLQ6UNIWbHXib9
KUaTLhnPWY1_GUa^S9bTTGASG6n;X:^GNfALKhBLZ9UnHEQXP9NTW8=TEV5hU:>O
QVQHG7B>Wij8JeIHLhjPXI1dFeQ/RIbWV7MVFfV8W:^LP6aIJ8BNZ9b7JE]TOi^[
X8M/G5ihU:NLR6mHH72>ZJRDN61OL8nVZ9MhH5UWPinVU7ULE61kV:BKP6=GH7RF
Y9b8J5MLM92QWh]/FEicU:JTTgANGW2<XjRGO61IJ8JOY9UoHeQTOiVTW8AXFFB0
VJRLQfaIG7NFY9b8K5]KL92WYXmfH5U_RJ>WU7QQFFR4WjVFOV=HJ82PZ9b0IUaQ
OYjXXHQ[FF5iU:RPR71HFG2@Y:2@LEUIJH^PXI=fGeMXQ9bTU7QPEVB1WZRIP6QL
I82O[:R<KV1TNiBXZ8a`FF5fS:>PS71LFfb8X:>CN5mKJHBOYiMlHeaXP9^WVGiT
G6AoVjNNPfMLHGRGYZ2<K5QOMY2QXHi_G5Q/S:6VU7=OEf^9X:^INF1KJH6IYiQl
I5AQPIVWWh=WFF1nUjbXS7MLH7bF[:R@MUmPM8nVY9AcG5][R:2VUWINF6J4V:>F
NFAFIh6IYYR1J5]TOYbXX8]/G65kUjVVS6iKG76AZ:NDM5iLK8^TYiQgGUaXQ9nX
W7UPEfB3VjNNP6=GH7bKY9b7J5MIN9BVX8I/F5I`SZ2PQVaHD6R6WjB?MeiDIh2L
YiIoI5UXP9bTW81XG6=oVjRQR6UNI7^GZ:B8K5aKM8nPY91`G5Q/Rj2VU7QQF6b<
WjBIO65HIhBLYiV0IU5PNIRYWXITEemiVjRXSfiNGgRDYjRCMV5PMYB[[i]lI6=`
SZB[VGUTFf^6W:RKO6=GI7nGY9R0HeANMiBTX8Q/F5Q`T:JTRg1IFfb8XjJAM5UI
J8>QZ9QlHeaXQ:2[W81XGVN0WjnSR6ULHgRHZJB;JE]PM96QXH]XEUQ/QijPSg1G
F6N4WjNHNF5LJhBP[:23I5QWOiRWX8QTEV1hV:JQSfUFFGBCX:>>KeQFK8^PX8mc
FEMWQj6WUgQPG6R8YjnOPFAHIX>LZ9j3IUMNNibVXHQXF5]dUZRPRfmFF6n>Y:6<
KUIGJ8VSXi=fG5AWR:BXVh1QF6N4X:VPPFQHI82Q[jJ<JeaPN9NYZ8i/FeacT:BX
U7APGgB@Z:nIO6IKKX^S[YUkHEUQO9^VVH1PDEadT9nIPfAGFG2<X9^1J55GK8RQ
XHmdH5iaT:N/VGaSH76<Y:jNP6=HJ8BPZIb0I5AQOiVXX8MTEU]cU:BOQf]FE6n<
XjJ@LEIFJ8NPX9=cG5MSQ9bVU7QPE61nV:BIO61HI7^HZ:24IUMLM9BWX8U[EUad
UZ^[V7ALG72@ZJVGNf1HJ8RSZ9akH5]XQ9n[Wh1TF6R1WZjQQVQLI7nLZjB8JEQN
N9>WYh]^EeQ`S:BXT71HEVb8XJ^HN5aDIhJNZ9j0IUMVP9b/WXU/F65lW:jVSW5O
I7VL]:nGN61OM9B/Z9AhGUMXQYnTU7=IDemlUij?N5iCGgbKYZ24I5]ON9>VWh=X
E5a`S:6PS6QCF6n;Y:BALeIFK8RNXiQgFEAWQZ2XWX1PF6N6Wj^TQfaLJ8JQ]:V@
L5iSO9^YYi1`EUadTJVTTg=KF6R@YjJINEaHHh6PYYQhH5AQP9^WV81TE5mhV:BL
PfIDEg>CYYn6JEMIL9>WY8m_GU]_Sjb_VgaSGVj;XjVLOfMKJHBT/:67J5aXPinc
Z8Q^FFAlVJnVSg1KG7>AZJRDLEQNK8^SY9=cFeAVPijXU7MLDf1kVjJDN5U?GWND
Xib1HeAIL9BTW8QVE5Q^TjNTSfaHE6b@Y:VDL5aFJ8RPYYAhG5MWP:6[V7aSFF20
X:VPPFIKHGbIZjB8J5QOMiRYZI5_G5ifU:b`WWQPG6n@YZjLP61DIh>LZ9aoI5AP
OiRTW85SD5afU:BNQfQ@Eg>AY:>@K5QGJhnQZ9AdFe1YQj2WU7aOEfV6Xj^KP61F
IX6Q/:B7IeQOO9b/YhacG61hV:jXT7ALG72@ZJRDMUiHJ8VTZIAdH5QTPJ2XUWAK
DEakVJROO6=DF7VFZJ64I5=HLI6XYha^FeQ_T:BXTGALEfj<Y:^GMUiFJ8bX[Z23
H5Q[R:N`Y8MWF6>3XJjWRFIIGWRL[:B>LEMLMiB_[91aG5QXS:BYUWIOF6V4X:bH
N5mFI7jL[9n0H5APN9R/Y8AVE5aiU:RTR6QAF72?YZ>>L5MFJ8^PY95`F5ATPijV
UWQHD660W:RLO61FG7bLZJJ7J5MOO9R[Yha^F5aiVJb[Tg1HF6n?YZJ>KUA@I8JP
Y9=dF51SPIn/VgaQE65lW:jSPfIGG7NI[ZB;K5QPMYN/Z91/EUU_SjRWTg5KFfV<
Z:^FLe]CHh6KZ9]kG5=PO9j[X8ATE5UfUjVVR6aHG7JG[:N@Lf1NM9>XZI1aFeQY
R:6VTg=HE6B3X:RKO5mDGgbLZ:20H5AONiV[YX]XEU]aTJNTS71KGWBD[:nDN61N
MYB_/Ib0Hea[QjBYVgmSFfN0Xk6PPf1DHGbL[jJ;JEMOMiV/Y91YE5Q^RjBTSfiA
E6R8WjJGLe]FI8JPZ9anH51POiRXXH=QEUiiVjRPQVQDFgRDZ:N;JeMDKi>TY8m`
F5=XRJBXTGAKE6V9Yk2LO6AKJHRT/:>4J5QXQ:2aY8U/EfAnVJnTS6iHFgBDYj>?
LEMHJhVXZ9MhH5QXR:N_WgiTFFJ4XjnOPFA@HGbK[j>4I5ALMYN[YXQVDEA/T:NW
T71CEfb8Y:JCM5]DIXROZ9ihGUISPin[X8ATEfB0VJVTQ6QHGgjL[:R>K5ULMYN[
YhmcFEQdU:R^VGQOF6R9XJNFNf5DI8BQ[9MlH5=NP9b/X7mQDeadTjNPQVIDFg6D
Y:J<J5UFKi2TZ9=dEUA[Qj6[V7QLE6J3X:RHNeaCG7jLYY^0I5AONiR[X8MXEUac
UjNSSfaHEg2AY:bCMV1DJ8nWZIQiGeATQ:2/V7aSE6AnW:jOP65HGWNHZjJ8J55I
MY>[Z8m`EU]aT:RYV7AIFFb<YjbLOV1KK8^V[:1oH5]VQ:>`Y8ATE5]iVJVTRFIG
FGBHZjR<KU]KM9BX[9A_EeQ[RJN/V7ULDFN7X:^KO5]DHgVLYiQnG55LM9BSW85P
EUU`TJBOQVUDEg2>YZB@KUQKK8bWYiMhGem_SZR_Wh1XG6R8X:^OP6MHHgbLZib4
IUINMYNTXHaYEUM_T9jOS6aHDFV8WjJAMe]AJ8JOZIQiHEMTPI^YVgaQCeihTjNL
Pf=@G7RC[:R<LEUQN9Rd[9ahGfAdV;2cY81XH7BF[;JTPFQNK8bY/:67IeATOib[
X8QSDEQaTjBLQ6UDF6n?Y9n<JeMKJHjSX91/F55SQibTU75HDfB4WZRLOeiDHgnL
Zin0HeALO9^XY8UVD5QaT:JTS6aCE6j>YjR@KeMCHhRSXIIhEe=TPj2^X81SEeb0
X:RQQV]KH7jL[:>8JEQHM92XZ8Q_FeQcT:j[TgIIF6j7Y:bGOUaKJh>X[Yj3HeMP
OYjWWX5PE5afUj^SRF]FGWRDZJV@K5ULKi6XZ9AcFe]`SZJ/VGQLE6R9Xj^NOV1G
IXRS[:64IeIOOYV/Y8I[F5afU:VVS6iFF72<Y:B@KeUKJHVTYiAfG5ITR:2XW7QN
F660WjVPQ6QHHH2KZJ>6J5QPN9^^Y8i_GeidUjRXTgANFFb;YjbHM5UDI7nLYY5g
F4iLN9RPV7]ID5UhW:^SQVUFFgRF[:^@KeQOM9B[[9QfH5i`T:J`W7QPF6b6XJjK
O5mDIXBNZJB4HeAOO9NXX8ATD5]hUZBOR6M?E72<Y:>8KU5DKhVTYY1`F5ITR:JX
V7QLE6B0WZVKOUaCI7jOZj67IUMPO9b`[9=`H6AhW;2_V7QVHGVDZk2FMUaLK8VT
ZIQgG5AVPib[W7aPDF1nV:NPQVADG7RFY:28JEAKM92XYhi`FEM/S:6WUgQLF6R4
X:RKO5aHI8BPZ9j1HeASOibWWX=SDeQgV:RNQfUCFg>GZJR@K5]IKY>TY9I`F5QX
SjBXV7UNE6>1X:NKNemDG7nLZj>1J5ANN9R`Z8i_EeigU:jXT6mGG72@ZJRAKUAD
J8JPYiIfF5=TP9bWV7UKD5ihV:BLP61CH7bK[ZN<Ke]QMYR_Y95dF5mcTjRWUg5I
F6R>YZbNOf=HJHVV[j27J5QTQ:B_XHQ[FfAoW:jTRfiKH7RGZjB;K5UKL8nSY8aY
EUAVQZ2VSg1HDF>0W:RHMemCHH2I[9alHE=NN9V[X8ITDEUdTjRXS6iHFgB@Zj^@
LeUGK8bVZ9IhG5QXQj6WU7IICf1lVJJHO5iDGWRFZ:26IeMOMiR/YXa_G5ihTj^/
TGMNG7BC[:bGMeaFJ8bV[9anH5ITQ:2/WX1WEeinW:jSPfQGFgRG[jR9KU]LM96Y
[95aFeQ^S:NYTgAKE6V6X:jHO5mDJ82P[j23HeQQO9^/Z8QVF61hUZ>TSVQDF7>?
WjB<K5ICK8bTZ9=gG5Q^RjJXV7QNE663WjVLO5aAG7bLZJ24I5ALN9V/Y8a[Feah
W:j/UgMPGWJFZjbFMf1IK8^WZIIhG5MWQZB/W7aPF6>0X:bOQ6IFGgNDY:26IeMH
Ki2SWhQ[E5MYQijPRFaKE6J6X:NHN5aKJ8BQ[ZB4IemXPIj/Y8ITF5ihU:JTR6QD
G7J@ZJV@LEQLM92WYiQgFea^S:VYW7aPFfB<ZjjSP6=HH7jKZ9aoH55LN9VWXhQW
F5mgU:RXT71NHgJG[jbKNF5PMYBX[iihGeUYRJBYW81PD6=lVjVKP61CG7BFY9n4
I55GKhnPX8QXE5I/S:6TSg1FDf^8XjRFMeaDHh>PYiMhH5=TOi^XWX1SF61kV:JL
Q6AAEWJCXj>9KUMIL92[Z9QlHF1`T:R[VGUQFFV9YZ^LO5mHHGbGYY]hGe1HMYJT
WXASCeQcTjJOR6iGF76CZ:RALeiIK8nX[9UkGUQ[QjJ[W7UPG6N8Y:^TQ6AGGh2L
Z:B8J5MNNIR/Y8a/EUUcTJRWTG=KF72>Z:RCN5aDIXNTZIMiGeQVPj2YVh=SE6=o
VJRNQfIFG7NHZ:69JEAHLI2XZ95cFEU`T:R/VGQPG72@Zk>PP6AKJhNQ[:1oHeQS
OiRXX8ATEeiiV:RTS6aCF76?Y:2>KeAGJHbTY9QdFE=TQY^SUWMLDen0W:BIP61F
HG^IYYj6IU=NNIRXWX]YE5mdW:^TTFmIFFjAYZJCM5aGJh^TZ9MhGUAWQ9jXW81V
FF21WjRPQVMDHGbG[:B8KUQKM9BYYXicFE]`T:JWUW=GF6R8XJVGMUiAHhJKZ9]l
H5=QP:2YX8AQD5ilUjVTR6]HG7NHZJJ@L5ULL9BYZIQfG5Q^S:BYV7aPF6J3XJ^H
Nf1CG7bHY9]nG55LLi>XX8MXEU]dU:JTS6aFF6n@Y:BCL5aHJhjV[YMfH5ATQ:2Y
V7QKD65lVJVPOV5DH7nHZjB6I51NMiB/Y8a`F5acTJVYU7QOGW2>YjjKO61OK8JS
ZIb0H5MVQ9bYXH5WEV61W:VSSVmLI7^K[:J>KUULLI2V[9AcG5U`Rin[VG]LDfR4
W:RFN61GHh2KYiaoI5APO9R/X8AXEUagV:bTSVmGF72@Z:J>L5ULK8bWYiQdG5QX
R:2WV7aTFFB3W:RNOVAHI7jN[ZB8Je]PNib^Z8a/FEafUZRYTG1LG72?Z:VFN5aG
JHJTZIQkGU=TP9j/WhASFFIiWjbPRfQII7VHZjB<JeIKL92TY95/F5MXRJ>VT75K
E6J4X:^IN65HI86HZ9b0I5MTNIRVVhATE61kV:VQS6aDG7BHYjJFK61NK9BYZiQf
GeA[Sj>/W7]PEV24WjBLOV1CH7bHZJ63IeIIMYNYX8MYE5M_SjNSQV]FDfV8XJJ@
KeMFJ8BQ[9UiG5MTP9bXVGaNDfAlVJRQR6AHHgRHZ:B@K5UPN9B[Z9MdGV1gV:R^
WWUQGg6AZ:^LOfAIJhRS[9b0I5MPO9^TUgaODeUdUZ6LPfA@E7B@Y:>7KUAHLhn/
Z9AhG5a^RjR[W7UNF6B4WjNNO5mDHH2HYZ23He=LMYBTXH]YF5adU:JWSV]HE6b>
XjNCM5iHJhVTZ9QkH5MVR:B/WX=QEVAlX:jNQVADG7RHYj20H5AHLI6TXHQXE5I_
S:RYTG=IEVb8Y:bKN5aGIXBQZI^0I5]VPIn/Wh5TE61kUjNTRfaOH7RIZjRAL5aL
M9BX[9MgH5Q_SjB/VGaQF6V4X:RGO61CHGnHY9b0HE=KMi>TVh5TE5]aTjBOQf]G
F72>Y:BALEULKhjW[9QfGU]_R:B`X85PEfR1X:jPR6AFGgVL[:>7JeMIMiNYXHQ/
EeU`SZRWSg1FEfb8Y:RFMeaGJ8RT[j20IeaVPj2YW85TFFAlWZRQR6QKHGRHYjB<
JeaILI6SYi5^G5Q/SZ6[UgIPEfR7XjnKO61FI8>P[:20I5]VPIj/Y8MXF61lUZ^X
RfUFFg6?Y:BAKUAGK8bTZ95cEe5WQ:6XW7aLF65nX:ROQ6AFFgbKZ:J6J5]LN9^/
Z8]YG5adUjR^Tg1LG7B;YjbDM5iHJHRT[iakHEMXQ:2aX85SDFIlVJbPQV=AFGJH
Y:68J5QFL96VY8M`EU5/QjBYT75IEVN6Y:bHN5aDI82N[:20HeQSOj2^XHQ[FfB0
WZbXRf]KG7RF[:N@L5MIKhnSZ9A`FeAXR:>XUWMHD61oWZNGNem?G7^GZ9]oH51L
LiJ/XHUXDe]aTJRTSfaKFFj@Z:jGM5]HK8^SZIihG5QXR:B/W81TEV63WZROQfUH
HGnL[:>8K5]LMYN/Y8a^F5Q/Sj^[Tg=OFFV9Y:jIMeiGI82L[9alH55OOYbXX8IV
EV1iV:VTR6QGFgBDZJR>K5QKLI2YZ9=cF5Q/S:B/V75NFFR8XjjOOUiDI86KYin1
I5INP9^YY8QXDeahU:RTRfmGEgBDZ:JCM5QHJHVTZ9AfFE=WPJ2[VG]LDf20X:NL
P65CG7RH[ZB8JEQNMYR/Z91`F5]`T:^XTG=LG6n<YZ^DMUaGJ8BSZ9QkFeITPJ>/
X8AWF621X:bSQ6UFG7NF[:B7JEMHKXnWY8i[E5MXQj2WTfmHDFB3W:RHNeaHIX>P
ZIj1IeQQP9VYXhIWEeahV:RQS6UDF6jCYjB@KeMDK8bSZ9AdF5MXRJN/WWmPF6V8
Xk2TQ6MHI8>P/:N8JeQPO9R_Z8a/F5acT:BVT6aFG6n>Z:RHMeaHKhnX[in0H5IV
Q:B/WX5PDeigW:JLQ61@E6bGYjJ9IUQFL9>V[91/G5]^T:V`VGQPFfn?Yk2PO6=I
IXRQZ9ioGe5NP9^[X7aVEU]kVJbVQfQDF7BDZjN8JEAAK8^TZ8m_Ee5WQZBXV7MI
EfJ6Y;2PP61AGh6LZj66I5=OO9V^YXU/EUUcTJRPR6mDF6V8Xij<JE5CH8JSY9Qg
G5QXQZ2^Y81WFF61W:bSQfACH7VHZ:29JeAKM9BXY8i_F5Q^TjVYT71LEfb<YjbC
M5QCIhJT[9QhG5AQOZ2/X85PE5iiWk2XRf]IH7bN/Jb?KUMIMYB/ZhmcF5I`S:NY
UWAHDfB6Y:VLOUaCGWnP[9ioIUIONiV[Y8QVE5icT:NSRfiDFG>@YZJAL5QHK8jW
ZIMhG5MYQ:B[VgmLF6R6XJbPOf1AG7bKZ9j7He5LMYV[XhQXE5AaU:VXTfmHF6b?
ZjnLN61IJH^T[9ifH5QTPIn_XH1SE620W:bXR6QIH7bL/:b<Le]LO9Rc]9AhGUUc
Tjn/UgQHE6>6YZRHN5QAFGnNYiQfGU1GN9NTWh1VF5UfV:bWRf]GGWNF[:jHLEaI
LI6W/9M`FeAXRInYUWAGC6B0W:bNOV1>GWjN[:26Ie1ON9R/X8QYE5acU:bXT75K
Ffj<YjN@L5QKJ8RTZ9QhG5AXQ9j_WX1QE6AnWZRPPF1DFGRFY:>8IU5HLhnSXHa/
EUUdTjV/UgIOG6n<ZJjKO5aDJ8RT/:>3H5ATP:B_X8ISE5inWjbVRfaGGWRI[:J<
L5QHM9B/[9IdFeQ/S:RYTgAHDF66YjbHO61@I8BQ/:63IUAONIRXW8ITD5UdU:RT
QVMCDfb>Y:B?K5=DJ8NVYY1fFE=WR:J^W7QNE620X:bPP61@G7RFZJ23J4mGMi6X
Yhi[EU]_SZJVT6mFE6^<Yj^GN5QCJ8JNYYaiFe=NOibTWh1SDej0VJ^VQVMCF7BH
YZB?KeQHMYBY[91cFeQ_Sj^/V7UPF6^;Z:jLO5mHJ8BW[:20HEMPP:2`Y8IVEf1i
VJbVS6aDF76C[:R@LEIDJ8^YYiMfEUATQZB[W7aQF6B4XJVSPF=IHh2S[ZJ6JeUL
Oi^/Z8IYE5A`T:RTSV]DF6b;Y:V@LEQ@J8VPZI]hG5IWQ9j[W7iPD6=oVjbPQ6AD
G7VIZ:>8J5AHMY6XYha/EUM_T:RXU7MLF6n>YjbLOV1IJ8bX[Z24I5QTP:6/X8=V
EUalW;2WR6UDFgBD[:R<JEAGKY2[ZiA`EUAYRjJYUWQKDF>4XJRHN5iCGWnKZIin
He=LMiN^XhAVDeQ`T:RWRfQHFFjAZjVCL5QHLI6//IahH5UXRjV`X81OE6B0WZnP
Q6AGI7jO[ZR;IUQNN9^[Z8m[EUIaUZV[U75LEVn@Z:bHO5iDK8bX[YanGeAPP:B`
Y8=QEUmkV:bWQ6ICFgB@Z:B;J55GKi2TZ95^EeI^S:R/U7AHE6R8Y:bHMU]CH7jP
[iinGdiKN9J/Y8=TD5]dU:VPRfQ@F7>DZ:^?Ke]GL92[[YIgGU]_S:R/V7QLE6B0
VjBLN5aCG7J@X9QkFdiHM9>SW8AQC5AcTJBTSVaIEfn@Z:bGM5mIKi2Y/9moI5QX
RJNaWh1TEfN3Y;6VQVMKH7^I[:R>JeAKN9NXZ9=/E5M^T:NXT71HD6R8X:bFMe]A
I86QZIaoFe=QP9j[XHATD5ilVjbTR6IDFGJIZjN>K5QHLi2YZ91dFEQ[SjVYV7IL
EfN8Y[2NO6AIIhBP]:B0IUAOO9n`Z8QTDeUfTJ^YSW1DF7J@ZjbDM5IGKXRWZ9Qg
FeATR:B[W7aQE660X:nQQ65DFgRKZ:23I51DLI2VX8AXD55_S:BTRFmHDfR8YZR@
L5A@Hh6PYiMgFE1TPIj^Wh=TEVJ0W[6VRFUGGWNK[:B@K5ILLIB[Zi=_FeUaT:R/
U7ILE6^<Y[2LOfIIKXRX]ZB8IeQXQ:2`Y8QVE5ahV:RPRfUDF72DYZN@K5QDK8jV
ZiAdFeMWQZB/VGINFFN7XJbPQ61FI82LZ9n1I5=HMiBWXHQVE5]`U:NTS6]HE6n@
YZnGN5aHK8bX/9]lH5MWQ:B_WgiOE61oVjbQPfA?G7RH[j><Je1KL96[Yhi_EeQd
Tjb^Ug=HFF^<ZjjLNeaHJ8^W[9ikGUAPPj2XW7iQDEQiVJRNP6A@E76DZ:>8JeAF
K8jXYi1`FEIXS:J[UgAKEVN7Y:bONf1HI8BT/:B6J5]TP:6aZ8QVF5QaU:JTR6QD
Efb<XjJ>JEADJ8^TZIAgG5MYRJJ[W7aOE6B6X;2QPFAFH7RL[Z28IeAIM9BTXhaY
Ee]`TJRWTFaIF6R?Z:bIMemHJHVW/9ilHEMTQ:2`Y85SEV=oW:bSQfMDG7RFZ:J;
JEAHL92[YXa_EeQ/RjJWU7=HEVN8XjVKNEaHI82SZI]lGeAPPIbXY85NDE]hV:bV
R6MDF7BD[:b@LEaOLIJ`[j1hH5a/SZB/VgILD623WZVLOUm@H7jN[:N;J5QLO9^/
Z8a/EeifUjR[TG1LF7>@ZJbDN5iKJhRWZ9QgF51SQ9nYW7]LCeaoVJRNP6M@FGRH
[9n6J5=LLI6VXHQWDeIYR:BTSfaCEfN8Y:RHM5MDHhJNYY]iGeAPP9j/X81TEf5o
WZnWR6QFGWRFZJV?J5AHLI6XZIIdFEM`TJR/V7ILF6N8Y:jINf5DI82N[:21I5QT
OYb_Y8MYFf5kVk2XS6]HGW>G[:bDL5QHJh^VZIIaFEMXQj2^Vg]PF6R3X:bNPF1D
HgnL[:B8JeUPOi^^Z8a`FEihUZVYT75KEfb8Y:RCN5UDJhBQYYIiGUITQ:6YW7iQ
Ef1lW:^LP6ADFGBFYj66HEAGLhnSYhUXDeA/S:BYU7=HD6N8WjNFN5a@HH2LZ9Ul
H5=LO9bVW8=SE5]iVJRTRf]IG76FZjR@Lf1NL92Y[9MdGUa/S:R/W7aQF6B4X:bP
O65HGWjNZIn0IeALNIJXXhQ[FEigV:b/Sg1LG7BD[:V@M5aHK8^Y[9QkG5IYQjBY
V7]KE65nX:bLP5m>FgRKZ9j6He=HLIJ[Y8mXE5Q/SZNXTg1FE6b9Y:bGM5aGJ8RT
[9aoGeAPO9b[WWiSDEahVJRNQ6ADG7BDZ:68K5QLM96Y[9AdG5i_RjV/VGQNFf^7
X:bLOf=HIh>O[:21IUQQO9b[XHMWE5mkUjRVS6QDEW>@YZN>KeIFK8VTY9=fFeAW
R:2XVGULEVB4X:^PO61DGgbL[Z24I51LMYBXY8]XF5Q`UZVXTg1IGW6>Z:bDM5aG
JHbV[9ahH5aYR:BaXh=XG6V6XKBXR6UIH7VHZjN<KUUNMYB[Z8m^F5A^T:JWT7AI
E6V;Z:bKNF1KIXJQZ9alGeAPO9RVW81TE5mlVJ^TR6UDFgBI[ZB>KeAGKY2XZ95`
FEAXR:2TTgIIDf24XJ^KOfAGI82LZj24I5QSO9b/Y8a[GV=kV:RXSVmIF7>@X:J@
LEUHKhVTYiAdG5QTQYbTUgANE620V:BKO61FG7RDYj>4J5MKN9N[Yha_F5UaT:bX
SViGEfV9YjbDLEiFJhVS/9mlGUMXPInXW81PE5n0W:^VQVQGF7RGZ:J8JeMFLi6V
[91`FEA^RjBXTgAHDfN7Y:RFN5iCI8>KZiUkH51QOY^/X8IXEV1oVk2XTG1KI7VH
ZJNDLeQNLi>XZ9QhGeQ[SjB[VG]PDF>4WjRHNF5DH7^IZ9b3HE=HM9BSWhATE5M`
T:JTSg1HEg2AYjNDN5iHKXbVZiMhGUASPij/WX1TDen0VJRPQVUGH7^L[jJ9KU]O
NiV_/9AdG61gTJ^[UgMKF6b<Y:NFMeU@HH2LY9AhF4iLN9RSUWiND5QdU:>KP61D
F76DY:>?KeaNLI2WZiIdHF1cSZN/Vg]SH6j<Z:bQQ6IPK8bW/JJ6J5UTP9b[XhQT
EeUdUjRTR6]FE6b9Y:B<KUAAJ8JTYY1gGUQVR:>WVGUPEV5lVjRKOfAFFgNGYj26
J5QOLI>VX8U[Fe]`U:RVSfmIG72?Y:VHLeaFIhJPZ9QhG5AVP9^XWX1P\>"]},
  ImageCacheContents->"Sound"]
}, Closed]],

Cell[CellGroupData[{

Cell["FFT of the data", "Section"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.000232515 0 0.618034 [
[.25632 -0.0125 -12 -9 ]
[.25632 -0.0125 12 0 ]
[.48884 -0.0125 -12 -9 ]
[.48884 -0.0125 12 0 ]
[.72135 -0.0125 -12 -9 ]
[.72135 -0.0125 12 0 ]
[.95387 -0.0125 -12 -9 ]
[.95387 -0.0125 12 0 ]
[1.025 0 0 -6 ]
[1.025 0 58 6 ]
[.01131 .12361 -18 -4.5 ]
[.01131 .12361 0 4.5 ]
[.01131 .24721 -18 -4.5 ]
[.01131 .24721 0 4.5 ]
[.01131 .37082 -18 -4.5 ]
[.01131 .37082 0 4.5 ]
[.01131 .49443 -18 -4.5 ]
[.01131 .49443 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -29 0 ]
[.02381 .64303 29 12 ]
[.5 .63053 -65 0 ]
[.5 .63053 65 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.25632 0 m
.25632 .00625 L
s
[(1000)] .25632 -0.0125 0 1 Mshowa
.48884 0 m
.48884 .00625 L
s
[(2000)] .48884 -0.0125 0 1 Mshowa
.72135 0 m
.72135 .00625 L
s
[(3000)] .72135 -0.0125 0 1 Mshowa
.95387 0 m
.95387 .00625 L
s
[(4000)] .95387 -0.0125 0 1 Mshowa
.125 Mabswid
.07031 0 m
.07031 .00375 L
s
.11682 0 m
.11682 .00375 L
s
.16332 0 m
.16332 .00375 L
s
.20982 0 m
.20982 .00375 L
s
.30283 0 m
.30283 .00375 L
s
.34933 0 m
.34933 .00375 L
s
.39583 0 m
.39583 .00375 L
s
.44234 0 m
.44234 .00375 L
s
.53534 0 m
.53534 .00375 L
s
.58185 0 m
.58185 .00375 L
s
.62835 0 m
.62835 .00375 L
s
.67485 0 m
.67485 .00375 L
s
.76786 0 m
.76786 .00375 L
s
.81436 0 m
.81436 .00375 L
s
.86086 0 m
.86086 .00375 L
s
.90737 0 m
.90737 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(frequency) show
117.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.02381 .12361 m
.03006 .12361 L
s
[(0.2)] .01131 .12361 1 0 Mshowa
.02381 .24721 m
.03006 .24721 L
s
[(0.4)] .01131 .24721 1 0 Mshowa
.02381 .37082 m
.03006 .37082 L
s
[(0.6)] .01131 .37082 1 0 Mshowa
.02381 .49443 m
.03006 .49443 L
s
[(0.8)] .01131 .49443 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .0309 m
.02756 .0309 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .15451 m
.02756 .15451 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .30902 m
.02756 .30902 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .46353 m
.02756 .46353 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .58713 m
.02756 .58713 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -90 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(amplitude) show
117.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.5 .63053 -126 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(FFT) show
87.000000 13.000000 moveto
(of) show
105.000000 13.000000 moveto
(Recorded) show
159.000000 13.000000 moveto
(Sound) show
189.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .00568 m
.02404 .00034 L
.02427 .00029 L
.02451 .0005 L
.02474 .00036 L
.02497 .00049 L
.0252 .00058 L
.02544 .00046 L
.02567 .00023 L
.0259 .00019 L
.02613 .0004 L
.02637 .00013 L
.0266 .00034 L
.02683 .0013 L
.02706 .00079 L
.0273 .00132 L
.02753 .00146 L
.02776 .00192 L
.02799 .00118 L
.02823 .00191 L
.02846 .00053 L
.02869 .00069 L
.02892 .00357 L
.02916 .00155 L
.02939 .00218 L
.02962 .00379 L
.02985 .00118 L
.03009 .00325 L
.03032 .00371 L
.03055 .00315 L
.03078 .00141 L
.03102 .00199 L
.03125 .00179 L
.03148 .00174 L
.03172 .00556 L
.03195 .00211 L
.03218 .00179 L
.03241 .00154 L
.03265 .0016 L
.03288 .00277 L
.03311 .00524 L
.03334 .00266 L
.03358 .00253 L
.03381 .00339 L
.03404 .00454 L
.03427 .00383 L
.03451 .00628 L
.03474 .0038 L
.03497 .0026 L
.0352 .00436 L
Mistroke
.03544 .00362 L
.03567 .00107 L
.0359 .00083 L
.03613 .00116 L
.03637 .00235 L
.0366 .00355 L
.03683 .00368 L
.03706 .00283 L
.0373 .00056 L
.03753 .00391 L
.03776 .00082 L
.03799 .00687 L
.03823 .00502 L
.03846 .00293 L
.03869 .00108 L
.03892 .00573 L
.03916 .00316 L
.03939 .0023 L
.03962 .00252 L
.03985 .00131 L
.04009 .00185 L
.04032 .00401 L
.04055 .00405 L
.04078 .00124 L
.04102 .00396 L
.04125 .00067 L
.04148 .00069 L
.04171 .00427 L
.04195 .00565 L
.04218 .0012 L
.04241 .00297 L
.04264 .00164 L
.04288 .003 L
.04311 .003 L
.04334 .00463 L
.04357 .00188 L
.04381 .00184 L
.04404 .00432 L
.04427 .0052 L
.0445 .00083 L
.04474 .00488 L
.04497 .00273 L
.0452 .00241 L
.04543 .00166 L
.04567 .00233 L
.0459 .00228 L
.04613 .00232 L
.04636 .00397 L
.0466 .00254 L
.04683 .00162 L
Mistroke
.04706 .00572 L
.04729 .00174 L
.04753 .00292 L
.04776 .00179 L
.04799 .00027 L
.04822 .00335 L
.04846 .00464 L
.04869 .00351 L
.04892 .00565 L
.04915 .00541 L
.04939 .00334 L
.04962 .00295 L
.04985 .00295 L
.05008 .00105 L
.05032 .00313 L
.05055 .00422 L
.05078 .00286 L
.05101 .00167 L
.05125 .00192 L
.05148 .00205 L
.05171 .00188 L
.05194 .003 L
.05218 .00311 L
.05241 .00309 L
.05264 .0052 L
.05287 .0034 L
.05311 .00414 L
.05334 .00264 L
.05357 .00074 L
.0538 .00253 L
.05404 .00361 L
.05427 .00465 L
.0545 .00352 L
.05473 .00091 L
.05497 .00295 L
.0552 .00303 L
.05543 .00445 L
.05566 .00303 L
.0559 .0022 L
.05613 .00366 L
.05636 .0034 L
.05659 .00255 L
.05683 .00209 L
.05706 .00179 L
.05729 .00419 L
.05752 .00672 L
.05776 .00218 L
.05799 .00137 L
.05822 .00301 L
.05845 .00312 L
Mistroke
.05869 .00246 L
.05892 .00158 L
.05915 .00339 L
.05938 .00557 L
.05962 .0043 L
.05985 .00381 L
.06008 .00345 L
.06031 .00256 L
.06055 .00084 L
.06078 .00031 L
.06101 .00425 L
.06124 .00278 L
.06148 .00385 L
.06171 .00547 L
.06194 .00215 L
.06217 .00099 L
.06241 .00339 L
.06264 .00139 L
.06287 .00314 L
.0631 .00273 L
.06334 .00058 L
.06357 .00224 L
.0638 .0042 L
.06403 .00242 L
.06427 .00182 L
.0645 .00225 L
.06473 .0026 L
.06496 .00413 L
.0652 .00369 L
.06543 .00343 L
.06566 .00234 L
.06589 .00239 L
.06613 .00084 L
.06636 .00253 L
.06659 .0024 L
.06682 .00217 L
.06706 .0034 L
.06729 .00179 L
.06752 .00238 L
.06775 .00157 L
.06799 .00188 L
.06822 .00295 L
.06845 .00091 L
.06868 .00357 L
.06892 .00207 L
.06915 .00191 L
.06938 .00265 L
.06961 .00012 L
.06985 .00301 L
.07008 .00385 L
Mistroke
.07031 .00107 L
.07055 .0009 L
.07078 .00045 L
.07101 .00316 L
.07124 .00209 L
.07148 .0047 L
.07171 .00215 L
.07194 .0017 L
.07217 .00273 L
.07241 .0019 L
.07264 .00388 L
.07287 .0013 L
.0731 .00167 L
.07334 .00044 L
.07357 .00146 L
.0738 .00284 L
.07403 .00447 L
.07427 .00297 L
.0745 .00066 L
.07473 .00146 L
.07496 .00134 L
.0752 .00248 L
.07543 .00225 L
.07566 .00426 L
.07589 .0013 L
.07613 .00234 L
.07636 .00262 L
.07659 .00279 L
.07682 .00144 L
.07706 .00144 L
.07729 .00058 L
.07752 .00275 L
.07775 .00321 L
.07799 .00279 L
.07822 .0026 L
.07845 .00138 L
.07868 .00192 L
.07892 .00157 L
.07915 .00097 L
.07938 .00283 L
.07961 .00167 L
.07985 .00257 L
.08008 .00019 L
.08031 .00237 L
.08054 .00083 L
.08078 .00105 L
.08101 .0037 L
.08124 .00151 L
.08147 .00191 L
.08171 .002 L
Mistroke
.08194 .00129 L
.08217 .00141 L
.0824 .00084 L
.08264 .00249 L
.08287 .00145 L
.0831 .00046 L
.08333 .00366 L
.08357 .00249 L
.0838 .00086 L
.08403 .00153 L
.08426 .00218 L
.0845 .00077 L
.08473 .00121 L
.08496 .00168 L
.08519 .00148 L
.08543 .00123 L
.08566 .00084 L
.08589 .00268 L
.08612 .00127 L
.08636 .00065 L
.08659 .00274 L
.08682 .00311 L
.08705 .00183 L
.08729 .00017 L
.08752 .00263 L
.08775 .00259 L
.08798 .00087 L
.08822 .00038 L
.08845 .00174 L
.08868 .00188 L
.08891 .00087 L
.08915 .00092 L
.08938 .0004 L
.08961 .00084 L
.08984 .00088 L
.09008 .00058 L
.09031 .00101 L
.09054 .00075 L
.09077 .00158 L
.09101 .001 L
.09124 .00123 L
.09147 .00131 L
.0917 .00018 L
.09194 .00088 L
.09217 .00136 L
.0924 .00145 L
.09263 .00067 L
.09287 .00194 L
.0931 .00133 L
.09333 .00096 L
Mistroke
.09356 .00081 L
.0938 .00091 L
.09403 .00084 L
.09426 .0008 L
.09449 .00236 L
.09473 .00074 L
.09496 .00152 L
.09519 .00039 L
.09542 .00096 L
.09566 .0008 L
.09589 .00217 L
.09612 .00162 L
.09635 .00092 L
.09659 .00054 L
.09682 .0015 L
.09705 .00252 L
.09728 .00124 L
.09752 .00021 L
.09775 .00112 L
.09798 .0013 L
.09821 .00133 L
.09845 .00061 L
.09868 .00196 L
.09891 .00123 L
.09914 .00015 L
.09938 .00144 L
.09961 .00047 L
.09984 .00155 L
.10007 .00209 L
.10031 .00123 L
.10054 .00114 L
.10077 .00073 L
.101 .00051 L
.10124 .00038 L
.10147 .00076 L
.1017 .00178 L
.10193 .00141 L
.10217 .00064 L
.1024 .00103 L
.10263 .00078 L
.10286 .00202 L
.1031 .00162 L
.10333 .00152 L
.10356 .00103 L
.10379 .00092 L
.10403 .0029 L
.10426 .00242 L
.10449 .00022 L
.10472 .00118 L
.10496 .00104 L
Mistroke
.10519 .00181 L
.10542 .00201 L
.10565 .00158 L
.10589 .00039 L
.10612 .00095 L
.10635 .00144 L
.10658 .00148 L
.10682 .00195 L
.10705 .00083 L
.10728 .00045 L
.10751 .00113 L
.10775 .00144 L
.10798 .00144 L
.10821 .00031 L
.10844 .00183 L
.10868 .00078 L
.10891 .00228 L
.10914 .00155 L
.10937 .00088 L
.10961 .00018 L
.10984 .00132 L
.11007 .00046 L
.11031 .00089 L
.11054 .00036 L
.11077 .00114 L
.111 .00171 L
.11124 .00045 L
.11147 .00079 L
.1117 .00058 L
.11193 .0005 L
.11217 .00151 L
.1124 .00102 L
.11263 .001 L
.11286 .00039 L
.1131 .00037 L
.11333 .00046 L
.11356 .00065 L
.11379 .00077 L
.11403 .00034 L
.11426 .00186 L
.11449 .00075 L
.11472 .00203 L
.11496 .00099 L
.11519 .00164 L
.11542 .00091 L
.11565 .0002 L
.11589 .00061 L
.11612 .00068 L
.11635 .00139 L
.11658 .00112 L
Mistroke
.11682 .00062 L
.11705 .00124 L
.11728 .00033 L
.11751 .00106 L
.11775 .00077 L
.11798 .00091 L
.11821 .0005 L
.11844 .00099 L
.11868 .00063 L
.11891 .00121 L
.11914 .00073 L
.11937 .00049 L
.11961 .00097 L
.11984 .00074 L
.12007 .00045 L
.1203 .00047 L
.12054 .00086 L
.12077 .00019 L
.121 .00091 L
.12123 .00041 L
.12147 .00127 L
.1217 .00052 L
.12193 .00063 L
.12216 .00077 L
.1224 .00079 L
.12263 .00073 L
.12286 .00079 L
.12309 .00073 L
.12333 .00085 L
.12356 .00078 L
.12379 .0004 L
.12402 .00134 L
.12426 .00096 L
.12449 .00089 L
.12472 .00055 L
.12495 .00053 L
.12519 .00062 L
.12542 .00035 L
.12565 .00044 L
.12588 .00229 L
.12612 .00171 L
.12635 .00165 L
.12658 .00127 L
.12681 .00079 L
.12705 .00151 L
.12728 .00079 L
.12751 .00034 L
.12774 .00081 L
.12798 .00127 L
.12821 .00092 L
Mistroke
.12844 .00076 L
.12867 .00083 L
.12891 .0004 L
.12914 .00089 L
.12937 .0012 L
.1296 .0003 L
.12984 .00138 L
.13007 .00042 L
.1303 .00121 L
.13053 .00025 L
.13077 .00079 L
.131 .00066 L
.13123 .00076 L
.13146 .00037 L
.1317 .0003 L
.13193 .00045 L
.13216 .00147 L
.13239 .00114 L
.13263 .00117 L
.13286 .00109 L
.13309 .00086 L
.13332 .00013 L
.13356 .00058 L
.13379 .00064 L
.13402 .00038 L
.13425 .0008 L
.13449 .00012 L
.13472 .00094 L
.13495 .00099 L
.13518 .00071 L
.13542 .00089 L
.13565 .00054 L
.13588 .00059 L
.13611 .0021 L
.13635 .00065 L
.13658 .00105 L
.13681 .00161 L
.13704 .00046 L
.13728 .00087 L
.13751 .00107 L
.13774 .00073 L
.13797 .00125 L
.13821 .00043 L
.13844 .00056 L
.13867 .00091 L
.1389 .00086 L
.13914 .00054 L
.13937 .00097 L
.1396 .00072 L
.13983 .0006 L
Mistroke
.14007 .00087 L
.1403 .00059 L
.14053 .00093 L
.14076 .0007 L
.141 .00162 L
.14123 .00033 L
.14146 .00101 L
.14169 7e-05 L
.14193 .00092 L
.14216 .00121 L
.14239 .00141 L
.14262 .001 L
.14286 .00052 L
.14309 .00161 L
.14332 .00062 L
.14355 .00092 L
.14379 .00111 L
.14402 .00155 L
.14425 .00053 L
.14448 .00091 L
.14472 .00112 L
.14495 .00056 L
.14518 .00036 L
.14541 .00018 L
.14565 .00115 L
.14588 .00092 L
.14611 .00064 L
.14634 .00101 L
.14658 .00046 L
.14681 .00159 L
.14704 .00027 L
.14727 .00137 L
.14751 .00113 L
.14774 .00066 L
.14797 .00057 L
.1482 .00078 L
.14844 .00077 L
.14867 .00044 L
.1489 .0007 L
.14914 .00074 L
.14937 .00084 L
.1496 .00055 L
.14983 .00073 L
.15007 .00124 L
.1503 .00042 L
.15053 .00118 L
.15076 .00078 L
.151 .00033 L
.15123 .00056 L
.15146 .00077 L
Mistroke
.15169 .0018 L
.15193 .00038 L
.15216 .00061 L
.15239 .00094 L
.15262 .00107 L
.15286 .00096 L
.15309 .0008 L
.15332 .00066 L
.15355 .00082 L
.15379 .00058 L
.15402 .00096 L
.15425 .00114 L
.15448 .0008 L
.15472 .00128 L
.15495 .00125 L
.15518 .00104 L
.15541 .00063 L
.15565 .00091 L
.15588 .00118 L
.15611 .00035 L
.15634 .00065 L
.15658 .00169 L
.15681 .00122 L
.15704 .00175 L
.15727 .00031 L
.15751 .00117 L
.15774 .00116 L
.15797 .00071 L
.1582 .00044 L
.15844 .00054 L
.15867 .00093 L
.1589 .0009 L
.15913 .00106 L
.15937 .00101 L
.1596 .00022 L
.15983 .00048 L
.16006 .00126 L
.1603 .0008 L
.16053 .00088 L
.16076 .00088 L
.16099 .00037 L
.16123 .00088 L
.16146 .00103 L
.16169 .00153 L
.16192 .00072 L
.16216 .0008 L
.16239 .00095 L
.16262 .00045 L
.16285 .00158 L
.16309 .0016 L
Mistroke
.16332 .00092 L
.16355 .00102 L
.16378 .00022 L
.16402 .00018 L
.16425 .00061 L
.16448 .0017 L
.16471 .0013 L
.16495 .00066 L
.16518 .00125 L
.16541 .00042 L
.16564 .0009 L
.16588 .00083 L
.16611 .00117 L
.16634 .00325 L
.16657 .00054 L
.16681 .00184 L
.16704 .00082 L
.16727 .00114 L
.1675 .00133 L
.16774 .0009 L
.16797 .00115 L
.1682 .00063 L
.16843 .00046 L
.16867 .00094 L
.1689 .00073 L
.16913 .00122 L
.16936 .00124 L
.1696 .00072 L
.16983 .00072 L
.17006 .0007 L
.17029 .00018 L
.17053 .00109 L
.17076 .0001 L
.17099 .00115 L
.17122 .00084 L
.17146 .00057 L
.17169 .00058 L
.17192 .00105 L
.17215 .00038 L
.17239 .00069 L
.17262 .00151 L
.17285 .00133 L
.17308 .00136 L
.17332 .00058 L
.17355 .00138 L
.17378 .00166 L
.17401 .00133 L
.17425 .00123 L
.17448 .00123 L
.17471 .00069 L
Mistroke
.17494 .00091 L
.17518 .00139 L
.17541 .0011 L
.17564 .00084 L
.17587 .00109 L
.17611 .00104 L
.17634 .00129 L
.17657 .00048 L
.1768 .00093 L
.17704 .00113 L
.17727 .00175 L
.1775 .0013 L
.17773 .00158 L
.17797 .00151 L
.1782 .00095 L
.17843 .00094 L
.17866 .00108 L
.1789 .0009 L
.17913 .00048 L
.17936 .00074 L
.17959 .00057 L
.17983 .00093 L
.18006 .00064 L
.18029 .00043 L
.18052 .00056 L
.18076 .00098 L
.18099 .00064 L
.18122 .001 L
.18145 .00092 L
.18169 .00108 L
.18192 .00091 L
.18215 .00071 L
.18238 .00103 L
.18262 .0012 L
.18285 .0011 L
.18308 .00099 L
.18331 .00076 L
.18355 .00076 L
.18378 .00096 L
.18401 .00113 L
.18424 .00098 L
.18448 .00081 L
.18471 .00157 L
.18494 .00074 L
.18517 .00101 L
.18541 .00161 L
.18564 .00119 L
.18587 .00094 L
.1861 .00073 L
.18634 .00104 L
Mistroke
.18657 .00091 L
.1868 .00136 L
.18703 .00102 L
.18727 .00168 L
.1875 .00105 L
.18773 .00097 L
.18797 .0012 L
.1882 .00059 L
.18843 .00057 L
.18866 .0016 L
.1889 .00159 L
.18913 .00081 L
.18936 .00133 L
.18959 .00026 L
.18983 .0013 L
.19006 .00071 L
.19029 .00032 L
.19052 .00048 L
.19076 .00102 L
.19099 .00087 L
.19122 .00127 L
.19145 .0013 L
.19169 .00079 L
.19192 .00058 L
.19215 .00174 L
.19238 .00121 L
.19262 .00086 L
.19285 .00128 L
.19308 .00068 L
.19331 .00046 L
.19355 .00111 L
.19378 .00165 L
.19401 .00111 L
.19424 .00137 L
.19448 .00149 L
.19471 .00095 L
.19494 .00142 L
.19517 .00155 L
.19541 .00086 L
.19564 .00106 L
.19587 .00038 L
.1961 .00143 L
.19634 .00071 L
.19657 .0011 L
.1968 .00118 L
.19703 .00088 L
.19727 .00142 L
.1975 .00087 L
.19773 .00099 L
.19796 .00026 L
Mistroke
.1982 .00149 L
.19843 .00153 L
.19866 .00128 L
.19889 .00145 L
.19913 .00202 L
.19936 .001 L
.19959 .00045 L
.19982 .00113 L
.20006 .00109 L
.20029 .00115 L
.20052 .00113 L
.20075 .00137 L
.20099 .00115 L
.20122 .00141 L
.20145 .00134 L
.20168 .00119 L
.20192 .0021 L
.20215 .00122 L
.20238 .00143 L
.20261 .00114 L
.20285 .00148 L
.20308 .00163 L
.20331 .00154 L
.20354 .00171 L
.20378 .00189 L
.20401 .00116 L
.20424 .00117 L
.20447 .00185 L
.20471 .00126 L
.20494 .00095 L
.20517 .00052 L
.2054 .00094 L
.20564 .00079 L
.20587 .00098 L
.2061 .00113 L
.20633 .00134 L
.20657 .00159 L
.2068 .00133 L
.20703 .00206 L
.20726 .00207 L
.2075 .00202 L
.20773 .00046 L
.20796 .0021 L
.20819 .00149 L
.20843 .00147 L
.20866 .00173 L
.20889 .00116 L
.20912 .00098 L
.20936 .00111 L
.20959 .00152 L
Mistroke
.20982 .00136 L
.21005 .002 L
.21029 .00109 L
.21052 .00083 L
.21075 .0015 L
.21098 .00169 L
.21122 .00134 L
.21145 .00198 L
.21168 .00096 L
.21191 .00153 L
.21215 .00166 L
.21238 .00204 L
.21261 .0021 L
.21284 .00159 L
.21308 9e-05 L
.21331 .00155 L
.21354 .00204 L
.21377 .00128 L
.21401 .00211 L
.21424 .00122 L
.21447 .00206 L
.2147 .0022 L
.21494 .00167 L
.21517 .0015 L
.2154 .00199 L
.21563 .0024 L
.21587 .00153 L
.2161 .00245 L
.21633 .00057 L
.21656 .00133 L
.2168 .00276 L
.21703 .00149 L
.21726 .00147 L
.21749 .00258 L
.21773 .00206 L
.21796 .00259 L
.21819 .00145 L
.21842 .00181 L
.21866 .00112 L
.21889 .00283 L
.21912 .00165 L
.21935 .00142 L
.21959 .0014 L
.21982 .0024 L
.22005 .00176 L
.22028 .00162 L
.22052 .00136 L
.22075 .00188 L
.22098 .00154 L
.22121 .00134 L
Mistroke
.22145 .00219 L
.22168 .00205 L
.22191 .00204 L
.22214 .00252 L
.22238 .00188 L
.22261 .00216 L
.22284 .00174 L
.22307 .00224 L
.22331 .00148 L
.22354 .00278 L
.22377 .00235 L
.224 .00183 L
.22424 .00279 L
.22447 .0024 L
.2247 .00144 L
.22493 .00244 L
.22517 .00269 L
.2254 .00168 L
.22563 .00152 L
.22586 .00194 L
.2261 .00293 L
.22633 .00206 L
.22656 .00261 L
.2268 .00155 L
.22703 .00155 L
.22726 .00238 L
.22749 .00249 L
.22773 .00173 L
.22796 .00236 L
.22819 .00221 L
.22842 .0016 L
.22866 .00273 L
.22889 .00189 L
.22912 .00252 L
.22935 .00244 L
.22959 .00304 L
.22982 .0024 L
.23005 .0027 L
.23028 .00264 L
.23052 .00237 L
.23075 .00263 L
.23098 .00341 L
.23121 .00269 L
.23145 .00316 L
.23168 .00205 L
.23191 .00295 L
.23214 .00385 L
.23238 .00354 L
.23261 .00278 L
.23284 .00311 L
Mistroke
.23307 .00275 L
.23331 .00238 L
.23354 .00272 L
.23377 .00248 L
.234 .00289 L
.23424 .00279 L
.23447 .00261 L
.2347 .00339 L
.23493 .00287 L
.23517 .00322 L
.2354 .00396 L
.23563 .00248 L
.23586 .00329 L
.2361 .0026 L
.23633 .00435 L
.23656 .00308 L
.23679 .00277 L
.23703 .00325 L
.23726 .00265 L
.23749 .00483 L
.23772 .00361 L
.23796 .00244 L
.23819 .00415 L
.23842 .00461 L
.23865 .00387 L
.23889 .00379 L
.23912 .00354 L
.23935 .00366 L
.23958 .0044 L
.23982 .00408 L
.24005 .00367 L
.24028 .00376 L
.24051 .00387 L
.24075 .00425 L
.24098 .00403 L
.24121 .0044 L
.24144 .00459 L
.24168 .00341 L
.24191 .00413 L
.24214 .00439 L
.24237 .00454 L
.24261 .00427 L
.24284 .00423 L
.24307 .00452 L
.2433 .00406 L
.24354 .00472 L
.24377 .00454 L
.244 .00477 L
.24423 .00626 L
.24447 .00412 L
Mistroke
.2447 .00542 L
.24493 .00644 L
.24516 .00667 L
.2454 .00683 L
.24563 .00586 L
.24586 .00457 L
.24609 .00622 L
.24633 .00577 L
.24656 .0056 L
.24679 .00667 L
.24702 .00648 L
.24726 .00672 L
.24749 .00654 L
.24772 .00641 L
.24795 .00755 L
.24819 .00699 L
.24842 .0081 L
.24865 .00836 L
.24888 .00734 L
.24912 .00814 L
.24935 .00848 L
.24958 .01005 L
.24981 .0086 L
.25005 .0096 L
.25028 .01024 L
.25051 .0113 L
.25074 .01163 L
.25098 .01192 L
.25121 .01113 L
.25144 .01328 L
.25167 .01293 L
.25191 .01416 L
.25214 .01483 L
.25237 .01502 L
.2526 .01559 L
.25284 .01682 L
.25307 .01822 L
.2533 .01942 L
.25353 .01962 L
.25377 .02252 L
.254 .02272 L
.25423 .02588 L
.25446 .02689 L
.2547 .03051 L
.25493 .0342 L
.25516 .03843 L
.25539 .04504 L
.25563 .05404 L
.25586 .06545 L
.25609 .0836 L
Mistroke
.25632 .11505 L
.25656 .19646 L
.25679 .61803 L
.25702 .55209 L
.25725 .18954 L
.25749 .11679 L
.25772 .08184 L
.25795 .06307 L
.25818 .0518 L
.25842 .04431 L
.25865 .03775 L
.25888 .03461 L
.25911 .03014 L
.25935 .02758 L
.25958 .02448 L
.25981 .02338 L
.26004 .02085 L
.26028 .01964 L
.26051 .0189 L
.26074 .01742 L
.26097 .01688 L
.26121 .01527 L
.26144 .01547 L
.26167 .01491 L
.2619 .01354 L
.26214 .01319 L
.26237 .01233 L
.2626 .01221 L
.26283 .01122 L
.26307 .01099 L
.2633 .00921 L
.26353 .01077 L
.26376 .01002 L
.264 .00887 L
.26423 .00998 L
.26446 .0094 L
.26469 .00878 L
.26493 .00821 L
.26516 .00791 L
.26539 .00675 L
.26563 .00766 L
.26586 .00735 L
.26609 .00724 L
.26632 .0068 L
.26656 .00693 L
.26679 .00761 L
.26702 .00641 L
.26725 .00751 L
.26749 .00676 L
.26772 .00607 L
Mistroke
.26795 .00643 L
.26818 .00637 L
.26842 .00582 L
.26865 .00634 L
.26888 .00573 L
.26911 .00526 L
.26935 .00604 L
.26958 .00602 L
.26981 .00554 L
.27004 .0049 L
.27028 .00483 L
.27051 .00464 L
.27074 .00423 L
.27097 .00368 L
.27121 .00426 L
.27144 .00423 L
.27167 .0044 L
.2719 .00362 L
.27214 .00419 L
.27237 .00498 L
.2726 .00436 L
.27283 .00444 L
.27307 .00444 L
.2733 .00295 L
.27353 .00346 L
.27376 .0039 L
.274 .00428 L
.27423 .00432 L
.27446 .00418 L
.27469 .00366 L
.27493 .0041 L
.27516 .00436 L
.27539 .00323 L
.27562 .004 L
.27586 .00329 L
.27609 .00446 L
.27632 .00297 L
.27655 .00337 L
.27679 .00253 L
.27702 .00279 L
.27725 .00353 L
.27748 .00341 L
.27772 .00317 L
.27795 .00401 L
.27818 .00467 L
.27841 .00335 L
.27865 .00302 L
.27888 .00322 L
.27911 .00329 L
.27934 .00357 L
Mistroke
.27958 .00265 L
.27981 .00311 L
.28004 .00278 L
.28027 .00304 L
.28051 .00327 L
.28074 .00324 L
.28097 .00347 L
.2812 .00293 L
.28144 .00278 L
.28167 .00259 L
.2819 .00196 L
.28213 .00318 L
.28237 .00293 L
.2826 .00247 L
.28283 .00289 L
.28306 .00233 L
.2833 .00142 L
.28353 .00308 L
.28376 .00223 L
.28399 .00257 L
.28423 .00266 L
.28446 .00191 L
.28469 .0023 L
.28492 .00224 L
.28516 .00174 L
.28539 .0019 L
.28562 .00278 L
.28585 .0025 L
.28609 .00235 L
.28632 .00254 L
.28655 .00246 L
.28678 .00258 L
.28702 .0018 L
.28725 .00205 L
.28748 .00253 L
.28771 .00224 L
.28795 .00213 L
.28818 .00276 L
.28841 .0019 L
.28864 .00199 L
.28888 .00216 L
.28911 .00189 L
.28934 .00196 L
.28957 .00192 L
.28981 .00203 L
.29004 .00259 L
.29027 .00156 L
.2905 .00279 L
.29074 .0018 L
.29097 .00214 L
Mistroke
.2912 .00224 L
.29143 .00209 L
.29167 .00199 L
.2919 .00205 L
.29213 .00279 L
.29236 .00135 L
.2926 .0016 L
.29283 .00252 L
.29306 .00163 L
.29329 .00126 L
.29353 .00184 L
.29376 .00214 L
.29399 .00189 L
.29422 .00241 L
.29446 .00209 L
.29469 .00199 L
.29492 .00212 L
.29515 .00158 L
.29539 .00178 L
.29562 .00159 L
.29585 .00193 L
.29608 .00193 L
.29632 .00185 L
.29655 .00186 L
.29678 .00172 L
.29701 .00167 L
.29725 .00149 L
.29748 .00173 L
.29771 .00176 L
.29794 .00182 L
.29818 .00171 L
.29841 .00085 L
.29864 .00164 L
.29887 .00181 L
.29911 .00172 L
.29934 .00161 L
.29957 .00185 L
.2998 .00141 L
.30004 .00171 L
.30027 .00193 L
.3005 .00201 L
.30073 .00188 L
.30097 .00184 L
.3012 .00151 L
.30143 .00124 L
.30166 .00147 L
.3019 .00154 L
.30213 .00081 L
.30236 .00124 L
.30259 .00159 L
Mistroke
.30283 .00199 L
.30306 .00147 L
.30329 .00137 L
.30352 .00187 L
.30376 .00137 L
.30399 .00158 L
.30422 .00193 L
.30445 .00136 L
.30469 .00154 L
.30492 .00081 L
.30515 .0019 L
.30539 .00188 L
.30562 .0015 L
.30585 .00112 L
.30608 .00121 L
.30632 .00147 L
.30655 .00179 L
.30678 .00178 L
.30701 .0017 L
.30725 .00135 L
.30748 .00093 L
.30771 .00112 L
.30794 .00136 L
.30818 .00125 L
.30841 .00202 L
.30864 .0016 L
.30887 .0008 L
.30911 .0017 L
.30934 .00069 L
.30957 .00197 L
.3098 .00138 L
.31004 .00132 L
.31027 .0012 L
.3105 .00131 L
.31073 .00152 L
.31097 .00109 L
.3112 .00157 L
.31143 .00115 L
.31166 .00137 L
.3119 .00129 L
.31213 .00112 L
.31236 .00147 L
.31259 .00113 L
.31283 .00102 L
.31306 .00132 L
.31329 .00131 L
.31352 .00145 L
.31376 .00172 L
.31399 .00094 L
.31422 .00152 L
Mistroke
.31445 .00097 L
.31469 .00104 L
.31492 .00115 L
.31515 .00122 L
.31538 .00103 L
.31562 .00101 L
.31585 .00099 L
.31608 .00084 L
.31631 .00122 L
.31655 .00074 L
.31678 .0013 L
.31701 .00106 L
.31724 .00125 L
.31748 .00125 L
.31771 .0012 L
.31794 .00084 L
.31817 .00093 L
.31841 .00098 L
.31864 .00159 L
.31887 .00134 L
.3191 .00171 L
.31934 .00116 L
.31957 .00125 L
.3198 .00102 L
.32003 .00104 L
.32027 .00084 L
.3205 .00097 L
.32073 .00103 L
.32096 .00061 L
.3212 .0014 L
.32143 .00059 L
.32166 .00105 L
.32189 .00095 L
.32213 .00122 L
.32236 .001 L
.32259 .00097 L
.32282 .00119 L
.32306 .00126 L
.32329 .00116 L
.32352 .00117 L
.32375 .001 L
.32399 .00057 L
.32422 .00127 L
.32445 .00149 L
.32468 .00129 L
.32492 .00108 L
.32515 .00088 L
.32538 .00129 L
.32561 .00088 L
.32585 .00089 L
Mistroke
.32608 .0009 L
.32631 .00089 L
.32654 .00093 L
.32678 .00152 L
.32701 .00104 L
.32724 .00055 L
.32747 .00099 L
.32771 .0016 L
.32794 .00102 L
.32817 .00084 L
.3284 .00108 L
.32864 .00081 L
.32887 .00115 L
.3291 .00106 L
.32933 .00069 L
.32957 .00077 L
.3298 .00115 L
.33003 .00129 L
.33026 .00097 L
.3305 .00089 L
.33073 .00141 L
.33096 .00103 L
.33119 .00057 L
.33143 .00111 L
.33166 .00108 L
.33189 .0014 L
.33212 .00125 L
.33236 .00017 L
.33259 .00107 L
.33282 .00122 L
.33305 .00073 L
.33329 .00124 L
.33352 .00069 L
.33375 .00107 L
.33398 .001 L
.33422 .00098 L
.33445 .00064 L
.33468 .00119 L
.33491 .00128 L
.33515 .0009 L
.33538 .00083 L
.33561 .00043 L
.33584 .00129 L
.33608 .0012 L
.33631 .00097 L
.33654 .00064 L
.33677 .0006 L
.33701 .0009 L
.33724 .00062 L
.33747 .00108 L
Mistroke
.3377 .00068 L
.33794 .001 L
.33817 .00083 L
.3384 .00115 L
.33863 .00094 L
.33887 .00054 L
.3391 .00099 L
.33933 .00076 L
.33956 .00044 L
.3398 .00082 L
.34003 .00094 L
.34026 .00066 L
.34049 .00066 L
.34073 .00084 L
.34096 .00073 L
.34119 .00104 L
.34142 .00061 L
.34166 .00086 L
.34189 .00121 L
.34212 .00106 L
.34235 .00105 L
.34259 .00066 L
.34282 .001 L
.34305 .00075 L
.34328 .00059 L
.34352 .00069 L
.34375 .00115 L
.34398 .00095 L
.34422 .00094 L
.34445 .00102 L
.34468 .0011 L
.34491 .00071 L
.34515 .00082 L
.34538 .00128 L
.34561 .00088 L
.34584 .00027 L
.34608 .00069 L
.34631 .00109 L
.34654 .00078 L
.34677 .0014 L
.34701 .00099 L
.34724 .00073 L
.34747 .00107 L
.3477 .00116 L
.34794 .00066 L
.34817 .00106 L
.3484 .00033 L
.34863 .00087 L
.34887 .00081 L
.3491 .00088 L
Mistroke
.34933 .00097 L
.34956 .00062 L
.3498 .00069 L
.35003 .00096 L
.35026 .00076 L
.35049 .0009 L
.35073 .00062 L
.35096 .00074 L
.35119 .00069 L
.35142 .00083 L
.35166 .00081 L
.35189 .00086 L
.35212 .00091 L
.35235 .00084 L
.35259 .00103 L
.35282 .0009 L
.35305 .00062 L
.35328 .00078 L
.35352 .00066 L
.35375 .001 L
.35398 .0007 L
.35421 .00088 L
.35445 .0011 L
.35468 .0011 L
.35491 .00081 L
.35514 .00074 L
.35538 .00055 L
.35561 .00076 L
.35584 .00117 L
.35607 .00059 L
.35631 .00067 L
.35654 .00079 L
.35677 .00053 L
.357 .00095 L
.35724 .00065 L
.35747 .00069 L
.3577 .00099 L
.35793 .00052 L
.35817 .00048 L
.3584 .00064 L
.35863 .00056 L
.35886 .00029 L
.3591 .00081 L
.35933 .00083 L
.35956 .00092 L
.35979 .00073 L
.36003 .00041 L
.36026 .00056 L
.36049 .00069 L
.36072 .00076 L
Mistroke
.36096 .00057 L
.36119 .00082 L
.36142 .00082 L
.36165 .00119 L
.36189 .00068 L
.36212 .00057 L
.36235 .00058 L
.36258 .00075 L
.36282 .00052 L
.36305 .00084 L
.36328 .00088 L
.36351 .00107 L
.36375 .00086 L
.36398 .00047 L
.36421 .0007 L
.36444 .00068 L
.36468 .00078 L
.36491 .00042 L
.36514 .00043 L
.36537 .00058 L
.36561 .00081 L
.36584 .00089 L
.36607 .00063 L
.3663 .00055 L
.36654 .00035 L
.36677 .00063 L
.367 .00076 L
.36723 .00082 L
.36747 .00071 L
.3677 .0007 L
.36793 .00052 L
.36816 .00049 L
.3684 .00075 L
.36863 .00039 L
.36886 .00095 L
.36909 .00051 L
.36933 .00079 L
.36956 .00058 L
.36979 .00062 L
.37002 .00071 L
.37026 .00047 L
.37049 .00061 L
.37072 .00067 L
.37095 .00081 L
.37119 .00082 L
.37142 .00068 L
.37165 .0007 L
.37188 .00065 L
.37212 .00088 L
.37235 .00071 L
Mistroke
.37258 .00051 L
.37281 .00078 L
.37305 .00083 L
.37328 .00065 L
.37351 .00051 L
.37374 .00041 L
.37398 .0005 L
.37421 .00092 L
.37444 .00073 L
.37467 .00091 L
.37491 .00074 L
.37514 .0006 L
.37537 .00074 L
.3756 .00037 L
.37584 .00053 L
.37607 .00078 L
.3763 .00082 L
.37653 .00068 L
.37677 .00045 L
.377 .00048 L
.37723 .0007 L
.37746 .00068 L
.3777 .00077 L
.37793 .00069 L
.37816 .00042 L
.37839 .00043 L
.37863 .00062 L
.37886 .00049 L
.37909 .00053 L
.37932 .00047 L
.37956 .00068 L
.37979 .00077 L
.38002 .00053 L
.38025 .00082 L
.38049 .00057 L
.38072 .0006 L
.38095 .00065 L
.38118 .00062 L
.38142 .00078 L
.38165 .00079 L
.38188 .00071 L
.38211 .00056 L
.38235 .00056 L
.38258 .00092 L
.38281 .00048 L
.38305 .00069 L
.38328 .00081 L
.38351 .00087 L
.38374 .00051 L
.38398 .00068 L
Mistroke
.38421 .00039 L
.38444 .00047 L
.38467 .00075 L
.38491 .00034 L
.38514 .00097 L
.38537 .0008 L
.3856 .00033 L
.38584 .00076 L
.38607 .00072 L
.3863 .00054 L
.38653 .00071 L
.38677 .00085 L
.387 .00041 L
.38723 .00079 L
.38746 .00069 L
.3877 .00051 L
.38793 .00057 L
.38816 .00013 L
.38839 .00055 L
.38863 .00045 L
.38886 .00099 L
.38909 .00027 L
.38932 .00075 L
.38956 .00039 L
.38979 .00025 L
.39002 .00041 L
.39025 .00044 L
.39049 .00035 L
.39072 .00064 L
.39095 .00087 L
.39118 .00046 L
.39142 .00074 L
.39165 .00044 L
.39188 .00047 L
.39211 .00029 L
.39235 .00024 L
.39258 7e-05 L
.39281 .00082 L
.39304 .00052 L
.39328 .00057 L
.39351 .00091 L
.39374 .00084 L
.39397 .00061 L
.39421 .00061 L
.39444 .00023 L
.39467 .00052 L
.3949 .00052 L
.39514 .00108 L
.39537 .00029 L
.3956 .00034 L
Mistroke
.39583 .00094 L
.39607 .0006 L
.3963 .00062 L
.39653 .00072 L
.39676 .00071 L
.397 .00058 L
.39723 .00071 L
.39746 .00051 L
.39769 .00047 L
.39793 .0005 L
.39816 .00133 L
.39839 .00019 L
.39862 .00023 L
.39886 .00043 L
.39909 .00044 L
.39932 .00012 L
.39955 .00026 L
.39979 .00054 L
.40002 .00091 L
.40025 .00073 L
.40048 .00039 L
.40072 .0006 L
.40095 .00051 L
.40118 .00071 L
.40141 5e-05 L
.40165 .00075 L
.40188 .00061 L
.40211 .00021 L
.40234 .00026 L
.40258 .00036 L
.40281 .00043 L
.40304 .00086 L
.40327 .00041 L
.40351 .0006 L
.40374 .00106 L
.40397 .00025 L
.4042 .00052 L
.40444 .00021 L
.40467 .00052 L
.4049 .00078 L
.40513 .00045 L
.40537 .00069 L
.4056 .00046 L
.40583 .00026 L
.40606 .0008 L
.4063 .00026 L
.40653 .00044 L
.40676 .00053 L
.40699 .00023 L
.40723 .00068 L
Mistroke
.40746 .00026 L
.40769 .00029 L
.40792 .00028 L
.40816 .00085 L
.40839 .00072 L
.40862 .00026 L
.40885 .00034 L
.40909 .00077 L
.40932 .00054 L
.40955 .00014 L
.40978 .00063 L
.41002 .00035 L
.41025 .00043 L
.41048 .0008 L
.41071 .00063 L
.41095 .00074 L
.41118 .00021 L
.41141 .00032 L
.41164 .00089 L
.41188 .00046 L
.41211 .00024 L
.41234 .00102 L
.41257 .00052 L
.41281 .00068 L
.41304 .00061 L
.41327 .00061 L
.4135 .00056 L
.41374 .00073 L
.41397 .00047 L
.4142 .00056 L
.41443 .00055 L
.41467 .00105 L
.4149 .00056 L
.41513 .00081 L
.41536 .00103 L
.4156 .00014 L
.41583 .00096 L
.41606 .00014 L
.41629 .00067 L
.41653 .00092 L
.41676 .00041 L
.41699 .00072 L
.41722 .00087 L
.41746 .00085 L
.41769 .00085 L
.41792 .00022 L
.41815 .00052 L
.41839 .0005 L
.41862 .00068 L
.41885 .00038 L
Mistroke
.41908 .00048 L
.41932 .00034 L
.41955 .00041 L
.41978 .00042 L
.42001 .00078 L
.42025 .00093 L
.42048 .00022 L
.42071 .00096 L
.42094 .00089 L
.42118 .00011 L
.42141 .00033 L
.42164 .00025 L
.42188 .00099 L
.42211 .00111 L
.42234 .00073 L
.42257 .00084 L
.42281 .00077 L
.42304 .00035 L
.42327 .00079 L
.4235 .00056 L
.42374 .00022 L
.42397 .00046 L
.4242 .00043 L
.42443 .00025 L
.42467 .00078 L
.4249 .00029 L
.42513 .00042 L
.42536 .00019 L
.4256 .00065 L
.42583 .00021 L
.42606 .00072 L
.42629 .00034 L
.42653 .00061 L
.42676 .00037 L
.42699 .0008 L
.42722 .00053 L
.42746 .00047 L
.42769 .00064 L
.42792 .00046 L
.42815 .00025 L
.42839 .00012 L
.42862 .00041 L
.42885 .00076 L
.42908 .00063 L
.42932 .00025 L
.42955 .00041 L
.42978 .00046 L
.43001 .00075 L
.43025 .00039 L
.43048 .00058 L
Mistroke
.43071 .0004 L
.43094 .00055 L
.43118 .00082 L
.43141 .001 L
.43164 .00078 L
.43187 .00069 L
.43211 .00065 L
.43234 .00047 L
.43257 .00079 L
.4328 .00028 L
.43304 .00024 L
.43327 .00017 L
.4335 .00027 L
.43373 .00055 L
.43397 .00041 L
.4342 .00085 L
.43443 .00057 L
.43466 .00096 L
.4349 .00039 L
.43513 .00062 L
.43536 .00102 L
.43559 .00067 L
.43583 .00063 L
.43606 .00048 L
.43629 .00158 L
.43652 .00044 L
.43676 .00077 L
.43699 .001 L
.43722 .00028 L
.43745 .00028 L
.43769 .00033 L
.43792 .00051 L
.43815 .0001 L
.43838 .00093 L
.43862 .00073 L
.43885 7e-05 L
.43908 .00069 L
.43931 .00036 L
.43955 .00061 L
.43978 .00037 L
.44001 5e-05 L
.44024 .00031 L
.44048 .00092 L
.44071 .0008 L
.44094 .00047 L
.44117 .00026 L
.44141 .001 L
.44164 .00011 L
.44187 .00079 L
.4421 .00097 L
Mistroke
.44234 .00026 L
.44257 .00084 L
.4428 .00133 L
.44303 .0009 L
.44327 .0005 L
.4435 .00037 L
.44373 .00049 L
.44396 .00086 L
.4442 .00032 L
.44443 .00026 L
.44466 .00165 L
.44489 .00091 L
.44513 .00059 L
.44536 .00063 L
.44559 .00052 L
.44582 .00095 L
.44606 .00088 L
.44629 .00149 L
.44652 .00177 L
.44675 .00047 L
.44699 .0004 L
.44722 .00061 L
.44745 .00021 L
.44768 .0011 L
.44792 .00046 L
.44815 .00033 L
.44838 .00121 L
.44861 .00116 L
.44885 .00012 L
.44908 .00155 L
.44931 .00131 L
.44954 .00036 L
.44978 .00116 L
.45001 .0011 L
.45024 .00081 L
.45047 .00085 L
.45071 .00034 L
.45094 .00093 L
.45117 .00019 L
.4514 .0002 L
.45164 .00195 L
.45187 .0004 L
.4521 .00117 L
.45233 .00028 L
.45257 .00153 L
.4528 .00099 L
.45303 .00148 L
.45326 .00098 L
.4535 .00075 L
.45373 .00107 L
Mistroke
.45396 .00073 L
.45419 .00166 L
.45443 .00086 L
.45466 .00085 L
.45489 .00074 L
.45512 .00104 L
.45536 .00155 L
.45559 .00076 L
.45582 .00066 L
.45605 .00032 L
.45629 .00076 L
.45652 .00079 L
.45675 .00087 L
.45698 .00053 L
.45722 .00067 L
.45745 .00076 L
.45768 .00102 L
.45791 .00072 L
.45815 .00098 L
.45838 .0004 L
.45861 .00068 L
.45884 .00161 L
.45908 .00123 L
.45931 .00106 L
.45954 .00081 L
.45977 .00142 L
.46001 .00079 L
.46024 .00071 L
.46047 .00049 L
.4607 .00028 L
.46094 .00038 L
.46117 .00085 L
.4614 .00015 L
.46164 .00082 L
.46187 .00117 L
.4621 .00141 L
.46233 .00066 L
.46257 .00082 L
.4628 .00101 L
.46303 .00111 L
.46326 .00185 L
.4635 .0006 L
.46373 .00011 L
.46396 .00082 L
.46419 .0005 L
.46443 .00143 L
.46466 .00069 L
.46489 .00011 L
.46512 .00092 L
.46536 .00022 L
Mistroke
.46559 .00119 L
.46582 .00065 L
.46605 .0015 L
.46629 .00062 L
.46652 .00037 L
.46675 .00182 L
.46698 .00116 L
.46722 .00125 L
.46745 .00052 L
.46768 .001 L
.46791 .0006 L
.46815 .00163 L
.46838 .00064 L
.46861 .00069 L
.46884 .00117 L
.46908 .00218 L
.46931 .00139 L
.46954 .00104 L
.46977 .00084 L
.47001 .00149 L
.47024 .00189 L
.47047 .0014 L
.4707 .00076 L
.47094 .00101 L
.47117 .00094 L
.4714 .00011 L
.47163 .00146 L
.47187 .00141 L
.4721 .00056 L
.47233 .00074 L
.47256 .0004 L
.4728 .00097 L
.47303 .00089 L
.47326 .00087 L
.47349 .00127 L
.47373 .00062 L
.47396 .00133 L
.47419 .00148 L
.47442 .00116 L
.47466 .00029 L
.47489 .00047 L
.47512 .00075 L
.47535 .00187 L
.47559 .00177 L
.47582 .00209 L
.47605 .00182 L
.47628 .00064 L
.47652 .00093 L
.47675 .00095 L
.47698 .00184 L
Mistroke
.47721 .00116 L
.47745 .00067 L
.47768 .00084 L
.47791 .00199 L
.47814 .00111 L
.47838 .00044 L
.47861 .00119 L
.47884 .00048 L
.47907 .0012 L
.47931 .0011 L
.47954 .00047 L
.47977 .0003 L
.48 .00014 L
.48024 .00072 L
.48047 .00024 L
.4807 .00123 L
.48093 .00116 L
.48117 .0014 L
.4814 .0003 L
.48163 .00041 L
.48186 .0009 L
.4821 .00081 L
.48233 .00035 L
.48256 .00082 L
.48279 .00031 L
.48303 .00151 L
.48326 .00086 L
.48349 .00133 L
.48372 .00079 L
.48396 .00141 L
.48419 .00137 L
.48442 .0007 L
.48465 .00012 L
.48489 .00089 L
.48512 .00097 L
.48535 .00061 L
.48558 .0006 L
.48582 .00073 L
.48605 .00073 L
.48628 .00046 L
.48651 .00089 L
.48675 .00088 L
.48698 .00062 L
.48721 .00036 L
.48744 .0006 L
.48768 .00058 L
.48791 .00047 L
.48814 .00055 L
.48837 .00038 L
.48861 .00025 L
Mistroke
.48884 .00134 L
.48907 .00099 L
.4893 .00148 L
.48954 .00095 L
.48977 .00028 L
.49 .0041 L
.49023 .0005 L
.49047 3e-05 L
.4907 .00092 L
.49093 .0003 L
.49116 .00101 L
.4914 .00075 L
.49163 8e-05 L
.49186 .0005 L
.49209 .00055 L
.49233 .00039 L
.49256 .00016 L
.49279 .0004 L
.49302 .00018 L
.49326 .00058 L
.49349 .0005 L
.49372 .00094 L
.49395 .00038 L
.49419 .00046 L
.49442 .00073 L
.49465 .00096 L
.49488 .00055 L
.49512 .00041 L
.49535 .00094 L
.49558 .00025 L
.49581 .00067 L
.49605 .00065 L
.49628 .00111 L
.49651 .00071 L
.49674 .00051 L
.49698 6e-05 L
.49721 .00037 L
.49744 9e-05 L
.49767 .00042 L
.49791 .00063 L
.49814 .00069 L
.49837 .0004 L
.4986 .00052 L
.49884 .00085 L
.49907 .00107 L
.4993 .00042 L
.49953 .0007 L
.49977 .00131 L
.5 .00037 L
.50023 8e-05 L
Mistroke
.50047 .00061 L
.5007 .00041 L
.50093 .00036 L
.50116 .00028 L
.5014 .00097 L
.50163 .00068 L
.50186 .00057 L
.50209 .00099 L
.50233 .0014 L
.50256 .00076 L
.50279 .00019 L
.50302 .00059 L
.50326 .00086 L
.50349 .00068 L
.50372 .00028 L
.50395 .00026 L
.50419 .00058 L
.50442 .00035 L
.50465 .00074 L
.50488 .00046 L
.50512 .00084 L
.50535 .00011 L
.50558 .00031 L
.50581 .0002 L
.50605 .00046 L
.50628 .00076 L
.50651 .00032 L
.50674 .00039 L
.50698 .00026 L
.50721 .00048 L
.50744 .00017 L
.50767 .00026 L
.50791 6e-05 L
.50814 .00046 L
.50837 .00032 L
.5086 .00042 L
.50884 .0006 L
.50907 .00018 L
.5093 .00073 L
.50953 .00049 L
.50977 6e-05 L
.51 .00025 L
.51023 .00098 L
.51046 .00085 L
.5107 .00023 L
.51093 .00055 L
.51116 .00065 L
.51139 .00056 L
.51163 .00044 L
.51186 .00034 L
Mistroke
.51209 4e-05 L
.51232 .00058 L
.51256 .00092 L
.51279 .00042 L
.51302 .00042 L
.51325 .00032 L
.51349 .00045 L
.51372 .00028 L
.51395 .00066 L
.51418 .00032 L
.51442 .00062 L
.51465 .00069 L
.51488 .0003 L
.51511 .00029 L
.51535 .00027 L
.51558 .00053 L
.51581 .00052 L
.51604 .00021 L
.51628 .00013 L
.51651 .00045 L
.51674 .00058 L
.51697 .00061 L
.51721 .00064 L
.51744 .00028 L
.51767 .00063 L
.5179 .00044 L
.51814 .00018 L
.51837 6e-05 L
.5186 .00026 L
.51883 .00033 L
.51907 .00012 L
.5193 .00019 L
.51953 .00017 L
.51976 .00056 L
.52 .00014 L
.52023 .00068 L
.52046 .00042 L
.52069 .00043 L
.52093 .00072 L
.52116 .00036 L
.52139 .00055 L
.52162 .00045 L
.52186 .00049 L
.52209 .00033 L
.52232 .00053 L
.52255 .00017 L
.52279 .00056 L
.52302 .00016 L
.52325 .00017 L
.52348 .00054 L
Mistroke
.52372 .00037 L
.52395 .00027 L
.52418 .00047 L
.52441 .00053 L
.52465 .00076 L
.52488 .00033 L
.52511 .00032 L
.52534 .00047 L
.52558 .00023 L
.52581 .00024 L
.52604 .00036 L
.52627 .00058 L
.52651 .00024 L
.52674 .00034 L
.52697 .00039 L
.5272 .00061 L
.52744 .00023 L
.52767 .00049 L
.5279 .00046 L
.52813 .00044 L
.52837 .00021 L
.5286 .00032 L
.52883 .00036 L
.52906 .00061 L
.5293 .00054 L
.52953 .00041 L
.52976 .00023 L
.52999 .00053 L
.53023 .00044 L
.53046 .00072 L
.53069 .00044 L
.53092 .00016 L
.53116 .00035 L
.53139 .00025 L
.53162 .0003 L
.53185 .00045 L
.53209 .00017 L
.53232 .00049 L
.53255 .00062 L
.53278 .00036 L
.53302 .00037 L
.53325 .00055 L
.53348 .00014 L
.53371 .00014 L
.53395 .00049 L
.53418 .00031 L
.53441 .00018 L
.53464 .00053 L
.53488 .00028 L
.53511 .00038 L
Mistroke
.53534 .00043 L
.53557 .00043 L
.53581 .00042 L
.53604 .00038 L
.53627 .00028 L
.5365 .00038 L
.53674 .00021 L
.53697 .00033 L
.5372 .00024 L
.53743 .00029 L
.53767 .0002 L
.5379 .00038 L
.53813 .00023 L
.53836 .00024 L
.5386 .00061 L
.53883 .00041 L
.53906 .00052 L
.5393 .00016 L
.53953 .00059 L
.53976 .00077 L
.53999 .00039 L
.54023 .00041 L
.54046 .00022 L
.54069 .00065 L
.54092 .0006 L
.54116 .00027 L
.54139 .00016 L
.54162 .00033 L
.54185 .00026 L
.54209 7e-05 L
.54232 8e-05 L
.54255 .00022 L
.54278 .00056 L
.54302 .00043 L
.54325 .00067 L
.54348 .00061 L
.54371 .0004 L
.54395 .00043 L
.54418 .00053 L
.54441 .00037 L
.54464 .00016 L
.54488 .00024 L
.54511 .00013 L
.54534 .00031 L
.54557 .00044 L
.54581 .00035 L
.54604 .00063 L
.54627 .00023 L
.5465 .00033 L
.54674 .0003 L
Mistroke
.54697 .0003 L
.5472 .00014 L
.54743 .00047 L
.54767 .0005 L
.5479 .00017 L
.54813 .0005 L
.54836 .00035 L
.5486 .00039 L
.54883 .00041 L
.54906 .0003 L
.54929 .00031 L
.54953 .00016 L
.54976 .00043 L
.54999 .00037 L
.55022 .0001 L
.55046 .00013 L
.55069 .00012 L
.55092 .00047 L
.55115 .00034 L
.55139 .00033 L
.55162 .00059 L
.55185 .00022 L
.55208 .00062 L
.55232 .00027 L
.55255 3e-05 L
.55278 .00068 L
.55301 .00068 L
.55325 .00034 L
.55348 .00033 L
.55371 .00058 L
.55394 .00066 L
.55418 .00035 L
.55441 .00053 L
.55464 2e-05 L
.55487 .00059 L
.55511 .00047 L
.55534 .00029 L
.55557 .00026 L
.5558 .00069 L
.55604 .00037 L
.55627 .00044 L
.5565 .00049 L
.55673 .00013 L
.55697 .00033 L
.5572 .0002 L
.55743 .00026 L
.55766 .00082 L
.5579 .00062 L
.55813 .00024 L
.55836 .0003 L
Mistroke
.55859 .00043 L
.55883 .0004 L
.55906 .00059 L
.55929 .00011 L
.55952 .00039 L
.55976 .00022 L
.55999 .00037 L
.56022 .00034 L
.56045 .00028 L
.56069 .00045 L
.56092 .0005 L
.56115 .0003 L
.56138 .00064 L
.56162 .00041 L
.56185 .00066 L
.56208 .00041 L
.56231 .00025 L
.56255 .00113 L
.56278 .00044 L
.56301 .00022 L
.56324 2e-05 L
.56348 .00057 L
.56371 .00025 L
.56394 .00086 L
.56417 .00073 L
.56441 .00108 L
.56464 .0004 L
.56487 .00099 L
.5651 .00047 L
.56534 .00012 L
.56557 .00041 L
.5658 .00034 L
.56603 .0009 L
.56627 .0007 L
.5665 .00041 L
.56673 .00041 L
.56696 .0007 L
.5672 .0009 L
.56743 .00055 L
.56766 .00048 L
.56789 .00028 L
.56813 .00088 L
.56836 .00014 L
.56859 .0004 L
.56882 .00086 L
.56906 .00062 L
.56929 .00056 L
.56952 .0002 L
.56975 6e-05 L
.56999 .00052 L
Mistroke
.57022 .00064 L
.57045 .00054 L
.57068 .00019 L
.57092 .00022 L
.57115 .00035 L
.57138 .00033 L
.57161 .00027 L
.57185 .00034 L
.57208 .00043 L
.57231 .00036 L
.57254 .00071 L
.57278 .00052 L
.57301 .00045 L
.57324 .00061 L
.57347 .00012 L
.57371 .00046 L
.57394 .00066 L
.57417 .00028 L
.5744 .00062 L
.57464 .00035 L
.57487 .00052 L
.5751 .00066 L
.57533 .00102 L
.57557 .00029 L
.5758 .00027 L
.57603 .00017 L
.57626 .00011 L
.5765 .00034 L
.57673 .00022 L
.57696 .00026 L
.57719 .00013 L
.57743 .00025 L
.57766 .00072 L
.57789 .00024 L
.57813 .00046 L
.57836 .00063 L
.57859 .00044 L
.57882 .00099 L
.57906 .00058 L
.57929 .00012 L
.57952 .00103 L
.57975 .00046 L
.57999 .00023 L
.58022 .00078 L
.58045 .00128 L
.58068 .00032 L
.58092 .0007 L
.58115 .0006 L
.58138 .00025 L
.58161 .00027 L
Mistroke
.58185 .00044 L
.58208 .00036 L
.58231 .00051 L
.58254 .00058 L
.58278 .00037 L
.58301 .00013 L
.58324 .00032 L
.58347 .00013 L
.58371 .00025 L
.58394 .0001 L
.58417 .00053 L
.5844 .00035 L
.58464 .00051 L
.58487 .00052 L
.5851 .00045 L
.58533 .00054 L
.58557 .00037 L
.5858 .00028 L
.58603 .00029 L
.58626 .00056 L
.5865 8e-05 L
.58673 .00088 L
.58696 .00054 L
.58719 .00048 L
.58743 .00034 L
.58766 .00015 L
.58789 .0005 L
.58812 .00038 L
.58836 .00023 L
.58859 .0003 L
.58882 .00041 L
.58905 .00035 L
.58929 .00061 L
.58952 .00029 L
.58975 .00077 L
.58998 .00042 L
.59022 .00032 L
.59045 .00023 L
.59068 .00067 L
.59091 .00061 L
.59115 .00072 L
.59138 .00018 L
.59161 .00046 L
.59184 .00056 L
.59208 .00083 L
.59231 .00035 L
.59254 .00057 L
.59277 .00079 L
.59301 .00035 L
.59324 .00017 L
Mistroke
.59347 .00061 L
.5937 .0004 L
.59394 .00019 L
.59417 .00034 L
.5944 .00028 L
.59463 .00055 L
.59487 .0005 L
.5951 .00081 L
.59533 .00076 L
.59556 .00025 L
.5958 .00052 L
.59603 .00056 L
.59626 .00038 L
.59649 .00022 L
.59673 .00041 L
.59696 .00037 L
.59719 .00022 L
.59742 .00125 L
.59766 .00035 L
.59789 .00046 L
.59812 .00067 L
.59835 .00062 L
.59859 .00054 L
.59882 .00036 L
.59905 .0001 L
.59928 .00037 L
.59952 .00047 L
.59975 .00047 L
.59998 .00026 L
.60021 .00036 L
.60045 .00022 L
.60068 .00028 L
.60091 .00014 L
.60114 .0004 L
.60138 .00093 L
.60161 .0009 L
.60184 .00068 L
.60207 .00026 L
.60231 .00023 L
.60254 .00021 L
.60277 .00041 L
.603 .00038 L
.60324 .00066 L
.60347 .00039 L
.6037 .00058 L
.60393 .00035 L
.60417 .00073 L
.6044 .00015 L
.60463 .00038 L
.60486 .00069 L
Mistroke
.6051 8e-05 L
.60533 .00028 L
.60556 .00046 L
.60579 .00032 L
.60603 .00039 L
.60626 .00053 L
.60649 .00056 L
.60672 .00017 L
.60696 .00024 L
.60719 .00063 L
.60742 .00055 L
.60765 .00033 L
.60789 .00062 L
.60812 .00039 L
.60835 .00056 L
.60858 .00044 L
.60882 .00097 L
.60905 .00046 L
.60928 .00094 L
.60951 .0003 L
.60975 .00065 L
.60998 .0003 L
.61021 .00073 L
.61044 .00121 L
.61068 .00075 L
.61091 .00037 L
.61114 .00024 L
.61137 .00016 L
.61161 .00052 L
.61184 9e-05 L
.61207 .00073 L
.6123 .00065 L
.61254 .00081 L
.61277 .00075 L
.613 .00041 L
.61323 .00082 L
.61347 .00023 L
.6137 .00077 L
.61393 .00057 L
.61416 .00048 L
.6144 9e-05 L
.61463 .00052 L
.61486 .00101 L
.61509 .00058 L
.61533 .00055 L
.61556 .00087 L
.61579 .00049 L
.61602 .00046 L
.61626 .00022 L
.61649 .00068 L
Mistroke
.61672 .00032 L
.61695 .00072 L
.61719 .00091 L
.61742 .00043 L
.61765 .00024 L
.61789 .0003 L
.61812 .00068 L
.61835 .00011 L
.61858 .00047 L
.61882 .00061 L
.61905 .00082 L
.61928 .00076 L
.61951 .00026 L
.61975 .0004 L
.61998 .00038 L
.62021 .00075 L
.62044 .00143 L
.62068 .00052 L
.62091 .00106 L
.62114 .00079 L
.62137 .00062 L
.62161 .00073 L
.62184 .00011 L
.62207 .00018 L
.6223 .00043 L
.62254 .00049 L
.62277 .00087 L
.623 .00015 L
.62323 .00025 L
.62347 .00053 L
.6237 .00105 L
.62393 .00081 L
.62416 .00028 L
.6244 .0004 L
.62463 .00026 L
.62486 .0007 L
.62509 .00026 L
.62533 .00106 L
.62556 .00037 L
.62579 .0009 L
.62602 .00028 L
.62626 .00051 L
.62649 .0008 L
.62672 .00049 L
.62695 .00051 L
.62719 .00037 L
.62742 .00078 L
.62765 .00045 L
.62788 .00016 L
.62812 .00095 L
Mistroke
.62835 .00062 L
.62858 .00042 L
.62881 .00029 L
.62905 .00109 L
.62928 .00026 L
.62951 .00025 L
.62974 .00024 L
.62998 .00053 L
.63021 .00078 L
.63044 .00059 L
.63067 .00071 L
.63091 .00035 L
.63114 .00011 L
.63137 .00048 L
.6316 .00062 L
.63184 .00038 L
.63207 .00022 L
.6323 .00069 L
.63253 .0004 L
.63277 .00035 L
.633 .00048 L
.63323 .00106 L
.63346 .00094 L
.6337 .00025 L
.63393 .00054 L
.63416 .00099 L
.63439 .00073 L
.63463 .0005 L
.63486 .00024 L
.63509 .00076 L
.63532 .00097 L
.63556 .00074 L
.63579 .00024 L
.63602 .00028 L
.63625 .00042 L
.63649 .00145 L
.63672 .0007 L
.63695 .00079 L
.63718 .00056 L
.63742 .00037 L
.63765 .00011 L
.63788 .00042 L
.63811 .00032 L
.63835 .00019 L
.63858 .00059 L
.63881 .00038 L
.63904 .00063 L
.63928 .00081 L
.63951 .00023 L
.63974 .00024 L
Mistroke
.63997 .00083 L
.64021 .00076 L
.64044 .00097 L
.64067 .00082 L
.6409 .0005 L
.64114 .00048 L
.64137 .00022 L
.6416 .00042 L
.64183 .00061 L
.64207 .00071 L
.6423 .00018 L
.64253 .00047 L
.64276 .00032 L
.643 .00026 L
.64323 .00051 L
.64346 .00045 L
.64369 .00015 L
.64393 .00065 L
.64416 .0002 L
.64439 .00076 L
.64462 .00059 L
.64486 .00057 L
.64509 .00028 L
.64532 .00125 L
.64555 .00095 L
.64579 .00014 L
.64602 .0004 L
.64625 .00037 L
.64648 .00034 L
.64672 .00055 L
.64695 .00035 L
.64718 .00052 L
.64741 .00064 L
.64765 .00065 L
.64788 .00017 L
.64811 .00021 L
.64834 .00026 L
.64858 .00028 L
.64881 .0004 L
.64904 .0004 L
.64927 .00068 L
.64951 .00039 L
.64974 .00031 L
.64997 .00031 L
.6502 .00066 L
.65044 .00059 L
.65067 .00075 L
.6509 .00053 L
.65113 .00057 L
.65137 .00056 L
Mistroke
.6516 .00029 L
.65183 .00076 L
.65206 .00045 L
.6523 .00073 L
.65253 .00081 L
.65276 .00064 L
.65299 .00011 L
.65323 .00085 L
.65346 .00016 L
.65369 .00013 L
.65392 .00098 L
.65416 .00051 L
.65439 .00037 L
.65462 .00041 L
.65485 .00051 L
.65509 .00055 L
.65532 .001 L
.65555 .00041 L
.65578 .00045 L
.65602 .00061 L
.65625 .00028 L
.65648 .0006 L
.65672 .00037 L
.65695 3e-05 L
.65718 .00015 L
.65741 .001 L
.65765 .00038 L
.65788 .00036 L
.65811 .00028 L
.65834 .00011 L
.65858 .00014 L
.65881 .0002 L
.65904 .00046 L
.65927 .00076 L
.65951 .00043 L
.65974 .00053 L
.65997 .00021 L
.6602 .00018 L
.66044 .00079 L
.66067 6e-05 L
.6609 .00057 L
.66113 .00031 L
.66137 .00034 L
.6616 7e-05 L
.66183 .00019 L
.66206 .0003 L
.6623 .00035 L
.66253 .00028 L
.66276 .00025 L
.66299 .00021 L
Mistroke
.66323 .00056 L
.66346 .00052 L
.66369 .00031 L
.66392 .00018 L
.66416 .00042 L
.66439 .00034 L
.66462 .00032 L
.66485 .00024 L
.66509 .00013 L
.66532 7e-05 L
.66555 .00023 L
.66578 .00068 L
.66602 .00049 L
.66625 .00028 L
.66648 .0001 L
.66671 .00044 L
.66695 .00038 L
.66718 .00024 L
.66741 .00039 L
.66764 .00044 L
.66788 .00042 L
.66811 .00064 L
.66834 .0004 L
.66857 .00045 L
.66881 .00045 L
.66904 .00048 L
.66927 .00051 L
.6695 .00025 L
.66974 .00039 L
.66997 .00054 L
.6702 .00045 L
.67043 .00046 L
.67067 .00056 L
.6709 .00018 L
.67113 .00061 L
.67136 .00048 L
.6716 .00032 L
.67183 .00027 L
.67206 .00024 L
.67229 .00063 L
.67253 .00014 L
.67276 .00042 L
.67299 .00048 L
.67322 .00017 L
.67346 .00024 L
.67369 .00047 L
.67392 .00036 L
.67415 .00033 L
.67439 .00044 L
.67462 .00018 L
Mistroke
.67485 .00068 L
.67508 .0004 L
.67532 .00041 L
.67555 3e-05 L
.67578 .00051 L
.67601 .00037 L
.67625 .00031 L
.67648 .00048 L
.67671 .00066 L
.67694 3e-05 L
.67718 .00045 L
.67741 .00063 L
.67764 .00027 L
.67787 3e-05 L
.67811 .0001 L
.67834 .00044 L
.67857 .00045 L
.6788 .00015 L
.67904 .0004 L
.67927 .00022 L
.6795 .00012 L
.67973 .00025 L
.67997 .00049 L
.6802 .00017 L
.68043 .00051 L
.68066 .00037 L
.6809 .00022 L
.68113 .00045 L
.68136 3e-05 L
.68159 .00021 L
.68183 .00023 L
.68206 .00028 L
.68229 .00067 L
.68252 .00048 L
.68276 .00042 L
.68299 .00045 L
.68322 .0003 L
.68345 .00042 L
.68369 .00032 L
.68392 .0004 L
.68415 .00018 L
.68438 .00036 L
.68462 .00042 L
.68485 .00079 L
.68508 .00035 L
.68531 .00031 L
.68555 .00062 L
.68578 .00015 L
.68601 .00032 L
.68624 .00019 L
Mistroke
.68648 .00045 L
.68671 .00016 L
.68694 .00021 L
.68717 .00027 L
.68741 .00042 L
.68764 .00015 L
.68787 .00029 L
.6881 .00035 L
.68834 .00046 L
.68857 8e-05 L
.6888 .00053 L
.68903 6e-05 L
.68927 .00054 L
.6895 .00035 L
.68973 .00034 L
.68996 .00044 L
.6902 .0003 L
.69043 .00033 L
.69066 .00025 L
.69089 .00017 L
.69113 .00054 L
.69136 .00062 L
.69159 .00022 L
.69182 .00029 L
.69206 7e-05 L
.69229 .00026 L
.69252 .00019 L
.69275 .00016 L
.69299 .00012 L
.69322 .00037 L
.69345 .00038 L
.69368 .00031 L
.69392 .00036 L
.69415 .00032 L
.69438 .00029 L
.69461 .00015 L
.69485 .00047 L
.69508 .0003 L
.69531 .00047 L
.69555 .00075 L
.69578 .00043 L
.69601 .00021 L
.69624 .00034 L
.69648 .0007 L
.69671 .00039 L
.69694 .00019 L
.69717 .00024 L
.69741 .00012 L
.69764 .00071 L
.69787 .00018 L
Mistroke
.6981 .00035 L
.69834 .00027 L
.69857 .00077 L
.6988 .00051 L
.69903 .00046 L
.69927 .00018 L
.6995 .00063 L
.69973 .00034 L
.69996 .00029 L
.7002 .00049 L
.70043 7e-05 L
.70066 .00028 L
.70089 .00046 L
.70113 .00035 L
.70136 .00027 L
.70159 .00022 L
.70182 2e-05 L
.70206 .00046 L
.70229 .00065 L
.70252 .0004 L
.70275 .00053 L
.70299 .00021 L
.70322 .00054 L
.70345 .00058 L
.70368 .00073 L
.70392 .00057 L
.70415 .00025 L
.70438 .00025 L
.70461 .00051 L
.70485 .00024 L
.70508 .00047 L
.70531 .00031 L
.70554 .00035 L
.70578 .00022 L
.70601 .00053 L
.70624 .00034 L
.70647 .00041 L
.70671 .00043 L
.70694 .0003 L
.70717 .00025 L
.7074 .00056 L
.70764 .00045 L
.70787 .00082 L
.7081 .00031 L
.70833 .00075 L
.70857 .00061 L
.7088 .0008 L
.70903 7e-05 L
.70926 .00049 L
.7095 .0006 L
Mistroke
.70973 .00011 L
.70996 .00055 L
.71019 .00033 L
.71043 .00051 L
.71066 .00026 L
.71089 .00043 L
.71112 .00075 L
.71136 .00068 L
.71159 .00018 L
.71182 .00072 L
.71205 .00031 L
.71229 .00014 L
.71252 .00077 L
.71275 .00078 L
.71298 .00043 L
.71322 .00062 L
.71345 .00025 L
.71368 .00084 L
.71391 .00056 L
.71415 .00048 L
.71438 .00035 L
.71461 .00057 L
.71484 .00023 L
.71508 .00024 L
.71531 .0003 L
.71554 .00082 L
.71577 .00069 L
.71601 .00043 L
.71624 .00067 L
.71647 .00023 L
.7167 .00059 L
.71694 .00058 L
.71717 .00052 L
.7174 .00073 L
.71763 .00055 L
.71787 .00056 L
.7181 .00032 L
.71833 .00088 L
.71856 .00089 L
.7188 .00074 L
.71903 .00057 L
.71926 .00044 L
.71949 .00086 L
.71973 .00038 L
.71996 .00117 L
.72019 .0005 L
.72042 .00051 L
.72066 .00032 L
.72089 .0007 L
.72112 .00033 L
Mistroke
.72135 .00064 L
.72159 .00071 L
.72182 .00038 L
.72205 .00059 L
.72228 .00114 L
.72252 .00066 L
.72275 .00041 L
.72298 .0004 L
.72321 .00049 L
.72345 .00078 L
.72368 .00057 L
.72391 .00077 L
.72414 .00118 L
.72438 .00115 L
.72461 .00055 L
.72484 .00041 L
.72507 .00028 L
.72531 .0006 L
.72554 .00031 L
.72577 .00084 L
.726 .00065 L
.72624 .00056 L
.72647 .00015 L
.7267 .00054 L
.72693 .00096 L
.72717 .00011 L
.7274 .0007 L
.72763 .00037 L
.72786 .00095 L
.7281 .0004 L
.72833 .00054 L
.72856 .00046 L
.72879 .00106 L
.72903 .00064 L
.72926 .00026 L
.72949 .00069 L
.72972 .00067 L
.72996 .0005 L
.73019 .00093 L
.73042 .00059 L
.73065 .00104 L
.73089 .00079 L
.73112 .0003 L
.73135 .00068 L
.73158 .0003 L
.73182 .0006 L
.73205 .00062 L
.73228 .00126 L
.73251 .00066 L
.73275 .00094 L
Mistroke
.73298 .0009 L
.73321 .00025 L
.73344 .00157 L
.73368 .00091 L
.73391 .00076 L
.73414 .00074 L
.73438 .00097 L
.73461 .00029 L
.73484 .00079 L
.73507 .00054 L
.73531 .00014 L
.73554 .00095 L
.73577 .00012 L
.736 .00127 L
.73624 .00076 L
.73647 .00093 L
.7367 .00077 L
.73693 .0005 L
.73717 .00081 L
.7374 .00046 L
.73763 .00094 L
.73786 .00145 L
.7381 .00088 L
.73833 .00033 L
.73856 .00133 L
.73879 .00119 L
.73903 .00091 L
.73926 .00044 L
.73949 .00071 L
.73972 .00118 L
.73996 .00028 L
.74019 .00027 L
.74042 .00051 L
.74065 .00085 L
.74089 .00075 L
.74112 .00097 L
.74135 .0005 L
.74158 .00085 L
.74182 .00101 L
.74205 .00064 L
.74228 .00122 L
.74251 .00041 L
.74275 .00024 L
.74298 .00062 L
.74321 .00073 L
.74344 .00096 L
.74368 .00031 L
.74391 .0012 L
.74414 .00094 L
.74437 .00049 L
Mistroke
.74461 .00044 L
.74484 .00084 L
.74507 .00033 L
.7453 .00113 L
.74554 .00057 L
.74577 .00042 L
.746 .0002 L
.74623 .00018 L
.74647 .0008 L
.7467 .00016 L
.74693 .00109 L
.74716 .0008 L
.7474 .00111 L
.74763 .00103 L
.74786 .00038 L
.74809 .0005 L
.74833 .00062 L
.74856 .00085 L
.74879 .00088 L
.74902 .00068 L
.74926 .00105 L
.74949 .00062 L
.74972 .0003 L
.74995 .00072 L
.75019 .00052 L
.75042 .00086 L
.75065 .00027 L
.75088 .00058 L
.75112 .00106 L
.75135 .00084 L
.75158 .00035 L
.75181 .00072 L
.75205 .0004 L
.75228 .00108 L
.75251 .0017 L
.75274 .0011 L
.75298 .00091 L
.75321 .00137 L
.75344 .00049 L
.75367 .00105 L
.75391 .0015 L
.75414 .00055 L
.75437 .00033 L
.7546 .00057 L
.75484 .00052 L
.75507 .00085 L
.7553 7e-05 L
.75553 .00069 L
.75577 .00064 L
.756 .0004 L
Mistroke
.75623 .00096 L
.75646 .00091 L
.7567 .00068 L
.75693 .00085 L
.75716 .00154 L
.75739 .00081 L
.75763 .00073 L
.75786 .00054 L
.75809 .00094 L
.75832 .00057 L
.75856 .00068 L
.75879 .00058 L
.75902 .00039 L
.75925 .00069 L
.75949 .00126 L
.75972 .00048 L
.75995 .00108 L
.76018 .00125 L
.76042 .00135 L
.76065 .00038 L
.76088 .0005 L
.76111 .00117 L
.76135 .00042 L
.76158 .00046 L
.76181 .00106 L
.76204 .00055 L
.76228 .00065 L
.76251 .00115 L
.76274 .00076 L
.76297 .00034 L
.76321 .00079 L
.76344 .0004 L
.76367 .00059 L
.7639 .00172 L
.76414 .00078 L
.76437 .00044 L
.7646 .00087 L
.76483 .00066 L
.76507 .00092 L
.7653 .00114 L
.76553 .00016 L
.76576 .00114 L
.766 .00028 L
.76623 .00108 L
.76646 .00046 L
.76669 .00045 L
.76693 .00084 L
.76716 .00083 L
.76739 .0001 L
.76762 .00051 L
Mistroke
.76786 .00077 L
.76809 .00055 L
.76832 .00078 L
.76855 .00073 L
.76879 .00085 L
.76902 .00156 L
.76925 .00104 L
.76948 .00135 L
.76972 .00053 L
.76995 .00056 L
.77018 .00039 L
.77041 .00156 L
.77065 .00059 L
.77088 .00166 L
.77111 .00099 L
.77134 .00097 L
.77158 .00032 L
.77181 .00047 L
.77204 .0001 L
.77227 .00036 L
.77251 .00091 L
.77274 .00073 L
.77297 .00118 L
.7732 .00071 L
.77344 .00099 L
.77367 .00053 L
.7739 .00108 L
.77414 .00022 L
.77437 .00137 L
.7746 .00032 L
.77483 .00114 L
.77507 .00128 L
.7753 .00068 L
.77553 .00024 L
.77576 .00107 L
.776 .00144 L
.77623 .00016 L
.77646 .00042 L
.77669 .00054 L
.77693 .00139 L
.77716 .00103 L
.77739 .00071 L
.77762 .00034 L
.77786 .00066 L
.77809 .00048 L
.77832 .00059 L
.77855 .0006 L
.77879 .00084 L
.77902 .00024 L
.77925 .00037 L
Mistroke
.77948 .00104 L
.77972 .00047 L
.77995 .00052 L
.78018 .00038 L
.78041 .00083 L
.78065 .00021 L
.78088 .00016 L
.78111 .001 L
.78134 .00012 L
.78158 .00066 L
.78181 .00138 L
.78204 .00087 L
.78227 .00059 L
.78251 .00068 L
.78274 8e-05 L
.78297 .00118 L
.7832 .00067 L
.78344 .00031 L
.78367 .00034 L
.7839 .00052 L
.78413 .00098 L
.78437 .00066 L
.7846 .00014 L
.78483 .00109 L
.78506 .0011 L
.7853 .00043 L
.78553 .00045 L
.78576 .00037 L
.78599 .00115 L
.78623 .00051 L
.78646 .00084 L
.78669 .00069 L
.78692 .00142 L
.78716 .00022 L
.78739 .00037 L
.78762 .00068 L
.78785 .00026 L
.78809 .00072 L
.78832 .00074 L
.78855 .00054 L
.78878 .00033 L
.78902 .00057 L
.78925 .00181 L
.78948 .00037 L
.78971 .00076 L
.78995 .00057 L
.79018 .0007 L
.79041 .00059 L
.79064 .00121 L
.79088 .00055 L
Mistroke
.79111 .00029 L
.79134 .00012 L
.79157 .00047 L
.79181 .00037 L
.79204 .00091 L
.79227 .00095 L
.7925 .00089 L
.79274 .00036 L
.79297 .00049 L
.7932 .00074 L
.79343 .00045 L
.79367 .00066 L
.7939 .00019 L
.79413 .001 L
.79436 .00078 L
.7946 .00047 L
.79483 .00098 L
.79506 .00029 L
.79529 .00072 L
.79553 .00085 L
.79576 .00025 L
.79599 .00021 L
.79622 .00041 L
.79646 .00069 L
.79669 .00054 L
.79692 .00046 L
.79715 .00048 L
.79739 .00053 L
.79762 9e-05 L
.79785 .00105 L
.79808 .00036 L
.79832 .00041 L
.79855 .00028 L
.79878 .00051 L
.79901 .00071 L
.79925 .00129 L
.79948 .00045 L
.79971 .00036 L
.79994 8e-05 L
.80018 .00026 L
.80041 .00028 L
.80064 .00026 L
.80087 .0009 L
.80111 .0009 L
.80134 .00062 L
.80157 .00053 L
.8018 .00126 L
.80204 .00123 L
.80227 .00058 L
.8025 .00062 L
Mistroke
.80273 .00095 L
.80297 .00091 L
.8032 .00052 L
.80343 .00041 L
.80366 .00067 L
.8039 .00078 L
.80413 .00059 L
.80436 .00033 L
.80459 .00093 L
.80483 .00054 L
.80506 .0007 L
.80529 .00018 L
.80552 .00049 L
.80576 .00052 L
.80599 .00055 L
.80622 .00087 L
.80645 .00025 L
.80669 .00055 L
.80692 .00046 L
.80715 .00012 L
.80738 .00053 L
.80762 .0001 L
.80785 .00049 L
.80808 .00071 L
.80831 .00059 L
.80855 .00041 L
.80878 .00063 L
.80901 .00054 L
.80924 5e-05 L
.80948 .00024 L
.80971 .00045 L
.80994 .00079 L
.81017 .00076 L
.81041 .00028 L
.81064 .00025 L
.81087 .00047 L
.8111 .0006 L
.81134 .00045 L
.81157 .00061 L
.8118 .00011 L
.81203 .00042 L
.81227 .00066 L
.8125 .00069 L
.81273 .00081 L
.81297 .00047 L
.8132 .00045 L
.81343 .00022 L
.81366 .00057 L
.8139 .00059 L
.81413 .00078 L
Mistroke
.81436 .00061 L
.81459 .00021 L
.81483 .0001 L
.81506 .00042 L
.81529 .00074 L
.81552 .00015 L
.81576 .0006 L
.81599 .00065 L
.81622 .00085 L
.81645 .00019 L
.81669 .00042 L
.81692 .00029 L
.81715 .00054 L
.81738 .00013 L
.81762 .00058 L
.81785 .00016 L
.81808 .00033 L
.81831 .0005 L
.81855 .00088 L
.81878 .00042 L
.81901 .0002 L
.81924 .00036 L
.81948 9e-05 L
.81971 .0006 L
.81994 .00068 L
.82017 .00085 L
.82041 .00059 L
.82064 .00085 L
.82087 .00012 L
.8211 .0002 L
.82134 .0007 L
.82157 .00012 L
.8218 .00047 L
.82203 .00055 L
.82227 .00069 L
.8225 .00027 L
.82273 7e-05 L
.82296 .00018 L
.8232 .00051 L
.82343 .00023 L
.82366 .00064 L
.82389 .00038 L
.82413 .00026 L
.82436 .00037 L
.82459 .00067 L
.82482 .00057 L
.82506 .00044 L
.82529 .00023 L
.82552 .00038 L
.82575 .0005 L
Mistroke
.82599 .00054 L
.82622 .00036 L
.82645 .00012 L
.82668 .00021 L
.82692 .00056 L
.82715 .00067 L
.82738 .00019 L
.82761 .00028 L
.82785 .00017 L
.82808 .00015 L
.82831 .00031 L
.82854 .00025 L
.82878 .00073 L
.82901 .00035 L
.82924 .00014 L
.82947 .0004 L
.82971 .00032 L
.82994 .00018 L
.83017 .00082 L
.8304 .00034 L
.83064 .00064 L
.83087 .00018 L
.8311 .00023 L
.83133 .0006 L
.83157 .00024 L
.8318 .00026 L
.83203 .00063 L
.83226 .00029 L
.8325 .0002 L
.83273 .00033 L
.83296 .00026 L
.83319 .00034 L
.83343 7e-05 L
.83366 .00036 L
.83389 .00038 L
.83412 .00034 L
.83436 .00014 L
.83459 .00011 L
.83482 .00047 L
.83505 .00043 L
.83529 .0003 L
.83552 .00051 L
.83575 .00031 L
.83598 .00049 L
.83622 .00063 L
.83645 .00029 L
.83668 .00044 L
.83691 .00034 L
.83715 .00026 L
.83738 .00043 L
Mistroke
.83761 .00054 L
.83784 .00034 L
.83808 .0001 L
.83831 1e-05 L
.83854 .00022 L
.83877 .00049 L
.83901 .00041 L
.83924 .00055 L
.83947 .00025 L
.8397 .00011 L
.83994 .00013 L
.84017 .00029 L
.8404 .00025 L
.84063 .00043 L
.84087 .00044 L
.8411 .00032 L
.84133 .00024 L
.84156 .00063 L
.8418 9e-05 L
.84203 .00028 L
.84226 .00049 L
.84249 .00039 L
.84273 .00028 L
.84296 .0003 L
.84319 .00042 L
.84342 .00017 L
.84366 .0005 L
.84389 .00042 L
.84412 .00022 L
.84435 .0005 L
.84459 .00016 L
.84482 .0003 L
.84505 .00044 L
.84528 .00058 L
.84552 .00056 L
.84575 .00027 L
.84598 .00026 L
.84621 .00022 L
.84645 .00024 L
.84668 .00057 L
.84691 .00023 L
.84714 .00043 L
.84738 .00031 L
.84761 .00035 L
.84784 .0003 L
.84807 .00063 L
.84831 .00047 L
.84854 .0005 L
.84877 .00031 L
.849 6e-05 L
Mistroke
.84924 .00036 L
.84947 .00031 L
.8497 8e-05 L
.84993 .00082 L
.85017 .00032 L
.8504 .00043 L
.85063 .00061 L
.85086 .0003 L
.8511 .00013 L
.85133 .00023 L
.85156 .00048 L
.8518 7e-05 L
.85203 .00015 L
.85226 .00042 L
.85249 .00038 L
.85273 .00048 L
.85296 .00025 L
.85319 .00029 L
.85342 .00051 L
.85366 .00035 L
.85389 .00021 L
.85412 .00051 L
.85435 .00031 L
.85459 .00024 L
.85482 .00035 L
.85505 .00028 L
.85528 .0004 L
.85552 .00027 L
.85575 .00078 L
.85598 .00055 L
.85621 .0003 L
.85645 .0001 L
.85668 .00044 L
.85691 .00053 L
.85714 5e-05 L
.85738 .00023 L
.85761 5e-05 L
.85784 .00049 L
.85807 .00011 L
.85831 .0006 L
.85854 .00051 L
.85877 .00017 L
.859 .00046 L
.85924 .00019 L
.85947 .00031 L
.8597 .00069 L
.85993 .00015 L
.86017 .00035 L
.8604 .00031 L
.86063 .00047 L
Mistroke
.86086 .00022 L
.8611 .00027 L
.86133 .00019 L
.86156 .00015 L
.86179 .00046 L
.86203 .00023 L
.86226 .00049 L
.86249 .00021 L
.86272 .00028 L
.86296 .00035 L
.86319 .00063 L
.86342 .00043 L
.86365 .00024 L
.86389 .00039 L
.86412 .00014 L
.86435 .00037 L
.86458 .00028 L
.86482 .00046 L
.86505 .00014 L
.86528 .00013 L
.86551 .00035 L
.86575 .00031 L
.86598 .00017 L
.86621 .00043 L
.86644 .00021 L
.86668 .00037 L
.86691 .0003 L
.86714 .0006 L
.86737 .00032 L
.86761 .0001 L
.86784 .00033 L
.86807 .00034 L
.8683 .00025 L
.86854 9e-05 L
.86877 .00027 L
.869 2e-05 L
.86923 .00035 L
.86947 3e-05 L
.8697 .0008 L
.86993 .00031 L
.87016 .0002 L
.8704 .00032 L
.87063 .00049 L
.87086 .00023 L
.87109 8e-05 L
.87133 .00019 L
.87156 .00028 L
.87179 .00016 L
.87202 .00051 L
.87226 .00019 L
Mistroke
.87249 .00016 L
.87272 .00018 L
.87295 .00011 L
.87319 .00018 L
.87342 .00033 L
.87365 .00024 L
.87388 .00035 L
.87412 .00037 L
.87435 .00026 L
.87458 .00017 L
.87481 7e-05 L
.87505 .00027 L
.87528 .00033 L
.87551 .0001 L
.87574 .00026 L
.87598 .00012 L
.87621 .00022 L
.87644 .00034 L
.87667 .00027 L
.87691 .00018 L
.87714 .00032 L
.87737 .00034 L
.8776 .00031 L
.87784 .00013 L
.87807 .00022 L
.8783 .00018 L
.87853 .00018 L
.87877 .00036 L
.879 .00013 L
.87923 9e-05 L
.87946 .00038 L
.8797 9e-05 L
.87993 .00041 L
.88016 .00027 L
.88039 .00037 L
.88063 .00016 L
.88086 .00012 L
.88109 .00017 L
.88132 .00018 L
.88156 .0002 L
.88179 .00061 L
.88202 6e-05 L
.88225 .00046 L
.88249 .00011 L
.88272 .00035 L
.88295 .00014 L
.88318 .00014 L
.88342 .00018 L
.88365 .00026 L
.88388 .00018 L
Mistroke
.88411 .00036 L
.88435 .00043 L
.88458 .00066 L
.88481 .00022 L
.88504 .00037 L
.88528 .00026 L
.88551 .00042 L
.88574 5e-05 L
.88597 .00023 L
.88621 .00011 L
.88644 .00037 L
.88667 .00019 L
.8869 9e-05 L
.88714 .00037 L
.88737 .00023 L
.8876 .00017 L
.88783 .00025 L
.88807 .0002 L
.8883 .00021 L
.88853 .00015 L
.88876 .00058 L
.889 .00033 L
.88923 .00032 L
.88946 .00016 L
.88969 6e-05 L
.88993 .00011 L
.89016 .00033 L
.89039 .00031 L
.89063 .00027 L
.89086 .00014 L
.89109 .00013 L
.89132 .00026 L
.89156 .00019 L
.89179 .0004 L
.89202 2e-05 L
.89225 .00029 L
.89249 .00037 L
.89272 8e-05 L
.89295 .00021 L
.89318 .00017 L
.89342 .00031 L
.89365 .00037 L
.89388 .00027 L
.89411 .00026 L
.89435 .00024 L
.89458 .00017 L
.89481 .00011 L
.89504 .00025 L
.89528 .00018 L
.89551 .00017 L
Mistroke
.89574 .00017 L
.89597 .00018 L
.89621 .00022 L
.89644 .00034 L
.89667 .00024 L
.8969 .00011 L
.89714 .00022 L
.89737 .00035 L
.8976 .00018 L
.89783 .00041 L
.89807 .00017 L
.8983 .00017 L
.89853 .00016 L
.89876 .00012 L
.899 .00026 L
.89923 .00017 L
.89946 .00033 L
.89969 .00042 L
.89993 .00028 L
.90016 .00029 L
.90039 .00025 L
.90062 .00033 L
.90086 .00034 L
.90109 .00021 L
.90132 .00016 L
.90155 .00015 L
.90179 .00012 L
.90202 .00048 L
.90225 .00019 L
.90248 .00018 L
.90272 .00026 L
.90295 .00019 L
.90318 .00037 L
.90341 .00029 L
.90365 .00014 L
.90388 .00038 L
.90411 .00021 L
.90434 .00024 L
.90458 .00036 L
.90481 5e-05 L
.90504 .00022 L
.90527 .00014 L
.90551 .00016 L
.90574 .00029 L
.90597 .00029 L
.9062 .00016 L
.90644 .00029 L
.90667 .00015 L
.9069 .00053 L
.90713 .00024 L
Mistroke
.90737 .00022 L
.9076 .00018 L
.90783 7e-05 L
.90806 .00018 L
.9083 .00031 L
.90853 .00029 L
.90876 .00024 L
.90899 .00028 L
.90923 6e-05 L
.90946 .00014 L
.90969 .00026 L
.90992 .00014 L
.91016 .00027 L
.91039 .00031 L
.91062 .00015 L
.91085 .00027 L
.91109 .00026 L
.91132 .00013 L
.91155 .0003 L
.91178 .00019 L
.91202 .00014 L
.91225 7e-05 L
.91248 .00015 L
.91271 .0002 L
.91295 .00015 L
.91318 .00027 L
.91341 .00023 L
.91364 .00012 L
.91388 .00028 L
.91411 .0002 L
.91434 .00037 L
.91457 .00023 L
.91481 .0003 L
.91504 .00016 L
.91527 .00026 L
.9155 .00015 L
.91574 .00014 L
.91597 .0003 L
.9162 .00012 L
.91643 .00012 L
.91667 .00013 L
.9169 .00021 L
.91713 .00026 L
.91736 .00016 L
.9176 .00027 L
.91783 .00025 L
.91806 .00015 L
.91829 .00017 L
.91853 .00025 L
.91876 .0002 L
Mistroke
.91899 .00021 L
.91922 8e-05 L
.91946 .00025 L
.91969 .00023 L
.91992 .00018 L
.92015 .00026 L
.92039 .00022 L
.92062 .00026 L
.92085 .00024 L
.92108 .00017 L
.92132 .00017 L
.92155 .00012 L
.92178 .00022 L
.92201 .00013 L
.92225 .00016 L
.92248 .00024 L
.92271 .00018 L
.92294 .0001 L
.92318 .00016 L
.92341 .00013 L
.92364 .00019 L
.92387 .00012 L
.92411 .00012 L
.92434 .00023 L
.92457 .00022 L
.9248 .00018 L
.92504 .00025 L
.92527 .00012 L
.9255 .00012 L
.92573 .0002 L
.92597 .00017 L
.9262 9e-05 L
.92643 .00028 L
.92666 .00021 L
.9269 .00017 L
.92713 .00023 L
.92736 .00025 L
.92759 .00016 L
.92783 .00012 L
.92806 .00033 L
.92829 .00019 L
.92852 9e-05 L
.92876 .00023 L
.92899 .00016 L
.92922 .0002 L
.92945 .00013 L
.92969 .00026 L
.92992 .00022 L
.93015 .0002 L
.93039 .00017 L
Mistroke
.93062 .00017 L
.93085 .00014 L
.93108 .00022 L
.93132 .00017 L
.93155 .00011 L
.93178 .00026 L
.93201 .00018 L
.93225 .0003 L
.93248 .00024 L
.93271 .00016 L
.93294 .00022 L
.93318 .00022 L
.93341 .00023 L
.93364 .00024 L
.93387 .00022 L
.93411 .00023 L
.93434 .00024 L
.93457 .00012 L
.9348 .00016 L
.93504 .0003 L
.93527 .0003 L
.9355 6e-05 L
.93573 .00023 L
.93597 .00013 L
.9362 .00026 L
.93643 .00011 L
.93666 .00022 L
.9369 .00011 L
.93713 .00016 L
.93736 .00023 L
.93759 .00014 L
.93783 .00017 L
.93806 6e-05 L
.93829 .00031 L
.93852 .0004 L
.93876 .00015 L
.93899 .0002 L
.93922 .00023 L
.93945 .00014 L
.93969 .00015 L
.93992 .00027 L
.94015 7e-05 L
.94038 .00017 L
.94062 .00031 L
.94085 .00024 L
.94108 .00011 L
.94131 .00032 L
.94155 .00014 L
.94178 .0003 L
.94201 .00043 L
Mistroke
.94224 .00024 L
.94248 .00021 L
.94271 .00039 L
.94294 .00022 L
.94317 .00016 L
.94341 .00026 L
.94364 .00035 L
.94387 .00023 L
.9441 .00026 L
.94434 .00024 L
.94457 .00023 L
.9448 .00028 L
.94503 .00031 L
.94527 .00014 L
.9455 .00026 L
.94573 .00033 L
.94596 .00034 L
.9462 .00023 L
.94643 .00024 L
.94666 .00015 L
.94689 .00019 L
.94713 .00036 L
.94736 .00026 L
.94759 .00036 L
.94782 5e-05 L
.94806 .00024 L
.94829 .00011 L
.94852 .00031 L
.94875 6e-05 L
.94899 .00019 L
.94922 .00018 L
.94945 .00034 L
.94968 .00027 L
.94992 .00028 L
.95015 .00029 L
.95038 .00026 L
.95061 .00031 L
.95085 .00011 L
.95108 .00022 L
.95131 .00017 L
.95154 9e-05 L
.95178 .00024 L
.95201 7e-05 L
.95224 .00017 L
.95247 .00012 L
.95271 .00038 L
.95294 .00022 L
.95317 .00018 L
.9534 .00011 L
.95364 .00014 L
Mistroke
.95387 .00031 L
.9541 .00035 L
.95433 .00014 L
.95457 .00026 L
.9548 .00027 L
.95503 .00023 L
.95526 .0002 L
.9555 .00019 L
.95573 .00017 L
.95596 .00017 L
.95619 .0004 L
.95643 7e-05 L
.95666 .00027 L
.95689 .00014 L
.95712 .00037 L
.95736 .00032 L
.95759 .00013 L
.95782 .00026 L
.95805 .00028 L
.95829 .00032 L
.95852 5e-05 L
.95875 .00025 L
.95898 .00016 L
.95922 .00026 L
.95945 .00026 L
.95968 .00024 L
.95991 .00031 L
.96015 .00013 L
.96038 .00015 L
.96061 .00014 L
.96084 .00031 L
.96108 9e-05 L
.96131 .00019 L
.96154 .00027 L
.96177 .00012 L
.96201 .00011 L
.96224 3e-05 L
.96247 .00028 L
.9627 .00027 L
.96294 .0003 L
.96317 .00026 L
.9634 .00016 L
.96363 .00018 L
.96387 .00035 L
.9641 .00026 L
.96433 .00018 L
.96456 .00037 L
.9648 .00025 L
.96503 .00015 L
.96526 .00024 L
Mistroke
.96549 .00016 L
.96573 .00024 L
.96596 6e-05 L
.96619 .00017 L
.96642 .00022 L
.96666 .00016 L
.96689 .00024 L
.96712 .00026 L
.96735 .00017 L
.96759 .00035 L
.96782 .00013 L
.96805 .00016 L
.96828 .00018 L
.96852 .00028 L
.96875 .00032 L
.96898 .00013 L
.96922 .00025 L
.96945 .00016 L
.96968 .00017 L
.96991 .0004 L
.97015 .00028 L
.97038 .00021 L
.97061 .00042 L
.97084 .0002 L
.97108 .00037 L
.97131 .00014 L
.97154 .00023 L
.97177 .00016 L
.97201 .00017 L
.97224 .00023 L
.97247 .00024 L
.9727 .00016 L
.97294 .0003 L
.97317 .0002 L
.9734 .00021 L
.97363 .00021 L
.97387 .00052 L
.9741 .0003 L
.97433 6e-05 L
.97456 .00034 L
.9748 .00019 L
.97503 .00018 L
.97526 .00022 L
.97549 .0002 L
.97573 .00034 L
.97596 .00025 L
.97619 8e-05 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{62, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol0041oo`<000Aoo`8000Aoo`8000Ao
o`8001Uoo`@000=oo`8000Aoo`8000Aoo`8001Yoo`<000Aoo`8000Aoo`8000Aoo`8001Yoo`<000=o
o`8000Aoo`8000Aoo`80041oo`00@Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0002
Ool01000Oomoo`006Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0002Ool01000Oomo
o`0077oo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`000Woo00<007ooOol067oo00D0
07ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`000Woo00<007ooOol0?Goo0011Ool00`00
Oomoo`02Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo000JOol01@00Oomoogoo0000
0Woo00@007ooOol0009oo`04001oogoo0002Ool00`00Oomoo`0JOol01000Oomoo`000Woo00@007oo
Ool0009oo`04001oogoo0002Ool00`00Oomoo`0FOol40002Ool01000Oomoo`000Woo00@007ooOol0
009oo`04001oogoo000oOol0045oo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000Woo
00@007ooOol001]oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol0009oo`03001oogoo
01Qoo`8000=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol001Qoo`03001oo`0000=o
o`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol003moo`00@Goo00<007ooOol00Woo00@0
07ooOol0009oo`04001oogoo0002Ool01000Oomoo`0067oo00@007ooOol0009oo`04001oogoo0002
Ool01000Oomoo`000Woo00@007ooOol001aoo`04001oogoo0002Ool01000Oomoo`000Woo00@007oo
Ool0009oo`03001oogoo01Ioo`03001oo`0000=oo`04001oogoo0002Ool01000Oomoo`000Woo00@0
07ooOol003moo`00@7oo0P001Goo0P0017oo0P0017oo0P006Woo0P0017oo0P0017oo0P0017oo0P00
6Woo0`0017oo0P0017oo0P0017oo0P006Woo0P0017oo0P0017oo0P0017oo0P00@7oo003lOol4000G
Ool30006Ool00?ioo`03001oogoo01Moo`03001oogoo00Eoo`00j7oo10000Woo10000goo10000Woo
100000=oo`0000000`000Woo100000Aoo`00001oo`80009oo`<000=oo`03001oogoo00Aoo`007Goo
00<007ooOol02Woo0P000goo0`0000Yoo`00001oo`00Ool007oo001oo`800004Ool007oo000FOol2
00000goo0000000D0002Ool200000goo001oo`07000017oo000007oo2`0000=oo`000000400000Eo
o`00001oo`00009oo`800003Ool0000000800003Ool0000000<00003Ool0000000@00003Ool00000
01d000eoo`03001oogoo00=oo`03001oogoo009oo`03001oogoo00=oo`07001oogooOol007oo0000
0Woo00@007ooOol000Eoo`04001oogoo0002Ool01@00Oomoogoo00000Woo00<007ooOol017oo000H
Ooo90008Ool00`00Oomoo`03Ool00`00Oomoo`02Ool500000goo001oo`02Ool00`00Ool00002Ool0
0`00Oomoo`0500001Goo001oogoo00000Woo00<007ooOol00goo00<007oo00001Goo000MOol8000R
Ool8000ZOol00`00Oomoo`0/Ool00`00Oomoo`0[Ool00`00Oomoo`0@Ool00`00Oomoo`03Ool20003
Ool01`00Oomoogoo001oo`0000=oo`03001oo`00009oo`04001oogoo0003Ool00`00Ool00002Ool0
1000Oomoo`000goo00D007oo001oo`0000Eoo`007Goo00<007ooOol0:Woo00@007oo000009Yoo`@0
009oo`800003Ool00000009oo`<000=oo`H00003Ool0000000=oo`<00003Ool0000000<000=oo`H0
0003Ool0000000Aoo`007Goo00<007ooOol0:Woo00<007oo0000W7oo00<007ooOol0=7oo000MOol0
0`00Oomoo`0ZOol00`00Ool0002LOol3000dOol001eoo`03001oogoo02]oo`800==oo`007Goo00<0
07ooOol0:goo0P00dgoo000MOol00`00Oomoo`0[Ool00`00Oomoo`3BOol001eoo`03001oogoo02]o
o`03001oogoo0=9oo`007Goo00<007ooOol0:goo00<007ooOol0dWoo000MOol00`00Oomoo`0[Ool0
0`00Oomoo`3BOol001eoo`03001oogoo02]oo`03001oogoo0=9oo`007Goo00<007ooOol0:goo00<0
07ooOol0dWoo000MOol00`00Oomoo`0[Ool00`00Oomoo`3BOol001eoo`03001oogoo02]oo`03001o
ogoo0=9oo`007Goo00<007ooOol0:goo00<007ooOol0dWoo000MOol00`00Oomoo`0[Ool00`00Oomo
o`3BOol001eoo`03001oogoo02]oo`03001oogoo0=9oo`007Goo00<007ooOol0:goo00<007ooOol0
dWoo000MOol00`00Oomoo`0[Ool00`00Oomoo`3BOol001eoo`03001oogoo02]oo`03001oogoo0=9o
o`007Goo00<007ooOol0:goo00<007ooOol0dWoo000:Ool20004Ool20003Ool40004Ool00`00Oomo
o`0[Ool00`00Oomoo`3BOol000Uoo`04001oogoo0003Ool20004Ool00`00Oomoo`04Ool00`00Oomo
o`0[Ool00`00Oomoo`3BOol000Uoo`04001oogoo000:Ool00`00Oomoo`03Ool2000/Ool00`00Oomo
o`3BOol000Uoo`04001oogoo000;Ool00`00Oomoo`02Ool00`00Oomoo`0[Ool00`00Oomoo`3BOol0
00Uoo`04001oogoo0008Ool01000Oomoo`0017oo00<007ooOol0:goo00<007ooOol0dWoo000:Ool2
000:Ool20005Ool00`00Oomoo`0[Ool00`00Oomoo`3BOol001eoo`03001oogoo02]oo`03001oogoo
0=9oo`007Goo00<007ooOol0:goo00<007ooOol0dWoo000MOol00`00Oomoo`0[Ool00`00Oomoo`3B
Ool001eoo`03001oogoo02]oo`03001oogoo0=9oo`007Goo00<007ooOol0:goo00<007ooOol0dWoo
000MOol00`00Oomoo`0[Ool00`00Oomoo`3BOol001eoo`03001oogoo02]oo`03001oogoo0=9oo`00
7Goo00<007ooOol0:goo00<007ooOol0dWoo000MOol00`00Oomoo`0[Ool00`00Oomoo`3BOol001eo
o`03001oogoo02]oo`03001oogoo0=9oo`007Goo00<007ooOol0:goo00<007ooOol0dWoo000MOol0
0`00Oomoo`0[Ool00`00Oomoo`3BOol001eoo`03001oogoo02]oo`03001oogoo0=9oo`007Goo00<0
07ooOol0:goo00<007ooOol0dWoo000MOol00`00Oomoo`0[Ool00`00Oomoo`3BOol001eoo`03001o
ogoo02]oo`03001oogoo0=9oo`007Goo00<007ooOol0:goo00<007ooOol0dWoo000MOol00`00Oomo
o`0[Ool00`00Oomoo`3BOol001eoo`03001oogoo02]oo`03001oogoo0=9oo`002Woo0P0017oo0P00
17oo0`0017oo00<007ooOol0:goo00<007ooOol0dWoo0009Ool01000Oomoo`000goo0P001Goo00<0
07ooOol00goo00<007ooOol0:goo00<007ooOol0dWoo0009Ool01000Oomoo`0027oo100017oo0P00
;7oo00<007ooOol0dWoo0009Ool01000Oomoo`0027oo00<007oo00001Goo00<007ooOol0:goo00<0
07ooOol0dWoo0009Ool01000Oomoo`0027oo00<007oo00001Goo00<007ooOol0:goo00<007ooOol0
dWoo000:Ool2000:Ool20005Ool00`00Oomoo`0[Ool00`00Oomoo`3BOol001eoo`03001oogoo02]o
o`03001oogoo0=9oo`007Goo00<007ooOol0:goo00<007ooOol0dWoo000MOol00`00Oomoo`0[Ool0
0`00Oomoo`3BOol001eoo`03001oogoo02]oo`03001oogoo0=9oo`007Goo00<007ooOol0:goo00<0
07ooOol0dWoo000MOol00`00Oomoo`0[Ool00`00Oomoo`3BOol001eoo`03001oogoo02]oo`03001o
ogoo0=9oo`007Goo00<007ooOol0:goo00<007ooOol0dWoo000MOol00`00Oomoo`0[Ool00`00Oomo
o`3BOol001eoo`03001oogoo02]oo`03001oogoo0=9oo`007Goo00<007ooOol0:goo00<007ooOol0
dWoo000MOol00`00Oomoo`0[Ool00`00Oomoo`3BOol001eoo`03001oogoo02]oo`03001oogoo0=9o
o`007Goo00<007ooOol0:goo00<007ooOol0dWoo000MOol00`00Oomoo`0[Ool00`00Oomoo`3BOol0
01eoo`03001oogoo02]oo`03001oogoo0=9oo`007Goo00<007ooOol0:goo00<007ooOol0dWoo000M
Ool00`00Oomoo`0[Ool00`00Oomoo`3BOol001eoo`03001oogoo02]oo`03001oogoo0=9oo`002Woo
0P0017oo0P0017oo0P001Goo00<007ooOol0:goo00<007ooOol0dWoo0009Ool01000Oomoo`000goo
0P000goo00@007ooOol000Aoo`03001oogoo02]oo`03001oogoo0=9oo`002Goo00@007ooOol000Qo
o`04001oogoo0004Ool2000/Ool00`00Oomoo`3BOol000Uoo`04001oogoo0008Ool30005Ool00`00
Oomoo`0[Ool00`00Oomoo`3BOol000Uoo`04001oogoo0008Ool00`00Oomoo`05Ool00`00Oomoo`0[
Ool00`00Oomoo`3BOol000Yoo`8000Yoo`<000Aoo`03001oogoo02]oo`03001oogoo0=9oo`007Goo
00<007ooOol0:goo00<007ooOol0dWoo000MOol00`00Oomoo`0[Ool00`00Oomoo`3BOol001eoo`03
001oogoo02]oo`03001oogoo0=9oo`007Goo00<007ooOol0:goo00<007ooOol0dWoo000MOol00`00
Oomoo`0[Ool00`00Oomoo`3BOol001eoo`03001oogoo02]oo`03001oogoo0=9oo`007Goo00<007oo
Ool0:goo00<007ooOol0dWoo000MOol00`00Oomoo`0[Ool00`00Oomoo`3BOol001eoo`03001oogoo
02]oo`03001oogoo0=9oo`007Goo00<007ooOol0:goo00<007ooOol0dWoo000MOol00`00Oomoo`0[
Ool00`00Oomoo`3BOol001eoo`03001oogoo02]oo`03001oogoo0=9oo`007Goo00<007ooOol0:goo
00<007ooOol0dWoo000MOol00`00Oomoo`0[Ool00`00Oomoo`3BOol001eoo`03001oogoo02]oo`03
001oogoo0=9oo`007Goo00<007ooOol0:goo00<007ooOol0dWoo000MOol00`00Oomoo`0[Ool00`00
Oomoo`3BOol001eoo`03001oogoo02]oo`03001oogoo0=9oo`002Woo0P0017oo0P0017oo0P001Goo
00<007ooOol0:goo00<007ooOol0dWoo0009Ool01000Oomoo`000goo0P000goo00@007ooOol000Ao
o`03001oogoo02]oo`03001oogoo0=9oo`002Goo00@007ooOol000Qoo`04001oogoo0004Ool2000/
Ool00`00Oomoo`3BOol000Uoo`04001oogoo0009Ool20005Ool00`00Oomoo`0[Ool00`00Oomoo`3B
Ool000Uoo`04001oogoo0008Ool01000Oomoo`0017oo00<007ooOol0:goo00<007ooOol0dWoo000:
Ool2000:Ool20005Ool00`00Oomoo`0[Ool00`00Oomoo`3BOol001eoo`03001oogoo02]oo`03001o
ogoo0=9oo`007Goo00<007ooOol0:goo00<007ooOol0dWoo000MOol00`00Oomoo`0[Ool00`00Oomo
o`3BOol001eoo`03001oogoo02]oo`03001oogoo0=9oo`007Goo00<007ooOol0:goo00<007ooOol0
dWoo000MOol00`00Oomoo`0[Ool00`00Oomoo`3BOol001eoo`03001oogoo02]oo`03001oogoo0=9o
o`007Goo00<007ooOol0:goo00<007ooOol0dWoo000MOol00`00Oomoo`0[Ool00`00Oomoo`3BOol0
01eoo`03001oogoo02]oo`03001oogoo0=9oo`007Goo00<007ooOol0:goo00<007ooOol0dWoo000M
Ool00`00Oomoo`0[Ool00`00Oomoo`3BOol001eoo`03001oogoo02]oo`03001oogoo0=9oo`007Goo
00<007ooOol0:goo00<007ooOol0dWoo000MOol00`00Oomoo`0[Ool00`00Oomoo`3BOol001eoo`03
001oogoo02]oo`03001oogoo0=9oo`007Goo00<007ooOol0:goo00<007ooOol0dWoo000MOol00`00
Oomoo`0[Ool00`00Oomoo`3BOol001eoo`03001oogoo02]oo`03001oogoo0=9oo`005Goo0`001Goo
00<007ooOol0:goo00<007ooOol0dWoo000FOol00`00Oomoo`04Ool00`00Oomoo`0[Ool00`00Oomo
o`3BOol001Ioo`03001oogoo00Aoo`8002aoo`03001oogoo0=9oo`005Woo00<007ooOol0ogoo27oo
000FOol00`00Oomoo`3oOol8Ool001Eoo`800?moo`Yoo`00ogoo8Goo003oOolQOol00?moob5oo`00
3Woo1000:goo0`000goo0`001Goo0`002Goo0`000Woo10001goo0P000Woo0P000Woo10000Woo0`00
0goo0`000Woo10000goo1@0000=oo`0000000P000Woo1@001Woo0`0017oo0`000Woo1@0000Aoo`00
001oo`80009oo`D006Aoo`003goo00<007ooOol0;7oo00<007ooOol00goo00<007ooOol01Goo00<0
07ooOol01goo00D007ooOomoo`00009oo`03001oogoo00Qoo`04001oo`000002Ool00`00Oomoo`03
Ool01`00Oomoogoo001oo`0000=oo`04001oogoo0004Ool01`00Oomoogoo001oo`0000Eoo`05001o
ogooOol00007Ool01000Oomoo`000Woo00L007ooOomoo`00Ool00002Ool01000Oomoo`000Woo00@0
07ooOol000=oo`03001oogoo06=oo`000goo1@0000Moo`00Ool007oo001oo`040002Ool500000goo
000000030002Ool30002Ool50002Ool500000goo000000020006Ool00`00Oomoo`03Ool00`00Oomo
o`05Ool00`00Oomoo`07Ool01@00Oomoogoo00000Woo00<007ooOol027oo0`000goo1@0000=oo`00
Ool017oo00D007ooOomoo`00009oo`03001oogoo009oo`06001oogooOol007oo1@0000=oo`00Ool0
0Woo00<007ooOol01goo0P000Woo00L007ooOomoo`00Ool00002Ool01000Oomoo`000Woo00@007oo
Ool000=oo`03001oogoo06=oo`000goo00@007ooOol0009oo`07001oo`00Ool007oo00000goo00D0
07ooOomoo`0000Eoo`03001oogoo009oo`06001oogoo001oo`000Woo00@007ooOol000=oo`03001o
o`0000Yoo`<000=oo`<000=oo`05001oo`00Ool00007Ool01@00Oomoogoo00000Woo00<007ooOol0
27oo00@007ooOol0009oo`07001oogooOol007oo00000goo00<007oo00000goo00<007ooOol00P00
0goo00L007ooOomoo`00Ool00003Ool00`00Ool00003Ool00`00Oomoo`05Ool20004Ool01`00Oomo
ogoo001oo`00009oo`04001oogoo0002Ool01000Oomoo`000goo00<007ooOol0Hgoo0003Ool40002
Ool01`00Ool007oo001oo`0000=oo`05001oogooOol00005Ool00`00Oomoo`02Ool00`00Oomoo`02
Ool01000Oomoo`000Woo00H007ooOomoo`00Ool50006Ool00`00Oomoo`03Ool00`00Oomoo`03Ool0
1@00Ool007oo000027oo0`000Woo100027oo00@007ooOol000=oo`<000=oo`@0009oo`<0009oo`80
0003Ool00000009oo`@0009oo`<000=oo`@000Moo`04001oogoo0003Ool3000017oo000007oo0P00
00=oo`0000000`000goo1000IGoo0006Ool02P00Oomoo`00Ool007oo001oo`000goo00D007ooOomo
o`0000Eoo`03001oogoo009oo`03001oogoo009oo`04001oogoo0002Ool01`00Oomoogoo001oo`00
00=oo`03001oogoo00=oo`D00003Ool0000000<0009oo`D000ioo`03001oogoo00Moo`@001moo`03
001oogoo00Uoo`03001oogoo00Ioo`<001Qoo`03001oogoo06=oo`0017oo0`0000=oo`0000002@00
17oo00<007ooOol00Woo0P000goo100000Aoo`00001oo`8000=oo`@0009oo`<002Ioo`<002Uoo`80
00Yoo`80029oo`8006Eoo`005goo00<007ooOol027oo00<007ooOol037oo00<007ooOol0k7oo000E
Ool30005Ool00`00Oomoo`02Ool00`00Oomoo`0;Ool2003^Ool00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-624.383, -0.194327, 
  21.5298, 0.00809988}}],

Cell[CellGroupData[{

Cell["\<\
Table[ListPlot[Transpose[{Range[0,Length[dataChunk[i]]/2], 
\t\tamplitude[dataChunk[i]]}],
\t\tPlotJoined->True,PlotRange->{{950,1050},{0,1}},
\t\tPlotLabel->\"FFT of Recorded Sound\",
\t\tAxesLabel->{\"frequency\",\"amplitude\"}],
\t\t{i,0,27}];\
\>", "Input",
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-9.5 0.01 0 0.618034 [
[.3 -0.0125 -9 -9 ]
[.3 -0.0125 9 0 ]
[.5 -0.0125 -12 -9 ]
[.5 -0.0125 12 0 ]
[.7 -0.0125 -12 -9 ]
[.7 -0.0125 12 0 ]
[.9 -0.0125 -12 -9 ]
[.9 -0.0125 12 0 ]
[1.025 0 0 -6 ]
[1.025 0 58 6 ]
[.0875 .12361 -18 -4.5 ]
[.0875 .12361 0 4.5 ]
[.0875 .24721 -18 -4.5 ]
[.0875 .24721 0 4.5 ]
[.0875 .37082 -18 -4.5 ]
[.0875 .37082 0 4.5 ]
[.0875 .49443 -18 -4.5 ]
[.0875 .49443 0 4.5 ]
[.0875 .61803 -6 -4.5 ]
[.0875 .61803 0 4.5 ]
[.1 .64303 -29 0 ]
[.1 .64303 29 12 ]
[.5 .63053 -65 0 ]
[.5 .63053 65 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.3 0 m
.3 .00625 L
s
[(980)] .3 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1000)] .5 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(1020)] .7 -0.0125 0 1 Mshowa
.9 0 m
.9 .00625 L
s
[(1040)] .9 -0.0125 0 1 Mshowa
.125 Mabswid
.15 0 m
.15 .00375 L
s
.2 0 m
.2 .00375 L
s
.25 0 m
.25 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.45 0 m
.45 .00375 L
s
.55 0 m
.55 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.75 0 m
.75 .00375 L
s
.8 0 m
.8 .00375 L
s
.85 0 m
.85 .00375 L
s
.05 0 m
.05 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(frequency) show
117.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.1 .12361 m
.10625 .12361 L
s
[(0.2)] .0875 .12361 1 0 Mshowa
.1 .24721 m
.10625 .24721 L
s
[(0.4)] .0875 .24721 1 0 Mshowa
.1 .37082 m
.10625 .37082 L
s
[(0.6)] .0875 .37082 1 0 Mshowa
.1 .49443 m
.10625 .49443 L
s
[(0.8)] .0875 .49443 1 0 Mshowa
.1 .61803 m
.10625 .61803 L
s
[(1)] .0875 .61803 1 0 Mshowa
.125 Mabswid
.1 .0309 m
.10375 .0309 L
s
.1 .0618 m
.10375 .0618 L
s
.1 .09271 m
.10375 .09271 L
s
.1 .15451 m
.10375 .15451 L
s
.1 .18541 m
.10375 .18541 L
s
.1 .21631 m
.10375 .21631 L
s
.1 .27812 m
.10375 .27812 L
s
.1 .30902 m
.10375 .30902 L
s
.1 .33992 m
.10375 .33992 L
s
.1 .40172 m
.10375 .40172 L
s
.1 .43262 m
.10375 .43262 L
s
.1 .46353 m
.10375 .46353 L
s
.1 .52533 m
.10375 .52533 L
s
.1 .55623 m
.10375 .55623 L
s
.1 .58713 m
.10375 .58713 L
s
.25 Mabswid
.1 0 m
.1 .61803 L
s
gsave
.1 .64303 -90 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(amplitude) show
117.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.5 .63053 -126 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(FFT) show
87.000000 13.000000 moveto
(of) show
105.000000 13.000000 moveto
(Recorded) show
159.000000 13.000000 moveto
(Sound) show
189.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .00542 m
.01 .00644 L
.02 .00667 L
.03 .00683 L
.04 .00586 L
.05 .00457 L
.06 .00622 L
.07 .00577 L
.08 .0056 L
.09 .00667 L
.1 .00648 L
.11 .00672 L
.12 .00654 L
.13 .00641 L
.14 .00755 L
.15 .00699 L
.16 .0081 L
.17 .00836 L
.18 .00734 L
.19 .00814 L
.2 .00848 L
.21 .01005 L
.22 .0086 L
.23 .0096 L
.24 .01024 L
.25 .0113 L
.26 .01163 L
.27 .01192 L
.28 .01113 L
.29 .01328 L
.3 .01293 L
.31 .01416 L
.32 .01483 L
.33 .01502 L
.34 .01559 L
.35 .01682 L
.36 .01822 L
.37 .01942 L
.38 .01962 L
.39 .02252 L
.4 .02272 L
.41 .02588 L
.42 .02689 L
.43 .03051 L
.44 .0342 L
.45 .03843 L
.46 .04504 L
.47 .05404 L
.48 .06545 L
.49 .0836 L
Mistroke
.5 .11505 L
.51 .19646 L
.52 .61803 L
.53 .55209 L
.54 .18954 L
.55 .11679 L
.56 .08184 L
.57 .06307 L
.58 .0518 L
.59 .04431 L
.6 .03775 L
.61 .03461 L
.62 .03014 L
.63 .02758 L
.64 .02448 L
.65 .02338 L
.66 .02085 L
.67 .01964 L
.68 .0189 L
.69 .01742 L
.7 .01688 L
.71 .01527 L
.72 .01547 L
.73 .01491 L
.74 .01354 L
.75 .01319 L
.76 .01233 L
.77 .01221 L
.78 .01122 L
.79 .01099 L
.8 .00921 L
.81 .01077 L
.82 .01002 L
.83 .00887 L
.84 .00998 L
.85 .0094 L
.86 .00878 L
.87 .00821 L
.88 .00791 L
.89 .00675 L
.9 .00766 L
.91 .00735 L
.92 .00724 L
.93 .0068 L
.94 .00693 L
.95 .00761 L
.96 .00641 L
.97 .00751 L
.98 .00676 L
.99 .00607 L
Mistroke
1 .00643 L
Mfstroke
1 .00643 m
1 .00643 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
@7oo0`0017oo0P0017oo0P006Goo0`0017oo0P0017oo0P0017oo0P005Woo0`0017oo0P000goo1000
0goo0P005Woo0`0017oo0P0017oo0`000goo0P00CGoo0013Ool01000Oomoo`000Woo00@007ooOol0
009oo`03001oogoo01Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000Woo00@007oo
Ool001Ioo`03001oogoo009oo`04001oogoo0003Ool00`00Oomoo`02Ool01000Oomoo`005Woo00<0
07ooOol00Woo00@007ooOol000Aoo`05001oogooOol00002Ool00`00Oomoo`1:Ool0045oo`<0009o
o`04001oogoo0002Ool01000Oomoo`006Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo
0002Ool01000Oomoo`005Woo00<007ooOol00Woo00@007ooOol000Aoo`05001oogooOol00002Ool0
0`00Oomoo`0DOol00`00Oomoo`02Ool01000Oomoo`000Woo10000Woo00@007ooOol004aoo`00@7oo
00@007ooOol000=oo`8000=oo`04001oogoo000IOol00`00Oomoo`02Ool01000Oomoo`000Woo00@0
07ooOol0009oo`04001oogoo000FOol00`00Oomoo`02Ool01000Oomoo`001Goo00@007ooOol0009o
o`03001oogoo01Aoo`03001oogoo009oo`04001oogoo0002Ool00`00Ool00003Ool01000Oomoo`00
C7oo0010Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo000IOol00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol0009oo`04001oogoo000FOol00`00Oomoo`02Ool01000Oomoo`00
0Woo00@007ooOol0009oo`04001oogoo000FOol00`00Oomoo`02Ool01000Oomoo`000Woo00<007oo
00000goo00@007ooOol004aoo`00@Goo0P0017oo0P0017oo0P006Goo0P001Goo0P0017oo0P0017oo
0P005Woo0P001Goo0P0017oo0P0017oo0P005Woo0P001Goo0P0017oo0P0017oo0P00:Goo10005goo
0`001Woo003nOol00`00Oomoo`0GOol00`00Oomoo`05Ool00>Qoo`@0009oo`@000=oo`@0009oo`@0
0003Ool0000000<0009oo`@00004Ool00000Ool20002Ool30003Ool00`00Oomoo`04Ool00>Uoo`03
001oogoo00=oo`03001oogoo009oo`03001oogoo00=oo`07001oogooOol007oo00000Woo00@007oo
Ool000Eoo`04001oogoo0002Ool01@00Oomoogoo00000Woo00<007ooOol017oo0007OooI0009Ool0
0`00Oomoo`03Ool00`00Oomoo`02Ool500000goo001oo`02Ool00`00Ool00002Ool00`00Oomoo`05
00001Goo001oogoo00000Woo00<007ooOol00goo00<007oo00001Goo000AOol30009Ool00`00Oomo
o`07Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomo
o`07Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomo
o`07Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomo
o`07Ool00`00Oomoo`08Ool00`00Oomoo`0BOol00`00Oomoo`03Ool20003Ool01`00Oomoogoo001o
o`0000=oo`03001oo`00009oo`04001oogoo0003Ool00`00Ool00002Ool01000Oomoo`000goo00D0
07oo001oo`0000Eoo`001goo2P000goo800000=oo`00000010003Goo00<007ooOol0:7oo00<007oo
Ool0:7oo00<007ooOol04Woo0`000goo100000=oo`000000800027oo10000Woo0P0000=oo`000000
0Woo0`000goo1P0000=oo`0000000goo0`0000=oo`0000000`000goo1P0000=oo`00000017oo000M
Ool00`00Oomoo`0DOol00`00Oomoo`04OolA001JOol=0003Ool30004Ool00`00Oomoo`0YOol00`00
Oomoo`0dOol001eoo`03001oogoo02aoo`/0049oo`d004=oo`<003Aoo`007Goo00<007ooOol0=goo
2@00<Woo1`00Qgoo000MOol00`00Oomoo`10Ool4000ZOol4002>Ool001eoo`03001oogoo04Aoo`80
02Ioo`80099oo`007Goo00<007ooOol0AWoo0P008Woo0P00U7oo000MOol00`00Oomoo`18Ool2000N
Ool2002FOol001eoo`03001oogoo04Yoo`8001Yoo`8009Qoo`007Goo00<007ooOol0C7oo00<007oo
Ool05Woo00<007ooOol0V7oo000MOol00`00Oomoo`1=Ool00`00Oomoo`0DOol00`00Oomoo`2IOol0
01eoo`03001oogoo04eoo`03001oogoo01=oo`03001oogoo09Yoo`007Goo00<007ooOol0CWoo00<0
07ooOol04Goo00<007ooOol0Vgoo000MOol00`00Oomoo`1?Ool00`00Oomoo`0@Ool00`00Oomoo`2K
Ool001eoo`03001oogoo04moo`03001oogoo00moo`03001oogoo09aoo`007Goo00<007ooOol0D7oo
00<007ooOol03Woo00<007ooOol0W7oo000MOol00`00Oomoo`1AOol00`00Oomoo`0<Ool00`00Oomo
o`2MOol001eoo`03001oogoo055oo`03001oogoo00aoo`03001oogoo09eoo`007Goo00<007ooOol0
DGoo00<007ooOol037oo00<007ooOol0WGoo000MOol00`00Oomoo`1BOol00`00Oomoo`0:Ool00`00
Oomoo`2NOol001eoo`03001oogoo059oo`03001oogoo00Yoo`03001oogoo09ioo`007Goo00<007oo
Ool0DWoo00<007ooOol02Woo00<007ooOol0WWoo000MOol00`00Oomoo`1COol00`00Oomoo`09Ool0
0`00Oomoo`2NOol000Yoo`8000Aoo`8000=oo`@000Aoo`03001oogoo05=oo`03001oogoo00Qoo`03
001oogoo09moo`002Goo00@007ooOol000=oo`8000Aoo`03001oogoo00Aoo`03001oogoo05=oo`03
001oogoo00Qoo`03001oogoo09moo`002Goo00@007ooOol000Yoo`03001oogoo00=oo`8005Aoo`03
001oogoo00Qoo`03001oogoo09moo`002Goo00@007ooOol000]oo`03001oogoo009oo`03001oogoo
05=oo`03001oogoo00Qoo`03001oogoo09moo`002Goo00@007ooOol000Qoo`04001oogoo0004Ool0
0`00Oomoo`1COol00`00Oomoo`08Ool00`00Oomoo`2OOol000Yoo`8000Yoo`8000Eoo`03001oogoo
05Aoo`03001oogoo00Moo`03001oogoo09moo`007Goo00<007ooOol0E7oo00<007ooOol01Woo00<0
07ooOol0X7oo000MOol00`00Oomoo`1DOol00`00Oomoo`06Ool00`00Oomoo`2POol001eoo`03001o
ogoo05Aoo`03001oogoo00Ioo`03001oogoo0:1oo`007Goo00<007ooOol0E7oo00<007ooOol01Woo
00<007ooOol0X7oo000MOol00`00Oomoo`1DOol00`00Oomoo`06Ool00`00Oomoo`2POol001eoo`03
001oogoo05Aoo`03001oogoo00Ioo`03001oogoo0:1oo`007Goo00<007ooOol0E7oo00<007ooOol0
1Woo00<007ooOol0X7oo000MOol00`00Oomoo`1DOol00`00Oomoo`05Ool00`00Oomoo`2QOol001eo
o`03001oogoo05Eoo`03001oogoo00Aoo`03001oogoo0:5oo`007Goo00<007ooOol0EGoo00<007oo
Ool017oo00<007ooOol0XGoo000MOol00`00Oomoo`1EOol00`00Oomoo`04Ool00`00Oomoo`2QOol0
01eoo`03001oogoo05Eoo`03001oogoo00Aoo`03001oogoo0:5oo`007Goo00<007ooOol0EGoo00<0
07ooOol017oo00<007ooOol0XGoo000MOol00`00Oomoo`1EOol00`00Oomoo`04Ool00`00Oomoo`2Q
Ool001eoo`03001oogoo05Eoo`03001oogoo00Aoo`03001oogoo0:5oo`007Goo00<007ooOol0EGoo
00<007ooOol017oo00<007ooOol0XGoo000MOol00`00Oomoo`1EOol00`00Oomoo`04Ool00`00Oomo
o`2QOol001eoo`03001oogoo05Eoo`03001oogoo00Aoo`03001oogoo0:5oo`007Goo00<007ooOol0
EGoo00<007ooOol017oo00<007ooOol0XGoo000MOol00`00Oomoo`1EOol00`00Oomoo`04Ool00`00
Oomoo`2QOol001eoo`03001oogoo05Eoo`03001oogoo00Aoo`03001oogoo0:5oo`002Woo0P0017oo
0P0017oo0`0017oo00<007ooOol0EGoo00<007ooOol017oo00<007ooOol0XGoo0009Ool01000Oomo
o`000goo0P001Goo00<007ooOol00goo00<007ooOol0EGoo00<007ooOol017oo00<007ooOol0XGoo
0009Ool01000Oomoo`0027oo100017oo0P00EWoo00<007ooOol017oo00<007ooOol0XGoo0009Ool0
1000Oomoo`0027oo00<007oo00001Goo00<007ooOol0EGoo00<007ooOol00goo00<007ooOol0XWoo
0009Ool01000Oomoo`0027oo00<007oo00001Goo00<007ooOol0EGoo00<007ooOol00goo00<007oo
Ool0XWoo000:Ool2000:Ool20005Ool00`00Oomoo`1EOol00`00Oomoo`03Ool00`00Oomoo`2ROol0
01eoo`03001oogoo05Eoo`03001oogoo00=oo`03001oogoo0:9oo`007Goo00<007ooOol0EGoo00<0
07ooOol00goo00<007ooOol0XWoo000MOol00`00Oomoo`1EOol00`00Oomoo`03Ool00`00Oomoo`2R
Ool001eoo`03001oogoo05Eoo`03001oogoo00=oo`03001oogoo0:9oo`007Goo00<007ooOol0EGoo
00<007ooOol00goo00<007ooOol0XWoo000MOol00`00Oomoo`1EOol00`00Oomoo`03Ool00`00Oomo
o`2ROol001eoo`03001oogoo05Eoo`03001oogoo00=oo`03001oogoo0:9oo`007Goo00<007ooOol0
EGoo00<007ooOol00goo00<007ooOol0XWoo000MOol00`00Oomoo`1EOol00`00Oomoo`03Ool00`00
Oomoo`2ROol001eoo`03001oogoo05Ioo`03001oogoo009oo`03001oogoo0:9oo`007Goo00<007oo
Ool0EWoo00<007ooOol00Woo00<007ooOol0XWoo000MOol00`00Oomoo`1FOol00`00Oomoo`02Ool0
0`00Oomoo`2ROol001eoo`03001oogoo05Ioo`03001oogoo009oo`03001oogoo0:9oo`007Goo00<0
07ooOol0EWoo00<007ooOol00Woo00<007ooOol0XWoo000MOol00`00Oomoo`1FOol00`00Oomoo`02
Ool00`00Oomoo`2ROol001eoo`03001oogoo05Ioo`03001oogoo009oo`03001oogoo0:9oo`007Goo
00<007ooOol0EWoo00<007ooOol00Woo00<007ooOol0XWoo000MOol00`00Oomoo`1FOol00`00Oomo
o`02Ool00`00Oomoo`2ROol001eoo`03001oogoo05Ioo`03001oogoo009oo`03001oogoo0:9oo`00
7Goo00<007ooOol0EWoo00<007ooOol00Woo00<007ooOol0XWoo000MOol00`00Oomoo`1FOol00`00
Oomoo`02Ool00`00Oomoo`2ROol000Yoo`8000Aoo`8000Aoo`8000Eoo`03001oogoo05Ioo`03001o
ogoo009oo`03001oogoo0:9oo`002Goo00@007ooOol000=oo`8000=oo`04001oogoo0004Ool00`00
Oomoo`1FOol00`00Oomoo`02Ool00`00Oomoo`2ROol000Uoo`04001oogoo0008Ool01000Oomoo`00
17oo0P00Egoo00D007ooOomoo`000:Eoo`002Goo00@007ooOol000Qoo`<000Eoo`03001oogoo05Io
o`05001oogooOol0002UOol000Uoo`04001oogoo0008Ool00`00Oomoo`05Ool00`00Oomoo`1FOol0
1@00Oomoogoo0000YGoo000:Ool2000:Ool30004Ool00`00Oomoo`1FOol01@00Oomoogoo0000YGoo
000MOol00`00Oomoo`1FOol01@00Oomoogoo0000YGoo000MOol00`00Oomoo`1FOol01@00Oomoogoo
0000YGoo000MOol00`00Oomoo`1FOol01@00Oomoogoo0000YGoo000MOol00`00Oomoo`1FOol01@00
Oomoogoo0000YGoo000MOol00`00Oomoo`1FOol01@00Oomoogoo0000YGoo000MOol00`00Oomoo`1F
Ool01@00Oomoogoo0000YGoo000MOol00`00Oomoo`1FOol01@00Oomoogoo0000YGoo000MOol00`00
Oomoo`1FOol01@00Oomoogoo0000YGoo000MOol00`00Oomoo`1FOol01@00Oomoogoo0000YGoo000M
Ool00`00Oomoo`1FOol01@00Oomoogoo0000YGoo000MOol00`00Oomoo`1FOol01@00Oomoogoo0000
YGoo000MOol00`00Oomoo`1FOol01@00Oomoogoo0000YGoo000MOol00`00Oomoo`1FOol01@00Oomo
ogoo0000YGoo000MOol00`00Oomoo`1FOol01@00Oomoogoo0000YGoo000MOol00`00Oomoo`1FOol0
1@00Oomoogoo0000YGoo000MOol00`00Oomoo`1FOol01@00Oomoogoo0000YGoo000MOol00`00Oomo
o`1FOol01@00Oomoogoo0000YGoo000MOol00`00Oomoo`1FOol01@00Oomoogoo0000YGoo000MOol0
0`00Oomoo`1FOol01@00Oomoogoo0000YGoo000MOol00`00Oomoo`1FOol01@00Oomoogoo0000YGoo
000:Ool20004Ool20004Ool20005Ool00`00Oomoo`1FOol01@00Oomoogoo0000YGoo0009Ool01000
Oomoo`000goo0P000goo00@007ooOol000Aoo`03001oogoo05Ioo`05001oogooOol0002UOol000Uo
o`04001oogoo0008Ool01000Oomoo`0017oo0P00Egoo00D007ooOomoo`000:Eoo`002Goo00@007oo
Ool000Uoo`8000Eoo`03001oogoo05Ioo`04001oogoo002VOol000Uoo`04001oogoo0008Ool01000
Oomoo`0017oo00<007ooOol0EWoo00@007ooOol00:Ioo`002Woo0P002Woo0P001Goo00<007ooOol0
EWoo00@007ooOol00:Ioo`007Goo00<007ooOol0EWoo00@007ooOol00:Ioo`007Goo00<007ooOol0
Egoo00<007oo0000YWoo000MOol00`00Oomoo`1GOol00`00Ool0002VOol001eoo`03001oogoo05Mo
o`03001oo`000:Ioo`007Goo00<007ooOol0Egoo00<007oo0000YWoo000MOol00`00Oomoo`1GOol0
0`00Ool0002VOol001eoo`03001oogoo05Moo`03001oo`000:Ioo`007Goo00<007ooOol0Egoo00<0
07oo0000YWoo000MOol00`00Oomoo`1GOol00`00Ool0002VOol001eoo`03001oogoo05Moo`03001o
o`000:Ioo`007Goo00<007ooOol0Egoo00<007oo0000YWoo000MOol00`00Oomoo`1GOol00`00Ool0
002VOol001eoo`03001oogoo05Moo`03001oo`000:Ioo`007Goo00<007ooOol0Egoo0P00Ygoo000M
Ool00`00Oomoo`1GOol2002WOol001eoo`03001oogoo05Moo`800:Moo`007Goo00<007ooOol0Egoo
0P00Ygoo000MOol00`00Oomoo`1GOol2002WOol001eoo`03001oogoo05Moo`800:Moo`007Goo00<0
07ooOol0Egoo0P00Ygoo000MOol00`00Oomoo`1GOol00`00Oomoo`2VOol001Eoo`<000Eoo`03001o
ogoo05Moo`03001oogoo0:Ioo`005Woo00<007ooOol017oo00<007ooOol0Egoo00<007ooOol0YWoo
000FOol00`00Oomoo`04Ool2001HOol00`00Oomoo`2VOol001Ioo`03001oogoo0?moo`Qoo`005Woo
00<007ooOol0ogoo27oo000EOol2003oOol:Ool00?moob5oo`00ogoo8Goo003oOolQOol000ioo`@0
029oo`<000=oo`<000Eoo`<000Uoo`<0009oo`@000Moo`80009oo`80009oo`@0009oo`<000=oo`<0
009oo`@000=oo`D00003Ool000000080009oo`D000Ioo`<000Aoo`<0009oo`D00004Ool00000Ool2
0002Ool5001]Ool000moo`03001oogoo02=oo`03001oogoo00=oo`03001oogoo00Eoo`03001oogoo
00Moo`05001oogooOol00002Ool00`00Oomoo`08Ool01000Ool000000Woo00<007ooOol00goo00L0
07ooOomoo`00Ool00003Ool01000Oomoo`0017oo00L007ooOomoo`00Ool00005Ool01@00Oomoogoo
00001goo00@007ooOol0009oo`07001oogooOol007oo00000Woo00@007ooOol0009oo`04001oogoo
0003Ool00`00Oomoo`1/Ool000=oo`D00007Ool007oo001oo`00Ool010000Woo1@0000=oo`000000
0`000Woo0`000Woo1@000Woo1@0000=oo`0000000P000goo00<007ooOol01Goo00<007ooOol01goo
00D007ooOomoo`00009oo`03001oogoo00Qoo`<000=oo`D00003Ool007oo00Aoo`05001oogooOol0
0002Ool00`00Oomoo`02Ool01P00Oomoogoo001oo`D00003Ool007oo009oo`03001oogoo00Moo`80
009oo`07001oogooOol007oo00000Woo00@007ooOol0009oo`04001oogoo0003Ool00`00Oomoo`1/
Ool000=oo`04001oogoo0002Ool01`00Ool007oo001oo`0000=oo`05001oogooOol00005Ool00`00
Oomoo`02Ool01P00Oomoo`00Ool0009oo`04001oogoo0003Ool01000Ool007oo0`000goo0`000goo
00D007oo001oo`0000Moo`05001oogooOol00002Ool00`00Oomoo`08Ool01000Oomoo`000Woo00L0
07ooOomoo`00Ool00003Ool00`00Ool00003Ool00`00Oomoo`020003Ool01`00Oomoogoo001oo`00
00=oo`03001oo`0000=oo`03001oogoo00Eoo`8000Aoo`07001oogooOol007oo00000Woo00@007oo
Ool0009oo`04001oogoo0003Ool00`00Oomoo`1/Ool000=oo`@0009oo`07001oo`00Ool007oo0000
0goo00D007ooOomoo`0000Eoo`03001oogoo009oo`03001oogoo009oo`04001oogoo0002Ool01P00
Oomoogoo001oo`D000=oo`03001oogoo00=oo`05001oo`00Ool00008Ool30002Ool40008Ool01000
Oomoo`000goo0`000goo10000Woo0`000Woo0P0000=oo`0000000Woo10000Woo0`000goo10001goo
00@007ooOol000=oo`<00004Ool00000Ool200000goo000000030003Ool4001^Ool000Ioo`0:001o
ogoo001oo`00Ool007oo0003Ool01@00Oomoogoo00001Goo00<007ooOol00Woo00<007ooOol00Woo
00@007ooOol0009oo`06001oogooOol007oo1P0000=oo`0000000`000Woo1@003Woo00<007ooOol0
1goo10007goo00<007ooOol02Goo00<007ooOol01Woo0`0067oo00<007ooOol0K7oo0004Ool30000
0goo000000090004Ool00`00Oomoo`02Ool20003Ool4000017oo000007oo0P000goo10000Woo0`00
7Goo0`00:Goo0P002Woo0P008Woo0P00KWoo000GOol00`00Oomoo`08Ool00`00Oomoo`0<Ool00`00
Oomoo`3/Ool001Eoo`<000Eoo`03001oogoo009oo`03001oogoo00]oo`800>ioo`00ogoo8Goo003o
OolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5o
o`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {946.587, -0.14072, 0.462505, 
  0.00748348}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-9.5 0.01 0 0.618034 [
[.3 -0.0125 -9 -9 ]
[.3 -0.0125 9 0 ]
[.5 -0.0125 -12 -9 ]
[.5 -0.0125 12 0 ]
[.7 -0.0125 -12 -9 ]
[.7 -0.0125 12 0 ]
[.9 -0.0125 -12 -9 ]
[.9 -0.0125 12 0 ]
[1.025 0 0 -6 ]
[1.025 0 58 6 ]
[.0875 .12361 -18 -4.5 ]
[.0875 .12361 0 4.5 ]
[.0875 .24721 -18 -4.5 ]
[.0875 .24721 0 4.5 ]
[.0875 .37082 -18 -4.5 ]
[.0875 .37082 0 4.5 ]
[.0875 .49443 -18 -4.5 ]
[.0875 .49443 0 4.5 ]
[.0875 .61803 -6 -4.5 ]
[.0875 .61803 0 4.5 ]
[.1 .64303 -29 0 ]
[.1 .64303 29 12 ]
[.5 .63053 -65 0 ]
[.5 .63053 65 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.3 0 m
.3 .00625 L
s
[(980)] .3 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1000)] .5 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(1020)] .7 -0.0125 0 1 Mshowa
.9 0 m
.9 .00625 L
s
[(1040)] .9 -0.0125 0 1 Mshowa
.125 Mabswid
.15 0 m
.15 .00375 L
s
.2 0 m
.2 .00375 L
s
.25 0 m
.25 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.45 0 m
.45 .00375 L
s
.55 0 m
.55 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.75 0 m
.75 .00375 L
s
.8 0 m
.8 .00375 L
s
.85 0 m
.85 .00375 L
s
.05 0 m
.05 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(frequency) show
117.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.1 .12361 m
.10625 .12361 L
s
[(0.2)] .0875 .12361 1 0 Mshowa
.1 .24721 m
.10625 .24721 L
s
[(0.4)] .0875 .24721 1 0 Mshowa
.1 .37082 m
.10625 .37082 L
s
[(0.6)] .0875 .37082 1 0 Mshowa
.1 .49443 m
.10625 .49443 L
s
[(0.8)] .0875 .49443 1 0 Mshowa
.1 .61803 m
.10625 .61803 L
s
[(1)] .0875 .61803 1 0 Mshowa
.125 Mabswid
.1 .0309 m
.10375 .0309 L
s
.1 .0618 m
.10375 .0618 L
s
.1 .09271 m
.10375 .09271 L
s
.1 .15451 m
.10375 .15451 L
s
.1 .18541 m
.10375 .18541 L
s
.1 .21631 m
.10375 .21631 L
s
.1 .27812 m
.10375 .27812 L
s
.1 .30902 m
.10375 .30902 L
s
.1 .33992 m
.10375 .33992 L
s
.1 .40172 m
.10375 .40172 L
s
.1 .43262 m
.10375 .43262 L
s
.1 .46353 m
.10375 .46353 L
s
.1 .52533 m
.10375 .52533 L
s
.1 .55623 m
.10375 .55623 L
s
.1 .58713 m
.10375 .58713 L
s
.25 Mabswid
.1 0 m
.1 .61803 L
s
gsave
.1 .64303 -90 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(amplitude) show
117.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.5 .63053 -126 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(FFT) show
87.000000 13.000000 moveto
(of) show
105.000000 13.000000 moveto
(Recorded) show
159.000000 13.000000 moveto
(Sound) show
189.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .0069 m
.01 .00602 L
.02 .00659 L
.03 .00611 L
.04 .00718 L
.05 .00655 L
.06 .00697 L
.07 .0064 L
.08 .00638 L
.09 .00736 L
.1 .00729 L
.11 .00613 L
.12 .00631 L
.13 .00852 L
.14 .00812 L
.15 .00787 L
.16 .00883 L
.17 .00867 L
.18 .00928 L
.19 .0099 L
.2 .00925 L
.21 .00953 L
.22 .00927 L
.23 .00981 L
.24 .0102 L
.25 .01128 L
.26 .01132 L
.27 .01054 L
.28 .01209 L
.29 .01293 L
.3 .01398 L
.31 .01323 L
.32 .01439 L
.33 .01573 L
.34 .01613 L
.35 .01747 L
.36 .01841 L
.37 .02036 L
.38 .02159 L
.39 .02202 L
.4 .02423 L
.41 .02617 L
.42 .02787 L
.43 .03175 L
.44 .03524 L
.45 .04085 L
.46 .04605 L
.47 .05454 L
.48 .06775 L
.49 .08676 L
Mistroke
.5 .11951 L
.51 .20085 L
.52 .59185 L
.53 .61803 L
.54 .20425 L
.55 .12237 L
.56 .0878 L
.57 .06764 L
.58 .05494 L
.59 .04682 L
.6 .04083 L
.61 .03559 L
.62 .03168 L
.63 .02888 L
.64 .02564 L
.65 .0241 L
.66 .02171 L
.67 .02109 L
.68 .01923 L
.69 .01852 L
.7 .01756 L
.71 .01614 L
.72 .01577 L
.73 .01448 L
.74 .01426 L
.75 .01389 L
.76 .01379 L
.77 .01296 L
.78 .01227 L
.79 .01109 L
.8 .01126 L
.81 .01043 L
.82 .01032 L
.83 .01086 L
.84 .00927 L
.85 .00997 L
.86 .00945 L
.87 .00873 L
.88 .00867 L
.89 .0085 L
.9 .00824 L
.91 .00846 L
.92 .00821 L
.93 .00693 L
.94 .00751 L
.95 .00696 L
.96 .0073 L
.97 .00674 L
.98 .0066 L
.99 .00593 L
Mistroke
1 .00621 L
Mfstroke
1 .00621 m
1 .00621 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
@7oo0`0017oo0P0017oo0P006Goo0`0017oo0P0017oo0P0017oo0P005Woo0`0017oo0P000goo1000
0goo0P005Woo0`0017oo0P0017oo0`000goo0P00CGoo0013Ool01000Oomoo`000Woo00@007ooOol0
009oo`03001oogoo01Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000Woo00@007oo
Ool001Ioo`03001oogoo009oo`04001oogoo0003Ool00`00Oomoo`02Ool01000Oomoo`005Woo00<0
07ooOol00Woo00@007ooOol000Aoo`05001oogooOol00002Ool00`00Oomoo`1:Ool0045oo`<0009o
o`04001oogoo0002Ool01000Oomoo`006Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo
0002Ool01000Oomoo`005Woo00<007ooOol00Woo00@007ooOol000Aoo`05001oogooOol00002Ool0
0`00Oomoo`0DOol00`00Oomoo`02Ool01000Oomoo`000Woo10000Woo00@007ooOol004aoo`00@7oo
00@007ooOol000=oo`8000=oo`04001oogoo000IOol00`00Oomoo`02Ool01000Oomoo`000Woo00@0
07ooOol0009oo`04001oogoo000FOol00`00Oomoo`02Ool01000Oomoo`001Goo00@007ooOol0009o
o`03001oogoo01Aoo`03001oogoo009oo`04001oogoo0002Ool00`00Ool00003Ool01000Oomoo`00
C7oo0010Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo000IOol00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol0009oo`04001oogoo000FOol00`00Oomoo`02Ool01000Oomoo`00
0Woo00@007ooOol0009oo`04001oogoo000FOol00`00Oomoo`02Ool01000Oomoo`000Woo00<007oo
00000goo00@007ooOol004aoo`00@Goo0P0017oo0P0017oo0P006Goo0P001Goo0P0017oo0P0017oo
0P005Woo0P001Goo0P0017oo0P0017oo0P005Woo0P001Goo0P0017oo0P0017oo0P00:Goo10005goo
0`001Woo003nOol00`00Oomoo`0GOol00`00Oomoo`05Ool00>Qoo`@0009oo`@000=oo`@0009oo`@0
0003Ool0000000<0009oo`@00004Ool00000Ool20002Ool30003Ool00`00Oomoo`04Ool00>Uoo`03
001oogoo00=oo`03001oogoo009oo`03001oogoo00=oo`07001oogooOol007oo00000Woo00@007oo
Ool000Eoo`04001oogoo0002Ool01@00Oomoogoo00000Woo00<007ooOol017oo0007OooI0009Ool0
0`00Oomoo`03Ool00`00Oomoo`02Ool500000goo001oo`02Ool00`00Ool00002Ool00`00Oomoo`05
00001Goo001oogoo00000Woo00<007ooOol00goo00<007oo00001Goo000BOol00`00Oomoo`08Ool0
0`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool0
0`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool0
0`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool0
0`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`03Ool2
0003Ool01`00Oomoogoo001oo`0000=oo`03001oo`00009oo`04001oogoo0003Ool00`00Ool00002
Ool01000Oomoo`000goo00D007oo001oo`0000Eoo`001goo:@0000=oo`00000020003Goo00<007oo
Ool0:7oo00<007ooOol0:7oo00<007ooOol06goo0`0000=oo`0000007P0027oo10000Woo0P0000=o
o`0000000Woo0`000goo1P0000=oo`0000000goo0`0000=oo`0000000`000goo1P0000=oo`000000
17oo000MOol00`00Oomoo`0@Ool00`00Oomoo`08OolC001FOolH0003Ool00`00Oomoo`0WOol00`00
Oomoo`0dOol001eoo`03001oogoo02ioo`T004Aoo`T004Eoo`<003Aoo`007Goo00<007ooOol0=goo
1P00>7oo1P00QGoo000MOol00`00Oomoo`0mOol7000/Ool5002;Ool001eoo`03001oogoo04Aoo`80
02Ioo`@0091oo`007Goo00<007ooOol0AWoo0P008Woo0P00U7oo000MOol00`00Oomoo`18Ool2000N
Ool2002FOol001eoo`03001oogoo04Yoo`8001Yoo`8009Qoo`007Goo00<007ooOol0C7oo00<007oo
Ool05Woo00<007ooOol0V7oo000MOol00`00Oomoo`1=Ool00`00Oomoo`0DOol00`00Oomoo`2IOol0
01eoo`03001oogoo04eoo`03001oogoo01Aoo`03001oogoo09Uoo`007Goo00<007ooOol0CWoo00<0
07ooOol04Woo00<007ooOol0VWoo000MOol00`00Oomoo`1?Ool00`00Oomoo`0@Ool00`00Oomoo`2K
Ool001eoo`03001oogoo04moo`03001oogoo011oo`03001oogoo09]oo`007Goo00<007ooOol0D7oo
00<007ooOol03Woo00<007ooOol0W7oo000MOol00`00Oomoo`1@Ool00`00Oomoo`0>Ool00`00Oomo
o`2LOol001eoo`03001oogoo055oo`03001oogoo00aoo`03001oogoo09eoo`007Goo00<007ooOol0
DGoo00<007ooOol037oo00<007ooOol0WGoo000MOol00`00Oomoo`1AOol00`00Oomoo`0<Ool00`00
Oomoo`2MOol001eoo`03001oogoo059oo`03001oogoo00Yoo`03001oogoo09ioo`007Goo00<007oo
Ool0DWoo00<007ooOol02Woo00<007ooOol0WWoo000MOol00`00Oomoo`1BOol00`00Oomoo`0:Ool0
0`00Oomoo`2NOol000Yoo`8000Aoo`8000=oo`@000Aoo`03001oogoo05=oo`03001oogoo00Uoo`03
001oogoo09ioo`002Goo00@007ooOol000=oo`8000Aoo`03001oogoo00Aoo`03001oogoo05=oo`03
001oogoo00Qoo`03001oogoo09moo`002Goo00@007ooOol000Yoo`03001oogoo00=oo`8005Aoo`03
001oogoo00Qoo`03001oogoo09moo`002Goo00@007ooOol000]oo`03001oogoo009oo`03001oogoo
05=oo`03001oogoo00Qoo`03001oogoo09moo`002Goo00@007ooOol000Qoo`04001oogoo0004Ool0
0`00Oomoo`1COol00`00Oomoo`08Ool00`00Oomoo`2OOol000Yoo`8000Yoo`8000Eoo`03001oogoo
05=oo`03001oogoo00Qoo`03001oogoo09moo`007Goo00<007ooOol0E7oo00<007ooOol01goo00<0
07ooOol0Wgoo000MOol00`00Oomoo`1DOol00`00Oomoo`06Ool00`00Oomoo`2POol001eoo`03001o
ogoo05Aoo`03001oogoo00Ioo`03001oogoo0:1oo`007Goo00<007ooOol0E7oo00<007ooOol01Woo
00<007ooOol0X7oo000MOol00`00Oomoo`1DOol00`00Oomoo`06Ool00`00Oomoo`2POol001eoo`03
001oogoo05Aoo`03001oogoo00Ioo`03001oogoo0:1oo`007Goo00<007ooOol0E7oo00<007ooOol0
1Woo00<007ooOol0X7oo000MOol00`00Oomoo`1DOol00`00Oomoo`06Ool00`00Oomoo`2POol001eo
o`03001oogoo05Aoo`03001oogoo00Ioo`03001oogoo0:1oo`007Goo00<007ooOol0EGoo00<007oo
Ool01Goo00<007ooOol0X7oo000MOol00`00Oomoo`1EOol00`00Oomoo`04Ool00`00Oomoo`2QOol0
01eoo`03001oogoo05Eoo`03001oogoo00Aoo`03001oogoo0:5oo`007Goo00<007ooOol0EGoo00<0
07ooOol017oo00<007ooOol0XGoo000MOol00`00Oomoo`1EOol00`00Oomoo`04Ool00`00Oomoo`2Q
Ool001eoo`03001oogoo05Eoo`03001oogoo00Aoo`03001oogoo0:5oo`007Goo00<007ooOol0EGoo
00<007ooOol017oo00<007ooOol0XGoo000MOol00`00Oomoo`1EOol00`00Oomoo`04Ool00`00Oomo
o`2QOol001eoo`03001oogoo05Eoo`03001oogoo00Aoo`03001oogoo0:5oo`007Goo00<007ooOol0
EGoo00<007ooOol017oo00<007ooOol0XGoo000MOol00`00Oomoo`1EOol00`00Oomoo`04Ool00`00
Oomoo`2QOol001eoo`03001oogoo05Eoo`03001oogoo00Aoo`03001oogoo0:5oo`002Woo0P0017oo
0P0017oo0`0017oo00<007ooOol0EGoo00<007ooOol017oo00<007ooOol0XGoo0009Ool01000Oomo
o`000goo0P001Goo00<007ooOol00goo00<007ooOol0EGoo00<007ooOol017oo00<007ooOol0XGoo
0009Ool01000Oomoo`0027oo100017oo0P00EWoo00<007ooOol017oo00<007ooOol0XGoo0009Ool0
1000Oomoo`0027oo00<007oo00001Goo00<007ooOol0EGoo00<007ooOol017oo00<007ooOol0XGoo
0009Ool01000Oomoo`0027oo00<007oo00001Goo00<007ooOol0EGoo00<007ooOol017oo00<007oo
Ool0XGoo000:Ool2000:Ool20005Ool00`00Oomoo`1EOol00`00Oomoo`04Ool00`00Oomoo`2QOol0
01eoo`03001oogoo05Eoo`03001oogoo00Aoo`03001oogoo0:5oo`007Goo00<007ooOol0EGoo00<0
07ooOol017oo00<007ooOol0XGoo000MOol00`00Oomoo`1EOol00`00Oomoo`04Ool00`00Oomoo`2Q
Ool001eoo`03001oogoo05Eoo`03001oogoo00=oo`03001oogoo0:9oo`007Goo00<007ooOol0EGoo
00<007ooOol00goo00<007ooOol0XWoo000MOol00`00Oomoo`1EOol00`00Oomoo`03Ool00`00Oomo
o`2ROol001eoo`03001oogoo05Eoo`03001oogoo00=oo`03001oogoo0:9oo`007Goo00<007ooOol0
EGoo00<007ooOol00goo00<007ooOol0XWoo000MOol00`00Oomoo`1FOol00`00Oomoo`02Ool00`00
Oomoo`2ROol001eoo`03001oogoo05Ioo`03001oogoo009oo`03001oogoo0:9oo`007Goo00<007oo
Ool0EWoo00<007ooOol00Woo00<007ooOol0XWoo000MOol00`00Oomoo`1FOol00`00Oomoo`02Ool0
0`00Oomoo`2ROol001eoo`03001oogoo05Ioo`03001oogoo009oo`03001oogoo0:9oo`007Goo00<0
07ooOol0EWoo00<007ooOol00Woo00<007ooOol0XWoo000MOol00`00Oomoo`1FOol00`00Oomoo`02
Ool00`00Oomoo`2ROol001eoo`03001oogoo05Ioo`03001oogoo009oo`03001oogoo0:9oo`007Goo
00<007ooOol0EWoo00<007ooOol00Woo00<007ooOol0XWoo000MOol00`00Oomoo`1FOol00`00Oomo
o`02Ool00`00Oomoo`2ROol001eoo`03001oogoo05Ioo`03001oogoo009oo`03001oogoo0:9oo`00
7Goo00<007ooOol0EWoo00<007ooOol00Woo00<007ooOol0XWoo000MOol00`00Oomoo`1FOol00`00
Oomoo`02Ool00`00Oomoo`2ROol000Yoo`8000Aoo`8000Aoo`8000Eoo`03001oogoo05Ioo`03001o
ogoo009oo`03001oogoo0:9oo`002Goo00@007ooOol000=oo`8000=oo`04001oogoo0004Ool00`00
Oomoo`1FOol00`00Oomoo`02Ool00`00Oomoo`2ROol000Uoo`04001oogoo0008Ool01000Oomoo`00
17oo0P00Egoo00<007ooOol00Woo00<007ooOol0XWoo0009Ool01000Oomoo`0027oo0`001Goo00<0
07ooOol0EWoo00<007ooOol00Woo00<007ooOol0XWoo0009Ool01000Oomoo`0027oo00<007ooOol0
1Goo00<007ooOol0EWoo00<007ooOol00Woo00<007ooOol0XWoo000:Ool2000:Ool30004Ool00`00
Oomoo`1FOol00`00Oomoo`02Ool00`00Oomoo`2ROol001eoo`03001oogoo05Ioo`03001oogoo009o
o`03001oogoo0:9oo`007Goo00<007ooOol0EWoo00<007ooOol00Woo00<007ooOol0XWoo000MOol0
0`00Oomoo`1FOol00`00Oomoo`02Ool00`00Oomoo`2ROol001eoo`03001oogoo05Ioo`03001oogoo
009oo`03001oogoo0:9oo`007Goo00<007ooOol0EWoo00<007ooOol00Woo00<007ooOol0XWoo000M
Ool00`00Oomoo`1FOol01@00Oomoogoo0000YGoo000MOol00`00Oomoo`1FOol01@00Oomoogoo0000
YGoo000MOol00`00Oomoo`1FOol01@00Oomoogoo0000YGoo000MOol00`00Oomoo`1FOol01@00Oomo
ogoo0000YGoo000MOol00`00Oomoo`1FOol01@00Oomoogoo0000YGoo000MOol00`00Oomoo`1FOol0
1@00Oomoogoo0000YGoo000MOol00`00Oomoo`1FOol01@00Oomoogoo0000YGoo000MOol00`00Oomo
o`1FOol01@00Oomoogoo0000YGoo000MOol00`00Oomoo`1FOol01@00Oomoogoo0000YGoo000MOol0
0`00Oomoo`1FOol01@00Oomoogoo0000YGoo000MOol00`00Oomoo`1FOol01@00Oomoogoo0000YGoo
000MOol00`00Oomoo`1FOol01@00Oomoogoo0000YGoo000MOol00`00Oomoo`1FOol01@00Oomoogoo
0000YGoo000MOol00`00Oomoo`1FOol01@00Oomoogoo0000YGoo000MOol00`00Oomoo`1FOol01@00
Oomoogoo0000YGoo000:Ool20004Ool20004Ool20005Ool00`00Oomoo`1FOol01@00Oomoogoo0000
YGoo0009Ool01000Oomoo`000goo0P000goo00@007ooOol000Aoo`03001oogoo05Ioo`05001oogoo
Ool0002UOol000Uoo`04001oogoo0008Ool01000Oomoo`0017oo0P00Egoo00D007ooOomoo`000:Eo
o`002Goo00@007ooOol000Uoo`8000Eoo`03001oogoo05Moo`04001oogoo002UOol000Uoo`04001o
ogoo0008Ool01000Oomoo`0017oo00<007ooOol0Egoo00@007ooOol00:Eoo`002Woo0P002Woo0P00
1Goo00<007ooOol0Egoo00@007ooOol00:Eoo`007Goo00<007ooOol0Egoo00@007ooOol00:Eoo`00
7Goo00<007ooOol0Egoo00@007ooOol00:Eoo`007Goo00<007ooOol0Egoo00@007ooOol00:Eoo`00
7Goo00<007ooOol0Egoo00@007ooOol00:Eoo`007Goo00<007ooOol0Egoo00@007ooOol00:Eoo`00
7Goo00<007ooOol0Egoo00@007ooOol00:Eoo`007Goo00<007ooOol0Egoo00@007ooOol00:Eoo`00
7Goo00<007ooOol0Egoo00@007ooOol00:Eoo`007Goo00<007ooOol0Egoo00@007ooOol00:Eoo`00
7Goo00<007ooOol0Egoo00<007oo0000YWoo000MOol00`00Oomoo`1GOol00`00Ool0002VOol001eo
o`03001oogoo05Moo`03001oo`000:Ioo`007Goo00<007ooOol0Egoo00<007oo0000YWoo000MOol0
0`00Oomoo`1GOol00`00Ool0002VOol001eoo`03001oogoo05Moo`03001oo`000:Ioo`007Goo00<0
07ooOol0Egoo00<007oo0000YWoo000MOol00`00Oomoo`1GOol00`00Ool0002VOol001eoo`03001o
ogoo05Moo`03001oo`000:Ioo`007Goo00<007ooOol0Egoo00<007oo0000YWoo000MOol00`00Oomo
o`1HOol2002VOol001eoo`03001oogoo05Qoo`800:Ioo`005Goo0`001Goo00<007ooOol0F7oo0P00
YWoo000FOol00`00Oomoo`04Ool00`00Oomoo`1IOol00`00Oomoo`2TOol001Ioo`03001oogoo00Ao
o`8005Yoo`03001oogoo0:Aoo`005Woo00<007ooOol0ogoo27oo000FOol00`00Oomoo`3oOol8Ool0
01Eoo`800?moo`Yoo`00ogoo8Goo003oOolQOol00?moob5oo`003Woo10008Woo0`000goo0`001Goo
0`002Goo0`000Woo10001goo0P000Woo0P000Woo10000Woo0`000goo0`000Woo10000goo1@0000=o
o`0000000P000Woo1@001Woo0`0017oo0`000Woo1@0000Aoo`00001oo`80009oo`D006eoo`003goo
00<007ooOol08goo00<007ooOol00goo00<007ooOol01Goo00<007ooOol01goo00D007ooOomoo`00
009oo`03001oogoo00Qoo`04001oo`000002Ool00`00Oomoo`03Ool01`00Oomoogoo001oo`0000=o
o`04001oogoo0004Ool01`00Oomoogoo001oo`0000Eoo`05001oogooOol00007Ool01000Oomoo`00
0Woo00L007ooOomoo`00Ool00002Ool01000Oomoo`000Woo00@007ooOol000=oo`03001oogoo06ao
o`000goo1@0000Moo`00Ool007oo001oo`040002Ool500000goo000000030002Ool30002Ool50002
Ool500000goo000000020003Ool00`00Oomoo`05Ool00`00Oomoo`07Ool01@00Oomoogoo00000Woo
00<007ooOol027oo0`000goo1@0000=oo`00Ool017oo00D007ooOomoo`00009oo`03001oogoo009o
o`06001oogooOol007oo1@0000=oo`00Ool00Woo00<007ooOol01goo0P000Woo00L007ooOomoo`00
Ool00002Ool01000Oomoo`000Woo00@007ooOol000=oo`03001oogoo06aoo`000goo00@007ooOol0
009oo`07001oo`00Ool007oo00000goo00D007ooOomoo`0000Eoo`03001oogoo009oo`06001oogoo
001oo`000Woo00@007ooOol000=oo`04001oo`00Ool30003Ool30003Ool01@00Ool007oo00001goo
00D007ooOomoo`00009oo`03001oogoo00Qoo`04001oogoo0002Ool01`00Oomoogoo001oo`0000=o
o`03001oo`0000=oo`03001oogoo008000=oo`07001oogooOol007oo00000goo00<007oo00000goo
00<007ooOol01Goo0P0017oo00L007ooOomoo`00Ool00002Ool01000Oomoo`000Woo00@007ooOol0
00=oo`03001oogoo06aoo`000goo10000Woo00L007oo001oo`00Ool00003Ool01@00Oomoogoo0000
1Goo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`06001oogooOol007oo1@000goo
00<007ooOol00goo00D007oo001oo`0000Qoo`<0009oo`@000Qoo`04001oogoo0003Ool30003Ool4
0002Ool30002Ool200000goo00000002Ool40002Ool30003Ool40007Ool01000Oomoo`000goo0`00
00Aoo`00001oo`800003Ool0000000<000=oo`@006ioo`001Woo00X007ooOol007oo001oo`00Ool0
00=oo`05001oogooOol00005Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01000Oomoo`000Woo00H0
07ooOomoo`00Ool600000goo000000030002Ool5000>Ool00`00Oomoo`07Ool4000OOol00`00Oomo
o`09Ool00`00Oomoo`06Ool3000HOol00`00Oomoo`1/Ool000Aoo`<00003Ool0000000T000Aoo`03
001oogoo009oo`8000=oo`@00004Ool00000Ool20003Ool40002Ool3000MOol3000YOol2000:Ool2
000ROol2001^Ool001Moo`03001oogoo00Qoo`03001oogoo00aoo`03001oogoo0>aoo`005Goo0`00
1Goo00<007ooOol00Woo00<007ooOol02goo0P00kWoo003oOolQOol00?moob5oo`00ogoo8Goo003o
OolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {946.587, -0.14072, 0.462505, 
  0.00748348}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-9.5 0.01 0 0.618034 [
[.3 -0.0125 -9 -9 ]
[.3 -0.0125 9 0 ]
[.5 -0.0125 -12 -9 ]
[.5 -0.0125 12 0 ]
[.7 -0.0125 -12 -9 ]
[.7 -0.0125 12 0 ]
[.9 -0.0125 -12 -9 ]
[.9 -0.0125 12 0 ]
[1.025 0 0 -6 ]
[1.025 0 58 6 ]
[.0875 .12361 -18 -4.5 ]
[.0875 .12361 0 4.5 ]
[.0875 .24721 -18 -4.5 ]
[.0875 .24721 0 4.5 ]
[.0875 .37082 -18 -4.5 ]
[.0875 .37082 0 4.5 ]
[.0875 .49443 -18 -4.5 ]
[.0875 .49443 0 4.5 ]
[.0875 .61803 -6 -4.5 ]
[.0875 .61803 0 4.5 ]
[.1 .64303 -29 0 ]
[.1 .64303 29 12 ]
[.5 .63053 -65 0 ]
[.5 .63053 65 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.3 0 m
.3 .00625 L
s
[(980)] .3 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1000)] .5 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(1020)] .7 -0.0125 0 1 Mshowa
.9 0 m
.9 .00625 L
s
[(1040)] .9 -0.0125 0 1 Mshowa
.125 Mabswid
.15 0 m
.15 .00375 L
s
.2 0 m
.2 .00375 L
s
.25 0 m
.25 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.45 0 m
.45 .00375 L
s
.55 0 m
.55 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.75 0 m
.75 .00375 L
s
.8 0 m
.8 .00375 L
s
.85 0 m
.85 .00375 L
s
.05 0 m
.05 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(frequency) show
117.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.1 .12361 m
.10625 .12361 L
s
[(0.2)] .0875 .12361 1 0 Mshowa
.1 .24721 m
.10625 .24721 L
s
[(0.4)] .0875 .24721 1 0 Mshowa
.1 .37082 m
.10625 .37082 L
s
[(0.6)] .0875 .37082 1 0 Mshowa
.1 .49443 m
.10625 .49443 L
s
[(0.8)] .0875 .49443 1 0 Mshowa
.1 .61803 m
.10625 .61803 L
s
[(1)] .0875 .61803 1 0 Mshowa
.125 Mabswid
.1 .0309 m
.10375 .0309 L
s
.1 .0618 m
.10375 .0618 L
s
.1 .09271 m
.10375 .09271 L
s
.1 .15451 m
.10375 .15451 L
s
.1 .18541 m
.10375 .18541 L
s
.1 .21631 m
.10375 .21631 L
s
.1 .27812 m
.10375 .27812 L
s
.1 .30902 m
.10375 .30902 L
s
.1 .33992 m
.10375 .33992 L
s
.1 .40172 m
.10375 .40172 L
s
.1 .43262 m
.10375 .43262 L
s
.1 .46353 m
.10375 .46353 L
s
.1 .52533 m
.10375 .52533 L
s
.1 .55623 m
.10375 .55623 L
s
.1 .58713 m
.10375 .58713 L
s
.25 Mabswid
.1 0 m
.1 .61803 L
s
gsave
.1 .64303 -90 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(amplitude) show
117.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.5 .63053 -126 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(FFT) show
87.000000 13.000000 moveto
(of) show
105.000000 13.000000 moveto
(Recorded) show
159.000000 13.000000 moveto
(Sound) show
189.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .00452 m
.01 .00419 L
.02 .00346 L
.03 .0055 L
.04 .0041 L
.05 .00374 L
.06 .00332 L
.07 .00412 L
.08 .00443 L
.09 .00447 L
.1 .00395 L
.11 .00553 L
.12 .0057 L
.13 .00513 L
.14 .00476 L
.15 .00506 L
.16 .00568 L
.17 .00638 L
.18 .00573 L
.19 .0064 L
.2 .00604 L
.21 .00639 L
.22 .00577 L
.23 .00669 L
.24 .00718 L
.25 .00733 L
.26 .00829 L
.27 .00795 L
.28 .00886 L
.29 .00877 L
.3 .00825 L
.31 .0103 L
.32 .01062 L
.33 .00982 L
.34 .01141 L
.35 .0122 L
.36 .01284 L
.37 .01385 L
.38 .01451 L
.39 .01504 L
.4 .0173 L
.41 .01855 L
.42 .02042 L
.43 .0228 L
.44 .02505 L
.45 .02911 L
.46 .03236 L
.47 .04048 L
.48 .05029 L
.49 .06656 L
Mistroke
.5 .10086 L
.51 .20119 L
.52 .61803 L
.53 .39023 L
.54 .11612 L
.55 .0744 L
.56 .05482 L
.57 .04368 L
.58 .03604 L
.59 .03156 L
.6 .02697 L
.61 .02375 L
.62 .02139 L
.63 .01973 L
.64 .01841 L
.65 .01627 L
.66 .01427 L
.67 .01386 L
.68 .01245 L
.69 .01175 L
.7 .01197 L
.71 .01115 L
.72 .01055 L
.73 .01032 L
.74 .00953 L
.75 .00834 L
.76 .00904 L
.77 .00884 L
.78 .00804 L
.79 .0075 L
.8 .00696 L
.81 .00617 L
.82 .00734 L
.83 .00621 L
.84 .00625 L
.85 .00663 L
.86 .00481 L
.87 .00577 L
.88 .00634 L
.89 .00538 L
.9 .00482 L
.91 .00437 L
.92 .0047 L
.93 .00513 L
.94 .00571 L
.95 .00568 L
.96 .00397 L
.97 .00441 L
.98 .00461 L
.99 .00239 L
Mistroke
1 .00308 L
Mfstroke
1 .00308 m
1 .00308 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
@7oo0`0017oo0P0017oo0P006Goo0`0017oo0P0017oo0P0017oo0P005Woo0`0017oo0P000goo1000
0goo0P005Woo0`0017oo0P0017oo0`000goo0P00CGoo0013Ool01000Oomoo`000Woo00@007ooOol0
009oo`03001oogoo01Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000Woo00@007oo
Ool001Ioo`03001oogoo009oo`04001oogoo0003Ool00`00Oomoo`02Ool01000Oomoo`005Woo00<0
07ooOol00Woo00@007ooOol000Aoo`05001oogooOol00002Ool00`00Oomoo`1:Ool0045oo`<0009o
o`04001oogoo0002Ool01000Oomoo`006Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo
0002Ool01000Oomoo`005Woo00<007ooOol00Woo00@007ooOol000Aoo`05001oogooOol00002Ool0
0`00Oomoo`0DOol00`00Oomoo`02Ool01000Oomoo`000Woo10000Woo00@007ooOol004aoo`00@7oo
00@007ooOol000=oo`8000=oo`04001oogoo000IOol00`00Oomoo`02Ool01000Oomoo`000Woo00@0
07ooOol0009oo`04001oogoo000FOol00`00Oomoo`02Ool01000Oomoo`001Goo00@007ooOol0009o
o`03001oogoo01Aoo`03001oogoo009oo`04001oogoo0002Ool00`00Ool00003Ool01000Oomoo`00
C7oo0010Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo000IOol00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol0009oo`04001oogoo000FOol00`00Oomoo`02Ool01000Oomoo`00
0Woo00@007ooOol0009oo`04001oogoo000FOol00`00Oomoo`02Ool01000Oomoo`000Woo00<007oo
00000goo00@007ooOol004aoo`00@Goo0P0017oo0P0017oo0P006Goo0P001Goo0P0017oo0P0017oo
0P005Woo0P001Goo0P0017oo0P0017oo0P005Woo0P001Goo0P0017oo0P0017oo0P00:Goo10005goo
0`001Woo003nOol00`00Oomoo`0GOol00`00Oomoo`05Ool00>Qoo`@0009oo`@000=oo`@0009oo`@0
0003Ool0000000<0009oo`@00004Ool00000Ool20002Ool30003Ool00`00Oomoo`04Ool00>Uoo`03
001oogoo00=oo`03001oogoo009oo`03001oogoo00=oo`07001oogooOol007oo00000Woo00@007oo
Ool000Eoo`04001oogoo0002Ool01@00Oomoogoo00000Woo00<007ooOol017oo0007OooI0009Ool0
0`00Oomoo`03Ool00`00Oomoo`02Ool500000goo001oo`02Ool00`00Ool00002Ool00`00Oomoo`05
00001Goo001oogoo00000Woo00<007ooOol00goo00<007oo00001Goo0007Ool60002Ool@0003Ool7
0009Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomo
o`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomo
o`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool40005Ool:0002Ool<0009Ool0
0`00Oomoo`03Ool20003Ool01`00Oomoogoo001oo`0000=oo`03001oo`00009oo`04001oogoo0003
Ool00`00Ool00002Ool01000Oomoo`000goo00D007oo001oo`0000Eoo`003Goo0P003Woo00<007oo
00000P001goo8@000goo0`008goo00<007ooOol0:7oo00<007ooOol01Goo6P000goo1@0000=oo`00
Ool01goo0`004goo10000Woo0P0000=oo`0000000Woo0`000goo1P0000=oo`0000000goo0`0000=o
o`0000000`000goo1P0000=oo`00000017oo000MOol00`00Oomoo`0ZOol30003Ool9000lOolA0013
Ool00`00Oomoo`0dOol001eoo`03001oogoo03Uoo`T002ioo`D005Aoo`<003Aoo`007Goo00<007oo
Ool0@Woo100097oo1P00T7oo000MOol00`00Oomoo`16Ool2000POol2002FOol001eoo`03001oogoo
04Qoo`@001Uoo`<009Qoo`007Goo00<007ooOol0C7oo00<007ooOol05Goo00<007ooOol0VGoo000M
Ool00`00Oomoo`1=Ool00`00Oomoo`0COol00`00Oomoo`2JOol001eoo`03001oogoo04ioo`03001o
ogoo015oo`03001oogoo09]oo`007Goo00<007ooOol0Cgoo00<007ooOol03goo00<007ooOol0W7oo
000MOol00`00Oomoo`1?Ool00`00Oomoo`0>Ool00`00Oomoo`2MOol001eoo`03001oogoo051oo`03
001oogoo00eoo`03001oogoo09eoo`007Goo00<007ooOol0D7oo00<007ooOol037oo00<007ooOol0
WWoo000MOol00`00Oomoo`1AOol00`00Oomoo`0;Ool00`00Oomoo`2NOol001eoo`03001oogoo055o
o`03001oogoo00Yoo`03001oogoo09moo`007Goo00<007ooOol0DGoo00<007ooOol02Woo00<007oo
Ool0Wgoo000MOol00`00Oomoo`1BOol00`00Oomoo`09Ool00`00Oomoo`2OOol001eoo`03001oogoo
059oo`03001oogoo00Qoo`03001oogoo0:1oo`007Goo00<007ooOol0DWoo00<007ooOol027oo00<0
07ooOol0X7oo000MOol00`00Oomoo`1COol00`00Oomoo`07Ool00`00Oomoo`2POol001eoo`03001o
ogoo05=oo`03001oogoo00Moo`03001oogoo0:1oo`007Goo00<007ooOol0Dgoo00<007ooOol01goo
00<007ooOol0X7oo000MOol00`00Oomoo`1COol00`00Oomoo`06Ool00`00Oomoo`2QOol000Yoo`80
00Aoo`8000=oo`@000Aoo`03001oogoo05=oo`03001oogoo00Ioo`03001oogoo0:5oo`002Goo00@0
07ooOol000=oo`8000Aoo`03001oogoo00Aoo`03001oogoo05=oo`03001oogoo00Ioo`03001oogoo
0:5oo`002Goo00@007ooOol000Yoo`03001oogoo00=oo`8005Aoo`03001oogoo00Ioo`03001oogoo
0:5oo`002Goo00@007ooOol000]oo`03001oogoo009oo`03001oogoo05Aoo`03001oogoo00Eoo`03
001oogoo0:5oo`002Goo00@007ooOol000Qoo`04001oogoo0004Ool00`00Oomoo`1DOol00`00Oomo
o`05Ool00`00Oomoo`2QOol000Yoo`8000Yoo`8000Eoo`03001oogoo05Aoo`03001oogoo00Eoo`03
001oogoo0:5oo`007Goo00<007ooOol0E7oo00<007ooOol01Goo00<007ooOol0XGoo000MOol00`00
Oomoo`1DOol00`00Oomoo`05Ool00`00Oomoo`2QOol001eoo`03001oogoo05Aoo`03001oogoo00Eo
o`03001oogoo0:5oo`007Goo00<007ooOol0E7oo00<007ooOol01Goo00<007ooOol0XGoo000MOol0
0`00Oomoo`1DOol00`00Oomoo`05Ool00`00Oomoo`2QOol001eoo`03001oogoo05Aoo`03001oogoo
00Aoo`03001oogoo0:9oo`007Goo00<007ooOol0E7oo00<007ooOol017oo00<007ooOol0XWoo000M
Ool00`00Oomoo`1DOol00`00Oomoo`04Ool00`00Oomoo`2ROol001eoo`03001oogoo05Eoo`03001o
ogoo00=oo`03001oogoo0:9oo`007Goo00<007ooOol0EGoo00<007ooOol00goo00<007ooOol0XWoo
000MOol00`00Oomoo`1EOol00`00Oomoo`03Ool00`00Oomoo`2ROol001eoo`03001oogoo05Eoo`03
001oogoo00=oo`03001oogoo0:9oo`007Goo00<007ooOol0EGoo00<007ooOol00goo00<007ooOol0
XWoo000MOol00`00Oomoo`1EOol00`00Oomoo`03Ool00`00Oomoo`2ROol001eoo`03001oogoo05Eo
o`03001oogoo00=oo`03001oogoo0:9oo`007Goo00<007ooOol0EGoo00<007ooOol00goo00<007oo
Ool0XWoo000MOol00`00Oomoo`1EOol00`00Oomoo`03Ool00`00Oomoo`2ROol001eoo`03001oogoo
05Eoo`03001oogoo00=oo`03001oogoo0:9oo`007Goo00<007ooOol0EGoo00<007ooOol00goo00<0
07ooOol0XWoo000MOol00`00Oomoo`1EOol00`00Oomoo`03Ool00`00Oomoo`2ROol001eoo`03001o
ogoo05Eoo`03001oogoo00=oo`03001oogoo0:9oo`002Woo0P0017oo0P0017oo0`0017oo00<007oo
Ool0EGoo00<007ooOol00goo00<007ooOol0XWoo0009Ool01000Oomoo`000goo0P001Goo00<007oo
Ool00goo00<007ooOol0EGoo00<007ooOol00goo00<007ooOol0XWoo0009Ool01000Oomoo`0027oo
100017oo0P00EWoo00<007ooOol00goo00<007ooOol0XWoo0009Ool01000Oomoo`0027oo00<007oo
00001Goo00<007ooOol0EGoo00<007ooOol00goo00<007ooOol0XWoo0009Ool01000Oomoo`0027oo
00<007oo00001Goo00<007ooOol0EGoo00<007ooOol00Woo00<007ooOol0Xgoo000:Ool2000:Ool2
0005Ool00`00Oomoo`1EOol00`00Oomoo`02Ool00`00Oomoo`2SOol001eoo`03001oogoo05Eoo`03
001oogoo009oo`03001oogoo0:=oo`007Goo00<007ooOol0EGoo00<007ooOol00Woo00<007ooOol0
Xgoo000MOol00`00Oomoo`1EOol00`00Oomoo`02Ool00`00Oomoo`2SOol001eoo`03001oogoo05Eo
o`03001oogoo009oo`03001oogoo0:=oo`007Goo00<007ooOol0EGoo00<007ooOol00Woo00<007oo
Ool0Xgoo000MOol00`00Oomoo`1EOol00`00Oomoo`02Ool00`00Oomoo`2SOol001eoo`03001oogoo
05Eoo`03001oogoo009oo`03001oogoo0:=oo`007Goo00<007ooOol0EGoo00<007ooOol00Woo00<0
07ooOol0Xgoo000MOol00`00Oomoo`1EOol00`00Oomoo`02Ool00`00Oomoo`2SOol001eoo`03001o
ogoo05Ioo`05001oogooOol0002UOol001eoo`03001oogoo05Ioo`05001oogooOol0002UOol001eo
o`03001oogoo05Ioo`05001oogooOol0002UOol001eoo`03001oogoo05Ioo`05001oogooOol0002U
Ool001eoo`03001oogoo05Ioo`05001oogooOol0002UOol001eoo`03001oogoo05Ioo`05001oogoo
Ool0002UOol001eoo`03001oogoo05Ioo`05001oogooOol0002UOol001eoo`03001oogoo05Ioo`05
001oogooOol0002UOol001eoo`03001oogoo05Ioo`05001oogooOol0002UOol001eoo`03001oogoo
05Ioo`04001oogoo002VOol001eoo`03001oogoo05Ioo`04001oogoo002VOol001eoo`03001oogoo
05Ioo`04001oogoo002VOol000Yoo`8000Aoo`8000Aoo`8000Eoo`03001oogoo05Ioo`04001oogoo
002VOol000Uoo`04001oogoo0003Ool20003Ool01000Oomoo`0017oo00<007ooOol0EWoo00@007oo
Ool00:Ioo`002Goo00@007ooOol000Qoo`04001oogoo0004Ool2001GOol01000Oomoo`00YWoo0009
Ool01000Oomoo`0027oo0`001Goo00<007ooOol0EWoo00@007ooOol00:Ioo`002Goo00@007ooOol0
00Qoo`03001oogoo00Eoo`03001oogoo05Ioo`04001oogoo002VOol000Yoo`8000Yoo`<000Aoo`03
001oogoo05Ioo`04001oogoo002VOol001eoo`03001oogoo05Ioo`04001oogoo002VOol001eoo`03
001oogoo05Ioo`04001oogoo002VOol001eoo`03001oogoo05Ioo`04001oogoo002VOol001eoo`03
001oogoo05Ioo`04001oogoo002VOol001eoo`03001oogoo05Ioo`04001oogoo002VOol001eoo`03
001oogoo05Ioo`04001oogoo002VOol001eoo`03001oogoo05Ioo`04001oogoo002VOol001eoo`03
001oogoo05Ioo`04001oogoo002VOol001eoo`03001oogoo05Ioo`04001oogoo002VOol001eoo`03
001oogoo05Ioo`04001oogoo002VOol001eoo`03001oogoo05Ioo`04001oogoo002VOol001eoo`03
001oogoo05Ioo`04001oogoo002VOol001eoo`03001oogoo05Ioo`04001oogoo002VOol001eoo`03
001oogoo05Ioo`03001oo`000:Moo`007Goo00<007ooOol0EWoo00<007oo0000Ygoo000MOol00`00
Oomoo`1FOol00`00Ool0002WOol001eoo`03001oogoo05Ioo`03001oo`000:Moo`007Goo00<007oo
Ool0EWoo00<007oo0000Ygoo000MOol00`00Oomoo`1FOol00`00Ool0002WOol001eoo`03001oogoo
05Ioo`03001oo`000:Moo`002Woo0P0017oo0P0017oo0P001Goo00<007ooOol0EWoo00<007oo0000
Ygoo0009Ool01000Oomoo`000goo0P000goo00@007ooOol000Aoo`03001oogoo05Ioo`03001oo`00
0:Moo`002Goo00@007ooOol000Qoo`04001oogoo0004Ool2001GOol00`00Ool0002WOol000Uoo`04
001oogoo0009Ool20005Ool00`00Oomoo`1FOol00`00Ool0002WOol000Uoo`04001oogoo0008Ool0
1000Oomoo`0017oo00<007ooOol0EWoo00<007oo0000Ygoo000:Ool2000:Ool20005Ool00`00Oomo
o`1FOol00`00Ool0002WOol001eoo`03001oogoo05Ioo`03001oo`000:Moo`007Goo00<007ooOol0
Egoo0P00Ygoo000MOol00`00Oomoo`1GOol2002WOol001eoo`03001oogoo05Moo`800:Moo`007Goo
00<007ooOol0Egoo0P00Ygoo000MOol00`00Oomoo`1GOol2002WOol001eoo`03001oogoo05Moo`80
0:Moo`007Goo00<007ooOol0Egoo0P00Ygoo000MOol00`00Oomoo`1GOol2002WOol001eoo`03001o
ogoo05Moo`800:Moo`007Goo00<007ooOol0Egoo0P00Ygoo000MOol00`00Oomoo`1GOol2002WOol0
01eoo`03001oogoo05Moo`03001oogoo0:Ioo`007Goo00<007ooOol0Egoo00<007ooOol0YWoo000M
Ool00`00Oomoo`1GOol00`00Oomoo`2VOol001eoo`03001oogoo05Moo`03001oogoo0:Ioo`007Goo
00<007ooOol0Egoo00<007ooOol0YWoo000MOol00`00Oomoo`1GOol00`00Oomoo`2VOol001eoo`03
001oogoo05Moo`03001oogoo0:Ioo`007Goo00<007ooOol0Egoo00<007ooOol0YWoo000MOol00`00
Oomoo`1GOol00`00Oomoo`2VOol001Eoo`<000Eoo`03001oogoo05Moo`03001oogoo0:Ioo`005Woo
00<007ooOol017oo00<007ooOol0Egoo00<007ooOol0YWoo000FOol00`00Oomoo`04Ool2001HOol0
0`00Oomoo`2VOol001Ioo`03001oogoo0?moo`Qoo`005Woo00<007ooOol0ogoo27oo000EOol2003o
Ool:Ool00?moob5oo`00ogoo8Goo003oOolQOol000ioo`@0029oo`<000=oo`<000Eoo`<000Uoo`<0
009oo`@000Moo`80009oo`80009oo`@0009oo`<000=oo`<0009oo`@000=oo`D00003Ool000000080
009oo`D000Ioo`<000Aoo`<0009oo`D00004Ool00000Ool20002Ool5001]Ool000moo`03001oogoo
02=oo`03001oogoo00=oo`03001oogoo00Eoo`03001oogoo00Moo`05001oogooOol00002Ool00`00
Oomoo`08Ool01000Ool000000Woo00<007ooOol00goo00L007ooOomoo`00Ool00003Ool01000Oomo
o`0017oo00L007ooOomoo`00Ool00005Ool01@00Oomoogoo00001goo00@007ooOol0009oo`07001o
ogooOol007oo00000Woo00@007ooOol0009oo`04001oogoo0003Ool00`00Oomoo`1/Ool000=oo`D0
0007Ool007oo001oo`00Ool010000Woo1@0000=oo`0000000`000Woo0`000Woo1@000Woo1@0000=o
o`0000000P000goo00<007ooOol01Goo00<007ooOol01goo00D007ooOomoo`00009oo`03001oogoo
00Qoo`<000=oo`D00003Ool007oo00Aoo`05001oogooOol00002Ool00`00Oomoo`02Ool01P00Oomo
ogoo001oo`D00003Ool007oo009oo`03001oogoo00Moo`80009oo`07001oogooOol007oo00000Woo
00@007ooOol0009oo`04001oogoo0003Ool00`00Oomoo`1/Ool000=oo`04001oogoo0002Ool01`00
Ool007oo001oo`0000=oo`05001oogooOol00005Ool00`00Oomoo`02Ool01P00Oomoo`00Ool0009o
o`04001oogoo0003Ool01000Ool007oo0`000goo0`000goo00D007oo001oo`0000Moo`05001oogoo
Ool00002Ool00`00Oomoo`08Ool01000Oomoo`000Woo00L007ooOomoo`00Ool00003Ool00`00Ool0
0003Ool00`00Oomoo`020003Ool01`00Oomoogoo001oo`0000=oo`03001oo`0000=oo`03001oogoo
00Eoo`8000Aoo`07001oogooOol007oo00000Woo00@007ooOol0009oo`04001oogoo0003Ool00`00
Oomoo`1/Ool000=oo`@0009oo`07001oo`00Ool007oo00000goo00D007ooOomoo`0000Eoo`03001o
ogoo009oo`03001oogoo009oo`04001oogoo0002Ool01P00Oomoogoo001oo`D000=oo`03001oogoo
00=oo`05001oo`00Ool00008Ool30002Ool40008Ool01000Oomoo`000goo0`000goo10000Woo0`00
0Woo0P0000=oo`0000000Woo10000Woo0`000goo10001goo00@007ooOol000=oo`<00004Ool00000
Ool200000goo000000030003Ool4001^Ool000Ioo`0:001oogoo001oo`00Ool007oo0003Ool01@00
Oomoogoo00001Goo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`06001oogooOol0
07oo1P0000=oo`0000000`000Woo1@003Woo00<007ooOol01goo10007goo00<007ooOol02Goo00<0
07ooOol01Woo0`0067oo00<007ooOol0K7oo0004Ool300000goo000000090004Ool00`00Oomoo`02
Ool20003Ool4000017oo000007oo0P000goo10000Woo0`007Goo0`00:Goo0P002Woo0P008Woo0P00
KWoo000GOol00`00Oomoo`08Ool00`00Oomoo`0<Ool00`00Oomoo`3/Ool001Eoo`<000Eoo`03001o
ogoo009oo`03001oogoo00]oo`800>ioo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003o
OolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {946.587, -0.14072, 0.462505, 
  0.00748348}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-9.5 0.01 0 0.618034 [
[.3 -0.0125 -9 -9 ]
[.3 -0.0125 9 0 ]
[.5 -0.0125 -12 -9 ]
[.5 -0.0125 12 0 ]
[.7 -0.0125 -12 -9 ]
[.7 -0.0125 12 0 ]
[.9 -0.0125 -12 -9 ]
[.9 -0.0125 12 0 ]
[1.025 0 0 -6 ]
[1.025 0 58 6 ]
[.0875 .12361 -18 -4.5 ]
[.0875 .12361 0 4.5 ]
[.0875 .24721 -18 -4.5 ]
[.0875 .24721 0 4.5 ]
[.0875 .37082 -18 -4.5 ]
[.0875 .37082 0 4.5 ]
[.0875 .49443 -18 -4.5 ]
[.0875 .49443 0 4.5 ]
[.0875 .61803 -6 -4.5 ]
[.0875 .61803 0 4.5 ]
[.1 .64303 -29 0 ]
[.1 .64303 29 12 ]
[.5 .63053 -65 0 ]
[.5 .63053 65 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.3 0 m
.3 .00625 L
s
[(980)] .3 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1000)] .5 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(1020)] .7 -0.0125 0 1 Mshowa
.9 0 m
.9 .00625 L
s
[(1040)] .9 -0.0125 0 1 Mshowa
.125 Mabswid
.15 0 m
.15 .00375 L
s
.2 0 m
.2 .00375 L
s
.25 0 m
.25 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.45 0 m
.45 .00375 L
s
.55 0 m
.55 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.75 0 m
.75 .00375 L
s
.8 0 m
.8 .00375 L
s
.85 0 m
.85 .00375 L
s
.05 0 m
.05 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(frequency) show
117.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.1 .12361 m
.10625 .12361 L
s
[(0.2)] .0875 .12361 1 0 Mshowa
.1 .24721 m
.10625 .24721 L
s
[(0.4)] .0875 .24721 1 0 Mshowa
.1 .37082 m
.10625 .37082 L
s
[(0.6)] .0875 .37082 1 0 Mshowa
.1 .49443 m
.10625 .49443 L
s
[(0.8)] .0875 .49443 1 0 Mshowa
.1 .61803 m
.10625 .61803 L
s
[(1)] .0875 .61803 1 0 Mshowa
.125 Mabswid
.1 .0309 m
.10375 .0309 L
s
.1 .0618 m
.10375 .0618 L
s
.1 .09271 m
.10375 .09271 L
s
.1 .15451 m
.10375 .15451 L
s
.1 .18541 m
.10375 .18541 L
s
.1 .21631 m
.10375 .21631 L
s
.1 .27812 m
.10375 .27812 L
s
.1 .30902 m
.10375 .30902 L
s
.1 .33992 m
.10375 .33992 L
s
.1 .40172 m
.10375 .40172 L
s
.1 .43262 m
.10375 .43262 L
s
.1 .46353 m
.10375 .46353 L
s
.1 .52533 m
.10375 .52533 L
s
.1 .55623 m
.10375 .55623 L
s
.1 .58713 m
.10375 .58713 L
s
.25 Mabswid
.1 0 m
.1 .61803 L
s
gsave
.1 .64303 -90 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(amplitude) show
117.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.5 .63053 -126 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(FFT) show
87.000000 13.000000 moveto
(of) show
105.000000 13.000000 moveto
(Recorded) show
159.000000 13.000000 moveto
(Sound) show
189.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .00371 m
.01 .00434 L
.02 .00424 L
.03 .00475 L
.04 .00456 L
.05 .00442 L
.06 .00495 L
.07 .00546 L
.08 .00644 L
.09 .00526 L
.1 .00496 L
.11 .00452 L
.12 .00386 L
.13 .00446 L
.14 .00556 L
.15 .00503 L
.16 .00516 L
.17 .00491 L
.18 .00659 L
.19 .00672 L
.2 .00613 L
.21 .00765 L
.22 .00654 L
.23 .00653 L
.24 .00705 L
.25 .00801 L
.26 .00858 L
.27 .00917 L
.28 .00949 L
.29 .00974 L
.3 .00964 L
.31 .00979 L
.32 .01088 L
.33 .01204 L
.34 .01111 L
.35 .01347 L
.36 .01629 L
.37 .01802 L
.38 .01544 L
.39 .01605 L
.4 .01751 L
.41 .01969 L
.42 .02175 L
.43 .02583 L
.44 .02655 L
.45 .03762 L
.46 .06231 L
.47 .07003 L
.48 .05982 L
.49 .14275 L
Mistroke
.5 .26309 L
.51 .61803 L
.52 .47563 L
.53 .16235 L
.54 .08982 L
.55 .05951 L
.56 .04616 L
.57 .03863 L
.58 .0322 L
.59 .02936 L
.6 .02262 L
.61 .02038 L
.62 .01956 L
.63 .01791 L
.64 .0167 L
.65 .01306 L
.66 .01336 L
.67 .0123 L
.68 .01165 L
.69 .01597 L
.7 .01366 L
.71 .01078 L
.72 .00856 L
.73 .00744 L
.74 .01212 L
.75 .01235 L
.76 .0104 L
.77 .0102 L
.78 .00667 L
.79 .00983 L
.8 .0093 L
.81 .00729 L
.82 .00387 L
.83 .0033 L
.84 .00611 L
.85 .00681 L
.86 .00499 L
.87 .00281 L
.88 .0041 L
.89 .00516 L
.9 .00632 L
.91 .00408 L
.92 .00447 L
.93 .00316 L
.94 .00413 L
.95 .00652 L
.96 .00555 L
.97 .00754 L
.98 .00665 L
.99 .00432 L
Mistroke
1 .00423 L
Mfstroke
1 .00423 m
1 .00423 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
@7oo0`0017oo0P0017oo0P006Goo0`0017oo0P0017oo0P0017oo0P005Woo0`0017oo0P000goo1000
0goo0P005Woo0`0017oo0P0017oo0`000goo0P00CGoo0013Ool01000Oomoo`000Woo00@007ooOol0
009oo`03001oogoo01Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000Woo00@007oo
Ool001Ioo`03001oogoo009oo`04001oogoo0003Ool00`00Oomoo`02Ool01000Oomoo`005Woo00<0
07ooOol00Woo00@007ooOol000Aoo`05001oogooOol00002Ool00`00Oomoo`1:Ool0045oo`<0009o
o`04001oogoo0002Ool01000Oomoo`006Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo
0002Ool01000Oomoo`005Woo00<007ooOol00Woo00@007ooOol000Aoo`05001oogooOol00002Ool0
0`00Oomoo`0DOol00`00Oomoo`02Ool01000Oomoo`000Woo10000Woo00@007ooOol004aoo`00@7oo
00@007ooOol000=oo`8000=oo`04001oogoo000IOol00`00Oomoo`02Ool01000Oomoo`000Woo00@0
07ooOol0009oo`04001oogoo000FOol00`00Oomoo`02Ool01000Oomoo`001Goo00@007ooOol0009o
o`03001oogoo01Aoo`03001oogoo009oo`04001oogoo0002Ool00`00Ool00003Ool01000Oomoo`00
C7oo0010Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo000IOol00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol0009oo`04001oogoo000FOol00`00Oomoo`02Ool01000Oomoo`00
0Woo00@007ooOol0009oo`04001oogoo000FOol00`00Oomoo`02Ool01000Oomoo`000Woo00<007oo
00000goo00@007ooOol004aoo`00@Goo0P0017oo0P0017oo0P006Goo0P001Goo0P0017oo0P0017oo
0P005Woo0P001Goo0P0017oo0P0017oo0P005Woo0P001Goo0P0017oo0P0017oo0P00:Goo10005goo
0`001Woo003nOol00`00Oomoo`0GOol00`00Oomoo`05Ool00>Qoo`@0009oo`@000=oo`@0009oo`@0
0003Ool0000000<0009oo`@00004Ool00000Ool20002Ool30003Ool00`00Oomoo`04Ool00>Uoo`03
001oogoo00=oo`03001oogoo009oo`03001oogoo00=oo`07001oogooOol007oo00000Woo00@007oo
Ool000Eoo`04001oogoo0002Ool01@00Oomoogoo00000Woo00<007ooOol017oo0007OooI0009Ool0
0`00Oomoo`03Ool00`00Oomoo`02Ool500000goo001oo`02Ool00`00Ool00002Ool00`00Oomoo`05
00001Goo001oogoo00000Woo00<007ooOol00goo00<007oo00001Goo0007Ool?0006Ool900000goo
000000060004Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`07Ool0
0`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`07Ool0
0`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`060002Ool;00000goo0000
00080007Ool40009Ool00`00Oomoo`03Ool20003Ool01`00Oomoogoo001oo`0000=oo`03001oo`00
009oo`04001oogoo0003Ool00`00Ool00002Ool01000Oomoo`000goo00D007oo001oo`0000Eoo`00
5Woo1P0000=oo`00Ool01Woo00<007ooOol01Woo7P009goo00<007ooOol0:7oo00@007ooOomoo`D0
00Qoo`P000Ioo`<000Uoo`8000Uoo`P000aoo`@0009oo`800003Ool00000009oo`<000=oo`H00003
Ool0000000=oo`<00003Ool0000000<000=oo`H00003Ool0000000Aoo`007Goo00<007ooOol0;7oo
2@00?Goo2P0000=oo`0000000`001Goo2000>Woo00<007ooOol0=7oo000MOol00`00Oomoo`0eOol;
000^Ool4000:Ool00`00Oomoo`1:Ool3000dOol001eoo`03001oogoo041oo`@002Aoo`H0099oo`00
7Goo00<007ooOol0A7oo0`0087oo00<007ooOol0UWoo000MOol00`00Oomoo`17Ool00`00Oomoo`0J
Ool3002IOol001eoo`03001oogoo04Qoo`03001oogoo01Qoo`03001oogoo09Yoo`007Goo00<007oo
Ool0B7oo00<007ooOol05Woo0P00WGoo000MOol00`00Oomoo`19Ool00`00Oomoo`0DOol00`00Oomo
o`2MOol001eoo`03001oogoo04Uoo`03001oogoo01Aoo`03001oogoo09eoo`007Goo00<007ooOol0
BGoo00<007ooOol04goo00<007ooOol0WWoo000MOol00`00Oomoo`1:Ool00`00Oomoo`02Ool00`00
Oomoo`0<Ool00`00Oomoo`2OOol001eoo`03001oogoo04Yoo`8000=oo`03001oogoo00aoo`03001o
ogoo09moo`007Goo00<007ooOol0C7oo00@007oo000000ioo`03001oogoo09moo`007Goo00<007oo
Ool0CGoo00<007oo00003Goo00<007ooOol0X7oo000MOol00`00Oomoo`1?Ool00`00Oomoo`0;Ool0
0`00Oomoo`2POol001eoo`03001oogoo051oo`03001oogoo00Yoo`03001oogoo0:1oo`007Goo00<0
07ooOol0D7oo00<007ooOol02Goo00<007ooOol0XGoo000MOol00`00Oomoo`1@Ool00`00Oomoo`09
Ool00`00Oomoo`2QOol001eoo`03001oogoo051oo`03001oogoo00Uoo`03001oogoo0:5oo`007Goo
00<007ooOol0D7oo00<007ooOol02Goo00<007ooOol0XGoo000MOol00`00Oomoo`1@Ool00`00Oomo
o`08Ool00`00Oomoo`2ROol001eoo`03001oogoo051oo`03001oogoo00Qoo`03001oogoo0:9oo`00
2Woo0P0017oo0P000goo100017oo00<007ooOol0D7oo00<007ooOol027oo00<007ooOol0XWoo0009
Ool01000Oomoo`000goo0P0017oo00<007ooOol017oo00<007ooOol0D7oo00<007ooOol027oo00<0
07ooOol0XWoo0009Ool01000Oomoo`002Woo00<007ooOol00goo0P00DWoo00<007ooOol01goo00<0
07ooOol0XWoo0009Ool01000Oomoo`002goo00<007ooOol00Woo00<007ooOol0DGoo00<007ooOol0
1Woo00<007ooOol0Xgoo0009Ool01000Oomoo`0027oo00@007ooOol000Aoo`03001oogoo055oo`03
001oogoo00Ioo`03001oogoo0:=oo`002Woo0P002Woo0P001Goo00<007ooOol0DGoo00<007ooOol0
1Woo00<007ooOol0Xgoo000MOol00`00Oomoo`1AOol00`00Oomoo`06Ool00`00Oomoo`2SOol001eo
o`03001oogoo055oo`03001oogoo00Ioo`03001oogoo0:=oo`007Goo00<007ooOol0DGoo00<007oo
Ool01Goo00<007ooOol0Y7oo000MOol00`00Oomoo`1AOol00`00Oomoo`05Ool00`00Oomoo`2TOol0
01eoo`03001oogoo055oo`03001oogoo00Eoo`03001oogoo0:Aoo`007Goo00<007ooOol0DGoo00<0
07ooOol01Goo00<007ooOol0Y7oo000MOol00`00Oomoo`1AOol00`00Oomoo`05Ool00`00Oomoo`2T
Ool001eoo`03001oogoo059oo`03001oogoo00Aoo`03001oogoo0:Aoo`007Goo00<007ooOol0DWoo
00<007ooOol017oo00<007ooOol0Y7oo000MOol00`00Oomoo`1BOol00`00Oomoo`04Ool00`00Oomo
o`2TOol001eoo`03001oogoo059oo`03001oogoo00Aoo`03001oogoo0:Aoo`007Goo00<007ooOol0
DWoo00<007ooOol017oo00<007ooOol0Y7oo000MOol00`00Oomoo`1BOol00`00Oomoo`04Ool00`00
Oomoo`2TOol001eoo`03001oogoo059oo`03001oogoo00Aoo`03001oogoo0:Aoo`007Goo00<007oo
Ool0DWoo00<007ooOol017oo00<007ooOol0Y7oo000MOol00`00Oomoo`1BOol00`00Oomoo`04Ool0
0`00Oomoo`2TOol001eoo`03001oogoo059oo`03001oogoo00Aoo`03001oogoo0:Aoo`007Goo00<0
07ooOol0DWoo00<007ooOol017oo00<007ooOol0Y7oo000MOol00`00Oomoo`1BOol00`00Oomoo`04
Ool00`00Oomoo`2TOol001eoo`03001oogoo059oo`03001oogoo00Aoo`03001oogoo0:Aoo`007Goo
00<007ooOol0Dgoo00<007ooOol00goo00<007ooOol0Y7oo000:Ool20004Ool20004Ool30004Ool0
0`00Oomoo`1COol00`00Oomoo`03Ool00`00Oomoo`2TOol000Uoo`04001oogoo0003Ool20005Ool0
0`00Oomoo`03Ool00`00Oomoo`1COol00`00Oomoo`02Ool00`00Oomoo`2UOol000Uoo`04001oogoo
0008Ool40004Ool2001DOol00`00Oomoo`02Ool00`00Oomoo`2UOol000Uoo`04001oogoo0008Ool0
0`00Ool00005Ool00`00Oomoo`1COol00`00Oomoo`02Ool00`00Oomoo`2UOol000Uoo`04001oogoo
0008Ool00`00Ool00005Ool00`00Oomoo`1COol00`00Oomoo`02Ool00`00Oomoo`2UOol000Yoo`80
00Yoo`8000Eoo`03001oogoo05=oo`03001oogoo009oo`03001oogoo0:Eoo`007Goo00<007ooOol0
Dgoo00<007ooOol00Woo00<007ooOol0YGoo000MOol00`00Oomoo`1COol00`00Oomoo`02Ool00`00
Oomoo`2UOol001eoo`03001oogoo05=oo`03001oogoo009oo`03001oogoo0:Eoo`007Goo00<007oo
Ool0Dgoo00<007ooOol00Woo00<007ooOol0YGoo000MOol00`00Oomoo`1COol00`00Oomoo`02Ool0
0`00Oomoo`2UOol001eoo`03001oogoo05=oo`03001oogoo009oo`03001oogoo0:Eoo`007Goo00<0
07ooOol0Dgoo00<007ooOol00Woo00<007ooOol0YGoo000MOol00`00Oomoo`1COol00`00Oomoo`02
Ool00`00Oomoo`2UOol001eoo`03001oogoo05=oo`03001oogoo009oo`03001oogoo0:Eoo`007Goo
00<007ooOol0Dgoo00<007ooOol00Woo00<007ooOol0YGoo000MOol00`00Oomoo`1COol00`00Oomo
o`02Ool00`00Oomoo`2UOol001eoo`03001oogoo05=oo`03001oogoo009oo`03001oogoo0:Eoo`00
7Goo00<007ooOol0Dgoo00<007ooOol00Woo00<007ooOol0YGoo000MOol00`00Oomoo`1COol00`00
Oomoo`02Ool00`00Oomoo`2UOol001eoo`03001oogoo05=oo`03001oogoo009oo`03001oogoo0:Eo
o`007Goo00<007ooOol0Dgoo00<007ooOol00Woo00<007ooOol0YGoo000MOol00`00Oomoo`1COol0
0`00Oomoo`02Ool00`00Oomoo`2UOol001eoo`03001oogoo05=oo`03001oogoo009oo`03001oogoo
0:Eoo`007Goo00<007ooOol0Dgoo00<007ooOol00Woo00<007ooOol0YGoo000MOol00`00Oomoo`1D
Ool01@00Oomoogoo0000Ygoo000MOol00`00Oomoo`1DOol01@00Oomoogoo0000Ygoo000:Ool20004
Ool20004Ool20005Ool00`00Oomoo`1DOol01@00Oomoogoo0000Ygoo0009Ool01000Oomoo`000goo
0P000goo00@007ooOol000Aoo`03001oogoo05Aoo`05001oogooOol0002WOol000Uoo`04001oogoo
0008Ool01000Oomoo`0017oo0P00EGoo00D007ooOomoo`000:Moo`002Goo00@007ooOol000Qoo`<0
00Eoo`03001oogoo05Aoo`05001oogooOol0002WOol000Uoo`04001oogoo0008Ool00`00Oomoo`05
Ool00`00Oomoo`1DOol01@00Oomoogoo0000Ygoo000:Ool2000:Ool30004Ool00`00Oomoo`1DOol0
1@00Oomoogoo0000Ygoo000MOol00`00Oomoo`1DOol01@00Oomoogoo0000Ygoo000MOol00`00Oomo
o`1DOol01@00Oomoogoo0000Ygoo000MOol00`00Oomoo`1DOol01000Oomoo`00Z7oo000MOol00`00
Oomoo`1DOol01000Oomoo`00Z7oo000MOol00`00Oomoo`1DOol01000Oomoo`00Z7oo000MOol00`00
Oomoo`1DOol01000Oomoo`00Z7oo000MOol00`00Oomoo`1DOol01000Oomoo`00Z7oo000MOol00`00
Oomoo`1DOol01000Oomoo`00Z7oo000MOol00`00Oomoo`1DOol01000Oomoo`00Z7oo000MOol00`00
Oomoo`1DOol01000Oomoo`00Z7oo000MOol00`00Oomoo`1DOol01000Oomoo`00Z7oo000MOol00`00
Oomoo`1DOol01000Oomoo`00Z7oo000MOol00`00Oomoo`1DOol01000Oomoo`00Z7oo000MOol00`00
Oomoo`1DOol01000Oomoo`00Z7oo000MOol00`00Oomoo`1DOol01000Oomoo`00Z7oo000MOol00`00
Oomoo`1DOol01000Oomoo`00Z7oo000MOol00`00Oomoo`1DOol01000Oomoo`00Z7oo000MOol00`00
Oomoo`1DOol01000Oomoo`00Z7oo000MOol00`00Oomoo`1DOol01000Oomoo`00Z7oo000MOol00`00
Oomoo`1DOol01000Oomoo`00Z7oo000:Ool20004Ool20004Ool20005Ool00`00Oomoo`1DOol01000
Oomoo`00Z7oo0009Ool01000Oomoo`000goo0P000goo00@007ooOol000Aoo`03001oogoo05Aoo`04
001oogoo002XOol000Uoo`04001oogoo0008Ool01000Oomoo`0017oo0P00EGoo00@007ooOol00:Qo
o`002Goo00@007ooOol000Uoo`8000Eoo`03001oogoo05Aoo`04001oogoo002XOol000Uoo`04001o
ogoo0008Ool01000Oomoo`0017oo00<007ooOol0E7oo00@007ooOol00:Qoo`002Woo0P002Woo0P00
1Goo00<007ooOol0E7oo00@007ooOol00:Qoo`007Goo00<007ooOol0E7oo00@007ooOol00:Qoo`00
7Goo00<007ooOol0E7oo00<007oo0000ZGoo000MOol00`00Oomoo`1DOol00`00Ool0002YOol001eo
o`03001oogoo05Aoo`03001oo`000:Uoo`007Goo00<007ooOol0E7oo00<007oo0000ZGoo000MOol0
0`00Oomoo`1EOol2002YOol001eoo`03001oogoo05Eoo`800:Uoo`007Goo00<007ooOol0EGoo0P00
ZGoo000MOol00`00Oomoo`1EOol2002YOol001eoo`03001oogoo05Eoo`800:Uoo`007Goo00<007oo
Ool0EGoo0P00ZGoo000MOol00`00Oomoo`1EOol2002YOol001eoo`03001oogoo05Eoo`800:Uoo`00
7Goo00<007ooOol0EGoo0P00ZGoo000MOol00`00Oomoo`1EOol2002YOol001eoo`03001oogoo05Eo
o`800:Uoo`007Goo00<007ooOol0EGoo00<007ooOol0Z7oo000MOol00`00Oomoo`1EOol00`00Oomo
o`2XOol001eoo`03001oogoo05Eoo`03001oogoo0:Qoo`007Goo00<007ooOol0EGoo00<007ooOol0
Z7oo000MOol00`00Oomoo`1EOol00`00Oomoo`2XOol001Eoo`<000Eoo`03001oogoo05Eoo`03001o
ogoo0:Qoo`005Woo00<007ooOol017oo00<007ooOol0EGoo00<007ooOol0Z7oo000FOol00`00Oomo
o`04Ool2001FOol00`00Oomoo`2XOol001Ioo`03001oogoo0?moo`Qoo`005Woo00<007ooOol0ogoo
27oo000EOol2003oOol:Ool00?moob5oo`00ogoo8Goo003oOolQOol000ioo`@0029oo`<000=oo`<0
00Eoo`<000Uoo`<0009oo`@000Moo`80009oo`80009oo`@0009oo`<000=oo`<0009oo`@000=oo`D0
0003Ool000000080009oo`D000Ioo`<000Aoo`<0009oo`D00004Ool00000Ool20002Ool5001]Ool0
00moo`03001oogoo02=oo`03001oogoo00=oo`03001oogoo00Eoo`03001oogoo00Moo`05001oogoo
Ool00002Ool00`00Oomoo`08Ool01000Ool000000Woo00<007ooOol00goo00L007ooOomoo`00Ool0
0003Ool01000Oomoo`0017oo00L007ooOomoo`00Ool00005Ool01@00Oomoogoo00001goo00@007oo
Ool0009oo`07001oogooOol007oo00000Woo00@007ooOol0009oo`04001oogoo0003Ool00`00Oomo
o`1/Ool000=oo`D00007Ool007oo001oo`00Ool010000Woo1@0000=oo`0000000`000Woo0`000Woo
1@000Woo1@0000=oo`0000000P000goo00<007ooOol01Goo00<007ooOol01goo00D007ooOomoo`00
009oo`03001oogoo00Qoo`<000=oo`D00003Ool007oo00Aoo`05001oogooOol00002Ool00`00Oomo
o`02Ool01P00Oomoogoo001oo`D00003Ool007oo009oo`03001oogoo00Moo`80009oo`07001oogoo
Ool007oo00000Woo00@007ooOol0009oo`04001oogoo0003Ool00`00Oomoo`1/Ool000=oo`04001o
ogoo0002Ool01`00Ool007oo001oo`0000=oo`05001oogooOol00005Ool00`00Oomoo`02Ool01P00
Oomoo`00Ool0009oo`04001oogoo0003Ool01000Ool007oo0`000goo0`000goo00D007oo001oo`00
00Moo`05001oogooOol00002Ool00`00Oomoo`08Ool01000Oomoo`000Woo00L007ooOomoo`00Ool0
0003Ool00`00Ool00003Ool00`00Oomoo`020003Ool01`00Oomoogoo001oo`0000=oo`03001oo`00
00=oo`03001oogoo00Eoo`8000Aoo`07001oogooOol007oo00000Woo00@007ooOol0009oo`04001o
ogoo0003Ool00`00Oomoo`1/Ool000=oo`@0009oo`07001oo`00Ool007oo00000goo00D007ooOomo
o`0000Eoo`03001oogoo009oo`03001oogoo009oo`04001oogoo0002Ool01P00Oomoogoo001oo`D0
00=oo`03001oogoo00=oo`05001oo`00Ool00008Ool30002Ool40008Ool01000Oomoo`000goo0`00
0goo10000Woo0`000Woo0P0000=oo`0000000Woo10000Woo0`000goo10001goo00@007ooOol000=o
o`<00004Ool00000Ool200000goo000000030003Ool4001^Ool000Ioo`0:001oogoo001oo`00Ool0
07oo0003Ool01@00Oomoogoo00001Goo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009o
o`06001oogooOol007oo1P0000=oo`0000000`000Woo1@003Woo00<007ooOol01goo10007goo00<0
07ooOol02Goo00<007ooOol01Woo0`0067oo00<007ooOol0K7oo0004Ool300000goo000000090004
Ool00`00Oomoo`02Ool20003Ool4000017oo000007oo0P000goo10000Woo0`007Goo0`00:Goo0P00
2Woo0P008Woo0P00KWoo000GOol00`00Oomoo`08Ool00`00Oomoo`0<Ool00`00Oomoo`3/Ool001Eo
o`<000Eoo`03001oogoo009oo`03001oogoo00]oo`800>ioo`00ogoo8Goo003oOolQOol00?moob5o
o`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {946.587, -0.14072, 0.462505, 
  0.00748348}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-9.5 0.01 0 0.618034 [
[.3 -0.0125 -9 -9 ]
[.3 -0.0125 9 0 ]
[.5 -0.0125 -12 -9 ]
[.5 -0.0125 12 0 ]
[.7 -0.0125 -12 -9 ]
[.7 -0.0125 12 0 ]
[.9 -0.0125 -12 -9 ]
[.9 -0.0125 12 0 ]
[1.025 0 0 -6 ]
[1.025 0 58 6 ]
[.0875 .12361 -18 -4.5 ]
[.0875 .12361 0 4.5 ]
[.0875 .24721 -18 -4.5 ]
[.0875 .24721 0 4.5 ]
[.0875 .37082 -18 -4.5 ]
[.0875 .37082 0 4.5 ]
[.0875 .49443 -18 -4.5 ]
[.0875 .49443 0 4.5 ]
[.0875 .61803 -6 -4.5 ]
[.0875 .61803 0 4.5 ]
[.1 .64303 -29 0 ]
[.1 .64303 29 12 ]
[.5 .63053 -65 0 ]
[.5 .63053 65 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.3 0 m
.3 .00625 L
s
[(980)] .3 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1000)] .5 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(1020)] .7 -0.0125 0 1 Mshowa
.9 0 m
.9 .00625 L
s
[(1040)] .9 -0.0125 0 1 Mshowa
.125 Mabswid
.15 0 m
.15 .00375 L
s
.2 0 m
.2 .00375 L
s
.25 0 m
.25 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.45 0 m
.45 .00375 L
s
.55 0 m
.55 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.75 0 m
.75 .00375 L
s
.8 0 m
.8 .00375 L
s
.85 0 m
.85 .00375 L
s
.05 0 m
.05 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(frequency) show
117.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.1 .12361 m
.10625 .12361 L
s
[(0.2)] .0875 .12361 1 0 Mshowa
.1 .24721 m
.10625 .24721 L
s
[(0.4)] .0875 .24721 1 0 Mshowa
.1 .37082 m
.10625 .37082 L
s
[(0.6)] .0875 .37082 1 0 Mshowa
.1 .49443 m
.10625 .49443 L
s
[(0.8)] .0875 .49443 1 0 Mshowa
.1 .61803 m
.10625 .61803 L
s
[(1)] .0875 .61803 1 0 Mshowa
.125 Mabswid
.1 .0309 m
.10375 .0309 L
s
.1 .0618 m
.10375 .0618 L
s
.1 .09271 m
.10375 .09271 L
s
.1 .15451 m
.10375 .15451 L
s
.1 .18541 m
.10375 .18541 L
s
.1 .21631 m
.10375 .21631 L
s
.1 .27812 m
.10375 .27812 L
s
.1 .30902 m
.10375 .30902 L
s
.1 .33992 m
.10375 .33992 L
s
.1 .40172 m
.10375 .40172 L
s
.1 .43262 m
.10375 .43262 L
s
.1 .46353 m
.10375 .46353 L
s
.1 .52533 m
.10375 .52533 L
s
.1 .55623 m
.10375 .55623 L
s
.1 .58713 m
.10375 .58713 L
s
.25 Mabswid
.1 0 m
.1 .61803 L
s
gsave
.1 .64303 -90 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(amplitude) show
117.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.5 .63053 -126 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(FFT) show
87.000000 13.000000 moveto
(of) show
105.000000 13.000000 moveto
(Recorded) show
159.000000 13.000000 moveto
(Sound) show
189.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .00038 m
.01 .00083 L
.02 .00022 L
.03 .00189 L
.04 .00171 L
.05 .0019 L
.06 .00045 L
.07 .00193 L
.08 .00017 L
.09 .00284 L
.1 .00225 L
.11 .00086 L
.12 .00048 L
.13 .00137 L
.14 .00285 L
.15 .00105 L
.16 .00159 L
.17 .00222 L
.18 .00042 L
.19 .00165 L
.2 .00287 L
.21 .00255 L
.22 .00239 L
.23 .00163 L
.24 .00219 L
.25 .00114 L
.26 .00122 L
.27 .00059 L
.28 .00243 L
.29 .00343 L
.3 .00143 L
.31 .00155 L
.32 .00283 L
.33 .00234 L
.34 .00265 L
.35 .00102 L
.36 .00177 L
.37 .00274 L
.38 .0014 L
.39 .00367 L
.4 .00403 L
.41 .00582 L
.42 .00383 L
.43 .00301 L
.44 .00449 L
.45 .00816 L
.46 .01233 L
.47 .01478 L
.48 .02113 L
.49 .04606 L
Mistroke
.5 .61803 L
.51 .06385 L
.52 .07934 L
.53 .01162 L
.54 .01431 L
.55 .00855 L
.56 .00555 L
.57 .00524 L
.58 .00455 L
.59 .003 L
.6 .0029 L
.61 .00279 L
.62 .00279 L
.63 .00279 L
.64 .00264 L
.65 .00234 L
.66 .0014 L
.67 .00254 L
.68 .00143 L
.69 .00197 L
.7 .001 L
.71 .00192 L
.72 .0013 L
.73 .00315 L
.74 .00077 L
.75 .00206 L
.76 .00159 L
.77 .00181 L
.78 .00172 L
.79 .00306 L
.8 .0015 L
.81 .00232 L
.82 .00143 L
.83 .00107 L
.84 .00156 L
.85 .00137 L
.86 .00146 L
.87 .00138 L
.88 .00106 L
.89 .00037 L
.9 .00203 L
.91 .00059 L
.92 .00375 L
.93 .00192 L
.94 .00235 L
.95 .00212 L
.96 .00182 L
.97 .00076 L
.98 .00182 L
.99 .00172 L
Mistroke
1 .0012 L
Mfstroke
1 .0012 m
1 .0012 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
@7oo0`0017oo0P0017oo0P006Goo0`0017oo0P0017oo0P0017oo0P005Woo0`0017oo0P000goo1000
0goo0P005Woo0`0017oo0P0017oo0`000goo0P00CGoo0013Ool01000Oomoo`000Woo00@007ooOol0
009oo`03001oogoo01Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000Woo00@007oo
Ool001Ioo`03001oogoo009oo`04001oogoo0003Ool00`00Oomoo`02Ool01000Oomoo`005Woo00<0
07ooOol00Woo00@007ooOol000Aoo`05001oogooOol00002Ool00`00Oomoo`1:Ool0045oo`<0009o
o`04001oogoo0002Ool01000Oomoo`006Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo
0002Ool01000Oomoo`005Woo00<007ooOol00Woo00@007ooOol000Aoo`05001oogooOol00002Ool0
0`00Oomoo`0DOol00`00Oomoo`02Ool01000Oomoo`000Woo10000Woo00@007ooOol004aoo`00@7oo
00@007ooOol000=oo`8000=oo`04001oogoo000IOol00`00Oomoo`02Ool01000Oomoo`000Woo00@0
07ooOol0009oo`04001oogoo000FOol00`00Oomoo`02Ool01000Oomoo`001Goo00@007ooOol0009o
o`03001oogoo01Aoo`03001oogoo009oo`04001oogoo0002Ool00`00Ool00003Ool01000Oomoo`00
C7oo0010Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo000IOol00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol0009oo`04001oogoo000FOol00`00Oomoo`02Ool01000Oomoo`00
0Woo00@007ooOol0009oo`04001oogoo000FOol00`00Oomoo`02Ool01000Oomoo`000Woo00<007oo
00000goo00@007ooOol004aoo`00@Goo0P0017oo0P0017oo0P006Goo0P001Goo0P0017oo0P0017oo
0P005Woo0P001Goo0P0017oo0P0017oo0P005Woo0P001Goo0P0017oo0P0017oo0P00:Goo10005goo
0`001Woo003nOol00`00Oomoo`0GOol00`00Oomoo`05Ool00>Qoo`@0009oo`@000=oo`@0009oo`@0
0003Ool0000000<0009oo`@00004Ool00000Ool20002Ool30003Ool00`00Oomoo`04Ool00>Uoo`03
001oogoo00=oo`03001oogoo009oo`03001oogoo00=oo`07001oogooOol007oo00000Woo00@007oo
Ool000Eoo`04001oogoo0002Ool01@00Oomoogoo00000Woo00<007ooOol017oo0007OooI0009Ool0
0`00Oomoo`03Ool00`00Oomoo`02Ool500000goo001oo`02Ool00`00Ool00002Ool00`00Oomoo`05
00001Goo001oogoo00000Woo00<007ooOol00goo00<007oo00001Goo0009Ool01000Oomoogoo1P00
0goo00@007ooOomoo`H000=oo`X000=ooa0000=ooad00003Ool0000000H000Yoo`03001oogoo00Qo
o`03001oogoo04D000=oo`8000=ooa8000Uoo`03001oogoo00=oo`8000=oo`07001oogooOol007oo
00000goo00<007oo00000Woo00@007ooOol000=oo`03001oo`00009oo`04001oogoo0003Ool01@00
Ool007oo00001Goo000MOol00`00Oomoo`0XOol00`00Oomoo`0EOol00`00Oomoo`05Ool20009Ool0
0`00Oomoo`07Ool4000MOol00`00Oomoo`0XOol00`00Oomoo`0LOol40002Ool200000goo00000002
Ool30003Ool600000goo00000003Ool300000goo000000030003Ool600000goo00000004Ool001eo
o`03001oogoo04Yoo`<000aoo`@006aoo`03001oogoo03Aoo`007Goo00<007ooOol0CGoo0P002Woo
00<007ooOol0KGoo0`00=7oo000MOol00`00Oomoo`1?Ool00`00Oomoo`07Ool00`00Oomoo`2TOol0
01eoo`03001oogoo04moo`03001oogoo00Moo`03001oogoo0:Aoo`007Goo00<007ooOol0D7oo00<0
07ooOol01Woo00<007ooOol0Y7oo000MOol00`00Oomoo`1@Ool00`00Oomoo`05Ool00`00Oomoo`2U
Ool001eoo`03001oogoo051oo`03001oogoo00Eoo`03001oogoo0:Eoo`007Goo00<007ooOol0DGoo
00<007ooOol017oo00<007ooOol0YGoo000MOol00`00Oomoo`1AOol00`00Oomoo`04Ool00`00Oomo
o`2UOol001eoo`03001oogoo055oo`03001oogoo00Aoo`03001oogoo0:Eoo`007Goo00<007ooOol0
DGoo00<007ooOol017oo00<007ooOol0YGoo000MOol00`00Oomoo`1AOol01@00Oomoogoo00000Woo
00<007ooOol0YGoo000MOol00`00Oomoo`1AOol01`00Oomoogoo001oo`000:Qoo`007Goo00<007oo
Ool0DGoo00@007ooOomoo`<00:Qoo`007Goo00<007ooOol0DGoo00@007ooOomoo`<00:Qoo`007Goo
00<007ooOol0DGoo00L007ooOomoo`00Ool0002XOol001eoo`03001oogoo055oo`05001oogooOol0
002ZOol001eoo`03001oogoo055oo`05001oogooOol0002ZOol001eoo`03001oogoo055oo`05001o
ogooOol0002ZOol001eoo`03001oogoo055oo`05001oogooOol0002ZOol001eoo`03001oogoo055o
o`05001oogooOol0002ZOol001eoo`03001oogoo055oo`05001oogooOol0002ZOol000Yoo`8000Ao
o`8000=oo`@000Aoo`03001oogoo055oo`05001oogooOol0002ZOol000Uoo`04001oogoo0003Ool2
0004Ool00`00Oomoo`04Ool00`00Oomoo`1AOol01@00Oomoogoo0000ZWoo0009Ool01000Oomoo`00
2Woo00<007ooOol00goo0P00DWoo00D007ooOomoo`000:Yoo`002Goo00@007ooOol000]oo`03001o
ogoo009oo`03001oogoo055oo`05001oogooOol0002ZOol000Uoo`04001oogoo0008Ool01000Oomo
o`0017oo00<007ooOol0DGoo00D007ooOomoo`000:Yoo`002Woo0P002Woo0P001Goo00<007ooOol0
DGoo00D007ooOomoo`000:Yoo`007Goo00<007ooOol0DGoo00D007ooOomoo`000:Yoo`007Goo00<0
07ooOol0DGoo00D007ooOomoo`000:Yoo`007Goo00<007ooOol0DGoo00D007ooOomoo`000:Yoo`00
7Goo00<007ooOol0DGoo00D007ooOomoo`000:Yoo`007Goo00<007ooOol0DGoo00D007ooOomoo`00
0:Yoo`007Goo00<007ooOol0DGoo00D007ooOomoo`000:Yoo`007Goo00<007ooOol0DGoo00D007oo
Oomoo`000:Yoo`007Goo00<007ooOol0DGoo00D007ooOomoo`000:Yoo`007Goo00<007ooOol0DGoo
00D007ooOomoo`000:Yoo`007Goo00<007ooOol0DGoo00D007ooOomoo`000:Yoo`007Goo00<007oo
Ool0DGoo00D007ooOomoo`000:Yoo`007Goo00<007ooOol0DWoo00@007ooOol00:Yoo`007Goo00<0
07ooOol0DWoo00@007ooOol00:Yoo`007Goo00<007ooOol0DWoo00@007ooOol00:Yoo`007Goo00<0
07ooOol0DWoo00<007oo0000Zgoo000MOol00`00Oomoo`1BOol00`00Ool0002[Ool001eoo`03001o
ogoo059oo`03001oo`000:]oo`007Goo00<007ooOol0DWoo00<007oo0000Zgoo000MOol00`00Oomo
o`1BOol00`00Ool0002[Ool001eoo`03001oogoo059oo`03001oo`000:]oo`007Goo00<007ooOol0
DWoo00<007oo0000Zgoo000:Ool20004Ool20004Ool30004Ool00`00Oomoo`1BOol00`00Ool0002[
Ool000Uoo`04001oogoo0003Ool20005Ool00`00Oomoo`03Ool00`00Oomoo`1BOol00`00Ool0002[
Ool000Uoo`04001oogoo0008Ool40004Ool2001COol00`00Ool0002[Ool000Uoo`04001oogoo0008
Ool00`00Ool00005Ool00`00Oomoo`1BOol00`00Ool0002[Ool000Uoo`04001oogoo0008Ool00`00
Ool00005Ool00`00Oomoo`1BOol00`00Ool0002[Ool000Yoo`8000Yoo`8000Eoo`03001oogoo059o
o`03001oo`000:]oo`007Goo00<007ooOol0DWoo00<007oo0000Zgoo000MOol00`00Oomoo`1BOol0
0`00Ool0002[Ool001eoo`03001oogoo059oo`03001oo`000:]oo`007Goo00<007ooOol0DWoo00<0
07oo0000Zgoo000MOol00`00Oomoo`1BOol00`00Ool0002[Ool001eoo`03001oogoo059oo`03001o
o`000:]oo`007Goo00<007ooOol0DWoo00<007oo0000Zgoo000MOol00`00Oomoo`1BOol00`00Ool0
002[Ool001eoo`03001oogoo059oo`03001oo`000:]oo`007Goo00<007ooOol0DWoo00<007oo0000
Zgoo000MOol00`00Oomoo`1BOol00`00Ool0002[Ool001eoo`03001oogoo059oo`03001oo`000:]o
o`007Goo00<007ooOol0DWoo00<007oo0000Zgoo000MOol00`00Oomoo`1BOol00`00Ool0002[Ool0
01eoo`03001oogoo059oo`03001oo`000:]oo`007Goo00<007ooOol0DWoo00<007oo0000Zgoo000M
Ool00`00Oomoo`1BOol00`00Ool0002[Ool001eoo`03001oogoo059oo`03001oo`000:]oo`007Goo
00<007ooOol0DWoo00<007oo0000Zgoo000MOol00`00Oomoo`1BOol00`00Ool0002[Ool001eoo`03
001oogoo059oo`03001oo`000:]oo`002Woo0P0017oo0P0017oo0P001Goo00<007ooOol0DWoo00<0
07oo0000Zgoo0009Ool01000Oomoo`000goo0P000goo00@007ooOol000Aoo`03001oogoo059oo`03
001oo`000:]oo`002Goo00@007ooOol000Qoo`04001oogoo0004Ool2001COol00`00Ool0002[Ool0
00Uoo`04001oogoo0008Ool30005Ool00`00Oomoo`1BOol00`00Ool0002[Ool000Uoo`04001oogoo
0008Ool00`00Oomoo`05Ool00`00Oomoo`1BOol00`00Ool0002[Ool000Yoo`8000Yoo`<000Aoo`03
001oogoo059oo`03001oo`000:]oo`007Goo00<007ooOol0DWoo00<007oo0000Zgoo000MOol00`00
Oomoo`1BOol00`00Ool0002[Ool001eoo`03001oogoo059oo`03001oo`000:]oo`007Goo00<007oo
Ool0DWoo00<007oo0000Zgoo000MOol00`00Oomoo`1BOol00`00Ool0002[Ool001eoo`03001oogoo
059oo`03001oo`000:]oo`007Goo00<007ooOol0DWoo00<007oo0000Zgoo000MOol00`00Oomoo`1B
Ool00`00Ool0002[Ool001eoo`03001oogoo059oo`03001oo`000:]oo`007Goo00<007ooOol0DWoo
00<007oo0000Zgoo000MOol00`00Oomoo`1BOol00`00Ool0002[Ool001eoo`03001oogoo059oo`03
001oo`000:]oo`007Goo00<007ooOol0DWoo00<007oo0000Zgoo000MOol00`00Oomoo`1BOol00`00
Ool0002[Ool001eoo`03001oogoo059oo`03001oo`000:]oo`007Goo00<007ooOol0DWoo00<007oo
0000Zgoo000MOol00`00Oomoo`1BOol00`00Ool0002[Ool001eoo`03001oogoo059oo`03001oo`00
0:]oo`007Goo00<007ooOol0DWoo00<007oo0000Zgoo000MOol00`00Oomoo`1COol2002[Ool000Yo
o`8000Aoo`8000Aoo`8000Eoo`03001oogoo05=oo`03001oogoo0:Yoo`002Goo00@007ooOol000=o
o`8000=oo`04001oogoo0004Ool00`00Oomoo`1COol00`00Oomoo`2ZOol000Uoo`04001oogoo0008
Ool01000Oomoo`0017oo0P00E7oo00<007ooOol0ZWoo0009Ool01000Oomoo`002Goo0P001Goo00<0
07ooOol0Dgoo00<007ooOol0ZWoo0009Ool01000Oomoo`0027oo00@007ooOol000Aoo`03001oogoo
05=oo`03001oogoo0:Yoo`002Woo0P002Woo0P001Goo00<007ooOol0Dgoo00<007ooOol0ZWoo000M
Ool00`00Oomoo`1COol00`00Oomoo`2ZOol001eoo`03001oogoo05=oo`03001oogoo0:Yoo`007Goo
00<007ooOol0Dgoo00<007ooOol0ZWoo000MOol00`00Oomoo`1COol00`00Oomoo`2ZOol001eoo`03
001oogoo05=oo`03001oogoo0:Yoo`007Goo00<007ooOol0Dgoo00<007ooOol0ZWoo000MOol00`00
Oomoo`1COol00`00Oomoo`2ZOol001eoo`03001oogoo05=oo`03001oogoo0:Yoo`007Goo00<007oo
Ool0Dgoo00<007ooOol0ZWoo000MOol00`00Oomoo`1COol00`00Oomoo`2ZOol001eoo`03001oogoo
05=oo`03001oogoo0:Yoo`007Goo00<007ooOol0Dgoo00<007ooOol0ZWoo000MOol00`00Oomoo`1C
Ool00`00Oomoo`2ZOol001eoo`03001oogoo05=oo`03001oogoo0:Yoo`007Goo00<007ooOol0Dgoo
00<007ooOol0ZWoo000MOol00`00Oomoo`1COol00`00Oomoo`2ZOol001eoo`03001oogoo05=oo`03
001oogoo0:Yoo`007Goo00<007ooOol0Dgoo00<007ooOol0ZWoo000MOol00`00Oomoo`1COol00`00
Oomoo`2ZOol001eoo`03001oogoo05=oo`03001oogoo0:Yoo`007Goo00<007ooOol0Dgoo00<007oo
Ool0ZWoo000EOol30005Ool00`00Oomoo`1COol00`00Oomoo`2ZOol001Ioo`03001oogoo00Aoo`03
001oogoo05=oo`03001oogoo0:Yoo`005Woo00<007ooOol017oo0P00E7oo00<007ooOol0ZWoo000F
Ool00`00Oomoo`3oOol8Ool001Ioo`03001oogoo0?moo`Qoo`005Goo0P00ogoo2Woo003oOolQOol0
0?moob5oo`00ogoo8Goo000>Ool4000ROol30003Ool30005Ool30009Ool30002Ool40007Ool20002
Ool20002Ool40002Ool30003Ool30002Ool40003Ool500000goo000000020002Ool50006Ool30004
Ool30002Ool5000017oo000007oo0P000Woo1@00KGoo000?Ool00`00Oomoo`0SOol00`00Oomoo`03
Ool00`00Oomoo`05Ool00`00Oomoo`07Ool01@00Oomoogoo00000Woo00<007ooOol027oo00@007oo
0000009oo`03001oogoo00=oo`07001oogooOol007oo00000goo00@007ooOol000Aoo`07001oogoo
Ool007oo00001Goo00D007ooOomoo`0000Moo`04001oogoo0002Ool01`00Oomoogoo001oo`00009o
o`04001oogoo0002Ool01000Oomoo`000goo00<007ooOol0K7oo0003Ool500001goo001oo`00Ool0
07oo00@0009oo`D00003Ool0000000<0009oo`<0009oo`D0009oo`D00003Ool00000008000=oo`03
001oogoo00Eoo`03001oogoo00Moo`05001oogooOol00002Ool00`00Oomoo`08Ool30003Ool50000
0goo001oo`04Ool01@00Oomoogoo00000Woo00<007ooOol00Woo00H007ooOomoo`00Ool500000goo
001oo`02Ool00`00Oomoo`07Ool20002Ool01`00Oomoogoo001oo`00009oo`04001oogoo0002Ool0
1000Oomoo`000goo00<007ooOol0K7oo0003Ool01000Oomoo`000Woo00L007oo001oo`00Ool00003
Ool01@00Oomoogoo00001Goo00<007ooOol00Woo00H007ooOol007oo0002Ool01000Oomoo`000goo
00@007oo001oo`<000=oo`<000=oo`05001oo`00Ool00007Ool01@00Oomoogoo00000Woo00<007oo
Ool027oo00@007ooOol0009oo`07001oogooOol007oo00000goo00<007oo00000goo00<007ooOol0
0P000goo00L007ooOomoo`00Ool00003Ool00`00Ool00003Ool00`00Oomoo`05Ool20004Ool01`00
Oomoogoo001oo`00009oo`04001oogoo0002Ool01000Oomoo`000goo00<007ooOol0K7oo0003Ool4
0002Ool01`00Ool007oo001oo`0000=oo`05001oogooOol00005Ool00`00Oomoo`02Ool00`00Oomo
o`02Ool01000Oomoo`000Woo00H007ooOomoo`00Ool50003Ool00`00Oomoo`03Ool01@00Ool007oo
000027oo0`000Woo100027oo00@007ooOol000=oo`<000=oo`@0009oo`<0009oo`800003Ool00000
009oo`@0009oo`<000=oo`@000Moo`04001oogoo0003Ool3000017oo000007oo0P0000=oo`000000
0`000goo1000KWoo0006Ool02P00Oomoo`00Ool007oo001oo`000goo00D007ooOomoo`0000Eoo`03
001oogoo009oo`03001oogoo009oo`04001oogoo0002Ool01P00Oomoogoo001oo`H00003Ool00000
00<0009oo`D000ioo`03001oogoo00Moo`@001moo`03001oogoo00Uoo`03001oogoo00Ioo`<001Qo
o`03001oogoo06aoo`0017oo0`0000=oo`0000002@0017oo00<007ooOol00Woo0P000goo100000Ao
o`00001oo`8000=oo`@0009oo`<001eoo`<002Uoo`8000Yoo`80029oo`8006ioo`005goo00<007oo
Ool027oo00<007ooOol037oo00<007ooOol0k7oo000EOol30005Ool00`00Oomoo`02Ool00`00Oomo
o`0;Ool2003^Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol0
0?moob5oo`00ogoo8Goo003oOolQOol00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {946.587, -0.14072, 0.462505, 
  0.00748348}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-9.5 0.01 0 0.618034 [
[.3 -0.0125 -9 -9 ]
[.3 -0.0125 9 0 ]
[.5 -0.0125 -12 -9 ]
[.5 -0.0125 12 0 ]
[.7 -0.0125 -12 -9 ]
[.7 -0.0125 12 0 ]
[.9 -0.0125 -12 -9 ]
[.9 -0.0125 12 0 ]
[1.025 0 0 -6 ]
[1.025 0 58 6 ]
[.0875 .12361 -18 -4.5 ]
[.0875 .12361 0 4.5 ]
[.0875 .24721 -18 -4.5 ]
[.0875 .24721 0 4.5 ]
[.0875 .37082 -18 -4.5 ]
[.0875 .37082 0 4.5 ]
[.0875 .49443 -18 -4.5 ]
[.0875 .49443 0 4.5 ]
[.0875 .61803 -6 -4.5 ]
[.0875 .61803 0 4.5 ]
[.1 .64303 -29 0 ]
[.1 .64303 29 12 ]
[.5 .63053 -65 0 ]
[.5 .63053 65 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.3 0 m
.3 .00625 L
s
[(980)] .3 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1000)] .5 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(1020)] .7 -0.0125 0 1 Mshowa
.9 0 m
.9 .00625 L
s
[(1040)] .9 -0.0125 0 1 Mshowa
.125 Mabswid
.15 0 m
.15 .00375 L
s
.2 0 m
.2 .00375 L
s
.25 0 m
.25 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.45 0 m
.45 .00375 L
s
.55 0 m
.55 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.75 0 m
.75 .00375 L
s
.8 0 m
.8 .00375 L
s
.85 0 m
.85 .00375 L
s
.05 0 m
.05 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(frequency) show
117.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.1 .12361 m
.10625 .12361 L
s
[(0.2)] .0875 .12361 1 0 Mshowa
.1 .24721 m
.10625 .24721 L
s
[(0.4)] .0875 .24721 1 0 Mshowa
.1 .37082 m
.10625 .37082 L
s
[(0.6)] .0875 .37082 1 0 Mshowa
.1 .49443 m
.10625 .49443 L
s
[(0.8)] .0875 .49443 1 0 Mshowa
.1 .61803 m
.10625 .61803 L
s
[(1)] .0875 .61803 1 0 Mshowa
.125 Mabswid
.1 .0309 m
.10375 .0309 L
s
.1 .0618 m
.10375 .0618 L
s
.1 .09271 m
.10375 .09271 L
s
.1 .15451 m
.10375 .15451 L
s
.1 .18541 m
.10375 .18541 L
s
.1 .21631 m
.10375 .21631 L
s
.1 .27812 m
.10375 .27812 L
s
.1 .30902 m
.10375 .30902 L
s
.1 .33992 m
.10375 .33992 L
s
.1 .40172 m
.10375 .40172 L
s
.1 .43262 m
.10375 .43262 L
s
.1 .46353 m
.10375 .46353 L
s
.1 .52533 m
.10375 .52533 L
s
.1 .55623 m
.10375 .55623 L
s
.1 .58713 m
.10375 .58713 L
s
.25 Mabswid
.1 0 m
.1 .61803 L
s
gsave
.1 .64303 -90 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(amplitude) show
117.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.5 .63053 -126 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(FFT) show
87.000000 13.000000 moveto
(of) show
105.000000 13.000000 moveto
(Recorded) show
159.000000 13.000000 moveto
(Sound) show
189.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .00148 m
.01 .00286 L
.02 .00408 L
.03 .00325 L
.04 .00579 L
.05 .00255 L
.06 .00269 L
.07 .00216 L
.08 .00549 L
.09 .00278 L
.1 .00052 L
.11 .00334 L
.12 .00176 L
.13 .00234 L
.14 .00397 L
.15 .00337 L
.16 .00516 L
.17 .00347 L
.18 .00595 L
.19 .00403 L
.2 .00319 L
.21 .00584 L
.22 .00191 L
.23 .00445 L
.24 .00152 L
.25 .00546 L
.26 .00324 L
.27 .00531 L
.28 .00346 L
.29 .00419 L
.3 .00527 L
.31 .00415 L
.32 .00708 L
.33 .0077 L
.34 .00646 L
.35 .0067 L
.36 .00344 L
.37 .00439 L
.38 .00927 L
.39 .0069 L
.4 .0104 L
.41 .01051 L
.42 .01272 L
.43 .01147 L
.44 .01693 L
.45 .02781 L
.46 .02313 L
.47 .02266 L
.48 .04479 L
.49 .10524 L
Mistroke
.5 .61803 L
.51 .242 L
.52 .04527 L
.53 .03507 L
.54 .04137 L
.55 .00809 L
.56 .00872 L
.57 .01231 L
.58 .00902 L
.59 .01024 L
.6 .00764 L
.61 .00923 L
.62 .00847 L
.63 .00586 L
.64 .00879 L
.65 .00328 L
.66 .00813 L
.67 .00691 L
.68 .0057 L
.69 .00142 L
.7 .00442 L
.71 .00638 L
.72 .00403 L
.73 .00377 L
.74 .00381 L
.75 .00287 L
.76 .00488 L
.77 .00367 L
.78 .00216 L
.79 .00258 L
.8 .00515 L
.81 .00538 L
.82 .00405 L
.83 .00392 L
.84 .00338 L
.85 .00142 L
.86 .00176 L
.87 .00193 L
.88 .00375 L
.89 .00217 L
.9 .00282 L
.91 .00323 L
.92 .00426 L
.93 .0021 L
.94 .00468 L
.95 .00427 L
.96 .00441 L
.97 .00349 L
.98 .00333 L
.99 .0038 L
Mistroke
1 .00243 L
Mfstroke
1 .00243 m
1 .00243 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
@7oo0`0017oo0P0017oo0P006Goo0`0017oo0P0017oo0P0017oo0P005Woo0`0017oo0P000goo1000
0goo0P005Woo0`0017oo0P0017oo0`000goo0P00CGoo0013Ool01000Oomoo`000Woo00@007ooOol0
009oo`03001oogoo01Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000Woo00@007oo
Ool001Ioo`03001oogoo009oo`04001oogoo0003Ool00`00Oomoo`02Ool01000Oomoo`005Woo00<0
07ooOol00Woo00@007ooOol000Aoo`05001oogooOol00002Ool00`00Oomoo`1:Ool0045oo`<0009o
o`04001oogoo0002Ool01000Oomoo`006Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo
0002Ool01000Oomoo`005Woo00<007ooOol00Woo00@007ooOol000Aoo`05001oogooOol00002Ool0
0`00Oomoo`0DOol00`00Oomoo`02Ool01000Oomoo`000Woo10000Woo00@007ooOol004aoo`00@7oo
00@007ooOol000=oo`8000=oo`04001oogoo000IOol00`00Oomoo`02Ool01000Oomoo`000Woo00@0
07ooOol0009oo`04001oogoo000FOol00`00Oomoo`02Ool01000Oomoo`001Goo00@007ooOol0009o
o`03001oogoo01Aoo`03001oogoo009oo`04001oogoo0002Ool00`00Ool00003Ool01000Oomoo`00
C7oo0010Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo000IOol00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol0009oo`04001oogoo000FOol00`00Oomoo`02Ool01000Oomoo`00
0Woo00@007ooOol0009oo`04001oogoo000FOol00`00Oomoo`02Ool01000Oomoo`000Woo00<007oo
00000goo00@007ooOol004aoo`00@Goo0P0017oo0P0017oo0P006Goo0P001Goo0P0017oo0P0017oo
0P005Woo0P001Goo0P0017oo0P0017oo0P005Woo0P001Goo0P0017oo0P0017oo0P00:Goo10005goo
0`001Woo003nOol00`00Oomoo`0GOol00`00Oomoo`05Ool00>Qoo`@0009oo`@000=oo`@0009oo`@0
0003Ool0000000<0009oo`@00004Ool00000Ool20002Ool30003Ool00`00Oomoo`04Ool00>Uoo`03
001oogoo00=oo`03001oogoo009oo`03001oogoo00=oo`07001oogooOol007oo00000Woo00@007oo
Ool000Eoo`04001oogoo0002Ool01@00Oomoogoo00000Woo00<007ooOol017oo0007OooI0009Ool0
0`00Oomoo`03Ool00`00Oomoo`02Ool500000goo001oo`02Ool00`00Ool00002Ool00`00Oomoo`05
00001Goo001oogoo00000Woo00<007ooOol00goo00<007oo00001Goo0007Ool900000goo00000005
00001goo00000000Ool007oo00l00003Ool0000000<00003Ool0000000X00003Ool0000000P000Mo
o`H000Aoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001o
ogoo00Ioo`@000Eoo`D0009ooa@00003Ool0000002L000Uoo`03001oogoo00=oo`8000=oo`07001o
ogooOol007oo00000goo00<007oo00000Woo00@007ooOol000=oo`03001oo`00009oo`04001oogoo
0003Ool01@00Ool007oo00001Goo000@Ool00`00Oomoo`05Ool00`00Oomoo`02Ool00`00Oomoo`0>
Ool00`00Oomoo`03Ool00`00Oomoo`06Ool01@00Oomoogoo00001Woo00@007ooOomoo`P000Eoo`@0
01Ioo`03001oogoo00Qoo`@00004Ool000000002Ool:0004Ool50003Ool01000Ool0000057oo00<0
07ooOol047oo00<007ooOol077oo10000Woo0P0000=oo`0000000Woo0`000goo1P0000=oo`000000
0goo0`0000=oo`0000000`000goo1P0000=oo`00000017oo000MOol00`00Oomoo`0mOol9000HOol0
1@00Oomoogoo00000goo0P00HGoo00<007ooOol0=7oo000MOol00`00Oomoo`16Ool00`00Oomoo`0E
Ool00`00Oomoo`1XOol3000dOol001eoo`03001oogoo04Moo`03001oo`0000@000moo`03001oogoo
0:1oo`007Goo00<007ooOol0B7oo00<007ooOol00Woo00<007ooOol03Goo00<007ooOol0X7oo000M
Ool00`00Oomoo`1>Ool00`00Oomoo`0<Ool00`00Oomoo`2POol001eoo`03001oogoo04ioo`03001o
ogoo00Qoo`@00:=oo`007Goo00<007ooOol0CWoo00<007ooOol01goo00D007ooOomoo`000:=oo`00
7Goo00<007ooOol0Cgoo00<007ooOol01Goo00<007ooOol0YWoo000MOol00`00Oomoo`1?Ool00`00
Oomoo`05Ool00`00Oomoo`2VOol001eoo`03001oogoo04moo`03001oogoo00Eoo`03001oogoo0:Io
o`007Goo00<007ooOol0Cgoo00<007ooOol01Goo00<007ooOol0YWoo000MOol00`00Oomoo`1@Ool0
0`00Oomoo`04Ool00`00Oomoo`2VOol001eoo`03001oogoo051oo`03001oogoo00Aoo`03001oogoo
0:Ioo`007Goo00<007ooOol0D7oo00<007ooOol017oo00<007ooOol0YWoo000MOol00`00Oomoo`1@
Ool00`00Oomoo`04Ool00`00Oomoo`2VOol001eoo`03001oogoo051oo`03001oogoo00Aoo`03001o
ogoo0:Ioo`007Goo00<007ooOol0D7oo00<007ooOol017oo00<007ooOol0YWoo000MOol00`00Oomo
o`1@Ool00`00Oomoo`04Ool00`00Oomoo`2VOol001eoo`03001oogoo055oo`03001oogoo00=oo`03
001oogoo0:Ioo`007Goo00<007ooOol0DGoo00<007ooOol00Woo00<007ooOol0Ygoo000MOol00`00
Oomoo`1AOol00`00Oomoo`02Ool00`00Oomoo`2WOol001eoo`03001oogoo055oo`03001oogoo009o
o`03001oogoo0:Moo`002Woo0P0017oo0P000goo100017oo00<007ooOol0DGoo00<007ooOol00Woo
00<007ooOol0Ygoo0009Ool01000Oomoo`000goo0P0017oo00<007ooOol017oo00<007ooOol0DGoo
00<007ooOol00Woo00<007ooOol0Ygoo0009Ool01000Oomoo`002Woo00<007ooOol00goo0P00DWoo
00<007ooOol00Woo00<007ooOol0Ygoo0009Ool01000Oomoo`002goo00<007ooOol00Woo00<007oo
Ool0DGoo00<007ooOol00Woo00<007ooOol0Ygoo0009Ool01000Oomoo`0027oo00@007ooOol000Ao
o`03001oogoo055oo`03001oogoo009oo`03001oogoo0:Moo`002Woo0P002Woo0P001Goo00<007oo
Ool0DGoo00<007ooOol00Woo00<007ooOol0Ygoo000MOol00`00Oomoo`1AOol00`00Oomoo`02Ool0
0`00Oomoo`2WOol001eoo`03001oogoo055oo`03001oogoo009oo`03001oogoo0:Moo`007Goo00<0
07ooOol0DGoo00<007ooOol00Woo00<007ooOol0Ygoo000MOol00`00Oomoo`1AOol00`00Oomoo`02
Ool00`00Oomoo`2WOol001eoo`03001oogoo055oo`03001oogoo009oo`03001oogoo0:Moo`007Goo
00<007ooOol0DGoo00<007ooOol00Woo00<007ooOol0Ygoo000MOol00`00Oomoo`1AOol00`00Oomo
o`02Ool00`00Oomoo`2WOol001eoo`03001oogoo055oo`03001oogoo009oo`03001oogoo0:Moo`00
7Goo00<007ooOol0DGoo00<007ooOol00Woo00<007ooOol0Ygoo000MOol00`00Oomoo`1AOol00`00
Oomoo`02Ool00`00Oomoo`2WOol001eoo`03001oogoo055oo`03001oogoo009oo`03001oogoo0:Mo
o`007Goo00<007ooOol0DGoo00<007ooOol00Woo00<007ooOol0Ygoo000MOol00`00Oomoo`1AOol0
1@00Oomoogoo0000ZWoo000MOol00`00Oomoo`1AOol01@00Oomoogoo0000ZWoo000MOol00`00Oomo
o`1AOol01@00Oomoogoo0000ZWoo000MOol00`00Oomoo`1AOol01@00Oomoogoo0000ZWoo000MOol0
0`00Oomoo`1AOol01@00Oomoogoo0000ZWoo000MOol00`00Oomoo`1AOol01@00Oomoogoo0000ZWoo
000MOol00`00Oomoo`1AOol01@00Oomoogoo0000ZWoo000MOol00`00Oomoo`1AOol01@00Oomoogoo
0000ZWoo000MOol00`00Oomoo`1AOol01@00Oomoogoo0000ZWoo000:Ool20004Ool20004Ool30004
Ool00`00Oomoo`1BOol01000Oomoo`00ZWoo0009Ool01000Oomoo`000goo0P001Goo00<007ooOol0
0goo00<007ooOol0DWoo00@007ooOol00:Yoo`002Goo00@007ooOol000Qoo`@000Aoo`8005=oo`04
001oogoo002ZOol000Uoo`04001oogoo0008Ool00`00Ool00005Ool00`00Oomoo`1BOol01000Oomo
o`00ZWoo0009Ool01000Oomoo`0027oo00<007oo00001Goo00<007ooOol0DWoo00@007ooOol00:Yo
o`002Woo0P002Woo0P001Goo00<007ooOol0DWoo00@007ooOol00:Yoo`007Goo00<007ooOol0DWoo
00@007ooOol00:Yoo`007Goo00<007ooOol0DWoo00@007ooOol00:Yoo`007Goo00<007ooOol0DWoo
00@007ooOol00:Yoo`007Goo00<007ooOol0DWoo00@007ooOol00:Yoo`007Goo00<007ooOol0DWoo
00@007ooOol00:Yoo`007Goo00<007ooOol0DWoo00@007ooOol00:Yoo`007Goo00<007ooOol0DWoo
00@007ooOol00:Yoo`007Goo00<007ooOol0DWoo00@007ooOol00:Yoo`007Goo00<007ooOol0DWoo
00@007ooOol00:Yoo`007Goo00<007ooOol0DWoo00@007ooOol00:Yoo`007Goo00<007ooOol0DWoo
00@007ooOol00:Yoo`007Goo00<007ooOol0DWoo00@007ooOol00:Yoo`007Goo00<007ooOol0DWoo
00@007ooOol00:Yoo`007Goo00<007ooOol0DWoo00@007ooOol00:Yoo`007Goo00<007ooOol0DWoo
00@007ooOol00:Yoo`007Goo00<007ooOol0DWoo00@007ooOol00:Yoo`007Goo00<007ooOol0DWoo
00<007oo0000Zgoo000MOol00`00Oomoo`1BOol00`00Ool0002[Ool001eoo`03001oogoo059oo`03
001oo`000:]oo`007Goo00<007ooOol0DWoo00<007oo0000Zgoo000MOol00`00Oomoo`1BOol00`00
Ool0002[Ool000Yoo`8000Aoo`8000Aoo`8000Eoo`03001oogoo059oo`03001oo`000:]oo`002Goo
00@007ooOol000=oo`8000=oo`04001oogoo0004Ool00`00Oomoo`1BOol00`00Ool0002[Ool000Uo
o`04001oogoo0008Ool01000Oomoo`0017oo0P00Dgoo00<007oo0000Zgoo0009Ool01000Oomoo`00
27oo0`001Goo00<007ooOol0DWoo00<007oo0000Zgoo0009Ool01000Oomoo`0027oo00<007ooOol0
1Goo00<007ooOol0DWoo00<007oo0000Zgoo000:Ool2000:Ool30004Ool00`00Oomoo`1BOol00`00
Ool0002[Ool001eoo`03001oogoo059oo`03001oo`000:]oo`007Goo00<007ooOol0DWoo00<007oo
0000Zgoo000MOol00`00Oomoo`1BOol00`00Ool0002[Ool001eoo`03001oogoo059oo`03001oo`00
0:]oo`007Goo00<007ooOol0DWoo00<007oo0000Zgoo000MOol00`00Oomoo`1BOol00`00Ool0002[
Ool001eoo`03001oogoo059oo`03001oo`000:]oo`007Goo00<007ooOol0DWoo00<007oo0000Zgoo
000MOol00`00Oomoo`1BOol00`00Ool0002[Ool001eoo`03001oogoo059oo`03001oo`000:]oo`00
7Goo00<007ooOol0DWoo00<007oo0000Zgoo000MOol00`00Oomoo`1BOol00`00Ool0002[Ool001eo
o`03001oogoo059oo`03001oo`000:]oo`007Goo00<007ooOol0DWoo00<007oo0000Zgoo000MOol0
0`00Oomoo`1BOol00`00Ool0002[Ool001eoo`03001oogoo059oo`03001oo`000:]oo`007Goo00<0
07ooOol0DWoo00<007oo0000Zgoo000MOol00`00Oomoo`1BOol00`00Ool0002[Ool001eoo`03001o
ogoo059oo`03001oo`000:]oo`007Goo00<007ooOol0DWoo00<007oo0000Zgoo000:Ool20004Ool2
0004Ool20005Ool00`00Oomoo`1BOol00`00Ool0002[Ool000Uoo`04001oogoo0003Ool20003Ool0
1000Oomoo`0017oo00<007ooOol0DWoo00<007oo0000Zgoo0009Ool01000Oomoo`0027oo00@007oo
Ool000Aoo`8005Aoo`800:]oo`002Goo00@007ooOol000Uoo`8000Eoo`03001oogoo05=oo`800:]o
o`002Goo00@007ooOol000Qoo`04001oogoo0004Ool00`00Oomoo`1COol2002[Ool000Yoo`8000Yo
o`8000Eoo`03001oogoo05=oo`800:]oo`007Goo00<007ooOol0Dgoo0P00Zgoo000MOol00`00Oomo
o`1COol2002[Ool001eoo`03001oogoo05=oo`800:]oo`007Goo00<007ooOol0Dgoo0P00Zgoo000M
Ool00`00Oomoo`1COol00`00Oomoo`2ZOol001eoo`03001oogoo05=oo`03001oogoo0:Yoo`007Goo
00<007ooOol0Dgoo00<007ooOol0ZWoo000MOol00`00Oomoo`1COol00`00Oomoo`2ZOol001eoo`03
001oogoo05=oo`03001oogoo0:Yoo`007Goo00<007ooOol0Dgoo00<007ooOol0ZWoo000MOol00`00
Oomoo`1COol00`00Oomoo`2ZOol001eoo`03001oogoo05=oo`03001oogoo0:Yoo`007Goo00<007oo
Ool0Dgoo00<007ooOol0ZWoo000MOol00`00Oomoo`1COol00`00Oomoo`2ZOol001eoo`03001oogoo
05=oo`03001oogoo0:Yoo`007Goo00<007ooOol0Dgoo00<007ooOol0ZWoo000MOol00`00Oomoo`1C
Ool00`00Oomoo`2ZOol001eoo`03001oogoo05=oo`03001oogoo0:Yoo`007Goo00<007ooOol0Dgoo
00<007ooOol0ZWoo000MOol00`00Oomoo`1COol00`00Oomoo`2ZOol001eoo`03001oogoo05=oo`03
001oogoo0:Yoo`005Goo0`001Goo00<007ooOol0Dgoo00<007ooOol0ZWoo000FOol00`00Oomoo`04
Ool00`00Oomoo`1COol00`00Oomoo`2ZOol001Ioo`03001oogoo00Aoo`8005Aoo`03001oogoo0:Yo
o`005Woo00<007ooOol0ogoo27oo000FOol00`00Oomoo`3oOol8Ool001Eoo`800?moo`Yoo`00ogoo
8Goo003oOolQOol00?moob5oo`003Woo10008Woo0`000goo0`001Goo0`002Goo0`000Woo10001goo
0P000Woo0P000Woo10000Woo0`000goo0`000Woo10000goo1@0000=oo`0000000P000Woo1@001Woo
0`0017oo0`000Woo1@0000Aoo`00001oo`80009oo`D006eoo`003goo00<007ooOol08goo00<007oo
Ool00goo00<007ooOol01Goo00<007ooOol01goo00D007ooOomoo`00009oo`03001oogoo00Qoo`04
001oo`000002Ool00`00Oomoo`03Ool01`00Oomoogoo001oo`0000=oo`04001oogoo0004Ool01`00
Oomoogoo001oo`0000Eoo`05001oogooOol00007Ool01000Oomoo`000Woo00L007ooOomoo`00Ool0
0002Ool01000Oomoo`000Woo00@007ooOol000=oo`03001oogoo06aoo`000goo1@0000Moo`00Ool0
07oo001oo`040002Ool500000goo000000030002Ool30002Ool50002Ool500000goo000000020003
Ool00`00Oomoo`05Ool00`00Oomoo`07Ool01@00Oomoogoo00000Woo00<007ooOol027oo0`000goo
1@0000=oo`00Ool017oo00D007ooOomoo`00009oo`03001oogoo009oo`06001oogooOol007oo1@00
00=oo`00Ool00Woo00<007ooOol01goo0P000Woo00L007ooOomoo`00Ool00002Ool01000Oomoo`00
0Woo00@007ooOol000=oo`03001oogoo06aoo`000goo00@007ooOol0009oo`07001oo`00Ool007oo
00000goo00D007ooOomoo`0000Eoo`03001oogoo009oo`06001oogoo001oo`000Woo00@007ooOol0
00=oo`04001oo`00Ool30003Ool30003Ool01@00Ool007oo00001goo00D007ooOomoo`00009oo`03
001oogoo00Qoo`04001oogoo0002Ool01`00Oomoogoo001oo`0000=oo`03001oo`0000=oo`03001o
ogoo008000=oo`07001oogooOol007oo00000goo00<007oo00000goo00<007ooOol01Goo0P0017oo
00L007ooOomoo`00Ool00002Ool01000Oomoo`000Woo00@007ooOol000=oo`03001oogoo06aoo`00
0goo10000Woo00L007oo001oo`00Ool00003Ool01@00Oomoogoo00001Goo00<007ooOol00Woo00<0
07ooOol00Woo00@007ooOol0009oo`06001oogooOol007oo1@000goo00<007ooOol00goo00D007oo
001oo`0000Qoo`<0009oo`@000Qoo`04001oogoo0003Ool30003Ool40002Ool30002Ool200000goo
00000002Ool40002Ool30003Ool40007Ool01000Oomoo`000goo0`0000Aoo`00001oo`800003Ool0
000000<000=oo`@006ioo`001Woo00X007ooOol007oo001oo`00Ool000=oo`05001oogooOol00005
Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01000Oomoo`000Woo00H007ooOomoo`00Ool600000goo
000000030002Ool5000>Ool00`00Oomoo`07Ool4000OOol00`00Oomoo`09Ool00`00Oomoo`06Ool3
000HOol00`00Oomoo`1/Ool000Aoo`<00003Ool0000000T000Aoo`03001oogoo009oo`8000=oo`@0
0004Ool00000Ool20003Ool40002Ool3000MOol3000YOol2000:Ool2000ROol2001^Ool001Moo`03
001oogoo00Qoo`03001oogoo00aoo`03001oogoo0>aoo`005Goo0`001Goo00<007ooOol00Woo00<0
07ooOol02goo0P00kWoo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo
8Goo003oOolQOol00?moob5oo`00ogoo8Goo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {946.587, -0.14072, 0.462505, 
  0.00748348}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-9.5 0.01 0 0.618034 [
[.3 -0.0125 -9 -9 ]
[.3 -0.0125 9 0 ]
[.5 -0.0125 -12 -9 ]
[.5 -0.0125 12 0 ]
[.7 -0.0125 -12 -9 ]
[.7 -0.0125 12 0 ]
[.9 -0.0125 -12 -9 ]
[.9 -0.0125 12 0 ]
[1.025 0 0 -6 ]
[1.025 0 58 6 ]
[.0875 .12361 -18 -4.5 ]
[.0875 .12361 0 4.5 ]
[.0875 .24721 -18 -4.5 ]
[.0875 .24721 0 4.5 ]
[.0875 .37082 -18 -4.5 ]
[.0875 .37082 0 4.5 ]
[.0875 .49443 -18 -4.5 ]
[.0875 .49443 0 4.5 ]
[.0875 .61803 -6 -4.5 ]
[.0875 .61803 0 4.5 ]
[.1 .64303 -29 0 ]
[.1 .64303 29 12 ]
[.5 .63053 -65 0 ]
[.5 .63053 65 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.3 0 m
.3 .00625 L
s
[(980)] .3 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1000)] .5 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(1020)] .7 -0.0125 0 1 Mshowa
.9 0 m
.9 .00625 L
s
[(1040)] .9 -0.0125 0 1 Mshowa
.125 Mabswid
.15 0 m
.15 .00375 L
s
.2 0 m
.2 .00375 L
s
.25 0 m
.25 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.45 0 m
.45 .00375 L
s
.55 0 m
.55 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.75 0 m
.75 .00375 L
s
.8 0 m
.8 .00375 L
s
.85 0 m
.85 .00375 L
s
.05 0 m
.05 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(frequency) show
117.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.1 .12361 m
.10625 .12361 L
s
[(0.2)] .0875 .12361 1 0 Mshowa
.1 .24721 m
.10625 .24721 L
s
[(0.4)] .0875 .24721 1 0 Mshowa
.1 .37082 m
.10625 .37082 L
s
[(0.6)] .0875 .37082 1 0 Mshowa
.1 .49443 m
.10625 .49443 L
s
[(0.8)] .0875 .49443 1 0 Mshowa
.1 .61803 m
.10625 .61803 L
s
[(1)] .0875 .61803 1 0 Mshowa
.125 Mabswid
.1 .0309 m
.10375 .0309 L
s
.1 .0618 m
.10375 .0618 L
s
.1 .09271 m
.10375 .09271 L
s
.1 .15451 m
.10375 .15451 L
s
.1 .18541 m
.10375 .18541 L
s
.1 .21631 m
.10375 .21631 L
s
.1 .27812 m
.10375 .27812 L
s
.1 .30902 m
.10375 .30902 L
s
.1 .33992 m
.10375 .33992 L
s
.1 .40172 m
.10375 .40172 L
s
.1 .43262 m
.10375 .43262 L
s
.1 .46353 m
.10375 .46353 L
s
.1 .52533 m
.10375 .52533 L
s
.1 .55623 m
.10375 .55623 L
s
.1 .58713 m
.10375 .58713 L
s
.25 Mabswid
.1 0 m
.1 .61803 L
s
gsave
.1 .64303 -90 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(amplitude) show
117.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.5 .63053 -126 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(FFT) show
87.000000 13.000000 moveto
(of) show
105.000000 13.000000 moveto
(Recorded) show
159.000000 13.000000 moveto
(Sound) show
189.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .0026 m
.01 .00114 L
.02 .00551 L
.03 .00056 L
.04 .00193 L
.05 .00096 L
.06 .00264 L
.07 .00159 L
.08 .00179 L
.09 .00436 L
.1 .00287 L
.11 .0047 L
.12 .00215 L
.13 .0021 L
.14 .00394 L
.15 .00213 L
.16 .00496 L
.17 .00273 L
.18 .00436 L
.19 .00394 L
.2 .0031 L
.21 .00349 L
.22 .00403 L
.23 .00483 L
.24 .00447 L
.25 .00482 L
.26 .00349 L
.27 .00228 L
.28 .00454 L
.29 .00223 L
.3 .00487 L
.31 .00654 L
.32 .0051 L
.33 .00417 L
.34 .00317 L
.35 .00653 L
.36 .01029 L
.37 .00554 L
.38 .00878 L
.39 .00647 L
.4 .00672 L
.41 .00538 L
.42 .00987 L
.43 .01227 L
.44 .01153 L
.45 .01416 L
.46 .01199 L
.47 .03276 L
.48 .04342 L
.49 .08663 L
Mistroke
.5 .61803 L
.51 .13699 L
.52 .11118 L
.53 .05445 L
.54 .03224 L
.55 .02253 L
.56 .0154 L
.57 .0141 L
.58 .01057 L
.59 .01149 L
.6 .00639 L
.61 .00756 L
.62 .00566 L
.63 .00752 L
.64 .00623 L
.65 .00492 L
.66 .00388 L
.67 .00547 L
.68 .00537 L
.69 .00441 L
.7 .00376 L
.71 .00511 L
.72 .00478 L
.73 .00232 L
.74 .00564 L
.75 .00309 L
.76 .00444 L
.77 .00349 L
.78 .00399 L
.79 .00208 L
.8 .00309 L
.81 .00192 L
.82 .00112 L
.83 .0067 L
.84 .00322 L
.85 .00456 L
.86 .00367 L
.87 .00468 L
.88 .0026 L
.89 .00153 L
.9 .00422 L
.91 .00281 L
.92 .00335 L
.93 .00486 L
.94 .00222 L
.95 .00128 L
.96 .00055 L
.97 .00324 L
.98 .00288 L
.99 .00115 L
Mistroke
1 .00357 L
Mfstroke
1 .00357 m
1 .00357 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
@7oo0`0017oo0P0017oo0P006Goo0`0017oo0P0017oo0P0017oo0P005Woo0`0017oo0P000goo1000
0goo0P005Woo0`0017oo0P0017oo0`000goo0P00CGoo0013Ool01000Oomoo`000Woo00@007ooOol0
009oo`03001oogoo01Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000Woo00@007oo
Ool001Ioo`03001oogoo009oo`04001oogoo0003Ool00`00Oomoo`02Ool01000Oomoo`005Woo00<0
07ooOol00Woo00@007ooOol000Aoo`05001oogooOol00002Ool00`00Oomoo`1:Ool0045oo`<0009o
o`04001oogoo0002Ool01000Oomoo`006Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo
0002Ool01000Oomoo`005Woo00<007ooOol00Woo00@007ooOol000Aoo`05001oogooOol00002Ool0
0`00Oomoo`0DOol00`00Oomoo`02Ool01000Oomoo`000Woo10000Woo00@007ooOol004aoo`00@7oo
00@007ooOol000=oo`8000=oo`04001oogoo000IOol00`00Oomoo`02Ool01000Oomoo`000Woo00@0
07ooOol0009oo`04001oogoo000FOol00`00Oomoo`02Ool01000Oomoo`001Goo00@007ooOol0009o
o`03001oogoo01Aoo`03001oogoo009oo`04001oogoo0002Ool00`00Ool00003Ool01000Oomoo`00
C7oo0010Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo000IOol00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol0009oo`04001oogoo000FOol00`00Oomoo`02Ool01000Oomoo`00
0Woo00@007ooOol0009oo`04001oogoo000FOol00`00Oomoo`02Ool01000Oomoo`000Woo00<007oo
00000goo00@007ooOol004aoo`00@Goo0P0017oo0P0017oo0P006Goo0P001Goo0P0017oo0P0017oo
0P005Woo0P001Goo0P0017oo0P0017oo0P005Woo0P001Goo0P0017oo0P0017oo0P00:Goo10005goo
0`001Woo003nOol00`00Oomoo`0GOol00`00Oomoo`05Ool00>Qoo`@0009oo`@000=oo`@0009oo`@0
0003Ool0000000<0009oo`@00004Ool00000Ool20002Ool30003Ool00`00Oomoo`04Ool00>Uoo`03
001oogoo00=oo`03001oogoo009oo`03001oogoo00=oo`07001oogooOol007oo00000Woo00@007oo
Ool000Eoo`04001oogoo0002Ool01@00Oomoogoo00000Woo00<007ooOol017oo0007OooI0009Ool0
0`00Oomoo`03Ool00`00Oomoo`02Ool500000goo001oo`02Ool00`00Ool00002Ool00`00Oomoo`05
00001Goo001oogoo00000Woo00<007ooOol00goo00<007oo00001Goo0007Ool400000goo001oo`02
Oolj00000goo000000070009Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00
Oomoo`08Ool00`00Oomoo`06Ool60003Ool<00000goo0000000@0002OolI0004Ool70009Ool00`00
Oomoo`03Ool20003Ool01`00Oomoogoo001oo`0000=oo`03001oo`00009oo`04001oogoo0003Ool0
0`00Ool00002Ool01000Oomoo`000goo00D007oo001oo`0000Eoo`002goo00<007ooOol03goo00<0
07ooOol0:7oo00<007oo000027oo0P0000=oo`00000030003goo00<007ooOol04Woo2P001Woo0`00
0goo00<007ooOol01Woo00<007ooOol047oo0P003Goo00<007ooOol077oo10000Woo0P0000=oo`00
00000Woo0`000goo1P0000=oo`0000000goo0`0000=oo`0000000`000goo1P0000=oo`00000017oo
000MOol00`00Oomoo`0eOol00`00Oomoo`0<Ool7000FOol7001QOol00`00Oomoo`0dOol001eoo`03
001oogoo04Yoo`03001oogoo019oo`8006Qoo`<003Aoo`007Goo00<007ooOol0Bgoo00<007ooOol0
47oo00<007ooOol0Wgoo000MOol00`00Oomoo`1<Ool00`00Oomoo`0>Ool00`00Oomoo`2POol001eo
o`03001oogoo04eoo`03001oogoo00aoo`03001oogoo0:5oo`007Goo00<007ooOol0CGoo00<007oo
Ool037oo00<007ooOol0XGoo000MOol00`00Oomoo`1>Ool00`00Oomoo`0:Ool00`00Oomoo`2ROol0
01eoo`03001oogoo04moo`03001oogoo00Qoo`03001oogoo0:=oo`007Goo00<007ooOol0Cgoo00<0
07ooOol027oo00<007ooOol0Xgoo000MOol00`00Oomoo`1?Ool00`00Oomoo`07Ool00`00Oomoo`2T
Ool001eoo`03001oogoo051oo`03001oogoo00Ioo`03001oogoo0:Aoo`007Goo00<007ooOol0D7oo
00<007ooOol01Woo00<007ooOol0Y7oo000MOol00`00Oomoo`1@Ool00`00Oomoo`06Ool00`00Oomo
o`2TOol001eoo`03001oogoo051oo`03001oogoo00Eoo`03001oogoo0:Eoo`007Goo00<007ooOol0
D7oo00<007ooOol01Goo00<007ooOol0YGoo000MOol00`00Oomoo`1AOol00`00Oomoo`04Ool00`00
Oomoo`2UOol001eoo`03001oogoo055oo`03001oogoo00Aoo`03001oogoo0:Eoo`007Goo00<007oo
Ool0DGoo00<007ooOol017oo00<007ooOol0YGoo000MOol00`00Oomoo`1AOol00`00Oomoo`04Ool0
0`00Oomoo`2UOol001eoo`03001oogoo055oo`03001oogoo00=oo`03001oogoo0:Ioo`007Goo00<0
07ooOol0DGoo00<007ooOol00goo00<007ooOol0YWoo000MOol00`00Oomoo`1AOol00`00Oomoo`03
Ool00`00Oomoo`2VOol000Yoo`8000Aoo`8000=oo`@000Aoo`03001oogoo055oo`03001oogoo00=o
o`03001oogoo0:Ioo`002Goo00@007ooOol000=oo`8000Aoo`03001oogoo00Aoo`03001oogoo055o
o`03001oogoo009oo`03001oogoo0:Moo`002Goo00@007ooOol000Yoo`03001oogoo00=oo`80059o
o`03001oogoo009oo`03001oogoo0:Moo`002Goo00@007ooOol000]oo`03001oogoo009oo`03001o
ogoo055oo`03001oogoo009oo`03001oogoo0:Moo`002Goo00@007ooOol000Qoo`04001oogoo0004
Ool00`00Oomoo`1AOol01@00Oomoogoo0000ZWoo000:Ool2000:Ool20005Ool00`00Oomoo`1AOol0
1@00Oomoogoo0000ZWoo000MOol00`00Oomoo`1AOol01@00Oomoogoo0000ZWoo000MOol00`00Oomo
o`1AOol01@00Oomoogoo0000ZWoo000MOol00`00Oomoo`1AOol01@00Oomoogoo0000ZWoo000MOol0
0`00Oomoo`1AOol01@00Oomoogoo0000ZWoo000MOol00`00Oomoo`1AOol01@00Oomoogoo0000ZWoo
000MOol00`00Oomoo`1AOol01@00Oomoogoo0000ZWoo000MOol00`00Oomoo`1AOol01@00Oomoogoo
0000ZWoo000MOol00`00Oomoo`1AOol01@00Oomoogoo0000ZWoo000MOol00`00Oomoo`1AOol01@00
Oomoogoo0000ZWoo000MOol00`00Oomoo`1AOol01@00Oomoogoo0000ZWoo000MOol00`00Oomoo`1A
Ool01@00Oomoogoo0000ZWoo000MOol00`00Oomoo`1AOol01@00Oomoogoo0000ZWoo000MOol00`00
Oomoo`1AOol01@00Oomoogoo0000ZWoo000MOol00`00Oomoo`1AOol01@00Oomoogoo0000ZWoo000M
Ool00`00Oomoo`1AOol01@00Oomoogoo0000ZWoo000MOol00`00Oomoo`1AOol01@00Oomoogoo0000
ZWoo000MOol00`00Oomoo`1AOol01@00Oomoogoo0000ZWoo000MOol00`00Oomoo`1AOol01@00Oomo
ogoo0000ZWoo000MOol00`00Oomoo`1BOol01000Oomoo`00ZWoo000MOol00`00Oomoo`1BOol01000
Oomoo`00ZWoo000MOol00`00Oomoo`1BOol01000Oomoo`00ZWoo000:Ool20004Ool20004Ool30004
Ool00`00Oomoo`1BOol01000Oomoo`00ZWoo0009Ool01000Oomoo`000goo0P001Goo00<007ooOol0
0goo00<007ooOol0DWoo00@007ooOol00:Yoo`002Goo00@007ooOol000Qoo`@000Aoo`8005=oo`04
001oogoo002ZOol000Uoo`04001oogoo0008Ool00`00Ool00005Ool00`00Oomoo`1BOol01000Oomo
o`00ZWoo0009Ool01000Oomoo`0027oo00<007oo00001Goo00<007ooOol0DWoo00@007ooOol00:Yo
o`002Woo0P002Woo0P001Goo00<007ooOol0DWoo00<007oo0000Zgoo000MOol00`00Oomoo`1BOol0
0`00Ool0002[Ool001eoo`03001oogoo059oo`03001oo`000:]oo`007Goo00<007ooOol0DWoo00<0
07oo0000Zgoo000MOol00`00Oomoo`1BOol00`00Ool0002[Ool001eoo`03001oogoo059oo`03001o
o`000:]oo`007Goo00<007ooOol0DWoo00<007oo0000Zgoo000MOol00`00Oomoo`1BOol00`00Ool0
002[Ool001eoo`03001oogoo059oo`03001oo`000:]oo`007Goo00<007ooOol0DWoo00<007oo0000
Zgoo000MOol00`00Oomoo`1BOol00`00Ool0002[Ool001eoo`03001oogoo059oo`03001oo`000:]o
o`007Goo00<007ooOol0DWoo00<007oo0000Zgoo000MOol00`00Oomoo`1BOol00`00Ool0002[Ool0
01eoo`03001oogoo059oo`03001oo`000:]oo`007Goo00<007ooOol0DWoo00<007oo0000Zgoo000M
Ool00`00Oomoo`1BOol00`00Ool0002[Ool001eoo`03001oogoo059oo`03001oo`000:]oo`007Goo
00<007ooOol0DWoo00<007oo0000Zgoo000MOol00`00Oomoo`1BOol00`00Ool0002[Ool001eoo`03
001oogoo059oo`03001oo`000:]oo`007Goo00<007ooOol0DWoo00<007oo0000Zgoo000:Ool20004
Ool20004Ool20005Ool00`00Oomoo`1BOol00`00Ool0002[Ool000Uoo`04001oogoo0003Ool20003
Ool01000Oomoo`0017oo00<007ooOol0DWoo00<007oo0000Zgoo0009Ool01000Oomoo`0027oo00@0
07ooOol000Aoo`8005=oo`03001oo`000:]oo`002Goo00@007ooOol000Qoo`<000Eoo`03001oogoo
059oo`03001oo`000:]oo`002Goo00@007ooOol000Qoo`03001oogoo00Eoo`03001oogoo059oo`03
001oo`000:]oo`002Woo0P002Woo0`0017oo00<007ooOol0DWoo00<007oo0000Zgoo000MOol00`00
Oomoo`1BOol00`00Ool0002[Ool001eoo`03001oogoo059oo`03001oo`000:]oo`007Goo00<007oo
Ool0DWoo00<007oo0000Zgoo000MOol00`00Oomoo`1BOol00`00Ool0002[Ool001eoo`03001oogoo
059oo`03001oo`000:]oo`007Goo00<007ooOol0DWoo00<007oo0000Zgoo000MOol00`00Oomoo`1B
Ool00`00Ool0002[Ool001eoo`03001oogoo059oo`03001oo`000:]oo`007Goo00<007ooOol0DWoo
00<007oo0000Zgoo000MOol00`00Oomoo`1BOol00`00Ool0002[Ool001eoo`03001oogoo059oo`03
001oo`000:]oo`007Goo00<007ooOol0DWoo00<007oo0000Zgoo000MOol00`00Oomoo`1BOol00`00
Ool0002[Ool001eoo`03001oogoo059oo`03001oo`000:]oo`007Goo00<007ooOol0DWoo00<007oo
0000Zgoo000MOol00`00Oomoo`1BOol00`00Ool0002[Ool001eoo`03001oogoo059oo`03001oo`00
0:]oo`007Goo00<007ooOol0DWoo00<007oo0000Zgoo000MOol00`00Oomoo`1BOol00`00Ool0002[
Ool001eoo`03001oogoo059oo`03001oo`000:]oo`002Woo0P0017oo0P0017oo0P001Goo00<007oo
Ool0DWoo00<007oo0000Zgoo0009Ool01000Oomoo`000goo0P000goo00@007ooOol000Aoo`03001o
ogoo05=oo`800:]oo`002Goo00@007ooOol000Qoo`04001oogoo0004Ool2001DOol2002[Ool000Uo
o`04001oogoo0009Ool20005Ool00`00Oomoo`1COol2002[Ool000Uoo`04001oogoo0008Ool01000
Oomoo`0017oo00<007ooOol0Dgoo00<007ooOol0ZWoo000:Ool2000:Ool20005Ool00`00Oomoo`1C
Ool00`00Oomoo`2ZOol001eoo`03001oogoo05=oo`03001oogoo0:Yoo`007Goo00<007ooOol0Dgoo
00<007ooOol0ZWoo000MOol00`00Oomoo`1COol00`00Oomoo`2ZOol001eoo`03001oogoo05=oo`03
001oogoo0:Yoo`007Goo00<007ooOol0Dgoo00<007ooOol0ZWoo000MOol00`00Oomoo`1COol00`00
Oomoo`2ZOol001eoo`03001oogoo05=oo`03001oogoo0:Yoo`007Goo00<007ooOol0Dgoo00<007oo
Ool0ZWoo000MOol00`00Oomoo`1COol00`00Oomoo`2ZOol001eoo`03001oogoo05=oo`03001oogoo
0:Yoo`007Goo00<007ooOol0Dgoo00<007ooOol0ZWoo000MOol00`00Oomoo`1COol00`00Oomoo`2Z
Ool001eoo`03001oogoo05=oo`03001oogoo0:Yoo`007Goo00<007ooOol0Dgoo00<007ooOol0ZWoo
000MOol00`00Oomoo`1COol00`00Oomoo`2ZOol001eoo`03001oogoo05=oo`03001oogoo0:Yoo`00
7Goo00<007ooOol0Dgoo00<007ooOol0ZWoo000MOol00`00Oomoo`1COol00`00Oomoo`2ZOol001eo
o`03001oogoo05=oo`03001oogoo0:Yoo`007Goo00<007ooOol0Dgoo00<007ooOol0ZWoo000MOol0
0`00Oomoo`1COol00`00Oomoo`2ZOol001Eoo`<000Eoo`03001oogoo05=oo`03001oogoo0:Yoo`00
5Woo00<007ooOol017oo00<007ooOol0Dgoo00<007ooOol0ZWoo000FOol00`00Oomoo`04Ool2001D
Ool00`00Oomoo`2ZOol001Ioo`03001oogoo0?moo`Qoo`005Woo00<007ooOol0ogoo27oo000EOol2
003oOol:Ool00?moob5oo`00ogoo8Goo003oOolQOol000ioo`@0029oo`<000=oo`<000Eoo`<000Uo
o`<0009oo`@000Moo`80009oo`80009oo`@0009oo`<000=oo`<0009oo`@000=oo`D00003Ool00000
0080009oo`D000Ioo`<000Aoo`<0009oo`D00004Ool00000Ool20002Ool5001]Ool000moo`03001o
ogoo02=oo`03001oogoo00=oo`03001oogoo00Eoo`03001oogoo00Moo`05001oogooOol00002Ool0
0`00Oomoo`08Ool01000Ool000000Woo00<007ooOol00goo00L007ooOomoo`00Ool00003Ool01000
Oomoo`0017oo00L007ooOomoo`00Ool00005Ool01@00Oomoogoo00001goo00@007ooOol0009oo`07
001oogooOol007oo00000Woo00@007ooOol0009oo`04001oogoo0003Ool00`00Oomoo`1/Ool000=o
o`D00007Ool007oo001oo`00Ool010000Woo1@0000=oo`0000000`000Woo0`000Woo1@000Woo1@00
00=oo`0000000P000goo00<007ooOol01Goo00<007ooOol01goo00D007ooOomoo`00009oo`03001o
ogoo00Qoo`<000=oo`D00003Ool007oo00Aoo`05001oogooOol00002Ool00`00Oomoo`02Ool01P00
Oomoogoo001oo`D00003Ool007oo009oo`03001oogoo00Moo`80009oo`07001oogooOol007oo0000
0Woo00@007ooOol0009oo`04001oogoo0003Ool00`00Oomoo`1/Ool000=oo`04001oogoo0002Ool0
1`00Ool007oo001oo`0000=oo`05001oogooOol00005Ool00`00Oomoo`02Ool01P00Oomoo`00Ool0
009oo`04001oogoo0003Ool01000Ool007oo0`000goo0`000goo00D007oo001oo`0000Moo`05001o
ogooOol00002Ool00`00Oomoo`08Ool01000Oomoo`000Woo00L007ooOomoo`00Ool00003Ool00`00
Ool00003Ool00`00Oomoo`020003Ool01`00Oomoogoo001oo`0000=oo`03001oo`0000=oo`03001o
ogoo00Eoo`8000Aoo`07001oogooOol007oo00000Woo00@007ooOol0009oo`04001oogoo0003Ool0
0`00Oomoo`1/Ool000=oo`@0009oo`07001oo`00Ool007oo00000goo00D007ooOomoo`0000Eoo`03
001oogoo009oo`03001oogoo009oo`04001oogoo0002Ool01P00Oomoogoo001oo`D000=oo`03001o
ogoo00=oo`05001oo`00Ool00008Ool30002Ool40008Ool01000Oomoo`000goo0`000goo10000Woo
0`000Woo0P0000=oo`0000000Woo10000Woo0`000goo10001goo00@007ooOol000=oo`<00004Ool0
0000Ool200000goo000000030003Ool4001^Ool000Ioo`0:001oogoo001oo`00Ool007oo0003Ool0
1@00Oomoogoo00001Goo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`06001oogoo
Ool007oo1P0000=oo`0000000`000Woo1@003Woo00<007ooOol01goo10007goo00<007ooOol02Goo
00<007ooOol01Woo0`0067oo00<007ooOol0K7oo0004Ool300000goo000000090004Ool00`00Oomo
o`02Ool20003Ool4000017oo000007oo0P000goo10000Woo0`007Goo0`00:Goo0P002Woo0P008Woo
0P00KWoo000GOol00`00Oomoo`08Ool00`00Oomoo`0<Ool00`00Oomoo`3/Ool001Eoo`<000Eoo`03
001oogoo009oo`03001oogoo00]oo`800>ioo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {946.587, -0.14072, 0.462505, 
  0.00748348}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-9.5 0.01 0 0.618034 [
[.3 -0.0125 -9 -9 ]
[.3 -0.0125 9 0 ]
[.5 -0.0125 -12 -9 ]
[.5 -0.0125 12 0 ]
[.7 -0.0125 -12 -9 ]
[.7 -0.0125 12 0 ]
[.9 -0.0125 -12 -9 ]
[.9 -0.0125 12 0 ]
[1.025 0 0 -6 ]
[1.025 0 58 6 ]
[.0875 .12361 -18 -4.5 ]
[.0875 .12361 0 4.5 ]
[.0875 .24721 -18 -4.5 ]
[.0875 .24721 0 4.5 ]
[.0875 .37082 -18 -4.5 ]
[.0875 .37082 0 4.5 ]
[.0875 .49443 -18 -4.5 ]
[.0875 .49443 0 4.5 ]
[.0875 .61803 -6 -4.5 ]
[.0875 .61803 0 4.5 ]
[.1 .64303 -29 0 ]
[.1 .64303 29 12 ]
[.5 .63053 -65 0 ]
[.5 .63053 65 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.3 0 m
.3 .00625 L
s
[(980)] .3 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1000)] .5 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(1020)] .7 -0.0125 0 1 Mshowa
.9 0 m
.9 .00625 L
s
[(1040)] .9 -0.0125 0 1 Mshowa
.125 Mabswid
.15 0 m
.15 .00375 L
s
.2 0 m
.2 .00375 L
s
.25 0 m
.25 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.45 0 m
.45 .00375 L
s
.55 0 m
.55 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.75 0 m
.75 .00375 L
s
.8 0 m
.8 .00375 L
s
.85 0 m
.85 .00375 L
s
.05 0 m
.05 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(frequency) show
117.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.1 .12361 m
.10625 .12361 L
s
[(0.2)] .0875 .12361 1 0 Mshowa
.1 .24721 m
.10625 .24721 L
s
[(0.4)] .0875 .24721 1 0 Mshowa
.1 .37082 m
.10625 .37082 L
s
[(0.6)] .0875 .37082 1 0 Mshowa
.1 .49443 m
.10625 .49443 L
s
[(0.8)] .0875 .49443 1 0 Mshowa
.1 .61803 m
.10625 .61803 L
s
[(1)] .0875 .61803 1 0 Mshowa
.125 Mabswid
.1 .0309 m
.10375 .0309 L
s
.1 .0618 m
.10375 .0618 L
s
.1 .09271 m
.10375 .09271 L
s
.1 .15451 m
.10375 .15451 L
s
.1 .18541 m
.10375 .18541 L
s
.1 .21631 m
.10375 .21631 L
s
.1 .27812 m
.10375 .27812 L
s
.1 .30902 m
.10375 .30902 L
s
.1 .33992 m
.10375 .33992 L
s
.1 .40172 m
.10375 .40172 L
s
.1 .43262 m
.10375 .43262 L
s
.1 .46353 m
.10375 .46353 L
s
.1 .52533 m
.10375 .52533 L
s
.1 .55623 m
.10375 .55623 L
s
.1 .58713 m
.10375 .58713 L
s
.25 Mabswid
.1 0 m
.1 .61803 L
s
gsave
.1 .64303 -90 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(amplitude) show
117.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.5 .63053 -126 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(FFT) show
87.000000 13.000000 moveto
(of) show
105.000000 13.000000 moveto
(Recorded) show
159.000000 13.000000 moveto
(Sound) show
189.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .00414 m
.01 .00272 L
.02 .00379 L
.03 .00226 L
.04 .00575 L
.05 .00787 L
.06 .00634 L
.07 .0113 L
.08 .00168 L
.09 .00139 L
.1 .00442 L
.11 .01006 L
.12 .00655 L
.13 .00684 L
.14 .00754 L
.15 .00587 L
.16 .00776 L
.17 .0074 L
.18 .00319 L
.19 .00536 L
.2 .00682 L
.21 .00612 L
.22 .00167 L
.23 .00446 L
.24 .00133 L
.25 .0069 L
.26 .00173 L
.27 .0022 L
.28 .00419 L
.29 .00149 L
.3 .00929 L
.31 .00171 L
.32 .00361 L
.33 .00628 L
.34 .00226 L
.35 .00233 L
.36 .00649 L
.37 .00487 L
.38 .00368 L
.39 .00656 L
.4 .00557 L
.41 .00847 L
.42 .01208 L
.43 .00412 L
.44 .0158 L
.45 .01235 L
.46 .01573 L
.47 .01079 L
.48 .02078 L
.49 .05406 L
Mistroke
.5 .61803 L
.51 .07626 L
.52 .02977 L
.53 .01261 L
.54 .02106 L
.55 .07094 L
.56 .02064 L
.57 .02073 L
.58 .01683 L
.59 .01496 L
.6 .01234 L
.61 .00891 L
.62 .00369 L
.63 .0023 L
.64 .00391 L
.65 .01581 L
.66 .00385 L
.67 .00855 L
.68 .01329 L
.69 .00141 L
.7 .0077 L
.71 .00423 L
.72 .00362 L
.73 .00623 L
.74 .00679 L
.75 .00822 L
.76 .00161 L
.77 .00156 L
.78 .00348 L
.79 .00512 L
.8 .00457 L
.81 .00471 L
.82 .00868 L
.83 .00207 L
.84 .00314 L
.85 .00609 L
.86 .00338 L
.87 .00795 L
.88 .00659 L
.89 .01019 L
.9 .00797 L
.91 .00339 L
.92 .00892 L
.93 .00243 L
.94 .00754 L
.95 .00472 L
.96 .00453 L
.97 .00171 L
.98 .00576 L
.99 .00354 L
Mistroke
1 .00224 L
Mfstroke
1 .00224 m
1 .00224 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
@7oo0`0017oo0P0017oo0P006Goo0`0017oo0P0017oo0P0017oo0P005Woo0`0017oo0P000goo1000
0goo0P005Woo0`0017oo0P0017oo0`000goo0P00CGoo0013Ool01000Oomoo`000Woo00@007ooOol0
009oo`03001oogoo01Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000Woo00@007oo
Ool001Ioo`03001oogoo009oo`04001oogoo0003Ool00`00Oomoo`02Ool01000Oomoo`005Woo00<0
07ooOol00Woo00@007ooOol000Aoo`05001oogooOol00002Ool00`00Oomoo`1:Ool0045oo`<0009o
o`04001oogoo0002Ool01000Oomoo`006Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo
0002Ool01000Oomoo`005Woo00<007ooOol00Woo00@007ooOol000Aoo`05001oogooOol00002Ool0
0`00Oomoo`0DOol00`00Oomoo`02Ool01000Oomoo`000Woo10000Woo00@007ooOol004aoo`00@7oo
00@007ooOol000=oo`8000=oo`04001oogoo000IOol00`00Oomoo`02Ool01000Oomoo`000Woo00@0
07ooOol0009oo`04001oogoo000FOol00`00Oomoo`02Ool01000Oomoo`001Goo00@007ooOol0009o
o`03001oogoo01Aoo`03001oogoo009oo`04001oogoo0002Ool00`00Ool00003Ool01000Oomoo`00
C7oo0010Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo000IOol00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol0009oo`04001oogoo000FOol00`00Oomoo`02Ool01000Oomoo`00
0Woo00@007ooOol0009oo`04001oogoo000FOol00`00Oomoo`02Ool01000Oomoo`000Woo00<007oo
00000goo00@007ooOol004aoo`00@Goo0P0017oo0P0017oo0P006Goo0P001Goo0P0017oo0P0017oo
0P005Woo0P001Goo0P0017oo0P0017oo0P005Woo0P001Goo0P0017oo0P0017oo0P00:Goo10005goo
0`001Woo003nOol00`00Oomoo`0GOol00`00Oomoo`05Ool00>Qoo`@0009oo`@000=oo`@0009oo`@0
0003Ool0000000<0009oo`@00004Ool00000Ool20002Ool30003Ool00`00Oomoo`04Ool00>Uoo`03
001oogoo00=oo`03001oogoo009oo`03001oogoo00=oo`07001oogooOol007oo00000Woo00@007oo
Ool000Eoo`04001oogoo0002Ool01@00Oomoogoo00000Woo00<007ooOol017oo0007OooI0009Ool0
0`00Oomoo`03Ool00`00Oomoo`02Ool500000goo001oo`02Ool00`00Ool00002Ool00`00Oomoo`05
00001Goo001oogoo00000Woo00<007ooOol00goo00<007oo00001Goo0007Ool90002Ool00`00Oomo
o`03Ool60009Ool00`00Oomoo`03Ool30002Ool00`00Oomoo`0I00000goo0000000400000goo0000
00030002Ool00`00Oomoo`04Ool01@00Oomoogoo00002Woo00<007ooOol027oo00<007ooOol027oo
00<007ooOol01P0000Aoo`00Oomoo`8000Aoo`T000Aoo`l00003Ool0000000P000Ioo`03001oo`00
00800005Ool00000001oo`0800000goo000000020009Ool00`00Oomoo`03Ool20003Ool01`00Oomo
ogoo001oo`0000=oo`03001oo`00009oo`04001oogoo0003Ool00`00Ool00002Ool01000Oomoo`00
0goo00D007oo001oo`0000Eoo`0047oo1P0000=oo`00Ool017oo0P0000=oo`0000002`000goo1@00
27oo00<007ooOol027oo00<007ooOol00goo00<007ooOol017oo00<007ooOol00goo1`0000=oo`00
00003Woo00<007ooOol057oo0P001Goo00D007ooOomoo`00009oo`800005Ool007ooOol00006Ool5
000>Ool00`00Oomoo`04Ool01000Oomoogoo100000Aoo`00000000=oo`05001oogooOol00008Ool0
0`00Oomoo`0:Ool40002Ool200000goo00000002Ool30003Ool600000goo00000003Ool300000goo
000000030003Ool600000goo00000004Ool001Ioo`03001oogoo00Aoo`03001oo`00049oo`05001o
ogoo001oo`030002Ool2000;Ool2000=Ool20008Ool00`00Ool00005Ool00`00Oomoo`0ZOol00`00
Oomoo`0OOol00`00Oomoo`0dOol001eoo`03001oogoo04Ioo`04001oogooOol20002Ool00`00Oomo
o`08Ool00`00Ool00007Ool5000;Ool00`00Oomoo`1COol3000dOol001eoo`03001oogoo04moo`03
001oogoo00Ioo`05001oogooOol00003Ool3002MOol001eoo`03001oogoo04moo`03001oogoo00Io
o`05001oogooOol00003Ool00`00Oomoo`2MOol001eoo`03001oogoo04moo`03001oogoo00Eoo`03
001oogoo009oo`05001oogooOol0002OOol001eoo`03001oogoo051oo`03001oogoo00Aoo`03001o
ogoo009oo`05001oogooOol0002OOol001eoo`03001oogoo051oo`03001oogoo00Aoo`03001oogoo
00=oo`03001oo`000:1oo`007Goo00<007ooOol0D7oo00<007ooOol00goo00<007ooOol017oo00<0
07oo0000X7oo000MOol00`00Oomoo`1AOol00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Ool0002P
Ool001eoo`03001oogoo055oo`03001oogoo009oo`03001oogoo00Aoo`03001oo`000:1oo`007Goo
00<007ooOol0DGoo00<007ooOol00Woo00<007ooOol017oo00<007oo0000X7oo000MOol00`00Oomo
o`1AOol00`00Oomoo`02Ool00`00Oomoo`05Ool00`00Oomoo`2OOol001eoo`03001oogoo055oo`05
001oogooOol00008Ool00`00Oomoo`2OOol001eoo`03001oogoo055oo`05001oogooOol00008Ool0
0`00Oomoo`2OOol001eoo`03001oogoo055oo`05001oogooOol0002ZOol001eoo`03001oogoo055o
o`05001oogooOol0002ZOol001eoo`03001oogoo055oo`05001oogooOol0002ZOol001eoo`03001o
ogoo055oo`05001oogooOol0002ZOol001eoo`03001oogoo055oo`05001oogooOol0002ZOol001eo
o`03001oogoo055oo`05001oogooOol0002ZOol001eoo`03001oogoo055oo`05001oogooOol0002Z
Ool001eoo`03001oogoo055oo`05001oogooOol0002ZOol000Yoo`8000Aoo`8000=oo`@000Aoo`03
001oogoo055oo`05001oogooOol0002ZOol000Uoo`04001oogoo0003Ool20004Ool00`00Oomoo`04
Ool00`00Oomoo`1AOol01@00Oomoogoo0000ZWoo0009Ool01000Oomoo`002Woo00<007ooOol00goo
0P00DWoo00D007ooOomoo`000:Yoo`002Goo00@007ooOol000]oo`03001oogoo009oo`03001oogoo
055oo`05001oogooOol0002ZOol000Uoo`04001oogoo0008Ool01000Oomoo`0017oo00<007ooOol0
DGoo00D007ooOomoo`000:Yoo`002Woo0P002Woo0P001Goo00<007ooOol0DGoo00D007ooOomoo`00
0:Yoo`007Goo00<007ooOol0DGoo00D007ooOomoo`000:Yoo`007Goo00<007ooOol0DGoo00D007oo
Oomoo`000:Yoo`007Goo00<007ooOol0DGoo00D007ooOomoo`000:Yoo`007Goo00<007ooOol0DGoo
00D007ooOomoo`000:Yoo`007Goo00<007ooOol0DGoo00D007ooOomoo`000:Yoo`007Goo00<007oo
Ool0DGoo00D007ooOomoo`000:Yoo`007Goo00<007ooOol0DGoo00D007ooOomoo`000:Yoo`007Goo
00<007ooOol0DGoo00D007ooOomoo`000:Yoo`007Goo00<007ooOol0DGoo00D007ooOomoo`000:Yo
o`007Goo00<007ooOol0DGoo00D007ooOomoo`000:Yoo`007Goo00<007ooOol0DGoo00D007ooOomo
o`000:Yoo`007Goo00<007ooOol0DGoo00D007ooOomoo`000:Yoo`007Goo00<007ooOol0DWoo00@0
07ooOol00:Yoo`007Goo00<007ooOol0DWoo00@007ooOol00:Yoo`007Goo00<007ooOol0DWoo00@0
07ooOol00:Yoo`007Goo00<007ooOol0DWoo00@007ooOol00:Yoo`007Goo00<007ooOol0DWoo00<0
07oo0000Zgoo000MOol00`00Oomoo`1BOol00`00Ool0002[Ool001eoo`03001oogoo059oo`03001o
o`000:]oo`007Goo00<007ooOol0DWoo00<007oo0000Zgoo000MOol00`00Oomoo`1BOol00`00Ool0
002[Ool000Yoo`8000Aoo`8000Aoo`<000Aoo`03001oogoo059oo`03001oo`000:]oo`002Goo00@0
07ooOol000=oo`8000Eoo`03001oogoo00=oo`03001oogoo059oo`03001oo`000:]oo`002Goo00@0
07ooOol000Qoo`@000Aoo`8005=oo`03001oo`000:]oo`002Goo00@007ooOol000Qoo`03001oo`00
00Eoo`03001oogoo059oo`03001oo`000:]oo`002Goo00@007ooOol000Qoo`03001oo`0000Eoo`03
001oogoo059oo`03001oo`000:]oo`002Woo0P002Woo0P001Goo00<007ooOol0DWoo00<007oo0000
Zgoo000MOol00`00Oomoo`1BOol00`00Ool0002[Ool001eoo`03001oogoo059oo`03001oo`000:]o
o`007Goo00<007ooOol0DWoo00<007oo0000Zgoo000MOol00`00Oomoo`1BOol00`00Ool0002[Ool0
01eoo`03001oogoo059oo`03001oo`000:]oo`007Goo00<007ooOol0DWoo00<007oo0000Zgoo000M
Ool00`00Oomoo`1BOol00`00Ool0002[Ool001eoo`03001oogoo059oo`03001oo`000:]oo`007Goo
00<007ooOol0DWoo00<007oo0000Zgoo000MOol00`00Oomoo`1BOol00`00Ool0002[Ool001eoo`03
001oogoo059oo`03001oo`000:]oo`007Goo00<007ooOol0DWoo00<007oo0000Zgoo000MOol00`00
Oomoo`1BOol00`00Ool0002[Ool001eoo`03001oogoo059oo`03001oo`000:]oo`007Goo00<007oo
Ool0DWoo00<007oo0000Zgoo000MOol00`00Oomoo`1BOol00`00Ool0002[Ool001eoo`03001oogoo
059oo`03001oo`000:]oo`007Goo00<007ooOol0DWoo00<007oo0000Zgoo000MOol00`00Oomoo`1B
Ool00`00Ool0002[Ool001eoo`03001oogoo059oo`03001oo`000:]oo`007Goo00<007ooOol0DWoo
00<007oo0000Zgoo000:Ool20004Ool20004Ool20005Ool00`00Oomoo`1BOol00`00Ool0002[Ool0
00Uoo`04001oogoo0003Ool20003Ool01000Oomoo`0017oo00<007ooOol0DWoo00<007oo0000Zgoo
0009Ool01000Oomoo`0027oo00@007ooOol000Aoo`8005=oo`03001oo`000:]oo`002Goo00@007oo
Ool000Qoo`<000Eoo`03001oogoo059oo`03001oo`000:]oo`002Goo00@007ooOol000Qoo`03001o
ogoo00Eoo`03001oogoo059oo`03001oo`000:]oo`002Woo0P002Woo0`0017oo00<007ooOol0DWoo
00<007oo0000Zgoo000MOol00`00Oomoo`1BOol00`00Ool0002[Ool001eoo`03001oogoo059oo`03
001oo`000:]oo`007Goo00<007ooOol0DWoo00<007oo0000Zgoo000MOol00`00Oomoo`1BOol00`00
Ool0002[Ool001eoo`03001oogoo059oo`03001oo`000:]oo`007Goo00<007ooOol0DWoo00<007oo
0000Zgoo000MOol00`00Oomoo`1BOol00`00Ool0002[Ool001eoo`03001oogoo059oo`03001oo`00
0:]oo`007Goo00<007ooOol0DWoo00<007oo0000Zgoo000MOol00`00Oomoo`1BOol00`00Ool0002[
Ool001eoo`03001oogoo059oo`03001oo`000:]oo`007Goo00<007ooOol0DWoo00<007oo0000Zgoo
000MOol00`00Oomoo`1BOol00`00Ool0002[Ool001eoo`03001oogoo059oo`03001oo`000:]oo`00
7Goo00<007ooOol0DWoo00<007oo0000Zgoo000MOol00`00Oomoo`1BOol00`00Ool0002[Ool001eo
o`03001oogoo059oo`03001oo`000:]oo`007Goo00<007ooOol0DWoo00<007oo0000Zgoo000MOol0
0`00Oomoo`1BOol00`00Ool0002[Ool001eoo`03001oogoo05=oo`800:]oo`002Woo0P0017oo0P00
17oo0P001Goo00<007ooOol0Dgoo0P00Zgoo0009Ool01000Oomoo`000goo0P000goo00@007ooOol0
00Aoo`03001oogoo05=oo`03001oogoo0:Yoo`002Goo00@007ooOol000Qoo`04001oogoo0004Ool2
001DOol00`00Oomoo`2ZOol000Uoo`04001oogoo0009Ool20005Ool00`00Oomoo`1COol00`00Oomo
o`2ZOol000Uoo`04001oogoo0008Ool01000Oomoo`0017oo00<007ooOol0Dgoo00<007ooOol0ZWoo
000:Ool2000:Ool20005Ool00`00Oomoo`1COol00`00Oomoo`2ZOol001eoo`03001oogoo05=oo`03
001oogoo0:Yoo`007Goo00<007ooOol0Dgoo00<007ooOol0ZWoo000MOol00`00Oomoo`1COol00`00
Oomoo`2ZOol001eoo`03001oogoo05=oo`03001oogoo0:Yoo`007Goo00<007ooOol0Dgoo00<007oo
Ool0ZWoo000MOol00`00Oomoo`1COol00`00Oomoo`2ZOol001eoo`03001oogoo05=oo`03001oogoo
0:Yoo`007Goo00<007ooOol0Dgoo00<007ooOol0ZWoo000MOol00`00Oomoo`1COol00`00Oomoo`2Z
Ool001eoo`03001oogoo05=oo`03001oogoo0:Yoo`007Goo00<007ooOol0Dgoo00<007ooOol0ZWoo
000MOol00`00Oomoo`1COol00`00Oomoo`2ZOol001eoo`03001oogoo05=oo`03001oogoo0:Yoo`00
7Goo00<007ooOol0Dgoo00<007ooOol0ZWoo000MOol00`00Oomoo`1COol00`00Oomoo`2ZOol001eo
o`03001oogoo05=oo`03001oogoo0:Yoo`007Goo00<007ooOol0Dgoo00<007ooOol0ZWoo000MOol0
0`00Oomoo`1COol00`00Oomoo`2ZOol001eoo`03001oogoo05=oo`03001oogoo0:Yoo`007Goo00<0
07ooOol0Dgoo00<007ooOol0ZWoo000MOol00`00Oomoo`1COol00`00Oomoo`2ZOol001Eoo`<000Eo
o`03001oogoo05=oo`03001oogoo0:Yoo`005Woo00<007ooOol017oo00<007ooOol0Dgoo00<007oo
Ool0ZWoo000FOol00`00Oomoo`04Ool2001DOol00`00Oomoo`2ZOol001Ioo`03001oogoo0?moo`Qo
o`005Woo00<007ooOol0ogoo27oo000EOol2003oOol:Ool00?moob5oo`00ogoo8Goo003oOolQOol0
00ioo`@0029oo`<000=oo`<000Eoo`<000Uoo`<0009oo`@000Moo`80009oo`80009oo`@0009oo`<0
00=oo`<0009oo`@000=oo`D00003Ool000000080009oo`D000Ioo`<000Aoo`<0009oo`D00004Ool0
0000Ool20002Ool5001]Ool000moo`03001oogoo02=oo`03001oogoo00=oo`03001oogoo00Eoo`03
001oogoo00Moo`05001oogooOol00002Ool00`00Oomoo`08Ool01000Ool000000Woo00<007ooOol0
0goo00L007ooOomoo`00Ool00003Ool01000Oomoo`0017oo00L007ooOomoo`00Ool00005Ool01@00
Oomoogoo00001goo00@007ooOol0009oo`07001oogooOol007oo00000Woo00@007ooOol0009oo`04
001oogoo0003Ool00`00Oomoo`1/Ool000=oo`D00007Ool007oo001oo`00Ool010000Woo1@0000=o
o`0000000`000Woo0`000Woo1@000Woo1@0000=oo`0000000P000goo00<007ooOol01Goo00<007oo
Ool01goo00D007ooOomoo`00009oo`03001oogoo00Qoo`<000=oo`D00003Ool007oo00Aoo`05001o
ogooOol00002Ool00`00Oomoo`02Ool01P00Oomoogoo001oo`D00003Ool007oo009oo`03001oogoo
00Moo`80009oo`07001oogooOol007oo00000Woo00@007ooOol0009oo`04001oogoo0003Ool00`00
Oomoo`1/Ool000=oo`04001oogoo0002Ool01`00Ool007oo001oo`0000=oo`05001oogooOol00005
Ool00`00Oomoo`02Ool01P00Oomoo`00Ool0009oo`04001oogoo0003Ool01000Ool007oo0`000goo
0`000goo00D007oo001oo`0000Moo`05001oogooOol00002Ool00`00Oomoo`08Ool01000Oomoo`00
0Woo00L007ooOomoo`00Ool00003Ool00`00Ool00003Ool00`00Oomoo`020003Ool01`00Oomoogoo
001oo`0000=oo`03001oo`0000=oo`03001oogoo00Eoo`8000Aoo`07001oogooOol007oo00000Woo
00@007ooOol0009oo`04001oogoo0003Ool00`00Oomoo`1/Ool000=oo`@0009oo`07001oo`00Ool0
07oo00000goo00D007ooOomoo`0000Eoo`03001oogoo009oo`03001oogoo009oo`04001oogoo0002
Ool01P00Oomoogoo001oo`D000=oo`03001oogoo00=oo`05001oo`00Ool00008Ool30002Ool40008
Ool01000Oomoo`000goo0`000goo10000Woo0`000Woo0P0000=oo`0000000Woo10000Woo0`000goo
10001goo00@007ooOol000=oo`<00004Ool00000Ool200000goo000000030003Ool4001^Ool000Io
o`0:001oogoo001oo`00Ool007oo0003Ool01@00Oomoogoo00001Goo00<007ooOol00Woo00<007oo
Ool00Woo00@007ooOol0009oo`06001oogooOol007oo1P0000=oo`0000000`000Woo1@003Woo00<0
07ooOol01goo10007goo00<007ooOol02Goo00<007ooOol01Woo0`0067oo00<007ooOol0K7oo0004
Ool300000goo000000090004Ool00`00Oomoo`02Ool20003Ool4000017oo000007oo0P000goo1000
0Woo0`007Goo0`00:Goo0P002Woo0P008Woo0P00KWoo000GOol00`00Oomoo`08Ool00`00Oomoo`0<
Ool00`00Oomoo`3/Ool001Eoo`<000Eoo`03001oogoo009oo`03001oogoo00]oo`800>ioo`00ogoo
8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol0
0?moob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {946.587, -0.14072, 0.462505, 
  0.00748348}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-9.5 0.01 0 0.618034 [
[.3 -0.0125 -9 -9 ]
[.3 -0.0125 9 0 ]
[.5 -0.0125 -12 -9 ]
[.5 -0.0125 12 0 ]
[.7 -0.0125 -12 -9 ]
[.7 -0.0125 12 0 ]
[.9 -0.0125 -12 -9 ]
[.9 -0.0125 12 0 ]
[1.025 0 0 -6 ]
[1.025 0 58 6 ]
[.0875 .12361 -18 -4.5 ]
[.0875 .12361 0 4.5 ]
[.0875 .24721 -18 -4.5 ]
[.0875 .24721 0 4.5 ]
[.0875 .37082 -18 -4.5 ]
[.0875 .37082 0 4.5 ]
[.0875 .49443 -18 -4.5 ]
[.0875 .49443 0 4.5 ]
[.0875 .61803 -6 -4.5 ]
[.0875 .61803 0 4.5 ]
[.1 .64303 -29 0 ]
[.1 .64303 29 12 ]
[.5 .63053 -65 0 ]
[.5 .63053 65 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.3 0 m
.3 .00625 L
s
[(980)] .3 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1000)] .5 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(1020)] .7 -0.0125 0 1 Mshowa
.9 0 m
.9 .00625 L
s
[(1040)] .9 -0.0125 0 1 Mshowa
.125 Mabswid
.15 0 m
.15 .00375 L
s
.2 0 m
.2 .00375 L
s
.25 0 m
.25 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.45 0 m
.45 .00375 L
s
.55 0 m
.55 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.75 0 m
.75 .00375 L
s
.8 0 m
.8 .00375 L
s
.85 0 m
.85 .00375 L
s
.05 0 m
.05 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(frequency) show
117.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.1 .12361 m
.10625 .12361 L
s
[(0.2)] .0875 .12361 1 0 Mshowa
.1 .24721 m
.10625 .24721 L
s
[(0.4)] .0875 .24721 1 0 Mshowa
.1 .37082 m
.10625 .37082 L
s
[(0.6)] .0875 .37082 1 0 Mshowa
.1 .49443 m
.10625 .49443 L
s
[(0.8)] .0875 .49443 1 0 Mshowa
.1 .61803 m
.10625 .61803 L
s
[(1)] .0875 .61803 1 0 Mshowa
.125 Mabswid
.1 .0309 m
.10375 .0309 L
s
.1 .0618 m
.10375 .0618 L
s
.1 .09271 m
.10375 .09271 L
s
.1 .15451 m
.10375 .15451 L
s
.1 .18541 m
.10375 .18541 L
s
.1 .21631 m
.10375 .21631 L
s
.1 .27812 m
.10375 .27812 L
s
.1 .30902 m
.10375 .30902 L
s
.1 .33992 m
.10375 .33992 L
s
.1 .40172 m
.10375 .40172 L
s
.1 .43262 m
.10375 .43262 L
s
.1 .46353 m
.10375 .46353 L
s
.1 .52533 m
.10375 .52533 L
s
.1 .55623 m
.10375 .55623 L
s
.1 .58713 m
.10375 .58713 L
s
.25 Mabswid
.1 0 m
.1 .61803 L
s
gsave
.1 .64303 -90 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(amplitude) show
117.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.5 .63053 -126 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(FFT) show
87.000000 13.000000 moveto
(of) show
105.000000 13.000000 moveto
(Recorded) show
159.000000 13.000000 moveto
(Sound) show
189.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .00688 m
.01 .00852 L
.02 .00706 L
.03 .00311 L
.04 .01166 L
.05 .00386 L
.06 .00644 L
.07 .00472 L
.08 .00932 L
.09 .01078 L
.1 .00891 L
.11 .007 L
.12 .00849 L
.13 .01005 L
.14 .00804 L
.15 .01346 L
.16 .01507 L
.17 .01646 L
.18 .00462 L
.19 .01063 L
.2 .01497 L
.21 .0089 L
.22 .01359 L
.23 .00741 L
.24 .00605 L
.25 .0168 L
.26 .00607 L
.27 .00461 L
.28 .00799 L
.29 .01069 L
.3 .02052 L
.31 .00552 L
.32 .00903 L
.33 .01349 L
.34 .00199 L
.35 .01364 L
.36 .0166 L
.37 .01137 L
.38 .01532 L
.39 .02003 L
.4 .01106 L
.41 .02417 L
.42 .02081 L
.43 .01181 L
.44 .02209 L
.45 .0093 L
.46 .03687 L
.47 .0562 L
.48 .08383 L
.49 .12581 L
Mistroke
.5 .61803 L
.51 .34288 L
.52 .0818 L
.53 .08538 L
.54 .12502 L
.55 .05293 L
.56 .03301 L
.57 .02605 L
.58 .01418 L
.59 .01903 L
.6 .01905 L
.61 .02442 L
.62 .01177 L
.63 .00778 L
.64 .01139 L
.65 .00286 L
.66 .02129 L
.67 .01677 L
.68 .00637 L
.69 .01464 L
.7 .01204 L
.71 .01371 L
.72 .01392 L
.73 .00181 L
.74 .00578 L
.75 .00598 L
.76 .01137 L
.77 .00581 L
.78 .00801 L
.79 .01476 L
.8 .00822 L
.81 .00893 L
.82 .02055 L
.83 .00576 L
.84 .00341 L
.85 .00443 L
.86 .01225 L
.87 .01443 L
.88 .01457 L
.89 .00707 L
.9 .00389 L
.91 .01374 L
.92 .00439 L
.93 .00896 L
.94 .01894 L
.95 .01526 L
.96 .00913 L
.97 .00557 L
.98 .01389 L
.99 .01193 L
Mistroke
1 .00446 L
Mfstroke
1 .00446 m
1 .00446 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
@7oo0`0017oo0P0017oo0P006Goo0`0017oo0P0017oo0P0017oo0P005Woo0`0017oo0P000goo1000
0goo0P005Woo0`0017oo0P0017oo0`000goo0P00CGoo0013Ool01000Oomoo`000Woo00@007ooOol0
009oo`03001oogoo01Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000Woo00@007oo
Ool001Ioo`03001oogoo009oo`04001oogoo0003Ool00`00Oomoo`02Ool01000Oomoo`005Woo00<0
07ooOol00Woo00@007ooOol000Aoo`05001oogooOol00002Ool00`00Oomoo`1:Ool0045oo`<0009o
o`04001oogoo0002Ool01000Oomoo`006Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo
0002Ool01000Oomoo`005Woo00<007ooOol00Woo00@007ooOol000Aoo`05001oogooOol00002Ool0
0`00Oomoo`0DOol00`00Oomoo`02Ool01000Oomoo`000Woo10000Woo00@007ooOol004aoo`00@7oo
00@007ooOol000=oo`8000=oo`04001oogoo000IOol00`00Oomoo`02Ool01000Oomoo`000Woo00@0
07ooOol0009oo`04001oogoo000FOol00`00Oomoo`02Ool01000Oomoo`001Goo00@007ooOol0009o
o`03001oogoo01Aoo`03001oogoo009oo`04001oogoo0002Ool00`00Ool00003Ool01000Oomoo`00
C7oo0010Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo000IOol00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol0009oo`04001oogoo000FOol00`00Oomoo`02Ool01000Oomoo`00
0Woo00@007ooOol0009oo`04001oogoo000FOol00`00Oomoo`02Ool01000Oomoo`000Woo00<007oo
00000goo00@007ooOol004aoo`00@Goo0P0017oo0P0017oo0P006Goo0P001Goo0P0017oo0P0017oo
0P005Woo0P001Goo0P0017oo0P0017oo0P005Woo0P001Goo0P0017oo0P0017oo0P00:Goo10005goo
0`001Woo003nOol00`00Oomoo`0GOol00`00Oomoo`05Ool00>Qoo`@0009oo`@000=oo`@0009oo`@0
0003Ool0000000<0009oo`@00004Ool00000Ool20002Ool30003Ool00`00Oomoo`04Ool00>Uoo`03
001oogoo00=oo`03001oogoo009oo`03001oogoo00=oo`07001oogooOol007oo00000Woo00@007oo
Ool000Eoo`04001oogoo0002Ool01@00Oomoogoo00000Woo00<007ooOol017oo0007OooI0009Ool0
0`00Oomoo`03Ool00`00Oomoo`02Ool500000goo001oo`02Ool00`00Ool00002Ool00`00Oomoo`05
00001Goo001oogoo00000Woo00<007ooOol00goo00<007oo00001Goo000<Ool30003Ool2000017oo
000000001Goo00<007ooOol01goo00<007ooOol017oo00D007ooOomoo`0000Yoo`03001oogoo00<0
00Eoo`03001oogoo00Eoo`800003Ool007oo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001o
ogoo00Qoo`03001oogoo00Qoo`03001oogoo00Moo`03001oogoo00Qoo`03001oogoo00Aoo`80009o
o`03001oogoo00Qoo`03001oogoo00Eoo`@000Qoo`<000=oo`8000Aoo`03001oogoo00Qoo`03001o
ogoo00Moo`03001oogoo00=oo`8000=oo`07001oogooOol007oo00000goo00<007oo00000Woo00@0
07ooOol000=oo`03001oo`00009oo`04001oogoo0003Ool01@00Ool007oo00001Goo0007Ool50003
Ool00`00Ool00002Ool01000Oomoogoo0P000Woo1`0000Aoo`00000000Moo`8000Aoo`80009oo`@0
00=oo`04001oogooOol30002Ool00`00Ool0000300001Goo001oogoo00005Goo00<007ooOol027oo
00<007ooOol067oo0`0000=oo`0000001Woo00D007ooOomoo`0000Eoo`03001oogoo00@00003Ool0
000000<000=oo`<000=oo`8000Aoo`03001oogoo00Aoo`07001oo`00Ool007oo00000Woo00<007oo
Ool00goo1@000goo00<007ooOol01goo10000Woo0P0000=oo`0000000Woo0`000goo1P0000=oo`00
00000goo0`0000=oo`0000000`000goo1P0000=oo`00000017oo000@Ool00`00Oomoo`07Ool20000
0goo001oo`04Ool01000Oomoogoo0P0017oo00<007ooOol00P0000Aoo`00Oomoo`8000Aoo`03001o
o`0000Moo`05001oogooOol00003Ool00`00Oomoo`02Ool2000017oo0000000017oo00<007ooOol0
17oo00D007ooOomoo`0001]oo`8000Moo`05001oogooOol00002Ool00`00Oomoo`02Ool01000Ool0
07oo1`001goo00<007ooOol00goo00<007oo00000Woo00D007ooOomoo`0000Ioo`@00003Ool007oo
00Aoo`03001oogoo009oo`05001oogooOol00005Ool3000;Ool00`00Oomoo`0dOol001eoo`03001o
ogoo00Uoo`@000Eoo`03001oogoo00Qoo`03001oogoo00Moo`03001oo`0000]oo`04001oogooOol2
000017oo001oo`0017oo00L007oo001oo`00Ool0000JOol00`00Ool000030003Ool00`00Oomoo`05
Ool01000Ool000000goo00<007ooOol04goo00<007ooOol00Woo00<007oo00002goo00<007ooOol0
2Woo0`0057oo0`00=7oo000MOol00`00Oomoo`0XOol00`00Oomoo`0@Ool01P00Oomoogoo001oo`80
00=oo`04001oogoo000IOol00`00Oomoo`04Ool00`00Ool00009Ool00`00Oomoo`0OOol00`00Oomo
o`1UOol001eoo`03001oogoo041oo`03001oogoo00Ioo`03001oogoo01Ioo`03001oogoo00Ioo`03
001oogoo099oo`007Goo00<007ooOol0BWoo00<007ooOol057oo00<007ooOol0W7oo000MOol00`00
Oomoo`1:Ool00`00Oomoo`0COol00`00Oomoo`2MOol001eoo`03001oogoo04Yoo`03001oogoo01=o
o`03001oogoo09eoo`007Goo00<007ooOol0Bgoo00<007ooOol04Goo00<007ooOol0WWoo000MOol0
0`00Oomoo`1<Ool00`00Oomoo`0@Ool00`00Oomoo`2NOol001eoo`03001oogoo04aoo`03001oogoo
00moo`03001oogoo09moo`007Goo00<007ooOol0CGoo00<007ooOol03Woo00<007ooOol0Wgoo000M
Ool00`00Oomoo`1=Ool00`00Oomoo`0>Ool00`00Oomoo`2OOol001eoo`03001oogoo04ioo`03001o
ogoo00eoo`03001oogoo09moo`007Goo00<007ooOol0CWoo00<007ooOol03Goo00<007ooOol0Wgoo
000MOol00`00Oomoo`1>Ool00`00Oomoo`0<Ool00`00Oomoo`2POol001eoo`03001oogoo04moo`03
001oogoo00Eoo`8000Aoo`03001oogoo0:1oo`007Goo00<007ooOol0Cgoo00<007ooOol01Goo00<0
07oo00000goo00<007ooOol0X7oo000MOol00`00Oomoo`1?Ool00`00Oomoo`05Ool00`00Ool00003
Ool00`00Oomoo`2POol001eoo`03001oogoo051oo`03001oogoo00Aoo`04001oogoo0002Ool00`00
Oomoo`2POol001eoo`03001oogoo051oo`03001oogoo00Aoo`04001oogoo0002Ool00`00Oomoo`2P
Ool001eoo`03001oogoo051oo`03001oogoo00Aoo`04001oogoo0002Ool00`00Oomoo`2POol001eo
o`03001oogoo051oo`03001oogoo00Aoo`04001oogooOol2002SOol000Yoo`8000Aoo`8000=oo`@0
00Aoo`03001oogoo051oo`03001oogoo00Aoo`04001oogooOol2002SOol000Uoo`04001oogoo0003
Ool20004Ool00`00Oomoo`04Ool00`00Oomoo`1AOol00`00Oomoo`03Ool01000Oomoogoo0P00Xgoo
0009Ool01000Oomoo`002Woo00<007ooOol00goo0P00DWoo00<007ooOol00goo00<007ooOol00Woo
00<007ooOol0XGoo0009Ool01000Oomoo`002goo00<007ooOol00Woo00<007ooOol0DGoo00<007oo
Ool00goo00<007ooOol0YWoo0009Ool01000Oomoo`0027oo00@007ooOol000Aoo`03001oogoo055o
o`03001oogoo00=oo`03001oogoo0:Ioo`002Woo0P002Woo0P001Goo00<007ooOol0DGoo00<007oo
Ool00goo00<007ooOol0YWoo000MOol00`00Oomoo`1AOol00`00Oomoo`03Ool00`00Oomoo`2VOol0
01eoo`03001oogoo055oo`03001oogoo00=oo`03001oogoo0:Ioo`007Goo00<007ooOol0DGoo00<0
07ooOol00Woo00<007ooOol0Ygoo000MOol00`00Oomoo`1AOol00`00Oomoo`02Ool00`00Oomoo`2W
Ool001eoo`03001oogoo055oo`03001oogoo009oo`03001oogoo0:Moo`007Goo00<007ooOol0DGoo
00<007ooOol00Woo00<007ooOol0Ygoo000MOol00`00Oomoo`1AOol00`00Oomoo`02Ool00`00Oomo
o`2WOol001eoo`03001oogoo055oo`03001oogoo009oo`03001oogoo0:Moo`007Goo00<007ooOol0
DGoo00<007ooOol00Woo00<007ooOol0Ygoo000MOol00`00Oomoo`1AOol00`00Oomoo`02Ool00`00
Oomoo`2WOol001eoo`03001oogoo055oo`03001oogoo009oo`03001oogoo0:Moo`007Goo00<007oo
Ool0DGoo00<007ooOol00Woo00<007ooOol0Ygoo000MOol00`00Oomoo`1AOol00`00Oomoo`02Ool0
0`00Oomoo`2WOol001eoo`03001oogoo055oo`03001oogoo009oo`03001oogoo0:Moo`007Goo00<0
07ooOol0DGoo00<007ooOol00Woo00<007ooOol0Ygoo000MOol00`00Oomoo`1AOol00`00Oomoo`02
Ool00`00Oomoo`2WOol001eoo`03001oogoo055oo`03001oogoo009oo`03001oogoo0:Moo`007Goo
00<007ooOol0DGoo00<007ooOol00Woo00<007ooOol0Ygoo000MOol00`00Oomoo`1AOol00`00Oomo
o`02Ool00`00Oomoo`2WOol001eoo`03001oogoo055oo`03001oogoo009oo`03001oogoo0:Moo`00
7Goo00<007ooOol0DGoo00<007ooOol00Woo00<007ooOol0Ygoo000:Ool20004Ool20004Ool30004
Ool00`00Oomoo`1AOol00`00Oomoo`02Ool00`00Oomoo`2WOol000Uoo`04001oogoo0003Ool20005
Ool00`00Oomoo`03Ool00`00Oomoo`1AOol00`00Oomoo`02Ool00`00Oomoo`2WOol000Uoo`04001o
ogoo0008Ool40004Ool2001BOol00`00Oomoo`02Ool00`00Oomoo`2WOol000Uoo`04001oogoo0008
Ool00`00Ool00005Ool00`00Oomoo`1BOol01@00Oomoogoo0000ZGoo0009Ool01000Oomoo`0027oo
00<007oo00001Goo00<007ooOol0DWoo00D007ooOomoo`000:Uoo`002Woo0P002Woo0P001Goo00<0
07ooOol0DWoo00D007ooOomoo`000:Uoo`007Goo00<007ooOol0DWoo00D007ooOomoo`000:Uoo`00
7Goo00<007ooOol0DWoo00D007ooOomoo`000:Uoo`007Goo00<007ooOol0DWoo00D007ooOomoo`00
0:Uoo`007Goo00<007ooOol0DWoo00D007ooOomoo`000:Uoo`007Goo00<007ooOol0DWoo00@007oo
Ool00:Yoo`007Goo00<007ooOol0DWoo00@007ooOol00:Yoo`007Goo00<007ooOol0DWoo00@007oo
Ool00:Yoo`007Goo00<007ooOol0DWoo00@007ooOol00:Yoo`007Goo00<007ooOol0DWoo00@007oo
Ool00:Yoo`007Goo00<007ooOol0DWoo00@007ooOol00:Yoo`007Goo00<007ooOol0DWoo00@007oo
Ool00:Yoo`007Goo00<007ooOol0DWoo00@007ooOol00:Yoo`007Goo00<007ooOol0DWoo00@007oo
Ool00:Yoo`007Goo00<007ooOol0DWoo00@007ooOol00:Yoo`007Goo00<007ooOol0DWoo00@007oo
Ool00:Yoo`007Goo00<007ooOol0DWoo00@007ooOol00:Yoo`007Goo00<007ooOol0DWoo00@007oo
Ool00:Yoo`007Goo00<007ooOol0DWoo00@007ooOol00:Yoo`007Goo00<007ooOol0DWoo00@007oo
Ool00:Yoo`007Goo00<007ooOol0DWoo00@007ooOol00:Yoo`007Goo00<007ooOol0DWoo00@007oo
Ool00:Yoo`002Woo0P0017oo0P0017oo0P001Goo00<007ooOol0DWoo00@007ooOol00:Yoo`002Goo
00@007ooOol000=oo`8000=oo`04001oogoo0004Ool00`00Oomoo`1BOol01000Oomoo`00ZWoo0009
Ool01000Oomoo`0027oo00@007ooOol000Aoo`8005=oo`04001oogoo002ZOol000Uoo`04001oogoo
0008Ool30005Ool00`00Oomoo`1BOol01000Oomoo`00ZWoo0009Ool01000Oomoo`0027oo00<007oo
Ool01Goo00<007ooOol0DWoo00@007ooOol00:Yoo`002Woo0P002Woo0`0017oo00<007ooOol0DWoo
00@007ooOol00:Yoo`007Goo00<007ooOol0DWoo00@007ooOol00:Yoo`007Goo00<007ooOol0DWoo
00@007ooOol00:Yoo`007Goo00<007ooOol0DWoo00@007ooOol00:Yoo`007Goo00<007ooOol0DWoo
00@007ooOol00:Yoo`007Goo00<007ooOol0DWoo00@007ooOol00:Yoo`007Goo00<007ooOol0DWoo
00@007ooOol00:Yoo`007Goo00<007ooOol0DWoo00<007oo0000Zgoo000MOol00`00Oomoo`1BOol0
0`00Ool0002[Ool001eoo`03001oogoo059oo`03001oo`000:]oo`007Goo00<007ooOol0DWoo00<0
07oo0000Zgoo000MOol00`00Oomoo`1BOol00`00Ool0002[Ool001eoo`03001oogoo059oo`03001o
o`000:]oo`007Goo00<007ooOol0DWoo00<007oo0000Zgoo000MOol00`00Oomoo`1BOol00`00Ool0
002[Ool001eoo`03001oogoo059oo`03001oo`000:]oo`007Goo00<007ooOol0DWoo00<007oo0000
Zgoo000MOol00`00Oomoo`1BOol00`00Ool0002[Ool001eoo`03001oogoo059oo`03001oo`000:]o
o`007Goo00<007ooOol0DWoo00<007oo0000Zgoo000MOol00`00Oomoo`1BOol00`00Ool0002[Ool0
00Yoo`8000Aoo`8000Aoo`8000Eoo`03001oogoo059oo`03001oo`000:]oo`002Goo00@007ooOol0
00=oo`8000=oo`04001oogoo0004Ool00`00Oomoo`1BOol00`00Ool0002[Ool000Uoo`04001oogoo
0008Ool01000Oomoo`0017oo0P00Dgoo00<007oo0000Zgoo0009Ool01000Oomoo`002Goo0P001Goo
00<007ooOol0Dgoo0P00Zgoo0009Ool01000Oomoo`0027oo00@007ooOol000Aoo`03001oogoo05=o
o`800:]oo`002Woo0P002Woo0P001Goo00<007ooOol0Dgoo0P00Zgoo000MOol00`00Oomoo`1COol2
002[Ool001eoo`03001oogoo05=oo`800:]oo`007Goo00<007ooOol0Dgoo0P00Zgoo000MOol00`00
Oomoo`1COol2002[Ool001eoo`03001oogoo05=oo`800:]oo`007Goo00<007ooOol0Dgoo0P00Zgoo
000MOol00`00Oomoo`1COol2002[Ool001eoo`03001oogoo05=oo`800:]oo`007Goo00<007ooOol0
Dgoo0P00Zgoo000MOol00`00Oomoo`1COol00`00Oomoo`2ZOol001eoo`03001oogoo05=oo`03001o
ogoo0:Yoo`007Goo00<007ooOol0Dgoo00<007ooOol0ZWoo000MOol00`00Oomoo`1COol00`00Oomo
o`2ZOol001eoo`03001oogoo05=oo`03001oogoo0:Yoo`007Goo00<007ooOol0Dgoo00<007ooOol0
ZWoo000MOol00`00Oomoo`1COol00`00Oomoo`2ZOol001eoo`03001oogoo05=oo`03001oogoo0:Yo
o`007Goo00<007ooOol0Dgoo00<007ooOol0ZWoo000MOol00`00Oomoo`1COol00`00Oomoo`2ZOol0
01eoo`03001oogoo05=oo`03001oogoo0:Yoo`007Goo00<007ooOol0Dgoo00<007ooOol0ZWoo000E
Ool30005Ool00`00Oomoo`1COol00`00Oomoo`2ZOol001Ioo`03001oogoo00Aoo`03001oogoo05=o
o`03001oogoo0:Yoo`005Woo00<007ooOol017oo0P00E7oo00<007ooOol0ZWoo000FOol00`00Oomo
o`3oOol8Ool001Ioo`03001oogoo0?moo`Qoo`005Goo0P00ogoo2Woo003oOolQOol00?moob5oo`00
ogoo8Goo000>Ool4000ROol30003Ool30005Ool30009Ool30002Ool40007Ool20002Ool20002Ool4
0002Ool30003Ool30002Ool40003Ool500000goo000000020002Ool50006Ool30004Ool30002Ool5
000017oo000007oo0P000Woo1@00KGoo000?Ool00`00Oomoo`0SOol00`00Oomoo`03Ool00`00Oomo
o`05Ool00`00Oomoo`07Ool01@00Oomoogoo00000Woo00<007ooOol027oo00@007oo0000009oo`03
001oogoo00=oo`07001oogooOol007oo00000goo00@007ooOol000Aoo`07001oogooOol007oo0000
1Goo00D007ooOomoo`0000Moo`04001oogoo0002Ool01`00Oomoogoo001oo`00009oo`04001oogoo
0002Ool01000Oomoo`000goo00<007ooOol0K7oo0003Ool500001goo001oo`00Ool007oo00@0009o
o`D00003Ool0000000<0009oo`<0009oo`D0009oo`D00003Ool00000008000=oo`03001oogoo00Eo
o`03001oogoo00Moo`05001oogooOol00002Ool00`00Oomoo`08Ool30003Ool500000goo001oo`04
Ool01@00Oomoogoo00000Woo00<007ooOol00Woo00H007ooOomoo`00Ool500000goo001oo`02Ool0
0`00Oomoo`07Ool20002Ool01`00Oomoogoo001oo`00009oo`04001oogoo0002Ool01000Oomoo`00
0goo00<007ooOol0K7oo0003Ool01000Oomoo`000Woo00L007oo001oo`00Ool00003Ool01@00Oomo
ogoo00001Goo00<007ooOol00Woo00H007ooOol007oo0002Ool01000Oomoo`000goo00@007oo001o
o`<000=oo`<000=oo`05001oo`00Ool00007Ool01@00Oomoogoo00000Woo00<007ooOol027oo00@0
07ooOol0009oo`07001oogooOol007oo00000goo00<007oo00000goo00<007ooOol00P000goo00L0
07ooOomoo`00Ool00003Ool00`00Ool00003Ool00`00Oomoo`05Ool20004Ool01`00Oomoogoo001o
o`00009oo`04001oogoo0002Ool01000Oomoo`000goo00<007ooOol0K7oo0003Ool40002Ool01`00
Ool007oo001oo`0000=oo`05001oogooOol00005Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01000
Oomoo`000Woo00H007ooOomoo`00Ool50003Ool00`00Oomoo`03Ool01@00Ool007oo000027oo0`00
0Woo100027oo00@007ooOol000=oo`<000=oo`@0009oo`<0009oo`800003Ool00000009oo`@0009o
o`<000=oo`@000Moo`04001oogoo0003Ool3000017oo000007oo0P0000=oo`0000000`000goo1000
KWoo0006Ool02P00Oomoo`00Ool007oo001oo`000goo00D007ooOomoo`0000Eoo`03001oogoo009o
o`03001oogoo009oo`04001oogoo0002Ool01P00Oomoogoo001oo`H00003Ool0000000<0009oo`D0
00ioo`03001oogoo00Moo`@001moo`03001oogoo00Uoo`03001oogoo00Ioo`<001Qoo`03001oogoo
06aoo`0017oo0`0000=oo`0000002@0017oo00<007ooOol00Woo0P000goo100000Aoo`00001oo`80
00=oo`@0009oo`<001eoo`<002Uoo`8000Yoo`80029oo`8006ioo`005goo00<007ooOol027oo00<0
07ooOol037oo00<007ooOol0k7oo000EOol30005Ool00`00Oomoo`02Ool00`00Oomoo`0;Ool2003^
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {946.587, -0.14072, 0.462505, 
  0.00748348}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-9.5 0.01 0 0.618034 [
[.3 -0.0125 -9 -9 ]
[.3 -0.0125 9 0 ]
[.5 -0.0125 -12 -9 ]
[.5 -0.0125 12 0 ]
[.7 -0.0125 -12 -9 ]
[.7 -0.0125 12 0 ]
[.9 -0.0125 -12 -9 ]
[.9 -0.0125 12 0 ]
[1.025 0 0 -6 ]
[1.025 0 58 6 ]
[.0875 .12361 -18 -4.5 ]
[.0875 .12361 0 4.5 ]
[.0875 .24721 -18 -4.5 ]
[.0875 .24721 0 4.5 ]
[.0875 .37082 -18 -4.5 ]
[.0875 .37082 0 4.5 ]
[.0875 .49443 -18 -4.5 ]
[.0875 .49443 0 4.5 ]
[.0875 .61803 -6 -4.5 ]
[.0875 .61803 0 4.5 ]
[.1 .64303 -29 0 ]
[.1 .64303 29 12 ]
[.5 .63053 -65 0 ]
[.5 .63053 65 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.3 0 m
.3 .00625 L
s
[(980)] .3 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1000)] .5 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(1020)] .7 -0.0125 0 1 Mshowa
.9 0 m
.9 .00625 L
s
[(1040)] .9 -0.0125 0 1 Mshowa
.125 Mabswid
.15 0 m
.15 .00375 L
s
.2 0 m
.2 .00375 L
s
.25 0 m
.25 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.45 0 m
.45 .00375 L
s
.55 0 m
.55 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.75 0 m
.75 .00375 L
s
.8 0 m
.8 .00375 L
s
.85 0 m
.85 .00375 L
s
.05 0 m
.05 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(frequency) show
117.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.1 .12361 m
.10625 .12361 L
s
[(0.2)] .0875 .12361 1 0 Mshowa
.1 .24721 m
.10625 .24721 L
s
[(0.4)] .0875 .24721 1 0 Mshowa
.1 .37082 m
.10625 .37082 L
s
[(0.6)] .0875 .37082 1 0 Mshowa
.1 .49443 m
.10625 .49443 L
s
[(0.8)] .0875 .49443 1 0 Mshowa
.1 .61803 m
.10625 .61803 L
s
[(1)] .0875 .61803 1 0 Mshowa
.125 Mabswid
.1 .0309 m
.10375 .0309 L
s
.1 .0618 m
.10375 .0618 L
s
.1 .09271 m
.10375 .09271 L
s
.1 .15451 m
.10375 .15451 L
s
.1 .18541 m
.10375 .18541 L
s
.1 .21631 m
.10375 .21631 L
s
.1 .27812 m
.10375 .27812 L
s
.1 .30902 m
.10375 .30902 L
s
.1 .33992 m
.10375 .33992 L
s
.1 .40172 m
.10375 .40172 L
s
.1 .43262 m
.10375 .43262 L
s
.1 .46353 m
.10375 .46353 L
s
.1 .52533 m
.10375 .52533 L
s
.1 .55623 m
.10375 .55623 L
s
.1 .58713 m
.10375 .58713 L
s
.25 Mabswid
.1 0 m
.1 .61803 L
s
gsave
.1 .64303 -90 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(amplitude) show
117.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.5 .63053 -126 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(FFT) show
87.000000 13.000000 moveto
(of) show
105.000000 13.000000 moveto
(Recorded) show
159.000000 13.000000 moveto
(Sound) show
189.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .00531 m
.01 .00232 L
.02 .00312 L
.03 .0005 L
.04 .00362 L
.05 .00263 L
.06 .00109 L
.07 .0077 L
.08 .00394 L
.09 .00337 L
.1 .00758 L
.11 .00395 L
.12 .00674 L
.13 .00388 L
.14 .00615 L
.15 .00334 L
.16 .00686 L
.17 .00466 L
.18 .00162 L
.19 .00315 L
.2 .00331 L
.21 .00146 L
.22 .00592 L
.23 .00399 L
.24 .00485 L
.25 .00154 L
.26 .00548 L
.27 .00404 L
.28 .00741 L
.29 .0072 L
.3 .0066 L
.31 .00159 L
.32 .0041 L
.33 .00514 L
.34 .00675 L
.35 .00598 L
.36 .006 L
.37 .00799 L
.38 .00562 L
.39 .00481 L
.4 .01039 L
.41 .0121 L
.42 .00963 L
.43 .00888 L
.44 .00953 L
.45 .01748 L
.46 .01968 L
.47 .02452 L
.48 .03656 L
.49 .06292 L
Mistroke
.5 .61803 L
.51 .16718 L
.52 .03212 L
.53 .0277 L
.54 .04293 L
.55 .01299 L
.56 .01379 L
.57 .01452 L
.58 .00926 L
.59 .01106 L
.6 .00902 L
.61 .00459 L
.62 .00774 L
.63 .00697 L
.64 .00555 L
.65 .00532 L
.66 .00673 L
.67 .00694 L
.68 .0053 L
.69 .00371 L
.7 .00571 L
.71 .00653 L
.72 .00289 L
.73 .00395 L
.74 .00422 L
.75 .00537 L
.76 .00441 L
.77 .004 L
.78 .00219 L
.79 .00246 L
.8 .00574 L
.81 .0069 L
.82 .00709 L
.83 .00386 L
.84 .00576 L
.85 .00091 L
.86 .00257 L
.87 .00236 L
.88 .00437 L
.89 .00561 L
.9 .00489 L
.91 .00473 L
.92 .00171 L
.93 .00429 L
.94 .00522 L
.95 .005 L
.96 .00617 L
.97 .00239 L
.98 .00546 L
.99 .00659 L
Mistroke
1 .00242 L
Mfstroke
1 .00242 m
1 .00242 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
@7oo0`0017oo0P0017oo0P006Goo0`0017oo0P0017oo0P0017oo0P005Woo0`0017oo0P000goo1000
0goo0P005Woo0`0017oo0P0017oo0`000goo0P00CGoo0013Ool01000Oomoo`000Woo00@007ooOol0
009oo`03001oogoo01Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000Woo00@007oo
Ool001Ioo`03001oogoo009oo`04001oogoo0003Ool00`00Oomoo`02Ool01000Oomoo`005Woo00<0
07ooOol00Woo00@007ooOol000Aoo`05001oogooOol00002Ool00`00Oomoo`1:Ool0045oo`<0009o
o`04001oogoo0002Ool01000Oomoo`006Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo
0002Ool01000Oomoo`005Woo00<007ooOol00Woo00@007ooOol000Aoo`05001oogooOol00002Ool0
0`00Oomoo`0DOol00`00Oomoo`02Ool01000Oomoo`000Woo10000Woo00@007ooOol004aoo`00@7oo
00@007ooOol000=oo`8000=oo`04001oogoo000IOol00`00Oomoo`02Ool01000Oomoo`000Woo00@0
07ooOol0009oo`04001oogoo000FOol00`00Oomoo`02Ool01000Oomoo`001Goo00@007ooOol0009o
o`03001oogoo01Aoo`03001oogoo009oo`04001oogoo0002Ool00`00Ool00003Ool01000Oomoo`00
C7oo0010Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo000IOol00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol0009oo`04001oogoo000FOol00`00Oomoo`02Ool01000Oomoo`00
0Woo00@007ooOol0009oo`04001oogoo000FOol00`00Oomoo`02Ool01000Oomoo`000Woo00<007oo
00000goo00@007ooOol004aoo`00@Goo0P0017oo0P0017oo0P006Goo0P001Goo0P0017oo0P0017oo
0P005Woo0P001Goo0P0017oo0P0017oo0P005Woo0P001Goo0P0017oo0P0017oo0P00:Goo10005goo
0`001Woo003nOol00`00Oomoo`0GOol00`00Oomoo`05Ool00>Qoo`@0009oo`@000=oo`@0009oo`@0
0003Ool0000000<0009oo`@00004Ool00000Ool20002Ool30003Ool00`00Oomoo`04Ool00>Uoo`03
001oogoo00=oo`03001oogoo009oo`03001oogoo00=oo`07001oogooOol007oo00000Woo00@007oo
Ool000Eoo`04001oogoo0002Ool01@00Oomoogoo00000Woo00<007ooOol017oo0007OooI0009Ool0
0`00Oomoo`03Ool00`00Oomoo`02Ool500000goo001oo`02Ool00`00Ool00002Ool00`00Oomoo`05
00001Goo001oogoo00000Woo00<007ooOol00goo00<007oo00001Goo0008Ool40004Ool600000goo
0000000800001Goo00000000Ool00`000Woo2`000Woo1`0000Aoo`00000000Eoo`P000=oo`03001o
ogoo00Aoo`800003Ool007oo00Uoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`@0
00Ioo`03001oogoo00Eoo`@000=ooa<000Aoo`@00003Ool0000000L00003Ool0000000`0009oo`<0
00=oo`8000Uoo`03001oogoo00=oo`8000=oo`07001oogooOol007oo00000goo00<007oo00000Woo
00@007ooOol000=oo`03001oo`00009oo`04001oogoo0003Ool01@00Ool007oo00001Goo0007Ool0
0`00Oomoo`0<Ool00`00Oomoo`04Ool01@00Oomoogoo00000goo00@007ooOomoo`8000]oo`8000Mo
o`04001oogooOol60007Ool:0002Ool00`00Oomoo`02Ool6000<Ool00`00Oomoo`0>Ool20002Ool2
0003Ool>0003Ool40007Ool00`00Oomoo`08Ool50004Ool00`00Oomoo`07Ool00`00Ool0000<Ool2
0003Ool3000:Ool40002Ool200000goo00000002Ool30003Ool600000goo00000003Ool300000goo
000000030003Ool600000goo00000004Ool001eoo`03001oogoo03eoo`@000Ioo`03001oogoo01Ao
o`@00004Ool007ooOol2001QOol00`00Oomoo`0dOol001eoo`03001oogoo04Qoo`8001Aoo`05001o
ogooOol0001VOol3000dOol001eoo`03001oogoo04Yoo`<0015oo`03001oogoo09moo`007Goo00<0
07ooOol0CGoo00<007ooOol027oo0P000goo00<007ooOol0X7oo000MOol00`00Oomoo`1>Ool00`00
Oomoo`06Ool00`00Ool00003Ool00`00Oomoo`2POol001eoo`03001oogoo04moo`03001oogoo00Eo
o`04001oogoo0002Ool00`00Oomoo`2POol001eoo`03001oogoo04moo`03001oogoo00Eoo`04001o
ogooOol2002SOol001eoo`03001oogoo051oo`03001oogoo00Aoo`03001oogoo009oo`03001oogoo
0:5oo`007Goo00<007ooOol0D7oo00<007ooOol017oo00<007ooOol0YWoo000MOol00`00Oomoo`1@
Ool00`00Oomoo`04Ool00`00Oomoo`2VOol001eoo`03001oogoo055oo`03001oogoo00=oo`03001o
ogoo0:Ioo`007Goo00<007ooOol0DGoo00<007ooOol00goo00<007ooOol0YWoo000MOol00`00Oomo
o`1AOol00`00Oomoo`02Ool00`00Oomoo`2WOol001eoo`03001oogoo055oo`03001oogoo009oo`03
001oogoo0:Moo`007Goo00<007ooOol0DGoo00<007ooOol00Woo00<007ooOol0Ygoo000MOol00`00
Oomoo`1AOol00`00Oomoo`02Ool00`00Oomoo`2WOol001eoo`03001oogoo055oo`03001oogoo009o
o`03001oogoo0:Moo`007Goo00<007ooOol0DGoo00<007ooOol00Woo00<007ooOol0Ygoo000MOol0
0`00Oomoo`1AOol00`00Oomoo`02Ool00`00Oomoo`2WOol001eoo`03001oogoo055oo`03001oogoo
009oo`03001oogoo0:Moo`007Goo00<007ooOol0DGoo00<007ooOol00Woo00<007ooOol0Ygoo000M
Ool00`00Oomoo`1AOol00`00Oomoo`02Ool00`00Oomoo`2WOol000Yoo`8000Aoo`8000=oo`@000Ao
o`03001oogoo055oo`03001oogoo009oo`03001oogoo0:Moo`002Goo00@007ooOol000=oo`8000Ao
o`03001oogoo00Aoo`03001oogoo055oo`03001oogoo009oo`03001oogoo0:Moo`002Goo00@007oo
Ool000Yoo`03001oogoo00=oo`80059oo`03001oogoo009oo`03001oogoo0:Moo`002Goo00@007oo
Ool000]oo`03001oogoo009oo`03001oogoo055oo`03001oogoo009oo`03001oogoo0:Moo`002Goo
00@007ooOol000Qoo`04001oogoo0004Ool00`00Oomoo`1AOol00`00Oomoo`02Ool00`00Oomoo`2W
Ool000Yoo`8000Yoo`8000Eoo`03001oogoo055oo`05001oogooOol0002ZOol001eoo`03001oogoo
055oo`05001oogooOol0002ZOol001eoo`03001oogoo055oo`05001oogooOol0002ZOol001eoo`03
001oogoo055oo`05001oogooOol0002ZOol001eoo`03001oogoo055oo`05001oogooOol0002ZOol0
01eoo`03001oogoo055oo`05001oogooOol0002ZOol001eoo`03001oogoo055oo`05001oogooOol0
002ZOol001eoo`03001oogoo055oo`05001oogooOol0002ZOol001eoo`03001oogoo055oo`05001o
ogooOol0002ZOol001eoo`03001oogoo055oo`05001oogooOol0002ZOol001eoo`03001oogoo055o
o`05001oogooOol0002ZOol001eoo`03001oogoo055oo`05001oogooOol0002ZOol001eoo`03001o
ogoo055oo`05001oogooOol0002ZOol001eoo`03001oogoo055oo`05001oogooOol0002ZOol001eo
o`03001oogoo055oo`05001oogooOol0002ZOol001eoo`03001oogoo059oo`04001oogoo002ZOol0
01eoo`03001oogoo059oo`04001oogoo002ZOol001eoo`03001oogoo059oo`04001oogoo002ZOol0
01eoo`03001oogoo059oo`04001oogoo002ZOol001eoo`03001oogoo059oo`04001oogoo002ZOol0
01eoo`03001oogoo059oo`04001oogoo002ZOol001eoo`03001oogoo059oo`04001oogoo002ZOol0
00Yoo`8000Aoo`8000Aoo`<000Aoo`03001oogoo059oo`04001oogoo002ZOol000Uoo`04001oogoo
0003Ool20005Ool00`00Oomoo`03Ool00`00Oomoo`1BOol01000Oomoo`00ZWoo0009Ool01000Oomo
o`0027oo100017oo0P00Dgoo00@007ooOol00:Yoo`002Goo00@007ooOol000Qoo`03001oo`0000Eo
o`03001oogoo059oo`04001oogoo002ZOol000Uoo`04001oogoo0008Ool00`00Ool00005Ool00`00
Oomoo`1BOol01000Oomoo`00ZWoo000:Ool2000:Ool20005Ool00`00Oomoo`1BOol01000Oomoo`00
ZWoo000MOol00`00Oomoo`1BOol01000Oomoo`00ZWoo000MOol00`00Oomoo`1BOol01000Oomoo`00
ZWoo000MOol00`00Oomoo`1BOol01000Oomoo`00ZWoo000MOol00`00Oomoo`1BOol01000Oomoo`00
ZWoo000MOol00`00Oomoo`1BOol00`00Ool0002[Ool001eoo`03001oogoo059oo`03001oo`000:]o
o`007Goo00<007ooOol0DWoo00<007oo0000Zgoo000MOol00`00Oomoo`1BOol00`00Ool0002[Ool0
01eoo`03001oogoo059oo`03001oo`000:]oo`007Goo00<007ooOol0DWoo00<007oo0000Zgoo000M
Ool00`00Oomoo`1BOol00`00Ool0002[Ool001eoo`03001oogoo059oo`03001oo`000:]oo`007Goo
00<007ooOol0DWoo00<007oo0000Zgoo000MOol00`00Oomoo`1BOol00`00Ool0002[Ool001eoo`03
001oogoo059oo`03001oo`000:]oo`007Goo00<007ooOol0DWoo00<007oo0000Zgoo000MOol00`00
Oomoo`1BOol00`00Ool0002[Ool001eoo`03001oogoo059oo`03001oo`000:]oo`007Goo00<007oo
Ool0DWoo00<007oo0000Zgoo000MOol00`00Oomoo`1BOol00`00Ool0002[Ool001eoo`03001oogoo
059oo`03001oo`000:]oo`002Woo0P0017oo0P0017oo0P001Goo00<007ooOol0DWoo00<007oo0000
Zgoo0009Ool01000Oomoo`000goo0P000goo00@007ooOol000Aoo`03001oogoo059oo`03001oo`00
0:]oo`002Goo00@007ooOol000Qoo`04001oogoo0004Ool2001COol00`00Ool0002[Ool000Uoo`04
001oogoo0008Ool30005Ool00`00Oomoo`1BOol00`00Ool0002[Ool000Uoo`04001oogoo0008Ool0
0`00Oomoo`05Ool00`00Oomoo`1BOol00`00Ool0002[Ool000Yoo`8000Yoo`<000Aoo`03001oogoo
059oo`03001oo`000:]oo`007Goo00<007ooOol0DWoo00<007oo0000Zgoo000MOol00`00Oomoo`1B
Ool00`00Ool0002[Ool001eoo`03001oogoo059oo`03001oo`000:]oo`007Goo00<007ooOol0DWoo
00<007oo0000Zgoo000MOol00`00Oomoo`1BOol00`00Ool0002[Ool001eoo`03001oogoo059oo`03
001oo`000:]oo`007Goo00<007ooOol0DWoo00<007oo0000Zgoo000MOol00`00Oomoo`1BOol00`00
Ool0002[Ool001eoo`03001oogoo059oo`03001oo`000:]oo`007Goo00<007ooOol0DWoo00<007oo
0000Zgoo000MOol00`00Oomoo`1BOol00`00Ool0002[Ool001eoo`03001oogoo059oo`03001oo`00
0:]oo`007Goo00<007ooOol0DWoo00<007oo0000Zgoo000MOol00`00Oomoo`1BOol00`00Ool0002[
Ool001eoo`03001oogoo059oo`03001oo`000:]oo`007Goo00<007ooOol0DWoo00<007oo0000Zgoo
000MOol00`00Oomoo`1BOol00`00Ool0002[Ool001eoo`03001oogoo059oo`03001oo`000:]oo`00
7Goo00<007ooOol0DWoo00<007oo0000Zgoo000MOol00`00Oomoo`1BOol00`00Ool0002[Ool000Yo
o`8000Aoo`8000Aoo`8000Eoo`03001oogoo05=oo`800:]oo`002Goo00@007ooOol000=oo`8000=o
o`04001oogoo0004Ool00`00Oomoo`1COol2002[Ool000Uoo`04001oogoo0008Ool01000Oomoo`00
17oo0P00E7oo0P00Zgoo0009Ool01000Oomoo`002Goo0P001Goo00<007ooOol0Dgoo0P00Zgoo0009
Ool01000Oomoo`0027oo00@007ooOol000Aoo`03001oogoo05=oo`800:]oo`002Woo0P002Woo0P00
1Goo00<007ooOol0Dgoo0P00Zgoo000MOol00`00Oomoo`1COol00`00Oomoo`2ZOol001eoo`03001o
ogoo05=oo`03001oogoo0:Yoo`007Goo00<007ooOol0Dgoo00<007ooOol0ZWoo000MOol00`00Oomo
o`1COol00`00Oomoo`2ZOol001eoo`03001oogoo05=oo`03001oogoo0:Yoo`007Goo00<007ooOol0
Dgoo00<007ooOol0ZWoo000MOol00`00Oomoo`1COol00`00Oomoo`2ZOol001eoo`03001oogoo05=o
o`03001oogoo0:Yoo`007Goo00<007ooOol0Dgoo00<007ooOol0ZWoo000MOol00`00Oomoo`1COol0
0`00Oomoo`2ZOol001eoo`03001oogoo05=oo`03001oogoo0:Yoo`007Goo00<007ooOol0Dgoo00<0
07ooOol0ZWoo000MOol00`00Oomoo`1COol00`00Oomoo`2ZOol001eoo`03001oogoo05=oo`03001o
ogoo0:Yoo`007Goo00<007ooOol0Dgoo00<007ooOol0ZWoo000MOol00`00Oomoo`1COol00`00Oomo
o`2ZOol001eoo`03001oogoo05=oo`03001oogoo0:Yoo`007Goo00<007ooOol0Dgoo00<007ooOol0
ZWoo000MOol00`00Oomoo`1COol00`00Oomoo`2ZOol001eoo`03001oogoo05=oo`03001oogoo0:Yo
o`007Goo00<007ooOol0Dgoo00<007ooOol0ZWoo000EOol30005Ool00`00Oomoo`1COol00`00Oomo
o`2ZOol001Ioo`03001oogoo00Aoo`03001oogoo05=oo`03001oogoo0:Yoo`005Woo00<007ooOol0
17oo0P00E7oo00<007ooOol0ZWoo000FOol00`00Oomoo`3oOol8Ool001Ioo`03001oogoo0?moo`Qo
o`005Goo0P00ogoo2Woo003oOolQOol00?moob5oo`00ogoo8Goo000>Ool4000ROol30003Ool30005
Ool30009Ool30002Ool40007Ool20002Ool20002Ool40002Ool30003Ool30002Ool40003Ool50000
0goo000000020002Ool50006Ool30004Ool30002Ool5000017oo000007oo0P000Woo1@00KGoo000?
Ool00`00Oomoo`0SOol00`00Oomoo`03Ool00`00Oomoo`05Ool00`00Oomoo`07Ool01@00Oomoogoo
00000Woo00<007ooOol027oo00@007oo0000009oo`03001oogoo00=oo`07001oogooOol007oo0000
0goo00@007ooOol000Aoo`07001oogooOol007oo00001Goo00D007ooOomoo`0000Moo`04001oogoo
0002Ool01`00Oomoogoo001oo`00009oo`04001oogoo0002Ool01000Oomoo`000goo00<007ooOol0
K7oo0003Ool500001goo001oo`00Ool007oo00@0009oo`D00003Ool0000000<0009oo`<0009oo`D0
009oo`D00003Ool00000008000=oo`03001oogoo00Eoo`03001oogoo00Moo`05001oogooOol00002
Ool00`00Oomoo`08Ool30003Ool500000goo001oo`04Ool01@00Oomoogoo00000Woo00<007ooOol0
0Woo00H007ooOomoo`00Ool500000goo001oo`02Ool00`00Oomoo`07Ool20002Ool01`00Oomoogoo
001oo`00009oo`04001oogoo0002Ool01000Oomoo`000goo00<007ooOol0K7oo0003Ool01000Oomo
o`000Woo00L007oo001oo`00Ool00003Ool01@00Oomoogoo00001Goo00<007ooOol00Woo00H007oo
Ool007oo0002Ool01000Oomoo`000goo00@007oo001oo`<000=oo`<000=oo`05001oo`00Ool00007
Ool01@00Oomoogoo00000Woo00<007ooOol027oo00@007ooOol0009oo`07001oogooOol007oo0000
0goo00<007oo00000goo00<007ooOol00P000goo00L007ooOomoo`00Ool00003Ool00`00Ool00003
Ool00`00Oomoo`05Ool20004Ool01`00Oomoogoo001oo`00009oo`04001oogoo0002Ool01000Oomo
o`000goo00<007ooOol0K7oo0003Ool40002Ool01`00Ool007oo001oo`0000=oo`05001oogooOol0
0005Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01000Oomoo`000Woo00H007ooOomoo`00Ool50003
Ool00`00Oomoo`03Ool01@00Ool007oo000027oo0`000Woo100027oo00@007ooOol000=oo`<000=o
o`@0009oo`<0009oo`800003Ool00000009oo`@0009oo`<000=oo`@000Moo`04001oogoo0003Ool3
000017oo000007oo0P0000=oo`0000000`000goo1000KWoo0006Ool02P00Oomoo`00Ool007oo001o
o`000goo00D007ooOomoo`0000Eoo`03001oogoo009oo`03001oogoo009oo`04001oogoo0002Ool0
1P00Oomoogoo001oo`H00003Ool0000000<0009oo`D000ioo`03001oogoo00Moo`@001moo`03001o
ogoo00Uoo`03001oogoo00Ioo`<001Qoo`03001oogoo06aoo`0017oo0`0000=oo`0000002@0017oo
00<007ooOol00Woo0P000goo100000Aoo`00001oo`8000=oo`@0009oo`<001eoo`<002Uoo`8000Yo
o`80029oo`8006ioo`005goo00<007ooOol027oo00<007ooOol037oo00<007ooOol0k7oo000EOol3
0005Ool00`00Oomoo`02Ool00`00Oomoo`0;Ool2003^Ool00?moob5oo`00ogoo8Goo003oOolQOol0
0?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {946.587, -0.14072, 0.462505, 
  0.00748348}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-9.5 0.01 0 0.618034 [
[.3 -0.0125 -9 -9 ]
[.3 -0.0125 9 0 ]
[.5 -0.0125 -12 -9 ]
[.5 -0.0125 12 0 ]
[.7 -0.0125 -12 -9 ]
[.7 -0.0125 12 0 ]
[.9 -0.0125 -12 -9 ]
[.9 -0.0125 12 0 ]
[1.025 0 0 -6 ]
[1.025 0 58 6 ]
[.0875 .12361 -18 -4.5 ]
[.0875 .12361 0 4.5 ]
[.0875 .24721 -18 -4.5 ]
[.0875 .24721 0 4.5 ]
[.0875 .37082 -18 -4.5 ]
[.0875 .37082 0 4.5 ]
[.0875 .49443 -18 -4.5 ]
[.0875 .49443 0 4.5 ]
[.0875 .61803 -6 -4.5 ]
[.0875 .61803 0 4.5 ]
[.1 .64303 -29 0 ]
[.1 .64303 29 12 ]
[.5 .63053 -65 0 ]
[.5 .63053 65 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.3 0 m
.3 .00625 L
s
[(980)] .3 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1000)] .5 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(1020)] .7 -0.0125 0 1 Mshowa
.9 0 m
.9 .00625 L
s
[(1040)] .9 -0.0125 0 1 Mshowa
.125 Mabswid
.15 0 m
.15 .00375 L
s
.2 0 m
.2 .00375 L
s
.25 0 m
.25 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.45 0 m
.45 .00375 L
s
.55 0 m
.55 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.75 0 m
.75 .00375 L
s
.8 0 m
.8 .00375 L
s
.85 0 m
.85 .00375 L
s
.05 0 m
.05 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(frequency) show
117.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.1 .12361 m
.10625 .12361 L
s
[(0.2)] .0875 .12361 1 0 Mshowa
.1 .24721 m
.10625 .24721 L
s
[(0.4)] .0875 .24721 1 0 Mshowa
.1 .37082 m
.10625 .37082 L
s
[(0.6)] .0875 .37082 1 0 Mshowa
.1 .49443 m
.10625 .49443 L
s
[(0.8)] .0875 .49443 1 0 Mshowa
.1 .61803 m
.10625 .61803 L
s
[(1)] .0875 .61803 1 0 Mshowa
.125 Mabswid
.1 .0309 m
.10375 .0309 L
s
.1 .0618 m
.10375 .0618 L
s
.1 .09271 m
.10375 .09271 L
s
.1 .15451 m
.10375 .15451 L
s
.1 .18541 m
.10375 .18541 L
s
.1 .21631 m
.10375 .21631 L
s
.1 .27812 m
.10375 .27812 L
s
.1 .30902 m
.10375 .30902 L
s
.1 .33992 m
.10375 .33992 L
s
.1 .40172 m
.10375 .40172 L
s
.1 .43262 m
.10375 .43262 L
s
.1 .46353 m
.10375 .46353 L
s
.1 .52533 m
.10375 .52533 L
s
.1 .55623 m
.10375 .55623 L
s
.1 .58713 m
.10375 .58713 L
s
.25 Mabswid
.1 0 m
.1 .61803 L
s
gsave
.1 .64303 -90 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(amplitude) show
117.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.5 .63053 -126 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(FFT) show
87.000000 13.000000 moveto
(of) show
105.000000 13.000000 moveto
(Recorded) show
159.000000 13.000000 moveto
(Sound) show
189.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .0148 m
.01 .01424 L
.02 .00432 L
.03 .0148 L
.04 .03581 L
.05 .02425 L
.06 .02688 L
.07 .01005 L
.08 .01743 L
.09 .03078 L
.1 .02381 L
.11 .02274 L
.12 .01185 L
.13 .02982 L
.14 .04646 L
.15 .03545 L
.16 .02189 L
.17 .01632 L
.18 .01609 L
.19 .0156 L
.2 .02148 L
.21 .01714 L
.22 .03583 L
.23 .03014 L
.24 .02446 L
.25 .02135 L
.26 .02221 L
.27 .04498 L
.28 .05803 L
.29 .04024 L
.3 .03058 L
.31 .02726 L
.32 .02866 L
.33 .00485 L
.34 .03152 L
.35 .02165 L
.36 .02844 L
.37 .02286 L
.38 .02599 L
.39 .04539 L
.4 .03402 L
.41 .02975 L
.42 .03822 L
.43 .03574 L
.44 .03379 L
.45 .00634 L
.46 .02883 L
.47 .09784 L
.48 .1774 L
.49 .18792 L
Mistroke
.5 .22122 L
.51 .2382 L
.52 .21238 L
.53 .20176 L
.54 .23509 L
.55 .61803 L
.56 .24791 L
.57 .17053 L
.58 .08636 L
.59 .08459 L
.6 .07772 L
.61 .06807 L
.62 .09795 L
.63 .08539 L
.64 .07489 L
.65 .00973 L
.66 .04729 L
.67 .073 L
.68 .08079 L
.69 .09203 L
.7 .0608 L
.71 .03835 L
.72 .04879 L
.73 .08384 L
.74 .08315 L
.75 .10096 L
.76 .08608 L
.77 .03487 L
.78 .0135 L
.79 .0375 L
.8 .05765 L
.81 .08211 L
.82 .07928 L
.83 .07846 L
.84 .06028 L
.85 .0508 L
.86 .04313 L
.87 .03183 L
.88 .01215 L
.89 .01388 L
.9 .06332 L
.91 .05843 L
.92 .05399 L
.93 .05174 L
.94 .05719 L
.95 .07595 L
.96 .06148 L
.97 .05533 L
.98 .02491 L
.99 .01595 L
Mistroke
1 .04564 L
Mfstroke
1 .04564 m
1 .04564 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
@7oo0`0017oo0P0017oo0P006Goo0`0017oo0P0017oo0P0017oo0P005Woo0`0017oo0P000goo1000
0goo0P005Woo0`0017oo0P0017oo0`000goo0P00CGoo0013Ool01000Oomoo`000Woo00@007ooOol0
009oo`03001oogoo01Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000Woo00@007oo
Ool001Ioo`03001oogoo009oo`04001oogoo0003Ool00`00Oomoo`02Ool01000Oomoo`005Woo00<0
07ooOol00Woo00@007ooOol000Aoo`05001oogooOol00002Ool00`00Oomoo`1:Ool0045oo`<0009o
o`04001oogoo0002Ool01000Oomoo`006Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo
0002Ool01000Oomoo`005Woo00<007ooOol00Woo00@007ooOol000Aoo`05001oogooOol00002Ool0
0`00Oomoo`0DOol00`00Oomoo`02Ool01000Oomoo`000Woo10000Woo00@007ooOol004aoo`00@7oo
00@007ooOol000=oo`8000=oo`04001oogoo000IOol00`00Oomoo`02Ool01000Oomoo`000Woo00@0
07ooOol0009oo`04001oogoo000FOol00`00Oomoo`02Ool01000Oomoo`001Goo00@007ooOol0009o
o`03001oogoo01Aoo`03001oogoo009oo`04001oogoo0002Ool00`00Ool00003Ool01000Oomoo`00
C7oo0010Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo000IOol00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol0009oo`04001oogoo000FOol00`00Oomoo`02Ool01000Oomoo`00
0Woo00@007ooOol0009oo`04001oogoo000FOol00`00Oomoo`02Ool01000Oomoo`000Woo00<007oo
00000goo00@007ooOol004aoo`00@Goo0P0017oo0P0017oo0P006Goo0P001Goo0P0017oo0P0017oo
0P005Woo0P001Goo0P0017oo0P0017oo0P005Woo0P001Goo0P0017oo0P0017oo0P00:Goo10005goo
0`001Woo003nOol00`00Oomoo`0GOol00`00Oomoo`05Ool00>Qoo`@0009oo`@000=oo`@0009oo`@0
0003Ool0000000<0009oo`@00004Ool00000Ool20002Ool30003Ool00`00Oomoo`04Ool00>Uoo`03
001oogoo00=oo`03001oogoo009oo`03001oogoo00=oo`07001oogooOol007oo00000Woo00@007oo
Ool000Eoo`04001oogoo0002Ool01@00Oomoogoo00000Woo00<007ooOol017oo0007OooI0009Ool0
0`00Oomoo`03Ool00`00Oomoo`02Ool500000goo001oo`02Ool00`00Ool00002Ool00`00Oomoo`05
00001Goo001oogoo00000Woo00<007ooOol00goo00<007oo00001Goo000;Ool00`00Oomoo`04Ool0
0`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool0
0`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`08Ool0
0`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`08Ool0
0`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`0BOol0
0`00Oomoo`03Ool20003Ool01`00Oomoogoo001oo`0000=oo`03001oo`00009oo`04001oogoo0003
Ool00`00Ool00002Ool01000Oomoo`000goo00D007oo001oo`0000Eoo`002Woo0P004Goo00<007oo
Ool0:7oo00<007ooOol00goo00<007ooOol05goo00<007ooOol027oo00<007ooOol07Goo00<007oo
Ool027oo00<007ooOol0:7oo00<007ooOol077oo10000Woo0P0000=oo`0000000Woo0`000goo1P00
00=oo`0000000goo0`0000=oo`0000000`000goo1P0000=oo`00000017oo0008Ool20002Ool00`00
Oomoo`07Ool20005Ool01@00Oomoogoo0000:goo00<007oo000067oo00<007ooOol0:7oo00<007oo
Ool06Woo00<007ooOol04Woo0`008Goo00<007ooOol0=7oo0007Ool00`00Oomoo`03Ool00`00Oomo
o`06Ool00`00Ool00004Ool00`00Oomoo`020009Ool700000goo0000000HOol00`00Ool0000GOol0
0`00Ool0000YOol2000KOol00`00Oomoo`0BOol00`00Ool0000EOol00`00Oomoo`09Ool3000dOol0
00eoo`03001oogoo00Eoo`04001oogoo0004Ool30002Ool00`00Oomoo`04Ool20007Ool00`00Ool0
0007Ool4000=Ool00`00Ool00002Ool20003Ool2000>Ool00`00Ool0000YOol2000JOol00`00Ool0
000BOol01000Oomoo`0057oo0P00@Woo000>Ool01000Oomoogoo0`0017oo00<007ooOol00P0017oo
00<007ooOol017oo00<007ooOol02Goo00<007ooOol00Woo0P000goo00<007ooOol01goo10000goo
0P000Woo00<007oo00000Woo00<007ooOol02goo00<007oo0000:Goo0P006Goo00@007ooOol0019o
o`04001oogoo000COol01000Oomoo`00@Goo000?Ool00`00Ool00008Ool200000goo001oo`04Ool0
0`00Oomoo`02Ool00`00Oomoo`0:Ool00`00Oomoo`020006Ool00`00Oomoo`05Ool01@00Oomoogoo
00000goo00<007ooOol00Woo00D007ooOomoo`0000Eoo`8000Eoo`05001oogooOol0000WOol01000
Oomoo`0067oo00@007ooOol0015oo`03001oogoo009oo`03001oogoo011oo`04001oogoo0011Ool0
011oo`03001oogoo00Yoo`03001oogoo00=oo`05001oogooOol0000>Ool20008Ool00`00Oomoo`04
Ool00`00Oomoo`0@Ool00`00Oomoo`020002Ool00`00Ool000030003Ool00`00Oomoo`0UOol01000
Oomoo`005goo00<007ooOol00Woo00<007ooOol03Woo00<007ooOol00Woo00<007ooOol03goo00D0
07ooOomoo`00045oo`007Goo00<007ooOol017oo00<007oo00006Goo00<007ooOol00goo00<007oo
Ool04Goo00<007oo00001Goo00<007ooOol01Goo00<007ooOol09Goo00@007ooOol000Yoo`8000]o
o`03001oogoo009oo`03001oogoo00eoo`03001oogoo00=oo`03001oogoo00moo`03001oogoo009o
o`03001oogoo03ioo`007Goo00<007ooOol01Goo00<007ooOol06Goo00<007ooOol00Woo00<007oo
Ool04Woo00<007ooOol03Goo00<007ooOol097oo00D007ooOomoo`0000Uoo`03001oo`0000Yoo`03
001oogoo00=oo`03001oogoo00Yoo`8000Ioo`03001oogoo00moo`03001oogoo009oo`03001oogoo
03ioo`007Goo00<007ooOol08Goo00D007ooOomoo`0002Eoo`03001oogoo02Aoo`05001oogooOol0
0008Ool01@00Oomoogoo00002Goo00<007ooOol00goo00<007ooOol02Goo00<007ooOol01Woo00<0
07ooOol03Woo00<007ooOol0A7oo000MOol00`00Oomoo`0ROol00`00Ool0000VOol00`00Oomoo`0T
Ool01@00Oomoogoo000027oo00D007ooOomoo`0000Qoo`03001oogoo00Aoo`03001oogoo00Qoo`03
001oogoo00Qoo`04001oogooOol50006Ool20016Ool001eoo`03001oogoo02=oo`03001oogoo02Eo
o`03001oogoo02Aoo`03001oogoo009oo`03001oogoo00Eoo`05001oogooOol00008Ool00`00Oomo
o`05Ool00`00Oomoo`06Ool00`00Oomoo`09Ool01000Ool000001Goo00<007ooOol00Woo00<007oo
Ool0AWoo000MOol00`00Oomoo`1;Ool00`00Oomoo`0SOol00`00Oomoo`03Ool00`00Oomoo`04Ool0
0`00Oomoo`03Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`06Ool00`00Oomoo`09Ool2
0007Ool01@00Oomoogoo0000BGoo000MOol00`00Oomoo`1<Ool00`00Oomoo`0LOol00`00Oomoo`03
Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`05Ool00`00Oomoo`06
Ool00`00Oomoo`04Ool00`00Oomoo`0DOol01000Oomoo`00BGoo000MOol00`00Oomoo`1<Ool00`00
Oomoo`0KOol20005Ool00`00Oomoo`04Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`05
Ool00`00Oomoo`06Ool00`00Oomoo`03Ool00`00Oomoo`0EOol00`00Ool0001:Ool001eoo`03001o
ogoo04aoo`03001oogoo01Uoo`800003Ool007oo00Aoo`03001oogoo00Eoo`05001oogooOol00007
Ool00`00Oomoo`03Ool00`00Oomoo`07Ool01000Oomoogoo0P006Goo00<007ooOol0BGoo000MOol0
0`00Oomoo`1<Ool00`00Oomoo`0HOol00`00Oomoo`02Ool01@00Oomoogoo00002Goo00@007ooOol0
00Moo`<000=oo`03001oogoo00Qoo`<006Moo`007Goo00<007ooOol0C7oo00<007ooOol05Goo0`00
1Goo00@007ooOol000]oo`8000Yoo`05001oogooOol0001dOol001eoo`03001oogoo04eoo`03001o
ogoo01Aoo`03001oogoo00Eoo`04001oogoo000<Ool00`00Oomoo`09Ool01000Oomoo`00M7oo000M
Ool00`00Oomoo`1=Ool00`00Oomoo`0DOol00`00Oomoo`06Ool2000IOol00`00Ool0001eOol001eo
o`03001oogoo04eoo`03001oogoo01Aoo`03001oogoo00Ioo`03001oogoo01Uoo`03001oogoo07Ao
o`007Goo00<007ooOol0CGoo00<007ooOol057oo00<007ooOol0VGoo000MOol00`00Oomoo`1=Ool0
0`00Oomoo`0COol00`00Oomoo`2JOol000Yoo`8000Aoo`8000=oo`@000Aoo`03001oogoo04eoo`03
001oogoo01=oo`03001oogoo09Yoo`002Goo00@007ooOol000=oo`8000Aoo`03001oogoo00Aoo`03
001oogoo04eoo`03001oogoo01=oo`03001oogoo09Yoo`002Goo00@007ooOol000Yoo`03001oogoo
00=oo`8004moo`03001oogoo019oo`03001oogoo09Yoo`002Goo00@007ooOol000]oo`03001oogoo
009oo`03001oogoo04ioo`03001oogoo019oo`03001oogoo09Yoo`002Goo00@007ooOol000Qoo`04
001oogoo0004Ool00`00Oomoo`1>Ool00`00Oomoo`0BOol00`00Oomoo`2JOol000Yoo`8000Yoo`80
00Eoo`03001oogoo04ioo`03001oogoo019oo`03001oogoo09Yoo`007Goo00<007ooOol0CWoo00<0
07ooOol04Woo00<007ooOol0VWoo000MOol00`00Oomoo`1>Ool00`00Oomoo`0BOol00`00Oomoo`2J
Ool001eoo`03001oogoo04ioo`03001oogoo015oo`03001oogoo09]oo`007Goo00<007ooOol0CWoo
00<007ooOol04Goo00<007ooOol0Vgoo000MOol00`00Oomoo`1>Ool00`00Oomoo`0AOol00`00Oomo
o`2KOol001eoo`03001oogoo04moo`03001oogoo011oo`03001oogoo09]oo`007Goo00<007ooOol0
Cgoo00<007ooOol047oo00<007ooOol0Vgoo000MOol00`00Oomoo`1?Ool00`00Oomoo`0@Ool00`00
Oomoo`2KOol001eoo`03001oogoo04moo`03001oogoo011oo`03001oogoo09]oo`007Goo00<007oo
Ool0D7oo00<007ooOol03goo00<007ooOol0Vgoo000MOol00`00Oomoo`1AOol00`00Oomoo`0>Ool0
0`00Oomoo`2KOol001eoo`03001oogoo055oo`03001oogoo00eoo`03001oogoo09aoo`007Goo00<0
07ooOol0DGoo00<007ooOol03Goo00<007ooOol0W7oo000MOol00`00Oomoo`1BOol00`00Oomoo`04
Ool00`00Oomoo`05Ool00`00Oomoo`2LOol001eoo`03001oogoo059oo`03001oogoo00=oo`8000Mo
o`03001oogoo09aoo`007Goo00<007ooOol0DWoo00<007ooOol00Woo00@007ooOol000Ioo`03001o
ogoo09aoo`007Goo00<007ooOol0Dgoo00D007ooOomoo`00009oo`03001oogoo00Aoo`03001oogoo
09aoo`007Goo00<007ooOol0Dgoo00@007ooOol000Aoo`03001oogoo00=oo`03001oogoo09aoo`00
7Goo00<007ooOol0Dgoo00@007ooOol000Aoo`03001oogoo00=oo`03001oogoo09aoo`007Goo00<0
07ooOol0E7oo00<007oo000017oo00<007ooOol00goo00<007ooOol0W7oo000MOol00`00Oomoo`1D
Ool20006Ool01@00Oomoogoo0000Wgoo000:Ool20004Ool20004Ool30004Ool00`00Oomoo`1EOol0
0`00Oomoo`04Ool01@00Oomoogoo0000Wgoo0009Ool01000Oomoo`000goo0P001Goo00<007ooOol0
0goo00<007ooOol0G7oo00D007ooOomoo`0009moo`002Goo00@007ooOol000Qoo`@000Aoo`8005eo
o`05001oogooOol0002OOol000Uoo`04001oogoo0008Ool00`00Ool00005Ool00`00Oomoo`1LOol0
1@00Oomoogoo0000Wgoo0009Ool01000Oomoo`0027oo00<007oo00001Goo00<007ooOol0G7oo00D0
07ooOomoo`0009moo`002Woo0P002Woo0P001Goo00<007ooOol0G7oo00D007ooOomoo`0009moo`00
7Goo00<007ooOol0G7oo00D007ooOomoo`0009moo`007Goo00<007ooOol0G7oo00D007ooOomoo`00
09moo`007Goo00<007ooOol0G7oo00D007ooOomoo`0009moo`007Goo00<007ooOol0G7oo00D007oo
Oomoo`0009moo`007Goo00<007ooOol0G7oo00D007ooOomoo`0009moo`007Goo00<007ooOol0G7oo
00D007ooOomoo`0009moo`007Goo00<007ooOol0G7oo00D007ooOomoo`0009moo`007Goo00<007oo
Ool0G7oo00D007ooOomoo`0009moo`007Goo00<007ooOol0G7oo00D007ooOomoo`0009moo`007Goo
00<007ooOol0G7oo00D007ooOomoo`0009moo`007Goo00<007ooOol0G7oo00D007ooOomoo`0009mo
o`007Goo00<007ooOol0G7oo00D007ooOomoo`0009moo`007Goo00<007ooOol0G7oo00D007ooOomo
o`0009moo`007Goo00<007ooOol0G7oo00D007ooOomoo`0009moo`007Goo00<007ooOol0G7oo00D0
07ooOomoo`0009moo`007Goo00<007ooOol0GGoo00@007ooOol009moo`007Goo00<007ooOol0GGoo
00@007ooOol009moo`007Goo00<007ooOol0GGoo00<007oo0000X7oo000MOol00`00Oomoo`1MOol0
0`00Ool0002POol001eoo`03001oogoo05eoo`03001oo`000:1oo`007Goo00<007ooOol0GGoo00<0
07oo0000X7oo000:Ool20004Ool20004Ool20005Ool00`00Oomoo`1MOol00`00Ool0002POol000Uo
o`04001oogoo0003Ool20003Ool01000Oomoo`0017oo00<007ooOol0GGoo00<007oo0000X7oo0009
Ool01000Oomoo`0027oo00@007ooOol000Aoo`8005ioo`03001oo`000:1oo`002Goo00@007ooOol0
00Qoo`<000Eoo`03001oogoo05eoo`03001oo`000:1oo`002Goo00@007ooOol000Qoo`03001oogoo
00Eoo`03001oogoo05eoo`03001oo`000:1oo`002Woo0P002Woo0`0017oo00<007ooOol0GGoo00<0
07oo0000X7oo000MOol00`00Oomoo`1MOol00`00Ool0002POol001eoo`03001oogoo05eoo`03001o
o`000:1oo`007Goo00<007ooOol0GGoo00<007oo0000X7oo000MOol00`00Oomoo`1MOol00`00Ool0
002POol001eoo`03001oogoo05eoo`03001oo`000:1oo`007Goo00<007ooOol0GGoo00<007oo0000
X7oo000MOol00`00Oomoo`1MOol00`00Ool0002POol001eoo`03001oogoo05eoo`03001oo`000:1o
o`007Goo00<007ooOol0GGoo00<007oo0000X7oo000MOol00`00Oomoo`1MOol00`00Ool0002POol0
01eoo`03001oogoo05eoo`03001oo`000:1oo`007Goo00<007ooOol0GGoo00<007oo0000X7oo000M
Ool00`00Oomoo`1MOol00`00Ool0002POol001eoo`03001oogoo05eoo`03001oo`000:1oo`007Goo
00<007ooOol0GGoo00<007oo0000X7oo000MOol00`00Oomoo`1MOol00`00Ool0002POol001eoo`03
001oogoo05eoo`03001oo`000:1oo`007Goo00<007ooOol0GGoo00<007oo0000X7oo000MOol00`00
Oomoo`1MOol00`00Ool0002POol001eoo`03001oogoo05eoo`03001oo`000:1oo`002Woo0P0017oo
0P0017oo0P001Goo00<007ooOol0GGoo00<007oo0000X7oo0009Ool01000Oomoo`000goo0P000goo
00@007ooOol000Aoo`03001oogoo05eoo`03001oo`000:1oo`002Goo00@007ooOol000Qoo`04001o
ogoo0004Ool2001NOol00`00Ool0002POol000Uoo`04001oogoo0009Ool20005Ool00`00Oomoo`1M
Ool00`00Ool0002POol000Uoo`04001oogoo0008Ool01000Oomoo`0017oo00<007ooOol0GGoo00<0
07oo0000X7oo000:Ool2000:Ool20005Ool00`00Oomoo`1MOol00`00Ool0002POol001eoo`03001o
ogoo05eoo`03001oo`000:1oo`007Goo00<007ooOol0GGoo00<007oo0000X7oo000MOol00`00Oomo
o`1MOol00`00Ool0002POol001eoo`03001oogoo05ioo`800:1oo`007Goo00<007ooOol0GWoo00<0
07ooOol0Wgoo000MOol00`00Oomoo`1NOol00`00Oomoo`2OOol001eoo`03001oogoo05ioo`03001o
ogoo09moo`007Goo00<007ooOol0GWoo00<007ooOol0Wgoo000MOol00`00Oomoo`1NOol00`00Oomo
o`2OOol001eoo`03001oogoo05ioo`03001oogoo09moo`007Goo00<007ooOol0GWoo00<007ooOol0
Wgoo000MOol00`00Oomoo`1NOol00`00Oomoo`2OOol001eoo`03001oogoo05ioo`03001oogoo09mo
o`007Goo00<007ooOol0GWoo00<007ooOol0Wgoo000MOol00`00Oomoo`1NOol00`00Oomoo`2OOol0
01eoo`03001oogoo05ioo`03001oogoo09moo`007Goo00<007ooOol0GWoo00<007ooOol0Wgoo000M
Ool00`00Oomoo`1NOol00`00Oomoo`2OOol001eoo`03001oogoo05ioo`03001oogoo09moo`007Goo
00<007ooOol0GWoo00<007ooOol0Wgoo000MOol00`00Oomoo`1NOol00`00Oomoo`2OOol001Eoo`<0
00Eoo`03001oogoo05ioo`03001oogoo09moo`005Woo00<007ooOol017oo00<007ooOol0GWoo00<0
07ooOol0Wgoo000FOol00`00Oomoo`04Ool2001OOol00`00Oomoo`2OOol001Ioo`03001oogoo0?mo
o`Qoo`005Woo00<007ooOol0ogoo27oo000EOol2003oOol:Ool00?moob5oo`00ogoo8Goo003oOolQ
Ool000ioo`@0029oo`<000=oo`<000Eoo`<000Uoo`<0009oo`@000Moo`80009oo`80009oo`@0009o
o`<000=oo`<0009oo`@000=oo`D00003Ool000000080009oo`D000Ioo`<000Aoo`<0009oo`D00004
Ool00000Ool20002Ool5001]Ool000moo`03001oogoo02=oo`03001oogoo00=oo`03001oogoo00Eo
o`03001oogoo00Moo`05001oogooOol00002Ool00`00Oomoo`08Ool01000Ool000000Woo00<007oo
Ool00goo00L007ooOomoo`00Ool00003Ool01000Oomoo`0017oo00L007ooOomoo`00Ool00005Ool0
1@00Oomoogoo00001goo00@007ooOol0009oo`07001oogooOol007oo00000Woo00@007ooOol0009o
o`04001oogoo0003Ool00`00Oomoo`1/Ool000=oo`D00007Ool007oo001oo`00Ool010000Woo1@00
00=oo`0000000`000Woo0`000Woo1@000Woo1@0000=oo`0000000P000goo00<007ooOol01Goo00<0
07ooOol01goo00D007ooOomoo`00009oo`03001oogoo00Qoo`<000=oo`D00003Ool007oo00Aoo`05
001oogooOol00002Ool00`00Oomoo`02Ool01P00Oomoogoo001oo`D00003Ool007oo009oo`03001o
ogoo00Moo`80009oo`07001oogooOol007oo00000Woo00@007ooOol0009oo`04001oogoo0003Ool0
0`00Oomoo`1/Ool000=oo`04001oogoo0002Ool01`00Ool007oo001oo`0000=oo`05001oogooOol0
0005Ool00`00Oomoo`02Ool01P00Oomoo`00Ool0009oo`04001oogoo0003Ool01000Ool007oo0`00
0goo0`000goo00D007oo001oo`0000Moo`05001oogooOol00002Ool00`00Oomoo`08Ool01000Oomo
o`000Woo00L007ooOomoo`00Ool00003Ool00`00Ool00003Ool00`00Oomoo`020003Ool01`00Oomo
ogoo001oo`0000=oo`03001oo`0000=oo`03001oogoo00Eoo`8000Aoo`07001oogooOol007oo0000
0Woo00@007ooOol0009oo`04001oogoo0003Ool00`00Oomoo`1/Ool000=oo`@0009oo`07001oo`00
Ool007oo00000goo00D007ooOomoo`0000Eoo`03001oogoo009oo`03001oogoo009oo`04001oogoo
0002Ool01P00Oomoogoo001oo`D000=oo`03001oogoo00=oo`05001oo`00Ool00008Ool30002Ool4
0008Ool01000Oomoo`000goo0`000goo10000Woo0`000Woo0P0000=oo`0000000Woo10000Woo0`00
0goo10001goo00@007ooOol000=oo`<00004Ool00000Ool200000goo000000030003Ool4001^Ool0
00Ioo`0:001oogoo001oo`00Ool007oo0003Ool01@00Oomoogoo00001Goo00<007ooOol00Woo00<0
07ooOol00Woo00@007ooOol0009oo`06001oogooOol007oo1P0000=oo`0000000`000Woo1@003Woo
00<007ooOol01goo10007goo00<007ooOol02Goo00<007ooOol01Woo0`0067oo00<007ooOol0K7oo
0004Ool300000goo000000090004Ool00`00Oomoo`02Ool20003Ool4000017oo000007oo0P000goo
10000Woo0`007Goo0`00:Goo0P002Woo0P008Woo0P00KWoo000GOol00`00Oomoo`08Ool00`00Oomo
o`0<Ool00`00Oomoo`3/Ool001Eoo`<000Eoo`03001oogoo009oo`03001oogoo00]oo`800>ioo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {946.587, -0.14072, 0.462505, 
  0.00748348}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-9.5 0.01 0 0.618034 [
[.3 -0.0125 -9 -9 ]
[.3 -0.0125 9 0 ]
[.5 -0.0125 -12 -9 ]
[.5 -0.0125 12 0 ]
[.7 -0.0125 -12 -9 ]
[.7 -0.0125 12 0 ]
[.9 -0.0125 -12 -9 ]
[.9 -0.0125 12 0 ]
[1.025 0 0 -6 ]
[1.025 0 58 6 ]
[.0875 .12361 -18 -4.5 ]
[.0875 .12361 0 4.5 ]
[.0875 .24721 -18 -4.5 ]
[.0875 .24721 0 4.5 ]
[.0875 .37082 -18 -4.5 ]
[.0875 .37082 0 4.5 ]
[.0875 .49443 -18 -4.5 ]
[.0875 .49443 0 4.5 ]
[.0875 .61803 -6 -4.5 ]
[.0875 .61803 0 4.5 ]
[.1 .64303 -29 0 ]
[.1 .64303 29 12 ]
[.5 .63053 -65 0 ]
[.5 .63053 65 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.3 0 m
.3 .00625 L
s
[(980)] .3 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1000)] .5 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(1020)] .7 -0.0125 0 1 Mshowa
.9 0 m
.9 .00625 L
s
[(1040)] .9 -0.0125 0 1 Mshowa
.125 Mabswid
.15 0 m
.15 .00375 L
s
.2 0 m
.2 .00375 L
s
.25 0 m
.25 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.45 0 m
.45 .00375 L
s
.55 0 m
.55 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.75 0 m
.75 .00375 L
s
.8 0 m
.8 .00375 L
s
.85 0 m
.85 .00375 L
s
.05 0 m
.05 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(frequency) show
117.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.1 .12361 m
.10625 .12361 L
s
[(0.2)] .0875 .12361 1 0 Mshowa
.1 .24721 m
.10625 .24721 L
s
[(0.4)] .0875 .24721 1 0 Mshowa
.1 .37082 m
.10625 .37082 L
s
[(0.6)] .0875 .37082 1 0 Mshowa
.1 .49443 m
.10625 .49443 L
s
[(0.8)] .0875 .49443 1 0 Mshowa
.1 .61803 m
.10625 .61803 L
s
[(1)] .0875 .61803 1 0 Mshowa
.125 Mabswid
.1 .0309 m
.10375 .0309 L
s
.1 .0618 m
.10375 .0618 L
s
.1 .09271 m
.10375 .09271 L
s
.1 .15451 m
.10375 .15451 L
s
.1 .18541 m
.10375 .18541 L
s
.1 .21631 m
.10375 .21631 L
s
.1 .27812 m
.10375 .27812 L
s
.1 .30902 m
.10375 .30902 L
s
.1 .33992 m
.10375 .33992 L
s
.1 .40172 m
.10375 .40172 L
s
.1 .43262 m
.10375 .43262 L
s
.1 .46353 m
.10375 .46353 L
s
.1 .52533 m
.10375 .52533 L
s
.1 .55623 m
.10375 .55623 L
s
.1 .58713 m
.10375 .58713 L
s
.25 Mabswid
.1 0 m
.1 .61803 L
s
gsave
.1 .64303 -90 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(amplitude) show
117.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.5 .63053 -126 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(FFT) show
87.000000 13.000000 moveto
(of) show
105.000000 13.000000 moveto
(Recorded) show
159.000000 13.000000 moveto
(Sound) show
189.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .00361 m
.01 .00127 L
.02 .01123 L
.03 .00443 L
.04 .00849 L
.05 .00193 L
.06 .01073 L
.07 .00582 L
.08 .00832 L
.09 .0036 L
.1 .00647 L
.11 .00173 L
.12 .00587 L
.13 .00179 L
.14 .00068 L
.15 .00929 L
.16 .00793 L
.17 .00086 L
.18 .01044 L
.19 .00767 L
.2 .00874 L
.21 .00983 L
.22 .00993 L
.23 .00539 L
.24 .0039 L
.25 .00765 L
.26 .00553 L
.27 .00331 L
.28 .00851 L
.29 .01429 L
.3 .00479 L
.31 .00921 L
.32 .01589 L
.33 .00924 L
.34 .005 L
.35 .01358 L
.36 .00789 L
.37 .01286 L
.38 .01856 L
.39 .01507 L
.4 .01535 L
.41 .01543 L
.42 .01284 L
.43 .01779 L
.44 .02151 L
.45 .01805 L
.46 .02556 L
.47 .02721 L
.48 .03237 L
.49 .0391 L
Mistroke
.5 .04688 L
.51 .05303 L
.52 .08186 L
.53 .19499 L
.54 .61803 L
.55 .29627 L
.56 .12536 L
.57 .07542 L
.58 .05894 L
.59 .04554 L
.6 .04037 L
.61 .03321 L
.62 .02772 L
.63 .01949 L
.64 .02356 L
.65 .02275 L
.66 .00608 L
.67 .01793 L
.68 .0143 L
.69 .0138 L
.7 .01634 L
.71 .01097 L
.72 .01379 L
.73 .00499 L
.74 .01815 L
.75 .00584 L
.76 .01631 L
.77 .01356 L
.78 .00769 L
.79 .01565 L
.8 .01305 L
.81 .00425 L
.82 .00933 L
.83 .01513 L
.84 .00369 L
.85 .01093 L
.86 .01426 L
.87 .00181 L
.88 .0039 L
.89 .00933 L
.9 .00144 L
.91 .0036 L
.92 .00526 L
.93 .00142 L
.94 .00863 L
.95 .00911 L
.96 .00433 L
.97 .00525 L
.98 .00662 L
.99 .00409 L
Mistroke
1 .00201 L
Mfstroke
1 .00201 m
1 .00201 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
@7oo0`0017oo0P0017oo0P006Goo0`0017oo0P0017oo0P0017oo0P005Woo0`0017oo0P000goo1000
0goo0P005Woo0`0017oo0P0017oo0`000goo0P00CGoo0013Ool01000Oomoo`000Woo00@007ooOol0
009oo`03001oogoo01Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000Woo00@007oo
Ool001Ioo`03001oogoo009oo`04001oogoo0003Ool00`00Oomoo`02Ool01000Oomoo`005Woo00<0
07ooOol00Woo00@007ooOol000Aoo`05001oogooOol00002Ool00`00Oomoo`1:Ool0045oo`<0009o
o`04001oogoo0002Ool01000Oomoo`006Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo
0002Ool01000Oomoo`005Woo00<007ooOol00Woo00@007ooOol000Aoo`05001oogooOol00002Ool0
0`00Oomoo`0DOol00`00Oomoo`02Ool01000Oomoo`000Woo10000Woo00@007ooOol004aoo`00@7oo
00@007ooOol000=oo`8000=oo`04001oogoo000IOol00`00Oomoo`02Ool01000Oomoo`000Woo00@0
07ooOol0009oo`04001oogoo000FOol00`00Oomoo`02Ool01000Oomoo`001Goo00@007ooOol0009o
o`03001oogoo01Aoo`03001oogoo009oo`04001oogoo0002Ool00`00Ool00003Ool01000Oomoo`00
C7oo0010Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo000IOol00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol0009oo`04001oogoo000FOol00`00Oomoo`02Ool01000Oomoo`00
0Woo00@007ooOol0009oo`04001oogoo000FOol00`00Oomoo`02Ool01000Oomoo`000Woo00<007oo
00000goo00@007ooOol004aoo`00@Goo0P0017oo0P0017oo0P006Goo0P001Goo0P0017oo0P0017oo
0P005Woo0P001Goo0P0017oo0P0017oo0P005Woo0P001Goo0P0017oo0P0017oo0P00:Goo10005goo
0`001Woo003nOol00`00Oomoo`0GOol00`00Oomoo`05Ool00>Qoo`@0009oo`@000=oo`@0009oo`@0
0003Ool0000000<0009oo`@00004Ool00000Ool20002Ool30003Ool00`00Oomoo`04Ool00>Uoo`03
001oogoo00=oo`03001oogoo009oo`03001oogoo00=oo`07001oogooOol007oo00000Woo00@007oo
Ool000Eoo`04001oogoo0002Ool01@00Oomoogoo00000Woo00<007ooOol017oo0007OooI0009Ool0
0`00Oomoo`03Ool00`00Oomoo`02Ool500000goo001oo`02Ool00`00Ool00002Ool00`00Oomoo`05
00001Goo001oogoo00000Woo00<007ooOol00goo00<007oo00001Goo0007Ool30003Ool300000goo
00000006Ool800000goo000000040003Ool20005Ool00`00Oomoo`05Ool40002Ool30005Ool20005
Ool300000goo001oo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomo
o`08Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`04Ool01@00Oomoogoo00002Woo00@0
07oo000000Eoo`03001oo`0000=oo`@00003Ool0000000@00004Ool000000002Ool700000goo0000
00020009Ool00`00Oomoo`03Ool20003Ool01`00Oomoogoo001oo`0000=oo`03001oo`00009oo`04
001oogoo0003Ool00`00Ool00002Ool01000Oomoo`000goo00D007oo001oo`0000Eoo`002Woo00<0
07oo00000goo00D007ooOol007oo00@000Aoo`05001oogooOol00005Ool40002Ool00`00Ool00006
0002Ool20003Ool30003Ool300001Goo000007oo00000goo00H007ooOomoo`00Ool3000LOol00`00
Oomoo`0POol00`00Oomoo`05Ool00`00Oomoo`03Ool20003Ool00`00Oomoo`03Ool20004Ool01000
Oomoo`000goo00<007oo00000goo00<007ooOol00Woo00<007oo000017oo00@007ooOomoo`<000Io
o`03001oogoo00Yoo`@0009oo`800003Ool00000009oo`<000=oo`H00003Ool0000000=oo`<00003
Ool0000000<000=oo`H00003Ool0000000Aoo`002goo00<007ooOol01Woo00<007ooOol01Woo00<0
07ooOol03Woo00<007ooOol01Goo0P003Woo00<007ooOol00Woo00<007oo00001Goo00@007ooOomo
o`8000Qoo`<0035oo`04001oo`00Ool500000goo000000030002Ool01P00Ool007oo001oo`<0009o
o`04001oo`000004Ool00`00Ool00003Ool3000WOol00`00Oomoo`0dOol001eoo`03001oogoo02ao
o`03001oogoo00Yoo`P000=oo`800003Ool0000002]oo`05001oogooOol00005Ool00`00Oomoo`06
Ool01@00Oomoogoo00001Woo00<007ooOol01Goo00<007ooOol0;7oo0`00=7oo000MOol00`00Oomo
o`16Ool01000Oomoo`0097oo1P00S7oo000MOol00`00Oomoo`1:Ool5000NOol00`00Oomoo`2@Ool0
01eoo`03001oogoo04moo`03001oogoo01Yoo`03001oogoo095oo`007Goo00<007ooOol0D7oo00<0
07ooOol05goo0P00U7oo000MOol00`00Oomoo`1AOol00`00Oomoo`0DOol2002FOol001eoo`03001o
ogoo059oo`03001oogoo015oo`8009Qoo`007Goo00<007ooOol0Dgoo0P004Goo00<007ooOol0Ugoo
000MOol00`00Oomoo`1EOol00`00Oomoo`0=Ool00`00Oomoo`2HOol001eoo`03001oogoo05Eoo`03
001oogoo00aoo`03001oogoo09Uoo`007Goo00<007ooOol0EWoo00<007ooOol02goo00<007ooOol0
VGoo000MOol00`00Oomoo`1FOol00`00Oomoo`0:Ool00`00Oomoo`2JOol001eoo`03001oogoo05Io
o`03001oogoo00Yoo`03001oogoo09Yoo`007Goo00<007ooOol0Egoo00<007ooOol027oo00<007oo
Ool0Vgoo000MOol00`00Oomoo`1GOol00`00Oomoo`08Ool00`00Oomoo`2KOol001eoo`03001oogoo
05Moo`03001oogoo00Qoo`03001oogoo09]oo`007Goo00<007ooOol0Egoo00<007ooOol01goo00<0
07ooOol0W7oo000MOol00`00Oomoo`1GOol00`00Oomoo`07Ool00`00Oomoo`2LOol001eoo`03001o
ogoo05Moo`03001oogoo00Moo`03001oogoo09aoo`007Goo00<007ooOol0Egoo00<007ooOol01goo
00<007ooOol0W7oo000MOol00`00Oomoo`1GOol00`00Oomoo`07Ool00`00Oomoo`2LOol000Yoo`80
00Aoo`8000=oo`@000Aoo`03001oogoo05Qoo`03001oogoo00Eoo`03001oogoo09eoo`002Goo00@0
07ooOol000=oo`8000Aoo`03001oogoo00Aoo`03001oogoo05Qoo`03001oogoo00Eoo`03001oogoo
09eoo`002Goo00@007ooOol000Yoo`03001oogoo00=oo`8005Uoo`03001oogoo00Eoo`03001oogoo
09eoo`002Goo00@007ooOol000]oo`03001oogoo009oo`03001oogoo05Qoo`03001oogoo00Eoo`03
001oogoo09eoo`002Goo00@007ooOol000Qoo`04001oogoo0004Ool00`00Oomoo`1HOol00`00Oomo
o`05Ool00`00Oomoo`2MOol000Yoo`8000Yoo`8000Eoo`03001oogoo05Qoo`03001oogoo00Eoo`03
001oogoo09eoo`007Goo00<007ooOol0F7oo00<007ooOol01Goo00<007ooOol0WGoo000MOol00`00
Oomoo`1HOol00`00Oomoo`05Ool00`00Oomoo`2MOol001eoo`03001oogoo05Qoo`03001oogoo00Eo
o`03001oogoo09eoo`007Goo00<007ooOol0F7oo00<007ooOol01Goo00<007ooOol0WGoo000MOol0
0`00Oomoo`1HOol00`00Oomoo`05Ool00`00Oomoo`2MOol001eoo`03001oogoo05Qoo`03001oogoo
00Eoo`03001oogoo09eoo`007Goo00<007ooOol0F7oo00<007ooOol017oo00<007ooOol0WWoo000M
Ool00`00Oomoo`1IOol00`00Oomoo`03Ool00`00Oomoo`2NOol001eoo`03001oogoo05Uoo`03001o
ogoo00=oo`03001oogoo09ioo`007Goo00<007ooOol0FGoo00<007ooOol00goo00<007ooOol0WWoo
000MOol00`00Oomoo`1IOol00`00Oomoo`03Ool00`00Oomoo`2NOol001eoo`03001oogoo05Uoo`03
001oogoo00=oo`03001oogoo09ioo`007Goo00<007ooOol0FGoo00<007ooOol00goo00<007ooOol0
WWoo000MOol00`00Oomoo`1IOol00`00Oomoo`03Ool00`00Oomoo`2NOol001eoo`03001oogoo05Uo
o`03001oogoo00=oo`03001oogoo09ioo`007Goo00<007ooOol0FGoo00<007ooOol00goo00<007oo
Ool0WWoo000MOol00`00Oomoo`1IOol00`00Oomoo`03Ool00`00Oomoo`2NOol001eoo`03001oogoo
05Uoo`03001oogoo00=oo`03001oogoo09ioo`007Goo00<007ooOol0FGoo00<007ooOol00goo00<0
07ooOol0WWoo000MOol00`00Oomoo`1IOol00`00Oomoo`03Ool00`00Oomoo`2NOol001eoo`03001o
ogoo05Uoo`03001oogoo00=oo`03001oogoo09ioo`002Woo0P0017oo0P0017oo0`0017oo00<007oo
Ool0FGoo00<007ooOol00goo00<007ooOol0WWoo0009Ool01000Oomoo`000goo0P001Goo00<007oo
Ool00goo00<007ooOol0FGoo00<007ooOol00goo00<007ooOol0WWoo0009Ool01000Oomoo`0027oo
100017oo0P00FWoo00<007ooOol00goo00<007ooOol0WWoo0009Ool01000Oomoo`0027oo00<007oo
00001Goo00<007ooOol0FGoo00<007ooOol00goo00<007ooOol0WWoo0009Ool01000Oomoo`0027oo
00<007oo00001Goo00<007ooOol0FGoo00<007ooOol00Woo00<007ooOol0Wgoo000:Ool2000:Ool2
0005Ool00`00Oomoo`1IOol00`00Oomoo`02Ool00`00Oomoo`2OOol001eoo`03001oogoo05Uoo`03
001oogoo009oo`03001oogoo09moo`007Goo00<007ooOol0FWoo00D007ooOomoo`000:5oo`007Goo
00<007ooOol0FWoo00D007ooOomoo`000:5oo`007Goo00<007ooOol0FWoo00D007ooOomoo`000:5o
o`007Goo00<007ooOol0FWoo00D007ooOomoo`000:5oo`007Goo00<007ooOol0FWoo00D007ooOomo
o`000:5oo`007Goo00<007ooOol0FWoo00D007ooOomoo`000:5oo`007Goo00<007ooOol0FWoo00D0
07ooOomoo`000:5oo`007Goo00<007ooOol0FWoo00D007ooOomoo`000:5oo`007Goo00<007ooOol0
FWoo00D007ooOomoo`000:5oo`007Goo00<007ooOol0FWoo00D007ooOomoo`000:5oo`007Goo00<0
07ooOol0FWoo00D007ooOomoo`000:5oo`007Goo00<007ooOol0FWoo00D007ooOomoo`000:5oo`00
7Goo00<007ooOol0FWoo00D007ooOomoo`000:5oo`007Goo00<007ooOol0FWoo00D007ooOomoo`00
0:5oo`007Goo00<007ooOol0FWoo00D007ooOomoo`000:5oo`007Goo00<007ooOol0FWoo00D007oo
Oomoo`000:5oo`007Goo00<007ooOol0FWoo00D007ooOomoo`000:5oo`007Goo00<007ooOol0FWoo
00D007ooOomoo`000:5oo`007Goo00<007ooOol0FWoo00D007ooOomoo`000:5oo`007Goo00<007oo
Ool0FWoo00D007ooOomoo`000:5oo`002Woo0P0017oo0P0017oo0P001Goo00<007ooOol0FWoo00D0
07ooOomoo`000:5oo`002Goo00@007ooOol000=oo`8000=oo`04001oogoo0004Ool00`00Oomoo`1J
Ool01@00Oomoogoo0000XGoo0009Ool01000Oomoo`0027oo00@007ooOol000Aoo`8005]oo`05001o
ogooOol0002QOol000Uoo`04001oogoo0008Ool30005Ool00`00Oomoo`1JOol01000Oomoo`00XWoo
0009Ool01000Oomoo`0027oo00<007ooOol01Goo00<007ooOol0FWoo00@007ooOol00:9oo`002Woo
0P002Woo0`0017oo00<007ooOol0FWoo00@007ooOol00:9oo`007Goo00<007ooOol0FWoo00@007oo
Ool00:9oo`007Goo00<007ooOol0FWoo00@007ooOol00:9oo`007Goo00<007ooOol0FWoo00@007oo
Ool00:9oo`007Goo00<007ooOol0FWoo00@007ooOol00:9oo`007Goo00<007ooOol0Fgoo00<007oo
0000XWoo000MOol00`00Oomoo`1KOol00`00Ool0002ROol001eoo`03001oogoo05]oo`03001oo`00
0:9oo`007Goo00<007ooOol0Fgoo00<007oo0000XWoo000MOol00`00Oomoo`1KOol00`00Ool0002R
Ool001eoo`03001oogoo05]oo`03001oo`000:9oo`007Goo00<007ooOol0Fgoo00<007oo0000XWoo
000MOol00`00Oomoo`1KOol00`00Ool0002ROol001eoo`03001oogoo05]oo`03001oo`000:9oo`00
7Goo00<007ooOol0Fgoo00<007oo0000XWoo000MOol00`00Oomoo`1KOol00`00Ool0002ROol001eo
o`03001oogoo05]oo`03001oo`000:9oo`007Goo00<007ooOol0Fgoo00<007oo0000XWoo000MOol0
0`00Oomoo`1KOol00`00Ool0002ROol001eoo`03001oogoo05]oo`03001oo`000:9oo`007Goo00<0
07ooOol0Fgoo00<007oo0000XWoo000:Ool20004Ool20004Ool20005Ool00`00Oomoo`1KOol00`00
Ool0002ROol000Uoo`04001oogoo0003Ool20003Ool01000Oomoo`0017oo00<007ooOol0Fgoo00<0
07oo0000XWoo0009Ool01000Oomoo`0027oo00@007ooOol000Aoo`8005aoo`03001oo`000:9oo`00
2Goo00@007ooOol000Uoo`8000Eoo`03001oogoo05]oo`03001oo`000:9oo`002Goo00@007ooOol0
00Qoo`04001oogoo0004Ool00`00Oomoo`1KOol00`00Ool0002ROol000Yoo`8000Yoo`8000Eoo`03
001oogoo05]oo`03001oo`000:9oo`007Goo00<007ooOol0Fgoo00<007oo0000XWoo000MOol00`00
Oomoo`1KOol00`00Ool0002ROol001eoo`03001oogoo05]oo`03001oo`000:9oo`007Goo00<007oo
Ool0Fgoo00<007oo0000XWoo000MOol00`00Oomoo`1KOol00`00Ool0002ROol001eoo`03001oogoo
05]oo`03001oo`000:9oo`007Goo00<007ooOol0Fgoo0P00Xgoo000MOol00`00Oomoo`1KOol2002S
Ool001eoo`03001oogoo05]oo`800:=oo`007Goo00<007ooOol0G7oo00<007ooOol0XGoo000MOol0
0`00Oomoo`1LOol00`00Oomoo`2QOol001eoo`03001oogoo05aoo`03001oogoo0:5oo`007Goo00<0
07ooOol0G7oo00<007ooOol0XGoo000MOol00`00Oomoo`1LOol00`00Oomoo`2QOol001eoo`03001o
ogoo05aoo`03001oogoo0:5oo`007Goo00<007ooOol0G7oo00<007ooOol0XGoo000MOol00`00Oomo
o`1LOol00`00Oomoo`2QOol001eoo`03001oogoo05aoo`03001oogoo0:5oo`007Goo00<007ooOol0
G7oo00<007ooOol0XGoo000MOol00`00Oomoo`1LOol00`00Oomoo`2QOol001eoo`03001oogoo05ao
o`03001oogoo0:5oo`005Goo0`001Goo00<007ooOol0G7oo00<007ooOol0XGoo000FOol00`00Oomo
o`04Ool00`00Oomoo`1LOol00`00Oomoo`2QOol001Ioo`03001oogoo00Aoo`8005eoo`03001oogoo
0:5oo`005Woo00<007ooOol0ogoo27oo000FOol00`00Oomoo`3oOol8Ool001Eoo`800?moo`Yoo`00
ogoo8Goo003oOolQOol00?moob5oo`003Woo10008Woo0`000goo0`001Goo0`002Goo0`000Woo1000
1goo0P000Woo0P000Woo10000Woo0`000goo0`000Woo10000goo1@0000=oo`0000000P000Woo1@00
1Woo0`0017oo0`000Woo1@0000Aoo`00001oo`80009oo`D006eoo`003goo00<007ooOol08goo00<0
07ooOol00goo00<007ooOol01Goo00<007ooOol01goo00D007ooOomoo`00009oo`03001oogoo00Qo
o`04001oo`000002Ool00`00Oomoo`03Ool01`00Oomoogoo001oo`0000=oo`04001oogoo0004Ool0
1`00Oomoogoo001oo`0000Eoo`05001oogooOol00007Ool01000Oomoo`000Woo00L007ooOomoo`00
Ool00002Ool01000Oomoo`000Woo00@007ooOol000=oo`03001oogoo06aoo`000goo1@0000Moo`00
Ool007oo001oo`040002Ool500000goo000000030002Ool30002Ool50002Ool500000goo00000002
0003Ool00`00Oomoo`05Ool00`00Oomoo`07Ool01@00Oomoogoo00000Woo00<007ooOol027oo0`00
0goo1@0000=oo`00Ool017oo00D007ooOomoo`00009oo`03001oogoo009oo`06001oogooOol007oo
1@0000=oo`00Ool00Woo00<007ooOol01goo0P000Woo00L007ooOomoo`00Ool00002Ool01000Oomo
o`000Woo00@007ooOol000=oo`03001oogoo06aoo`000goo00@007ooOol0009oo`07001oo`00Ool0
07oo00000goo00D007ooOomoo`0000Eoo`03001oogoo009oo`06001oogoo001oo`000Woo00@007oo
Ool000=oo`04001oo`00Ool30003Ool30003Ool01@00Ool007oo00001goo00D007ooOomoo`00009o
o`03001oogoo00Qoo`04001oogoo0002Ool01`00Oomoogoo001oo`0000=oo`03001oo`0000=oo`03
001oogoo008000=oo`07001oogooOol007oo00000goo00<007oo00000goo00<007ooOol01Goo0P00
17oo00L007ooOomoo`00Ool00002Ool01000Oomoo`000Woo00@007ooOol000=oo`03001oogoo06ao
o`000goo10000Woo00L007oo001oo`00Ool00003Ool01@00Oomoogoo00001Goo00<007ooOol00Woo
00<007ooOol00Woo00@007ooOol0009oo`06001oogooOol007oo1@000goo00<007ooOol00goo00D0
07oo001oo`0000Qoo`<0009oo`@000Qoo`04001oogoo0003Ool30003Ool40002Ool30002Ool20000
0goo00000002Ool40002Ool30003Ool40007Ool01000Oomoo`000goo0`0000Aoo`00001oo`800003
Ool0000000<000=oo`@006ioo`001Woo00X007ooOol007oo001oo`00Ool000=oo`05001oogooOol0
0005Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01000Oomoo`000Woo00H007ooOomoo`00Ool60000
0goo000000030002Ool5000>Ool00`00Oomoo`07Ool4000OOol00`00Oomoo`09Ool00`00Oomoo`06
Ool3000HOol00`00Oomoo`1/Ool000Aoo`<00003Ool0000000T000Aoo`03001oogoo009oo`8000=o
o`@00004Ool00000Ool20003Ool40002Ool3000MOol3000YOol2000:Ool2000ROol2001^Ool001Mo
o`03001oogoo00Qoo`03001oogoo00aoo`03001oogoo0>aoo`005Goo0`001Goo00<007ooOol00Woo
00<007ooOol02goo0P00kWoo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {946.587, -0.14072, 0.462505, 
  0.00748348}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-9.5 0.01 0 0.618034 [
[.3 -0.0125 -9 -9 ]
[.3 -0.0125 9 0 ]
[.5 -0.0125 -12 -9 ]
[.5 -0.0125 12 0 ]
[.7 -0.0125 -12 -9 ]
[.7 -0.0125 12 0 ]
[.9 -0.0125 -12 -9 ]
[.9 -0.0125 12 0 ]
[1.025 0 0 -6 ]
[1.025 0 58 6 ]
[.0875 .12361 -18 -4.5 ]
[.0875 .12361 0 4.5 ]
[.0875 .24721 -18 -4.5 ]
[.0875 .24721 0 4.5 ]
[.0875 .37082 -18 -4.5 ]
[.0875 .37082 0 4.5 ]
[.0875 .49443 -18 -4.5 ]
[.0875 .49443 0 4.5 ]
[.0875 .61803 -6 -4.5 ]
[.0875 .61803 0 4.5 ]
[.1 .64303 -29 0 ]
[.1 .64303 29 12 ]
[.5 .63053 -65 0 ]
[.5 .63053 65 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.3 0 m
.3 .00625 L
s
[(980)] .3 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1000)] .5 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(1020)] .7 -0.0125 0 1 Mshowa
.9 0 m
.9 .00625 L
s
[(1040)] .9 -0.0125 0 1 Mshowa
.125 Mabswid
.15 0 m
.15 .00375 L
s
.2 0 m
.2 .00375 L
s
.25 0 m
.25 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.45 0 m
.45 .00375 L
s
.55 0 m
.55 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.75 0 m
.75 .00375 L
s
.8 0 m
.8 .00375 L
s
.85 0 m
.85 .00375 L
s
.05 0 m
.05 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(frequency) show
117.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.1 .12361 m
.10625 .12361 L
s
[(0.2)] .0875 .12361 1 0 Mshowa
.1 .24721 m
.10625 .24721 L
s
[(0.4)] .0875 .24721 1 0 Mshowa
.1 .37082 m
.10625 .37082 L
s
[(0.6)] .0875 .37082 1 0 Mshowa
.1 .49443 m
.10625 .49443 L
s
[(0.8)] .0875 .49443 1 0 Mshowa
.1 .61803 m
.10625 .61803 L
s
[(1)] .0875 .61803 1 0 Mshowa
.125 Mabswid
.1 .0309 m
.10375 .0309 L
s
.1 .0618 m
.10375 .0618 L
s
.1 .09271 m
.10375 .09271 L
s
.1 .15451 m
.10375 .15451 L
s
.1 .18541 m
.10375 .18541 L
s
.1 .21631 m
.10375 .21631 L
s
.1 .27812 m
.10375 .27812 L
s
.1 .30902 m
.10375 .30902 L
s
.1 .33992 m
.10375 .33992 L
s
.1 .40172 m
.10375 .40172 L
s
.1 .43262 m
.10375 .43262 L
s
.1 .46353 m
.10375 .46353 L
s
.1 .52533 m
.10375 .52533 L
s
.1 .55623 m
.10375 .55623 L
s
.1 .58713 m
.10375 .58713 L
s
.25 Mabswid
.1 0 m
.1 .61803 L
s
gsave
.1 .64303 -90 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(amplitude) show
117.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.5 .63053 -126 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(FFT) show
87.000000 13.000000 moveto
(of) show
105.000000 13.000000 moveto
(Recorded) show
159.000000 13.000000 moveto
(Sound) show
189.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .00763 m
.01 .00138 L
.02 .00452 L
.03 .00342 L
.04 .00499 L
.05 .00282 L
.06 .00592 L
.07 .00083 L
.08 .00244 L
.09 .00188 L
.1 .00545 L
.11 .00103 L
.12 .00329 L
.13 .00792 L
.14 .00816 L
.15 .00265 L
.16 .0023 L
.17 .00408 L
.18 .0039 L
.19 .00353 L
.2 .00493 L
.21 .00262 L
.22 .00443 L
.23 .01701 L
.24 .00682 L
.25 .00119 L
.26 .00957 L
.27 .00755 L
.28 .00076 L
.29 .00478 L
.3 .0059 L
.31 .00331 L
.32 .00432 L
.33 .00231 L
.34 .00497 L
.35 .00285 L
.36 .0071 L
.37 .00751 L
.38 .01187 L
.39 .00995 L
.4 .00374 L
.41 .00792 L
.42 .00537 L
.43 .00565 L
.44 .01558 L
.45 .00143 L
.46 .01076 L
.47 .00836 L
.48 .00672 L
.49 .01269 L
Mistroke
.5 .01428 L
.51 .02185 L
.52 .0585 L
.53 .03375 L
.54 .61803 L
.55 .07057 L
.56 .0307 L
.57 .02124 L
.58 .01892 L
.59 .01046 L
.6 .00977 L
.61 .01132 L
.62 .01133 L
.63 .00856 L
.64 .00549 L
.65 .00581 L
.66 .01669 L
.67 .00608 L
.68 .01316 L
.69 .00359 L
.7 .00818 L
.71 .00744 L
.72 .00167 L
.73 .00939 L
.74 .00531 L
.75 .0054 L
.76 .00329 L
.77 .00962 L
.78 .00921 L
.79 .0024 L
.8 .01414 L
.81 .00205 L
.82 .00602 L
.83 .00969 L
.84 .01016 L
.85 .00886 L
.86 .00494 L
.87 .00465 L
.88 .01555 L
.89 .0067 L
.9 .00495 L
.91 .00197 L
.92 .00265 L
.93 .00346 L
.94 .00068 L
.95 .00045 L
.96 .01144 L
.97 .00192 L
.98 .00729 L
.99 .00489 L
Mistroke
1 .00084 L
Mfstroke
1 .00084 m
1 .00084 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
@7oo0`0017oo0P0017oo0P006Goo0`0017oo0P0017oo0P0017oo0P005Woo0`0017oo0P000goo1000
0goo0P005Woo0`0017oo0P0017oo0`000goo0P00CGoo0013Ool01000Oomoo`000Woo00@007ooOol0
009oo`03001oogoo01Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000Woo00@007oo
Ool001Ioo`03001oogoo009oo`04001oogoo0003Ool00`00Oomoo`02Ool01000Oomoo`005Woo00<0
07ooOol00Woo00@007ooOol000Aoo`05001oogooOol00002Ool00`00Oomoo`1:Ool0045oo`<0009o
o`04001oogoo0002Ool01000Oomoo`006Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo
0002Ool01000Oomoo`005Woo00<007ooOol00Woo00@007ooOol000Aoo`05001oogooOol00002Ool0
0`00Oomoo`0DOol00`00Oomoo`02Ool01000Oomoo`000Woo10000Woo00@007ooOol004aoo`00@7oo
00@007ooOol000=oo`8000=oo`04001oogoo000IOol00`00Oomoo`02Ool01000Oomoo`000Woo00@0
07ooOol0009oo`04001oogoo000FOol00`00Oomoo`02Ool01000Oomoo`001Goo00@007ooOol0009o
o`03001oogoo01Aoo`03001oogoo009oo`04001oogoo0002Ool00`00Ool00003Ool01000Oomoo`00
C7oo0010Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo000IOol00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol0009oo`04001oogoo000FOol00`00Oomoo`02Ool01000Oomoo`00
0Woo00@007ooOol0009oo`04001oogoo000FOol00`00Oomoo`02Ool01000Oomoo`000Woo00<007oo
00000goo00@007ooOol004aoo`00@Goo0P0017oo0P0017oo0P006Goo0P001Goo0P0017oo0P0017oo
0P005Woo0P001Goo0P0017oo0P0017oo0P005Woo0P001Goo0P0017oo0P0017oo0P00:Goo10005goo
0`001Woo003nOol00`00Oomoo`0GOol00`00Oomoo`05Ool00>Qoo`@0009oo`@000=oo`@0009oo`@0
0003Ool0000000<0009oo`@00004Ool00000Ool20002Ool30003Ool00`00Oomoo`04Ool00>Uoo`03
001oogoo00=oo`03001oogoo009oo`03001oogoo00=oo`07001oogooOol007oo00000Woo00@007oo
Ool000Eoo`04001oogoo0002Ool01@00Oomoogoo00000Woo00<007ooOol017oo0007OooI0009Ool0
0`00Oomoo`03Ool00`00Oomoo`02Ool500000goo001oo`02Ool00`00Ool00002Ool00`00Oomoo`05
00001Goo001oogoo00000Woo00<007ooOol00goo00<007oo00001Goo0008Ool<00000goo0000000<
0003OolA0005Ool30003OolC0008Ool30008Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomo
o`08Ool00`00Oomoo`07Ool00`00Oomoo`06Ool30003Ool30004Ool40004Ool200000goo001oo`02
0007Ool50004Ool;00000goo001oo`02Ool300000goo000000020009Ool00`00Oomoo`03Ool20003
Ool01`00Oomoogoo001oo`0000=oo`03001oo`00009oo`04001oogoo0003Ool00`00Ool00002Ool0
1000Oomoo`000goo00D007oo001oo`0000Eoo`001goo00<007ooOol02Woo00<007ooOol01Woo00<0
07ooOol00goo0`004Goo00D007ooOomoo`0000=oo`<000Ioo`03001oogoo00Yoo`@000=oo`04001o
ogooOol50003Ool20002Ool50002Ool00`00Oomoo`0BOol30003Ool70003Ool2000017oo001oogoo
10000goo1@000goo10000Woo00<007oo00000Woo1@0000=oo`0000000goo00L007ooOomoo`00Ool0
000;Ool00`00Ool00003Ool00`00Oomoo`0:Ool40002Ool200000goo00000002Ool30003Ool60000
0goo00000003Ool300000goo000000030003Ool600000goo00000004Ool001eoo`03001oogoo01Qo
o`03001oo`0001ioo`<000Uoo`03001oo`00009oo`8000Eoo`<0015oo`<000=oo`<000Moo`03001o
o`00009oo`03001oogoo01Moo`03001oogoo00Ioo`03001oogoo00Aoo`03001oo`0000moo`03001o
ogoo011oo`03001oogoo03Aoo`007Goo00<007ooOol06Goo00<007ooOol0:Woo00<007ooOol02goo
00<007ooOol037oo0P004Goo00<007ooOol0;7oo00<007ooOol08Goo0`00=7oo000MOol00`00Oomo
o`1EOol00`00Oomoo`0:Ool00`00Oomoo`2KOol001eoo`03001oogoo05Eoo`03001oogoo00Uoo`03
001oogoo09aoo`007Goo00<007ooOol0EGoo00<007ooOol027oo00<007ooOol0WGoo000MOol00`00
Oomoo`1FOol01000Oomoo`001Woo00<007ooOol0WGoo000MOol00`00Oomoo`1FOol01000Oomoo`00
1Woo00<007ooOol0WGoo000MOol00`00Oomoo`1FOol01000Ool000001Goo00<007ooOol0WWoo000M
Ool00`00Oomoo`1FOol01000Ool000001Goo00<007ooOol0WWoo000MOol00`00Oomoo`1GOol30005
Ool00`00Oomoo`2NOol001eoo`03001oogoo05Moo`03001oo`0000Eoo`03001oogoo09ioo`007Goo
00<007ooOol0FGoo00<007ooOol00goo00<007ooOol0WWoo000MOol00`00Oomoo`1IOol00`00Oomo
o`02Ool00`00Oomoo`2OOol001eoo`03001oogoo05Uoo`03001oogoo009oo`03001oogoo09moo`00
7Goo00<007ooOol0FGoo00<007ooOol00Woo00<007ooOol0Wgoo000MOol00`00Oomoo`1IOol00`00
Oomoo`02Ool00`00Oomoo`2OOol001eoo`03001oogoo05Uoo`03001oogoo009oo`03001oogoo09mo
o`007Goo00<007ooOol0FGoo00<007ooOol00Woo00<007ooOol0Wgoo000MOol00`00Oomoo`1IOol0
0`00Oomoo`02Ool00`00Oomoo`2OOol001eoo`03001oogoo05Uoo`03001oogoo009oo`03001oogoo
09moo`007Goo00<007ooOol0FGoo00<007ooOol00Woo00<007ooOol0Wgoo000MOol00`00Oomoo`1I
Ool00`00Oomoo`02Ool00`00Oomoo`2OOol000Yoo`8000Aoo`8000=oo`@000Aoo`03001oogoo05Uo
o`03001oogoo009oo`03001oogoo09moo`002Goo00@007ooOol000=oo`8000Aoo`03001oogoo00Ao
o`03001oogoo05Uoo`03001oogoo009oo`03001oogoo09moo`002Goo00@007ooOol000Yoo`03001o
ogoo00=oo`8005Yoo`03001oogoo009oo`03001oogoo09moo`002Goo00@007ooOol000]oo`03001o
ogoo009oo`03001oogoo05Uoo`03001oogoo009oo`03001oogoo09moo`002Goo00@007ooOol000Qo
o`04001oogoo0004Ool00`00Oomoo`1IOol00`00Oomoo`02Ool00`00Oomoo`2OOol000Yoo`8000Yo
o`8000Eoo`03001oogoo05Yoo`05001oogooOol0002QOol001eoo`03001oogoo05Yoo`05001oogoo
Ool0002QOol001eoo`03001oogoo05Yoo`05001oogooOol0002QOol001eoo`03001oogoo05Yoo`05
001oogooOol0002QOol001eoo`03001oogoo05Yoo`05001oogooOol0002QOol001eoo`03001oogoo
05Yoo`05001oogooOol0002QOol001eoo`03001oogoo05Yoo`05001oogooOol0002QOol001eoo`03
001oogoo05Yoo`05001oogooOol0002QOol001eoo`03001oogoo05Yoo`05001oogooOol0002QOol0
01eoo`03001oogoo05Yoo`05001oogooOol0002QOol001eoo`03001oogoo05Yoo`05001oogooOol0
002QOol001eoo`03001oogoo05Yoo`05001oogooOol0002QOol001eoo`03001oogoo05Yoo`05001o
ogooOol0002QOol001eoo`03001oogoo05Yoo`05001oogooOol0002QOol001eoo`03001oogoo05Yo
o`05001oogooOol0002QOol001eoo`03001oogoo05Yoo`05001oogooOol0002QOol001eoo`03001o
ogoo05Yoo`04001oogoo002ROol001eoo`03001oogoo05Yoo`04001oogoo002ROol001eoo`03001o
ogoo05Yoo`04001oogoo002ROol001eoo`03001oogoo05Yoo`04001oogoo002ROol001eoo`03001o
ogoo05Yoo`04001oogoo002ROol001eoo`03001oogoo05Yoo`04001oogoo002ROol000Yoo`8000Ao
o`8000Aoo`<000Aoo`03001oogoo05Yoo`04001oogoo002ROol000Uoo`04001oogoo0003Ool20005
Ool00`00Oomoo`03Ool00`00Oomoo`1JOol01000Oomoo`00XWoo0009Ool01000Oomoo`0027oo1000
17oo0P00Fgoo00@007ooOol00:9oo`002Goo00@007ooOol000Qoo`03001oo`0000Eoo`03001oogoo
05Yoo`04001oogoo002ROol000Uoo`04001oogoo0008Ool00`00Ool00005Ool00`00Oomoo`1JOol0
1000Oomoo`00XWoo000:Ool2000:Ool20005Ool00`00Oomoo`1JOol01000Oomoo`00XWoo000MOol0
0`00Oomoo`1JOol01000Oomoo`00XWoo000MOol00`00Oomoo`1JOol01000Oomoo`00XWoo000MOol0
0`00Oomoo`1JOol01000Oomoo`00XWoo000MOol00`00Oomoo`1JOol01000Oomoo`00XWoo000MOol0
0`00Oomoo`1JOol01000Oomoo`00XWoo000MOol00`00Oomoo`1JOol01000Oomoo`00XWoo000MOol0
0`00Oomoo`1JOol01000Oomoo`00XWoo000MOol00`00Oomoo`1JOol01000Oomoo`00XWoo000MOol0
0`00Oomoo`1JOol01000Oomoo`00XWoo000MOol00`00Oomoo`1JOol01000Oomoo`00XWoo000MOol0
0`00Oomoo`1JOol01000Oomoo`00XWoo000MOol00`00Oomoo`1JOol01000Oomoo`00XWoo000MOol0
0`00Oomoo`1JOol01000Oomoo`00XWoo000MOol00`00Oomoo`1JOol01000Oomoo`00XWoo000MOol0
0`00Oomoo`1KOol00`00Ool0002ROol001eoo`03001oogoo05]oo`03001oo`000:9oo`007Goo00<0
07ooOol0Fgoo00<007oo0000XWoo000MOol00`00Oomoo`1KOol00`00Ool0002ROol001eoo`03001o
ogoo05]oo`03001oo`000:9oo`007Goo00<007ooOol0Fgoo00<007oo0000XWoo000MOol00`00Oomo
o`1KOol00`00Ool0002ROol000Yoo`8000Aoo`8000Aoo`8000Eoo`03001oogoo05]oo`03001oo`00
0:9oo`002Goo00@007ooOol000=oo`8000=oo`04001oogoo0004Ool00`00Oomoo`1KOol00`00Ool0
002ROol000Uoo`04001oogoo0008Ool01000Oomoo`0017oo0P00G7oo00<007oo0000XWoo0009Ool0
1000Oomoo`0027oo0`001Goo00<007ooOol0Fgoo00<007oo0000XWoo0009Ool01000Oomoo`0027oo
00<007ooOol01Goo00<007ooOol0Fgoo00<007oo0000XWoo000:Ool2000:Ool30004Ool00`00Oomo
o`1KOol00`00Ool0002ROol001eoo`03001oogoo05]oo`03001oo`000:9oo`007Goo00<007ooOol0
Fgoo00<007oo0000XWoo000MOol00`00Oomoo`1KOol00`00Ool0002ROol001eoo`03001oogoo05]o
o`03001oo`000:9oo`007Goo00<007ooOol0Fgoo00<007oo0000XWoo000MOol00`00Oomoo`1KOol0
0`00Ool0002ROol001eoo`03001oogoo05]oo`03001oo`000:9oo`007Goo00<007ooOol0Fgoo00<0
07oo0000XWoo000MOol00`00Oomoo`1KOol00`00Ool0002ROol001eoo`03001oogoo05]oo`03001o
o`000:9oo`007Goo00<007ooOol0Fgoo00<007oo0000XWoo000MOol00`00Oomoo`1KOol00`00Ool0
002ROol001eoo`03001oogoo05]oo`03001oo`000:9oo`007Goo00<007ooOol0Fgoo00<007oo0000
XWoo000MOol00`00Oomoo`1KOol00`00Ool0002ROol001eoo`03001oogoo05]oo`03001oo`000:9o
o`007Goo00<007ooOol0Fgoo00<007oo0000XWoo000MOol00`00Oomoo`1KOol00`00Ool0002ROol0
01eoo`03001oogoo05]oo`03001oo`000:9oo`007Goo00<007ooOol0Fgoo00<007oo0000XWoo000:
Ool20004Ool20004Ool20005Ool00`00Oomoo`1KOol2002SOol000Uoo`04001oogoo0003Ool20003
Ool01000Oomoo`0017oo00<007ooOol0Fgoo0P00Xgoo0009Ool01000Oomoo`0027oo00@007ooOol0
00Aoo`8005aoo`800:=oo`002Goo00@007ooOol000Uoo`8000Eoo`03001oogoo05]oo`800:=oo`00
2Goo00@007ooOol000Qoo`04001oogoo0004Ool00`00Oomoo`1KOol2002SOol000Yoo`8000Yoo`80
00Eoo`03001oogoo05]oo`800:=oo`007Goo00<007ooOol0Fgoo0P00Xgoo000MOol00`00Oomoo`1K
Ool2002SOol001eoo`03001oogoo05]oo`800:=oo`007Goo00<007ooOol0G7oo00<007ooOol0XGoo
000MOol00`00Oomoo`1LOol00`00Oomoo`2QOol001eoo`03001oogoo05aoo`03001oogoo0:5oo`00
7Goo00<007ooOol0G7oo00<007ooOol0XGoo000MOol00`00Oomoo`1LOol00`00Oomoo`2QOol001eo
o`03001oogoo05aoo`03001oogoo0:5oo`007Goo00<007ooOol0G7oo00<007ooOol0XGoo000MOol0
0`00Oomoo`1LOol00`00Oomoo`2QOol001eoo`03001oogoo05aoo`03001oogoo0:5oo`007Goo00<0
07ooOol0G7oo00<007ooOol0XGoo000MOol00`00Oomoo`1LOol00`00Oomoo`2QOol001eoo`03001o
ogoo05aoo`03001oogoo0:5oo`007Goo00<007ooOol0G7oo00<007ooOol0XGoo000MOol00`00Oomo
o`1LOol00`00Oomoo`2QOol001eoo`03001oogoo05aoo`03001oogoo0:5oo`007Goo00<007ooOol0
G7oo00<007ooOol0XGoo000MOol00`00Oomoo`1LOol00`00Oomoo`2QOol001eoo`03001oogoo05ao
o`03001oogoo0:5oo`005Goo0`001Goo00<007ooOol0G7oo00<007ooOol0XGoo000FOol00`00Oomo
o`04Ool00`00Oomoo`1LOol00`00Oomoo`2QOol001Ioo`03001oogoo00Aoo`8005eoo`03001oogoo
0:5oo`005Woo00<007ooOol0ogoo27oo000FOol00`00Oomoo`3oOol8Ool001Eoo`800?moo`Yoo`00
ogoo8Goo003oOolQOol00?moob5oo`003Woo10008Woo0`000goo0`001Goo0`002Goo0`000Woo1000
1goo0P000Woo0P000Woo10000Woo0`000goo0`000Woo10000goo1@0000=oo`0000000P000Woo1@00
1Woo0`0017oo0`000Woo1@0000Aoo`00001oo`80009oo`D006eoo`003goo00<007ooOol08goo00<0
07ooOol00goo00<007ooOol01Goo00<007ooOol01goo00D007ooOomoo`00009oo`03001oogoo00Qo
o`04001oo`000002Ool00`00Oomoo`03Ool01`00Oomoogoo001oo`0000=oo`04001oogoo0004Ool0
1`00Oomoogoo001oo`0000Eoo`05001oogooOol00007Ool01000Oomoo`000Woo00L007ooOomoo`00
Ool00002Ool01000Oomoo`000Woo00@007ooOol000=oo`03001oogoo06aoo`000goo1@0000Moo`00
Ool007oo001oo`040002Ool500000goo000000030002Ool30002Ool50002Ool500000goo00000002
0003Ool00`00Oomoo`05Ool00`00Oomoo`07Ool01@00Oomoogoo00000Woo00<007ooOol027oo0`00
0goo1@0000=oo`00Ool017oo00D007ooOomoo`00009oo`03001oogoo009oo`06001oogooOol007oo
1@0000=oo`00Ool00Woo00<007ooOol01goo0P000Woo00L007ooOomoo`00Ool00002Ool01000Oomo
o`000Woo00@007ooOol000=oo`03001oogoo06aoo`000goo00@007ooOol0009oo`07001oo`00Ool0
07oo00000goo00D007ooOomoo`0000Eoo`03001oogoo009oo`06001oogoo001oo`000Woo00@007oo
Ool000=oo`04001oo`00Ool30003Ool30003Ool01@00Ool007oo00001goo00D007ooOomoo`00009o
o`03001oogoo00Qoo`04001oogoo0002Ool01`00Oomoogoo001oo`0000=oo`03001oo`0000=oo`03
001oogoo008000=oo`07001oogooOol007oo00000goo00<007oo00000goo00<007ooOol01Goo0P00
17oo00L007ooOomoo`00Ool00002Ool01000Oomoo`000Woo00@007ooOol000=oo`03001oogoo06ao
o`000goo10000Woo00L007oo001oo`00Ool00003Ool01@00Oomoogoo00001Goo00<007ooOol00Woo
00<007ooOol00Woo00@007ooOol0009oo`06001oogooOol007oo1@000goo00<007ooOol00goo00D0
07oo001oo`0000Qoo`<0009oo`@000Qoo`04001oogoo0003Ool30003Ool40002Ool30002Ool20000
0goo00000002Ool40002Ool30003Ool40007Ool01000Oomoo`000goo0`0000Aoo`00001oo`800003
Ool0000000<000=oo`@006ioo`001Woo00X007ooOol007oo001oo`00Ool000=oo`05001oogooOol0
0005Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01000Oomoo`000Woo00H007ooOomoo`00Ool60000
0goo000000030002Ool5000>Ool00`00Oomoo`07Ool4000OOol00`00Oomoo`09Ool00`00Oomoo`06
Ool3000HOol00`00Oomoo`1/Ool000Aoo`<00003Ool0000000T000Aoo`03001oogoo009oo`8000=o
o`@00004Ool00000Ool20003Ool40002Ool3000MOol3000YOol2000:Ool2000ROol2001^Ool001Mo
o`03001oogoo00Qoo`03001oogoo00aoo`03001oogoo0>aoo`005Goo0`001Goo00<007ooOol00Woo
00<007ooOol02goo0P00kWoo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {946.587, -0.14072, 0.462505, 
  0.00748348}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-9.5 0.01 0 0.618034 [
[.3 -0.0125 -9 -9 ]
[.3 -0.0125 9 0 ]
[.5 -0.0125 -12 -9 ]
[.5 -0.0125 12 0 ]
[.7 -0.0125 -12 -9 ]
[.7 -0.0125 12 0 ]
[.9 -0.0125 -12 -9 ]
[.9 -0.0125 12 0 ]
[1.025 0 0 -6 ]
[1.025 0 58 6 ]
[.0875 .12361 -18 -4.5 ]
[.0875 .12361 0 4.5 ]
[.0875 .24721 -18 -4.5 ]
[.0875 .24721 0 4.5 ]
[.0875 .37082 -18 -4.5 ]
[.0875 .37082 0 4.5 ]
[.0875 .49443 -18 -4.5 ]
[.0875 .49443 0 4.5 ]
[.0875 .61803 -6 -4.5 ]
[.0875 .61803 0 4.5 ]
[.1 .64303 -29 0 ]
[.1 .64303 29 12 ]
[.5 .63053 -65 0 ]
[.5 .63053 65 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.3 0 m
.3 .00625 L
s
[(980)] .3 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1000)] .5 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(1020)] .7 -0.0125 0 1 Mshowa
.9 0 m
.9 .00625 L
s
[(1040)] .9 -0.0125 0 1 Mshowa
.125 Mabswid
.15 0 m
.15 .00375 L
s
.2 0 m
.2 .00375 L
s
.25 0 m
.25 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.45 0 m
.45 .00375 L
s
.55 0 m
.55 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.75 0 m
.75 .00375 L
s
.8 0 m
.8 .00375 L
s
.85 0 m
.85 .00375 L
s
.05 0 m
.05 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(frequency) show
117.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.1 .12361 m
.10625 .12361 L
s
[(0.2)] .0875 .12361 1 0 Mshowa
.1 .24721 m
.10625 .24721 L
s
[(0.4)] .0875 .24721 1 0 Mshowa
.1 .37082 m
.10625 .37082 L
s
[(0.6)] .0875 .37082 1 0 Mshowa
.1 .49443 m
.10625 .49443 L
s
[(0.8)] .0875 .49443 1 0 Mshowa
.1 .61803 m
.10625 .61803 L
s
[(1)] .0875 .61803 1 0 Mshowa
.125 Mabswid
.1 .0309 m
.10375 .0309 L
s
.1 .0618 m
.10375 .0618 L
s
.1 .09271 m
.10375 .09271 L
s
.1 .15451 m
.10375 .15451 L
s
.1 .18541 m
.10375 .18541 L
s
.1 .21631 m
.10375 .21631 L
s
.1 .27812 m
.10375 .27812 L
s
.1 .30902 m
.10375 .30902 L
s
.1 .33992 m
.10375 .33992 L
s
.1 .40172 m
.10375 .40172 L
s
.1 .43262 m
.10375 .43262 L
s
.1 .46353 m
.10375 .46353 L
s
.1 .52533 m
.10375 .52533 L
s
.1 .55623 m
.10375 .55623 L
s
.1 .58713 m
.10375 .58713 L
s
.25 Mabswid
.1 0 m
.1 .61803 L
s
gsave
.1 .64303 -90 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(amplitude) show
117.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.5 .63053 -126 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(FFT) show
87.000000 13.000000 moveto
(of) show
105.000000 13.000000 moveto
(Recorded) show
159.000000 13.000000 moveto
(Sound) show
189.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .0133 m
.01 .00613 L
.02 .0152 L
.03 .0021 L
.04 .01328 L
.05 .00213 L
.06 .00821 L
.07 .01022 L
.08 .02138 L
.09 .00655 L
.1 .00715 L
.11 .00601 L
.12 .0093 L
.13 .01321 L
.14 .00266 L
.15 .00546 L
.16 .00377 L
.17 .01857 L
.18 .01365 L
.19 .01427 L
.2 .0062 L
.21 .00702 L
.22 .01107 L
.23 .01695 L
.24 .01151 L
.25 .00432 L
.26 .00771 L
.27 .02204 L
.28 .01299 L
.29 .00971 L
.3 .00847 L
.31 .01276 L
.32 .02056 L
.33 .01423 L
.34 .01327 L
.35 .01026 L
.36 .01252 L
.37 .00327 L
.38 .01118 L
.39 .01285 L
.4 .01366 L
.41 .01993 L
.42 .02275 L
.43 .01422 L
.44 .02634 L
.45 .01593 L
.46 .01655 L
.47 .01847 L
.48 .03169 L
.49 .04697 L
Mistroke
.5 .05208 L
.51 .07462 L
.52 .17467 L
.53 .21274 L
.54 .61803 L
.55 .11455 L
.56 .06792 L
.57 .05947 L
.58 .03353 L
.59 .03226 L
.6 .01866 L
.61 .0281 L
.62 .01843 L
.63 .01892 L
.64 .01602 L
.65 .01014 L
.66 .01205 L
.67 .00971 L
.68 .01758 L
.69 .00747 L
.7 .01809 L
.71 .00029 L
.72 .00751 L
.73 .01189 L
.74 .00589 L
.75 .00991 L
.76 .02945 L
.77 .00849 L
.78 .01411 L
.79 .00803 L
.8 .01961 L
.81 .01545 L
.82 .00709 L
.83 .00131 L
.84 .01446 L
.85 .00678 L
.86 .00584 L
.87 .01378 L
.88 .01236 L
.89 .00723 L
.9 .01254 L
.91 .00758 L
.92 .01269 L
.93 .00893 L
.94 .01311 L
.95 .02533 L
.96 .00756 L
.97 .00694 L
.98 .00492 L
.99 .00456 L
Mistroke
1 .01259 L
Mfstroke
1 .01259 m
1 .01259 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
@7oo0`0017oo0P0017oo0P006Goo0`0017oo0P0017oo0P0017oo0P005Woo0`0017oo0P000goo1000
0goo0P005Woo0`0017oo0P0017oo0`000goo0P00CGoo0013Ool01000Oomoo`000Woo00@007ooOol0
009oo`03001oogoo01Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000Woo00@007oo
Ool001Ioo`03001oogoo009oo`04001oogoo0003Ool00`00Oomoo`02Ool01000Oomoo`005Woo00<0
07ooOol00Woo00@007ooOol000Aoo`05001oogooOol00002Ool00`00Oomoo`1:Ool0045oo`<0009o
o`04001oogoo0002Ool01000Oomoo`006Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo
0002Ool01000Oomoo`005Woo00<007ooOol00Woo00@007ooOol000Aoo`05001oogooOol00002Ool0
0`00Oomoo`0DOol00`00Oomoo`02Ool01000Oomoo`000Woo10000Woo00@007ooOol004aoo`00@7oo
00@007ooOol000=oo`8000=oo`04001oogoo000IOol00`00Oomoo`02Ool01000Oomoo`000Woo00@0
07ooOol0009oo`04001oogoo000FOol00`00Oomoo`02Ool01000Oomoo`001Goo00@007ooOol0009o
o`03001oogoo01Aoo`03001oogoo009oo`04001oogoo0002Ool00`00Ool00003Ool01000Oomoo`00
C7oo0010Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo000IOol00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol0009oo`04001oogoo000FOol00`00Oomoo`02Ool01000Oomoo`00
0Woo00@007ooOol0009oo`04001oogoo000FOol00`00Oomoo`02Ool01000Oomoo`000Woo00<007oo
00000goo00@007ooOol004aoo`00@Goo0P0017oo0P0017oo0P006Goo0P001Goo0P0017oo0P0017oo
0P005Woo0P001Goo0P0017oo0P0017oo0P005Woo0P001Goo0P0017oo0P0017oo0P00:Goo10005goo
0`001Woo003nOol00`00Oomoo`0GOol00`00Oomoo`05Ool00>Qoo`@0009oo`@000=oo`@0009oo`@0
0003Ool0000000<0009oo`@00004Ool00000Ool20002Ool30003Ool00`00Oomoo`04Ool00>Uoo`03
001oogoo00=oo`03001oogoo009oo`03001oogoo00=oo`07001oogooOol007oo00000Woo00@007oo
Ool000Eoo`04001oogoo0002Ool01@00Oomoogoo00000Woo00<007ooOol017oo0007OooI0009Ool0
0`00Oomoo`03Ool00`00Oomoo`02Ool500000goo001oo`02Ool00`00Ool00002Ool00`00Oomoo`05
00001Goo001oogoo00000Woo00<007ooOol00goo00<007oo00001Goo000=Ool20003Ool20009Ool0
0`00Oomoo`05Ool50008Ool00`00Oomoo`08Ool20009Ool00`00Oomoo`08Ool01@00Oomoogoo0000
1Goo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol0
1goo00<007ooOol027oo00D007oo001oo`0000Ioo`03001oogoo00Qoo`03001oogoo009oo`<000=o
o`03001oogoo00Moo`03001oogoo00Qoo`03001oogoo00=oo`@000]oo`03001oogoo00=oo`8000=o
o`07001oogooOol007oo00000goo00<007oo00000Woo00@007ooOol000=oo`03001oo`00009oo`04
001oogoo0003Ool01@00Ool007oo00001Goo0008Ool20003Ool01@00Ool007oo00000Woo0P0017oo
2@0000Eoo`00Oomoo`00009oo`03001oogoo00Aoo`D000Ioo`04001oogoo0005Ool5000<Ool00`00
Ool0000JOol00`00Oomoo`0QOol20003Ool01000Ool000000goo0P0000Aoo`00000000Aoo`<00003
Ool0000000Eoo`06001oogooOol007oo1@000goo100000Eoo`00000007oo00<000Aoo`@000Aoo`03
001oogoo00Moo`@0009oo`800003Ool00000009oo`<000=oo`H00003Ool0000000=oo`<00003Ool0
000000<000=oo`H00003Ool0000000Aoo`001goo00H007ooOol007oo0003Ool00`00Oomoo`03Ool0
1@00Oomoogoo00000Woo00<007ooOol00goo00<007ooOol01Goo00<007oo00000`001Goo0`0000=o
o`0000000goo00@007ooOomoo`8000Eoo`04001oogooOol80003Ool60005Ool00`00Oomoo`0[Ool5
0002Ool01`00Ool007oo001oo`0000Eoo`05001oogooOol00003Ool01P00Oomoo`00Ool000Aoo`03
001oogoo00=oo`03001oogoo00=oo`<000=oo`8000=oo`05001oogooOol00003Ool00`00Oomoo`06
Ool00`00Oomoo`07Ool00`00Oomoo`0dOol000]oo`03001oogoo00Uoo`03001oo`0000=oo`03001o
ogoo00aoo`03001oogoo00Yoo`03001oogoo00Aoo`03001oo`0000Qoo`03001oo`00015oo`04001o
ogooOol20003Ool6000KOol01000Oomoogoo1@0027oo00D007ooOomoo`0000Yoo`04001oogoo0006
Ool01000Ool000006goo00@007ooOol001=oo`<003Aoo`0067oo00<007ooOol00Woo00<007ooOol0
8Goo00<007ooOol027oo00<007ooOol04Goo0`000Woo00<007oo00001Goo00<007ooOol067oo00D0
07oo001oo`0001eoo`03001oo`0000Moo`03001oogoo01aoo`03001oo`0004Yoo`007Goo00<007oo
Ool0AWoo00<007ooOol01Goo00<007ooOol05Woo00D007ooOomoo`0001ioo`03001oo`0002Moo`03
001oogoo04Uoo`007Goo00<007ooOol0Cgoo00<007ooOol04goo0P0097oo00<007ooOol0LWoo000M
Ool00`00Oomoo`1?Ool00`00Oomoo`0BOol00`00Oomoo`2IOol001eoo`03001oogoo051oo`03001o
ogoo015oo`03001oogoo09Uoo`007Goo00<007ooOol0D7oo00<007ooOol047oo00<007ooOol0VWoo
000MOol00`00Oomoo`1AOol2000@Ool00`00Oomoo`2JOol001eoo`03001oogoo05=oo`03001oogoo
00eoo`03001oogoo09Yoo`007Goo00<007ooOol0Dgoo00<007ooOol037oo00<007ooOol0Vgoo000M
Ool00`00Oomoo`1DOol00`00Oomoo`0:Ool00`00Oomoo`2LOol001eoo`03001oogoo05Aoo`03001o
ogoo00Uoo`03001oogoo09eoo`007Goo00<007ooOol0EGoo00<007ooOol027oo00<007ooOol0WGoo
000MOol00`00Oomoo`1EOol00`00Oomoo`08Ool00`00Oomoo`2MOol001eoo`03001oogoo05Eoo`03
001oogoo00Moo`03001oogoo09ioo`007Goo00<007ooOol0EGoo00<007ooOol01goo00<007ooOol0
WWoo000MOol00`00Oomoo`1EOol00`00Oomoo`07Ool00`00Oomoo`2NOol001eoo`03001oogoo05Eo
o`03001oogoo00Moo`03001oogoo09ioo`007Goo00<007ooOol0EWoo00<007ooOol01Woo00<007oo
Ool0WWoo000MOol00`00Oomoo`1FOol00`00Oomoo`05Ool00`00Oomoo`2OOol001eoo`03001oogoo
05Ioo`03001oogoo00Eoo`03001oogoo09moo`002Woo0P0017oo0P000goo100017oo00<007ooOol0
EWoo00<007ooOol01Goo00<007ooOol0Wgoo0009Ool01000Oomoo`000goo0P0017oo00<007ooOol0
17oo00<007ooOol0EWoo00<007ooOol01Goo00<007ooOol0Wgoo0009Ool01000Oomoo`002Woo00<0
07ooOol00goo0P00Egoo00<007ooOol01Goo00<007ooOol0Wgoo0009Ool01000Oomoo`002goo00<0
07ooOol00Woo00<007ooOol0EWoo00<007ooOol01Goo00<007ooOol0Wgoo0009Ool01000Oomoo`00
27oo00@007ooOol000Aoo`03001oogoo05Ioo`03001oogoo00Eoo`03001oogoo09moo`002Woo0P00
2Woo0P001Goo00<007ooOol0EWoo00<007ooOol01Goo00<007ooOol0Wgoo000MOol00`00Oomoo`1F
Ool00`00Oomoo`05Ool00`00Oomoo`2OOol001eoo`03001oogoo05Ioo`03001oogoo00Eoo`03001o
ogoo09moo`007Goo00<007ooOol0Egoo00<007ooOol017oo00<007ooOol0Wgoo000MOol00`00Oomo
o`1GOol00`00Oomoo`04Ool00`00Oomoo`2OOol001eoo`03001oogoo05Moo`03001oogoo00Aoo`03
001oogoo09moo`007Goo00<007ooOol0Egoo00<007ooOol017oo00<007ooOol0Wgoo000MOol00`00
Oomoo`1GOol00`00Oomoo`04Ool00`00Oomoo`2OOol001eoo`03001oogoo05Moo`03001oogoo00Ao
o`03001oogoo09moo`007Goo00<007ooOol0Egoo00<007ooOol017oo00<007ooOol0Wgoo000MOol0
0`00Oomoo`1GOol00`00Oomoo`04Ool00`00Oomoo`2OOol001eoo`03001oogoo05Qoo`03001oogoo
00=oo`03001oogoo09moo`007Goo00<007ooOol0F7oo00<007ooOol00goo00<007ooOol0Wgoo000M
Ool00`00Oomoo`1HOol00`00Oomoo`03Ool00`00Oomoo`2OOol001eoo`03001oogoo05Qoo`03001o
ogoo00=oo`03001oogoo09moo`007Goo00<007ooOol0FGoo00<007ooOol00Woo00<007ooOol0Wgoo
000MOol00`00Oomoo`1IOol00`00Oomoo`02Ool00`00Oomoo`2OOol001eoo`03001oogoo05Uoo`03
001oogoo009oo`03001oogoo09moo`007Goo00<007ooOol0FGoo00<007ooOol00Woo00<007ooOol0
Wgoo000MOol00`00Oomoo`1IOol00`00Oomoo`02Ool00`00Oomoo`2OOol001eoo`03001oogoo05Uo
o`03001oogoo009oo`03001oogoo09moo`007Goo00<007ooOol0FGoo00<007ooOol00Woo00<007oo
Ool0Wgoo000:Ool20004Ool20004Ool30004Ool00`00Oomoo`1IOol00`00Oomoo`02Ool00`00Oomo
o`2OOol000Uoo`04001oogoo0003Ool20005Ool00`00Oomoo`03Ool00`00Oomoo`1IOol01@00Oomo
ogoo0000XWoo0009Ool01000Oomoo`0027oo100017oo0P00FWoo00D007ooOomoo`000:9oo`002Goo
00@007ooOol000Qoo`03001oo`0000Eoo`03001oogoo05Uoo`05001oogooOol0002ROol000Uoo`04
001oogoo0008Ool00`00Ool00005Ool00`00Oomoo`1IOol01@00Oomoogoo0000XWoo000:Ool2000:
Ool20005Ool00`00Oomoo`1IOol01@00Oomoogoo0000XWoo000MOol00`00Oomoo`1IOol01@00Oomo
ogoo0000XWoo000MOol00`00Oomoo`1IOol01@00Oomoogoo0000XWoo000MOol00`00Oomoo`1IOol0
1@00Oomoogoo0000XWoo000MOol00`00Oomoo`1IOol01@00Oomoogoo0000XWoo000MOol00`00Oomo
o`1JOol01000Oomoo`00XWoo000MOol00`00Oomoo`1JOol01000Oomoo`00XWoo000MOol00`00Oomo
o`1JOol01000Oomoo`00XWoo000MOol00`00Oomoo`1JOol01000Oomoo`00XWoo000MOol00`00Oomo
o`1JOol01000Oomoo`00XWoo000MOol00`00Oomoo`1JOol01000Oomoo`00XWoo000MOol00`00Oomo
o`1JOol01000Oomoo`00XWoo000MOol00`00Oomoo`1JOol01000Oomoo`00XWoo000MOol00`00Oomo
o`1JOol01000Oomoo`00XWoo000MOol00`00Oomoo`1JOol01000Oomoo`00XWoo000MOol00`00Oomo
o`1JOol01000Oomoo`00XWoo000MOol00`00Oomoo`1JOol01000Oomoo`00XWoo000MOol00`00Oomo
o`1JOol01000Oomoo`00XWoo000MOol00`00Oomoo`1JOol01000Oomoo`00XWoo000MOol00`00Oomo
o`1JOol01000Oomoo`00XWoo000MOol00`00Oomoo`1JOol01000Oomoo`00XWoo000MOol00`00Oomo
o`1JOol01000Oomoo`00XWoo000:Ool20004Ool20004Ool20005Ool00`00Oomoo`1JOol01000Oomo
o`00XWoo0009Ool01000Oomoo`000goo0P000goo00@007ooOol000Aoo`03001oogoo05Yoo`04001o
ogoo002ROol000Uoo`04001oogoo0008Ool01000Oomoo`0017oo0P00Fgoo00@007ooOol00:9oo`00
2Goo00@007ooOol000Qoo`<000Eoo`03001oogoo05Yoo`04001oogoo002ROol000Uoo`04001oogoo
0008Ool00`00Oomoo`05Ool00`00Oomoo`1JOol01000Oomoo`00XWoo000:Ool2000:Ool30004Ool0
0`00Oomoo`1JOol01000Oomoo`00XWoo000MOol00`00Oomoo`1JOol01000Oomoo`00XWoo000MOol0
0`00Oomoo`1JOol01000Oomoo`00XWoo000MOol00`00Oomoo`1JOol01000Oomoo`00XWoo000MOol0
0`00Oomoo`1JOol01000Oomoo`00XWoo000MOol00`00Oomoo`1JOol01000Oomoo`00XWoo000MOol0
0`00Oomoo`1JOol01000Oomoo`00XWoo000MOol00`00Oomoo`1KOol00`00Ool0002ROol001eoo`03
001oogoo05]oo`03001oo`000:9oo`007Goo00<007ooOol0Fgoo00<007oo0000XWoo000MOol00`00
Oomoo`1KOol00`00Ool0002ROol001eoo`03001oogoo05]oo`03001oo`000:9oo`007Goo00<007oo
Ool0Fgoo00<007oo0000XWoo000MOol00`00Oomoo`1KOol00`00Ool0002ROol001eoo`03001oogoo
05]oo`03001oo`000:9oo`007Goo00<007ooOol0Fgoo00<007oo0000XWoo000MOol00`00Oomoo`1K
Ool00`00Ool0002ROol001eoo`03001oogoo05]oo`03001oo`000:9oo`007Goo00<007ooOol0Fgoo
00<007oo0000XWoo000MOol00`00Oomoo`1KOol00`00Ool0002ROol001eoo`03001oogoo05]oo`03
001oo`000:9oo`002Woo0P0017oo0P0017oo0P001Goo00<007ooOol0Fgoo00<007oo0000XWoo0009
Ool01000Oomoo`000goo0P000goo00@007ooOol000Aoo`03001oogoo05]oo`03001oo`000:9oo`00
2Goo00@007ooOol000Qoo`04001oogoo0004Ool2001LOol00`00Ool0002ROol000Uoo`04001oogoo
0009Ool20005Ool00`00Oomoo`1KOol2002SOol000Uoo`04001oogoo0008Ool01000Oomoo`0017oo
00<007ooOol0Fgoo0P00Xgoo000:Ool2000:Ool20005Ool00`00Oomoo`1KOol2002SOol001eoo`03
001oogoo05]oo`800:=oo`007Goo00<007ooOol0Fgoo0P00Xgoo000MOol00`00Oomoo`1KOol2002S
Ool001eoo`03001oogoo05]oo`800:=oo`007Goo00<007ooOol0Fgoo0P00Xgoo000MOol00`00Oomo
o`1KOol2002SOol001eoo`03001oogoo05]oo`800:=oo`007Goo00<007ooOol0Fgoo0P00Xgoo000M
Ool00`00Oomoo`1KOol2002SOol001eoo`03001oogoo05aoo`03001oogoo0:5oo`007Goo00<007oo
Ool0G7oo00<007ooOol0XGoo000MOol00`00Oomoo`1LOol00`00Oomoo`2QOol001eoo`03001oogoo
05aoo`03001oogoo0:5oo`007Goo00<007ooOol0G7oo00<007ooOol0XGoo000MOol00`00Oomoo`1L
Ool00`00Oomoo`2QOol001eoo`03001oogoo05aoo`03001oogoo0:5oo`007Goo00<007ooOol0G7oo
00<007ooOol0XGoo000MOol00`00Oomoo`1LOol00`00Oomoo`2QOol001eoo`03001oogoo05aoo`03
001oogoo0:5oo`007Goo00<007ooOol0G7oo00<007ooOol0XGoo000MOol00`00Oomoo`1LOol00`00
Oomoo`2QOol001Eoo`<000Eoo`03001oogoo05aoo`03001oogoo0:5oo`005Woo00<007ooOol017oo
00<007ooOol0G7oo00<007ooOol0XGoo000FOol00`00Oomoo`04Ool2001MOol00`00Oomoo`2QOol0
01Ioo`03001oogoo0?moo`Qoo`005Woo00<007ooOol0ogoo27oo000EOol2003oOol:Ool00?moob5o
o`00ogoo8Goo003oOolQOol000ioo`@0029oo`<000=oo`<000Eoo`<000Uoo`<0009oo`@000Moo`80
009oo`80009oo`@0009oo`<000=oo`<0009oo`@000=oo`D00003Ool000000080009oo`D000Ioo`<0
00Aoo`<0009oo`D00004Ool00000Ool20002Ool5001]Ool000moo`03001oogoo02=oo`03001oogoo
00=oo`03001oogoo00Eoo`03001oogoo00Moo`05001oogooOol00002Ool00`00Oomoo`08Ool01000
Ool000000Woo00<007ooOol00goo00L007ooOomoo`00Ool00003Ool01000Oomoo`0017oo00L007oo
Oomoo`00Ool00005Ool01@00Oomoogoo00001goo00@007ooOol0009oo`07001oogooOol007oo0000
0Woo00@007ooOol0009oo`04001oogoo0003Ool00`00Oomoo`1/Ool000=oo`D00007Ool007oo001o
o`00Ool010000Woo1@0000=oo`0000000`000Woo0`000Woo1@000Woo1@0000=oo`0000000P000goo
00<007ooOol01Goo00<007ooOol01goo00D007ooOomoo`00009oo`03001oogoo00Qoo`<000=oo`D0
0003Ool007oo00Aoo`05001oogooOol00002Ool00`00Oomoo`02Ool01P00Oomoogoo001oo`D00003
Ool007oo009oo`03001oogoo00Moo`80009oo`07001oogooOol007oo00000Woo00@007ooOol0009o
o`04001oogoo0003Ool00`00Oomoo`1/Ool000=oo`04001oogoo0002Ool01`00Ool007oo001oo`00
00=oo`05001oogooOol00005Ool00`00Oomoo`02Ool01P00Oomoo`00Ool0009oo`04001oogoo0003
Ool01000Ool007oo0`000goo0`000goo00D007oo001oo`0000Moo`05001oogooOol00002Ool00`00
Oomoo`08Ool01000Oomoo`000Woo00L007ooOomoo`00Ool00003Ool00`00Ool00003Ool00`00Oomo
o`020003Ool01`00Oomoogoo001oo`0000=oo`03001oo`0000=oo`03001oogoo00Eoo`8000Aoo`07
001oogooOol007oo00000Woo00@007ooOol0009oo`04001oogoo0003Ool00`00Oomoo`1/Ool000=o
o`@0009oo`07001oo`00Ool007oo00000goo00D007ooOomoo`0000Eoo`03001oogoo009oo`03001o
ogoo009oo`04001oogoo0002Ool01P00Oomoogoo001oo`D000=oo`03001oogoo00=oo`05001oo`00
Ool00008Ool30002Ool40008Ool01000Oomoo`000goo0`000goo10000Woo0`000Woo0P0000=oo`00
00000Woo10000Woo0`000goo10001goo00@007ooOol000=oo`<00004Ool00000Ool200000goo0000
00030003Ool4001^Ool000Ioo`0:001oogoo001oo`00Ool007oo0003Ool01@00Oomoogoo00001Goo
00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`06001oogooOol007oo1P0000=oo`00
00000`000Woo1@003Woo00<007ooOol01goo10007goo00<007ooOol02Goo00<007ooOol01Woo0`00
67oo00<007ooOol0K7oo0004Ool300000goo000000090004Ool00`00Oomoo`02Ool20003Ool40000
17oo000007oo0P000goo10000Woo0`007Goo0`00:Goo0P002Woo0P008Woo0P00KWoo000GOol00`00
Oomoo`08Ool00`00Oomoo`0<Ool00`00Oomoo`3/Ool001Eoo`<000Eoo`03001oogoo009oo`03001o
ogoo00]oo`800>ioo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5o
o`00ogoo8Goo003oOolQOol00?moob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {946.587, -0.14072, 0.462505, 
  0.00748348}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-9.5 0.01 0 0.618034 [
[.3 -0.0125 -9 -9 ]
[.3 -0.0125 9 0 ]
[.5 -0.0125 -12 -9 ]
[.5 -0.0125 12 0 ]
[.7 -0.0125 -12 -9 ]
[.7 -0.0125 12 0 ]
[.9 -0.0125 -12 -9 ]
[.9 -0.0125 12 0 ]
[1.025 0 0 -6 ]
[1.025 0 58 6 ]
[.0875 .12361 -18 -4.5 ]
[.0875 .12361 0 4.5 ]
[.0875 .24721 -18 -4.5 ]
[.0875 .24721 0 4.5 ]
[.0875 .37082 -18 -4.5 ]
[.0875 .37082 0 4.5 ]
[.0875 .49443 -18 -4.5 ]
[.0875 .49443 0 4.5 ]
[.0875 .61803 -6 -4.5 ]
[.0875 .61803 0 4.5 ]
[.1 .64303 -29 0 ]
[.1 .64303 29 12 ]
[.5 .63053 -65 0 ]
[.5 .63053 65 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.3 0 m
.3 .00625 L
s
[(980)] .3 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1000)] .5 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(1020)] .7 -0.0125 0 1 Mshowa
.9 0 m
.9 .00625 L
s
[(1040)] .9 -0.0125 0 1 Mshowa
.125 Mabswid
.15 0 m
.15 .00375 L
s
.2 0 m
.2 .00375 L
s
.25 0 m
.25 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.45 0 m
.45 .00375 L
s
.55 0 m
.55 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.75 0 m
.75 .00375 L
s
.8 0 m
.8 .00375 L
s
.85 0 m
.85 .00375 L
s
.05 0 m
.05 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(frequency) show
117.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.1 .12361 m
.10625 .12361 L
s
[(0.2)] .0875 .12361 1 0 Mshowa
.1 .24721 m
.10625 .24721 L
s
[(0.4)] .0875 .24721 1 0 Mshowa
.1 .37082 m
.10625 .37082 L
s
[(0.6)] .0875 .37082 1 0 Mshowa
.1 .49443 m
.10625 .49443 L
s
[(0.8)] .0875 .49443 1 0 Mshowa
.1 .61803 m
.10625 .61803 L
s
[(1)] .0875 .61803 1 0 Mshowa
.125 Mabswid
.1 .0309 m
.10375 .0309 L
s
.1 .0618 m
.10375 .0618 L
s
.1 .09271 m
.10375 .09271 L
s
.1 .15451 m
.10375 .15451 L
s
.1 .18541 m
.10375 .18541 L
s
.1 .21631 m
.10375 .21631 L
s
.1 .27812 m
.10375 .27812 L
s
.1 .30902 m
.10375 .30902 L
s
.1 .33992 m
.10375 .33992 L
s
.1 .40172 m
.10375 .40172 L
s
.1 .43262 m
.10375 .43262 L
s
.1 .46353 m
.10375 .46353 L
s
.1 .52533 m
.10375 .52533 L
s
.1 .55623 m
.10375 .55623 L
s
.1 .58713 m
.10375 .58713 L
s
.25 Mabswid
.1 0 m
.1 .61803 L
s
gsave
.1 .64303 -90 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(amplitude) show
117.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.5 .63053 -126 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(FFT) show
87.000000 13.000000 moveto
(of) show
105.000000 13.000000 moveto
(Recorded) show
159.000000 13.000000 moveto
(Sound) show
189.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .01724 m
.01 .02564 L
.02 .01536 L
.03 .01058 L
.04 .01852 L
.05 .04417 L
.06 .00746 L
.07 .019 L
.08 .03147 L
.09 .03683 L
.1 .00938 L
.11 .02165 L
.12 .00821 L
.13 .0089 L
.14 .01372 L
.15 .01262 L
.16 .02877 L
.17 .02619 L
.18 .01482 L
.19 .02189 L
.2 .00508 L
.21 .00855 L
.22 .02098 L
.23 .0209 L
.24 .0118 L
.25 .01347 L
.26 .01053 L
.27 .02703 L
.28 .02927 L
.29 .04244 L
.3 .01513 L
.31 .00998 L
.32 .00757 L
.33 .02248 L
.34 .03263 L
.35 .02699 L
.36 .0227 L
.37 .00711 L
.38 .01418 L
.39 .01088 L
.4 .01026 L
.41 .0052 L
.42 .03826 L
.43 .013 L
.44 .03751 L
.45 .02259 L
.46 .02968 L
.47 .01913 L
.48 .0279 L
.49 .04408 L
Mistroke
.5 .02633 L
.51 .09089 L
.52 .13723 L
.53 .61803 L
.54 .56073 L
.55 .10176 L
.56 .06487 L
.57 .05749 L
.58 .03605 L
.59 .0266 L
.6 .01695 L
.61 .01876 L
.62 .0138 L
.63 .03058 L
.64 .00348 L
.65 .00491 L
.66 .0151 L
.67 .01118 L
.68 .00999 L
.69 .0248 L
.7 .01692 L
.71 .02348 L
.72 .01076 L
.73 .03213 L
.74 .01892 L
.75 .02124 L
.76 .00859 L
.77 .0206 L
.78 .01955 L
.79 .03846 L
.8 .03585 L
.81 .00167 L
.82 .00526 L
.83 .03901 L
.84 .0277 L
.85 .02234 L
.86 .03895 L
.87 .04453 L
.88 .03542 L
.89 .02762 L
.9 .01174 L
.91 .01996 L
.92 .00846 L
.93 .00773 L
.94 .0286 L
.95 .01671 L
.96 .01694 L
.97 .00214 L
.98 .02629 L
.99 .0662 L
Mistroke
1 .03028 L
Mfstroke
1 .03028 m
1 .03028 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
@7oo0`0017oo0P0017oo0P006Goo0`0017oo0P0017oo0P0017oo0P005Woo0`0017oo0P000goo1000
0goo0P005Woo0`0017oo0P0017oo0`000goo0P00CGoo0013Ool01000Oomoo`000Woo00@007ooOol0
009oo`03001oogoo01Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000Woo00@007oo
Ool001Ioo`03001oogoo009oo`04001oogoo0003Ool00`00Oomoo`02Ool01000Oomoo`005Woo00<0
07ooOol00Woo00@007ooOol000Aoo`05001oogooOol00002Ool00`00Oomoo`1:Ool0045oo`<0009o
o`04001oogoo0002Ool01000Oomoo`006Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo
0002Ool01000Oomoo`005Woo00<007ooOol00Woo00@007ooOol000Aoo`05001oogooOol00002Ool0
0`00Oomoo`0DOol00`00Oomoo`02Ool01000Oomoo`000Woo10000Woo00@007ooOol004aoo`00@7oo
00@007ooOol000=oo`8000=oo`04001oogoo000IOol00`00Oomoo`02Ool01000Oomoo`000Woo00@0
07ooOol0009oo`04001oogoo000FOol00`00Oomoo`02Ool01000Oomoo`001Goo00@007ooOol0009o
o`03001oogoo01Aoo`03001oogoo009oo`04001oogoo0002Ool00`00Ool00003Ool01000Oomoo`00
C7oo0010Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo000IOol00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol0009oo`04001oogoo000FOol00`00Oomoo`02Ool01000Oomoo`00
0Woo00@007ooOol0009oo`04001oogoo000FOol00`00Oomoo`02Ool01000Oomoo`000Woo00<007oo
00000goo00@007ooOol004aoo`00@Goo0P0017oo0P0017oo0P006Goo0P001Goo0P0017oo0P0017oo
0P005Woo0P001Goo0P0017oo0P0017oo0P005Woo0P001Goo0P0017oo0P0017oo0P00:Goo10005goo
0`001Woo003nOol00`00Oomoo`0GOol00`00Oomoo`05Ool00>Qoo`@0009oo`@000=oo`@0009oo`@0
0003Ool0000000<0009oo`@00004Ool00000Ool20002Ool30003Ool00`00Oomoo`04Ool00>Uoo`03
001oogoo00=oo`03001oogoo009oo`03001oogoo00=oo`07001oogooOol007oo00000Woo00@007oo
Ool000Eoo`04001oogoo0002Ool01@00Oomoogoo00000Woo00<007ooOol017oo0007OooI0009Ool0
0`00Oomoo`03Ool00`00Oomoo`02Ool500000goo001oo`02Ool00`00Ool00002Ool00`00Oomoo`05
00001Goo001oogoo00000Woo00<007ooOol00goo00<007oo00001Goo000BOol00`00Oomoo`08Ool0
0`00Oomoo`07Ool00`00Oomoo`08Ool20009Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomo
o`07Ool01000Ool000001goo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007oo
Ool01Goo0`002Woo00<007ooOol027oo00<007ooOol027oo00@007oo000000Moo`03001oogoo00Mo
o`03001oogoo00Qoo`03001oogoo009oo`03001oogoo00eoo`03001oogoo00=oo`8000=oo`07001o
ogooOol007oo00000goo00<007oo00000Woo00@007ooOol000=oo`03001oo`00009oo`04001oogoo
0003Ool01@00Ool007oo00001Goo000DOol00`00Oomoo`06Ool01000Oomoogoo10003Goo00<007oo
00004goo00<007ooOol00P002Woo0P001Goo00<007oo00004Woo00<007ooOol06goo00@007ooOol0
00Uoo`03001oogoo00Yoo`03001oogoo00Qoo`03001oo`00011oo`03001oogoo009oo`<000Moo`80
00ioo`@0009oo`800003Ool00000009oo`<000=oo`H00003Ool0000000=oo`<00003Ool0000000<0
00=oo`H00003Ool0000000Aoo`0037oo100017oo0P001goo00D007ooOomoo`0000=oo`<000Uoo`04
001oogoo0006Ool50009Ool200000goo001oo`09Ool00`00Ool000040002Ool01@00Oomoogoo0000
9goo0P000Woo00<007ooOol00Woo00<007oo00000`001goo0P001goo00<007ooOol027oo00<007oo
000047oo0P000goo00<007oo00001Woo00@007ooOol000ioo`03001oogoo03Aoo`001goo00D007oo
Oomoo`0000Aoo`07001oogooOol007oo00001Goo0`0000=oo`00Ool01Goo00<007ooOol017oo0P00
00=oo`00Ool00Woo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol00Woo
00<007ooOol01Woo00<007ooOol027oo00@007ooOol002=oo`@00005Ool007ooOol00005Ool01@00
Oomoogoo00000goo0P0000Aoo`00Ool000=oo`800004Ool007oo0008Ool01000Oomoo`0047oo00D0
07oo001oo`0000=oo`03001oogoo00<000=oo`03001oogoo00aoo`<003Aoo`0027oo00<007oo0000
1Goo00@007ooOol0009oo`03001oogoo00=oo`800003Ool007oo00Moo`03001oogoo009oo`04001o
ogoo0005Ool40006Ool00`00Oomoo`05Ool00`00Oomoo`03Ool00`00Oomoo`03Ool2000;Ool01@00
Ool007oo00000Woo00@007ooOomoo`<001Qoo`03001oogoo00Aoo`03001oo`0000Yoo`03001oo`00
009oo`05001oogooOol00002Ool00`00Ool00003Ool40004Ool01@00Oomoogoo000017oo0P0027oo
00D007ooOomoo`0000Aoo`04001oogoo0005Ool00`00Oomoo`13Ool000Uoo`03001oogoo00Eoo`03
001oo`0000=oo`07001oogooOol007oo00002Woo00<007ooOol00P0057oo0P0017oo00<007ooOol0
1Goo00<007ooOol00P003Goo00D007oo001oo`00009oo`800003Ool007oo009oo`05001oogooOol0
000BOol00`00Oomoo`05Ool2000<Ool00`00Oomoo`05Ool00`00Ool00009Ool00`00Oomoo`02Ool0
1@00Oomoogoo00000goo00<007oo00001goo00<007ooOol01goo00<007oo00001goo00<007ooOol0
@Woo000AOol00`00Ool00004Ool2000017oo001oo`002goo0P0067oo00D007ooOomoo`0000Qoo`80
00moo`07001oo`00Ool007oo00000Woo00<007ooOol00Woo00D007ooOomoo`00015oo`03001oogoo
00Moo`03001oogoo01=oo`03001oogoo00Uoo`04001oogoo0004Ool01000Oomoo`000goo00<007oo
Ool00goo00<007ooOol02Goo00<007ooOol01Woo00D007ooOomoo`00041oo`004Goo00<007oo0000
1Woo00@007ooOol002Ioo`04001oogoo000JOol01@00Oomoogoo00002Goo00@007oo0000011oo`03
001oogoo02Yoo`04001oo`000005Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`0COol01@00Oomo
ogoo0000@7oo000BOol00`00Oomoo`08Ool00`00Oomoo`0UOol2000KOol00`00Oomoo`0;Ool01000
Ool0000047oo00<007ooOol0:goo00<007ooOol01Goo00<007ooOol017oo0P0000=oo`00Ool05Woo
00@007ooOol0041oo`004Woo00<007ooOol027oo00<007ooOol09Woo00<007ooOol0:7oo00@007oo
Ool000ioo`03001oogoo03eoo`03001oogoo01Ioo`03001oo`00045oo`007Goo00<007ooOol0E7oo
00<007ooOol037oo00<007ooOol0EWoo00<007oo0000@Goo000MOol00`00Oomoo`1DOol00`00Oomo
o`0<Ool00`00Oomoo`1FOol00`00Ool00011Ool001eoo`03001oogoo05Aoo`03001oogoo00Yoo`80
05Uoo`03001oo`00045oo`007Goo00<007ooOol0E7oo00<007ooOol02Goo00<007ooOol0FWoo00<0
07ooOol0@7oo000MOol00`00Oomoo`1DOol00`00Oomoo`09Ool00`00Oomoo`1JOol00`00Oomoo`10
Ool001eoo`03001oogoo05Aoo`03001oogoo00Uoo`03001oogoo09eoo`007Goo00<007ooOol0EGoo
00<007ooOol01goo00<007ooOol0WWoo000MOol00`00Oomoo`1EOol00`00Oomoo`07Ool00`00Oomo
o`2NOol001eoo`03001oogoo05Eoo`03001oogoo00Moo`03001oogoo09ioo`007Goo00<007ooOol0
EGoo00<007ooOol01goo00<007ooOol0WWoo000MOol00`00Oomoo`1EOol00`00Oomoo`06Ool00`00
Oomoo`2OOol001eoo`03001oogoo05Eoo`03001oogoo00Ioo`03001oogoo09moo`007Goo00<007oo
Ool0EWoo00<007ooOol01Goo00<007ooOol0Wgoo000MOol00`00Oomoo`1FOol00`00Oomoo`05Ool0
0`00Oomoo`2OOol000Yoo`8000Aoo`8000=oo`@000Aoo`03001oogoo05Ioo`03001oogoo00Eoo`03
001oogoo09moo`002Goo00@007ooOol000=oo`8000Aoo`03001oogoo00Aoo`03001oogoo05Ioo`03
001oogoo00Eoo`03001oogoo09moo`002Goo00@007ooOol000Yoo`03001oogoo00=oo`8005Moo`03
001oogoo00Eoo`03001oogoo09moo`002Goo00@007ooOol000]oo`03001oogoo009oo`03001oogoo
05Moo`03001oogoo00Aoo`03001oogoo09moo`002Goo00@007ooOol000Qoo`04001oogoo0004Ool0
0`00Oomoo`1GOol00`00Oomoo`04Ool00`00Oomoo`2OOol000Yoo`8000Yoo`8000Eoo`03001oogoo
05Moo`03001oogoo00Aoo`03001oogoo09moo`007Goo00<007ooOol0Egoo00<007ooOol017oo00<0
07ooOol0Wgoo000MOol00`00Oomoo`1GOol00`00Oomoo`04Ool00`00Oomoo`2OOol001eoo`03001o
ogoo05Moo`03001oogoo00Aoo`03001oogoo09moo`007Goo00<007ooOol0Egoo00<007ooOol017oo
00<007ooOol0Wgoo000MOol00`00Oomoo`1GOol00`00Oomoo`04Ool00`00Oomoo`2OOol001eoo`03
001oogoo05Moo`03001oogoo00Aoo`03001oogoo09moo`007Goo00<007ooOol0Egoo00<007ooOol0
17oo00<007ooOol0Wgoo000MOol00`00Oomoo`1GOol00`00Oomoo`04Ool00`00Oomoo`2OOol001eo
o`03001oogoo05Moo`03001oogoo00Aoo`03001oogoo09moo`007Goo00<007ooOol0Egoo00<007oo
Ool017oo00<007ooOol0Wgoo000MOol00`00Oomoo`1GOol00`00Oomoo`04Ool00`00Oomoo`2OOol0
01eoo`03001oogoo05Moo`03001oogoo00Aoo`03001oogoo09moo`007Goo00<007ooOol0Egoo00<0
07ooOol017oo00<007ooOol0Wgoo000MOol00`00Oomoo`1GOol00`00Oomoo`04Ool00`00Oomoo`2O
Ool001eoo`03001oogoo05Moo`03001oogoo00Aoo`03001oogoo09moo`007Goo00<007ooOol0Egoo
00<007ooOol017oo00<007ooOol0Wgoo000MOol00`00Oomoo`1GOol00`00Oomoo`04Ool00`00Oomo
o`2OOol001eoo`03001oogoo05Moo`03001oogoo00=oo`03001oogoo0:1oo`007Goo00<007ooOol0
Egoo00<007ooOol00goo00<007ooOol0X7oo000MOol00`00Oomoo`1GOol00`00Oomoo`03Ool00`00
Oomoo`2POol001eoo`03001oogoo05Moo`03001oogoo00=oo`03001oogoo0:1oo`002Woo0P0017oo
0P0017oo0`0017oo00<007ooOol0Egoo00<007ooOol00goo00<007ooOol0X7oo0009Ool01000Oomo
o`000goo0P001Goo00<007ooOol00goo00<007ooOol0Egoo00<007ooOol00goo00<007ooOol0X7oo
0009Ool01000Oomoo`0027oo100017oo0P00F7oo00<007ooOol00goo00<007ooOol0X7oo0009Ool0
1000Oomoo`0027oo00<007oo00001Goo00<007ooOol0Egoo00<007ooOol00goo00<007ooOol0X7oo
0009Ool01000Oomoo`0027oo00<007oo00001Goo00<007ooOol0Egoo00<007ooOol00goo00<007oo
Ool0X7oo000:Ool2000:Ool20005Ool00`00Oomoo`1HOol00`00Oomoo`02Ool00`00Oomoo`2POol0
01eoo`03001oogoo05Qoo`03001oogoo009oo`03001oogoo0:1oo`007Goo00<007ooOol0F7oo00<0
07ooOol00Woo00<007ooOol0X7oo000MOol00`00Oomoo`1HOol00`00Oomoo`02Ool00`00Oomoo`2P
Ool001eoo`03001oogoo05Qoo`03001oogoo009oo`03001oogoo0:1oo`007Goo00<007ooOol0F7oo
00<007ooOol00Woo00<007ooOol0X7oo000MOol00`00Oomoo`1HOol00`00Oomoo`02Ool00`00Oomo
o`2POol001eoo`03001oogoo05Qoo`03001oogoo009oo`03001oogoo0:1oo`007Goo00<007ooOol0
F7oo00<007ooOol00Woo00<007ooOol0X7oo000MOol00`00Oomoo`1HOol00`00Oomoo`02Ool00`00
Oomoo`2POol001eoo`03001oogoo05Qoo`03001oogoo009oo`03001oogoo0:1oo`007Goo00<007oo
Ool0F7oo00<007ooOol00Woo00<007ooOol0X7oo000MOol00`00Oomoo`1HOol00`00Oomoo`02Ool0
0`00Oomoo`2POol001eoo`03001oogoo05Qoo`03001oogoo009oo`03001oogoo0:1oo`007Goo00<0
07ooOol0F7oo00<007ooOol00Woo00<007ooOol0X7oo000MOol00`00Oomoo`1HOol00`00Oomoo`02
Ool00`00Oomoo`2POol001eoo`03001oogoo05Qoo`03001oogoo009oo`03001oogoo0:1oo`007Goo
00<007ooOol0F7oo00<007ooOol00Woo00<007ooOol0X7oo000MOol00`00Oomoo`1HOol00`00Oomo
o`02Ool00`00Oomoo`2POol001eoo`03001oogoo05Qoo`03001oogoo009oo`03001oogoo0:1oo`00
7Goo00<007ooOol0F7oo00<007ooOol00Woo00<007ooOol0X7oo000MOol00`00Oomoo`1HOol00`00
Oomoo`02Ool00`00Oomoo`2POol000Yoo`8000Aoo`8000Aoo`8000Eoo`03001oogoo05Qoo`03001o
ogoo009oo`03001oogoo0:1oo`002Goo00@007ooOol000=oo`8000=oo`04001oogoo0004Ool00`00
Oomoo`1HOol00`00Oomoo`02Ool00`00Oomoo`2POol000Uoo`04001oogoo0008Ool01000Oomoo`00
17oo0P00FGoo00<007ooOol00Woo00<007ooOol0X7oo0009Ool01000Oomoo`0027oo0`001Goo00<0
07ooOol0F7oo00<007ooOol00Woo00<007ooOol0X7oo0009Ool01000Oomoo`0027oo00<007ooOol0
1Goo00<007ooOol0F7oo00<007ooOol00Woo00<007ooOol0X7oo000:Ool2000:Ool30004Ool00`00
Oomoo`1HOol00`00Oomoo`02Ool00`00Oomoo`2POol001eoo`03001oogoo05Qoo`03001oogoo009o
o`03001oogoo0:1oo`007Goo00<007ooOol0F7oo00<007ooOol00Woo00<007ooOol0X7oo000MOol0
0`00Oomoo`1HOol00`00Oomoo`02Ool00`00Oomoo`2POol001eoo`03001oogoo05Qoo`03001oogoo
009oo`03001oogoo0:1oo`007Goo00<007ooOol0F7oo00<007ooOol00Woo00<007ooOol0X7oo000M
Ool00`00Oomoo`1HOol00`00Oomoo`02Ool00`00Oomoo`2POol001eoo`03001oogoo05Qoo`03001o
ogoo009oo`03001oogoo0:1oo`007Goo00<007ooOol0F7oo00<007ooOol00Woo00<007ooOol0X7oo
000MOol00`00Oomoo`1HOol00`00Oomoo`02Ool00`00Oomoo`2POol001eoo`03001oogoo05Qoo`03
001oogoo009oo`03001oogoo0:1oo`007Goo00<007ooOol0F7oo00<007ooOol00Woo00<007ooOol0
X7oo000MOol00`00Oomoo`1HOol00`00Oomoo`02Ool00`00Oomoo`2POol001eoo`03001oogoo05Qo
o`03001oogoo009oo`03001oogoo0:1oo`007Goo00<007ooOol0F7oo00D007ooOomoo`000:=oo`00
7Goo00<007ooOol0F7oo00D007ooOomoo`000:=oo`007Goo00<007ooOol0F7oo00D007ooOomoo`00
0:=oo`007Goo00<007ooOol0F7oo00D007ooOomoo`000:=oo`007Goo00<007ooOol0F7oo00D007oo
Oomoo`000:=oo`007Goo00<007ooOol0F7oo00D007ooOomoo`000:=oo`007Goo00<007ooOol0F7oo
00D007ooOomoo`000:=oo`002Woo0P0017oo0P0017oo0P001Goo00<007ooOol0F7oo00D007ooOomo
o`000:=oo`002Goo00@007ooOol000=oo`8000=oo`04001oogoo0004Ool00`00Oomoo`1HOol01@00
Oomoogoo0000Xgoo0009Ool01000Oomoo`0027oo00@007ooOol000Aoo`8005Uoo`05001oogooOol0
002SOol000Uoo`04001oogoo0009Ool20005Ool00`00Oomoo`1HOol01@00Oomoogoo0000Xgoo0009
Ool01000Oomoo`0027oo00@007ooOol000Aoo`03001oogoo05Uoo`04001oogoo002SOol000Yoo`80
00Yoo`8000Eoo`03001oogoo05Uoo`04001oogoo002SOol001eoo`03001oogoo05Uoo`04001oogoo
002SOol001eoo`03001oogoo05Uoo`04001oogoo002SOol001eoo`03001oogoo05Uoo`04001oogoo
002SOol001eoo`03001oogoo05Uoo`04001oogoo002SOol001eoo`03001oogoo05Uoo`04001oogoo
002SOol001eoo`03001oogoo05Uoo`04001oogoo002SOol001eoo`03001oogoo05Uoo`04001oogoo
002SOol001eoo`03001oogoo05Uoo`04001oogoo002SOol001eoo`03001oogoo05Uoo`04001oogoo
002SOol001eoo`03001oogoo05Uoo`04001oogoo002SOol001eoo`03001oogoo05Uoo`04001oogoo
002SOol001eoo`03001oogoo05Uoo`04001oogoo002SOol001eoo`03001oogoo05Uoo`04001oogoo
002SOol001eoo`03001oogoo05Uoo`04001oogoo002SOol001eoo`03001oogoo05Uoo`03001oo`00
0:Aoo`007Goo00<007ooOol0FGoo00<007oo0000Y7oo000MOol00`00Oomoo`1IOol00`00Ool0002T
Ool001eoo`03001oogoo05Uoo`03001oo`000:Aoo`007Goo00<007ooOol0FGoo0P00YGoo000MOol0
0`00Oomoo`1IOol2002UOol001eoo`03001oogoo05Uoo`800:Eoo`005Goo0`001Goo00<007ooOol0
FGoo0P00YGoo000FOol00`00Oomoo`04Ool00`00Oomoo`1IOol00`00Oomoo`2TOol001Ioo`03001o
ogoo00Aoo`8005Yoo`03001oogoo0:Aoo`005Woo00<007ooOol0ogoo27oo000FOol00`00Oomoo`3o
Ool8Ool001Eoo`800?moo`Yoo`00ogoo8Goo003oOolQOol00?moob5oo`003Woo10008Woo0`000goo
0`001Goo0`002Goo0`000Woo10001goo0P000Woo0P000Woo10000Woo0`000goo0`000Woo10000goo
1@0000=oo`0000000P000Woo1@001Woo0`0017oo0`000Woo1@0000Aoo`00001oo`80009oo`D006eo
o`003goo00<007ooOol08goo00<007ooOol00goo00<007ooOol01Goo00<007ooOol01goo00D007oo
Oomoo`00009oo`03001oogoo00Qoo`04001oo`000002Ool00`00Oomoo`03Ool01`00Oomoogoo001o
o`0000=oo`04001oogoo0004Ool01`00Oomoogoo001oo`0000Eoo`05001oogooOol00007Ool01000
Oomoo`000Woo00L007ooOomoo`00Ool00002Ool01000Oomoo`000Woo00@007ooOol000=oo`03001o
ogoo06aoo`000goo1@0000Moo`00Ool007oo001oo`040002Ool500000goo000000030002Ool30002
Ool50002Ool500000goo000000020003Ool00`00Oomoo`05Ool00`00Oomoo`07Ool01@00Oomoogoo
00000Woo00<007ooOol027oo0`000goo1@0000=oo`00Ool017oo00D007ooOomoo`00009oo`03001o
ogoo009oo`06001oogooOol007oo1@0000=oo`00Ool00Woo00<007ooOol01goo0P000Woo00L007oo
Oomoo`00Ool00002Ool01000Oomoo`000Woo00@007ooOol000=oo`03001oogoo06aoo`000goo00@0
07ooOol0009oo`07001oo`00Ool007oo00000goo00D007ooOomoo`0000Eoo`03001oogoo009oo`06
001oogoo001oo`000Woo00@007ooOol000=oo`04001oo`00Ool30003Ool30003Ool01@00Ool007oo
00001goo00D007ooOomoo`00009oo`03001oogoo00Qoo`04001oogoo0002Ool01`00Oomoogoo001o
o`0000=oo`03001oo`0000=oo`03001oogoo008000=oo`07001oogooOol007oo00000goo00<007oo
00000goo00<007ooOol01Goo0P0017oo00L007ooOomoo`00Ool00002Ool01000Oomoo`000Woo00@0
07ooOol000=oo`03001oogoo06aoo`000goo10000Woo00L007oo001oo`00Ool00003Ool01@00Oomo
ogoo00001Goo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`06001oogooOol007oo
1@000goo00<007ooOol00goo00D007oo001oo`0000Qoo`<0009oo`@000Qoo`04001oogoo0003Ool3
0003Ool40002Ool30002Ool200000goo00000002Ool40002Ool30003Ool40007Ool01000Oomoo`00
0goo0`0000Aoo`00001oo`800003Ool0000000<000=oo`@006ioo`001Woo00X007ooOol007oo001o
o`00Ool000=oo`05001oogooOol00005Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01000Oomoo`00
0Woo00H007ooOomoo`00Ool600000goo000000030002Ool5000>Ool00`00Oomoo`07Ool4000OOol0
0`00Oomoo`09Ool00`00Oomoo`06Ool3000HOol00`00Oomoo`1/Ool000Aoo`<00003Ool0000000T0
00Aoo`03001oogoo009oo`8000=oo`@00004Ool00000Ool20003Ool40002Ool3000MOol3000YOol2
000:Ool2000ROol2001^Ool001Moo`03001oogoo00Qoo`03001oogoo00aoo`03001oogoo0>aoo`00
5Goo0`001Goo00<007ooOol00Woo00<007ooOol02goo0P00kWoo003oOolQOol00?moob5oo`00ogoo
8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {946.587, -0.14072, 0.462505, 
  0.00748348}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-9.5 0.01 0 0.618034 [
[.3 -0.0125 -9 -9 ]
[.3 -0.0125 9 0 ]
[.5 -0.0125 -12 -9 ]
[.5 -0.0125 12 0 ]
[.7 -0.0125 -12 -9 ]
[.7 -0.0125 12 0 ]
[.9 -0.0125 -12 -9 ]
[.9 -0.0125 12 0 ]
[1.025 0 0 -6 ]
[1.025 0 58 6 ]
[.0875 .12361 -18 -4.5 ]
[.0875 .12361 0 4.5 ]
[.0875 .24721 -18 -4.5 ]
[.0875 .24721 0 4.5 ]
[.0875 .37082 -18 -4.5 ]
[.0875 .37082 0 4.5 ]
[.0875 .49443 -18 -4.5 ]
[.0875 .49443 0 4.5 ]
[.0875 .61803 -6 -4.5 ]
[.0875 .61803 0 4.5 ]
[.1 .64303 -29 0 ]
[.1 .64303 29 12 ]
[.5 .63053 -65 0 ]
[.5 .63053 65 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.3 0 m
.3 .00625 L
s
[(980)] .3 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1000)] .5 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(1020)] .7 -0.0125 0 1 Mshowa
.9 0 m
.9 .00625 L
s
[(1040)] .9 -0.0125 0 1 Mshowa
.125 Mabswid
.15 0 m
.15 .00375 L
s
.2 0 m
.2 .00375 L
s
.25 0 m
.25 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.45 0 m
.45 .00375 L
s
.55 0 m
.55 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.75 0 m
.75 .00375 L
s
.8 0 m
.8 .00375 L
s
.85 0 m
.85 .00375 L
s
.05 0 m
.05 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(frequency) show
117.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.1 .12361 m
.10625 .12361 L
s
[(0.2)] .0875 .12361 1 0 Mshowa
.1 .24721 m
.10625 .24721 L
s
[(0.4)] .0875 .24721 1 0 Mshowa
.1 .37082 m
.10625 .37082 L
s
[(0.6)] .0875 .37082 1 0 Mshowa
.1 .49443 m
.10625 .49443 L
s
[(0.8)] .0875 .49443 1 0 Mshowa
.1 .61803 m
.10625 .61803 L
s
[(1)] .0875 .61803 1 0 Mshowa
.125 Mabswid
.1 .0309 m
.10375 .0309 L
s
.1 .0618 m
.10375 .0618 L
s
.1 .09271 m
.10375 .09271 L
s
.1 .15451 m
.10375 .15451 L
s
.1 .18541 m
.10375 .18541 L
s
.1 .21631 m
.10375 .21631 L
s
.1 .27812 m
.10375 .27812 L
s
.1 .30902 m
.10375 .30902 L
s
.1 .33992 m
.10375 .33992 L
s
.1 .40172 m
.10375 .40172 L
s
.1 .43262 m
.10375 .43262 L
s
.1 .46353 m
.10375 .46353 L
s
.1 .52533 m
.10375 .52533 L
s
.1 .55623 m
.10375 .55623 L
s
.1 .58713 m
.10375 .58713 L
s
.25 Mabswid
.1 0 m
.1 .61803 L
s
gsave
.1 .64303 -90 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(amplitude) show
117.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.5 .63053 -126 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(FFT) show
87.000000 13.000000 moveto
(of) show
105.000000 13.000000 moveto
(Recorded) show
159.000000 13.000000 moveto
(Sound) show
189.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .00773 m
.01 .00559 L
.02 .01165 L
.03 .01468 L
.04 .01384 L
.05 .00592 L
.06 .0094 L
.07 .01216 L
.08 .01955 L
.09 .01032 L
.1 .02453 L
.11 .00818 L
.12 .01216 L
.13 .01046 L
.14 .01283 L
.15 .00423 L
.16 .0144 L
.17 .02463 L
.18 .01266 L
.19 .00766 L
.2 .01571 L
.21 .01107 L
.22 .00994 L
.23 .02066 L
.24 .00295 L
.25 .0069 L
.26 .01156 L
.27 .02483 L
.28 .00132 L
.29 .00563 L
.3 .01212 L
.31 .00948 L
.32 .00326 L
.33 .01988 L
.34 .01551 L
.35 .01515 L
.36 .00442 L
.37 .00535 L
.38 .01044 L
.39 .01928 L
.4 .02797 L
.41 .0233 L
.42 .00577 L
.43 .01301 L
.44 .02119 L
.45 .01645 L
.46 .00905 L
.47 .01912 L
.48 .03993 L
.49 .02501 L
Mistroke
.5 .03981 L
.51 .04319 L
.52 .16596 L
.53 .2176 L
.54 .61803 L
.55 .07366 L
.56 .05943 L
.57 .04593 L
.58 .01598 L
.59 .03063 L
.6 .01267 L
.61 .02642 L
.62 .0083 L
.63 .01114 L
.64 .0105 L
.65 .01627 L
.66 .02374 L
.67 .01374 L
.68 .00676 L
.69 .00522 L
.7 .00872 L
.71 .00846 L
.72 .02398 L
.73 .01847 L
.74 .00499 L
.75 .00805 L
.76 .01208 L
.77 .00579 L
.78 .01352 L
.79 .01177 L
.8 .00917 L
.81 .00744 L
.82 .00889 L
.83 .00779 L
.84 .00999 L
.85 .00789 L
.86 .01541 L
.87 .00517 L
.88 .0172 L
.89 .00957 L
.9 .01473 L
.91 .01513 L
.92 .00759 L
.93 .02628 L
.94 .00199 L
.95 .00816 L
.96 .00891 L
.97 .01085 L
.98 .01943 L
.99 .018 L
Mistroke
1 .01569 L
Mfstroke
1 .01569 m
1 .01569 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
@7oo0`0017oo0P0017oo0P006Goo0`0017oo0P0017oo0P0017oo0P005Woo0`0017oo0P000goo1000
0goo0P005Woo0`0017oo0P0017oo0`000goo0P00CGoo0013Ool01000Oomoo`000Woo00@007ooOol0
009oo`03001oogoo01Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000Woo00@007oo
Ool001Ioo`03001oogoo009oo`04001oogoo0003Ool00`00Oomoo`02Ool01000Oomoo`005Woo00<0
07ooOol00Woo00@007ooOol000Aoo`05001oogooOol00002Ool00`00Oomoo`1:Ool0045oo`<0009o
o`04001oogoo0002Ool01000Oomoo`006Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo
0002Ool01000Oomoo`005Woo00<007ooOol00Woo00@007ooOol000Aoo`05001oogooOol00002Ool0
0`00Oomoo`0DOol00`00Oomoo`02Ool01000Oomoo`000Woo10000Woo00@007ooOol004aoo`00@7oo
00@007ooOol000=oo`8000=oo`04001oogoo000IOol00`00Oomoo`02Ool01000Oomoo`000Woo00@0
07ooOol0009oo`04001oogoo000FOol00`00Oomoo`02Ool01000Oomoo`001Goo00@007ooOol0009o
o`03001oogoo01Aoo`03001oogoo009oo`04001oogoo0002Ool00`00Ool00003Ool01000Oomoo`00
C7oo0010Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo000IOol00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol0009oo`04001oogoo000FOol00`00Oomoo`02Ool01000Oomoo`00
0Woo00@007ooOol0009oo`04001oogoo000FOol00`00Oomoo`02Ool01000Oomoo`000Woo00<007oo
00000goo00@007ooOol004aoo`00@Goo0P0017oo0P0017oo0P006Goo0P001Goo0P0017oo0P0017oo
0P005Woo0P001Goo0P0017oo0P0017oo0P005Woo0P001Goo0P0017oo0P0017oo0P00:Goo10005goo
0`001Woo003nOol00`00Oomoo`0GOol00`00Oomoo`05Ool00>Qoo`@0009oo`@000=oo`@0009oo`@0
0003Ool0000000<0009oo`@00004Ool00000Ool20002Ool30003Ool00`00Oomoo`04Ool00>Uoo`03
001oogoo00=oo`03001oogoo009oo`03001oogoo00=oo`07001oogooOol007oo00000Woo00@007oo
Ool000Eoo`04001oogoo0002Ool01@00Oomoogoo00000Woo00<007ooOol017oo0007OooI0009Ool0
0`00Oomoo`03Ool00`00Oomoo`02Ool500000goo001oo`02Ool00`00Ool00002Ool00`00Oomoo`05
00001Goo001oogoo00000Woo00<007ooOol00goo00<007oo00001Goo000BOol00`00Oomoo`08Ool0
0`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`06Ool30005Ool30002Ool00`00Oomoo`020006
Ool01000Ool000001Woo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol0
27oo00<007ooOol01goo00<007ooOol01Goo100027oo0`002Woo00<007ooOol027oo00D007ooOomo
o`0000Eoo`03001oogoo00Ioo`<001Aoo`03001oogoo00=oo`8000=oo`07001oogooOol007oo0000
0goo00<007oo00000Woo00@007ooOol000=oo`03001oo`00009oo`04001oogoo0003Ool01@00Ool0
07oo00001Goo0007Ool40006Ool50007Ool01000Ool000001Goo00<007oo00001Woo0P002Woo00@0
07oo000000Aoo`03001oogoo00D00003Ool007oo00Moo`04001oo`000009Ool20006Ool20007Ool0
0`00Oomoo`0GOol2000:Ool20003Ool30006Ool01@00Ool00000Ool010000goo2P0000=oo`000000
0goo00L007ooOomoo`00Ool00004Ool01P00Oomoogoo001oo`D000moo`@0009oo`800003Ool00000
009oo`<000=oo`H00003Ool0000000=oo`<00003Ool0000000<000=oo`H00003Ool0000000Aoo`00
2goo0P000Woo0P001Goo00D007ooOomoo`00009oo`04001oo`00Ool50003Ool00`00Oomoo`02Ool0
1@00Oomoo`00Ool01@000Woo00<007ooOol00Woo00@007ooOol000Eoo`03001oogoo009oo`03001o
ogoo00Aoo`03001oogoo009oo`03001oogoo00Ioo`03001oo`0000Aoo`04001oogoo000LOol01P00
Oomoogoo001oo`@000Eoo`03001oogoo00Eoo`03001oogoo00=oo`03001oogoo009oo`03001oogoo
009oo`<000Yoo`0<001oogoo001oo`00Ool007oo001oo`0017oo0P000Woo00<007ooOol01Goo00<0
07ooOol03Goo00<007ooOol0=7oo000=Ool20008Ool01P00Ool007oo001oo`8000]oo`05001oogoo
Ool00003Ool00`00Oomoo`03Ool00`00Ool00004Ool01000Oomoo`002Woo00<007oo000010001Woo
00<007ooOol017oo00H007ooOomoo`00Ool20004Ool00`00Oomoo`0DOol00`00Oomoo`02Ool01000
Oomoo`001Woo0`0000=oo`00Ool027oo00D007ooOomoo`0001]oo`05001oogooOol00003Ool40002
Ool00`00Ool00008Ool00`00Ool000030009Ool3000dOol001Qoo`04001oogooOol3000<Ool00`00
Ool0000;Ool00`00Oomoo`04Ool00`00Ool0000;Ool00`00Oomoo`0:Ool20002Ool20005Ool00`00
Oomoo`04Ool00`00Oomoo`0DOol02@00Oomoogoo001oo`00Ool00009Ool00`00Oomoo`09Ool00`00
Ool0000ZOol00`00Ool00009Ool00`00Oomoo`12Ool001eoo`03001oogoo00aoo`03001oogoo019o
o`03001oogoo01Uoo`8000moo`04001oogoo000AOol01@00Ool007oo00000goo00<007ooOol05Goo
00<007ooOol0:Woo00<007ooOol0CGoo000MOol00`00Oomoo`1>Ool01000Oomoo`004Goo00@007oo
Ool009Uoo`007Goo00<007ooOol0CWoo00D007oo001oo`00011oo`03001oogoo09Yoo`007Goo00<0
07ooOol0Cgoo00@007ooOomoo`8000eoo`03001oogoo09]oo`007Goo00<007ooOol0EGoo00<007oo
Ool02Woo00<007ooOol0Vgoo000MOol00`00Oomoo`1EOol00`00Oomoo`0:Ool00`00Oomoo`2KOol0
01eoo`03001oogoo05Eoo`03001oogoo00Uoo`03001oogoo09aoo`007Goo00<007ooOol0EGoo00<0
07ooOol027oo00<007ooOol0WGoo000MOol00`00Oomoo`1EOol00`00Oomoo`08Ool00`00Oomoo`2M
Ool001eoo`03001oogoo05Eoo`03001oogoo00Moo`03001oogoo09ioo`007Goo00<007ooOol0EGoo
00<007ooOol01Woo00<007ooOol0Wgoo000MOol00`00Oomoo`1FOol00`00Oomoo`05Ool00`00Oomo
o`2OOol001eoo`03001oogoo05Ioo`03001oogoo00Eoo`03001oogoo09moo`007Goo00<007ooOol0
EWoo00<007ooOol01Goo00<007ooOol0Wgoo000MOol00`00Oomoo`1FOol00`00Oomoo`05Ool00`00
Oomoo`2OOol001eoo`03001oogoo05Ioo`03001oogoo00Eoo`03001oogoo09moo`007Goo00<007oo
Ool0EWoo00<007ooOol01Goo00<007ooOol0Wgoo000MOol00`00Oomoo`1FOol00`00Oomoo`05Ool0
0`00Oomoo`2OOol001eoo`03001oogoo05Ioo`03001oogoo00Eoo`03001oogoo09moo`002Woo0P00
17oo0P000goo100017oo00<007ooOol0EWoo00<007ooOol01Goo00<007ooOol0Wgoo0009Ool01000
Oomoo`000goo0P0017oo00<007ooOol017oo00<007ooOol0EWoo00<007ooOol01Goo00<007ooOol0
Wgoo0009Ool01000Oomoo`002Woo00<007ooOol00goo0P00Egoo00<007ooOol01Goo00<007ooOol0
Wgoo0009Ool01000Oomoo`002goo00<007ooOol00Woo00<007ooOol0EWoo00<007ooOol01Goo00<0
07ooOol0Wgoo0009Ool01000Oomoo`0027oo00@007ooOol000Aoo`03001oogoo05Ioo`03001oogoo
00Eoo`03001oogoo09moo`002Woo0P002Woo0P001Goo00<007ooOol0Egoo00<007ooOol017oo00<0
07ooOol0Wgoo000MOol00`00Oomoo`1GOol00`00Oomoo`04Ool00`00Oomoo`2OOol001eoo`03001o
ogoo05Moo`03001oogoo00Aoo`03001oogoo09moo`007Goo00<007ooOol0Egoo00<007ooOol017oo
00<007ooOol0Wgoo000MOol00`00Oomoo`1GOol00`00Oomoo`04Ool00`00Oomoo`2OOol001eoo`03
001oogoo05Moo`03001oogoo00Aoo`03001oogoo09moo`007Goo00<007ooOol0Egoo00<007ooOol0
17oo00<007ooOol0Wgoo000MOol00`00Oomoo`1GOol00`00Oomoo`04Ool00`00Oomoo`2OOol001eo
o`03001oogoo05Moo`03001oogoo00Aoo`03001oogoo09moo`007Goo00<007ooOol0Egoo00<007oo
Ool017oo00<007ooOol0Wgoo000MOol00`00Oomoo`1HOol00`00Oomoo`03Ool00`00Oomoo`2OOol0
01eoo`03001oogoo05Qoo`03001oogoo00=oo`03001oogoo09moo`007Goo00<007ooOol0F7oo00<0
07ooOol00goo00<007ooOol0Wgoo000MOol00`00Oomoo`1HOol00`00Oomoo`03Ool00`00Oomoo`2O
Ool001eoo`03001oogoo05Qoo`03001oogoo00=oo`03001oogoo09moo`007Goo00<007ooOol0FGoo
00<007ooOol00Woo00<007ooOol0Wgoo000MOol00`00Oomoo`1IOol01@00Oomoogoo0000XWoo000M
Ool00`00Oomoo`1IOol01@00Oomoogoo0000XWoo000MOol00`00Oomoo`1IOol01@00Oomoogoo0000
XWoo000MOol00`00Oomoo`1IOol01@00Oomoogoo0000XWoo000MOol00`00Oomoo`1IOol01@00Oomo
ogoo0000XWoo000MOol00`00Oomoo`1IOol01@00Oomoogoo0000XWoo000:Ool20004Ool20004Ool3
0004Ool00`00Oomoo`1IOol01@00Oomoogoo0000XWoo0009Ool01000Oomoo`000goo0P001Goo00<0
07ooOol00goo00<007ooOol0FGoo00D007ooOomoo`000:9oo`002Goo00@007ooOol000Qoo`@000Ao
o`8005Yoo`05001oogooOol0002ROol000Uoo`04001oogoo0008Ool00`00Ool00005Ool00`00Oomo
o`1IOol01@00Oomoogoo0000XWoo0009Ool01000Oomoo`0027oo00<007oo00001Goo00<007ooOol0
FGoo00D007ooOomoo`000:9oo`002Woo0P002Woo0P001Goo00<007ooOol0FGoo00D007ooOomoo`00
0:9oo`007Goo00<007ooOol0FGoo00D007ooOomoo`000:9oo`007Goo00<007ooOol0FGoo00D007oo
Oomoo`000:9oo`007Goo00<007ooOol0FGoo00D007ooOomoo`000:9oo`007Goo00<007ooOol0FGoo
00D007ooOomoo`000:9oo`007Goo00<007ooOol0FWoo00@007ooOol00:9oo`007Goo00<007ooOol0
FWoo00@007ooOol00:9oo`007Goo00<007ooOol0FWoo00@007ooOol00:9oo`007Goo00<007ooOol0
FWoo00@007ooOol00:9oo`007Goo00<007ooOol0FWoo00@007ooOol00:9oo`007Goo00<007ooOol0
FWoo00@007ooOol00:9oo`007Goo00<007ooOol0FWoo00@007ooOol00:9oo`007Goo00<007ooOol0
FWoo00@007ooOol00:9oo`007Goo00<007ooOol0FWoo00@007ooOol00:9oo`007Goo00<007ooOol0
FWoo00@007ooOol00:9oo`007Goo00<007ooOol0FWoo00@007ooOol00:9oo`007Goo00<007ooOol0
FWoo00@007ooOol00:9oo`007Goo00<007ooOol0FWoo00@007ooOol00:9oo`007Goo00<007ooOol0
FWoo00@007ooOol00:9oo`007Goo00<007ooOol0FWoo00@007ooOol00:9oo`007Goo00<007ooOol0
FWoo00@007ooOol00:9oo`007Goo00<007ooOol0FWoo00@007ooOol00:9oo`002Woo0P0017oo0P00
17oo0P001Goo00<007ooOol0FWoo00@007ooOol00:9oo`002Goo00@007ooOol000=oo`8000=oo`04
001oogoo0004Ool00`00Oomoo`1JOol01000Oomoo`00XWoo0009Ool01000Oomoo`0027oo00@007oo
Ool000Aoo`8005]oo`04001oogoo002ROol000Uoo`04001oogoo0008Ool30005Ool00`00Oomoo`1J
Ool01000Oomoo`00XWoo0009Ool01000Oomoo`0027oo00<007ooOol01Goo00<007ooOol0FWoo00@0
07ooOol00:9oo`002Woo0P002Woo0`0017oo00<007ooOol0FWoo00@007ooOol00:9oo`007Goo00<0
07ooOol0FWoo00@007ooOol00:9oo`007Goo00<007ooOol0FWoo00@007ooOol00:9oo`007Goo00<0
07ooOol0FWoo00@007ooOol00:9oo`007Goo00<007ooOol0FWoo00@007ooOol00:9oo`007Goo00<0
07ooOol0FWoo00@007ooOol00:9oo`007Goo00<007ooOol0FWoo00@007ooOol00:9oo`007Goo00<0
07ooOol0Fgoo00<007oo0000XWoo000MOol00`00Oomoo`1KOol00`00Ool0002ROol001eoo`03001o
ogoo05]oo`03001oo`000:9oo`007Goo00<007ooOol0Fgoo00<007oo0000XWoo000MOol00`00Oomo
o`1KOol00`00Ool0002ROol001eoo`03001oogoo05]oo`03001oo`000:9oo`007Goo00<007ooOol0
Fgoo00<007oo0000XWoo000MOol00`00Oomoo`1KOol00`00Ool0002ROol001eoo`03001oogoo05]o
o`03001oo`000:9oo`007Goo00<007ooOol0Fgoo00<007oo0000XWoo000MOol00`00Oomoo`1KOol0
0`00Ool0002ROol001eoo`03001oogoo05]oo`03001oo`000:9oo`007Goo00<007ooOol0Fgoo00<0
07oo0000XWoo000MOol00`00Oomoo`1KOol00`00Ool0002ROol000Yoo`8000Aoo`8000Aoo`8000Eo
o`03001oogoo05]oo`800:=oo`002Goo00@007ooOol000=oo`8000=oo`04001oogoo0004Ool00`00
Oomoo`1KOol2002SOol000Uoo`04001oogoo0008Ool01000Oomoo`0017oo0P00G7oo0P00Xgoo0009
Ool01000Oomoo`002Goo0P001Goo00<007ooOol0Fgoo0P00Xgoo0009Ool01000Oomoo`0027oo00@0
07ooOol000Aoo`03001oogoo05]oo`800:=oo`002Woo0P002Woo0P001Goo00<007ooOol0Fgoo0P00
Xgoo000MOol00`00Oomoo`1KOol2002SOol001eoo`03001oogoo05]oo`800:=oo`007Goo00<007oo
Ool0Fgoo0P00Xgoo000MOol00`00Oomoo`1KOol2002SOol001eoo`03001oogoo05]oo`800:=oo`00
7Goo00<007ooOol0Fgoo0P00Xgoo000MOol00`00Oomoo`1KOol2002SOol001eoo`03001oogoo05]o
o`800:=oo`007Goo00<007ooOol0Fgoo0P00Xgoo000MOol00`00Oomoo`1LOol00`00Oomoo`2QOol0
01eoo`03001oogoo05aoo`03001oogoo0:5oo`007Goo00<007ooOol0G7oo00<007ooOol0XGoo000M
Ool00`00Oomoo`1LOol00`00Oomoo`2QOol001eoo`03001oogoo05aoo`03001oogoo0:5oo`007Goo
00<007ooOol0G7oo00<007ooOol0XGoo000MOol00`00Oomoo`1LOol00`00Oomoo`2QOol001eoo`03
001oogoo05aoo`03001oogoo0:5oo`007Goo00<007ooOol0G7oo00<007ooOol0XGoo000MOol00`00
Oomoo`1LOol00`00Oomoo`2QOol001eoo`03001oogoo05aoo`03001oogoo0:5oo`007Goo00<007oo
Ool0G7oo00<007ooOol0XGoo000EOol30005Ool00`00Oomoo`1LOol00`00Oomoo`2QOol001Ioo`03
001oogoo00Aoo`03001oogoo05aoo`03001oogoo0:5oo`005Woo00<007ooOol017oo0P00GGoo00<0
07ooOol0XGoo000FOol00`00Oomoo`3oOol8Ool001Ioo`03001oogoo0?moo`Qoo`005Goo0P00ogoo
2Woo003oOolQOol00?moob5oo`00ogoo8Goo000>Ool4000ROol30003Ool30005Ool30009Ool30002
Ool40007Ool20002Ool20002Ool40002Ool30003Ool30002Ool40003Ool500000goo000000020002
Ool50006Ool30004Ool30002Ool5000017oo000007oo0P000Woo1@00KGoo000?Ool00`00Oomoo`0S
Ool00`00Oomoo`03Ool00`00Oomoo`05Ool00`00Oomoo`07Ool01@00Oomoogoo00000Woo00<007oo
Ool027oo00@007oo0000009oo`03001oogoo00=oo`07001oogooOol007oo00000goo00@007ooOol0
00Aoo`07001oogooOol007oo00001Goo00D007ooOomoo`0000Moo`04001oogoo0002Ool01`00Oomo
ogoo001oo`00009oo`04001oogoo0002Ool01000Oomoo`000goo00<007ooOol0K7oo0003Ool50000
1goo001oo`00Ool007oo00@0009oo`D00003Ool0000000<0009oo`<0009oo`D0009oo`D00003Ool0
0000008000=oo`03001oogoo00Eoo`03001oogoo00Moo`05001oogooOol00002Ool00`00Oomoo`08
Ool30003Ool500000goo001oo`04Ool01@00Oomoogoo00000Woo00<007ooOol00Woo00H007ooOomo
o`00Ool500000goo001oo`02Ool00`00Oomoo`07Ool20002Ool01`00Oomoogoo001oo`00009oo`04
001oogoo0002Ool01000Oomoo`000goo00<007ooOol0K7oo0003Ool01000Oomoo`000Woo00L007oo
001oo`00Ool00003Ool01@00Oomoogoo00001Goo00<007ooOol00Woo00H007ooOol007oo0002Ool0
1000Oomoo`000goo00@007oo001oo`<000=oo`<000=oo`05001oo`00Ool00007Ool01@00Oomoogoo
00000Woo00<007ooOol027oo00@007ooOol0009oo`07001oogooOol007oo00000goo00<007oo0000
0goo00<007ooOol00P000goo00L007ooOomoo`00Ool00003Ool00`00Ool00003Ool00`00Oomoo`05
Ool20004Ool01`00Oomoogoo001oo`00009oo`04001oogoo0002Ool01000Oomoo`000goo00<007oo
Ool0K7oo0003Ool40002Ool01`00Ool007oo001oo`0000=oo`05001oogooOol00005Ool00`00Oomo
o`02Ool00`00Oomoo`02Ool01000Oomoo`000Woo00H007ooOomoo`00Ool50003Ool00`00Oomoo`03
Ool01@00Ool007oo000027oo0`000Woo100027oo00@007ooOol000=oo`<000=oo`@0009oo`<0009o
o`800003Ool00000009oo`@0009oo`<000=oo`@000Moo`04001oogoo0003Ool3000017oo000007oo
0P0000=oo`0000000`000goo1000KWoo0006Ool02P00Oomoo`00Ool007oo001oo`000goo00D007oo
Oomoo`0000Eoo`03001oogoo009oo`03001oogoo009oo`04001oogoo0002Ool01P00Oomoogoo001o
o`H00003Ool0000000<0009oo`D000ioo`03001oogoo00Moo`@001moo`03001oogoo00Uoo`03001o
ogoo00Ioo`<001Qoo`03001oogoo06aoo`0017oo0`0000=oo`0000002@0017oo00<007ooOol00Woo
0P000goo100000Aoo`00001oo`8000=oo`@0009oo`<001eoo`<002Uoo`8000Yoo`80029oo`8006io
o`005goo00<007ooOol027oo00<007ooOol037oo00<007ooOol0k7oo000EOol30005Ool00`00Oomo
o`02Ool00`00Oomoo`0;Ool2003^Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo
8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {946.587, -0.14072, 0.462505, 
  0.00748348}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-9.5 0.01 0 0.618034 [
[.3 -0.0125 -9 -9 ]
[.3 -0.0125 9 0 ]
[.5 -0.0125 -12 -9 ]
[.5 -0.0125 12 0 ]
[.7 -0.0125 -12 -9 ]
[.7 -0.0125 12 0 ]
[.9 -0.0125 -12 -9 ]
[.9 -0.0125 12 0 ]
[1.025 0 0 -6 ]
[1.025 0 58 6 ]
[.0875 .12361 -18 -4.5 ]
[.0875 .12361 0 4.5 ]
[.0875 .24721 -18 -4.5 ]
[.0875 .24721 0 4.5 ]
[.0875 .37082 -18 -4.5 ]
[.0875 .37082 0 4.5 ]
[.0875 .49443 -18 -4.5 ]
[.0875 .49443 0 4.5 ]
[.0875 .61803 -6 -4.5 ]
[.0875 .61803 0 4.5 ]
[.1 .64303 -29 0 ]
[.1 .64303 29 12 ]
[.5 .63053 -65 0 ]
[.5 .63053 65 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.3 0 m
.3 .00625 L
s
[(980)] .3 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1000)] .5 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(1020)] .7 -0.0125 0 1 Mshowa
.9 0 m
.9 .00625 L
s
[(1040)] .9 -0.0125 0 1 Mshowa
.125 Mabswid
.15 0 m
.15 .00375 L
s
.2 0 m
.2 .00375 L
s
.25 0 m
.25 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.45 0 m
.45 .00375 L
s
.55 0 m
.55 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.75 0 m
.75 .00375 L
s
.8 0 m
.8 .00375 L
s
.85 0 m
.85 .00375 L
s
.05 0 m
.05 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(frequency) show
117.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.1 .12361 m
.10625 .12361 L
s
[(0.2)] .0875 .12361 1 0 Mshowa
.1 .24721 m
.10625 .24721 L
s
[(0.4)] .0875 .24721 1 0 Mshowa
.1 .37082 m
.10625 .37082 L
s
[(0.6)] .0875 .37082 1 0 Mshowa
.1 .49443 m
.10625 .49443 L
s
[(0.8)] .0875 .49443 1 0 Mshowa
.1 .61803 m
.10625 .61803 L
s
[(1)] .0875 .61803 1 0 Mshowa
.125 Mabswid
.1 .0309 m
.10375 .0309 L
s
.1 .0618 m
.10375 .0618 L
s
.1 .09271 m
.10375 .09271 L
s
.1 .15451 m
.10375 .15451 L
s
.1 .18541 m
.10375 .18541 L
s
.1 .21631 m
.10375 .21631 L
s
.1 .27812 m
.10375 .27812 L
s
.1 .30902 m
.10375 .30902 L
s
.1 .33992 m
.10375 .33992 L
s
.1 .40172 m
.10375 .40172 L
s
.1 .43262 m
.10375 .43262 L
s
.1 .46353 m
.10375 .46353 L
s
.1 .52533 m
.10375 .52533 L
s
.1 .55623 m
.10375 .55623 L
s
.1 .58713 m
.10375 .58713 L
s
.25 Mabswid
.1 0 m
.1 .61803 L
s
gsave
.1 .64303 -90 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(amplitude) show
117.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.5 .63053 -126 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(FFT) show
87.000000 13.000000 moveto
(of) show
105.000000 13.000000 moveto
(Recorded) show
159.000000 13.000000 moveto
(Sound) show
189.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .00356 m
.01 .01077 L
.02 .00488 L
.03 .00801 L
.04 .00365 L
.05 .00771 L
.06 .01238 L
.07 .00458 L
.08 .0051 L
.09 .00325 L
.1 .00743 L
.11 .01203 L
.12 .00261 L
.13 .00937 L
.14 .00911 L
.15 .00255 L
.16 .01042 L
.17 .00523 L
.18 .00485 L
.19 .00604 L
.2 .00633 L
.21 .0105 L
.22 .00999 L
.23 .00538 L
.24 .01835 L
.25 .00704 L
.26 .00886 L
.27 .00955 L
.28 .01557 L
.29 .00844 L
.3 .00861 L
.31 .0106 L
.32 .00828 L
.33 .00934 L
.34 .00971 L
.35 .00995 L
.36 .01434 L
.37 .01948 L
.38 .0145 L
.39 .00699 L
.4 .01523 L
.41 .02262 L
.42 .0166 L
.43 .02126 L
.44 .02252 L
.45 .02151 L
.46 .02085 L
.47 .03084 L
.48 .02014 L
.49 .04012 L
Mistroke
.5 .04247 L
.51 .06716 L
.52 .14982 L
.53 .22404 L
.54 .61803 L
.55 .10038 L
.56 .08155 L
.57 .05572 L
.58 .03725 L
.59 .04683 L
.6 .02634 L
.61 .03127 L
.62 .02429 L
.63 .0194 L
.64 .01292 L
.65 .02039 L
.66 .00688 L
.67 .01805 L
.68 .00642 L
.69 .005 L
.7 .00734 L
.71 .01275 L
.72 .01069 L
.73 .0117 L
.74 .01324 L
.75 .01 L
.76 .00441 L
.77 .0053 L
.78 .00429 L
.79 .00516 L
.8 .0058 L
.81 .00857 L
.82 .00802 L
.83 .01156 L
.84 .00526 L
.85 .00878 L
.86 .0118 L
.87 .00195 L
.88 .01408 L
.89 .01392 L
.9 .00561 L
.91 .01129 L
.92 .00634 L
.93 .00508 L
.94 .01936 L
.95 .00191 L
.96 .01533 L
.97 .00834 L
.98 .00889 L
.99 .00309 L
Mistroke
1 .00401 L
Mfstroke
1 .00401 m
1 .00401 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
@7oo0`0017oo0P0017oo0P006Goo0`0017oo0P0017oo0P0017oo0P005Woo0`0017oo0P000goo1000
0goo0P005Woo0`0017oo0P0017oo0`000goo0P00CGoo0013Ool01000Oomoo`000Woo00@007ooOol0
009oo`03001oogoo01Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000Woo00@007oo
Ool001Ioo`03001oogoo009oo`04001oogoo0003Ool00`00Oomoo`02Ool01000Oomoo`005Woo00<0
07ooOol00Woo00@007ooOol000Aoo`05001oogooOol00002Ool00`00Oomoo`1:Ool0045oo`<0009o
o`04001oogoo0002Ool01000Oomoo`006Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo
0002Ool01000Oomoo`005Woo00<007ooOol00Woo00@007ooOol000Aoo`05001oogooOol00002Ool0
0`00Oomoo`0DOol00`00Oomoo`02Ool01000Oomoo`000Woo10000Woo00@007ooOol004aoo`00@7oo
00@007ooOol000=oo`8000=oo`04001oogoo000IOol00`00Oomoo`02Ool01000Oomoo`000Woo00@0
07ooOol0009oo`04001oogoo000FOol00`00Oomoo`02Ool01000Oomoo`001Goo00@007ooOol0009o
o`03001oogoo01Aoo`03001oogoo009oo`04001oogoo0002Ool00`00Ool00003Ool01000Oomoo`00
C7oo0010Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo000IOol00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol0009oo`04001oogoo000FOol00`00Oomoo`02Ool01000Oomoo`00
0Woo00@007ooOol0009oo`04001oogoo000FOol00`00Oomoo`02Ool01000Oomoo`000Woo00<007oo
00000goo00@007ooOol004aoo`00@Goo0P0017oo0P0017oo0P006Goo0P001Goo0P0017oo0P0017oo
0P005Woo0P001Goo0P0017oo0P0017oo0P005Woo0P001Goo0P0017oo0P0017oo0P00:Goo10005goo
0`001Woo003nOol00`00Oomoo`0GOol00`00Oomoo`05Ool00>Qoo`@0009oo`@000=oo`@0009oo`@0
0003Ool0000000<0009oo`@00004Ool00000Ool20002Ool30003Ool00`00Oomoo`04Ool00>Uoo`03
001oogoo00=oo`03001oogoo009oo`03001oogoo00=oo`07001oogooOol007oo00000Woo00@007oo
Ool000Eoo`04001oogoo0002Ool01@00Oomoogoo00000Woo00<007ooOol017oo0007OooI0009Ool0
0`00Oomoo`03Ool00`00Oomoo`02Ool500000goo001oo`02Ool00`00Ool00002Ool00`00Oomoo`05
00001Goo001oogoo00000Woo00<007ooOol00goo00<007oo00001Goo0007Ool01000Oomoogoo0P00
0Woo10000goo20000goo0P000goo0P000goo1@000Woo00<007ooOol027oo00<007ooOol027oo00<0
07ooOol027oo00<007ooOol01goo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<0
07ooOol027oo00<007ooOol01goo00<007ooOol01Goo10002Woo00@007oo0000009oo`H000Yoo`05
001oogooOol00005Ool00`00Oomoo`03Ool20003Ool00`00Oomoo`05Ool40009Ool00`00Oomoo`03
Ool20003Ool01`00Oomoogoo001oo`0000=oo`03001oo`00009oo`04001oogoo0003Ool00`00Ool0
0002Ool01000Oomoo`000goo00D007oo001oo`0000Eoo`0027oo00<007oo00000Woo0P000goo0P00
00=oo`00Ool01Woo0P0000Aoo`00Oomoo`<0009oo`03001oo`0000Eoo`@000Aoo`8000=oo`D000=o
o`D00003Ool0000000H000Moo`8001Moo`03001oogoo021oo`05001oogooOol00003Ool2000:Ool0
0`00Oomoo`020005Ool60002Ool5000017oo001oo`000goo100000Eoo`00001oo`0000=oo`04001o
ogooOol4000<Ool40002Ool200000goo00000002Ool30003Ool600000goo00000003Ool300000goo
000000030003Ool600000goo00000004Ool000Uoo`03001oogoo00Qoo`03001oogoo00Ioo`03001o
o`0000Uoo`03001oogoo00Qoo`@0009oo`03001oo`0000Eoo`03001oo`0000Eoo`03001oogoo00Io
o`<000=oo`04001oogoo000dOol02@00Oomoogoo001oo`00Ool00006Ool:000@Ool20005Ool01000
Oomoogoo0`0017oo00<007ooOol00Woo00L007oo001oo`00Ool0000AOol00`00Oomoo`0dOol001eo
o`03001oogoo01]oo`03001oogoo00Eoo`03001oogoo011oo`03001oo`0000Aoo`<00004Ool00000
000/Ool01@00Ool007oo00000goo00<007ooOol0=Woo00<007oo00000Woo00<007ooOol047oo0`00
=7oo000MOol00`00Oomoo`0gOol00`00Oomoo`06Ool01000Oomoogoo20000goo00<007ooOol077oo
0P000goo00<007ooOol0?7oo00<007ooOol0Bgoo000MOol00`00Oomoo`1<Ool01000Ool000006Goo
0P0000=oo`000000TWoo000MOol00`00Oomoo`1=Ool01000Oomoo`0067oo00<007oo0000U7oo000M
Ool00`00Oomoo`1@Ool00`00Oomoo`0AOol01@00Oomoogoo0000Ugoo000MOol00`00Oomoo`1AOol2
000AOol200000goo001oo`2GOol001eoo`03001oogoo05=oo`03001oogoo00eoo`04001oogoo002I
Ool001eoo`03001oogoo05=oo`03001oogoo00eoo`03001oogoo09Yoo`007Goo00<007ooOol0E7oo
00<007ooOol02goo00<007ooOol0Vgoo000MOol00`00Oomoo`1DOol00`00Oomoo`0;Ool00`00Oomo
o`2KOol001eoo`03001oogoo05Aoo`03001oogoo00Yoo`03001oogoo09aoo`007Goo00<007ooOol0
EGoo00<007ooOol02Goo00<007ooOol0W7oo000MOol00`00Oomoo`1EOol00`00Oomoo`09Ool00`00
Oomoo`2LOol001eoo`03001oogoo05Eoo`03001oogoo00Qoo`03001oogoo09eoo`007Goo00<007oo
Ool0EGoo00<007ooOol027oo00<007ooOol0WGoo000MOol00`00Oomoo`1EOol00`00Oomoo`08Ool0
0`00Oomoo`2MOol001eoo`03001oogoo05Ioo`03001oogoo00Ioo`03001oogoo09ioo`007Goo00<0
07ooOol0EWoo00<007ooOol01Woo00<007ooOol0WWoo000MOol00`00Oomoo`1FOol00`00Oomoo`05
Ool00`00Oomoo`2OOol001eoo`03001oogoo05Ioo`03001oogoo00Eoo`03001oogoo09moo`007Goo
00<007ooOol0EWoo00<007ooOol01Goo00<007ooOol0Wgoo000:Ool20004Ool20003Ool40004Ool0
0`00Oomoo`1FOol00`00Oomoo`05Ool00`00Oomoo`2OOol000Uoo`04001oogoo0003Ool20004Ool0
0`00Oomoo`04Ool00`00Oomoo`1FOol00`00Oomoo`05Ool00`00Oomoo`2OOol000Uoo`04001oogoo
000:Ool00`00Oomoo`03Ool2001GOol00`00Oomoo`05Ool00`00Oomoo`2OOol000Uoo`04001oogoo
000;Ool00`00Oomoo`02Ool00`00Oomoo`1FOol00`00Oomoo`05Ool00`00Oomoo`2OOol000Uoo`04
001oogoo0008Ool01000Oomoo`0017oo00<007ooOol0Egoo00<007ooOol017oo00<007ooOol0Wgoo
000:Ool2000:Ool20005Ool00`00Oomoo`1GOol00`00Oomoo`04Ool00`00Oomoo`2OOol001eoo`03
001oogoo05Moo`03001oogoo00Aoo`03001oogoo09moo`007Goo00<007ooOol0Egoo00<007ooOol0
17oo00<007ooOol0Wgoo000MOol00`00Oomoo`1GOol00`00Oomoo`04Ool00`00Oomoo`2OOol001eo
o`03001oogoo05Moo`03001oogoo00Aoo`03001oogoo09moo`007Goo00<007ooOol0Egoo00<007oo
Ool017oo00<007ooOol0Wgoo000MOol00`00Oomoo`1GOol00`00Oomoo`04Ool00`00Oomoo`2OOol0
01eoo`03001oogoo05Moo`03001oogoo00Aoo`03001oogoo09moo`007Goo00<007ooOol0F7oo00<0
07ooOol00goo00<007ooOol0Wgoo000MOol00`00Oomoo`1HOol00`00Oomoo`03Ool00`00Oomoo`2O
Ool001eoo`03001oogoo05Qoo`03001oogoo00=oo`03001oogoo09moo`007Goo00<007ooOol0F7oo
00<007ooOol00goo00<007ooOol0Wgoo000MOol00`00Oomoo`1HOol00`00Oomoo`03Ool00`00Oomo
o`2OOol001eoo`03001oogoo05Qoo`03001oogoo00=oo`03001oogoo09moo`007Goo00<007ooOol0
F7oo00<007ooOol00goo00<007ooOol0Wgoo000MOol00`00Oomoo`1HOol00`00Oomoo`03Ool00`00
Oomoo`2OOol001eoo`03001oogoo05Uoo`03001oogoo009oo`03001oogoo09moo`007Goo00<007oo
Ool0FGoo00<007ooOol00Woo00<007ooOol0Wgoo000MOol00`00Oomoo`1IOol00`00Oomoo`02Ool0
0`00Oomoo`2OOol001eoo`03001oogoo05Uoo`03001oogoo009oo`03001oogoo09moo`007Goo00<0
07ooOol0FGoo00<007ooOol00Woo00<007ooOol0Wgoo000MOol00`00Oomoo`1IOol01@00Oomoogoo
0000XWoo000:Ool20004Ool20004Ool30004Ool00`00Oomoo`1IOol01@00Oomoogoo0000XWoo0009
Ool01000Oomoo`000goo0P001Goo00<007ooOol00goo00<007ooOol0FGoo00D007ooOomoo`000:9o
o`002Goo00@007ooOol000Qoo`@000Aoo`8005Yoo`05001oogooOol0002ROol000Uoo`04001oogoo
0008Ool00`00Ool00005Ool00`00Oomoo`1IOol01@00Oomoogoo0000XWoo0009Ool01000Oomoo`00
27oo00<007oo00001Goo00<007ooOol0FGoo00D007ooOomoo`000:9oo`002Woo0P002Woo0P001Goo
00<007ooOol0FGoo00D007ooOomoo`000:9oo`007Goo00<007ooOol0FGoo00D007ooOomoo`000:9o
o`007Goo00<007ooOol0FGoo00D007ooOomoo`000:9oo`007Goo00<007ooOol0FGoo00D007ooOomo
o`000:9oo`007Goo00<007ooOol0FGoo00D007ooOomoo`000:9oo`007Goo00<007ooOol0FGoo00D0
07ooOomoo`000:9oo`007Goo00<007ooOol0FGoo00D007ooOomoo`000:9oo`007Goo00<007ooOol0
FWoo00@007ooOol00:9oo`007Goo00<007ooOol0FWoo00@007ooOol00:9oo`007Goo00<007ooOol0
FWoo00@007ooOol00:9oo`007Goo00<007ooOol0FWoo00@007ooOol00:9oo`007Goo00<007ooOol0
FWoo00@007ooOol00:9oo`007Goo00<007ooOol0FWoo00@007ooOol00:9oo`007Goo00<007ooOol0
FWoo00@007ooOol00:9oo`007Goo00<007ooOol0FWoo00@007ooOol00:9oo`007Goo00<007ooOol0
FWoo00@007ooOol00:9oo`007Goo00<007ooOol0FWoo00@007ooOol00:9oo`007Goo00<007ooOol0
FWoo00@007ooOol00:9oo`007Goo00<007ooOol0FWoo00@007ooOol00:9oo`007Goo00<007ooOol0
FWoo00@007ooOol00:9oo`007Goo00<007ooOol0FWoo00@007ooOol00:9oo`007Goo00<007ooOol0
FWoo00@007ooOol00:9oo`002Woo0P0017oo0P0017oo0P001Goo00<007ooOol0FWoo00@007ooOol0
0:9oo`002Goo00@007ooOol000=oo`8000=oo`04001oogoo0004Ool00`00Oomoo`1JOol01000Oomo
o`00XWoo0009Ool01000Oomoo`0027oo00@007ooOol000Aoo`8005]oo`04001oogoo002ROol000Uo
o`04001oogoo0008Ool30005Ool00`00Oomoo`1JOol01000Oomoo`00XWoo0009Ool01000Oomoo`00
27oo00<007ooOol01Goo00<007ooOol0FWoo00@007ooOol00:9oo`002Woo0P002Woo0`0017oo00<0
07ooOol0FWoo00@007ooOol00:9oo`007Goo00<007ooOol0FWoo00@007ooOol00:9oo`007Goo00<0
07ooOol0FWoo00@007ooOol00:9oo`007Goo00<007ooOol0FWoo00@007ooOol00:9oo`007Goo00<0
07ooOol0FWoo00@007ooOol00:9oo`007Goo00<007ooOol0FWoo00@007ooOol00:9oo`007Goo00<0
07ooOol0FWoo00@007ooOol00:9oo`007Goo00<007ooOol0FWoo00@007ooOol00:9oo`007Goo00<0
07ooOol0Fgoo00<007oo0000XWoo000MOol00`00Oomoo`1KOol00`00Ool0002ROol001eoo`03001o
ogoo05]oo`03001oo`000:9oo`007Goo00<007ooOol0Fgoo00<007oo0000XWoo000MOol00`00Oomo
o`1KOol00`00Ool0002ROol001eoo`03001oogoo05]oo`03001oo`000:9oo`007Goo00<007ooOol0
Fgoo00<007oo0000XWoo000MOol00`00Oomoo`1KOol00`00Ool0002ROol001eoo`03001oogoo05]o
o`03001oo`000:9oo`007Goo00<007ooOol0Fgoo00<007oo0000XWoo000MOol00`00Oomoo`1KOol0
0`00Ool0002ROol001eoo`03001oogoo05]oo`03001oo`000:9oo`007Goo00<007ooOol0Fgoo00<0
07oo0000XWoo000:Ool20004Ool20004Ool20005Ool00`00Oomoo`1KOol00`00Ool0002ROol000Uo
o`04001oogoo0003Ool20003Ool01000Oomoo`0017oo00<007ooOol0Fgoo00<007oo0000XWoo0009
Ool01000Oomoo`0027oo00@007ooOol000Aoo`8005aoo`800:=oo`002Goo00@007ooOol000Uoo`80
00Eoo`03001oogoo05]oo`800:=oo`002Goo00@007ooOol000Qoo`04001oogoo0004Ool00`00Oomo
o`1KOol2002SOol000Yoo`8000Yoo`8000Eoo`03001oogoo05]oo`800:=oo`007Goo00<007ooOol0
Fgoo0P00Xgoo000MOol00`00Oomoo`1KOol2002SOol001eoo`03001oogoo05]oo`800:=oo`007Goo
00<007ooOol0Fgoo0P00Xgoo000MOol00`00Oomoo`1KOol2002SOol001eoo`03001oogoo05]oo`80
0:=oo`007Goo00<007ooOol0Fgoo0P00Xgoo000MOol00`00Oomoo`1KOol2002SOol001eoo`03001o
ogoo05]oo`800:=oo`007Goo00<007ooOol0Fgoo0P00Xgoo000MOol00`00Oomoo`1LOol00`00Oomo
o`2QOol001eoo`03001oogoo05aoo`03001oogoo0:5oo`007Goo00<007ooOol0G7oo00<007ooOol0
XGoo000MOol00`00Oomoo`1LOol00`00Oomoo`2QOol001eoo`03001oogoo05aoo`03001oogoo0:5o
o`007Goo00<007ooOol0G7oo00<007ooOol0XGoo000MOol00`00Oomoo`1LOol00`00Oomoo`2QOol0
01eoo`03001oogoo05aoo`03001oogoo0:5oo`007Goo00<007ooOol0G7oo00<007ooOol0XGoo000M
Ool00`00Oomoo`1LOol00`00Oomoo`2QOol001eoo`03001oogoo05aoo`03001oogoo0:5oo`005Goo
0`001Goo00<007ooOol0G7oo00<007ooOol0XGoo000FOol00`00Oomoo`04Ool00`00Oomoo`1LOol0
0`00Oomoo`2QOol001Ioo`03001oogoo00Aoo`8005eoo`03001oogoo0:5oo`005Woo00<007ooOol0
ogoo27oo000FOol00`00Oomoo`3oOol8Ool001Eoo`800?moo`Yoo`00ogoo8Goo003oOolQOol00?mo
ob5oo`003Woo10008Woo0`000goo0`001Goo0`002Goo0`000Woo10001goo0P000Woo0P000Woo1000
0Woo0`000goo0`000Woo10000goo1@0000=oo`0000000P000Woo1@001Woo0`0017oo0`000Woo1@00
00Aoo`00001oo`80009oo`D006eoo`003goo00<007ooOol08goo00<007ooOol00goo00<007ooOol0
1Goo00<007ooOol01goo00D007ooOomoo`00009oo`03001oogoo00Qoo`04001oo`000002Ool00`00
Oomoo`03Ool01`00Oomoogoo001oo`0000=oo`04001oogoo0004Ool01`00Oomoogoo001oo`0000Eo
o`05001oogooOol00007Ool01000Oomoo`000Woo00L007ooOomoo`00Ool00002Ool01000Oomoo`00
0Woo00@007ooOol000=oo`03001oogoo06aoo`000goo1@0000Moo`00Ool007oo001oo`040002Ool5
00000goo000000030002Ool30002Ool50002Ool500000goo000000020003Ool00`00Oomoo`05Ool0
0`00Oomoo`07Ool01@00Oomoogoo00000Woo00<007ooOol027oo0`000goo1@0000=oo`00Ool017oo
00D007ooOomoo`00009oo`03001oogoo009oo`06001oogooOol007oo1@0000=oo`00Ool00Woo00<0
07ooOol01goo0P000Woo00L007ooOomoo`00Ool00002Ool01000Oomoo`000Woo00@007ooOol000=o
o`03001oogoo06aoo`000goo00@007ooOol0009oo`07001oo`00Ool007oo00000goo00D007ooOomo
o`0000Eoo`03001oogoo009oo`06001oogoo001oo`000Woo00@007ooOol000=oo`04001oo`00Ool3
0003Ool30003Ool01@00Ool007oo00001goo00D007ooOomoo`00009oo`03001oogoo00Qoo`04001o
ogoo0002Ool01`00Oomoogoo001oo`0000=oo`03001oo`0000=oo`03001oogoo008000=oo`07001o
ogooOol007oo00000goo00<007oo00000goo00<007ooOol01Goo0P0017oo00L007ooOomoo`00Ool0
0002Ool01000Oomoo`000Woo00@007ooOol000=oo`03001oogoo06aoo`000goo10000Woo00L007oo
001oo`00Ool00003Ool01@00Oomoogoo00001Goo00<007ooOol00Woo00<007ooOol00Woo00@007oo
Ool0009oo`06001oogooOol007oo1@000goo00<007ooOol00goo00D007oo001oo`0000Qoo`<0009o
o`@000Qoo`04001oogoo0003Ool30003Ool40002Ool30002Ool200000goo00000002Ool40002Ool3
0003Ool40007Ool01000Oomoo`000goo0`0000Aoo`00001oo`800003Ool0000000<000=oo`@006io
o`001Woo00X007ooOol007oo001oo`00Ool000=oo`05001oogooOol00005Ool00`00Oomoo`02Ool0
0`00Oomoo`02Ool01000Oomoo`000Woo00H007ooOomoo`00Ool600000goo000000030002Ool5000>
Ool00`00Oomoo`07Ool4000OOol00`00Oomoo`09Ool00`00Oomoo`06Ool3000HOol00`00Oomoo`1/
Ool000Aoo`<00003Ool0000000T000Aoo`03001oogoo009oo`8000=oo`@00004Ool00000Ool20003
Ool40002Ool3000MOol3000YOol2000:Ool2000ROol2001^Ool001Moo`03001oogoo00Qoo`03001o
ogoo00aoo`03001oogoo0>aoo`005Goo0`001Goo00<007ooOol00Woo00<007ooOol02goo0P00kWoo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00ogoo8Goo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {946.587, -0.14072, 0.462505, 
  0.00748348}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-9.5 0.01 0 0.618034 [
[.3 -0.0125 -9 -9 ]
[.3 -0.0125 9 0 ]
[.5 -0.0125 -12 -9 ]
[.5 -0.0125 12 0 ]
[.7 -0.0125 -12 -9 ]
[.7 -0.0125 12 0 ]
[.9 -0.0125 -12 -9 ]
[.9 -0.0125 12 0 ]
[1.025 0 0 -6 ]
[1.025 0 58 6 ]
[.0875 .12361 -18 -4.5 ]
[.0875 .12361 0 4.5 ]
[.0875 .24721 -18 -4.5 ]
[.0875 .24721 0 4.5 ]
[.0875 .37082 -18 -4.5 ]
[.0875 .37082 0 4.5 ]
[.0875 .49443 -18 -4.5 ]
[.0875 .49443 0 4.5 ]
[.0875 .61803 -6 -4.5 ]
[.0875 .61803 0 4.5 ]
[.1 .64303 -29 0 ]
[.1 .64303 29 12 ]
[.5 .63053 -65 0 ]
[.5 .63053 65 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.3 0 m
.3 .00625 L
s
[(980)] .3 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1000)] .5 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(1020)] .7 -0.0125 0 1 Mshowa
.9 0 m
.9 .00625 L
s
[(1040)] .9 -0.0125 0 1 Mshowa
.125 Mabswid
.15 0 m
.15 .00375 L
s
.2 0 m
.2 .00375 L
s
.25 0 m
.25 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.45 0 m
.45 .00375 L
s
.55 0 m
.55 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.75 0 m
.75 .00375 L
s
.8 0 m
.8 .00375 L
s
.85 0 m
.85 .00375 L
s
.05 0 m
.05 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(frequency) show
117.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.1 .12361 m
.10625 .12361 L
s
[(0.2)] .0875 .12361 1 0 Mshowa
.1 .24721 m
.10625 .24721 L
s
[(0.4)] .0875 .24721 1 0 Mshowa
.1 .37082 m
.10625 .37082 L
s
[(0.6)] .0875 .37082 1 0 Mshowa
.1 .49443 m
.10625 .49443 L
s
[(0.8)] .0875 .49443 1 0 Mshowa
.1 .61803 m
.10625 .61803 L
s
[(1)] .0875 .61803 1 0 Mshowa
.125 Mabswid
.1 .0309 m
.10375 .0309 L
s
.1 .0618 m
.10375 .0618 L
s
.1 .09271 m
.10375 .09271 L
s
.1 .15451 m
.10375 .15451 L
s
.1 .18541 m
.10375 .18541 L
s
.1 .21631 m
.10375 .21631 L
s
.1 .27812 m
.10375 .27812 L
s
.1 .30902 m
.10375 .30902 L
s
.1 .33992 m
.10375 .33992 L
s
.1 .40172 m
.10375 .40172 L
s
.1 .43262 m
.10375 .43262 L
s
.1 .46353 m
.10375 .46353 L
s
.1 .52533 m
.10375 .52533 L
s
.1 .55623 m
.10375 .55623 L
s
.1 .58713 m
.10375 .58713 L
s
.25 Mabswid
.1 0 m
.1 .61803 L
s
gsave
.1 .64303 -90 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(amplitude) show
117.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.5 .63053 -126 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(FFT) show
87.000000 13.000000 moveto
(of) show
105.000000 13.000000 moveto
(Recorded) show
159.000000 13.000000 moveto
(Sound) show
189.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .00399 m
.01 .01144 L
.02 .00815 L
.03 .00817 L
.04 .00529 L
.05 .00315 L
.06 .00416 L
.07 .00654 L
.08 .00757 L
.09 .01685 L
.1 .01015 L
.11 .008 L
.12 .00262 L
.13 .01064 L
.14 .00435 L
.15 .00568 L
.16 .01284 L
.17 .01091 L
.18 .00264 L
.19 .01248 L
.2 .01206 L
.21 .00892 L
.22 .00936 L
.23 .00624 L
.24 .00409 L
.25 .00995 L
.26 .01105 L
.27 .00303 L
.28 .00586 L
.29 .00523 L
.3 .01132 L
.31 .00668 L
.32 .00576 L
.33 .01054 L
.34 .01179 L
.35 .00684 L
.36 .00846 L
.37 .00454 L
.38 .00519 L
.39 .00887 L
.4 .01285 L
.41 .00816 L
.42 .00436 L
.43 .01889 L
.44 .00523 L
.45 .01442 L
.46 .00254 L
.47 .01637 L
.48 .02449 L
.49 .02469 L
Mistroke
.5 .01713 L
.51 .02753 L
.52 .08096 L
.53 .05489 L
.54 .61803 L
.55 .12196 L
.56 .05988 L
.57 .02961 L
.58 .02457 L
.59 .02762 L
.6 .01106 L
.61 .01743 L
.62 .0101 L
.63 .01398 L
.64 .0213 L
.65 .00308 L
.66 .01538 L
.67 .00775 L
.68 .00575 L
.69 .01299 L
.7 .01 L
.71 .01429 L
.72 .00473 L
.73 .01108 L
.74 .00614 L
.75 .01042 L
.76 .00273 L
.77 .00913 L
.78 .00209 L
.79 .01407 L
.8 .0119 L
.81 .01409 L
.82 .00568 L
.83 .0087 L
.84 .00751 L
.85 .00765 L
.86 .0064 L
.87 .01574 L
.88 .00993 L
.89 .0049 L
.9 .01288 L
.91 .00453 L
.92 .01326 L
.93 .0016 L
.94 .0101 L
.95 .001 L
.96 .00657 L
.97 .0097 L
.98 .00449 L
.99 .00276 L
Mistroke
1 .00373 L
Mfstroke
1 .00373 m
1 .00373 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
@7oo0`0017oo0P0017oo0P006Goo0`0017oo0P0017oo0P0017oo0P005Woo0`0017oo0P000goo1000
0goo0P005Woo0`0017oo0P0017oo0`000goo0P00CGoo0013Ool01000Oomoo`000Woo00@007ooOol0
009oo`03001oogoo01Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000Woo00@007oo
Ool001Ioo`03001oogoo009oo`04001oogoo0003Ool00`00Oomoo`02Ool01000Oomoo`005Woo00<0
07ooOol00Woo00@007ooOol000Aoo`05001oogooOol00002Ool00`00Oomoo`1:Ool0045oo`<0009o
o`04001oogoo0002Ool01000Oomoo`006Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo
0002Ool01000Oomoo`005Woo00<007ooOol00Woo00@007ooOol000Aoo`05001oogooOol00002Ool0
0`00Oomoo`0DOol00`00Oomoo`02Ool01000Oomoo`000Woo10000Woo00@007ooOol004aoo`00@7oo
00@007ooOol000=oo`8000=oo`04001oogoo000IOol00`00Oomoo`02Ool01000Oomoo`000Woo00@0
07ooOol0009oo`04001oogoo000FOol00`00Oomoo`02Ool01000Oomoo`001Goo00@007ooOol0009o
o`03001oogoo01Aoo`03001oogoo009oo`04001oogoo0002Ool00`00Ool00003Ool01000Oomoo`00
C7oo0010Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo000IOol00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol0009oo`04001oogoo000FOol00`00Oomoo`02Ool01000Oomoo`00
0Woo00@007ooOol0009oo`04001oogoo000FOol00`00Oomoo`02Ool01000Oomoo`000Woo00<007oo
00000goo00@007ooOol004aoo`00@Goo0P0017oo0P0017oo0P006Goo0P001Goo0P0017oo0P0017oo
0P005Woo0P001Goo0P0017oo0P0017oo0P005Woo0P001Goo0P0017oo0P0017oo0P00:Goo10005goo
0`001Woo003nOol00`00Oomoo`0GOol00`00Oomoo`05Ool00>Qoo`@0009oo`@000=oo`@0009oo`@0
0003Ool0000000<0009oo`@00004Ool00000Ool20002Ool30003Ool00`00Oomoo`04Ool00>Uoo`03
001oogoo00=oo`03001oogoo009oo`03001oogoo00=oo`07001oogooOol007oo00000Woo00@007oo
Ool000Eoo`04001oogoo0002Ool01@00Oomoogoo00000Woo00<007ooOol017oo0007OooI0009Ool0
0`00Oomoo`03Ool00`00Oomoo`02Ool500000goo001oo`02Ool00`00Ool00002Ool00`00Oomoo`05
00001Goo001oogoo00000Woo00<007ooOol00goo00<007oo00001Goo0007Ool00`00Oomoo`07Ool5
0007Ool00`00Oomoo`020003Ool30006Ool01@00Oomoogoo00001goo0P0000=oo`00Ool00Woo0P00
0Woo0P0000=oo`00Ool02Goo00<007ooOol01@000Woo00@007ooOomoo`8000=oo`05001oo`00Ool0
0008Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`08Ool01000Oomo
ogoo0P001Goo00@007oo0000009oo`8000=oo`03001oogoo00Qoo`03001oogoo00Eoo`04001oo`00
Ool20003Ool01000Oomoogoo0P0017oo1P002Goo00<007ooOol00goo0P000goo00L007ooOomoo`00
Ool00003Ool00`00Ool00002Ool01000Oomoo`000goo00<007oo00000Woo00@007ooOol000=oo`05
001oo`00Ool00005Ool000Qoo`03001oo`0000H000Eoo`<000Aoo`<0009oo`03001oo`00009oo`80
00Aoo`03001oo`0000=oo`L0009oo`05001oogooOol00002Ool20002Ool70004Ool40005Ool20002
Ool200000goo001oo`02Ool2000017oo001oo`001goo00<007ooOol07Goo0P000goo10000Woo00@0
07ooOol0009oo`03001oo`0000800004Ool007ooOol20002Ool00`00Oomoo`03Ool;0004Ool00`00
Ool000020002Ool01`00Ool007oo001oo`00009oo`@000ioo`@0009oo`800003Ool00000009oo`<0
00=oo`H00003Ool0000000=oo`<00003Ool0000000<000=oo`H00003Ool0000000Aoo`002Goo00<0
07ooOol03Goo00<007ooOol00P001Goo00<007ooOol00goo10000goo0`002Woo0`0027oo00<007oo
Ool00goo10002goo0P0017oo00<007oo00000Woo00D007ooOomoo`0001aoo`800003Ool000000080
009oo`06001oogoo001oo`0017oo1@0017oo00D007ooOomoo`0000Qoo`D000]oo`04001oo`000003
Ool00`00Oomoo`02Ool01@00Oomoogoo00005Woo00<007ooOol0=7oo000JOol200000goo001oo`15
Ool00`00Oomoo`06Ool00`00Oomoo`03Ool00`00Oomoo`0BOol01000Oomoo`0017oo00<007oo0000
0goo00<007ooOol0:Woo00<007ooOol08goo0`00=7oo000MOol00`00Oomoo`1>Ool01`00Oomoogoo
001oo`00019oo`03001oogoo00Moo`03001oogoo08aoo`007Goo00<007ooOol0Cgoo0`000goo00<0
07ooOol02goo1000VGoo000MOol00`00Oomoo`1EOol00`00Oomoo`0:Ool00`00Oomoo`2KOol001eo
o`03001oogoo05Eoo`03001oogoo00Yoo`03001oogoo09]oo`007Goo00<007ooOol0EGoo00<007oo
Ool02Goo00<007ooOol0W7oo000MOol00`00Oomoo`1FOol00`00Oomoo`08Ool00`00Oomoo`2LOol0
01eoo`03001oogoo05Ioo`03001oogoo00Qoo`03001oogoo09aoo`007Goo00<007ooOol0EWoo00@0
07ooOol000Ioo`03001oogoo09eoo`007Goo00<007ooOol0EWoo00@007ooOol000Ioo`03001oogoo
09eoo`007Goo00<007ooOol0EWoo00@007oo000000Ioo`03001oogoo09eoo`007Goo00<007ooOol0
EWoo00@007oo000000Ioo`03001oogoo09eoo`007Goo00<007ooOol0Egoo0`001Woo00<007ooOol0
WGoo000MOol00`00Oomoo`1GOol00`00Ool00005Ool00`00Oomoo`2NOol001eoo`03001oogoo05Mo
o`03001oo`0000Eoo`03001oogoo09ioo`007Goo00<007ooOol0FGoo00<007ooOol00goo00<007oo
Ool0WWoo000MOol00`00Oomoo`1IOol00`00Oomoo`03Ool00`00Oomoo`2NOol001eoo`03001oogoo
05Uoo`03001oogoo00=oo`03001oogoo09ioo`007Goo00<007ooOol0FGoo00<007ooOol00goo00<0
07ooOol0WWoo000MOol00`00Oomoo`1IOol00`00Oomoo`03Ool00`00Oomoo`2NOol001eoo`03001o
ogoo05Uoo`03001oogoo009oo`03001oogoo09moo`002Woo0P0017oo0P000goo100017oo00<007oo
Ool0FGoo00<007ooOol00Woo00<007ooOol0Wgoo0009Ool01000Oomoo`000goo0P0017oo00<007oo
Ool017oo00<007ooOol0FGoo00<007ooOol00Woo00<007ooOol0Wgoo0009Ool01000Oomoo`002Woo
00<007ooOol00goo0P00FWoo00<007ooOol00Woo00<007ooOol0Wgoo0009Ool01000Oomoo`002goo
00<007ooOol00Woo00<007ooOol0FGoo00<007ooOol00Woo00<007ooOol0Wgoo0009Ool01000Oomo
o`0027oo00@007ooOol000Aoo`03001oogoo05Uoo`03001oogoo009oo`03001oogoo09moo`002Woo
0P002Woo0P001Goo00<007ooOol0FGoo00<007ooOol00Woo00<007ooOol0Wgoo000MOol00`00Oomo
o`1IOol00`00Oomoo`02Ool00`00Oomoo`2OOol001eoo`03001oogoo05Uoo`03001oogoo009oo`03
001oogoo09moo`007Goo00<007ooOol0FWoo00D007ooOomoo`000:5oo`007Goo00<007ooOol0FWoo
00D007ooOomoo`000:5oo`007Goo00<007ooOol0FWoo00D007ooOomoo`000:5oo`007Goo00<007oo
Ool0FWoo00D007ooOomoo`000:5oo`007Goo00<007ooOol0FWoo00D007ooOomoo`000:5oo`007Goo
00<007ooOol0FWoo00D007ooOomoo`000:5oo`007Goo00<007ooOol0FWoo00D007ooOomoo`000:5o
o`007Goo00<007ooOol0FWoo00D007ooOomoo`000:5oo`007Goo00<007ooOol0FWoo00D007ooOomo
o`000:5oo`007Goo00<007ooOol0FWoo00D007ooOomoo`000:5oo`007Goo00<007ooOol0FWoo00D0
07ooOomoo`000:5oo`007Goo00<007ooOol0FWoo00D007ooOomoo`000:5oo`007Goo00<007ooOol0
FWoo00D007ooOomoo`000:5oo`007Goo00<007ooOol0FWoo00D007ooOomoo`000:5oo`007Goo00<0
07ooOol0FWoo00D007ooOomoo`000:5oo`007Goo00<007ooOol0FWoo00D007ooOomoo`000:5oo`00
7Goo00<007ooOol0FWoo00D007ooOomoo`000:5oo`007Goo00<007ooOol0FWoo00D007ooOomoo`00
0:5oo`007Goo00<007ooOol0FWoo00D007ooOomoo`000:5oo`002Woo0P0017oo0P0017oo0`0017oo
00<007ooOol0FWoo00D007ooOomoo`000:5oo`002Goo00@007ooOol000=oo`8000Eoo`03001oogoo
00=oo`03001oogoo05Yoo`05001oogooOol0002QOol000Uoo`04001oogoo0008Ool40004Ool2001K
Ool01@00Oomoogoo0000XGoo0009Ool01000Oomoo`0027oo00<007oo00001Goo00<007ooOol0FWoo
00@007ooOol00:9oo`002Goo00@007ooOol000Qoo`03001oo`0000Eoo`03001oogoo05Yoo`04001o
ogoo002ROol000Yoo`8000Yoo`8000Eoo`03001oogoo05Yoo`04001oogoo002ROol001eoo`03001o
ogoo05Yoo`04001oogoo002ROol001eoo`03001oogoo05Yoo`04001oogoo002ROol001eoo`03001o
ogoo05Yoo`04001oogoo002ROol001eoo`03001oogoo05Yoo`04001oogoo002ROol001eoo`03001o
ogoo05Yoo`04001oogoo002ROol001eoo`03001oogoo05Yoo`04001oogoo002ROol001eoo`03001o
ogoo05Yoo`04001oogoo002ROol001eoo`03001oogoo05Yoo`04001oogoo002ROol001eoo`03001o
ogoo05Yoo`04001oogoo002ROol001eoo`03001oogoo05Yoo`04001oogoo002ROol001eoo`03001o
ogoo05Yoo`04001oogoo002ROol001eoo`03001oogoo05Yoo`04001oogoo002ROol001eoo`03001o
ogoo05Yoo`04001oogoo002ROol001eoo`03001oogoo05Yoo`04001oogoo002ROol001eoo`03001o
ogoo05Yoo`04001oogoo002ROol001eoo`03001oogoo05Yoo`04001oogoo002ROol001eoo`03001o
ogoo05]oo`03001oo`000:9oo`007Goo00<007ooOol0Fgoo00<007oo0000XWoo000MOol00`00Oomo
o`1KOol00`00Ool0002ROol001eoo`03001oogoo05]oo`03001oo`000:9oo`007Goo00<007ooOol0
Fgoo00<007oo0000XWoo000:Ool20004Ool20004Ool20005Ool00`00Oomoo`1KOol00`00Ool0002R
Ool000Uoo`04001oogoo0003Ool20003Ool01000Oomoo`0017oo00<007ooOol0Fgoo00<007oo0000
XWoo0009Ool01000Oomoo`0027oo00@007ooOol000Aoo`8005aoo`03001oo`000:9oo`002Goo00@0
07ooOol000Qoo`<000Eoo`03001oogoo05]oo`03001oo`000:9oo`002Goo00@007ooOol000Qoo`03
001oogoo00Eoo`03001oogoo05]oo`03001oo`000:9oo`002Woo0P002Woo0`0017oo00<007ooOol0
Fgoo00<007oo0000XWoo000MOol00`00Oomoo`1KOol00`00Ool0002ROol001eoo`03001oogoo05]o
o`03001oo`000:9oo`007Goo00<007ooOol0Fgoo00<007oo0000XWoo000MOol00`00Oomoo`1KOol0
0`00Ool0002ROol001eoo`03001oogoo05]oo`03001oo`000:9oo`007Goo00<007ooOol0Fgoo00<0
07oo0000XWoo000MOol00`00Oomoo`1KOol00`00Ool0002ROol001eoo`03001oogoo05]oo`03001o
o`000:9oo`007Goo00<007ooOol0Fgoo00<007oo0000XWoo000MOol00`00Oomoo`1KOol00`00Ool0
002ROol001eoo`03001oogoo05]oo`03001oo`000:9oo`007Goo00<007ooOol0Fgoo00<007oo0000
XWoo000MOol00`00Oomoo`1KOol00`00Ool0002ROol001eoo`03001oogoo05]oo`03001oo`000:9o
o`007Goo00<007ooOol0Fgoo00<007oo0000XWoo000MOol00`00Oomoo`1KOol00`00Ool0002ROol0
01eoo`03001oogoo05]oo`03001oo`000:9oo`007Goo00<007ooOol0Fgoo00<007oo0000XWoo000M
Ool00`00Oomoo`1KOol00`00Ool0002ROol001eoo`03001oogoo05]oo`03001oo`000:9oo`002Woo
0P0017oo0P0017oo0P001Goo00<007ooOol0Fgoo00<007oo0000XWoo0009Ool01000Oomoo`000goo
0P000goo00@007ooOol000Aoo`03001oogoo05]oo`03001oo`000:9oo`002Goo00@007ooOol000Qo
o`04001oogoo0004Ool2001LOol00`00Ool0002ROol000Uoo`04001oogoo0009Ool20005Ool00`00
Oomoo`1KOol2002SOol000Uoo`04001oogoo0008Ool01000Oomoo`0017oo00<007ooOol0Fgoo0P00
Xgoo000:Ool2000:Ool20005Ool00`00Oomoo`1KOol2002SOol001eoo`03001oogoo05]oo`800:=o
o`007Goo00<007ooOol0Fgoo0P00Xgoo000MOol00`00Oomoo`1KOol2002SOol001eoo`03001oogoo
05]oo`800:=oo`007Goo00<007ooOol0G7oo00<007ooOol0XGoo000MOol00`00Oomoo`1LOol00`00
Oomoo`2QOol001eoo`03001oogoo05aoo`03001oogoo0:5oo`007Goo00<007ooOol0G7oo00<007oo
Ool0XGoo000MOol00`00Oomoo`1LOol00`00Oomoo`2QOol001eoo`03001oogoo05aoo`03001oogoo
0:5oo`007Goo00<007ooOol0G7oo00<007ooOol0XGoo000MOol00`00Oomoo`1LOol00`00Oomoo`2Q
Ool001eoo`03001oogoo05aoo`03001oogoo0:5oo`007Goo00<007ooOol0G7oo00<007ooOol0XGoo
000MOol00`00Oomoo`1LOol00`00Oomoo`2QOol001eoo`03001oogoo05aoo`03001oogoo0:5oo`00
7Goo00<007ooOol0G7oo00<007ooOol0XGoo000MOol00`00Oomoo`1LOol00`00Oomoo`2QOol001eo
o`03001oogoo05aoo`03001oogoo0:5oo`007Goo00<007ooOol0G7oo00<007ooOol0XGoo000MOol0
0`00Oomoo`1LOol00`00Oomoo`2QOol001Eoo`<000Eoo`03001oogoo05aoo`03001oogoo0:5oo`00
5Woo00<007ooOol017oo00<007ooOol0G7oo00<007ooOol0XGoo000FOol00`00Oomoo`04Ool2001M
Ool00`00Oomoo`2QOol001Ioo`03001oogoo0?moo`Qoo`005Woo00<007ooOol0ogoo27oo000EOol2
003oOol:Ool00?moob5oo`00ogoo8Goo003oOolQOol000ioo`@0029oo`<000=oo`<000Eoo`<000Uo
o`<0009oo`@000Moo`80009oo`80009oo`@0009oo`<000=oo`<0009oo`@000=oo`D00003Ool00000
0080009oo`D000Ioo`<000Aoo`<0009oo`D00004Ool00000Ool20002Ool5001]Ool000moo`03001o
ogoo02=oo`03001oogoo00=oo`03001oogoo00Eoo`03001oogoo00Moo`05001oogooOol00002Ool0
0`00Oomoo`08Ool01000Ool000000Woo00<007ooOol00goo00L007ooOomoo`00Ool00003Ool01000
Oomoo`0017oo00L007ooOomoo`00Ool00005Ool01@00Oomoogoo00001goo00@007ooOol0009oo`07
001oogooOol007oo00000Woo00@007ooOol0009oo`04001oogoo0003Ool00`00Oomoo`1/Ool000=o
o`D00007Ool007oo001oo`00Ool010000Woo1@0000=oo`0000000`000Woo0`000Woo1@000Woo1@00
00=oo`0000000P000goo00<007ooOol01Goo00<007ooOol01goo00D007ooOomoo`00009oo`03001o
ogoo00Qoo`<000=oo`D00003Ool007oo00Aoo`05001oogooOol00002Ool00`00Oomoo`02Ool01P00
Oomoogoo001oo`D00003Ool007oo009oo`03001oogoo00Moo`80009oo`07001oogooOol007oo0000
0Woo00@007ooOol0009oo`04001oogoo0003Ool00`00Oomoo`1/Ool000=oo`04001oogoo0002Ool0
1`00Ool007oo001oo`0000=oo`05001oogooOol00005Ool00`00Oomoo`02Ool01P00Oomoo`00Ool0
009oo`04001oogoo0003Ool01000Ool007oo0`000goo0`000goo00D007oo001oo`0000Moo`05001o
ogooOol00002Ool00`00Oomoo`08Ool01000Oomoo`000Woo00L007ooOomoo`00Ool00003Ool00`00
Ool00003Ool00`00Oomoo`020003Ool01`00Oomoogoo001oo`0000=oo`03001oo`0000=oo`03001o
ogoo00Eoo`8000Aoo`07001oogooOol007oo00000Woo00@007ooOol0009oo`04001oogoo0003Ool0
0`00Oomoo`1/Ool000=oo`@0009oo`07001oo`00Ool007oo00000goo00D007ooOomoo`0000Eoo`03
001oogoo009oo`03001oogoo009oo`04001oogoo0002Ool01P00Oomoogoo001oo`D000=oo`03001o
ogoo00=oo`05001oo`00Ool00008Ool30002Ool40008Ool01000Oomoo`000goo0`000goo10000Woo
0`000Woo0P0000=oo`0000000Woo10000Woo0`000goo10001goo00@007ooOol000=oo`<00004Ool0
0000Ool200000goo000000030003Ool4001^Ool000Ioo`0:001oogoo001oo`00Ool007oo0003Ool0
1@00Oomoogoo00001Goo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`06001oogoo
Ool007oo1P0000=oo`0000000`000Woo1@003Woo00<007ooOol01goo10007goo00<007ooOol02Goo
00<007ooOol01Woo0`0067oo00<007ooOol0K7oo0004Ool300000goo000000090004Ool00`00Oomo
o`02Ool20003Ool4000017oo000007oo0P000goo10000Woo0`007Goo0`00:Goo0P002Woo0P008Woo
0P00KWoo000GOol00`00Oomoo`08Ool00`00Oomoo`0<Ool00`00Oomoo`3/Ool001Eoo`<000Eoo`03
001oogoo009oo`03001oogoo00]oo`800>ioo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {946.587, -0.14072, 0.462505, 
  0.00748348}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-9.5 0.01 0 0.618034 [
[.3 -0.0125 -9 -9 ]
[.3 -0.0125 9 0 ]
[.5 -0.0125 -12 -9 ]
[.5 -0.0125 12 0 ]
[.7 -0.0125 -12 -9 ]
[.7 -0.0125 12 0 ]
[.9 -0.0125 -12 -9 ]
[.9 -0.0125 12 0 ]
[1.025 0 0 -6 ]
[1.025 0 58 6 ]
[.0875 .12361 -18 -4.5 ]
[.0875 .12361 0 4.5 ]
[.0875 .24721 -18 -4.5 ]
[.0875 .24721 0 4.5 ]
[.0875 .37082 -18 -4.5 ]
[.0875 .37082 0 4.5 ]
[.0875 .49443 -18 -4.5 ]
[.0875 .49443 0 4.5 ]
[.0875 .61803 -6 -4.5 ]
[.0875 .61803 0 4.5 ]
[.1 .64303 -29 0 ]
[.1 .64303 29 12 ]
[.5 .63053 -65 0 ]
[.5 .63053 65 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.3 0 m
.3 .00625 L
s
[(980)] .3 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1000)] .5 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(1020)] .7 -0.0125 0 1 Mshowa
.9 0 m
.9 .00625 L
s
[(1040)] .9 -0.0125 0 1 Mshowa
.125 Mabswid
.15 0 m
.15 .00375 L
s
.2 0 m
.2 .00375 L
s
.25 0 m
.25 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.45 0 m
.45 .00375 L
s
.55 0 m
.55 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.75 0 m
.75 .00375 L
s
.8 0 m
.8 .00375 L
s
.85 0 m
.85 .00375 L
s
.05 0 m
.05 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(frequency) show
117.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.1 .12361 m
.10625 .12361 L
s
[(0.2)] .0875 .12361 1 0 Mshowa
.1 .24721 m
.10625 .24721 L
s
[(0.4)] .0875 .24721 1 0 Mshowa
.1 .37082 m
.10625 .37082 L
s
[(0.6)] .0875 .37082 1 0 Mshowa
.1 .49443 m
.10625 .49443 L
s
[(0.8)] .0875 .49443 1 0 Mshowa
.1 .61803 m
.10625 .61803 L
s
[(1)] .0875 .61803 1 0 Mshowa
.125 Mabswid
.1 .0309 m
.10375 .0309 L
s
.1 .0618 m
.10375 .0618 L
s
.1 .09271 m
.10375 .09271 L
s
.1 .15451 m
.10375 .15451 L
s
.1 .18541 m
.10375 .18541 L
s
.1 .21631 m
.10375 .21631 L
s
.1 .27812 m
.10375 .27812 L
s
.1 .30902 m
.10375 .30902 L
s
.1 .33992 m
.10375 .33992 L
s
.1 .40172 m
.10375 .40172 L
s
.1 .43262 m
.10375 .43262 L
s
.1 .46353 m
.10375 .46353 L
s
.1 .52533 m
.10375 .52533 L
s
.1 .55623 m
.10375 .55623 L
s
.1 .58713 m
.10375 .58713 L
s
.25 Mabswid
.1 0 m
.1 .61803 L
s
gsave
.1 .64303 -90 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(amplitude) show
117.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.5 .63053 -126 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(FFT) show
87.000000 13.000000 moveto
(of) show
105.000000 13.000000 moveto
(Recorded) show
159.000000 13.000000 moveto
(Sound) show
189.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .00662 m
.01 .00049 L
.02 .00412 L
.03 .00395 L
.04 .005 L
.05 .00413 L
.06 .00302 L
.07 .00833 L
.08 .00857 L
.09 .01312 L
.1 .00913 L
.11 .00882 L
.12 .00566 L
.13 .00679 L
.14 .00907 L
.15 .00783 L
.16 .0072 L
.17 .00376 L
.18 .00741 L
.19 .00703 L
.2 .00867 L
.21 .00935 L
.22 .00877 L
.23 .00913 L
.24 .0036 L
.25 .00819 L
.26 .0075 L
.27 .00613 L
.28 .01414 L
.29 .01309 L
.3 .00719 L
.31 .00864 L
.32 .00625 L
.33 .01059 L
.34 .01515 L
.35 .01167 L
.36 .00748 L
.37 .01416 L
.38 .02064 L
.39 .01861 L
.4 .01129 L
.41 .02068 L
.42 .01199 L
.43 .02437 L
.44 .02147 L
.45 .02672 L
.46 .02745 L
.47 .03114 L
.48 .03565 L
.49 .04261 L
Mistroke
.5 .06217 L
.51 .08666 L
.52 .21178 L
.53 .35759 L
.54 .61803 L
.55 .13966 L
.56 .10185 L
.57 .05695 L
.58 .04574 L
.59 .04006 L
.6 .03301 L
.61 .03335 L
.62 .02765 L
.63 .02316 L
.64 .02483 L
.65 .01776 L
.66 .01947 L
.67 .01532 L
.68 .01486 L
.69 .01763 L
.7 .0139 L
.71 .0121 L
.72 .01402 L
.73 .01463 L
.74 .00896 L
.75 .00737 L
.76 .00945 L
.77 .00836 L
.78 .00727 L
.79 .01096 L
.8 .01187 L
.81 .0066 L
.82 .0091 L
.83 .00875 L
.84 .00811 L
.85 .01092 L
.86 .0096 L
.87 .01225 L
.88 .00843 L
.89 .01049 L
.9 .00936 L
.91 .01166 L
.92 .00689 L
.93 .0059 L
.94 .00939 L
.95 .00641 L
.96 .00679 L
.97 .00619 L
.98 .00713 L
.99 .00991 L
Mistroke
1 .01043 L
Mfstroke
1 .01043 m
1 .01043 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
@7oo0`0017oo0P0017oo0P006Goo0`0017oo0P0017oo0P0017oo0P005Woo0`0017oo0P000goo1000
0goo0P005Woo0`0017oo0P0017oo0`000goo0P00CGoo0013Ool01000Oomoo`000Woo00@007ooOol0
009oo`03001oogoo01Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000Woo00@007oo
Ool001Ioo`03001oogoo009oo`04001oogoo0003Ool00`00Oomoo`02Ool01000Oomoo`005Woo00<0
07ooOol00Woo00@007ooOol000Aoo`05001oogooOol00002Ool00`00Oomoo`1:Ool0045oo`<0009o
o`04001oogoo0002Ool01000Oomoo`006Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo
0002Ool01000Oomoo`005Woo00<007ooOol00Woo00@007ooOol000Aoo`05001oogooOol00002Ool0
0`00Oomoo`0DOol00`00Oomoo`02Ool01000Oomoo`000Woo10000Woo00@007ooOol004aoo`00@7oo
00@007ooOol000=oo`8000=oo`04001oogoo000IOol00`00Oomoo`02Ool01000Oomoo`000Woo00@0
07ooOol0009oo`04001oogoo000FOol00`00Oomoo`02Ool01000Oomoo`001Goo00@007ooOol0009o
o`03001oogoo01Aoo`03001oogoo009oo`04001oogoo0002Ool00`00Ool00003Ool01000Oomoo`00
C7oo0010Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo000IOol00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol0009oo`04001oogoo000FOol00`00Oomoo`02Ool01000Oomoo`00
0Woo00@007ooOol0009oo`04001oogoo000FOol00`00Oomoo`02Ool01000Oomoo`000Woo00<007oo
00000goo00@007ooOol004aoo`00@Goo0P0017oo0P0017oo0P006Goo0P001Goo0P0017oo0P0017oo
0P005Woo0P001Goo0P0017oo0P0017oo0P005Woo0P001Goo0P0017oo0P0017oo0P00:Goo10005goo
0`001Woo003nOol00`00Oomoo`0GOol00`00Oomoo`05Ool00>Qoo`@0009oo`@000=oo`@0009oo`@0
0003Ool0000000<0009oo`@00004Ool00000Ool20002Ool30003Ool00`00Oomoo`04Ool00>Uoo`03
001oogoo00=oo`03001oogoo009oo`03001oogoo00=oo`07001oogooOol007oo00000Woo00@007oo
Ool000Eoo`04001oogoo0002Ool01@00Oomoogoo00000Woo00<007ooOol017oo0007OooI0009Ool0
0`00Oomoo`03Ool00`00Oomoo`02Ool500000goo001oo`02Ool00`00Ool00002Ool00`00Oomoo`05
00001Goo001oogoo00000Woo00<007ooOol00goo00<007oo00001Goo0008Ool00`00Oomoo`0;0007
Ool00`00Oomoo`07Ool01000Oomoogoo0`0017oo00<007ooOol01Goo10002Woo00<007ooOol027oo
00<007ooOol01goo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo
00<007ooOol01goo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo
00<007ooOol01goo00<007ooOol027oo00<007ooOol04Woo00<007ooOol00goo0P000goo00L007oo
Oomoo`00Ool00003Ool00`00Ool00002Ool01000Oomoo`000goo00<007oo00000Woo00@007ooOol0
00=oo`05001oo`00Ool00005Ool000Moo`03001oogoo00aoo`@0009oo`l000=oo``000=oo`H000Ao
o`L000Ioo`<001aoo`03001oogoo02Qoo`03001oogoo00Ioo`/000=oo`X00005Ool00000001oo`03
00000goo0000000200000goo0000000>0002Ool00`00Oomoo`06Ool40002Ool200000goo00000002
Ool30003Ool600000goo00000003Ool300000goo000000030003Ool600000goo00000004Ool001Yo
o`800003Ool007oo02Aoo`@000Moo`80009oo`8000=oo`03001oogoo009oo`<000=oo`03001oogoo
03Qoo`P00003Ool007oo00Yoo`<000Yoo`05001oogooOol00003Ool00`00Oomoo`02Ool00`00Oomo
o`0>Ool30009Ool00`00Oomoo`0dOol001eoo`03001oogoo031oo`8000Ioo`04001oo`000003Ool0
1000Ool00000<7oo0`0000=oo`000000100027oo00<007ooOol0@Goo0`00=7oo000MOol00`00Oomo
o`0iOol00`00Oomoo`04Ool01@00Oomoo`00Ool00`009Woo0`0000=oo`00Ool00Woo00<007ooOol0
Qgoo000MOol00`00Oomoo`14Ool01000Oomoogoo1@0087oo00D007ooOomoo`0008ioo`007Goo00<0
07ooOol0CGoo0P007Goo00<007ooOol0TGoo000MOol00`00Oomoo`1?Ool00`00Oomoo`0FOol4002D
Ool001eoo`03001oogoo051oo`03001oogoo019oo`<009Qoo`007Goo00<007ooOol0DGoo00<007oo
Ool047oo00<007ooOol0VGoo000MOol00`00Oomoo`1AOol00`00Oomoo`0@Ool00`00Oomoo`2IOol0
01eoo`03001oogoo059oo`03001oogoo00ioo`03001oogoo09Yoo`007Goo00<007ooOol0DWoo00<0
07ooOol03Goo00<007ooOol0Vgoo000MOol00`00Oomoo`1COol00`00Oomoo`0<Ool00`00Oomoo`2K
Ool001eoo`03001oogoo05=oo`03001oogoo00aoo`03001oogoo09]oo`007Goo00<007ooOol0E7oo
00<007ooOol02Woo00<007ooOol0W7oo000MOol00`00Oomoo`1DOol00`00Oomoo`0:Ool00`00Oomo
o`2LOol001eoo`03001oogoo05Aoo`03001oogoo00Yoo`03001oogoo09aoo`007Goo00<007ooOol0
EGoo00<007ooOol02Goo00<007ooOol0W7oo000MOol00`00Oomoo`1EOol00`00Oomoo`09Ool00`00
Oomoo`2LOol001eoo`03001oogoo05Eoo`03001oogoo00Qoo`03001oogoo09eoo`007Goo00<007oo
Ool0EGoo00<007ooOol027oo00<007ooOol0WGoo000MOol00`00Oomoo`1EOol00`00Oomoo`08Ool0
0`00Oomoo`2MOol001eoo`03001oogoo05Eoo`03001oogoo00Qoo`03001oogoo09eoo`002Woo0P00
17oo0P000goo100017oo00<007ooOol0EGoo00<007ooOol01goo00<007ooOol0WWoo0009Ool01000
Oomoo`000goo0P0017oo00<007ooOol017oo00<007ooOol0EGoo00<007ooOol01goo00<007ooOol0
WWoo0009Ool01000Oomoo`002Woo00<007ooOol00goo0P00Egoo00<007ooOol01Woo00<007ooOol0
WWoo0009Ool01000Oomoo`002goo00<007ooOol00Woo00<007ooOol0EWoo00<007ooOol01Woo00<0
07ooOol0WWoo0009Ool01000Oomoo`0027oo00@007ooOol000Aoo`03001oogoo05Ioo`03001oogoo
00Ioo`03001oogoo09ioo`002Woo0P002Woo0P001Goo00<007ooOol0EWoo00<007ooOol01Goo00<0
07ooOol0Wgoo000MOol00`00Oomoo`1FOol00`00Oomoo`05Ool00`00Oomoo`2OOol001eoo`03001o
ogoo05Ioo`03001oogoo00Eoo`03001oogoo09moo`007Goo00<007ooOol0EWoo00<007ooOol01Goo
00<007ooOol0Wgoo000MOol00`00Oomoo`1FOol00`00Oomoo`05Ool00`00Oomoo`2OOol001eoo`03
001oogoo05Ioo`03001oogoo00Eoo`03001oogoo09moo`007Goo00<007ooOol0EWoo00<007ooOol0
1Goo00<007ooOol0Wgoo000MOol00`00Oomoo`1FOol00`00Oomoo`05Ool00`00Oomoo`2OOol001eo
o`03001oogoo05Ioo`03001oogoo00Eoo`03001oogoo09moo`007Goo00<007ooOol0EWoo00<007oo
Ool01Goo00<007ooOol0Wgoo000MOol00`00Oomoo`1GOol00`00Oomoo`04Ool00`00Oomoo`2OOol0
01eoo`03001oogoo05Moo`03001oogoo00Aoo`03001oogoo09moo`007Goo00<007ooOol0Egoo00<0
07ooOol017oo00<007ooOol0Wgoo000MOol00`00Oomoo`1GOol00`00Oomoo`04Ool00`00Oomoo`2O
Ool001eoo`03001oogoo05Moo`03001oogoo00Aoo`03001oogoo09moo`007Goo00<007ooOol0Egoo
00<007ooOol017oo00<007ooOol0Wgoo000MOol00`00Oomoo`1GOol00`00Oomoo`04Ool00`00Oomo
o`2OOol001eoo`03001oogoo05Moo`03001oogoo00Aoo`03001oogoo09moo`007Goo00<007ooOol0
Egoo00<007ooOol017oo00<007ooOol0Wgoo000MOol00`00Oomoo`1GOol00`00Oomoo`04Ool00`00
Oomoo`2OOol001eoo`03001oogoo05Moo`03001oogoo00Aoo`03001oogoo09moo`007Goo00<007oo
Ool0Egoo00<007ooOol017oo00<007ooOol0Wgoo000:Ool20004Ool20004Ool30004Ool00`00Oomo
o`1GOol00`00Oomoo`04Ool00`00Oomoo`2OOol000Uoo`04001oogoo0003Ool20005Ool00`00Oomo
o`03Ool00`00Oomoo`1GOol00`00Oomoo`04Ool00`00Oomoo`2OOol000Uoo`04001oogoo0008Ool4
0004Ool2001HOol00`00Oomoo`04Ool00`00Oomoo`2OOol000Uoo`04001oogoo0008Ool00`00Ool0
0005Ool00`00Oomoo`1HOol00`00Oomoo`03Ool00`00Oomoo`2OOol000Uoo`04001oogoo0008Ool0
0`00Ool00005Ool00`00Oomoo`1HOol00`00Oomoo`03Ool00`00Oomoo`2OOol000Yoo`8000Yoo`80
00Eoo`03001oogoo05Qoo`03001oogoo00=oo`03001oogoo09moo`007Goo00<007ooOol0F7oo00<0
07ooOol00Woo00<007ooOol0X7oo000MOol00`00Oomoo`1HOol00`00Oomoo`02Ool00`00Oomoo`2P
Ool001eoo`03001oogoo05Qoo`03001oogoo009oo`03001oogoo0:1oo`007Goo00<007ooOol0F7oo
00<007ooOol00Woo00<007ooOol0X7oo000MOol00`00Oomoo`1HOol00`00Oomoo`02Ool00`00Oomo
o`2POol001eoo`03001oogoo05Qoo`03001oogoo009oo`03001oogoo0:1oo`007Goo00<007ooOol0
F7oo00<007ooOol00Woo00<007ooOol0X7oo000MOol00`00Oomoo`1HOol00`00Oomoo`02Ool00`00
Oomoo`2POol001eoo`03001oogoo05Qoo`03001oogoo009oo`03001oogoo0:1oo`007Goo00<007oo
Ool0F7oo00<007ooOol00Woo00<007ooOol0X7oo000MOol00`00Oomoo`1HOol00`00Oomoo`02Ool0
0`00Oomoo`2POol001eoo`03001oogoo05Qoo`03001oogoo009oo`03001oogoo0:1oo`007Goo00<0
07ooOol0F7oo00<007ooOol00Woo00<007ooOol0X7oo000MOol00`00Oomoo`1IOol01@00Oomoogoo
0000XWoo000MOol00`00Oomoo`1IOol01@00Oomoogoo0000XWoo000MOol00`00Oomoo`1IOol01@00
Oomoogoo0000XWoo000MOol00`00Oomoo`1IOol01@00Oomoogoo0000XWoo000MOol00`00Oomoo`1I
Ool01@00Oomoogoo0000XWoo000MOol00`00Oomoo`1IOol01@00Oomoogoo0000XWoo000MOol00`00
Oomoo`1IOol01@00Oomoogoo0000XWoo000MOol00`00Oomoo`1IOol01@00Oomoogoo0000XWoo000:
Ool20004Ool20004Ool20005Ool00`00Oomoo`1IOol01@00Oomoogoo0000XWoo0009Ool01000Oomo
o`000goo0P000goo00@007ooOol000Aoo`03001oogoo05Uoo`05001oogooOol0002ROol000Uoo`04
001oogoo0008Ool01000Oomoo`0017oo0P00FWoo00D007ooOomoo`000:9oo`002Goo00@007ooOol0
00Qoo`<000Eoo`03001oogoo05Uoo`05001oogooOol0002ROol000Uoo`04001oogoo0008Ool00`00
Oomoo`05Ool00`00Oomoo`1IOol01@00Oomoogoo0000XWoo000:Ool2000:Ool30004Ool00`00Oomo
o`1IOol01@00Oomoogoo0000XWoo000MOol00`00Oomoo`1IOol01@00Oomoogoo0000XWoo000MOol0
0`00Oomoo`1IOol01@00Oomoogoo0000XWoo000MOol00`00Oomoo`1IOol01@00Oomoogoo0000XWoo
000MOol00`00Oomoo`1JOol01000Oomoo`00XWoo000MOol00`00Oomoo`1JOol01000Oomoo`00XWoo
000MOol00`00Oomoo`1JOol01000Oomoo`00XWoo000MOol00`00Oomoo`1JOol01000Oomoo`00XWoo
000MOol00`00Oomoo`1JOol01000Oomoo`00XWoo000MOol00`00Oomoo`1JOol01000Oomoo`00XWoo
000MOol00`00Oomoo`1JOol01000Oomoo`00XWoo000MOol00`00Oomoo`1JOol01000Oomoo`00XWoo
000MOol00`00Oomoo`1JOol01000Oomoo`00XWoo000MOol00`00Oomoo`1JOol01000Oomoo`00XWoo
000MOol00`00Oomoo`1JOol01000Oomoo`00XWoo000MOol00`00Oomoo`1JOol01000Oomoo`00XWoo
000MOol00`00Oomoo`1JOol01000Oomoo`00XWoo000MOol00`00Oomoo`1JOol01000Oomoo`00XWoo
000MOol00`00Oomoo`1JOol01000Oomoo`00XWoo000MOol00`00Oomoo`1JOol01000Oomoo`00XWoo
000MOol00`00Oomoo`1JOol01000Oomoo`00XWoo000:Ool20004Ool20004Ool20005Ool00`00Oomo
o`1JOol01000Oomoo`00XWoo0009Ool01000Oomoo`000goo0P000goo00@007ooOol000Aoo`03001o
ogoo05Yoo`04001oogoo002ROol000Uoo`04001oogoo0008Ool01000Oomoo`0017oo0P00G7oo00<0
07oo0000XWoo0009Ool01000Oomoo`002Goo0P001Goo00<007ooOol0Fgoo00<007oo0000XWoo0009
Ool01000Oomoo`0027oo00@007ooOol000Aoo`03001oogoo05]oo`800:=oo`002Woo0P002Woo0P00
1Goo00<007ooOol0Fgoo0P00Xgoo000MOol00`00Oomoo`1KOol2002SOol001eoo`03001oogoo05]o
o`800:=oo`007Goo00<007ooOol0Fgoo0P00Xgoo000MOol00`00Oomoo`1KOol2002SOol001eoo`03
001oogoo05]oo`800:=oo`007Goo00<007ooOol0Fgoo0P00Xgoo000MOol00`00Oomoo`1KOol2002S
Ool001eoo`03001oogoo05]oo`800:=oo`007Goo00<007ooOol0Fgoo0P00Xgoo000MOol00`00Oomo
o`1KOol2002SOol001eoo`03001oogoo05]oo`800:=oo`007Goo00<007ooOol0Fgoo0P00Xgoo000M
Ool00`00Oomoo`1KOol2002SOol001eoo`03001oogoo05]oo`800:=oo`007Goo00<007ooOol0Fgoo
0P00Xgoo000MOol00`00Oomoo`1LOol00`00Oomoo`2QOol001eoo`03001oogoo05aoo`03001oogoo
0:5oo`007Goo00<007ooOol0G7oo00<007ooOol0XGoo000MOol00`00Oomoo`1LOol00`00Oomoo`2Q
Ool001eoo`03001oogoo05aoo`03001oogoo0:5oo`007Goo00<007ooOol0G7oo00<007ooOol0XGoo
000EOol30005Ool00`00Oomoo`1LOol00`00Oomoo`2QOol001Ioo`03001oogoo00Aoo`03001oogoo
05aoo`03001oogoo0:5oo`005Woo00<007ooOol017oo0P00GGoo00<007ooOol0XGoo000FOol00`00
Oomoo`3oOol8Ool001Ioo`03001oogoo0?moo`Qoo`005Goo0P00ogoo2Woo003oOolQOol00?moob5o
o`00ogoo8Goo000>Ool4000ROol30003Ool30005Ool30009Ool30002Ool40007Ool20002Ool20002
Ool40002Ool30003Ool30002Ool40003Ool500000goo000000020002Ool50006Ool30004Ool30002
Ool5000017oo000007oo0P000Woo1@00KGoo000?Ool00`00Oomoo`0SOol00`00Oomoo`03Ool00`00
Oomoo`05Ool00`00Oomoo`07Ool01@00Oomoogoo00000Woo00<007ooOol027oo00@007oo0000009o
o`03001oogoo00=oo`07001oogooOol007oo00000goo00@007ooOol000Aoo`07001oogooOol007oo
00001Goo00D007ooOomoo`0000Moo`04001oogoo0002Ool01`00Oomoogoo001oo`00009oo`04001o
ogoo0002Ool01000Oomoo`000goo00<007ooOol0K7oo0003Ool500001goo001oo`00Ool007oo00@0
009oo`D00003Ool0000000<0009oo`<0009oo`D0009oo`D00003Ool00000008000=oo`03001oogoo
00Eoo`03001oogoo00Moo`05001oogooOol00002Ool00`00Oomoo`08Ool30003Ool500000goo001o
o`04Ool01@00Oomoogoo00000Woo00<007ooOol00Woo00H007ooOomoo`00Ool500000goo001oo`02
Ool00`00Oomoo`07Ool20002Ool01`00Oomoogoo001oo`00009oo`04001oogoo0002Ool01000Oomo
o`000goo00<007ooOol0K7oo0003Ool01000Oomoo`000Woo00L007oo001oo`00Ool00003Ool01@00
Oomoogoo00001Goo00<007ooOol00Woo00H007ooOol007oo0002Ool01000Oomoo`000goo00@007oo
001oo`<000=oo`<000=oo`05001oo`00Ool00007Ool01@00Oomoogoo00000Woo00<007ooOol027oo
00@007ooOol0009oo`07001oogooOol007oo00000goo00<007oo00000goo00<007ooOol00P000goo
00L007ooOomoo`00Ool00003Ool00`00Ool00003Ool00`00Oomoo`05Ool20004Ool01`00Oomoogoo
001oo`00009oo`04001oogoo0002Ool01000Oomoo`000goo00<007ooOol0K7oo0003Ool40002Ool0
1`00Ool007oo001oo`0000=oo`05001oogooOol00005Ool00`00Oomoo`02Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00H007ooOomoo`00Ool50003Ool00`00Oomoo`03Ool01@00Ool007oo000027oo
0`000Woo100027oo00@007ooOol000=oo`<000=oo`@0009oo`<0009oo`800003Ool00000009oo`@0
009oo`<000=oo`@000Moo`04001oogoo0003Ool3000017oo000007oo0P0000=oo`0000000`000goo
1000KWoo0006Ool02P00Oomoo`00Ool007oo001oo`000goo00D007ooOomoo`0000Eoo`03001oogoo
009oo`03001oogoo009oo`04001oogoo0002Ool01P00Oomoogoo001oo`H00003Ool0000000<0009o
o`D000ioo`03001oogoo00Moo`@001moo`03001oogoo00Uoo`03001oogoo00Ioo`<001Qoo`03001o
ogoo06aoo`0017oo0`0000=oo`0000002@0017oo00<007ooOol00Woo0P000goo100000Aoo`00001o
o`8000=oo`@0009oo`<001eoo`<002Uoo`8000Yoo`80029oo`8006ioo`005goo00<007ooOol027oo
00<007ooOol037oo00<007ooOol0k7oo000EOol30005Ool00`00Oomoo`02Ool00`00Oomoo`0;Ool2
003^Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5o
o`00ogoo8Goo003oOolQOol00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {946.587, -0.14072, 0.462505, 
  0.00748348}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-9.5 0.01 0 0.618034 [
[.3 -0.0125 -9 -9 ]
[.3 -0.0125 9 0 ]
[.5 -0.0125 -12 -9 ]
[.5 -0.0125 12 0 ]
[.7 -0.0125 -12 -9 ]
[.7 -0.0125 12 0 ]
[.9 -0.0125 -12 -9 ]
[.9 -0.0125 12 0 ]
[1.025 0 0 -6 ]
[1.025 0 58 6 ]
[.0875 .12361 -18 -4.5 ]
[.0875 .12361 0 4.5 ]
[.0875 .24721 -18 -4.5 ]
[.0875 .24721 0 4.5 ]
[.0875 .37082 -18 -4.5 ]
[.0875 .37082 0 4.5 ]
[.0875 .49443 -18 -4.5 ]
[.0875 .49443 0 4.5 ]
[.0875 .61803 -6 -4.5 ]
[.0875 .61803 0 4.5 ]
[.1 .64303 -29 0 ]
[.1 .64303 29 12 ]
[.5 .63053 -65 0 ]
[.5 .63053 65 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.3 0 m
.3 .00625 L
s
[(980)] .3 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1000)] .5 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(1020)] .7 -0.0125 0 1 Mshowa
.9 0 m
.9 .00625 L
s
[(1040)] .9 -0.0125 0 1 Mshowa
.125 Mabswid
.15 0 m
.15 .00375 L
s
.2 0 m
.2 .00375 L
s
.25 0 m
.25 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.45 0 m
.45 .00375 L
s
.55 0 m
.55 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.75 0 m
.75 .00375 L
s
.8 0 m
.8 .00375 L
s
.85 0 m
.85 .00375 L
s
.05 0 m
.05 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(frequency) show
117.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.1 .12361 m
.10625 .12361 L
s
[(0.2)] .0875 .12361 1 0 Mshowa
.1 .24721 m
.10625 .24721 L
s
[(0.4)] .0875 .24721 1 0 Mshowa
.1 .37082 m
.10625 .37082 L
s
[(0.6)] .0875 .37082 1 0 Mshowa
.1 .49443 m
.10625 .49443 L
s
[(0.8)] .0875 .49443 1 0 Mshowa
.1 .61803 m
.10625 .61803 L
s
[(1)] .0875 .61803 1 0 Mshowa
.125 Mabswid
.1 .0309 m
.10375 .0309 L
s
.1 .0618 m
.10375 .0618 L
s
.1 .09271 m
.10375 .09271 L
s
.1 .15451 m
.10375 .15451 L
s
.1 .18541 m
.10375 .18541 L
s
.1 .21631 m
.10375 .21631 L
s
.1 .27812 m
.10375 .27812 L
s
.1 .30902 m
.10375 .30902 L
s
.1 .33992 m
.10375 .33992 L
s
.1 .40172 m
.10375 .40172 L
s
.1 .43262 m
.10375 .43262 L
s
.1 .46353 m
.10375 .46353 L
s
.1 .52533 m
.10375 .52533 L
s
.1 .55623 m
.10375 .55623 L
s
.1 .58713 m
.10375 .58713 L
s
.25 Mabswid
.1 0 m
.1 .61803 L
s
gsave
.1 .64303 -90 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(amplitude) show
117.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.5 .63053 -126 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(FFT) show
87.000000 13.000000 moveto
(of) show
105.000000 13.000000 moveto
(Recorded) show
159.000000 13.000000 moveto
(Sound) show
189.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .00135 m
.01 .00262 L
.02 .00628 L
.03 .00095 L
.04 .006 L
.05 .00397 L
.06 .00614 L
.07 .00923 L
.08 .00627 L
.09 .005 L
.1 .00541 L
.11 .00559 L
.12 .00543 L
.13 .0057 L
.14 .00759 L
.15 .00747 L
.16 .00865 L
.17 .01118 L
.18 .00651 L
.19 .00894 L
.2 .0035 L
.21 .00351 L
.22 .00739 L
.23 .00759 L
.24 .0086 L
.25 .01328 L
.26 .00602 L
.27 .01186 L
.28 .00508 L
.29 .00921 L
.3 .0108 L
.31 .0032 L
.32 .01398 L
.33 .01234 L
.34 .01306 L
.35 .0129 L
.36 .0156 L
.37 .01543 L
.38 .01748 L
.39 .015 L
.4 .01302 L
.41 .01685 L
.42 .02274 L
.43 .01615 L
.44 .02041 L
.45 .02664 L
.46 .03099 L
.47 .02934 L
.48 .03488 L
.49 .04793 L
Mistroke
.5 .05502 L
.51 .07701 L
.52 .09711 L
.53 .28159 L
.54 .61803 L
.55 .17242 L
.56 .08982 L
.57 .0657 L
.58 .05217 L
.59 .04533 L
.6 .03199 L
.61 .03239 L
.62 .03054 L
.63 .02297 L
.64 .02442 L
.65 .02079 L
.66 .01621 L
.67 .01159 L
.68 .01657 L
.69 .01712 L
.7 .01044 L
.71 .01019 L
.72 .00889 L
.73 .00774 L
.74 .00304 L
.75 .00861 L
.76 .01327 L
.77 .01533 L
.78 .00936 L
.79 .01043 L
.8 .00637 L
.81 .01079 L
.82 .00825 L
.83 .01073 L
.84 .0106 L
.85 .00296 L
.86 .009 L
.87 .00747 L
.88 .00535 L
.89 .00517 L
.9 .00529 L
.91 .00263 L
.92 .00866 L
.93 .00402 L
.94 .00155 L
.95 .00554 L
.96 .0095 L
.97 .0057 L
.98 .00589 L
.99 .00636 L
Mistroke
1 .00674 L
Mfstroke
1 .00674 m
1 .00674 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
@7oo0`0017oo0P0017oo0P006Goo0`0017oo0P0017oo0P0017oo0P005Woo0`0017oo0P000goo1000
0goo0P005Woo0`0017oo0P0017oo0`000goo0P00CGoo0013Ool01000Oomoo`000Woo00@007ooOol0
009oo`03001oogoo01Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000Woo00@007oo
Ool001Ioo`03001oogoo009oo`04001oogoo0003Ool00`00Oomoo`02Ool01000Oomoo`005Woo00<0
07ooOol00Woo00@007ooOol000Aoo`05001oogooOol00002Ool00`00Oomoo`1:Ool0045oo`<0009o
o`04001oogoo0002Ool01000Oomoo`006Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo
0002Ool01000Oomoo`005Woo00<007ooOol00Woo00@007ooOol000Aoo`05001oogooOol00002Ool0
0`00Oomoo`0DOol00`00Oomoo`02Ool01000Oomoo`000Woo10000Woo00@007ooOol004aoo`00@7oo
00@007ooOol000=oo`8000=oo`04001oogoo000IOol00`00Oomoo`02Ool01000Oomoo`000Woo00@0
07ooOol0009oo`04001oogoo000FOol00`00Oomoo`02Ool01000Oomoo`001Goo00@007ooOol0009o
o`03001oogoo01Aoo`03001oogoo009oo`04001oogoo0002Ool00`00Ool00003Ool01000Oomoo`00
C7oo0010Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo000IOol00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol0009oo`04001oogoo000FOol00`00Oomoo`02Ool01000Oomoo`00
0Woo00@007ooOol0009oo`04001oogoo000FOol00`00Oomoo`02Ool01000Oomoo`000Woo00<007oo
00000goo00@007ooOol004aoo`00@Goo0P0017oo0P0017oo0P006Goo0P001Goo0P0017oo0P0017oo
0P005Woo0P001Goo0P0017oo0P0017oo0P005Woo0P001Goo0P0017oo0P0017oo0P00:Goo10005goo
0`001Woo003nOol00`00Oomoo`0GOol00`00Oomoo`05Ool00>Qoo`@0009oo`@000=oo`@0009oo`@0
0003Ool0000000<0009oo`@00004Ool00000Ool20002Ool30003Ool00`00Oomoo`04Ool00>Uoo`03
001oogoo00=oo`03001oogoo009oo`03001oogoo00=oo`07001oogooOol007oo00000Woo00@007oo
Ool000Eoo`04001oogoo0002Ool01@00Oomoogoo00000Woo00<007ooOol017oo0007OooI0009Ool0
0`00Oomoo`03Ool00`00Oomoo`02Ool500000goo001oo`02Ool00`00Ool00002Ool00`00Oomoo`05
00001Goo001oogoo00000Woo00<007ooOol00goo00<007oo00001Goo0007Ool400000goo00000002
000017oo000000001Goo1@002Goo00<007ooOol01goo1@001goo00<007ooOol00goo0`000Woo00<0
07oo000027oo00<007ooOol01goo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<0
07ooOol027oo00<007ooOol01goo00<007ooOol027oo00<007ooOol01Goo10002Woo00<007ooOol0
27oo0P001Goo100000Eoo`00000007oo00H001Aoo`03001oogoo00=oo`8000=oo`07001oogooOol0
07oo00000goo00<007oo00000Woo00@007ooOol000=oo`03001oo`00009oo`04001oogoo0003Ool0
1@00Ool007oo00001Goo000;Ool00`00Oomoo`02Ool01000Oomoogoo1@0017oo3`0000=oo`000000
0P001Goo1`0000Ioo`00000007oo0003Ool400000goo001oo`0VOol00`00Oomoo`0XOol01000Oomo
ogoo10000goo0P0017oo0`0000Eoo`00000007oo00<000Aoo`03001oogoo00D000=oo`8000=oo`03
001oogoo00=oo``000Qoo`@0009oo`800003Ool00000009oo`<000=oo`H00003Ool0000000=oo`<0
0003Ool0000000<000=oo`H00003Ool0000000Aoo`007Goo00<007ooOol037oo00<007ooOol03Woo
00D007ooOomoo`0000Ioo`04001oogooOol90007Ool4000gOol30003Ool50009Ool200000goo001o
o`02Ool01@00Oomoogoo00000goo1000:goo00<007ooOol0=7oo000MOol00`00Oomoo`0eOol70004
Ool2000017oo00000000;goo0P000goo0`0047oo00<007ooOol0>Goo0`00=7oo000MOol00`00Oomo
o`12Ool01000Oomoogoo0P009goo0P0000Aoo`00000008]oo`007Goo00<007ooOol0B7oo0P0097oo
00@007ooOol008ioo`007Goo00<007ooOol0BWoo1@006Woo1@00TWoo000MOol00`00Oomoo`1?Ool0
0`00Oomoo`0FOol00`00Oomoo`2EOol001eoo`03001oogoo04moo`03001oogoo01Eoo`03001oogoo
09Ioo`007Goo00<007ooOol0D7oo00<007ooOol04goo00<007ooOol0Ugoo000MOol00`00Oomoo`1A
Ool2000BOol00`00Oomoo`2HOol001eoo`03001oogoo05=oo`03001oogoo00ioo`03001oogoo09Uo
o`007Goo00<007ooOol0Dgoo00<007ooOol03Woo00<007ooOol0VGoo000MOol00`00Oomoo`1DOol0
0`00Oomoo`0<Ool00`00Oomoo`2JOol001eoo`03001oogoo05Aoo`03001oogoo00]oo`03001oogoo
09]oo`007Goo00<007ooOol0E7oo00<007ooOol02goo00<007ooOol0Vgoo000MOol00`00Oomoo`1E
Ool00`00Oomoo`09Ool00`00Oomoo`2LOol001eoo`03001oogoo05Eoo`03001oogoo00Uoo`03001o
ogoo09aoo`007Goo00<007ooOol0EWoo00<007ooOol027oo00<007ooOol0W7oo000MOol00`00Oomo
o`1FOol00`00Oomoo`07Ool00`00Oomoo`2MOol001eoo`03001oogoo05Moo`03001oogoo00Ioo`03
001oogoo09eoo`007Goo00<007ooOol0Egoo00<007ooOol01Woo00<007ooOol0WGoo000MOol00`00
Oomoo`1GOol00`00Oomoo`06Ool00`00Oomoo`2MOol001eoo`03001oogoo05Moo`03001oogoo00Io
o`03001oogoo09eoo`002Woo0P0017oo0P000goo100017oo00<007ooOol0Egoo00<007ooOol01Goo
00<007ooOol0WWoo0009Ool01000Oomoo`000goo0P0017oo00<007ooOol017oo00<007ooOol0Egoo
00<007ooOol01Goo00<007ooOol0WWoo0009Ool01000Oomoo`002Woo00<007ooOol00goo0P00F7oo
00<007ooOol01Goo00<007ooOol0WWoo0009Ool01000Oomoo`002goo00<007ooOol00Woo00<007oo
Ool0Egoo00<007ooOol01Goo00<007ooOol0WWoo0009Ool01000Oomoo`0027oo00@007ooOol000Ao
o`03001oogoo05Moo`03001oogoo00Eoo`03001oogoo09ioo`002Woo0P002Woo0P001Goo00<007oo
Ool0Egoo00<007ooOol01Goo00<007ooOol0WWoo000MOol00`00Oomoo`1GOol00`00Oomoo`05Ool0
0`00Oomoo`2NOol001eoo`03001oogoo05Qoo`03001oogoo00Aoo`03001oogoo09ioo`007Goo00<0
07ooOol0F7oo00<007ooOol017oo00<007ooOol0WWoo000MOol00`00Oomoo`1HOol00`00Oomoo`03
Ool00`00Oomoo`2OOol001eoo`03001oogoo05Qoo`03001oogoo00=oo`03001oogoo09moo`007Goo
00<007ooOol0F7oo00<007ooOol00goo00<007ooOol0Wgoo000MOol00`00Oomoo`1HOol00`00Oomo
o`03Ool00`00Oomoo`2OOol001eoo`03001oogoo05Qoo`03001oogoo00=oo`03001oogoo09moo`00
7Goo00<007ooOol0F7oo00<007ooOol00goo00<007ooOol0Wgoo000MOol00`00Oomoo`1HOol00`00
Oomoo`03Ool00`00Oomoo`2OOol001eoo`03001oogoo05Qoo`03001oogoo00=oo`03001oogoo09mo
o`007Goo00<007ooOol0F7oo00<007ooOol00goo00<007ooOol0Wgoo000MOol00`00Oomoo`1HOol0
0`00Oomoo`03Ool00`00Oomoo`2OOol001eoo`03001oogoo05Qoo`03001oogoo00=oo`03001oogoo
09moo`007Goo00<007ooOol0F7oo00<007ooOol00goo00<007ooOol0Wgoo000MOol00`00Oomoo`1H
Ool00`00Oomoo`03Ool00`00Oomoo`2OOol001eoo`03001oogoo05Qoo`03001oogoo00=oo`03001o
ogoo09moo`007Goo00<007ooOol0F7oo00<007ooOol00goo00<007ooOol0Wgoo000MOol00`00Oomo
o`1HOol00`00Oomoo`03Ool00`00Oomoo`2OOol001eoo`03001oogoo05Qoo`03001oogoo00=oo`03
001oogoo09moo`007Goo00<007ooOol0F7oo00<007ooOol00goo00<007ooOol0Wgoo000:Ool20004
Ool20004Ool30004Ool00`00Oomoo`1IOol00`00Oomoo`02Ool00`00Oomoo`2OOol000Uoo`04001o
ogoo0003Ool20005Ool00`00Oomoo`03Ool00`00Oomoo`1IOol00`00Oomoo`02Ool00`00Oomoo`2O
Ool000Uoo`04001oogoo0008Ool40004Ool2001JOol00`00Oomoo`02Ool00`00Oomoo`2OOol000Uo
o`04001oogoo0008Ool00`00Ool00005Ool00`00Oomoo`1IOol00`00Oomoo`02Ool00`00Oomoo`2O
Ool000Uoo`04001oogoo0008Ool00`00Ool00005Ool00`00Oomoo`1IOol00`00Oomoo`02Ool00`00
Oomoo`2OOol000Yoo`8000Yoo`8000Eoo`03001oogoo05Uoo`03001oogoo009oo`03001oogoo09mo
o`007Goo00<007ooOol0FGoo00<007ooOol00Woo00<007ooOol0Wgoo000MOol00`00Oomoo`1IOol0
0`00Oomoo`02Ool00`00Oomoo`2OOol001eoo`03001oogoo05Uoo`03001oogoo009oo`03001oogoo
09moo`007Goo00<007ooOol0FGoo00<007ooOol00Woo00<007ooOol0Wgoo000MOol00`00Oomoo`1I
Ool00`00Oomoo`02Ool00`00Oomoo`2OOol001eoo`03001oogoo05Uoo`05001oogooOol0002ROol0
01eoo`03001oogoo05Uoo`05001oogooOol0002ROol001eoo`03001oogoo05Uoo`05001oogooOol0
002ROol001eoo`03001oogoo05Uoo`05001oogooOol0002ROol001eoo`03001oogoo05Uoo`05001o
ogooOol0002ROol001eoo`03001oogoo05Uoo`05001oogooOol0002ROol001eoo`03001oogoo05Uo
o`05001oogooOol0002ROol001eoo`03001oogoo05Uoo`05001oogooOol0002ROol001eoo`03001o
ogoo05Uoo`05001oogooOol0002ROol001eoo`03001oogoo05Uoo`05001oogooOol0002ROol001eo
o`03001oogoo05Uoo`05001oogooOol0002ROol001eoo`03001oogoo05Yoo`04001oogoo002ROol0
01eoo`03001oogoo05Yoo`04001oogoo002ROol001eoo`03001oogoo05Yoo`04001oogoo002ROol0
01eoo`03001oogoo05Yoo`04001oogoo002ROol001eoo`03001oogoo05Yoo`04001oogoo002ROol0
00Yoo`8000Aoo`8000Aoo`8000Eoo`03001oogoo05Yoo`04001oogoo002ROol000Uoo`04001oogoo
0003Ool20003Ool01000Oomoo`0017oo00<007ooOol0FWoo00@007ooOol00:9oo`002Goo00@007oo
Ool000Qoo`04001oogoo0004Ool2001KOol01000Oomoo`00XWoo0009Ool01000Oomoo`0027oo0`00
1Goo00<007ooOol0FWoo00@007ooOol00:9oo`002Goo00@007ooOol000Qoo`03001oogoo00Eoo`03
001oogoo05Yoo`04001oogoo002ROol000Yoo`8000Yoo`<000Aoo`03001oogoo05Yoo`04001oogoo
002ROol001eoo`03001oogoo05Yoo`04001oogoo002ROol001eoo`03001oogoo05Yoo`04001oogoo
002ROol001eoo`03001oogoo05Yoo`04001oogoo002ROol001eoo`03001oogoo05Yoo`04001oogoo
002ROol001eoo`03001oogoo05Yoo`04001oogoo002ROol001eoo`03001oogoo05Yoo`04001oogoo
002ROol001eoo`03001oogoo05Yoo`04001oogoo002ROol001eoo`03001oogoo05Yoo`04001oogoo
002ROol001eoo`03001oogoo05Yoo`04001oogoo002ROol001eoo`03001oogoo05Yoo`04001oogoo
002ROol001eoo`03001oogoo05Yoo`04001oogoo002ROol001eoo`03001oogoo05Yoo`04001oogoo
002ROol001eoo`03001oogoo05Yoo`04001oogoo002ROol001eoo`03001oogoo05]oo`03001oo`00
0:9oo`007Goo00<007ooOol0Fgoo00<007oo0000XWoo000MOol00`00Oomoo`1KOol00`00Ool0002R
Ool001eoo`03001oogoo05]oo`03001oo`000:9oo`007Goo00<007ooOol0Fgoo00<007oo0000XWoo
000MOol00`00Oomoo`1KOol00`00Ool0002ROol001eoo`03001oogoo05]oo`03001oo`000:9oo`00
2Woo0P0017oo0P0017oo0P001Goo00<007ooOol0Fgoo00<007oo0000XWoo0009Ool01000Oomoo`00
0goo0P000goo00@007ooOol000Aoo`03001oogoo05]oo`03001oo`000:9oo`002Goo00@007ooOol0
00Qoo`04001oogoo0004Ool2001LOol00`00Ool0002ROol000Uoo`04001oogoo0009Ool20005Ool0
0`00Oomoo`1KOol00`00Ool0002ROol000Uoo`04001oogoo0008Ool01000Oomoo`0017oo00<007oo
Ool0Fgoo00<007oo0000XWoo000:Ool2000:Ool20005Ool00`00Oomoo`1KOol00`00Ool0002ROol0
01eoo`03001oogoo05]oo`800:=oo`007Goo00<007ooOol0Fgoo0P00Xgoo000MOol00`00Oomoo`1K
Ool2002SOol001eoo`03001oogoo05]oo`800:=oo`007Goo00<007ooOol0Fgoo0P00Xgoo000MOol0
0`00Oomoo`1KOol2002SOol001eoo`03001oogoo05]oo`800:=oo`007Goo00<007ooOol0Fgoo0P00
Xgoo000MOol00`00Oomoo`1KOol2002SOol001eoo`03001oogoo05]oo`800:=oo`007Goo00<007oo
Ool0Fgoo0P00Xgoo000MOol00`00Oomoo`1KOol2002SOol001eoo`03001oogoo05aoo`03001oogoo
0:5oo`007Goo00<007ooOol0G7oo00<007ooOol0XGoo000MOol00`00Oomoo`1LOol00`00Oomoo`2Q
Ool001eoo`03001oogoo05aoo`03001oogoo0:5oo`007Goo00<007ooOol0G7oo00<007ooOol0XGoo
000MOol00`00Oomoo`1LOol00`00Oomoo`2QOol001eoo`03001oogoo05aoo`03001oogoo0:5oo`00
7Goo00<007ooOol0G7oo00<007ooOol0XGoo000MOol00`00Oomoo`1LOol00`00Oomoo`2QOol001Eo
o`<000Eoo`03001oogoo05aoo`03001oogoo0:5oo`005Woo00<007ooOol017oo00<007ooOol0G7oo
00<007ooOol0XGoo000FOol00`00Oomoo`04Ool2001MOol00`00Oomoo`2QOol001Ioo`03001oogoo
0?moo`Qoo`005Woo00<007ooOol0ogoo27oo000EOol2003oOol:Ool00?moob5oo`00ogoo8Goo003o
OolQOol000ioo`@0029oo`<000=oo`<000Eoo`<000Uoo`<0009oo`@000Moo`80009oo`80009oo`@0
009oo`<000=oo`<0009oo`@000=oo`D00003Ool000000080009oo`D000Ioo`<000Aoo`<0009oo`D0
0004Ool00000Ool20002Ool5001]Ool000moo`03001oogoo02=oo`03001oogoo00=oo`03001oogoo
00Eoo`03001oogoo00Moo`05001oogooOol00002Ool00`00Oomoo`08Ool01000Ool000000Woo00<0
07ooOol00goo00L007ooOomoo`00Ool00003Ool01000Oomoo`0017oo00L007ooOomoo`00Ool00005
Ool01@00Oomoogoo00001goo00@007ooOol0009oo`07001oogooOol007oo00000Woo00@007ooOol0
009oo`04001oogoo0003Ool00`00Oomoo`1/Ool000=oo`D00007Ool007oo001oo`00Ool010000Woo
1@0000=oo`0000000`000Woo0`000Woo1@000Woo1@0000=oo`0000000P000goo00<007ooOol01Goo
00<007ooOol01goo00D007ooOomoo`00009oo`03001oogoo00Qoo`<000=oo`D00003Ool007oo00Ao
o`05001oogooOol00002Ool00`00Oomoo`02Ool01P00Oomoogoo001oo`D00003Ool007oo009oo`03
001oogoo00Moo`80009oo`07001oogooOol007oo00000Woo00@007ooOol0009oo`04001oogoo0003
Ool00`00Oomoo`1/Ool000=oo`04001oogoo0002Ool01`00Ool007oo001oo`0000=oo`05001oogoo
Ool00005Ool00`00Oomoo`02Ool01P00Oomoo`00Ool0009oo`04001oogoo0003Ool01000Ool007oo
0`000goo0`000goo00D007oo001oo`0000Moo`05001oogooOol00002Ool00`00Oomoo`08Ool01000
Oomoo`000Woo00L007ooOomoo`00Ool00003Ool00`00Ool00003Ool00`00Oomoo`020003Ool01`00
Oomoogoo001oo`0000=oo`03001oo`0000=oo`03001oogoo00Eoo`8000Aoo`07001oogooOol007oo
00000Woo00@007ooOol0009oo`04001oogoo0003Ool00`00Oomoo`1/Ool000=oo`@0009oo`07001o
o`00Ool007oo00000goo00D007ooOomoo`0000Eoo`03001oogoo009oo`03001oogoo009oo`04001o
ogoo0002Ool01P00Oomoogoo001oo`D000=oo`03001oogoo00=oo`05001oo`00Ool00008Ool30002
Ool40008Ool01000Oomoo`000goo0`000goo10000Woo0`000Woo0P0000=oo`0000000Woo10000Woo
0`000goo10001goo00@007ooOol000=oo`<00004Ool00000Ool200000goo000000030003Ool4001^
Ool000Ioo`0:001oogoo001oo`00Ool007oo0003Ool01@00Oomoogoo00001Goo00<007ooOol00Woo
00<007ooOol00Woo00@007ooOol0009oo`06001oogooOol007oo1P0000=oo`0000000`000Woo1@00
3Woo00<007ooOol01goo10007goo00<007ooOol02Goo00<007ooOol01Woo0`0067oo00<007ooOol0
K7oo0004Ool300000goo000000090004Ool00`00Oomoo`02Ool20003Ool4000017oo000007oo0P00
0goo10000Woo0`007Goo0`00:Goo0P002Woo0P008Woo0P00KWoo000GOol00`00Oomoo`08Ool00`00
Oomoo`0<Ool00`00Oomoo`3/Ool001Eoo`<000Eoo`03001oogoo009oo`03001oogoo00]oo`800>io
o`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003o
OolQOol00?moob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {946.587, -0.14072, 0.462505, 
  0.00748348}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-9.5 0.01 0 0.618034 [
[.3 -0.0125 -9 -9 ]
[.3 -0.0125 9 0 ]
[.5 -0.0125 -12 -9 ]
[.5 -0.0125 12 0 ]
[.7 -0.0125 -12 -9 ]
[.7 -0.0125 12 0 ]
[.9 -0.0125 -12 -9 ]
[.9 -0.0125 12 0 ]
[1.025 0 0 -6 ]
[1.025 0 58 6 ]
[.0875 .12361 -18 -4.5 ]
[.0875 .12361 0 4.5 ]
[.0875 .24721 -18 -4.5 ]
[.0875 .24721 0 4.5 ]
[.0875 .37082 -18 -4.5 ]
[.0875 .37082 0 4.5 ]
[.0875 .49443 -18 -4.5 ]
[.0875 .49443 0 4.5 ]
[.0875 .61803 -6 -4.5 ]
[.0875 .61803 0 4.5 ]
[.1 .64303 -29 0 ]
[.1 .64303 29 12 ]
[.5 .63053 -65 0 ]
[.5 .63053 65 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.3 0 m
.3 .00625 L
s
[(980)] .3 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1000)] .5 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(1020)] .7 -0.0125 0 1 Mshowa
.9 0 m
.9 .00625 L
s
[(1040)] .9 -0.0125 0 1 Mshowa
.125 Mabswid
.15 0 m
.15 .00375 L
s
.2 0 m
.2 .00375 L
s
.25 0 m
.25 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.45 0 m
.45 .00375 L
s
.55 0 m
.55 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.75 0 m
.75 .00375 L
s
.8 0 m
.8 .00375 L
s
.85 0 m
.85 .00375 L
s
.05 0 m
.05 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(frequency) show
117.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.1 .12361 m
.10625 .12361 L
s
[(0.2)] .0875 .12361 1 0 Mshowa
.1 .24721 m
.10625 .24721 L
s
[(0.4)] .0875 .24721 1 0 Mshowa
.1 .37082 m
.10625 .37082 L
s
[(0.6)] .0875 .37082 1 0 Mshowa
.1 .49443 m
.10625 .49443 L
s
[(0.8)] .0875 .49443 1 0 Mshowa
.1 .61803 m
.10625 .61803 L
s
[(1)] .0875 .61803 1 0 Mshowa
.125 Mabswid
.1 .0309 m
.10375 .0309 L
s
.1 .0618 m
.10375 .0618 L
s
.1 .09271 m
.10375 .09271 L
s
.1 .15451 m
.10375 .15451 L
s
.1 .18541 m
.10375 .18541 L
s
.1 .21631 m
.10375 .21631 L
s
.1 .27812 m
.10375 .27812 L
s
.1 .30902 m
.10375 .30902 L
s
.1 .33992 m
.10375 .33992 L
s
.1 .40172 m
.10375 .40172 L
s
.1 .43262 m
.10375 .43262 L
s
.1 .46353 m
.10375 .46353 L
s
.1 .52533 m
.10375 .52533 L
s
.1 .55623 m
.10375 .55623 L
s
.1 .58713 m
.10375 .58713 L
s
.25 Mabswid
.1 0 m
.1 .61803 L
s
gsave
.1 .64303 -90 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(amplitude) show
117.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.5 .63053 -126 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(FFT) show
87.000000 13.000000 moveto
(of) show
105.000000 13.000000 moveto
(Recorded) show
159.000000 13.000000 moveto
(Sound) show
189.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .0046 m
.01 .00786 L
.02 .01067 L
.03 .0045 L
.04 .0028 L
.05 .00488 L
.06 .00554 L
.07 .00423 L
.08 .00582 L
.09 .00562 L
.1 .00339 L
.11 .00603 L
.12 .00701 L
.13 .00435 L
.14 .00903 L
.15 .00432 L
.16 .00912 L
.17 .00617 L
.18 .00881 L
.19 .0082 L
.2 .00615 L
.21 .00688 L
.22 .00765 L
.23 .00581 L
.24 .00742 L
.25 .00592 L
.26 .00922 L
.27 .00956 L
.28 .00688 L
.29 .00897 L
.3 .00602 L
.31 .00703 L
.32 .01012 L
.33 .00775 L
.34 .01092 L
.35 .01023 L
.36 .00737 L
.37 .00943 L
.38 .01577 L
.39 .0119 L
.4 .01819 L
.41 .01707 L
.42 .02124 L
.43 .02259 L
.44 .02118 L
.45 .02463 L
.46 .02465 L
.47 .03063 L
.48 .03601 L
.49 .04391 L
Mistroke
.5 .05596 L
.51 .07625 L
.52 .11845 L
.53 .5007 L
.54 .61803 L
.55 .17052 L
.56 .08874 L
.57 .06745 L
.58 .04594 L
.59 .0423 L
.6 .03448 L
.61 .03118 L
.62 .02324 L
.63 .02701 L
.64 .01669 L
.65 .02049 L
.66 .0141 L
.67 .01354 L
.68 .01713 L
.69 .01295 L
.7 .00875 L
.71 .01517 L
.72 .01206 L
.73 .01558 L
.74 .01283 L
.75 .00793 L
.76 .00397 L
.77 .00924 L
.78 .00759 L
.79 .01053 L
.8 .01092 L
.81 .00853 L
.82 .0053 L
.83 .0101 L
.84 .01088 L
.85 .00666 L
.86 .0091 L
.87 .01022 L
.88 .01062 L
.89 .00839 L
.9 .00418 L
.91 .00306 L
.92 .00964 L
.93 .00356 L
.94 .00566 L
.95 .00796 L
.96 .0029 L
.97 .00944 L
.98 .01195 L
.99 .00818 L
Mistroke
1 .00576 L
Mfstroke
1 .00576 m
1 .00576 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
@7oo0`0017oo0P0017oo0P006Goo0`0017oo0P0017oo0P0017oo0P005Woo0`0017oo0P000goo1000
0goo0P005Woo0`0017oo0P0017oo0`000goo0P00CGoo0013Ool01000Oomoo`000Woo00@007ooOol0
009oo`03001oogoo01Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000Woo00@007oo
Ool001Ioo`03001oogoo009oo`04001oogoo0003Ool00`00Oomoo`02Ool01000Oomoo`005Woo00<0
07ooOol00Woo00@007ooOol000Aoo`05001oogooOol00002Ool00`00Oomoo`1:Ool0045oo`<0009o
o`04001oogoo0002Ool01000Oomoo`006Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo
0002Ool01000Oomoo`005Woo00<007ooOol00Woo00@007ooOol000Aoo`05001oogooOol00002Ool0
0`00Oomoo`0DOol00`00Oomoo`02Ool01000Oomoo`000Woo10000Woo00@007ooOol004aoo`00@7oo
00@007ooOol000=oo`8000=oo`04001oogoo000IOol00`00Oomoo`02Ool01000Oomoo`000Woo00@0
07ooOol0009oo`04001oogoo000FOol00`00Oomoo`02Ool01000Oomoo`001Goo00@007ooOol0009o
o`03001oogoo01Aoo`03001oogoo009oo`04001oogoo0002Ool00`00Ool00003Ool01000Oomoo`00
C7oo0010Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo000IOol00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol0009oo`04001oogoo000FOol00`00Oomoo`02Ool01000Oomoo`00
0Woo00@007ooOol0009oo`04001oogoo000FOol00`00Oomoo`02Ool01000Oomoo`000Woo00<007oo
00000goo00@007ooOol004aoo`00@Goo0P0017oo0P0017oo0P006Goo0P001Goo0P0017oo0P0017oo
0P005Woo0P001Goo0P0017oo0P0017oo0P005Woo0P001Goo0P0017oo0P0017oo0P00:Goo10005goo
0`001Woo003nOol00`00Oomoo`0GOol00`00Oomoo`05Ool00>Qoo`@0009oo`@000=oo`@0009oo`@0
0003Ool0000000<0009oo`@00004Ool00000Ool20002Ool30003Ool00`00Oomoo`04Ool00>Uoo`03
001oogoo00=oo`03001oogoo009oo`03001oogoo00=oo`07001oogooOol007oo00000Woo00@007oo
Ool000Eoo`04001oogoo0002Ool01@00Oomoogoo00000Woo00<007ooOol017oo0007OooI0009Ool0
0`00Oomoo`03Ool00`00Oomoo`02Ool500000goo001oo`02Ool00`00Ool00002Ool00`00Oomoo`05
00001Goo001oogoo00000Woo00<007ooOol00goo00<007oo00001Goo0007Ool20004Ool7000017oo
0000000017oo0`000goo0`0000Aoo`00000000Uoo`03001oogoo00Qoo`03001oogoo00Qoo`03001o
ogoo00Qoo`03001oogoo00Moo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001o
ogoo00Qoo`03001oogoo00Moo`03001oogoo00Qoo`03001oogoo00Qoo`@000Moo`03001oogoo00Qo
o`03001oogoo00Ioo`H00004Ool000000002Ool50006Ool00`00Oomoo`07Ool00`00Oomoo`03Ool2
0003Ool01`00Oomoogoo001oo`0000=oo`03001oo`00009oo`04001oogoo0003Ool00`00Ool00002
Ool01000Oomoo`000goo00D007oo001oo`0000Eoo`002Goo0P0000=oo`00Ool01Woo00@007ooOomo
o`@00003Ool007oo00<000=oo`04001oogooOolS000017oo0000000017oo10006goo00<007ooOol0
9goo0P002Goo0P000goo1@000goo1@0017oo1@000goo0P0000=oo`00Ool00goo00@007ooOomoo`<0
00Aoo`800003Ool00000008000Qoo`@0009oo`800003Ool00000009oo`<000=oo`H00003Ool00000
00=oo`<00003Ool0000000<000=oo`H00003Ool0000000Aoo`002goo00<007ooOol03goo00<007oo
Ool0;7oo00@007ooOomoo`@000Aoo`03001oo`00008003Qoo`D00003Ool00000009oo`03001oogoo
00<00003Ool0000000Yoo`<000Eoo`@000Eoo`<001Eoo`03001oogoo00]oo`03001oogoo03Aoo`00
7Goo00<007ooOol0>Goo00@007ooOomoo`D002moo`800003Ool007oo00Aoo`03001oogoo00=oo`80
00=oo`03001oogoo045oo`<003Aoo`007Goo00<007ooOol0@Woo1P009Goo0P0000Eoo`00Oomoo`00
08aoo`007Goo00<007ooOol0B7oo1@007goo00@007ooOol0091oo`007Goo00<007ooOol0CGoo0P00
6goo0P00U7oo000MOol00`00Oomoo`1?Ool00`00Oomoo`0FOol2002FOol001eoo`03001oogoo051o
o`03001oogoo01Aoo`03001oogoo09Ioo`007Goo00<007ooOol0DGoo00<007ooOol047oo0`00VGoo
000MOol00`00Oomoo`1BOol00`00Oomoo`0?Ool00`00Oomoo`2IOol001eoo`03001oogoo05=oo`03
001oogoo00eoo`03001oogoo09Yoo`007Goo00<007ooOol0Dgoo00<007ooOol03Goo00<007ooOol0
VWoo000MOol00`00Oomoo`1DOol00`00Oomoo`0<Ool00`00Oomoo`2JOol001eoo`03001oogoo05Ao
o`03001oogoo00]oo`03001oogoo09]oo`007Goo00<007ooOol0E7oo00<007ooOol02goo00<007oo
Ool0Vgoo000MOol00`00Oomoo`1EOol00`00Oomoo`09Ool00`00Oomoo`2LOol001eoo`03001oogoo
05Eoo`03001oogoo00Uoo`03001oogoo09aoo`007Goo00<007ooOol0EGoo00<007ooOol02Goo00<0
07ooOol0W7oo000MOol00`00Oomoo`1FOol00`00Oomoo`07Ool00`00Oomoo`2MOol001eoo`03001o
ogoo05Ioo`03001oogoo00Moo`03001oogoo09eoo`007Goo00<007ooOol0EWoo00<007ooOol01goo
00<007ooOol0WGoo000MOol00`00Oomoo`1FOol00`00Oomoo`07Ool00`00Oomoo`2MOol001eoo`03
001oogoo05Ioo`03001oogoo00Moo`03001oogoo09eoo`002Woo0P0017oo0P000goo100017oo00<0
07ooOol0Egoo00<007ooOol01Goo00<007ooOol0WWoo0009Ool01000Oomoo`000goo0P0017oo00<0
07ooOol017oo00<007ooOol0Egoo00<007ooOol01Goo00<007ooOol0WWoo0009Ool01000Oomoo`00
2Woo00<007ooOol00goo0P00F7oo00<007ooOol01Goo00<007ooOol0WWoo0009Ool01000Oomoo`00
2goo00<007ooOol00Woo00<007ooOol0Egoo00<007ooOol01Goo00<007ooOol0WWoo0009Ool01000
Oomoo`0027oo00@007ooOol000Aoo`03001oogoo05Moo`03001oogoo00Eoo`03001oogoo09ioo`00
2Woo0P002Woo0P001Goo00<007ooOol0Egoo00<007ooOol01Goo00<007ooOol0WWoo000MOol00`00
Oomoo`1GOol00`00Oomoo`05Ool00`00Oomoo`2NOol001eoo`03001oogoo05Moo`03001oogoo00Eo
o`03001oogoo09ioo`007Goo00<007ooOol0Egoo00<007ooOol01Goo00<007ooOol0WWoo000MOol0
0`00Oomoo`1GOol00`00Oomoo`04Ool00`00Oomoo`2OOol001eoo`03001oogoo05Moo`03001oogoo
00Aoo`03001oogoo09moo`007Goo00<007ooOol0Egoo00<007ooOol017oo00<007ooOol0Wgoo000M
Ool00`00Oomoo`1GOol00`00Oomoo`04Ool00`00Oomoo`2OOol001eoo`03001oogoo05Moo`03001o
ogoo00Aoo`03001oogoo09moo`007Goo00<007ooOol0Egoo00<007ooOol017oo00<007ooOol0Wgoo
000MOol00`00Oomoo`1GOol00`00Oomoo`04Ool00`00Oomoo`2OOol001eoo`03001oogoo05Moo`03
001oogoo00Aoo`03001oogoo09moo`007Goo00<007ooOol0Egoo00<007ooOol017oo00<007ooOol0
Wgoo000MOol00`00Oomoo`1GOol00`00Oomoo`04Ool00`00Oomoo`2OOol001eoo`03001oogoo05Mo
o`03001oogoo00Aoo`03001oogoo09moo`007Goo00<007ooOol0Egoo00<007ooOol017oo00<007oo
Ool0Wgoo000MOol00`00Oomoo`1GOol00`00Oomoo`04Ool00`00Oomoo`2OOol001eoo`03001oogoo
05Moo`03001oogoo00Aoo`03001oogoo09moo`007Goo00<007ooOol0F7oo00<007ooOol00goo00<0
07ooOol0Wgoo000MOol00`00Oomoo`1HOol00`00Oomoo`03Ool00`00Oomoo`2OOol001eoo`03001o
ogoo05Qoo`03001oogoo00=oo`03001oogoo09moo`007Goo00<007ooOol0F7oo00<007ooOol00goo
00<007ooOol0Wgoo000:Ool20004Ool20004Ool30004Ool00`00Oomoo`1HOol00`00Oomoo`03Ool0
0`00Oomoo`2OOol000Uoo`04001oogoo0003Ool20005Ool00`00Oomoo`03Ool00`00Oomoo`1HOol0
0`00Oomoo`03Ool00`00Oomoo`2OOol000Uoo`04001oogoo0008Ool40004Ool2001IOol00`00Oomo
o`03Ool00`00Oomoo`2OOol000Uoo`04001oogoo0008Ool00`00Ool00005Ool00`00Oomoo`1HOol0
0`00Oomoo`03Ool00`00Oomoo`2OOol000Uoo`04001oogoo0008Ool00`00Ool00005Ool00`00Oomo
o`1HOol00`00Oomoo`03Ool00`00Oomoo`2OOol000Yoo`8000Yoo`8000Eoo`03001oogoo05Qoo`03
001oogoo00=oo`03001oogoo09moo`007Goo00<007ooOol0F7oo00<007ooOol00goo00<007ooOol0
Wgoo000MOol00`00Oomoo`1HOol00`00Oomoo`03Ool00`00Oomoo`2OOol001eoo`03001oogoo05Qo
o`03001oogoo00=oo`03001oogoo09moo`007Goo00<007ooOol0F7oo00<007ooOol00goo00<007oo
Ool0Wgoo000MOol00`00Oomoo`1HOol00`00Oomoo`02Ool00`00Oomoo`2POol001eoo`03001oogoo
05Qoo`03001oogoo009oo`03001oogoo0:1oo`007Goo00<007ooOol0F7oo00<007ooOol00Woo00<0
07ooOol0X7oo000MOol00`00Oomoo`1HOol00`00Oomoo`02Ool00`00Oomoo`2POol001eoo`03001o
ogoo05Qoo`03001oogoo009oo`03001oogoo0:1oo`007Goo00<007ooOol0F7oo00<007ooOol00Woo
00<007ooOol0X7oo000MOol00`00Oomoo`1HOol00`00Oomoo`02Ool00`00Oomoo`2POol001eoo`03
001oogoo05Qoo`03001oogoo009oo`03001oogoo0:1oo`007Goo00<007ooOol0F7oo00<007ooOol0
0Woo00<007ooOol0X7oo000MOol00`00Oomoo`1HOol00`00Oomoo`02Ool00`00Oomoo`2POol001eo
o`03001oogoo05Qoo`03001oogoo009oo`03001oogoo0:1oo`007Goo00<007ooOol0F7oo00<007oo
Ool00Woo00<007ooOol0X7oo000MOol00`00Oomoo`1HOol00`00Oomoo`02Ool00`00Oomoo`2POol0
01eoo`03001oogoo05Qoo`03001oogoo009oo`03001oogoo0:1oo`007Goo00<007ooOol0F7oo00<0
07ooOol00Woo00<007ooOol0X7oo000MOol00`00Oomoo`1HOol00`00Oomoo`02Ool00`00Oomoo`2P
Ool001eoo`03001oogoo05Qoo`03001oogoo009oo`03001oogoo0:1oo`002Woo0P0017oo0P0017oo
0P001Goo00<007ooOol0F7oo00<007ooOol00Woo00<007ooOol0X7oo0009Ool01000Oomoo`000goo
0P000goo00@007ooOol000Aoo`03001oogoo05Qoo`03001oogoo009oo`03001oogoo0:1oo`002Goo
00@007ooOol000Qoo`04001oogoo0004Ool2001IOol00`00Oomoo`02Ool00`00Oomoo`2POol000Uo
o`04001oogoo0008Ool30005Ool00`00Oomoo`1HOol00`00Oomoo`02Ool00`00Oomoo`2POol000Uo
o`04001oogoo0008Ool00`00Oomoo`05Ool00`00Oomoo`1HOol00`00Oomoo`02Ool00`00Oomoo`2P
Ool000Yoo`8000Yoo`<000Aoo`03001oogoo05Qoo`03001oogoo009oo`03001oogoo0:1oo`007Goo
00<007ooOol0F7oo00<007ooOol00Woo00<007ooOol0X7oo000MOol00`00Oomoo`1HOol00`00Oomo
o`02Ool00`00Oomoo`2POol001eoo`03001oogoo05Qoo`03001oogoo009oo`03001oogoo0:1oo`00
7Goo00<007ooOol0F7oo00<007ooOol00Woo00<007ooOol0X7oo000MOol00`00Oomoo`1IOol01@00
Oomoogoo0000XWoo000MOol00`00Oomoo`1IOol01@00Oomoogoo0000XWoo000MOol00`00Oomoo`1I
Ool01@00Oomoogoo0000XWoo000MOol00`00Oomoo`1IOol01@00Oomoogoo0000XWoo000MOol00`00
Oomoo`1IOol01@00Oomoogoo0000XWoo000MOol00`00Oomoo`1IOol01@00Oomoogoo0000XWoo000M
Ool00`00Oomoo`1IOol01@00Oomoogoo0000XWoo000MOol00`00Oomoo`1IOol01@00Oomoogoo0000
XWoo000MOol00`00Oomoo`1IOol01@00Oomoogoo0000XWoo000MOol00`00Oomoo`1IOol01@00Oomo
ogoo0000XWoo000MOol00`00Oomoo`1IOol01@00Oomoogoo0000XWoo000MOol00`00Oomoo`1IOol0
1@00Oomoogoo0000XWoo000MOol00`00Oomoo`1IOol01@00Oomoogoo0000XWoo000MOol00`00Oomo
o`1IOol01@00Oomoogoo0000XWoo000MOol00`00Oomoo`1IOol01@00Oomoogoo0000XWoo000MOol0
0`00Oomoo`1IOol01@00Oomoogoo0000XWoo000:Ool20004Ool20004Ool20005Ool00`00Oomoo`1I
Ool01@00Oomoogoo0000XWoo0009Ool01000Oomoo`000goo0P000goo00@007ooOol000Aoo`03001o
ogoo05Uoo`05001oogooOol0002ROol000Uoo`04001oogoo0008Ool01000Oomoo`0017oo0P00FWoo
00D007ooOomoo`000:9oo`002Goo00@007ooOol000Uoo`8000Eoo`03001oogoo05Uoo`05001oogoo
Ool0002ROol000Uoo`04001oogoo0008Ool01000Oomoo`0017oo00<007ooOol0FGoo00D007ooOomo
o`000:9oo`002Woo0P002Woo0P001Goo00<007ooOol0FGoo00D007ooOomoo`000:9oo`007Goo00<0
07ooOol0FGoo00@007ooOol00:=oo`007Goo00<007ooOol0FGoo00@007ooOol00:=oo`007Goo00<0
07ooOol0FGoo00@007ooOol00:=oo`007Goo00<007ooOol0FWoo00<007oo0000Xgoo000MOol00`00
Oomoo`1JOol00`00Ool0002SOol001eoo`03001oogoo05Yoo`03001oo`000:=oo`007Goo00<007oo
Ool0FWoo00<007oo0000Xgoo000MOol00`00Oomoo`1JOol00`00Ool0002SOol001eoo`03001oogoo
05Yoo`03001oo`000:=oo`007Goo00<007ooOol0FWoo00<007oo0000Xgoo000MOol00`00Oomoo`1J
Ool00`00Ool0002SOol001eoo`03001oogoo05]oo`800:=oo`007Goo00<007ooOol0Fgoo0P00Xgoo
000MOol00`00Oomoo`1KOol2002SOol001eoo`03001oogoo05]oo`800:=oo`007Goo00<007ooOol0
Fgoo0P00Xgoo000MOol00`00Oomoo`1KOol2002SOol001eoo`03001oogoo05]oo`800:=oo`007Goo
00<007ooOol0Fgoo0P00Xgoo000MOol00`00Oomoo`1KOol2002SOol001eoo`03001oogoo05aoo`03
001oogoo0:5oo`005Goo0`001Goo00<007ooOol0G7oo00<007ooOol0XGoo000FOol00`00Oomoo`04
Ool00`00Oomoo`1LOol00`00Oomoo`2QOol001Ioo`03001oogoo00Aoo`8005eoo`03001oogoo0:5o
o`005Woo00<007ooOol0ogoo27oo000FOol00`00Oomoo`3oOol8Ool001Eoo`800?moo`Yoo`00ogoo
8Goo003oOolQOol00?moob5oo`003Woo10008Woo0`000goo0`001Goo0`002Goo0`000Woo10001goo
0P000Woo0P000Woo10000Woo0`000goo0`000Woo10000goo1@0000=oo`0000000P000Woo1@001Woo
0`0017oo0`000Woo1@0000Aoo`00001oo`80009oo`D006eoo`003goo00<007ooOol08goo00<007oo
Ool00goo00<007ooOol01Goo00<007ooOol01goo00D007ooOomoo`00009oo`03001oogoo00Qoo`04
001oo`000002Ool00`00Oomoo`03Ool01`00Oomoogoo001oo`0000=oo`04001oogoo0004Ool01`00
Oomoogoo001oo`0000Eoo`05001oogooOol00007Ool01000Oomoo`000Woo00L007ooOomoo`00Ool0
0002Ool01000Oomoo`000Woo00@007ooOol000=oo`03001oogoo06aoo`000goo1@0000Moo`00Ool0
07oo001oo`040002Ool500000goo000000030002Ool30002Ool50002Ool500000goo000000020003
Ool00`00Oomoo`05Ool00`00Oomoo`07Ool01@00Oomoogoo00000Woo00<007ooOol027oo0`000goo
1@0000=oo`00Ool017oo00D007ooOomoo`00009oo`03001oogoo009oo`06001oogooOol007oo1@00
00=oo`00Ool00Woo00<007ooOol01goo0P000Woo00L007ooOomoo`00Ool00002Ool01000Oomoo`00
0Woo00@007ooOol000=oo`03001oogoo06aoo`000goo00@007ooOol0009oo`07001oo`00Ool007oo
00000goo00D007ooOomoo`0000Eoo`03001oogoo009oo`06001oogoo001oo`000Woo00@007ooOol0
00=oo`04001oo`00Ool30003Ool30003Ool01@00Ool007oo00001goo00D007ooOomoo`00009oo`03
001oogoo00Qoo`04001oogoo0002Ool01`00Oomoogoo001oo`0000=oo`03001oo`0000=oo`03001o
ogoo008000=oo`07001oogooOol007oo00000goo00<007oo00000goo00<007ooOol01Goo0P0017oo
00L007ooOomoo`00Ool00002Ool01000Oomoo`000Woo00@007ooOol000=oo`03001oogoo06aoo`00
0goo10000Woo00L007oo001oo`00Ool00003Ool01@00Oomoogoo00001Goo00<007ooOol00Woo00<0
07ooOol00Woo00@007ooOol0009oo`06001oogooOol007oo1@000goo00<007ooOol00goo00D007oo
001oo`0000Qoo`<0009oo`@000Qoo`04001oogoo0003Ool30003Ool40002Ool30002Ool200000goo
00000002Ool40002Ool30003Ool40007Ool01000Oomoo`000goo0`0000Aoo`00001oo`800003Ool0
000000<000=oo`@006ioo`001Woo00X007ooOol007oo001oo`00Ool000=oo`05001oogooOol00005
Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01000Oomoo`000Woo00H007ooOomoo`00Ool600000goo
000000030002Ool5000>Ool00`00Oomoo`07Ool4000OOol00`00Oomoo`09Ool00`00Oomoo`06Ool3
000HOol00`00Oomoo`1/Ool000Aoo`<00003Ool0000000T000Aoo`03001oogoo009oo`8000=oo`@0
0004Ool00000Ool20003Ool40002Ool3000MOol3000YOol2000:Ool2000ROol2001^Ool001Moo`03
001oogoo00Qoo`03001oogoo00aoo`03001oogoo0>aoo`005Goo0`001Goo00<007ooOol00Woo00<0
07ooOol02goo0P00kWoo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo
8Goo003oOolQOol00?moob5oo`00ogoo8Goo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {946.587, -0.14072, 0.462505, 
  0.00748348}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-9.5 0.01 0 0.618034 [
[.3 -0.0125 -9 -9 ]
[.3 -0.0125 9 0 ]
[.5 -0.0125 -12 -9 ]
[.5 -0.0125 12 0 ]
[.7 -0.0125 -12 -9 ]
[.7 -0.0125 12 0 ]
[.9 -0.0125 -12 -9 ]
[.9 -0.0125 12 0 ]
[1.025 0 0 -6 ]
[1.025 0 58 6 ]
[.0875 .12361 -18 -4.5 ]
[.0875 .12361 0 4.5 ]
[.0875 .24721 -18 -4.5 ]
[.0875 .24721 0 4.5 ]
[.0875 .37082 -18 -4.5 ]
[.0875 .37082 0 4.5 ]
[.0875 .49443 -18 -4.5 ]
[.0875 .49443 0 4.5 ]
[.0875 .61803 -6 -4.5 ]
[.0875 .61803 0 4.5 ]
[.1 .64303 -29 0 ]
[.1 .64303 29 12 ]
[.5 .63053 -65 0 ]
[.5 .63053 65 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.3 0 m
.3 .00625 L
s
[(980)] .3 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1000)] .5 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(1020)] .7 -0.0125 0 1 Mshowa
.9 0 m
.9 .00625 L
s
[(1040)] .9 -0.0125 0 1 Mshowa
.125 Mabswid
.15 0 m
.15 .00375 L
s
.2 0 m
.2 .00375 L
s
.25 0 m
.25 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.45 0 m
.45 .00375 L
s
.55 0 m
.55 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.75 0 m
.75 .00375 L
s
.8 0 m
.8 .00375 L
s
.85 0 m
.85 .00375 L
s
.05 0 m
.05 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(frequency) show
117.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.1 .12361 m
.10625 .12361 L
s
[(0.2)] .0875 .12361 1 0 Mshowa
.1 .24721 m
.10625 .24721 L
s
[(0.4)] .0875 .24721 1 0 Mshowa
.1 .37082 m
.10625 .37082 L
s
[(0.6)] .0875 .37082 1 0 Mshowa
.1 .49443 m
.10625 .49443 L
s
[(0.8)] .0875 .49443 1 0 Mshowa
.1 .61803 m
.10625 .61803 L
s
[(1)] .0875 .61803 1 0 Mshowa
.125 Mabswid
.1 .0309 m
.10375 .0309 L
s
.1 .0618 m
.10375 .0618 L
s
.1 .09271 m
.10375 .09271 L
s
.1 .15451 m
.10375 .15451 L
s
.1 .18541 m
.10375 .18541 L
s
.1 .21631 m
.10375 .21631 L
s
.1 .27812 m
.10375 .27812 L
s
.1 .30902 m
.10375 .30902 L
s
.1 .33992 m
.10375 .33992 L
s
.1 .40172 m
.10375 .40172 L
s
.1 .43262 m
.10375 .43262 L
s
.1 .46353 m
.10375 .46353 L
s
.1 .52533 m
.10375 .52533 L
s
.1 .55623 m
.10375 .55623 L
s
.1 .58713 m
.10375 .58713 L
s
.25 Mabswid
.1 0 m
.1 .61803 L
s
gsave
.1 .64303 -90 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(amplitude) show
117.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.5 .63053 -126 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(FFT) show
87.000000 13.000000 moveto
(of) show
105.000000 13.000000 moveto
(Recorded) show
159.000000 13.000000 moveto
(Sound) show
189.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .00341 m
.01 .00415 L
.02 .00665 L
.03 .00272 L
.04 .00457 L
.05 .00495 L
.06 .00454 L
.07 .00588 L
.08 .00465 L
.09 .00862 L
.1 .00481 L
.11 .00521 L
.12 .00638 L
.13 .00606 L
.14 .00661 L
.15 .00471 L
.16 .00546 L
.17 .00647 L
.18 .00664 L
.19 .00614 L
.2 .00571 L
.21 .01067 L
.22 .0121 L
.23 .00713 L
.24 .0051 L
.25 .00651 L
.26 .00695 L
.27 .01064 L
.28 .01177 L
.29 .01265 L
.3 .01133 L
.31 .00893 L
.32 .00764 L
.33 .01052 L
.34 .01064 L
.35 .00811 L
.36 .01124 L
.37 .01207 L
.38 .0136 L
.39 .01456 L
.4 .01549 L
.41 .01204 L
.42 .01853 L
.43 .01771 L
.44 .02154 L
.45 .02406 L
.46 .02694 L
.47 .03338 L
.48 .03557 L
.49 .04741 L
Mistroke
.5 .05886 L
.51 .07667 L
.52 .12081 L
.53 .40179 L
.54 .61803 L
.55 .14844 L
.56 .09143 L
.57 .06071 L
.58 .04455 L
.59 .04462 L
.6 .03379 L
.61 .02913 L
.62 .02234 L
.63 .01977 L
.64 .02216 L
.65 .01559 L
.66 .01761 L
.67 .01682 L
.68 .01705 L
.69 .01008 L
.7 .01188 L
.71 .00902 L
.72 .00993 L
.73 .01219 L
.74 .01117 L
.75 .01243 L
.76 .01043 L
.77 .01065 L
.78 .01238 L
.79 .01179 L
.8 .01037 L
.81 .00838 L
.82 .01288 L
.83 .00865 L
.84 .00512 L
.85 .00616 L
.86 .00406 L
.87 .00203 L
.88 .01127 L
.89 .00981 L
.9 .00704 L
.91 .00576 L
.92 .00957 L
.93 .00545 L
.94 .01019 L
.95 .00679 L
.96 .00382 L
.97 .00708 L
.98 .00465 L
.99 .00786 L
Mistroke
1 .0036 L
Mfstroke
1 .0036 m
1 .0036 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
@7oo0`0017oo0P0017oo0P006Goo0`0017oo0P0017oo0P0017oo0P005Woo0`0017oo0P000goo1000
0goo0P005Woo0`0017oo0P0017oo0`000goo0P00CGoo0013Ool01000Oomoo`000Woo00@007ooOol0
009oo`03001oogoo01Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000Woo00@007oo
Ool001Ioo`03001oogoo009oo`04001oogoo0003Ool00`00Oomoo`02Ool01000Oomoo`005Woo00<0
07ooOol00Woo00@007ooOol000Aoo`05001oogooOol00002Ool00`00Oomoo`1:Ool0045oo`<0009o
o`04001oogoo0002Ool01000Oomoo`006Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo
0002Ool01000Oomoo`005Woo00<007ooOol00Woo00@007ooOol000Aoo`05001oogooOol00002Ool0
0`00Oomoo`0DOol00`00Oomoo`02Ool01000Oomoo`000Woo10000Woo00@007ooOol004aoo`00@7oo
00@007ooOol000=oo`8000=oo`04001oogoo000IOol00`00Oomoo`02Ool01000Oomoo`000Woo00@0
07ooOol0009oo`04001oogoo000FOol00`00Oomoo`02Ool01000Oomoo`001Goo00@007ooOol0009o
o`03001oogoo01Aoo`03001oogoo009oo`04001oogoo0002Ool00`00Ool00003Ool01000Oomoo`00
C7oo0010Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo000IOol00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol0009oo`04001oogoo000FOol00`00Oomoo`02Ool01000Oomoo`00
0Woo00@007ooOol0009oo`04001oogoo000FOol00`00Oomoo`02Ool01000Oomoo`000Woo00<007oo
00000goo00@007ooOol004aoo`00@Goo0P0017oo0P0017oo0P006Goo0P001Goo0P0017oo0P0017oo
0P005Woo0P001Goo0P0017oo0P0017oo0P005Woo0P001Goo0P0017oo0P0017oo0P00:Goo10005goo
0`001Woo003nOol00`00Oomoo`0GOol00`00Oomoo`05Ool00>Qoo`@0009oo`@000=oo`@0009oo`@0
0003Ool0000000<0009oo`@00004Ool00000Ool20002Ool30003Ool00`00Oomoo`04Ool00>Uoo`03
001oogoo00=oo`03001oogoo009oo`03001oogoo00=oo`07001oogooOol007oo00000Woo00@007oo
Ool000Eoo`04001oogoo0002Ool01@00Oomoogoo00000Woo00<007ooOol017oo0007OooI0009Ool0
0`00Oomoo`03Ool00`00Oomoo`02Ool500000goo001oo`02Ool00`00Ool00002Ool00`00Oomoo`05
00001Goo001oogoo00000Woo00<007ooOol00goo00<007oo00001Goo0007Ool400000goo00000008
000017oo000000000Woo1@001Goo0`002Goo00<007ooOol01Goo10002Woo00<007ooOol027oo00<0
07ooOol01goo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<0
07ooOol01goo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol01Goo2000
1Goo00<007ooOol027oo1@0000Eoo`00000007oo008000Uoo`03001oogoo00=oo`8000=oo`07001o
ogooOol007oo00000goo00<007oo00000Woo00@007ooOol000=oo`03001oo`00009oo`04001oogoo
0003Ool01@00Ool007oo00001Goo000;Ool00`00Oomoo`08Ool01000Oomoogoo0P0000=oo`00Ool0
0Woo1@000goo2`0017oo0P000goo10001goo1P0017oo0`007Woo00<007ooOol0:7oo1@004Woo0`00
00Aoo`00000000=oo`03001oogoo009oo`03001oo`0000/00003Ool0000000Aoo`05001oogooOol0
000:Ool40002Ool200000goo00000002Ool30003Ool600000goo00000003Ool300000goo00000003
0003Ool600000goo00000004Ool001eoo`03001oogoo01Aoo`@000Uoo`P000Eoo`@000=oo`H000Ao
o`<003Uoo`@000Aooa8000=oo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo01Aoo`03001o
ogoo03Aoo`007Goo00<007ooOol0>goo10000goo1000;7oo2@00CWoo0`00=7oo000MOol00`00Oomo
o`16Ool2000UOol5002>Ool001eoo`03001oogoo04Qoo`@0021oo`03001oogoo095oo`007Goo00<0
07ooOol0C7oo00<007ooOol06goo0P00U7oo000MOol00`00Oomoo`1=Ool3000HOol2002FOol001eo
o`03001oogoo04moo`03001oogoo01Eoo`03001oogoo09Ioo`007Goo00<007ooOol0D7oo00<007oo
Ool04Goo0`00VGoo000MOol00`00Oomoo`1AOol00`00Oomoo`0@Ool00`00Oomoo`2IOol001eoo`03
001oogoo059oo`03001oogoo00ioo`03001oogoo09Yoo`007Goo00<007ooOol0Dgoo00<007ooOol0
37oo00<007ooOol0Vgoo000MOol00`00Oomoo`1COol00`00Oomoo`0<Ool00`00Oomoo`2KOol001eo
o`03001oogoo05Aoo`03001oogoo00]oo`03001oogoo09]oo`007Goo00<007ooOol0E7oo00<007oo
Ool02Woo00<007ooOol0W7oo000MOol00`00Oomoo`1EOol00`00Oomoo`09Ool00`00Oomoo`2LOol0
01eoo`03001oogoo05Eoo`03001oogoo00Uoo`03001oogoo09aoo`007Goo00<007ooOol0EGoo00<0
07ooOol027oo00<007ooOol0WGoo000MOol00`00Oomoo`1FOol00`00Oomoo`07Ool00`00Oomoo`2M
Ool001eoo`03001oogoo05Ioo`03001oogoo00Moo`03001oogoo09eoo`007Goo00<007ooOol0EWoo
00<007ooOol01goo00<007ooOol0WGoo000MOol00`00Oomoo`1FOol00`00Oomoo`07Ool00`00Oomo
o`2MOol001eoo`03001oogoo05Ioo`03001oogoo00Ioo`03001oogoo09ioo`002Woo0P0017oo0P00
0goo100017oo00<007ooOol0Egoo00<007ooOol01Goo00<007ooOol0WWoo0009Ool01000Oomoo`00
0goo0P0017oo00<007ooOol017oo00<007ooOol0Egoo00<007ooOol01Goo00<007ooOol0WWoo0009
Ool01000Oomoo`002Woo00<007ooOol00goo0P00F7oo00<007ooOol01Goo00<007ooOol0WWoo0009
Ool01000Oomoo`002goo00<007ooOol00Woo00<007ooOol0Egoo00<007ooOol01Goo00<007ooOol0
WWoo0009Ool01000Oomoo`0027oo00@007ooOol000Aoo`03001oogoo05Moo`03001oogoo00Eoo`03
001oogoo09ioo`002Woo0P002Woo0P001Goo00<007ooOol0Egoo00<007ooOol017oo00<007ooOol0
Wgoo000MOol00`00Oomoo`1GOol00`00Oomoo`04Ool00`00Oomoo`2OOol001eoo`03001oogoo05Mo
o`03001oogoo00Aoo`03001oogoo09moo`007Goo00<007ooOol0Egoo00<007ooOol017oo00<007oo
Ool0Wgoo000MOol00`00Oomoo`1GOol00`00Oomoo`04Ool00`00Oomoo`2OOol001eoo`03001oogoo
05Moo`03001oogoo00Aoo`03001oogoo09moo`007Goo00<007ooOol0Egoo00<007ooOol017oo00<0
07ooOol0Wgoo000MOol00`00Oomoo`1GOol00`00Oomoo`04Ool00`00Oomoo`2OOol001eoo`03001o
ogoo05Moo`03001oogoo00Aoo`03001oogoo09moo`007Goo00<007ooOol0Egoo00<007ooOol017oo
00<007ooOol0Wgoo000MOol00`00Oomoo`1GOol00`00Oomoo`04Ool00`00Oomoo`2OOol001eoo`03
001oogoo05Moo`03001oogoo00Aoo`03001oogoo09moo`007Goo00<007ooOol0F7oo00<007ooOol0
0goo00<007ooOol0Wgoo000MOol00`00Oomoo`1HOol00`00Oomoo`03Ool00`00Oomoo`2OOol001eo
o`03001oogoo05Qoo`03001oogoo00=oo`03001oogoo09moo`007Goo00<007ooOol0F7oo00<007oo
Ool00goo00<007ooOol0Wgoo000MOol00`00Oomoo`1HOol00`00Oomoo`03Ool00`00Oomoo`2OOol0
01eoo`03001oogoo05Qoo`03001oogoo00=oo`03001oogoo09moo`007Goo00<007ooOol0F7oo00<0
07ooOol00goo00<007ooOol0Wgoo000MOol00`00Oomoo`1HOol00`00Oomoo`03Ool00`00Oomoo`2O
Ool001eoo`03001oogoo05Qoo`03001oogoo00=oo`03001oogoo09moo`007Goo00<007ooOol0F7oo
00<007ooOol00goo00<007ooOol0Wgoo000:Ool20004Ool20004Ool30004Ool00`00Oomoo`1HOol0
0`00Oomoo`03Ool00`00Oomoo`2OOol000Uoo`04001oogoo0003Ool20005Ool00`00Oomoo`03Ool0
0`00Oomoo`1HOol00`00Oomoo`03Ool00`00Oomoo`2OOol000Uoo`04001oogoo0008Ool40004Ool2
001IOol00`00Oomoo`03Ool00`00Oomoo`2OOol000Uoo`04001oogoo0008Ool00`00Ool00005Ool0
0`00Oomoo`1HOol00`00Oomoo`03Ool00`00Oomoo`2OOol000Uoo`04001oogoo0008Ool00`00Ool0
0005Ool00`00Oomoo`1HOol00`00Oomoo`03Ool00`00Oomoo`2OOol000Yoo`8000Yoo`8000Eoo`03
001oogoo05Qoo`03001oogoo00=oo`03001oogoo09moo`007Goo00<007ooOol0F7oo00<007ooOol0
0Woo00<007ooOol0X7oo000MOol00`00Oomoo`1HOol00`00Oomoo`02Ool00`00Oomoo`2POol001eo
o`03001oogoo05Qoo`03001oogoo009oo`03001oogoo0:1oo`007Goo00<007ooOol0F7oo00<007oo
Ool00Woo00<007ooOol0X7oo000MOol00`00Oomoo`1HOol00`00Oomoo`02Ool00`00Oomoo`2POol0
01eoo`03001oogoo05Qoo`03001oogoo009oo`03001oogoo0:1oo`007Goo00<007ooOol0F7oo00<0
07ooOol00Woo00<007ooOol0X7oo000MOol00`00Oomoo`1HOol00`00Oomoo`02Ool00`00Oomoo`2P
Ool001eoo`03001oogoo05Qoo`03001oogoo009oo`03001oogoo0:1oo`007Goo00<007ooOol0F7oo
00<007ooOol00Woo00<007ooOol0X7oo000MOol00`00Oomoo`1HOol00`00Oomoo`02Ool00`00Oomo
o`2POol001eoo`03001oogoo05Qoo`03001oogoo009oo`03001oogoo0:1oo`007Goo00<007ooOol0
F7oo00<007ooOol00Woo00<007ooOol0X7oo000MOol00`00Oomoo`1HOol00`00Oomoo`02Ool00`00
Oomoo`2POol001eoo`03001oogoo05Qoo`03001oogoo009oo`03001oogoo0:1oo`007Goo00<007oo
Ool0FGoo00D007ooOomoo`000:9oo`007Goo00<007ooOol0FGoo00D007ooOomoo`000:9oo`007Goo
00<007ooOol0FGoo00D007ooOomoo`000:9oo`007Goo00<007ooOol0FGoo00D007ooOomoo`000:9o
o`007Goo00<007ooOol0FGoo00D007ooOomoo`000:9oo`007Goo00<007ooOol0FGoo00D007ooOomo
o`000:9oo`002Woo0P0017oo0P0017oo0P001Goo00<007ooOol0FGoo00D007ooOomoo`000:9oo`00
2Goo00@007ooOol000=oo`8000=oo`04001oogoo0004Ool00`00Oomoo`1IOol01@00Oomoogoo0000
XWoo0009Ool01000Oomoo`0027oo00@007ooOol000Aoo`8005Yoo`05001oogooOol0002ROol000Uo
o`04001oogoo0008Ool30005Ool00`00Oomoo`1IOol01@00Oomoogoo0000XWoo0009Ool01000Oomo
o`0027oo00<007ooOol01Goo00<007ooOol0FGoo00D007ooOomoo`000:9oo`002Woo0P002Woo0`00
17oo00<007ooOol0FGoo00D007ooOomoo`000:9oo`007Goo00<007ooOol0FGoo00D007ooOomoo`00
0:9oo`007Goo00<007ooOol0FGoo00D007ooOomoo`000:9oo`007Goo00<007ooOol0FGoo00D007oo
Oomoo`000:9oo`007Goo00<007ooOol0FGoo00D007ooOomoo`000:9oo`007Goo00<007ooOol0FGoo
00D007ooOomoo`000:9oo`007Goo00<007ooOol0FGoo00D007ooOomoo`000:9oo`007Goo00<007oo
Ool0FGoo00D007ooOomoo`000:9oo`007Goo00<007ooOol0FGoo00D007ooOomoo`000:9oo`007Goo
00<007ooOol0FGoo00D007ooOomoo`000:9oo`007Goo00<007ooOol0FGoo00D007ooOomoo`000:9o
o`007Goo00<007ooOol0FGoo00D007ooOomoo`000:9oo`007Goo00<007ooOol0FWoo00@007ooOol0
0:9oo`007Goo00<007ooOol0FWoo00@007ooOol00:9oo`007Goo00<007ooOol0FWoo00@007ooOol0
0:9oo`007Goo00<007ooOol0FWoo00@007ooOol00:9oo`007Goo00<007ooOol0FWoo00@007ooOol0
0:9oo`007Goo00<007ooOol0FWoo00@007ooOol00:9oo`007Goo00<007ooOol0FWoo00@007ooOol0
0:9oo`007Goo00<007ooOol0FWoo00@007ooOol00:9oo`007Goo00<007ooOol0FWoo00@007ooOol0
0:9oo`002Woo0P0017oo0P0017oo0P001Goo00<007ooOol0FWoo00@007ooOol00:9oo`002Goo00@0
07ooOol000=oo`8000=oo`04001oogoo0004Ool00`00Oomoo`1JOol01000Oomoo`00XWoo0009Ool0
1000Oomoo`0027oo00@007ooOol000Aoo`8005]oo`04001oogoo002ROol000Uoo`04001oogoo0009
Ool20005Ool00`00Oomoo`1JOol01000Oomoo`00XWoo0009Ool01000Oomoo`0027oo00@007ooOol0
00Aoo`03001oogoo05Yoo`03001oo`000:=oo`002Woo0P002Woo0P001Goo00<007ooOol0FWoo00<0
07oo0000Xgoo000MOol00`00Oomoo`1KOol2002SOol001eoo`03001oogoo05]oo`800:=oo`007Goo
00<007ooOol0Fgoo0P00Xgoo000MOol00`00Oomoo`1KOol2002SOol001eoo`03001oogoo05]oo`80
0:=oo`007Goo00<007ooOol0Fgoo0P00Xgoo000MOol00`00Oomoo`1KOol2002SOol001eoo`03001o
ogoo05]oo`800:=oo`007Goo00<007ooOol0Fgoo0P00Xgoo000MOol00`00Oomoo`1KOol2002SOol0
01eoo`03001oogoo05]oo`800:=oo`007Goo00<007ooOol0Fgoo0P00Xgoo000MOol00`00Oomoo`1K
Ool2002SOol001eoo`03001oogoo05]oo`800:=oo`007Goo00<007ooOol0Fgoo0P00Xgoo000MOol0
0`00Oomoo`1KOol2002SOol001eoo`03001oogoo05aoo`03001oogoo0:5oo`007Goo00<007ooOol0
G7oo00<007ooOol0XGoo000MOol00`00Oomoo`1LOol00`00Oomoo`2QOol001eoo`03001oogoo05ao
o`03001oogoo0:5oo`007Goo00<007ooOol0G7oo00<007ooOol0XGoo000EOol30005Ool00`00Oomo
o`1LOol00`00Oomoo`2QOol001Ioo`03001oogoo00Aoo`03001oogoo05aoo`03001oogoo0:5oo`00
5Woo00<007ooOol017oo0P00GGoo00<007ooOol0XGoo000FOol00`00Oomoo`3oOol8Ool001Ioo`03
001oogoo0?moo`Qoo`005Goo0P00ogoo2Woo003oOolQOol00?moob5oo`00ogoo8Goo000>Ool4000R
Ool30003Ool30005Ool30009Ool30002Ool40007Ool20002Ool20002Ool40002Ool30003Ool30002
Ool40003Ool500000goo000000020002Ool50006Ool30004Ool30002Ool5000017oo000007oo0P00
0Woo1@00KGoo000?Ool00`00Oomoo`0SOol00`00Oomoo`03Ool00`00Oomoo`05Ool00`00Oomoo`07
Ool01@00Oomoogoo00000Woo00<007ooOol027oo00@007oo0000009oo`03001oogoo00=oo`07001o
ogooOol007oo00000goo00@007ooOol000Aoo`07001oogooOol007oo00001Goo00D007ooOomoo`00
00Moo`04001oogoo0002Ool01`00Oomoogoo001oo`00009oo`04001oogoo0002Ool01000Oomoo`00
0goo00<007ooOol0K7oo0003Ool500001goo001oo`00Ool007oo00@0009oo`D00003Ool0000000<0
009oo`<0009oo`D0009oo`D00003Ool00000008000=oo`03001oogoo00Eoo`03001oogoo00Moo`05
001oogooOol00002Ool00`00Oomoo`08Ool30003Ool500000goo001oo`04Ool01@00Oomoogoo0000
0Woo00<007ooOol00Woo00H007ooOomoo`00Ool500000goo001oo`02Ool00`00Oomoo`07Ool20002
Ool01`00Oomoogoo001oo`00009oo`04001oogoo0002Ool01000Oomoo`000goo00<007ooOol0K7oo
0003Ool01000Oomoo`000Woo00L007oo001oo`00Ool00003Ool01@00Oomoogoo00001Goo00<007oo
Ool00Woo00H007ooOol007oo0002Ool01000Oomoo`000goo00@007oo001oo`<000=oo`<000=oo`05
001oo`00Ool00007Ool01@00Oomoogoo00000Woo00<007ooOol027oo00@007ooOol0009oo`07001o
ogooOol007oo00000goo00<007oo00000goo00<007ooOol00P000goo00L007ooOomoo`00Ool00003
Ool00`00Ool00003Ool00`00Oomoo`05Ool20004Ool01`00Oomoogoo001oo`00009oo`04001oogoo
0002Ool01000Oomoo`000goo00<007ooOol0K7oo0003Ool40002Ool01`00Ool007oo001oo`0000=o
o`05001oogooOol00005Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01000Oomoo`000Woo00H007oo
Oomoo`00Ool50003Ool00`00Oomoo`03Ool01@00Ool007oo000027oo0`000Woo100027oo00@007oo
Ool000=oo`<000=oo`@0009oo`<0009oo`800003Ool00000009oo`@0009oo`<000=oo`@000Moo`04
001oogoo0003Ool3000017oo000007oo0P0000=oo`0000000`000goo1000KWoo0006Ool02P00Oomo
o`00Ool007oo001oo`000goo00D007ooOomoo`0000Eoo`03001oogoo009oo`03001oogoo009oo`04
001oogoo0002Ool01P00Oomoogoo001oo`H00003Ool0000000<0009oo`D000ioo`03001oogoo00Mo
o`@001moo`03001oogoo00Uoo`03001oogoo00Ioo`<001Qoo`03001oogoo06aoo`0017oo0`0000=o
o`0000002@0017oo00<007ooOol00Woo0P000goo100000Aoo`00001oo`8000=oo`@0009oo`<001eo
o`<002Uoo`8000Yoo`80029oo`8006ioo`005goo00<007ooOol027oo00<007ooOol037oo00<007oo
Ool0k7oo000EOol30005Ool00`00Oomoo`02Ool00`00Oomoo`0;Ool2003^Ool00?moob5oo`00ogoo
8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol0
0001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {946.587, -0.14072, 0.462505, 
  0.00748348}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-9.5 0.01 0 0.618034 [
[.3 -0.0125 -9 -9 ]
[.3 -0.0125 9 0 ]
[.5 -0.0125 -12 -9 ]
[.5 -0.0125 12 0 ]
[.7 -0.0125 -12 -9 ]
[.7 -0.0125 12 0 ]
[.9 -0.0125 -12 -9 ]
[.9 -0.0125 12 0 ]
[1.025 0 0 -6 ]
[1.025 0 58 6 ]
[.0875 .12361 -18 -4.5 ]
[.0875 .12361 0 4.5 ]
[.0875 .24721 -18 -4.5 ]
[.0875 .24721 0 4.5 ]
[.0875 .37082 -18 -4.5 ]
[.0875 .37082 0 4.5 ]
[.0875 .49443 -18 -4.5 ]
[.0875 .49443 0 4.5 ]
[.0875 .61803 -6 -4.5 ]
[.0875 .61803 0 4.5 ]
[.1 .64303 -29 0 ]
[.1 .64303 29 12 ]
[.5 .63053 -65 0 ]
[.5 .63053 65 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.3 0 m
.3 .00625 L
s
[(980)] .3 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1000)] .5 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(1020)] .7 -0.0125 0 1 Mshowa
.9 0 m
.9 .00625 L
s
[(1040)] .9 -0.0125 0 1 Mshowa
.125 Mabswid
.15 0 m
.15 .00375 L
s
.2 0 m
.2 .00375 L
s
.25 0 m
.25 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.45 0 m
.45 .00375 L
s
.55 0 m
.55 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.75 0 m
.75 .00375 L
s
.8 0 m
.8 .00375 L
s
.85 0 m
.85 .00375 L
s
.05 0 m
.05 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(frequency) show
117.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.1 .12361 m
.10625 .12361 L
s
[(0.2)] .0875 .12361 1 0 Mshowa
.1 .24721 m
.10625 .24721 L
s
[(0.4)] .0875 .24721 1 0 Mshowa
.1 .37082 m
.10625 .37082 L
s
[(0.6)] .0875 .37082 1 0 Mshowa
.1 .49443 m
.10625 .49443 L
s
[(0.8)] .0875 .49443 1 0 Mshowa
.1 .61803 m
.10625 .61803 L
s
[(1)] .0875 .61803 1 0 Mshowa
.125 Mabswid
.1 .0309 m
.10375 .0309 L
s
.1 .0618 m
.10375 .0618 L
s
.1 .09271 m
.10375 .09271 L
s
.1 .15451 m
.10375 .15451 L
s
.1 .18541 m
.10375 .18541 L
s
.1 .21631 m
.10375 .21631 L
s
.1 .27812 m
.10375 .27812 L
s
.1 .30902 m
.10375 .30902 L
s
.1 .33992 m
.10375 .33992 L
s
.1 .40172 m
.10375 .40172 L
s
.1 .43262 m
.10375 .43262 L
s
.1 .46353 m
.10375 .46353 L
s
.1 .52533 m
.10375 .52533 L
s
.1 .55623 m
.10375 .55623 L
s
.1 .58713 m
.10375 .58713 L
s
.25 Mabswid
.1 0 m
.1 .61803 L
s
gsave
.1 .64303 -90 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(amplitude) show
117.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.5 .63053 -126 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(FFT) show
87.000000 13.000000 moveto
(of) show
105.000000 13.000000 moveto
(Recorded) show
159.000000 13.000000 moveto
(Sound) show
189.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .00555 m
.01 .00428 L
.02 .0033 L
.03 .00493 L
.04 .00695 L
.05 .00678 L
.06 .0072 L
.07 .00531 L
.08 .00452 L
.09 .00598 L
.1 .00702 L
.11 .00837 L
.12 .00546 L
.13 .0053 L
.14 .00351 L
.15 .00659 L
.16 .00751 L
.17 .00735 L
.18 .00487 L
.19 .00595 L
.2 .00889 L
.21 .00484 L
.22 .00702 L
.23 .01028 L
.24 .0056 L
.25 .00633 L
.26 .01167 L
.27 .00623 L
.28 .00933 L
.29 .00468 L
.3 .00568 L
.31 .01434 L
.32 .0127 L
.33 .01327 L
.34 .01488 L
.35 .01239 L
.36 .0118 L
.37 .01461 L
.38 .01734 L
.39 .01641 L
.4 .02124 L
.41 .01735 L
.42 .02033 L
.43 .01904 L
.44 .02847 L
.45 .0265 L
.46 .03175 L
.47 .04163 L
.48 .04618 L
.49 .05606 L
Mistroke
.5 .07251 L
.51 .09605 L
.52 .14971 L
.53 .26908 L
.54 .61803 L
.55 .18135 L
.56 .10384 L
.57 .07526 L
.58 .05663 L
.59 .04424 L
.6 .03636 L
.61 .03379 L
.62 .03238 L
.63 .03184 L
.64 .0253 L
.65 .02118 L
.66 .01716 L
.67 .02034 L
.68 .01777 L
.69 .01521 L
.7 .01593 L
.71 .01432 L
.72 .01359 L
.73 .01073 L
.74 .01083 L
.75 .01124 L
.76 .01103 L
.77 .01693 L
.78 .0117 L
.79 .0115 L
.8 .0066 L
.81 .00863 L
.82 .00842 L
.83 .01143 L
.84 .00999 L
.85 .00862 L
.86 .00777 L
.87 .00708 L
.88 .00274 L
.89 .01021 L
.9 .00353 L
.91 .00787 L
.92 .0033 L
.93 .00383 L
.94 .00936 L
.95 .00532 L
.96 .00964 L
.97 .00537 L
.98 .00583 L
.99 .00158 L
Mistroke
1 .00536 L
Mfstroke
1 .00536 m
1 .00536 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
@7oo0`0017oo0P0017oo0P006Goo0`0017oo0P0017oo0P0017oo0P005Woo0`0017oo0P000goo1000
0goo0P005Woo0`0017oo0P0017oo0`000goo0P00CGoo0013Ool01000Oomoo`000Woo00@007ooOol0
009oo`03001oogoo01Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000Woo00@007oo
Ool001Ioo`03001oogoo009oo`04001oogoo0003Ool00`00Oomoo`02Ool01000Oomoo`005Woo00<0
07ooOol00Woo00@007ooOol000Aoo`05001oogooOol00002Ool00`00Oomoo`1:Ool0045oo`<0009o
o`04001oogoo0002Ool01000Oomoo`006Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo
0002Ool01000Oomoo`005Woo00<007ooOol00Woo00@007ooOol000Aoo`05001oogooOol00002Ool0
0`00Oomoo`0DOol00`00Oomoo`02Ool01000Oomoo`000Woo10000Woo00@007ooOol004aoo`00@7oo
00@007ooOol000=oo`8000=oo`04001oogoo000IOol00`00Oomoo`02Ool01000Oomoo`000Woo00@0
07ooOol0009oo`04001oogoo000FOol00`00Oomoo`02Ool01000Oomoo`001Goo00@007ooOol0009o
o`03001oogoo01Aoo`03001oogoo009oo`04001oogoo0002Ool00`00Ool00003Ool01000Oomoo`00
C7oo0010Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo000IOol00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol0009oo`04001oogoo000FOol00`00Oomoo`02Ool01000Oomoo`00
0Woo00@007ooOol0009oo`04001oogoo000FOol00`00Oomoo`02Ool01000Oomoo`000Woo00<007oo
00000goo00@007ooOol004aoo`00@Goo0P0017oo0P0017oo0P006Goo0P001Goo0P0017oo0P0017oo
0P005Woo0P001Goo0P0017oo0P0017oo0P005Woo0P001Goo0P0017oo0P0017oo0P00:Goo10005goo
0`001Woo003nOol00`00Oomoo`0GOol00`00Oomoo`05Ool00>Qoo`@0009oo`@000=oo`@0009oo`@0
0003Ool0000000<0009oo`@00004Ool00000Ool20002Ool30003Ool00`00Oomoo`04Ool00>Uoo`03
001oogoo00=oo`03001oogoo009oo`03001oogoo00=oo`07001oogooOol007oo00000Woo00@007oo
Ool000Eoo`04001oogoo0002Ool01@00Oomoogoo00000Woo00<007ooOol017oo0007OooI0009Ool0
0`00Oomoo`03Ool00`00Oomoo`02Ool500000goo001oo`02Ool00`00Ool00002Ool00`00Oomoo`05
00001Goo001oogoo00000Woo00<007ooOol00goo00<007oo00001Goo0008Ool80002Ool00`00Oomo
o`02Ool30003Ool00`00Oomoo`04Ool40005Ool30002Ool40007Ool00`00Oomoo`05Ool4000:Ool0
0`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool0
0`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool0
0`00Oomoo`02Ool20003Ool300000goo000000030002Ool00`00Oomoo`05Ool40009Ool00`00Oomo
o`03Ool20003Ool01`00Oomoogoo001oo`0000=oo`03001oo`00009oo`04001oogoo0003Ool00`00
Ool00002Ool01000Oomoo`000goo00D007oo001oo`0000Eoo`001goo00<007ooOol01Woo1`000goo
2P000goo1P000goo0`000goo0`0000=oo`0000000`0000=oo`0000000`000goo0P00:Goo00<007oo
Ool0:7oo00<007ooOol04Woo1`0017oo1P000Woo00@007oo0000009oo`03001oogoo00=oo`X000=o
o`03001oogoo00Ioo`@0009oo`800003Ool00000009oo`<000=oo`H00003Ool0000000=oo`<00003
Ool0000000<000=oo`H00003Ool0000000Aoo`007Goo00<007ooOol06Goo00<007ooOol00goo00<0
07ooOol027oo1P000Woo1@00B7oo3P000Woo10001goo10002Goo00<007ooOol07goo00<007ooOol0
=7oo000MOol00`00Oomoo`0`Ool20005Ool60002Ool300000goo0000000`Ool300000goo00000004
000>Ool2000jOol3000dOol001eoo`03001oogoo03eoo`8000=oo`03001oo`0002eoo`<000=oo`03
001oogoo08Eoo`007Goo00<007ooOol0AGoo00<007oo00000P009Woo0P00SWoo000MOol00`00Oomo
o`16Ool01000Oomoogoo0P0087oo1000T7oo000MOol00`00Oomoo`1<Ool00`00Oomoo`0IOol4002D
Ool001eoo`03001oogoo04eoo`8001Qoo`03001oogoo09Ioo`007Goo00<007ooOol0Cgoo00<007oo
Ool057oo00<007ooOol0Ugoo000MOol00`00Oomoo`1@Ool00`00Oomoo`0COol00`00Oomoo`2GOol0
01eoo`03001oogoo055oo`03001oogoo015oo`03001oogoo09Qoo`007Goo00<007ooOol0DGoo00<0
07ooOol047oo00<007ooOol0VGoo000MOol00`00Oomoo`1BOol00`00Oomoo`0?Ool00`00Oomoo`2I
Ool001eoo`03001oogoo059oo`03001oogoo00ioo`03001oogoo09Yoo`007Goo00<007ooOol0Dgoo
00<007ooOol03Goo00<007ooOol0VWoo000MOol00`00Oomoo`1COol00`00Oomoo`0<Ool00`00Oomo
o`2KOol001eoo`03001oogoo05Aoo`03001oogoo00]oo`03001oogoo09]oo`007Goo00<007ooOol0
E7oo00<007ooOol02Woo00<007ooOol0W7oo000MOol00`00Oomoo`1DOol00`00Oomoo`0:Ool00`00
Oomoo`2LOol001eoo`03001oogoo05Eoo`03001oogoo00Uoo`03001oogoo09aoo`007Goo00<007oo
Ool0EGoo00<007ooOol027oo00<007ooOol0WGoo000MOol00`00Oomoo`1EOol00`00Oomoo`08Ool0
0`00Oomoo`2MOol001eoo`03001oogoo05Eoo`03001oogoo00Qoo`03001oogoo09eoo`002Woo0P00
17oo0P000goo100017oo00<007ooOol0EWoo00<007ooOol01goo00<007ooOol0WGoo0009Ool01000
Oomoo`000goo0P0017oo00<007ooOol017oo00<007ooOol0EWoo00<007ooOol01goo00<007ooOol0
WGoo0009Ool01000Oomoo`002Woo00<007ooOol00goo0P00Egoo00<007ooOol01goo00<007ooOol0
WGoo0009Ool01000Oomoo`002goo00<007ooOol00Woo00<007ooOol0EWoo00<007ooOol01Woo00<0
07ooOol0WWoo0009Ool01000Oomoo`0027oo00@007ooOol000Aoo`03001oogoo05Ioo`03001oogoo
00Ioo`03001oogoo09ioo`002Woo0P002Woo0P001Goo00<007ooOol0EWoo00<007ooOol01Woo00<0
07ooOol0WWoo000MOol00`00Oomoo`1GOol00`00Oomoo`05Ool00`00Oomoo`2NOol001eoo`03001o
ogoo05Moo`03001oogoo00Eoo`03001oogoo09ioo`007Goo00<007ooOol0Egoo00<007ooOol01Goo
00<007ooOol0WWoo000MOol00`00Oomoo`1GOol00`00Oomoo`05Ool00`00Oomoo`2NOol001eoo`03
001oogoo05Moo`03001oogoo00Eoo`03001oogoo09ioo`007Goo00<007ooOol0Egoo00<007ooOol0
1Goo00<007ooOol0WWoo000MOol00`00Oomoo`1GOol00`00Oomoo`04Ool00`00Oomoo`2OOol001eo
o`03001oogoo05Moo`03001oogoo00Aoo`03001oogoo09moo`007Goo00<007ooOol0Egoo00<007oo
Ool017oo00<007ooOol0Wgoo000MOol00`00Oomoo`1HOol00`00Oomoo`03Ool00`00Oomoo`2OOol0
01eoo`03001oogoo05Qoo`03001oogoo00=oo`03001oogoo09moo`007Goo00<007ooOol0F7oo00<0
07ooOol00goo00<007ooOol0Wgoo000MOol00`00Oomoo`1HOol00`00Oomoo`03Ool00`00Oomoo`2O
Ool001eoo`03001oogoo05Qoo`03001oogoo00=oo`03001oogoo09moo`007Goo00<007ooOol0F7oo
00<007ooOol00goo00<007ooOol0Wgoo000MOol00`00Oomoo`1HOol00`00Oomoo`03Ool00`00Oomo
o`2OOol001eoo`03001oogoo05Qoo`03001oogoo00=oo`03001oogoo09moo`007Goo00<007ooOol0
F7oo00<007ooOol00goo00<007ooOol0Wgoo000MOol00`00Oomoo`1HOol00`00Oomoo`03Ool00`00
Oomoo`2OOol001eoo`03001oogoo05Qoo`03001oogoo00=oo`03001oogoo09moo`007Goo00<007oo
Ool0F7oo00<007ooOol00goo00<007ooOol0Wgoo000:Ool20004Ool20004Ool30004Ool00`00Oomo
o`1HOol00`00Oomoo`03Ool00`00Oomoo`2OOol000Uoo`04001oogoo0003Ool20005Ool00`00Oomo
o`03Ool00`00Oomoo`1IOol00`00Oomoo`02Ool00`00Oomoo`2OOol000Uoo`04001oogoo0008Ool4
0004Ool2001JOol00`00Oomoo`02Ool00`00Oomoo`2OOol000Uoo`04001oogoo0008Ool00`00Ool0
0005Ool00`00Oomoo`1IOol00`00Oomoo`02Ool00`00Oomoo`2OOol000Uoo`04001oogoo0008Ool0
0`00Ool00005Ool00`00Oomoo`1IOol00`00Oomoo`02Ool00`00Oomoo`2OOol000Yoo`8000Yoo`80
00Eoo`03001oogoo05Uoo`03001oogoo009oo`03001oogoo09moo`007Goo00<007ooOol0FGoo00<0
07ooOol00Woo00<007ooOol0Wgoo000MOol00`00Oomoo`1IOol00`00Oomoo`02Ool00`00Oomoo`2O
Ool001eoo`03001oogoo05Uoo`03001oogoo009oo`03001oogoo09moo`007Goo00<007ooOol0FGoo
00<007ooOol00Woo00<007ooOol0Wgoo000MOol00`00Oomoo`1IOol00`00Oomoo`02Ool00`00Oomo
o`2OOol001eoo`03001oogoo05Uoo`03001oogoo009oo`03001oogoo09moo`007Goo00<007ooOol0
FGoo00D007ooOomoo`000:9oo`007Goo00<007ooOol0FGoo00D007ooOomoo`000:9oo`007Goo00<0
07ooOol0FGoo00D007ooOomoo`000:9oo`007Goo00<007ooOol0FGoo00D007ooOomoo`000:9oo`00
7Goo00<007ooOol0FGoo00D007ooOomoo`000:9oo`007Goo00<007ooOol0FGoo00D007ooOomoo`00
0:9oo`007Goo00<007ooOol0FGoo00D007ooOomoo`000:9oo`007Goo00<007ooOol0FGoo00D007oo
Oomoo`000:9oo`007Goo00<007ooOol0FWoo00@007ooOol00:9oo`007Goo00<007ooOol0FWoo00@0
07ooOol00:9oo`007Goo00<007ooOol0FWoo00@007ooOol00:9oo`007Goo00<007ooOol0FWoo00@0
07ooOol00:9oo`007Goo00<007ooOol0FWoo00@007ooOol00:9oo`007Goo00<007ooOol0FWoo00@0
07ooOol00:9oo`007Goo00<007ooOol0FWoo00@007ooOol00:9oo`002Woo0P0017oo0P0017oo0P00
1Goo00<007ooOol0FWoo00@007ooOol00:9oo`002Goo00@007ooOol000=oo`8000=oo`04001oogoo
0004Ool00`00Oomoo`1JOol01000Oomoo`00XWoo0009Ool01000Oomoo`0027oo00@007ooOol000Ao
o`8005]oo`04001oogoo002ROol000Uoo`04001oogoo0008Ool30005Ool00`00Oomoo`1JOol01000
Oomoo`00XWoo0009Ool01000Oomoo`0027oo00<007ooOol01Goo00<007ooOol0FWoo00@007ooOol0
0:9oo`002Woo0P002Woo0`0017oo00<007ooOol0FWoo00@007ooOol00:9oo`007Goo00<007ooOol0
FWoo00@007ooOol00:9oo`007Goo00<007ooOol0FWoo00@007ooOol00:9oo`007Goo00<007ooOol0
FWoo00@007ooOol00:9oo`007Goo00<007ooOol0FWoo00@007ooOol00:9oo`007Goo00<007ooOol0
FWoo00@007ooOol00:9oo`007Goo00<007ooOol0FWoo00@007ooOol00:9oo`007Goo00<007ooOol0
FWoo00@007ooOol00:9oo`007Goo00<007ooOol0FWoo00@007ooOol00:9oo`007Goo00<007ooOol0
FWoo00@007ooOol00:9oo`007Goo00<007ooOol0FWoo00@007ooOol00:9oo`007Goo00<007ooOol0
FWoo00@007ooOol00:9oo`007Goo00<007ooOol0FWoo00@007ooOol00:9oo`007Goo00<007ooOol0
Fgoo00<007oo0000XWoo000MOol00`00Oomoo`1KOol00`00Ool0002ROol001eoo`03001oogoo05]o
o`03001oo`000:9oo`007Goo00<007ooOol0Fgoo00<007oo0000XWoo000MOol00`00Oomoo`1KOol0
0`00Ool0002ROol001eoo`03001oogoo05]oo`03001oo`000:9oo`007Goo00<007ooOol0Fgoo00<0
07oo0000XWoo000MOol00`00Oomoo`1KOol00`00Ool0002ROol000Yoo`8000Aoo`8000Aoo`8000Eo
o`03001oogoo05]oo`03001oo`000:9oo`002Goo00@007ooOol000=oo`8000=oo`04001oogoo0004
Ool00`00Oomoo`1KOol00`00Ool0002ROol000Uoo`04001oogoo0008Ool01000Oomoo`0017oo0P00
G7oo00<007oo0000XWoo0009Ool01000Oomoo`002Goo0P001Goo00<007ooOol0Fgoo00<007oo0000
XWoo0009Ool01000Oomoo`0027oo00@007ooOol000Aoo`03001oogoo05]oo`03001oo`000:9oo`00
2Woo0P002Woo0P001Goo00<007ooOol0Fgoo00<007oo0000XWoo000MOol00`00Oomoo`1KOol2002S
Ool001eoo`03001oogoo05]oo`800:=oo`007Goo00<007ooOol0Fgoo0P00Xgoo000MOol00`00Oomo
o`1KOol2002SOol001eoo`03001oogoo05]oo`800:=oo`007Goo00<007ooOol0Fgoo0P00Xgoo000M
Ool00`00Oomoo`1KOol2002SOol001eoo`03001oogoo05]oo`800:=oo`007Goo00<007ooOol0Fgoo
0P00Xgoo000MOol00`00Oomoo`1KOol2002SOol001eoo`03001oogoo05]oo`800:=oo`007Goo00<0
07ooOol0G7oo00<007ooOol0XGoo000MOol00`00Oomoo`1LOol00`00Oomoo`2QOol001eoo`03001o
ogoo05aoo`03001oogoo0:5oo`007Goo00<007ooOol0G7oo00<007ooOol0XGoo000MOol00`00Oomo
o`1LOol00`00Oomoo`2QOol001eoo`03001oogoo05aoo`03001oogoo0:5oo`007Goo00<007ooOol0
G7oo00<007ooOol0XGoo000MOol00`00Oomoo`1LOol00`00Oomoo`2QOol001eoo`03001oogoo05ao
o`03001oogoo0:5oo`007Goo00<007ooOol0G7oo00<007ooOol0XGoo000EOol30005Ool00`00Oomo
o`1LOol00`00Oomoo`2QOol001Ioo`03001oogoo00Aoo`03001oogoo05aoo`03001oogoo0:5oo`00
5Woo00<007ooOol017oo0P00GGoo00<007ooOol0XGoo000FOol00`00Oomoo`3oOol8Ool001Ioo`03
001oogoo0?moo`Qoo`005Goo0P00ogoo2Woo003oOolQOol00?moob5oo`00ogoo8Goo000>Ool4000R
Ool30003Ool30005Ool30009Ool30002Ool40007Ool20002Ool20002Ool40002Ool30003Ool30002
Ool40003Ool500000goo000000020002Ool50006Ool30004Ool30002Ool5000017oo000007oo0P00
0Woo1@00KGoo000?Ool00`00Oomoo`0SOol00`00Oomoo`03Ool00`00Oomoo`05Ool00`00Oomoo`07
Ool01@00Oomoogoo00000Woo00<007ooOol027oo00@007oo0000009oo`03001oogoo00=oo`07001o
ogooOol007oo00000goo00@007ooOol000Aoo`07001oogooOol007oo00001Goo00D007ooOomoo`00
00Moo`04001oogoo0002Ool01`00Oomoogoo001oo`00009oo`04001oogoo0002Ool01000Oomoo`00
0goo00<007ooOol0K7oo0003Ool500001goo001oo`00Ool007oo00@0009oo`D00003Ool0000000<0
009oo`<0009oo`D0009oo`D00003Ool00000008000=oo`03001oogoo00Eoo`03001oogoo00Moo`05
001oogooOol00002Ool00`00Oomoo`08Ool30003Ool500000goo001oo`04Ool01@00Oomoogoo0000
0Woo00<007ooOol00Woo00H007ooOomoo`00Ool500000goo001oo`02Ool00`00Oomoo`07Ool20002
Ool01`00Oomoogoo001oo`00009oo`04001oogoo0002Ool01000Oomoo`000goo00<007ooOol0K7oo
0003Ool01000Oomoo`000Woo00L007oo001oo`00Ool00003Ool01@00Oomoogoo00001Goo00<007oo
Ool00Woo00H007ooOol007oo0002Ool01000Oomoo`000goo00@007oo001oo`<000=oo`<000=oo`05
001oo`00Ool00007Ool01@00Oomoogoo00000Woo00<007ooOol027oo00@007ooOol0009oo`07001o
ogooOol007oo00000goo00<007oo00000goo00<007ooOol00P000goo00L007ooOomoo`00Ool00003
Ool00`00Ool00003Ool00`00Oomoo`05Ool20004Ool01`00Oomoogoo001oo`00009oo`04001oogoo
0002Ool01000Oomoo`000goo00<007ooOol0K7oo0003Ool40002Ool01`00Ool007oo001oo`0000=o
o`05001oogooOol00005Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01000Oomoo`000Woo00H007oo
Oomoo`00Ool50003Ool00`00Oomoo`03Ool01@00Ool007oo000027oo0`000Woo100027oo00@007oo
Ool000=oo`<000=oo`@0009oo`<0009oo`800003Ool00000009oo`@0009oo`<000=oo`@000Moo`04
001oogoo0003Ool3000017oo000007oo0P0000=oo`0000000`000goo1000KWoo0006Ool02P00Oomo
o`00Ool007oo001oo`000goo00D007ooOomoo`0000Eoo`03001oogoo009oo`03001oogoo009oo`04
001oogoo0002Ool01P00Oomoogoo001oo`H00003Ool0000000<0009oo`D000ioo`03001oogoo00Mo
o`@001moo`03001oogoo00Uoo`03001oogoo00Ioo`<001Qoo`03001oogoo06aoo`0017oo0`0000=o
o`0000002@0017oo00<007ooOol00Woo0P000goo100000Aoo`00001oo`8000=oo`@0009oo`<001eo
o`<002Uoo`8000Yoo`80029oo`8006ioo`005goo00<007ooOol027oo00<007ooOol037oo00<007oo
Ool0k7oo000EOol30005Ool00`00Oomoo`02Ool00`00Oomoo`0;Ool2003^Ool00?moob5oo`00ogoo
8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol0
0001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {946.587, -0.14072, 0.462505, 
  0.00748348}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-9.5 0.01 0 0.618034 [
[.3 -0.0125 -9 -9 ]
[.3 -0.0125 9 0 ]
[.5 -0.0125 -12 -9 ]
[.5 -0.0125 12 0 ]
[.7 -0.0125 -12 -9 ]
[.7 -0.0125 12 0 ]
[.9 -0.0125 -12 -9 ]
[.9 -0.0125 12 0 ]
[1.025 0 0 -6 ]
[1.025 0 58 6 ]
[.0875 .12361 -18 -4.5 ]
[.0875 .12361 0 4.5 ]
[.0875 .24721 -18 -4.5 ]
[.0875 .24721 0 4.5 ]
[.0875 .37082 -18 -4.5 ]
[.0875 .37082 0 4.5 ]
[.0875 .49443 -18 -4.5 ]
[.0875 .49443 0 4.5 ]
[.0875 .61803 -6 -4.5 ]
[.0875 .61803 0 4.5 ]
[.1 .64303 -29 0 ]
[.1 .64303 29 12 ]
[.5 .63053 -65 0 ]
[.5 .63053 65 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.3 0 m
.3 .00625 L
s
[(980)] .3 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1000)] .5 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(1020)] .7 -0.0125 0 1 Mshowa
.9 0 m
.9 .00625 L
s
[(1040)] .9 -0.0125 0 1 Mshowa
.125 Mabswid
.15 0 m
.15 .00375 L
s
.2 0 m
.2 .00375 L
s
.25 0 m
.25 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.45 0 m
.45 .00375 L
s
.55 0 m
.55 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.75 0 m
.75 .00375 L
s
.8 0 m
.8 .00375 L
s
.85 0 m
.85 .00375 L
s
.05 0 m
.05 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(frequency) show
117.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.1 .12361 m
.10625 .12361 L
s
[(0.2)] .0875 .12361 1 0 Mshowa
.1 .24721 m
.10625 .24721 L
s
[(0.4)] .0875 .24721 1 0 Mshowa
.1 .37082 m
.10625 .37082 L
s
[(0.6)] .0875 .37082 1 0 Mshowa
.1 .49443 m
.10625 .49443 L
s
[(0.8)] .0875 .49443 1 0 Mshowa
.1 .61803 m
.10625 .61803 L
s
[(1)] .0875 .61803 1 0 Mshowa
.125 Mabswid
.1 .0309 m
.10375 .0309 L
s
.1 .0618 m
.10375 .0618 L
s
.1 .09271 m
.10375 .09271 L
s
.1 .15451 m
.10375 .15451 L
s
.1 .18541 m
.10375 .18541 L
s
.1 .21631 m
.10375 .21631 L
s
.1 .27812 m
.10375 .27812 L
s
.1 .30902 m
.10375 .30902 L
s
.1 .33992 m
.10375 .33992 L
s
.1 .40172 m
.10375 .40172 L
s
.1 .43262 m
.10375 .43262 L
s
.1 .46353 m
.10375 .46353 L
s
.1 .52533 m
.10375 .52533 L
s
.1 .55623 m
.10375 .55623 L
s
.1 .58713 m
.10375 .58713 L
s
.25 Mabswid
.1 0 m
.1 .61803 L
s
gsave
.1 .64303 -90 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(amplitude) show
117.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.5 .63053 -126 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(FFT) show
87.000000 13.000000 moveto
(of) show
105.000000 13.000000 moveto
(Recorded) show
159.000000 13.000000 moveto
(Sound) show
189.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .00772 m
.01 .00414 L
.02 .00712 L
.03 .00786 L
.04 .00681 L
.05 .00614 L
.06 .00513 L
.07 .00598 L
.08 .00809 L
.09 .00561 L
.1 .00817 L
.11 .00787 L
.12 .00721 L
.13 .00554 L
.14 .00696 L
.15 .00427 L
.16 .00747 L
.17 .00588 L
.18 .00959 L
.19 .00764 L
.2 .00657 L
.21 .00864 L
.22 .00909 L
.23 .00596 L
.24 .0132 L
.25 .00958 L
.26 .01002 L
.27 .01049 L
.28 .00915 L
.29 .01074 L
.3 .01509 L
.31 .01287 L
.32 .01359 L
.33 .00974 L
.34 .01454 L
.35 .01504 L
.36 .01645 L
.37 .01505 L
.38 .01314 L
.39 .02001 L
.4 .02142 L
.41 .0216 L
.42 .02418 L
.43 .02657 L
.44 .03118 L
.45 .03058 L
.46 .03466 L
.47 .04504 L
.48 .04774 L
.49 .061 L
Mistroke
.5 .07664 L
.51 .1057 L
.52 .1927 L
.53 .48581 L
.54 .61803 L
.55 .19027 L
.56 .1136 L
.57 .07673 L
.58 .06343 L
.59 .04932 L
.6 .04243 L
.61 .03838 L
.62 .03396 L
.63 .02958 L
.64 .02606 L
.65 .02445 L
.66 .02396 L
.67 .02041 L
.68 .02125 L
.69 .0173 L
.7 .01454 L
.71 .0173 L
.72 .01712 L
.73 .01436 L
.74 .01273 L
.75 .01406 L
.76 .0121 L
.77 .00926 L
.78 .01242 L
.79 .0101 L
.8 .00927 L
.81 .0085 L
.82 .0091 L
.83 .01186 L
.84 .00997 L
.85 .0089 L
.86 .009 L
.87 .00902 L
.88 .00819 L
.89 .00786 L
.9 .00834 L
.91 .01073 L
.92 .00948 L
.93 .00839 L
.94 .00893 L
.95 .00546 L
.96 .00688 L
.97 .00806 L
.98 .00628 L
.99 .00878 L
Mistroke
1 .00681 L
Mfstroke
1 .00681 m
1 .00681 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
@7oo0`0017oo0P0017oo0P006Goo0`0017oo0P0017oo0P0017oo0P005Woo0`0017oo0P000goo1000
0goo0P005Woo0`0017oo0P0017oo0`000goo0P00CGoo0013Ool01000Oomoo`000Woo00@007ooOol0
009oo`03001oogoo01Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000Woo00@007oo
Ool001Ioo`03001oogoo009oo`04001oogoo0003Ool00`00Oomoo`02Ool01000Oomoo`005Woo00<0
07ooOol00Woo00@007ooOol000Aoo`05001oogooOol00002Ool00`00Oomoo`1:Ool0045oo`<0009o
o`04001oogoo0002Ool01000Oomoo`006Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo
0002Ool01000Oomoo`005Woo00<007ooOol00Woo00@007ooOol000Aoo`05001oogooOol00002Ool0
0`00Oomoo`0DOol00`00Oomoo`02Ool01000Oomoo`000Woo10000Woo00@007ooOol004aoo`00@7oo
00@007ooOol000=oo`8000=oo`04001oogoo000IOol00`00Oomoo`02Ool01000Oomoo`000Woo00@0
07ooOol0009oo`04001oogoo000FOol00`00Oomoo`02Ool01000Oomoo`001Goo00@007ooOol0009o
o`03001oogoo01Aoo`03001oogoo009oo`04001oogoo0002Ool00`00Ool00003Ool01000Oomoo`00
C7oo0010Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo000IOol00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol0009oo`04001oogoo000FOol00`00Oomoo`02Ool01000Oomoo`00
0Woo00@007ooOol0009oo`04001oogoo000FOol00`00Oomoo`02Ool01000Oomoo`000Woo00<007oo
00000goo00@007ooOol004aoo`00@Goo0P0017oo0P0017oo0P006Goo0P001Goo0P0017oo0P0017oo
0P005Woo0P001Goo0P0017oo0P0017oo0P005Woo0P001Goo0P0017oo0P0017oo0P00:Goo10005goo
0`001Woo003nOol00`00Oomoo`0GOol00`00Oomoo`05Ool00>Qoo`@0009oo`@000=oo`@0009oo`@0
0003Ool0000000<0009oo`@00004Ool00000Ool20002Ool30003Ool00`00Oomoo`04Ool00>Uoo`03
001oogoo00=oo`03001oogoo009oo`03001oogoo00=oo`07001oogooOol007oo00000Woo00@007oo
Ool000Eoo`04001oogoo0002Ool01@00Oomoogoo00000Woo00<007ooOol017oo0007OooI0009Ool0
0`00Oomoo`03Ool00`00Oomoo`02Ool500000goo001oo`02Ool00`00Ool00002Ool00`00Oomoo`05
00001Goo001oogoo00000Woo00<007ooOol00goo00<007oo00001Goo0008Ool30007Ool40007Ool0
0`00Oomoo`06Ool30009Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomo
o`07Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomo
o`07Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomo
o`07Ool00`00Oomoo`08Ool00`00Oomoo`0BOol00`00Oomoo`03Ool20003Ool01`00Oomoogoo001o
o`0000=oo`03001oo`00009oo`04001oogoo0003Ool00`00Ool00002Ool01000Oomoo`000goo00D0
07oo001oo`0000Eoo`001goo00@007ooOomoo`P000=ooa0000=ooa800004Ool000000003Ool40002
Ool00`00Oomoo`02Ool2000TOol00`00Oomoo`0XOol00`00Oomoo`0;Ool40003Ool70004Ool>0000
0goo0000000A0008Ool40002Ool200000goo00000002Ool30003Ool600000goo00000003Ool30000
0goo000000030003Ool600000goo00000004Ool001eoo`03001oogoo01]oo`04001oogooOol30004
Ool200000goo000000020002Ool00`00Oomoo`06Ool2001:Ool80004Ool30007Ool4000>Ool00`00
Oomoo`0JOol00`00Oomoo`0dOol001eoo`03001oogoo02Qoo`03001oogoo00Eoo`P0009oo`03001o
ogoo03ioo`T004Eoo`<003Aoo`007Goo00<007ooOol0>goo1`00=Goo1000QGoo000MOol00`00Oomo
o`12Ool4000ZOol70029Ool001eoo`03001oogoo04Ioo`@002Aoo`80091oo`007Goo00<007ooOol0
BWoo0P0087oo0P00TWoo000MOol00`00Oomoo`1<Ool00`00Oomoo`0KOol2002DOol001eoo`03001o
ogoo04eoo`8001Uoo`8009Ioo`007Goo00<007ooOol0Cgoo00<007ooOol057oo0P00V7oo000MOol0
0`00Oomoo`1?Ool00`00Oomoo`0DOol00`00Oomoo`2GOol001eoo`03001oogoo051oo`03001oogoo
019oo`03001oogoo09Qoo`007Goo00<007ooOol0DGoo00<007ooOol047oo00<007ooOol0VGoo000M
Ool00`00Oomoo`1AOol00`00Oomoo`0@Ool00`00Oomoo`2IOol001eoo`03001oogoo059oo`03001o
ogoo00ioo`03001oogoo09Yoo`007Goo00<007ooOol0Dgoo00<007ooOol037oo00<007ooOol0Vgoo
000MOol00`00Oomoo`1COol00`00Oomoo`0<Ool00`00Oomoo`2KOol001eoo`03001oogoo05Aoo`03
001oogoo00]oo`03001oogoo09]oo`007Goo00<007ooOol0E7oo00<007ooOol02Woo00<007ooOol0
W7oo000MOol00`00Oomoo`1DOol00`00Oomoo`0:Ool00`00Oomoo`2LOol001eoo`03001oogoo05Eo
o`03001oogoo00Uoo`03001oogoo09aoo`007Goo00<007ooOol0EGoo00<007ooOol02Goo00<007oo
Ool0W7oo000MOol00`00Oomoo`1EOol00`00Oomoo`08Ool00`00Oomoo`2MOol000Yoo`8000Aoo`80
00=oo`@000Aoo`03001oogoo05Eoo`03001oogoo00Qoo`03001oogoo09eoo`002Goo00@007ooOol0
00=oo`8000Aoo`03001oogoo00Aoo`03001oogoo05Eoo`03001oogoo00Qoo`03001oogoo09eoo`00
2Goo00@007ooOol000Yoo`03001oogoo00=oo`8005Ioo`03001oogoo00Qoo`03001oogoo09eoo`00
2Goo00@007ooOol000]oo`03001oogoo009oo`03001oogoo05Eoo`03001oogoo00Qoo`03001oogoo
09eoo`002Goo00@007ooOol000Qoo`04001oogoo0004Ool00`00Oomoo`1FOol00`00Oomoo`07Ool0
0`00Oomoo`2MOol000Yoo`8000Yoo`8000Eoo`03001oogoo05Ioo`03001oogoo00Ioo`03001oogoo
09ioo`007Goo00<007ooOol0EWoo00<007ooOol01Woo00<007ooOol0WWoo000MOol00`00Oomoo`1F
Ool00`00Oomoo`06Ool00`00Oomoo`2NOol001eoo`03001oogoo05Ioo`03001oogoo00Ioo`03001o
ogoo09ioo`007Goo00<007ooOol0EWoo00<007ooOol01Woo00<007ooOol0WWoo000MOol00`00Oomo
o`1FOol00`00Oomoo`06Ool00`00Oomoo`2NOol001eoo`03001oogoo05Ioo`03001oogoo00Ioo`03
001oogoo09ioo`007Goo00<007ooOol0EWoo00<007ooOol01Woo00<007ooOol0WWoo000MOol00`00
Oomoo`1GOol00`00Oomoo`05Ool00`00Oomoo`2NOol001eoo`03001oogoo05Moo`03001oogoo00Ao
o`03001oogoo09moo`007Goo00<007ooOol0Egoo00<007ooOol017oo00<007ooOol0Wgoo000MOol0
0`00Oomoo`1GOol00`00Oomoo`04Ool00`00Oomoo`2OOol001eoo`03001oogoo05Moo`03001oogoo
00Aoo`03001oogoo09moo`007Goo00<007ooOol0Egoo00<007ooOol017oo00<007ooOol0Wgoo000M
Ool00`00Oomoo`1GOol00`00Oomoo`04Ool00`00Oomoo`2OOol001eoo`03001oogoo05Moo`03001o
ogoo00Aoo`03001oogoo09moo`007Goo00<007ooOol0Egoo00<007ooOol017oo00<007ooOol0Wgoo
000MOol00`00Oomoo`1GOol00`00Oomoo`04Ool00`00Oomoo`2OOol001eoo`03001oogoo05Moo`03
001oogoo00Aoo`03001oogoo09moo`007Goo00<007ooOol0Egoo00<007ooOol017oo00<007ooOol0
Wgoo000MOol00`00Oomoo`1GOol00`00Oomoo`04Ool00`00Oomoo`2OOol001eoo`03001oogoo05Mo
o`03001oogoo00Aoo`03001oogoo09moo`002Woo0P0017oo0P0017oo0`0017oo00<007ooOol0Egoo
00<007ooOol017oo00<007ooOol0Wgoo0009Ool01000Oomoo`000goo0P001Goo00<007ooOol00goo
00<007ooOol0Egoo00<007ooOol017oo00<007ooOol0Wgoo0009Ool01000Oomoo`0027oo100017oo
0P00F7oo00<007ooOol017oo00<007ooOol0Wgoo0009Ool01000Oomoo`0027oo00<007oo00001Goo
00<007ooOol0Egoo00<007ooOol017oo00<007ooOol0Wgoo0009Ool01000Oomoo`0027oo00<007oo
00001Goo00<007ooOol0Egoo00<007ooOol017oo00<007ooOol0Wgoo000:Ool2000:Ool20005Ool0
0`00Oomoo`1GOol00`00Oomoo`04Ool00`00Oomoo`2OOol001eoo`03001oogoo05Moo`03001oogoo
00Aoo`03001oogoo09moo`007Goo00<007ooOol0F7oo00<007ooOol00goo00<007ooOol0Wgoo000M
Ool00`00Oomoo`1HOol00`00Oomoo`03Ool00`00Oomoo`2OOol001eoo`03001oogoo05Qoo`03001o
ogoo00=oo`03001oogoo09moo`007Goo00<007ooOol0F7oo00<007ooOol00goo00<007ooOol0Wgoo
000MOol00`00Oomoo`1HOol00`00Oomoo`03Ool00`00Oomoo`2OOol001eoo`03001oogoo05Qoo`03
001oogoo00=oo`03001oogoo09moo`007Goo00<007ooOol0F7oo00<007ooOol00goo00<007ooOol0
Wgoo000MOol00`00Oomoo`1HOol00`00Oomoo`02Ool00`00Oomoo`2POol001eoo`03001oogoo05Qo
o`03001oogoo009oo`03001oogoo0:1oo`007Goo00<007ooOol0F7oo00<007ooOol00Woo00<007oo
Ool0X7oo000MOol00`00Oomoo`1HOol00`00Oomoo`02Ool00`00Oomoo`2POol001eoo`03001oogoo
05Qoo`03001oogoo009oo`03001oogoo0:1oo`007Goo00<007ooOol0F7oo00<007ooOol00Woo00<0
07ooOol0X7oo000MOol00`00Oomoo`1HOol00`00Oomoo`02Ool00`00Oomoo`2POol001eoo`03001o
ogoo05Qoo`03001oogoo009oo`03001oogoo0:1oo`007Goo00<007ooOol0F7oo00<007ooOol00Woo
00<007ooOol0X7oo000MOol00`00Oomoo`1HOol00`00Oomoo`02Ool00`00Oomoo`2POol001eoo`03
001oogoo05Qoo`03001oogoo009oo`03001oogoo0:1oo`007Goo00<007ooOol0F7oo00<007ooOol0
0Woo00<007ooOol0X7oo000MOol00`00Oomoo`1HOol00`00Oomoo`02Ool00`00Oomoo`2POol000Yo
o`8000Aoo`8000Aoo`8000Eoo`03001oogoo05Qoo`03001oogoo009oo`03001oogoo0:1oo`002Goo
00@007ooOol000=oo`8000=oo`04001oogoo0004Ool00`00Oomoo`1HOol00`00Oomoo`02Ool00`00
Oomoo`2POol000Uoo`04001oogoo0008Ool01000Oomoo`0017oo0P00FGoo00<007ooOol00Woo00<0
07ooOol0X7oo0009Ool01000Oomoo`0027oo0`001Goo00<007ooOol0F7oo00<007ooOol00Woo00<0
07ooOol0X7oo0009Ool01000Oomoo`0027oo00<007ooOol01Goo00<007ooOol0F7oo00<007ooOol0
0Woo00<007ooOol0X7oo000:Ool2000:Ool30004Ool00`00Oomoo`1HOol00`00Oomoo`02Ool00`00
Oomoo`2POol001eoo`03001oogoo05Qoo`03001oogoo009oo`03001oogoo0:1oo`007Goo00<007oo
Ool0F7oo00<007ooOol00Woo00<007ooOol0X7oo000MOol00`00Oomoo`1HOol00`00Oomoo`02Ool0
0`00Oomoo`2POol001eoo`03001oogoo05Qoo`03001oogoo009oo`03001oogoo0:1oo`007Goo00<0
07ooOol0F7oo00<007ooOol00Woo00<007ooOol0X7oo000MOol00`00Oomoo`1IOol01@00Oomoogoo
0000XWoo000MOol00`00Oomoo`1IOol01@00Oomoogoo0000XWoo000MOol00`00Oomoo`1IOol01@00
Oomoogoo0000XWoo000MOol00`00Oomoo`1IOol01@00Oomoogoo0000XWoo000MOol00`00Oomoo`1I
Ool01@00Oomoogoo0000XWoo000MOol00`00Oomoo`1IOol01@00Oomoogoo0000XWoo000MOol00`00
Oomoo`1IOol01@00Oomoogoo0000XWoo000MOol00`00Oomoo`1IOol01@00Oomoogoo0000XWoo000M
Ool00`00Oomoo`1IOol01@00Oomoogoo0000XWoo000MOol00`00Oomoo`1IOol01@00Oomoogoo0000
XWoo000MOol00`00Oomoo`1IOol01@00Oomoogoo0000XWoo000MOol00`00Oomoo`1IOol01@00Oomo
ogoo0000XWoo000MOol00`00Oomoo`1IOol01@00Oomoogoo0000XWoo000MOol00`00Oomoo`1IOol0
1@00Oomoogoo0000XWoo000MOol00`00Oomoo`1IOol01@00Oomoogoo0000XWoo000:Ool20004Ool2
0004Ool20005Ool00`00Oomoo`1IOol01@00Oomoogoo0000XWoo0009Ool01000Oomoo`000goo0P00
0goo00@007ooOol000Aoo`03001oogoo05Uoo`05001oogooOol0002ROol000Uoo`04001oogoo0008
Ool01000Oomoo`0017oo0P00FWoo00D007ooOomoo`000:9oo`002Goo00@007ooOol000Uoo`8000Eo
o`03001oogoo05Uoo`05001oogooOol0002ROol000Uoo`04001oogoo0008Ool01000Oomoo`0017oo
00<007ooOol0FGoo00D007ooOomoo`000:9oo`002Woo0P002Woo0P001Goo00<007ooOol0FGoo00D0
07ooOomoo`000:9oo`007Goo00<007ooOol0FWoo00@007ooOol00:9oo`007Goo00<007ooOol0FWoo
00<007oo0000Xgoo000MOol00`00Oomoo`1JOol00`00Ool0002SOol001eoo`03001oogoo05Yoo`03
001oo`000:=oo`007Goo00<007ooOol0FWoo00<007oo0000Xgoo000MOol00`00Oomoo`1JOol00`00
Ool0002SOol001eoo`03001oogoo05Yoo`03001oo`000:=oo`007Goo00<007ooOol0FWoo00<007oo
0000Xgoo000MOol00`00Oomoo`1JOol00`00Ool0002SOol001eoo`03001oogoo05]oo`800:=oo`00
7Goo00<007ooOol0Fgoo0P00Xgoo000MOol00`00Oomoo`1KOol2002SOol001eoo`03001oogoo05]o
o`800:=oo`007Goo00<007ooOol0Fgoo0P00Xgoo000MOol00`00Oomoo`1KOol2002SOol001eoo`03
001oogoo05]oo`800:=oo`007Goo00<007ooOol0Fgoo0P00Xgoo000MOol00`00Oomoo`1KOol2002S
Ool001eoo`03001oogoo05]oo`800:=oo`007Goo00<007ooOol0G7oo00<007ooOol0XGoo000MOol0
0`00Oomoo`1LOol00`00Oomoo`2QOol001Eoo`<000Eoo`03001oogoo05aoo`03001oogoo0:5oo`00
5Woo00<007ooOol017oo00<007ooOol0G7oo00<007ooOol0XGoo000FOol00`00Oomoo`04Ool2001M
Ool00`00Oomoo`2QOol001Ioo`03001oogoo0?moo`Qoo`005Woo00<007ooOol0ogoo27oo000EOol2
003oOol:Ool00?moob5oo`00ogoo8Goo003oOolQOol000ioo`@0029oo`<000=oo`<000Eoo`<000Uo
o`<0009oo`@000Moo`80009oo`80009oo`@0009oo`<000=oo`<0009oo`@000=oo`D00003Ool00000
0080009oo`D000Ioo`<000Aoo`<0009oo`D00004Ool00000Ool20002Ool5001]Ool000moo`03001o
ogoo02=oo`03001oogoo00=oo`03001oogoo00Eoo`03001oogoo00Moo`05001oogooOol00002Ool0
0`00Oomoo`08Ool01000Ool000000Woo00<007ooOol00goo00L007ooOomoo`00Ool00003Ool01000
Oomoo`0017oo00L007ooOomoo`00Ool00005Ool01@00Oomoogoo00001goo00@007ooOol0009oo`07
001oogooOol007oo00000Woo00@007ooOol0009oo`04001oogoo0003Ool00`00Oomoo`1/Ool000=o
o`D00007Ool007oo001oo`00Ool010000Woo1@0000=oo`0000000`000Woo0`000Woo1@000Woo1@00
00=oo`0000000P000goo00<007ooOol01Goo00<007ooOol01goo00D007ooOomoo`00009oo`03001o
ogoo00Qoo`<000=oo`D00003Ool007oo00Aoo`05001oogooOol00002Ool00`00Oomoo`02Ool01P00
Oomoogoo001oo`D00003Ool007oo009oo`03001oogoo00Moo`80009oo`07001oogooOol007oo0000
0Woo00@007ooOol0009oo`04001oogoo0003Ool00`00Oomoo`1/Ool000=oo`04001oogoo0002Ool0
1`00Ool007oo001oo`0000=oo`05001oogooOol00005Ool00`00Oomoo`02Ool01P00Oomoo`00Ool0
009oo`04001oogoo0003Ool01000Ool007oo0`000goo0`000goo00D007oo001oo`0000Moo`05001o
ogooOol00002Ool00`00Oomoo`08Ool01000Oomoo`000Woo00L007ooOomoo`00Ool00003Ool00`00
Ool00003Ool00`00Oomoo`020003Ool01`00Oomoogoo001oo`0000=oo`03001oo`0000=oo`03001o
ogoo00Eoo`8000Aoo`07001oogooOol007oo00000Woo00@007ooOol0009oo`04001oogoo0003Ool0
0`00Oomoo`1/Ool000=oo`@0009oo`07001oo`00Ool007oo00000goo00D007ooOomoo`0000Eoo`03
001oogoo009oo`03001oogoo009oo`04001oogoo0002Ool01P00Oomoogoo001oo`D000=oo`03001o
ogoo00=oo`05001oo`00Ool00008Ool30002Ool40008Ool01000Oomoo`000goo0`000goo10000Woo
0`000Woo0P0000=oo`0000000Woo10000Woo0`000goo10001goo00@007ooOol000=oo`<00004Ool0
0000Ool200000goo000000030003Ool4001^Ool000Ioo`0:001oogoo001oo`00Ool007oo0003Ool0
1@00Oomoogoo00001Goo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`06001oogoo
Ool007oo1P0000=oo`0000000`000Woo1@003Woo00<007ooOol01goo10007goo00<007ooOol02Goo
00<007ooOol01Woo0`0067oo00<007ooOol0K7oo0004Ool300000goo000000090004Ool00`00Oomo
o`02Ool20003Ool4000017oo000007oo0P000goo10000Woo0`007Goo0`00:Goo0P002Woo0P008Woo
0P00KWoo000GOol00`00Oomoo`08Ool00`00Oomoo`0<Ool00`00Oomoo`3/Ool001Eoo`<000Eoo`03
001oogoo009oo`03001oogoo00]oo`800>ioo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {946.587, -0.14072, 0.462505, 
  0.00748348}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-9.5 0.01 0 0.618034 [
[.3 -0.0125 -9 -9 ]
[.3 -0.0125 9 0 ]
[.5 -0.0125 -12 -9 ]
[.5 -0.0125 12 0 ]
[.7 -0.0125 -12 -9 ]
[.7 -0.0125 12 0 ]
[.9 -0.0125 -12 -9 ]
[.9 -0.0125 12 0 ]
[1.025 0 0 -6 ]
[1.025 0 58 6 ]
[.0875 .12361 -18 -4.5 ]
[.0875 .12361 0 4.5 ]
[.0875 .24721 -18 -4.5 ]
[.0875 .24721 0 4.5 ]
[.0875 .37082 -18 -4.5 ]
[.0875 .37082 0 4.5 ]
[.0875 .49443 -18 -4.5 ]
[.0875 .49443 0 4.5 ]
[.0875 .61803 -6 -4.5 ]
[.0875 .61803 0 4.5 ]
[.1 .64303 -29 0 ]
[.1 .64303 29 12 ]
[.5 .63053 -65 0 ]
[.5 .63053 65 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.3 0 m
.3 .00625 L
s
[(980)] .3 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1000)] .5 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(1020)] .7 -0.0125 0 1 Mshowa
.9 0 m
.9 .00625 L
s
[(1040)] .9 -0.0125 0 1 Mshowa
.125 Mabswid
.15 0 m
.15 .00375 L
s
.2 0 m
.2 .00375 L
s
.25 0 m
.25 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.45 0 m
.45 .00375 L
s
.55 0 m
.55 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.75 0 m
.75 .00375 L
s
.8 0 m
.8 .00375 L
s
.85 0 m
.85 .00375 L
s
.05 0 m
.05 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(frequency) show
117.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.1 .12361 m
.10625 .12361 L
s
[(0.2)] .0875 .12361 1 0 Mshowa
.1 .24721 m
.10625 .24721 L
s
[(0.4)] .0875 .24721 1 0 Mshowa
.1 .37082 m
.10625 .37082 L
s
[(0.6)] .0875 .37082 1 0 Mshowa
.1 .49443 m
.10625 .49443 L
s
[(0.8)] .0875 .49443 1 0 Mshowa
.1 .61803 m
.10625 .61803 L
s
[(1)] .0875 .61803 1 0 Mshowa
.125 Mabswid
.1 .0309 m
.10375 .0309 L
s
.1 .0618 m
.10375 .0618 L
s
.1 .09271 m
.10375 .09271 L
s
.1 .15451 m
.10375 .15451 L
s
.1 .18541 m
.10375 .18541 L
s
.1 .21631 m
.10375 .21631 L
s
.1 .27812 m
.10375 .27812 L
s
.1 .30902 m
.10375 .30902 L
s
.1 .33992 m
.10375 .33992 L
s
.1 .40172 m
.10375 .40172 L
s
.1 .43262 m
.10375 .43262 L
s
.1 .46353 m
.10375 .46353 L
s
.1 .52533 m
.10375 .52533 L
s
.1 .55623 m
.10375 .55623 L
s
.1 .58713 m
.10375 .58713 L
s
.25 Mabswid
.1 0 m
.1 .61803 L
s
gsave
.1 .64303 -90 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(amplitude) show
117.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.5 .63053 -126 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(FFT) show
87.000000 13.000000 moveto
(of) show
105.000000 13.000000 moveto
(Recorded) show
159.000000 13.000000 moveto
(Sound) show
189.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .00809 m
.01 .00425 L
.02 .0032 L
.03 .00476 L
.04 .00402 L
.05 .00873 L
.06 .00642 L
.07 .00742 L
.08 .00812 L
.09 .00579 L
.1 .00577 L
.11 .00633 L
.12 .00841 L
.13 .00542 L
.14 .00804 L
.15 .00699 L
.16 .00942 L
.17 .00846 L
.18 .00918 L
.19 .00609 L
.2 .00759 L
.21 .00831 L
.22 .00868 L
.23 .00719 L
.24 .00954 L
.25 .00997 L
.26 .01171 L
.27 .00759 L
.28 .01061 L
.29 .00936 L
.3 .00971 L
.31 .01154 L
.32 .01263 L
.33 .01562 L
.34 .01168 L
.35 .0161 L
.36 .01636 L
.37 .01741 L
.38 .01701 L
.39 .01899 L
.4 .02086 L
.41 .0232 L
.42 .02346 L
.43 .02501 L
.44 .02815 L
.45 .03216 L
.46 .03565 L
.47 .03916 L
.48 .05 L
.49 .06056 L
Mistroke
.5 .07602 L
.51 .10745 L
.52 .16089 L
.53 .61803 L
.54 .60972 L
.55 .18992 L
.56 .11279 L
.57 .08098 L
.58 .06501 L
.59 .04773 L
.6 .04257 L
.61 .03801 L
.62 .03193 L
.63 .02906 L
.64 .02973 L
.65 .024 L
.66 .02289 L
.67 .01898 L
.68 .01827 L
.69 .01706 L
.7 .01494 L
.71 .01918 L
.72 .0169 L
.73 .01443 L
.74 .015 L
.75 .01207 L
.76 .01456 L
.77 .01068 L
.78 .01176 L
.79 .01045 L
.8 .01138 L
.81 .00834 L
.82 .01256 L
.83 .0065 L
.84 .01058 L
.85 .00675 L
.86 .00615 L
.87 .00806 L
.88 .01024 L
.89 .00654 L
.9 .00844 L
.91 .00836 L
.92 .00766 L
.93 .0098 L
.94 .0067 L
.95 .00491 L
.96 .00899 L
.97 .00719 L
.98 .0055 L
.99 .00665 L
Mistroke
1 .00872 L
Mfstroke
1 .00872 m
1 .00872 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
@7oo0`0017oo0P0017oo0P006Goo0`0017oo0P0017oo0P0017oo0P005Woo0`0017oo0P000goo1000
0goo0P005Woo0`0017oo0P0017oo0`000goo0P00CGoo0013Ool01000Oomoo`000Woo00@007ooOol0
009oo`03001oogoo01Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000Woo00@007oo
Ool001Ioo`03001oogoo009oo`04001oogoo0003Ool00`00Oomoo`02Ool01000Oomoo`005Woo00<0
07ooOol00Woo00@007ooOol000Aoo`05001oogooOol00002Ool00`00Oomoo`1:Ool0045oo`<0009o
o`04001oogoo0002Ool01000Oomoo`006Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo
0002Ool01000Oomoo`005Woo00<007ooOol00Woo00@007ooOol000Aoo`05001oogooOol00002Ool0
0`00Oomoo`0DOol00`00Oomoo`02Ool01000Oomoo`000Woo10000Woo00@007ooOol004aoo`00@7oo
00@007ooOol000=oo`8000=oo`04001oogoo000IOol00`00Oomoo`02Ool01000Oomoo`000Woo00@0
07ooOol0009oo`04001oogoo000FOol00`00Oomoo`02Ool01000Oomoo`001Goo00@007ooOol0009o
o`03001oogoo01Aoo`03001oogoo009oo`04001oogoo0002Ool00`00Ool00003Ool01000Oomoo`00
C7oo0010Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo000IOol00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol0009oo`04001oogoo000FOol00`00Oomoo`02Ool01000Oomoo`00
0Woo00@007ooOol0009oo`04001oogoo000FOol00`00Oomoo`02Ool01000Oomoo`000Woo00<007oo
00000goo00@007ooOol004aoo`00@Goo0P0017oo0P0017oo0P006Goo0P001Goo0P0017oo0P0017oo
0P005Woo0P001Goo0P0017oo0P0017oo0P005Woo0P001Goo0P0017oo0P0017oo0P00:Goo10005goo
0`001Woo003nOol00`00Oomoo`0GOol00`00Oomoo`05Ool00>Qoo`@0009oo`@000=oo`@0009oo`@0
0003Ool0000000<0009oo`@00004Ool00000Ool20002Ool30003Ool00`00Oomoo`04Ool00>Uoo`03
001oogoo00=oo`03001oogoo009oo`03001oogoo00=oo`07001oogooOol007oo00000Woo00@007oo
Ool000Eoo`04001oogoo0002Ool01@00Oomoogoo00000Woo00<007ooOol017oo0007OooI0009Ool0
0`00Oomoo`03Ool00`00Oomoo`02Ool500000goo001oo`02Ool00`00Ool00002Ool00`00Oomoo`05
00001Goo001oogoo00000Woo00<007ooOol00goo00<007oo00001Goo0008Ool;000:Ool00`00Oomo
o`07Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomo
o`07Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomo
o`07Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomo
o`07Ool00`00Oomoo`07Ool3000COol00`00Oomoo`03Ool20003Ool01`00Oomoogoo001oo`0000=o
o`03001oo`00009oo`04001oogoo0003Ool00`00Ool00002Ool01000Oomoo`000goo00D007oo001o
o`0000Eoo`001goo00<007ooOol027oo:`000goo0`000Woo1@00:Goo00<007ooOol0:7oo00<007oo
Ool057oo0`0000=oo`0000000P0000=oo`0000001@0000=oo`0000002`000goo2P0027oo10000Woo
0P0000=oo`0000000Woo0`000goo1P0000=oo`0000000goo0`0000=oo`0000000`000goo1P0000=o
o`00000017oo000MOol00`00Oomoo`0MOol30003Ool20005Ool400000goo00000002001AOol30000
1Goo00000000Ool02@000goo00<007ooOol00Woo00<007ooOol01Goo00<007ooOol08Goo00<007oo
Ool0=7oo000MOol00`00Oomoo`0^Ool00`00Oomoo`02Ool:000jOol90002Ool20003Ool01@00Oomo
ogoo0000?Goo0`00=7oo000MOol00`00Oomoo`0mOol7000aOol20009Ool2001nOol001eoo`03001o
ogoo04Aoo`@002Yoo`<008]oo`007Goo00<007ooOol0B7oo0P008goo1@00SWoo000MOol00`00Oomo
o`1:Ool3000OOol00`00Oomoo`2AOol001eoo`03001oogoo04eoo`03001oogoo01Yoo`8009Aoo`00
7Goo00<007ooOol0CWoo00<007ooOol05goo0P00UWoo000MOol00`00Oomoo`1?Ool00`00Oomoo`0D
Ool2002HOol001eoo`03001oogoo051oo`03001oogoo01=oo`03001oogoo09Moo`007Goo00<007oo
Ool0DGoo00<007ooOol04Goo00<007ooOol0V7oo000MOol00`00Oomoo`1AOol00`00Oomoo`0@Ool0
0`00Oomoo`2IOol001eoo`03001oogoo059oo`03001oogoo00moo`03001oogoo09Uoo`007Goo00<0
07ooOol0DWoo00<007ooOol03Woo00<007ooOol0VWoo000MOol00`00Oomoo`1COol00`00Oomoo`0=
Ool00`00Oomoo`2JOol001eoo`03001oogoo05=oo`03001oogoo00aoo`03001oogoo09]oo`007Goo
00<007ooOol0Dgoo00<007ooOol037oo00<007ooOol0Vgoo000MOol00`00Oomoo`1DOol00`00Oomo
o`0;Ool00`00Oomoo`2KOol001eoo`03001oogoo05Aoo`03001oogoo00Yoo`03001oogoo09aoo`00
7Goo00<007ooOol0E7oo00<007ooOol02Woo00<007ooOol0W7oo000MOol00`00Oomoo`1EOol00`00
Oomoo`09Ool00`00Oomoo`2LOol001eoo`03001oogoo05Eoo`03001oogoo00Qoo`03001oogoo09eo
o`002Woo0P0017oo0P000goo100017oo00<007ooOol0EGoo00<007ooOol027oo00<007ooOol0WGoo
0009Ool01000Oomoo`000goo0P0017oo00<007ooOol017oo00<007ooOol0EGoo00<007ooOol027oo
00<007ooOol0WGoo0009Ool01000Oomoo`002Woo00<007ooOol00goo0P00EWoo00<007ooOol027oo
00<007ooOol0WGoo0009Ool01000Oomoo`002goo00<007ooOol00Woo00<007ooOol0EWoo00<007oo
Ool01goo00<007ooOol0WGoo0009Ool01000Oomoo`0027oo00@007ooOol000Aoo`03001oogoo05Io
o`03001oogoo00Moo`03001oogoo09eoo`002Woo0P002Woo0P001Goo00<007ooOol0EWoo00<007oo
Ool01Woo00<007ooOol0WWoo000MOol00`00Oomoo`1FOol00`00Oomoo`06Ool00`00Oomoo`2NOol0
01eoo`03001oogoo05Ioo`03001oogoo00Ioo`03001oogoo09ioo`007Goo00<007ooOol0Egoo00<0
07ooOol01Goo00<007ooOol0WWoo000MOol00`00Oomoo`1GOol00`00Oomoo`05Ool00`00Oomoo`2N
Ool001eoo`03001oogoo05Moo`03001oogoo00Eoo`03001oogoo09ioo`007Goo00<007ooOol0Egoo
00<007ooOol01Goo00<007ooOol0WWoo000MOol00`00Oomoo`1GOol00`00Oomoo`05Ool00`00Oomo
o`2NOol001eoo`03001oogoo05Moo`03001oogoo00Aoo`03001oogoo09moo`007Goo00<007ooOol0
Egoo00<007ooOol017oo00<007ooOol0Wgoo000MOol00`00Oomoo`1GOol00`00Oomoo`04Ool00`00
Oomoo`2OOol001eoo`03001oogoo05Moo`03001oogoo00Aoo`03001oogoo09moo`007Goo00<007oo
Ool0Egoo00<007ooOol017oo00<007ooOol0Wgoo000MOol00`00Oomoo`1GOol00`00Oomoo`04Ool0
0`00Oomoo`2OOol001eoo`03001oogoo05Moo`03001oogoo00Aoo`03001oogoo09moo`007Goo00<0
07ooOol0Egoo00<007ooOol017oo00<007ooOol0Wgoo000MOol00`00Oomoo`1GOol00`00Oomoo`04
Ool00`00Oomoo`2OOol001eoo`03001oogoo05Moo`03001oogoo00Aoo`03001oogoo09moo`007Goo
00<007ooOol0Egoo00<007ooOol017oo00<007ooOol0Wgoo000MOol00`00Oomoo`1GOol00`00Oomo
o`04Ool00`00Oomoo`2OOol001eoo`03001oogoo05Moo`03001oogoo00Aoo`03001oogoo09moo`00
7Goo00<007ooOol0Egoo00<007ooOol017oo00<007ooOol0Wgoo000:Ool20004Ool20004Ool30004
Ool00`00Oomoo`1GOol00`00Oomoo`04Ool00`00Oomoo`2OOol000Uoo`04001oogoo0003Ool20005
Ool00`00Oomoo`03Ool00`00Oomoo`1GOol00`00Oomoo`04Ool00`00Oomoo`2OOol000Uoo`04001o
ogoo0008Ool40004Ool2001HOol00`00Oomoo`04Ool00`00Oomoo`2OOol000Uoo`04001oogoo0008
Ool00`00Ool00005Ool00`00Oomoo`1GOol00`00Oomoo`04Ool00`00Oomoo`2OOol000Uoo`04001o
ogoo0008Ool00`00Ool00005Ool00`00Oomoo`1GOol00`00Oomoo`04Ool00`00Oomoo`2OOol000Yo
o`8000Yoo`8000Eoo`03001oogoo05Moo`03001oogoo00Aoo`03001oogoo09moo`007Goo00<007oo
Ool0Egoo00<007ooOol017oo00<007ooOol0Wgoo000MOol00`00Oomoo`1GOol00`00Oomoo`04Ool0
0`00Oomoo`2OOol001eoo`03001oogoo05Moo`03001oogoo00Aoo`03001oogoo09moo`007Goo00<0
07ooOol0F7oo00<007ooOol00goo00<007ooOol0Wgoo000MOol00`00Oomoo`1HOol00`00Oomoo`03
Ool00`00Oomoo`2OOol001eoo`03001oogoo05Qoo`03001oogoo00=oo`03001oogoo09moo`007Goo
00<007ooOol0F7oo00<007ooOol00goo00<007ooOol0Wgoo000MOol00`00Oomoo`1HOol00`00Oomo
o`02Ool00`00Oomoo`2POol001eoo`03001oogoo05Qoo`03001oogoo009oo`03001oogoo0:1oo`00
7Goo00<007ooOol0F7oo00<007ooOol00Woo00<007ooOol0X7oo000MOol00`00Oomoo`1HOol00`00
Oomoo`02Ool00`00Oomoo`2POol001eoo`03001oogoo05Qoo`03001oogoo009oo`03001oogoo0:1o
o`007Goo00<007ooOol0F7oo00<007ooOol00Woo00<007ooOol0X7oo000MOol00`00Oomoo`1HOol0
0`00Oomoo`02Ool00`00Oomoo`2POol001eoo`03001oogoo05Qoo`03001oogoo009oo`03001oogoo
0:1oo`007Goo00<007ooOol0F7oo00<007ooOol00Woo00<007ooOol0X7oo000MOol00`00Oomoo`1H
Ool00`00Oomoo`02Ool00`00Oomoo`2POol001eoo`03001oogoo05Qoo`03001oogoo009oo`03001o
ogoo0:1oo`007Goo00<007ooOol0F7oo00<007ooOol00Woo00<007ooOol0X7oo000MOol00`00Oomo
o`1HOol00`00Oomoo`02Ool00`00Oomoo`2POol001eoo`03001oogoo05Qoo`03001oogoo009oo`03
001oogoo0:1oo`002Woo0P0017oo0P0017oo0P001Goo00<007ooOol0F7oo00<007ooOol00Woo00<0
07ooOol0X7oo0009Ool01000Oomoo`000goo0P000goo00@007ooOol000Aoo`03001oogoo05Qoo`03
001oogoo009oo`03001oogoo0:1oo`002Goo00@007ooOol000Qoo`04001oogoo0004Ool2001IOol0
0`00Oomoo`02Ool00`00Oomoo`2POol000Uoo`04001oogoo0008Ool30005Ool00`00Oomoo`1HOol0
0`00Oomoo`02Ool00`00Oomoo`2POol000Uoo`04001oogoo0008Ool00`00Oomoo`05Ool00`00Oomo
o`1HOol00`00Oomoo`02Ool00`00Oomoo`2POol000Yoo`8000Yoo`<000Aoo`03001oogoo05Qoo`03
001oogoo009oo`03001oogoo0:1oo`007Goo00<007ooOol0F7oo00<007ooOol00Woo00<007ooOol0
X7oo000MOol00`00Oomoo`1HOol00`00Oomoo`02Ool00`00Oomoo`2POol001eoo`03001oogoo05Qo
o`03001oogoo009oo`03001oogoo0:1oo`007Goo00<007ooOol0F7oo00<007ooOol00Woo00<007oo
Ool0X7oo000MOol00`00Oomoo`1HOol00`00Oomoo`02Ool00`00Oomoo`2POol001eoo`03001oogoo
05Qoo`03001oogoo009oo`03001oogoo0:1oo`007Goo00<007ooOol0F7oo00<007ooOol00Woo00<0
07ooOol0X7oo000MOol00`00Oomoo`1HOol00`00Oomoo`02Ool00`00Oomoo`2POol001eoo`03001o
ogoo05Qoo`03001oogoo009oo`03001oogoo0:1oo`007Goo00<007ooOol0F7oo00<007ooOol00Woo
00<007ooOol0X7oo000MOol00`00Oomoo`1HOol00`00Oomoo`02Ool00`00Oomoo`2POol001eoo`03
001oogoo05Qoo`03001oogoo009oo`03001oogoo0:1oo`007Goo00<007ooOol0F7oo00<007ooOol0
0Woo00<007ooOol0X7oo000MOol00`00Oomoo`1HOol00`00Oomoo`02Ool00`00Oomoo`2POol001eo
o`03001oogoo05Qoo`03001oogoo009oo`03001oogoo0:1oo`007Goo00<007ooOol0F7oo00<007oo
Ool00Woo00<007ooOol0X7oo000MOol00`00Oomoo`1HOol00`00Oomoo`02Ool00`00Oomoo`2POol0
01eoo`03001oogoo05Qoo`03001oogoo009oo`03001oogoo0:1oo`007Goo00<007ooOol0F7oo00<0
07ooOol00Woo00<007ooOol0X7oo000MOol00`00Oomoo`1HOol00`00Oomoo`02Ool00`00Oomoo`2P
Ool000Yoo`8000Aoo`8000Aoo`8000Eoo`03001oogoo05Qoo`03001oogoo009oo`03001oogoo0:1o
o`002Goo00@007ooOol000=oo`8000=oo`04001oogoo0004Ool00`00Oomoo`1HOol00`00Oomoo`02
Ool00`00Oomoo`2POol000Uoo`04001oogoo0008Ool01000Oomoo`0017oo0P00FGoo00<007ooOol0
0Woo00<007ooOol0X7oo0009Ool01000Oomoo`002Goo0P001Goo00<007ooOol0F7oo00<007ooOol0
0Woo00<007ooOol0X7oo0009Ool01000Oomoo`0027oo00@007ooOol000Aoo`03001oogoo05Qoo`03
001oogoo009oo`03001oogoo0:1oo`002Woo0P002Woo0P001Goo00<007ooOol0FGoo00@007ooOol0
0:=oo`007Goo00<007ooOol0FGoo00@007ooOol00:=oo`007Goo00<007ooOol0FGoo00@007ooOol0
0:=oo`007Goo00<007ooOol0FGoo00@007ooOol00:=oo`007Goo00<007ooOol0FGoo00@007ooOol0
0:=oo`007Goo00<007ooOol0FGoo00@007ooOol00:=oo`007Goo00<007ooOol0FGoo00@007ooOol0
0:=oo`007Goo00<007ooOol0FGoo00@007ooOol00:=oo`007Goo00<007ooOol0FGoo00@007ooOol0
0:=oo`007Goo00<007ooOol0FGoo00@007ooOol00:=oo`007Goo00<007ooOol0FGoo00@007ooOol0
0:=oo`007Goo00<007ooOol0FGoo00@007ooOol00:=oo`007Goo00<007ooOol0FGoo00@007ooOol0
0:=oo`007Goo00<007ooOol0FGoo00@007ooOol00:=oo`007Goo00<007ooOol0FGoo00@007ooOol0
0:=oo`007Goo00<007ooOol0FGoo00@007ooOol00:=oo`007Goo00<007ooOol0FGoo00@007ooOol0
0:=oo`007Goo00<007ooOol0FGoo00@007ooOol00:=oo`007Goo00<007ooOol0FGoo00@007ooOol0
0:=oo`007Goo00<007ooOol0FGoo00@007ooOol00:=oo`007Goo00<007ooOol0FGoo00@007ooOol0
0:=oo`007Goo00<007ooOol0FGoo00@007ooOol00:=oo`005Goo0`001Goo00<007ooOol0FGoo00@0
07oo00000:=oo`005Woo00<007ooOol017oo00<007ooOol0FGoo0P00YGoo000FOol00`00Oomoo`04
Ool2001JOol00`00Oomoo`2TOol001Ioo`03001oogoo0?moo`Qoo`005Woo00<007ooOol0ogoo27oo
000EOol2003oOol:Ool00?moob5oo`00ogoo8Goo003oOolQOol000ioo`@0029oo`<000=oo`<000Eo
o`<000Uoo`<0009oo`@000Moo`80009oo`80009oo`@0009oo`<000=oo`<0009oo`@000=oo`D00003
Ool000000080009oo`D000Ioo`<000Aoo`<0009oo`D00004Ool00000Ool20002Ool5001]Ool000mo
o`03001oogoo02=oo`03001oogoo00=oo`03001oogoo00Eoo`03001oogoo00Moo`05001oogooOol0
0002Ool00`00Oomoo`08Ool01000Ool000000Woo00<007ooOol00goo00L007ooOomoo`00Ool00003
Ool01000Oomoo`0017oo00L007ooOomoo`00Ool00005Ool01@00Oomoogoo00001goo00@007ooOol0
009oo`07001oogooOol007oo00000Woo00@007ooOol0009oo`04001oogoo0003Ool00`00Oomoo`1/
Ool000=oo`D00007Ool007oo001oo`00Ool010000Woo1@0000=oo`0000000`000Woo0`000Woo1@00
0Woo1@0000=oo`0000000P000goo00<007ooOol01Goo00<007ooOol01goo00D007ooOomoo`00009o
o`03001oogoo00Qoo`<000=oo`D00003Ool007oo00Aoo`05001oogooOol00002Ool00`00Oomoo`02
Ool01P00Oomoogoo001oo`D00003Ool007oo009oo`03001oogoo00Moo`80009oo`07001oogooOol0
07oo00000Woo00@007ooOol0009oo`04001oogoo0003Ool00`00Oomoo`1/Ool000=oo`04001oogoo
0002Ool01`00Ool007oo001oo`0000=oo`05001oogooOol00005Ool00`00Oomoo`02Ool01P00Oomo
o`00Ool0009oo`04001oogoo0003Ool01000Ool007oo0`000goo0`000goo00D007oo001oo`0000Mo
o`05001oogooOol00002Ool00`00Oomoo`08Ool01000Oomoo`000Woo00L007ooOomoo`00Ool00003
Ool00`00Ool00003Ool00`00Oomoo`020003Ool01`00Oomoogoo001oo`0000=oo`03001oo`0000=o
o`03001oogoo00Eoo`8000Aoo`07001oogooOol007oo00000Woo00@007ooOol0009oo`04001oogoo
0003Ool00`00Oomoo`1/Ool000=oo`@0009oo`07001oo`00Ool007oo00000goo00D007ooOomoo`00
00Eoo`03001oogoo009oo`03001oogoo009oo`04001oogoo0002Ool01P00Oomoogoo001oo`D000=o
o`03001oogoo00=oo`05001oo`00Ool00008Ool30002Ool40008Ool01000Oomoo`000goo0`000goo
10000Woo0`000Woo0P0000=oo`0000000Woo10000Woo0`000goo10001goo00@007ooOol000=oo`<0
0004Ool00000Ool200000goo000000030003Ool4001^Ool000Ioo`0:001oogoo001oo`00Ool007oo
0003Ool01@00Oomoogoo00001Goo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`06
001oogooOol007oo1P0000=oo`0000000`000Woo1@003Woo00<007ooOol01goo10007goo00<007oo
Ool02Goo00<007ooOol01Woo0`0067oo00<007ooOol0K7oo0004Ool300000goo000000090004Ool0
0`00Oomoo`02Ool20003Ool4000017oo000007oo0P000goo10000Woo0`007Goo0`00:Goo0P002Woo
0P008Woo0P00KWoo000GOol00`00Oomoo`08Ool00`00Oomoo`0<Ool00`00Oomoo`3/Ool001Eoo`<0
00Eoo`03001oogoo009oo`03001oogoo00]oo`800>ioo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {946.587, -0.14072, 0.462505, 
  0.00748348}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-9.5 0.01 0 0.618034 [
[.3 -0.0125 -9 -9 ]
[.3 -0.0125 9 0 ]
[.5 -0.0125 -12 -9 ]
[.5 -0.0125 12 0 ]
[.7 -0.0125 -12 -9 ]
[.7 -0.0125 12 0 ]
[.9 -0.0125 -12 -9 ]
[.9 -0.0125 12 0 ]
[1.025 0 0 -6 ]
[1.025 0 58 6 ]
[.0875 .12361 -18 -4.5 ]
[.0875 .12361 0 4.5 ]
[.0875 .24721 -18 -4.5 ]
[.0875 .24721 0 4.5 ]
[.0875 .37082 -18 -4.5 ]
[.0875 .37082 0 4.5 ]
[.0875 .49443 -18 -4.5 ]
[.0875 .49443 0 4.5 ]
[.0875 .61803 -6 -4.5 ]
[.0875 .61803 0 4.5 ]
[.1 .64303 -29 0 ]
[.1 .64303 29 12 ]
[.5 .63053 -65 0 ]
[.5 .63053 65 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.3 0 m
.3 .00625 L
s
[(980)] .3 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1000)] .5 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(1020)] .7 -0.0125 0 1 Mshowa
.9 0 m
.9 .00625 L
s
[(1040)] .9 -0.0125 0 1 Mshowa
.125 Mabswid
.15 0 m
.15 .00375 L
s
.2 0 m
.2 .00375 L
s
.25 0 m
.25 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.45 0 m
.45 .00375 L
s
.55 0 m
.55 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.75 0 m
.75 .00375 L
s
.8 0 m
.8 .00375 L
s
.85 0 m
.85 .00375 L
s
.05 0 m
.05 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(frequency) show
117.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.1 .12361 m
.10625 .12361 L
s
[(0.2)] .0875 .12361 1 0 Mshowa
.1 .24721 m
.10625 .24721 L
s
[(0.4)] .0875 .24721 1 0 Mshowa
.1 .37082 m
.10625 .37082 L
s
[(0.6)] .0875 .37082 1 0 Mshowa
.1 .49443 m
.10625 .49443 L
s
[(0.8)] .0875 .49443 1 0 Mshowa
.1 .61803 m
.10625 .61803 L
s
[(1)] .0875 .61803 1 0 Mshowa
.125 Mabswid
.1 .0309 m
.10375 .0309 L
s
.1 .0618 m
.10375 .0618 L
s
.1 .09271 m
.10375 .09271 L
s
.1 .15451 m
.10375 .15451 L
s
.1 .18541 m
.10375 .18541 L
s
.1 .21631 m
.10375 .21631 L
s
.1 .27812 m
.10375 .27812 L
s
.1 .30902 m
.10375 .30902 L
s
.1 .33992 m
.10375 .33992 L
s
.1 .40172 m
.10375 .40172 L
s
.1 .43262 m
.10375 .43262 L
s
.1 .46353 m
.10375 .46353 L
s
.1 .52533 m
.10375 .52533 L
s
.1 .55623 m
.10375 .55623 L
s
.1 .58713 m
.10375 .58713 L
s
.25 Mabswid
.1 0 m
.1 .61803 L
s
gsave
.1 .64303 -90 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(amplitude) show
117.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.5 .63053 -126 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(FFT) show
87.000000 13.000000 moveto
(of) show
105.000000 13.000000 moveto
(Recorded) show
159.000000 13.000000 moveto
(Sound) show
189.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .00463 m
.01 .00775 L
.02 .00346 L
.03 .00556 L
.04 .00605 L
.05 .00627 L
.06 .00779 L
.07 .00642 L
.08 .00462 L
.09 .00474 L
.1 .00696 L
.11 .00691 L
.12 .00838 L
.13 .0077 L
.14 .00629 L
.15 .00507 L
.16 .00762 L
.17 .00821 L
.18 .00732 L
.19 .00977 L
.2 .00867 L
.21 .01041 L
.22 .00924 L
.23 .01171 L
.24 .01216 L
.25 .00811 L
.26 .01009 L
.27 .01171 L
.28 .00942 L
.29 .01135 L
.3 .01394 L
.31 .01206 L
.32 .01283 L
.33 .01412 L
.34 .01412 L
.35 .01537 L
.36 .01805 L
.37 .01872 L
.38 .0173 L
.39 .01953 L
.4 .02151 L
.41 .02252 L
.42 .02526 L
.43 .0278 L
.44 .0304 L
.45 .03304 L
.46 .03839 L
.47 .04387 L
.48 .05232 L
.49 .06461 L
Mistroke
.5 .08288 L
.51 .11352 L
.52 .19504 L
.53 .44234 L
.54 .61803 L
.55 .21085 L
.56 .11682 L
.57 .08109 L
.58 .06655 L
.59 .05326 L
.6 .04496 L
.61 .03837 L
.62 .03375 L
.63 .02909 L
.64 .02731 L
.65 .02708 L
.66 .0225 L
.67 .02039 L
.68 .02062 L
.69 .01786 L
.7 .01786 L
.71 .01604 L
.72 .01566 L
.73 .01546 L
.74 .0165 L
.75 .01396 L
.76 .01314 L
.77 .01202 L
.78 .01045 L
.79 .01128 L
.8 .01329 L
.81 .01056 L
.82 .00869 L
.83 .01011 L
.84 .00956 L
.85 .01211 L
.86 .00997 L
.87 .01006 L
.88 .00985 L
.89 .00922 L
.9 .0089 L
.91 .01046 L
.92 .00688 L
.93 .00672 L
.94 .01021 L
.95 .00736 L
.96 .00959 L
.97 .0079 L
.98 .00631 L
.99 .00556 L
Mistroke
1 .00674 L
Mfstroke
1 .00674 m
1 .00674 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
@7oo0`0017oo0P0017oo0P006Goo0`0017oo0P0017oo0P0017oo0P005Woo0`0017oo0P000goo1000
0goo0P005Woo0`0017oo0P0017oo0`000goo0P00CGoo0013Ool01000Oomoo`000Woo00@007ooOol0
009oo`03001oogoo01Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000Woo00@007oo
Ool001Ioo`03001oogoo009oo`04001oogoo0003Ool00`00Oomoo`02Ool01000Oomoo`005Woo00<0
07ooOol00Woo00@007ooOol000Aoo`05001oogooOol00002Ool00`00Oomoo`1:Ool0045oo`<0009o
o`04001oogoo0002Ool01000Oomoo`006Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo
0002Ool01000Oomoo`005Woo00<007ooOol00Woo00@007ooOol000Aoo`05001oogooOol00002Ool0
0`00Oomoo`0DOol00`00Oomoo`02Ool01000Oomoo`000Woo10000Woo00@007ooOol004aoo`00@7oo
00@007ooOol000=oo`8000=oo`04001oogoo000IOol00`00Oomoo`02Ool01000Oomoo`000Woo00@0
07ooOol0009oo`04001oogoo000FOol00`00Oomoo`02Ool01000Oomoo`001Goo00@007ooOol0009o
o`03001oogoo01Aoo`03001oogoo009oo`04001oogoo0002Ool00`00Ool00003Ool01000Oomoo`00
C7oo0010Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo000IOol00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol0009oo`04001oogoo000FOol00`00Oomoo`02Ool01000Oomoo`00
0Woo00@007ooOol0009oo`04001oogoo000FOol00`00Oomoo`02Ool01000Oomoo`000Woo00<007oo
00000goo00@007ooOol004aoo`00@Goo0P0017oo0P0017oo0P006Goo0P001Goo0P0017oo0P0017oo
0P005Woo0P001Goo0P0017oo0P0017oo0P005Woo0P001Goo0P0017oo0P0017oo0P00:Goo10005goo
0`001Woo003nOol00`00Oomoo`0GOol00`00Oomoo`05Ool00>Qoo`@0009oo`@000=oo`@0009oo`@0
0003Ool0000000<0009oo`@00004Ool00000Ool20002Ool30003Ool00`00Oomoo`04Ool00>Uoo`03
001oogoo00=oo`03001oogoo009oo`03001oogoo00=oo`07001oogooOol007oo00000Woo00@007oo
Ool000Eoo`04001oogoo0002Ool01@00Oomoogoo00000Woo00<007ooOol017oo0007OooI0009Ool0
0`00Oomoo`03Ool00`00Oomoo`02Ool500000goo001oo`02Ool00`00Ool00002Ool00`00Oomoo`05
00001Goo001oogoo00000Woo00<007ooOol00goo00<007oo00001Goo0007Ool2000017oo00000000
1Goo00<007ooOol00Woo1`0027oo0`002Goo00<007ooOol027oo00<007ooOol027oo00<007ooOol0
27oo00<007ooOol01goo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol0
27oo00<007ooOol01goo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol0
27oo00<007ooOol01goo00<007ooOol027oo00<007ooOol04Woo00<007ooOol00goo0P000goo00L0
07ooOomoo`00Ool00003Ool00`00Ool00002Ool01000Oomoo`000goo00<007oo00000Woo00@007oo
Ool000=oo`05001oo`00Ool00005Ool000Uoo`04001oogooOol:0006Ool90003Ool;00000goo0000
00020003Ool30003Ool40002Ool00`00Oomoo`0XOol00`00Oomoo`0XOol00`00Oomoo`0FOol30002
Ool30005Ool800000goo0000000300000goo0000000;0008Ool40002Ool200000goo00000002Ool3
0003Ool600000goo00000003Ool300000goo000000030003Ool600000goo00000004Ool001eoo`03
001oogoo01Aoo`03001oogoo009oo`<000=oo`<000Aoo`d005Eoo`l000=oo`8000=oo`D000Qoo`03
001oogoo00=oo`03001oogoo01Aoo`03001oogoo03Aoo`007Goo00<007ooOol0<goo2000@7oo3@00
@Goo0`00=7oo000MOol00`00Oomoo`0kOol7000cOol60025Ool001eoo`03001oogoo049oo`@002Yo
o`D008]oo`007Goo00<007ooOol0AWoo0P009Woo0P00T7oo000MOol00`00Oomoo`18Ool2000ROol2
002BOol001eoo`03001oogoo04Yoo`<001eoo`8009Aoo`007Goo00<007ooOol0CGoo00<007ooOol0
67oo0P00UWoo000MOol00`00Oomoo`1>Ool00`00Oomoo`0FOol00`00Oomoo`2FOol001eoo`03001o
ogoo04moo`03001oogoo01Aoo`03001oogoo09Moo`007Goo00<007ooOol0D7oo00<007ooOol04goo
00<007ooOol0Ugoo000MOol00`00Oomoo`1AOol00`00Oomoo`0AOol00`00Oomoo`2HOol001eoo`03
001oogoo055oo`03001oogoo011oo`03001oogoo09Uoo`007Goo00<007ooOol0DWoo00<007ooOol0
3goo00<007ooOol0VGoo000MOol00`00Oomoo`1BOol00`00Oomoo`0>Ool00`00Oomoo`2JOol001eo
o`03001oogoo05=oo`03001oogoo00aoo`03001oogoo09]oo`007Goo00<007ooOol0Dgoo00<007oo
Ool037oo00<007ooOol0Vgoo000MOol00`00Oomoo`1COol00`00Oomoo`0<Ool00`00Oomoo`2KOol0
01eoo`03001oogoo05Aoo`03001oogoo00Yoo`03001oogoo09aoo`007Goo00<007ooOol0E7oo00<0
07ooOol02Woo00<007ooOol0W7oo000MOol00`00Oomoo`1DOol00`00Oomoo`0:Ool00`00Oomoo`2L
Ool001eoo`03001oogoo05Eoo`03001oogoo00Uoo`03001oogoo09aoo`002Woo0P0017oo0P000goo
100017oo00<007ooOol0EGoo00<007ooOol027oo00<007ooOol0WGoo0009Ool01000Oomoo`000goo
0P0017oo00<007ooOol017oo00<007ooOol0EGoo00<007ooOol027oo00<007ooOol0WGoo0009Ool0
1000Oomoo`002Woo00<007ooOol00goo0P00EWoo00<007ooOol027oo00<007ooOol0WGoo0009Ool0
1000Oomoo`002goo00<007ooOol00Woo00<007ooOol0EGoo00<007ooOol027oo00<007ooOol0WGoo
0009Ool01000Oomoo`0027oo00@007ooOol000Aoo`03001oogoo05Eoo`03001oogoo00Qoo`03001o
ogoo09eoo`002Woo0P002Woo0P001Goo00<007ooOol0EWoo00<007ooOol01goo00<007ooOol0WGoo
000MOol00`00Oomoo`1FOol00`00Oomoo`07Ool00`00Oomoo`2MOol001eoo`03001oogoo05Ioo`03
001oogoo00Ioo`03001oogoo09ioo`007Goo00<007ooOol0EWoo00<007ooOol01Woo00<007ooOol0
WWoo000MOol00`00Oomoo`1FOol00`00Oomoo`06Ool00`00Oomoo`2NOol001eoo`03001oogoo05Io
o`03001oogoo00Ioo`03001oogoo09ioo`007Goo00<007ooOol0EWoo00<007ooOol01Woo00<007oo
Ool0WWoo000MOol00`00Oomoo`1FOol00`00Oomoo`06Ool00`00Oomoo`2NOol001eoo`03001oogoo
05Ioo`03001oogoo00Ioo`03001oogoo09ioo`007Goo00<007ooOol0Egoo00<007ooOol01Goo00<0
07ooOol0WWoo000MOol00`00Oomoo`1GOol00`00Oomoo`05Ool00`00Oomoo`2NOol001eoo`03001o
ogoo05Moo`03001oogoo00Eoo`03001oogoo09ioo`007Goo00<007ooOol0Egoo00<007ooOol017oo
00<007ooOol0Wgoo000MOol00`00Oomoo`1GOol00`00Oomoo`04Ool00`00Oomoo`2OOol001eoo`03
001oogoo05Moo`03001oogoo00Aoo`03001oogoo09moo`007Goo00<007ooOol0Egoo00<007ooOol0
17oo00<007ooOol0Wgoo000MOol00`00Oomoo`1GOol00`00Oomoo`04Ool00`00Oomoo`2OOol001eo
o`03001oogoo05Moo`03001oogoo00Aoo`03001oogoo09moo`007Goo00<007ooOol0Egoo00<007oo
Ool017oo00<007ooOol0Wgoo000MOol00`00Oomoo`1GOol00`00Oomoo`04Ool00`00Oomoo`2OOol0
01eoo`03001oogoo05Moo`03001oogoo00Aoo`03001oogoo09moo`007Goo00<007ooOol0Egoo00<0
07ooOol017oo00<007ooOol0Wgoo000:Ool20004Ool20004Ool30004Ool00`00Oomoo`1GOol00`00
Oomoo`04Ool00`00Oomoo`2OOol000Uoo`04001oogoo0003Ool20005Ool00`00Oomoo`03Ool00`00
Oomoo`1GOol00`00Oomoo`04Ool00`00Oomoo`2OOol000Uoo`04001oogoo0008Ool40004Ool2001H
Ool00`00Oomoo`04Ool00`00Oomoo`2OOol000Uoo`04001oogoo0008Ool00`00Ool00005Ool00`00
Oomoo`1GOol00`00Oomoo`04Ool00`00Oomoo`2OOol000Uoo`04001oogoo0008Ool00`00Ool00005
Ool00`00Oomoo`1GOol00`00Oomoo`04Ool00`00Oomoo`2OOol000Yoo`8000Yoo`8000Eoo`03001o
ogoo05Qoo`03001oogoo00=oo`03001oogoo09moo`007Goo00<007ooOol0F7oo00<007ooOol00goo
00<007ooOol0Wgoo000MOol00`00Oomoo`1HOol00`00Oomoo`03Ool00`00Oomoo`2OOol001eoo`03
001oogoo05Qoo`03001oogoo00=oo`03001oogoo09moo`007Goo00<007ooOol0F7oo00<007ooOol0
0goo00<007ooOol0Wgoo000MOol00`00Oomoo`1HOol00`00Oomoo`03Ool00`00Oomoo`2OOol001eo
o`03001oogoo05Qoo`03001oogoo00=oo`03001oogoo09moo`007Goo00<007ooOol0F7oo00<007oo
Ool00goo00<007ooOol0Wgoo000MOol00`00Oomoo`1HOol00`00Oomoo`03Ool00`00Oomoo`2OOol0
01eoo`03001oogoo05Qoo`03001oogoo00=oo`03001oogoo09moo`007Goo00<007ooOol0F7oo00<0
07ooOol00goo00<007ooOol0Wgoo000MOol00`00Oomoo`1HOol00`00Oomoo`03Ool00`00Oomoo`2O
Ool001eoo`03001oogoo05Qoo`03001oogoo009oo`03001oogoo0:1oo`007Goo00<007ooOol0F7oo
00<007ooOol00Woo00<007ooOol0X7oo000MOol00`00Oomoo`1HOol00`00Oomoo`02Ool00`00Oomo
o`2POol001eoo`03001oogoo05Qoo`03001oogoo009oo`03001oogoo0:1oo`007Goo00<007ooOol0
F7oo00<007ooOol00Woo00<007ooOol0X7oo000MOol00`00Oomoo`1HOol00`00Oomoo`02Ool00`00
Oomoo`2POol001eoo`03001oogoo05Qoo`03001oogoo009oo`03001oogoo0:1oo`007Goo00<007oo
Ool0F7oo00<007ooOol00Woo00<007ooOol0X7oo000MOol00`00Oomoo`1HOol00`00Oomoo`02Ool0
0`00Oomoo`2POol001eoo`03001oogoo05Qoo`03001oogoo009oo`03001oogoo0:1oo`002Woo0P00
17oo0P0017oo0P001Goo00<007ooOol0F7oo00<007ooOol00Woo00<007ooOol0X7oo0009Ool01000
Oomoo`000goo0P000goo00@007ooOol000Aoo`03001oogoo05Qoo`03001oogoo009oo`03001oogoo
0:1oo`002Goo00@007ooOol000Qoo`04001oogoo0004Ool2001IOol00`00Oomoo`02Ool00`00Oomo
o`2POol000Uoo`04001oogoo0008Ool30005Ool00`00Oomoo`1HOol00`00Oomoo`02Ool00`00Oomo
o`2POol000Uoo`04001oogoo0008Ool00`00Oomoo`05Ool00`00Oomoo`1HOol00`00Oomoo`02Ool0
0`00Oomoo`2POol000Yoo`8000Yoo`<000Aoo`03001oogoo05Uoo`05001oogooOol0002ROol001eo
o`03001oogoo05Uoo`05001oogooOol0002ROol001eoo`03001oogoo05Uoo`05001oogooOol0002R
Ool001eoo`03001oogoo05Uoo`05001oogooOol0002ROol001eoo`03001oogoo05Uoo`05001oogoo
Ool0002ROol001eoo`03001oogoo05Uoo`05001oogooOol0002ROol001eoo`03001oogoo05Uoo`05
001oogooOol0002ROol001eoo`03001oogoo05Uoo`05001oogooOol0002ROol001eoo`03001oogoo
05Uoo`05001oogooOol0002ROol001eoo`03001oogoo05Uoo`05001oogooOol0002ROol001eoo`03
001oogoo05Uoo`05001oogooOol0002ROol001eoo`03001oogoo05Uoo`05001oogooOol0002ROol0
01eoo`03001oogoo05Uoo`05001oogooOol0002ROol001eoo`03001oogoo05Uoo`05001oogooOol0
002ROol001eoo`03001oogoo05Uoo`05001oogooOol0002ROol001eoo`03001oogoo05Uoo`05001o
ogooOol0002ROol001eoo`03001oogoo05Uoo`05001oogooOol0002ROol001eoo`03001oogoo05Uo
o`05001oogooOol0002ROol001eoo`03001oogoo05Uoo`05001oogooOol0002ROol001eoo`03001o
ogoo05Yoo`04001oogoo002ROol001eoo`03001oogoo05Yoo`04001oogoo002ROol000Yoo`8000Ao
o`8000Aoo`8000Eoo`03001oogoo05Yoo`04001oogoo002ROol000Uoo`04001oogoo0003Ool20003
Ool01000Oomoo`0017oo00<007ooOol0FWoo00@007ooOol00:9oo`002Goo00@007ooOol000Qoo`04
001oogoo0004Ool2001KOol01000Oomoo`00XWoo0009Ool01000Oomoo`002Goo0P001Goo00<007oo
Ool0FWoo00@007ooOol00:9oo`002Goo00@007ooOol000Qoo`04001oogoo0004Ool00`00Oomoo`1J
Ool01000Oomoo`00XWoo000:Ool2000:Ool20005Ool00`00Oomoo`1JOol01000Oomoo`00XWoo000M
Ool00`00Oomoo`1JOol01000Oomoo`00XWoo000MOol00`00Oomoo`1JOol01000Oomoo`00XWoo000M
Ool00`00Oomoo`1JOol00`00Ool0002SOol001eoo`03001oogoo05Yoo`03001oo`000:=oo`007Goo
00<007ooOol0FWoo00<007oo0000Xgoo000MOol00`00Oomoo`1KOol2002SOol001eoo`03001oogoo
05]oo`800:=oo`007Goo00<007ooOol0Fgoo0P00Xgoo000MOol00`00Oomoo`1KOol2002SOol001eo
o`03001oogoo05]oo`800:=oo`007Goo00<007ooOol0Fgoo0P00Xgoo000MOol00`00Oomoo`1KOol2
002SOol001eoo`03001oogoo05]oo`800:=oo`007Goo00<007ooOol0Fgoo0P00Xgoo000MOol00`00
Oomoo`1KOol2002SOol001eoo`03001oogoo05]oo`800:=oo`007Goo00<007ooOol0Fgoo0P00Xgoo
000MOol00`00Oomoo`1KOol2002SOol001eoo`03001oogoo05aoo`03001oogoo0:5oo`007Goo00<0
07ooOol0G7oo00<007ooOol0XGoo000MOol00`00Oomoo`1LOol00`00Oomoo`2QOol001Eoo`<000Eo
o`03001oogoo05aoo`03001oogoo0:5oo`005Woo00<007ooOol017oo00<007ooOol0G7oo00<007oo
Ool0XGoo000FOol00`00Oomoo`04Ool2001MOol00`00Oomoo`2QOol001Ioo`03001oogoo0?moo`Qo
o`005Woo00<007ooOol0ogoo27oo000EOol2003oOol:Ool00?moob5oo`00ogoo8Goo003oOolQOol0
00ioo`@0029oo`<000=oo`<000Eoo`<000Uoo`<0009oo`@000Moo`80009oo`80009oo`@0009oo`<0
00=oo`<0009oo`@000=oo`D00003Ool000000080009oo`D000Ioo`<000Aoo`<0009oo`D00004Ool0
0000Ool20002Ool5001]Ool000moo`03001oogoo02=oo`03001oogoo00=oo`03001oogoo00Eoo`03
001oogoo00Moo`05001oogooOol00002Ool00`00Oomoo`08Ool01000Ool000000Woo00<007ooOol0
0goo00L007ooOomoo`00Ool00003Ool01000Oomoo`0017oo00L007ooOomoo`00Ool00005Ool01@00
Oomoogoo00001goo00@007ooOol0009oo`07001oogooOol007oo00000Woo00@007ooOol0009oo`04
001oogoo0003Ool00`00Oomoo`1/Ool000=oo`D00007Ool007oo001oo`00Ool010000Woo1@0000=o
o`0000000`000Woo0`000Woo1@000Woo1@0000=oo`0000000P000goo00<007ooOol01Goo00<007oo
Ool01goo00D007ooOomoo`00009oo`03001oogoo00Qoo`<000=oo`D00003Ool007oo00Aoo`05001o
ogooOol00002Ool00`00Oomoo`02Ool01P00Oomoogoo001oo`D00003Ool007oo009oo`03001oogoo
00Moo`80009oo`07001oogooOol007oo00000Woo00@007ooOol0009oo`04001oogoo0003Ool00`00
Oomoo`1/Ool000=oo`04001oogoo0002Ool01`00Ool007oo001oo`0000=oo`05001oogooOol00005
Ool00`00Oomoo`02Ool01P00Oomoo`00Ool0009oo`04001oogoo0003Ool01000Ool007oo0`000goo
0`000goo00D007oo001oo`0000Moo`05001oogooOol00002Ool00`00Oomoo`08Ool01000Oomoo`00
0Woo00L007ooOomoo`00Ool00003Ool00`00Ool00003Ool00`00Oomoo`020003Ool01`00Oomoogoo
001oo`0000=oo`03001oo`0000=oo`03001oogoo00Eoo`8000Aoo`07001oogooOol007oo00000Woo
00@007ooOol0009oo`04001oogoo0003Ool00`00Oomoo`1/Ool000=oo`@0009oo`07001oo`00Ool0
07oo00000goo00D007ooOomoo`0000Eoo`03001oogoo009oo`03001oogoo009oo`04001oogoo0002
Ool01P00Oomoogoo001oo`D000=oo`03001oogoo00=oo`05001oo`00Ool00008Ool30002Ool40008
Ool01000Oomoo`000goo0`000goo10000Woo0`000Woo0P0000=oo`0000000Woo10000Woo0`000goo
10001goo00@007ooOol000=oo`<00004Ool00000Ool200000goo000000030003Ool4001^Ool000Io
o`0:001oogoo001oo`00Ool007oo0003Ool01@00Oomoogoo00001Goo00<007ooOol00Woo00<007oo
Ool00Woo00@007ooOol0009oo`06001oogooOol007oo1P0000=oo`0000000`000Woo1@003Woo00<0
07ooOol01goo10007goo00<007ooOol02Goo00<007ooOol01Woo0`0067oo00<007ooOol0K7oo0004
Ool300000goo000000090004Ool00`00Oomoo`02Ool20003Ool4000017oo000007oo0P000goo1000
0Woo0`007Goo0`00:Goo0P002Woo0P008Woo0P00KWoo000GOol00`00Oomoo`08Ool00`00Oomoo`0<
Ool00`00Oomoo`3/Ool001Eoo`<000Eoo`03001oogoo009oo`03001oogoo00]oo`800>ioo`00ogoo
8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol0
0?moob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {946.587, -0.14072, 0.462505, 
  0.00748348}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-9.5 0.01 0 0.618034 [
[.3 -0.0125 -9 -9 ]
[.3 -0.0125 9 0 ]
[.5 -0.0125 -12 -9 ]
[.5 -0.0125 12 0 ]
[.7 -0.0125 -12 -9 ]
[.7 -0.0125 12 0 ]
[.9 -0.0125 -12 -9 ]
[.9 -0.0125 12 0 ]
[1.025 0 0 -6 ]
[1.025 0 58 6 ]
[.0875 .12361 -18 -4.5 ]
[.0875 .12361 0 4.5 ]
[.0875 .24721 -18 -4.5 ]
[.0875 .24721 0 4.5 ]
[.0875 .37082 -18 -4.5 ]
[.0875 .37082 0 4.5 ]
[.0875 .49443 -18 -4.5 ]
[.0875 .49443 0 4.5 ]
[.0875 .61803 -6 -4.5 ]
[.0875 .61803 0 4.5 ]
[.1 .64303 -29 0 ]
[.1 .64303 29 12 ]
[.5 .63053 -65 0 ]
[.5 .63053 65 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.3 0 m
.3 .00625 L
s
[(980)] .3 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1000)] .5 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(1020)] .7 -0.0125 0 1 Mshowa
.9 0 m
.9 .00625 L
s
[(1040)] .9 -0.0125 0 1 Mshowa
.125 Mabswid
.15 0 m
.15 .00375 L
s
.2 0 m
.2 .00375 L
s
.25 0 m
.25 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.45 0 m
.45 .00375 L
s
.55 0 m
.55 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.75 0 m
.75 .00375 L
s
.8 0 m
.8 .00375 L
s
.85 0 m
.85 .00375 L
s
.05 0 m
.05 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(frequency) show
117.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.1 .12361 m
.10625 .12361 L
s
[(0.2)] .0875 .12361 1 0 Mshowa
.1 .24721 m
.10625 .24721 L
s
[(0.4)] .0875 .24721 1 0 Mshowa
.1 .37082 m
.10625 .37082 L
s
[(0.6)] .0875 .37082 1 0 Mshowa
.1 .49443 m
.10625 .49443 L
s
[(0.8)] .0875 .49443 1 0 Mshowa
.1 .61803 m
.10625 .61803 L
s
[(1)] .0875 .61803 1 0 Mshowa
.125 Mabswid
.1 .0309 m
.10375 .0309 L
s
.1 .0618 m
.10375 .0618 L
s
.1 .09271 m
.10375 .09271 L
s
.1 .15451 m
.10375 .15451 L
s
.1 .18541 m
.10375 .18541 L
s
.1 .21631 m
.10375 .21631 L
s
.1 .27812 m
.10375 .27812 L
s
.1 .30902 m
.10375 .30902 L
s
.1 .33992 m
.10375 .33992 L
s
.1 .40172 m
.10375 .40172 L
s
.1 .43262 m
.10375 .43262 L
s
.1 .46353 m
.10375 .46353 L
s
.1 .52533 m
.10375 .52533 L
s
.1 .55623 m
.10375 .55623 L
s
.1 .58713 m
.10375 .58713 L
s
.25 Mabswid
.1 0 m
.1 .61803 L
s
gsave
.1 .64303 -90 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(amplitude) show
117.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.5 .63053 -126 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(FFT) show
87.000000 13.000000 moveto
(of) show
105.000000 13.000000 moveto
(Recorded) show
159.000000 13.000000 moveto
(Sound) show
189.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .00524 m
.01 .00735 L
.02 .00411 L
.03 .00659 L
.04 .00409 L
.05 .00578 L
.06 .00617 L
.07 .00803 L
.08 .00788 L
.09 .00582 L
.1 .00507 L
.11 .00645 L
.12 .00776 L
.13 .00709 L
.14 .00933 L
.15 .00583 L
.16 .00754 L
.17 .00577 L
.18 .00755 L
.19 .00695 L
.2 .0091 L
.21 .01159 L
.22 .00873 L
.23 .00878 L
.24 .01081 L
.25 .01021 L
.26 .00915 L
.27 .01064 L
.28 .00976 L
.29 .0101 L
.3 .01137 L
.31 .01366 L
.32 .01443 L
.33 .01378 L
.34 .01274 L
.35 .01671 L
.36 .01511 L
.37 .01791 L
.38 .01675 L
.39 .01871 L
.4 .02008 L
.41 .02372 L
.42 .02738 L
.43 .0265 L
.44 .0295 L
.45 .03496 L
.46 .03784 L
.47 .04265 L
.48 .05387 L
.49 .06459 L
Mistroke
.5 .08268 L
.51 .11583 L
.52 .18708 L
.53 .61803 L
.54 .59171 L
.55 .17776 L
.56 .11678 L
.57 .08234 L
.58 .06401 L
.59 .05171 L
.6 .04418 L
.61 .03946 L
.62 .03279 L
.63 .03105 L
.64 .028 L
.65 .02422 L
.66 .02288 L
.67 .02036 L
.68 .02105 L
.69 .01906 L
.7 .01634 L
.71 .01533 L
.72 .0161 L
.73 .01373 L
.74 .01555 L
.75 .01338 L
.76 .01336 L
.77 .01314 L
.78 .01156 L
.79 .00874 L
.8 .01211 L
.81 .01006 L
.82 .01065 L
.83 .00864 L
.84 .0067 L
.85 .00968 L
.86 .009 L
.87 .00838 L
.88 .00722 L
.89 .00913 L
.9 .00875 L
.91 .00854 L
.92 .00698 L
.93 .00754 L
.94 .0106 L
.95 .00661 L
.96 .00917 L
.97 .00789 L
.98 .00845 L
.99 .00563 L
Mistroke
1 .00599 L
Mfstroke
1 .00599 m
1 .00599 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
@7oo0`0017oo0P0017oo0P006Goo0`0017oo0P0017oo0P0017oo0P005Woo0`0017oo0P000goo1000
0goo0P005Woo0`0017oo0P0017oo0`000goo0P00CGoo0013Ool01000Oomoo`000Woo00@007ooOol0
009oo`03001oogoo01Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000Woo00@007oo
Ool001Ioo`03001oogoo009oo`04001oogoo0003Ool00`00Oomoo`02Ool01000Oomoo`005Woo00<0
07ooOol00Woo00@007ooOol000Aoo`05001oogooOol00002Ool00`00Oomoo`1:Ool0045oo`<0009o
o`04001oogoo0002Ool01000Oomoo`006Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo
0002Ool01000Oomoo`005Woo00<007ooOol00Woo00@007ooOol000Aoo`05001oogooOol00002Ool0
0`00Oomoo`0DOol00`00Oomoo`02Ool01000Oomoo`000Woo10000Woo00@007ooOol004aoo`00@7oo
00@007ooOol000=oo`8000=oo`04001oogoo000IOol00`00Oomoo`02Ool01000Oomoo`000Woo00@0
07ooOol0009oo`04001oogoo000FOol00`00Oomoo`02Ool01000Oomoo`001Goo00@007ooOol0009o
o`03001oogoo01Aoo`03001oogoo009oo`04001oogoo0002Ool00`00Ool00003Ool01000Oomoo`00
C7oo0010Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo000IOol00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol0009oo`04001oogoo000FOol00`00Oomoo`02Ool01000Oomoo`00
0Woo00@007ooOol0009oo`04001oogoo000FOol00`00Oomoo`02Ool01000Oomoo`000Woo00<007oo
00000goo00@007ooOol004aoo`00@Goo0P0017oo0P0017oo0P006Goo0P001Goo0P0017oo0P0017oo
0P005Woo0P001Goo0P0017oo0P0017oo0P005Woo0P001Goo0P0017oo0P0017oo0P00:Goo10005goo
0`001Woo003nOol00`00Oomoo`0GOol00`00Oomoo`05Ool00>Qoo`@0009oo`@000=oo`@0009oo`@0
0003Ool0000000<0009oo`@00004Ool00000Ool20002Ool30003Ool00`00Oomoo`04Ool00>Uoo`03
001oogoo00=oo`03001oogoo009oo`03001oogoo00=oo`07001oogooOol007oo00000Woo00@007oo
Ool000Eoo`04001oogoo0002Ool01@00Oomoogoo00000Woo00<007ooOol017oo0007OooI0009Ool0
0`00Oomoo`03Ool00`00Oomoo`02Ool500000goo001oo`02Ool00`00Ool00002Ool00`00Oomoo`05
00001Goo001oogoo00000Woo00<007ooOol00goo00<007oo00001Goo0007Ool2000017oo00000000
0Woo10002Goo0`0027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol0
27oo00<007ooOol01goo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol0
27oo00<007ooOol01goo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol0
27oo00<007ooOol01goo00<007ooOol027oo00<007ooOol027oo00<007ooOol01goo00<007ooOol0
0goo0P000goo00L007ooOomoo`00Ool00003Ool00`00Ool00002Ool01000Oomoo`000goo00<007oo
00000Woo00@007ooOol000=oo`05001oo`00Ool00005Ool000Uoo`04001oogooOol20003Ool:0000
0goo001oo`0E00000goo000000040003Ool300000goo000000020002Ool00`00Oomoo`0XOol00`00
Oomoo`0XOol00`00Oomoo`0@Ool30005OolI00000goo0000000;0008Ool40002Ool200000goo0000
0002Ool30003Ool600000goo00000003Ool300000goo000000030003Ool600000goo00000004Ool0
01eoo`03001oogoo01Aoo`03001oogoo00Aoo`<000=oo`03001oogoo009oo`d0055oo`<00003Ool0
000000L000=oo`D001Uoo`03001oogoo01Aoo`03001oogoo03Aoo`007Goo00<007ooOol0<goo2P00
?Woo2@000goo00<007ooOol0?goo0`00=7oo000MOol00`00Oomoo`0mOol5000cOol60025Ool001eo
o`03001oogoo049oo`@002Yoo`D008]oo`007Goo00<007ooOol0AWoo0P009Goo0`00T7oo000MOol0
0`00Oomoo`18Ool2000ROol00`00Oomoo`2AOol001eoo`03001oogoo04Yoo`<001eoo`8009Aoo`00
7Goo00<007ooOol0CGoo00<007ooOol067oo0P00UWoo000MOol00`00Oomoo`1>Ool00`00Oomoo`0F
Ool00`00Oomoo`2FOol001eoo`03001oogoo04moo`03001oogoo01Aoo`03001oogoo09Moo`007Goo
00<007ooOol0D7oo00<007ooOol04Woo00<007ooOol0V7oo000MOol00`00Oomoo`1AOol00`00Oomo
o`0@Ool00`00Oomoo`2IOol001eoo`03001oogoo055oo`03001oogoo011oo`03001oogoo09Uoo`00
7Goo00<007ooOol0DWoo00<007ooOol03Woo00<007ooOol0VWoo000MOol00`00Oomoo`1BOol00`00
Oomoo`0>Ool00`00Oomoo`2JOol001eoo`03001oogoo05=oo`03001oogoo00aoo`03001oogoo09]o
o`007Goo00<007ooOol0Dgoo00<007ooOol037oo00<007ooOol0Vgoo000MOol00`00Oomoo`1COol0
0`00Oomoo`0<Ool00`00Oomoo`2KOol001eoo`03001oogoo05Aoo`03001oogoo00Yoo`03001oogoo
09aoo`007Goo00<007ooOol0E7oo00<007ooOol02Woo00<007ooOol0W7oo000MOol00`00Oomoo`1D
Ool00`00Oomoo`0:Ool00`00Oomoo`2LOol001eoo`03001oogoo05Eoo`03001oogoo00Uoo`03001o
ogoo09aoo`002Woo0P0017oo0P000goo100017oo00<007ooOol0EGoo00<007ooOol027oo00<007oo
Ool0WGoo0009Ool01000Oomoo`000goo0P0017oo00<007ooOol017oo00<007ooOol0EGoo00<007oo
Ool027oo00<007ooOol0WGoo0009Ool01000Oomoo`002Woo00<007ooOol00goo0P00EWoo00<007oo
Ool027oo00<007ooOol0WGoo0009Ool01000Oomoo`002goo00<007ooOol00Woo00<007ooOol0EGoo
00<007ooOol027oo00<007ooOol0WGoo0009Ool01000Oomoo`0027oo00@007ooOol000Aoo`03001o
ogoo05Eoo`03001oogoo00Qoo`03001oogoo09eoo`002Woo0P002Woo0P001Goo00<007ooOol0EWoo
00<007ooOol01Woo00<007ooOol0WWoo000MOol00`00Oomoo`1FOol00`00Oomoo`06Ool00`00Oomo
o`2NOol001eoo`03001oogoo05Ioo`03001oogoo00Ioo`03001oogoo09ioo`007Goo00<007ooOol0
EWoo00<007ooOol01Woo00<007ooOol0WWoo000MOol00`00Oomoo`1FOol00`00Oomoo`06Ool00`00
Oomoo`2NOol001eoo`03001oogoo05Ioo`03001oogoo00Ioo`03001oogoo09ioo`007Goo00<007oo
Ool0EWoo00<007ooOol01Woo00<007ooOol0WWoo000MOol00`00Oomoo`1FOol00`00Oomoo`05Ool0
0`00Oomoo`2OOol001eoo`03001oogoo05Moo`03001oogoo00Aoo`03001oogoo09moo`007Goo00<0
07ooOol0Egoo00<007ooOol017oo00<007ooOol0Wgoo000MOol00`00Oomoo`1GOol00`00Oomoo`04
Ool00`00Oomoo`2OOol001eoo`03001oogoo05Moo`03001oogoo00Aoo`03001oogoo09moo`007Goo
00<007ooOol0Egoo00<007ooOol017oo00<007ooOol0Wgoo000MOol00`00Oomoo`1GOol00`00Oomo
o`04Ool00`00Oomoo`2OOol001eoo`03001oogoo05Moo`03001oogoo00Aoo`03001oogoo09moo`00
7Goo00<007ooOol0Egoo00<007ooOol017oo00<007ooOol0Wgoo000MOol00`00Oomoo`1GOol00`00
Oomoo`04Ool00`00Oomoo`2OOol001eoo`03001oogoo05Moo`03001oogoo00Aoo`03001oogoo09mo
o`007Goo00<007ooOol0Egoo00<007ooOol017oo00<007ooOol0Wgoo000MOol00`00Oomoo`1GOol0
0`00Oomoo`04Ool00`00Oomoo`2OOol001eoo`03001oogoo05Moo`03001oogoo00Aoo`03001oogoo
09moo`007Goo00<007ooOol0Egoo00<007ooOol017oo00<007ooOol0Wgoo000:Ool20004Ool20004
Ool30004Ool00`00Oomoo`1GOol00`00Oomoo`04Ool00`00Oomoo`2OOol000Uoo`04001oogoo0003
Ool20005Ool00`00Oomoo`03Ool00`00Oomoo`1GOol00`00Oomoo`04Ool00`00Oomoo`2OOol000Uo
o`04001oogoo0008Ool40004Ool2001HOol00`00Oomoo`04Ool00`00Oomoo`2OOol000Uoo`04001o
ogoo0008Ool00`00Ool00005Ool00`00Oomoo`1GOol00`00Oomoo`04Ool00`00Oomoo`2OOol000Uo
o`04001oogoo0008Ool00`00Ool00005Ool00`00Oomoo`1GOol00`00Oomoo`04Ool00`00Oomoo`2O
Ool000Yoo`8000Yoo`8000Eoo`03001oogoo05Moo`03001oogoo00Aoo`03001oogoo09moo`007Goo
00<007ooOol0Egoo00<007ooOol017oo00<007ooOol0Wgoo000MOol00`00Oomoo`1GOol00`00Oomo
o`04Ool00`00Oomoo`2OOol001eoo`03001oogoo05Moo`03001oogoo00Aoo`03001oogoo09moo`00
7Goo00<007ooOol0Egoo00<007ooOol017oo00<007ooOol0Wgoo000MOol00`00Oomoo`1GOol00`00
Oomoo`03Ool00`00Oomoo`2POol001eoo`03001oogoo05Moo`03001oogoo00=oo`03001oogoo0:1o
o`007Goo00<007ooOol0Egoo00<007ooOol00goo00<007ooOol0X7oo000MOol00`00Oomoo`1HOol0
0`00Oomoo`02Ool00`00Oomoo`2POol001eoo`03001oogoo05Qoo`03001oogoo009oo`03001oogoo
0:1oo`007Goo00<007ooOol0F7oo00<007ooOol00Woo00<007ooOol0X7oo000MOol00`00Oomoo`1H
Ool00`00Oomoo`02Ool00`00Oomoo`2POol001eoo`03001oogoo05Qoo`03001oogoo009oo`03001o
ogoo0:1oo`007Goo00<007ooOol0F7oo00<007ooOol00Woo00<007ooOol0X7oo000MOol00`00Oomo
o`1HOol00`00Oomoo`02Ool00`00Oomoo`2POol001eoo`03001oogoo05Qoo`03001oogoo009oo`03
001oogoo0:1oo`007Goo00<007ooOol0F7oo00<007ooOol00Woo00<007ooOol0X7oo000MOol00`00
Oomoo`1HOol00`00Oomoo`02Ool00`00Oomoo`2POol001eoo`03001oogoo05Qoo`03001oogoo009o
o`03001oogoo0:1oo`007Goo00<007ooOol0F7oo00<007ooOol00Woo00<007ooOol0X7oo000MOol0
0`00Oomoo`1HOol00`00Oomoo`02Ool00`00Oomoo`2POol001eoo`03001oogoo05Qoo`03001oogoo
009oo`03001oogoo0:1oo`002Woo0P0017oo0P0017oo0P001Goo00<007ooOol0F7oo00<007ooOol0
0Woo00<007ooOol0X7oo0009Ool01000Oomoo`000goo0P000goo00@007ooOol000Aoo`03001oogoo
05Qoo`03001oogoo009oo`03001oogoo0:1oo`002Goo00@007ooOol000Qoo`04001oogoo0004Ool2
001IOol00`00Oomoo`02Ool00`00Oomoo`2POol000Uoo`04001oogoo0008Ool30005Ool00`00Oomo
o`1HOol00`00Oomoo`02Ool00`00Oomoo`2POol000Uoo`04001oogoo0008Ool00`00Oomoo`05Ool0
0`00Oomoo`1HOol00`00Oomoo`02Ool00`00Oomoo`2POol000Yoo`8000Yoo`<000Aoo`03001oogoo
05Qoo`03001oogoo009oo`03001oogoo0:1oo`007Goo00<007ooOol0F7oo00<007ooOol00Woo00<0
07ooOol0X7oo000MOol00`00Oomoo`1HOol00`00Oomoo`02Ool00`00Oomoo`2POol001eoo`03001o
ogoo05Qoo`03001oogoo009oo`03001oogoo0:1oo`007Goo00<007ooOol0F7oo00<007ooOol00Woo
00<007ooOol0X7oo000MOol00`00Oomoo`1HOol00`00Oomoo`02Ool00`00Oomoo`2POol001eoo`03
001oogoo05Qoo`03001oogoo009oo`03001oogoo0:1oo`007Goo00<007ooOol0F7oo00<007ooOol0
0Woo00<007ooOol0X7oo000MOol00`00Oomoo`1HOol00`00Oomoo`02Ool00`00Oomoo`2POol001eo
o`03001oogoo05Qoo`03001oogoo009oo`03001oogoo0:1oo`007Goo00<007ooOol0F7oo00<007oo
Ool00Woo00<007ooOol0X7oo000MOol00`00Oomoo`1HOol00`00Oomoo`02Ool00`00Oomoo`2POol0
01eoo`03001oogoo05Qoo`03001oogoo009oo`03001oogoo0:1oo`007Goo00<007ooOol0F7oo00<0
07ooOol00Woo00<007ooOol0X7oo000MOol00`00Oomoo`1HOol00`00Oomoo`02Ool00`00Oomoo`2P
Ool001eoo`03001oogoo05Qoo`03001oogoo009oo`03001oogoo0:1oo`007Goo00<007ooOol0F7oo
00<007ooOol00Woo00<007ooOol0X7oo000MOol00`00Oomoo`1HOol00`00Oomoo`02Ool00`00Oomo
o`2POol001eoo`03001oogoo05Qoo`03001oogoo009oo`03001oogoo0:1oo`007Goo00<007ooOol0
F7oo00<007ooOol00Woo00<007ooOol0X7oo000MOol00`00Oomoo`1HOol00`00Oomoo`02Ool00`00
Oomoo`2POol000Yoo`8000Aoo`8000Aoo`8000Eoo`03001oogoo05Qoo`03001oogoo009oo`03001o
ogoo0:1oo`002Goo00@007ooOol000=oo`8000=oo`04001oogoo0004Ool00`00Oomoo`1HOol00`00
Oomoo`02Ool00`00Oomoo`2POol000Uoo`04001oogoo0008Ool01000Oomoo`0017oo0P00FGoo00D0
07ooOomoo`000:=oo`002Goo00@007ooOol000Uoo`8000Eoo`03001oogoo05Qoo`05001oogooOol0
002SOol000Uoo`04001oogoo0008Ool01000Oomoo`0017oo00<007ooOol0F7oo00D007ooOomoo`00
0:=oo`002Woo0P002Woo0P001Goo00<007ooOol0F7oo00D007ooOomoo`000:=oo`007Goo00<007oo
Ool0F7oo00D007ooOomoo`000:=oo`007Goo00<007ooOol0FGoo00@007ooOol00:=oo`007Goo00<0
07ooOol0FGoo00@007ooOol00:=oo`007Goo00<007ooOol0FGoo00@007ooOol00:=oo`007Goo00<0
07ooOol0FGoo00@007ooOol00:=oo`007Goo00<007ooOol0FGoo00@007ooOol00:=oo`007Goo00<0
07ooOol0FGoo00@007ooOol00:=oo`007Goo00<007ooOol0FGoo00@007ooOol00:=oo`007Goo00<0
07ooOol0FGoo00@007ooOol00:=oo`007Goo00<007ooOol0FGoo00@007ooOol00:=oo`007Goo00<0
07ooOol0FGoo00@007ooOol00:=oo`007Goo00<007ooOol0FGoo00@007ooOol00:=oo`007Goo00<0
07ooOol0FGoo00@007ooOol00:=oo`007Goo00<007ooOol0FGoo00@007ooOol00:=oo`007Goo00<0
07ooOol0FGoo00@007ooOol00:=oo`007Goo00<007ooOol0FGoo00@007ooOol00:=oo`007Goo00<0
07ooOol0FGoo00@007ooOol00:=oo`007Goo00<007ooOol0FGoo00@007ooOol00:=oo`007Goo00<0
07ooOol0FGoo00@007ooOol00:=oo`007Goo00<007ooOol0FGoo00<007oo0000Y7oo000MOol00`00
Oomoo`1IOol00`00Ool0002TOol001Eoo`<000Eoo`03001oogoo05Uoo`800:Eoo`005Woo00<007oo
Ool017oo00<007ooOol0FGoo0P00YGoo000FOol00`00Oomoo`04Ool2001JOol00`00Oomoo`2TOol0
01Ioo`03001oogoo0?moo`Qoo`005Woo00<007ooOol0ogoo27oo000EOol2003oOol:Ool00?moob5o
o`00ogoo8Goo003oOolQOol000ioo`@0029oo`<000=oo`<000Eoo`<000Uoo`<0009oo`@000Moo`80
009oo`80009oo`@0009oo`<000=oo`<0009oo`@000=oo`D00003Ool000000080009oo`D000Ioo`<0
00Aoo`<0009oo`D00004Ool00000Ool20002Ool5001]Ool000moo`03001oogoo02=oo`03001oogoo
00=oo`03001oogoo00Eoo`03001oogoo00Moo`05001oogooOol00002Ool00`00Oomoo`08Ool01000
Ool000000Woo00<007ooOol00goo00L007ooOomoo`00Ool00003Ool01000Oomoo`0017oo00L007oo
Oomoo`00Ool00005Ool01@00Oomoogoo00001goo00@007ooOol0009oo`07001oogooOol007oo0000
0Woo00@007ooOol0009oo`04001oogoo0003Ool00`00Oomoo`1/Ool000=oo`D00007Ool007oo001o
o`00Ool010000Woo1@0000=oo`0000000`000Woo0`000Woo1@000Woo1@0000=oo`0000000P000goo
00<007ooOol01Goo00<007ooOol01goo00D007ooOomoo`00009oo`03001oogoo00Qoo`<000=oo`D0
0003Ool007oo00Aoo`05001oogooOol00002Ool00`00Oomoo`02Ool01P00Oomoogoo001oo`D00003
Ool007oo009oo`03001oogoo00Moo`80009oo`07001oogooOol007oo00000Woo00@007ooOol0009o
o`04001oogoo0003Ool00`00Oomoo`1/Ool000=oo`04001oogoo0002Ool01`00Ool007oo001oo`00
00=oo`05001oogooOol00005Ool00`00Oomoo`02Ool01P00Oomoo`00Ool0009oo`04001oogoo0003
Ool01000Ool007oo0`000goo0`000goo00D007oo001oo`0000Moo`05001oogooOol00002Ool00`00
Oomoo`08Ool01000Oomoo`000Woo00L007ooOomoo`00Ool00003Ool00`00Ool00003Ool00`00Oomo
o`020003Ool01`00Oomoogoo001oo`0000=oo`03001oo`0000=oo`03001oogoo00Eoo`8000Aoo`07
001oogooOol007oo00000Woo00@007ooOol0009oo`04001oogoo0003Ool00`00Oomoo`1/Ool000=o
o`@0009oo`07001oo`00Ool007oo00000goo00D007ooOomoo`0000Eoo`03001oogoo009oo`03001o
ogoo009oo`04001oogoo0002Ool01P00Oomoogoo001oo`D000=oo`03001oogoo00=oo`05001oo`00
Ool00008Ool30002Ool40008Ool01000Oomoo`000goo0`000goo10000Woo0`000Woo0P0000=oo`00
00000Woo10000Woo0`000goo10001goo00@007ooOol000=oo`<00004Ool00000Ool200000goo0000
00030003Ool4001^Ool000Ioo`0:001oogoo001oo`00Ool007oo0003Ool01@00Oomoogoo00001Goo
00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`06001oogooOol007oo1P0000=oo`00
00000`000Woo1@003Woo00<007ooOol01goo10007goo00<007ooOol02Goo00<007ooOol01Woo0`00
67oo00<007ooOol0K7oo0004Ool300000goo000000090004Ool00`00Oomoo`02Ool20003Ool40000
17oo000007oo0P000goo10000Woo0`007Goo0`00:Goo0P002Woo0P008Woo0P00KWoo000GOol00`00
Oomoo`08Ool00`00Oomoo`0<Ool00`00Oomoo`3/Ool001Eoo`<000Eoo`03001oogoo009oo`03001o
ogoo00]oo`800>ioo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5o
o`00ogoo8Goo003oOolQOol00?moob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {946.587, -0.14072, 0.462505, 
  0.00748348}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-9.5 0.01 0 0.618034 [
[.3 -0.0125 -9 -9 ]
[.3 -0.0125 9 0 ]
[.5 -0.0125 -12 -9 ]
[.5 -0.0125 12 0 ]
[.7 -0.0125 -12 -9 ]
[.7 -0.0125 12 0 ]
[.9 -0.0125 -12 -9 ]
[.9 -0.0125 12 0 ]
[1.025 0 0 -6 ]
[1.025 0 58 6 ]
[.0875 .12361 -18 -4.5 ]
[.0875 .12361 0 4.5 ]
[.0875 .24721 -18 -4.5 ]
[.0875 .24721 0 4.5 ]
[.0875 .37082 -18 -4.5 ]
[.0875 .37082 0 4.5 ]
[.0875 .49443 -18 -4.5 ]
[.0875 .49443 0 4.5 ]
[.0875 .61803 -6 -4.5 ]
[.0875 .61803 0 4.5 ]
[.1 .64303 -29 0 ]
[.1 .64303 29 12 ]
[.5 .63053 -65 0 ]
[.5 .63053 65 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.3 0 m
.3 .00625 L
s
[(980)] .3 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1000)] .5 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(1020)] .7 -0.0125 0 1 Mshowa
.9 0 m
.9 .00625 L
s
[(1040)] .9 -0.0125 0 1 Mshowa
.125 Mabswid
.15 0 m
.15 .00375 L
s
.2 0 m
.2 .00375 L
s
.25 0 m
.25 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.45 0 m
.45 .00375 L
s
.55 0 m
.55 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.75 0 m
.75 .00375 L
s
.8 0 m
.8 .00375 L
s
.85 0 m
.85 .00375 L
s
.05 0 m
.05 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(frequency) show
117.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.1 .12361 m
.10625 .12361 L
s
[(0.2)] .0875 .12361 1 0 Mshowa
.1 .24721 m
.10625 .24721 L
s
[(0.4)] .0875 .24721 1 0 Mshowa
.1 .37082 m
.10625 .37082 L
s
[(0.6)] .0875 .37082 1 0 Mshowa
.1 .49443 m
.10625 .49443 L
s
[(0.8)] .0875 .49443 1 0 Mshowa
.1 .61803 m
.10625 .61803 L
s
[(1)] .0875 .61803 1 0 Mshowa
.125 Mabswid
.1 .0309 m
.10375 .0309 L
s
.1 .0618 m
.10375 .0618 L
s
.1 .09271 m
.10375 .09271 L
s
.1 .15451 m
.10375 .15451 L
s
.1 .18541 m
.10375 .18541 L
s
.1 .21631 m
.10375 .21631 L
s
.1 .27812 m
.10375 .27812 L
s
.1 .30902 m
.10375 .30902 L
s
.1 .33992 m
.10375 .33992 L
s
.1 .40172 m
.10375 .40172 L
s
.1 .43262 m
.10375 .43262 L
s
.1 .46353 m
.10375 .46353 L
s
.1 .52533 m
.10375 .52533 L
s
.1 .55623 m
.10375 .55623 L
s
.1 .58713 m
.10375 .58713 L
s
.25 Mabswid
.1 0 m
.1 .61803 L
s
gsave
.1 .64303 -90 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(amplitude) show
117.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
gsave
.5 .63053 -126 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(FFT) show
87.000000 13.000000 moveto
(of) show
105.000000 13.000000 moveto
(Recorded) show
159.000000 13.000000 moveto
(Sound) show
189.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .00455 m
.01 .00661 L
.02 .00307 L
.03 .00675 L
.04 .00475 L
.05 .00746 L
.06 .00535 L
.07 .0072 L
.08 .00735 L
.09 .00485 L
.1 .00916 L
.11 .00502 L
.12 .00634 L
.13 .00864 L
.14 .00656 L
.15 .00804 L
.16 .00587 L
.17 .00819 L
.18 .00864 L
.19 .00868 L
.2 .00803 L
.21 .00951 L
.22 .01165 L
.23 .01176 L
.24 .00959 L
.25 .01076 L
.26 .01005 L
.27 .01312 L
.28 .01157 L
.29 .01204 L
.3 .01367 L
.31 .0137 L
.32 .01651 L
.33 .01312 L
.34 .01558 L
.35 .01714 L
.36 .01491 L
.37 .01995 L
.38 .01967 L
.39 .01995 L
.4 .023 L
.41 .02312 L
.42 .02539 L
.43 .02728 L
.44 .03082 L
.45 .0334 L
.46 .04218 L
.47 .04523 L
.48 .05472 L
.49 .06362 L
Mistroke
.5 .08385 L
.51 .11862 L
.52 .20144 L
.53 .50129 L
.54 .61803 L
.55 .22498 L
.56 .11684 L
.57 .08326 L
.58 .06431 L
.59 .05534 L
.6 .04593 L
.61 .03832 L
.62 .03468 L
.63 .03159 L
.64 .02944 L
.65 .0275 L
.66 .02328 L
.67 .02321 L
.68 .02129 L
.69 .02044 L
.7 .01797 L
.71 .01742 L
.72 .01459 L
.73 .01796 L
.74 .01445 L
.75 .01244 L
.76 .01356 L
.77 .01268 L
.78 .01118 L
.79 .01165 L
.8 .00894 L
.81 .00895 L
.82 .01117 L
.83 .00978 L
.84 .00902 L
.85 .01141 L
.86 .01205 L
.87 .00878 L
.88 .00783 L
.89 .00881 L
.9 .00843 L
.91 .00716 L
.92 .01012 L
.93 .00904 L
.94 .0066 L
.95 .00827 L
.96 .00398 L
.97 .00409 L
.98 .00489 L
.99 .00839 L
Mistroke
1 .00805 L
Mfstroke
1 .00805 m
1 .00805 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
@7oo0`0017oo0P0017oo0P006Goo0`0017oo0P0017oo0P0017oo0P005Woo0`0017oo0P000goo1000
0goo0P005Woo0`0017oo0P0017oo0`000goo0P00CGoo0013Ool01000Oomoo`000Woo00@007ooOol0
009oo`03001oogoo01Moo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`000Woo00@007oo
Ool001Ioo`03001oogoo009oo`04001oogoo0003Ool00`00Oomoo`02Ool01000Oomoo`005Woo00<0
07ooOol00Woo00@007ooOol000Aoo`05001oogooOol00002Ool00`00Oomoo`1:Ool0045oo`<0009o
o`04001oogoo0002Ool01000Oomoo`006Goo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo
0002Ool01000Oomoo`005Woo00<007ooOol00Woo00@007ooOol000Aoo`05001oogooOol00002Ool0
0`00Oomoo`0DOol00`00Oomoo`02Ool01000Oomoo`000Woo10000Woo00@007ooOol004aoo`00@7oo
00@007ooOol000=oo`8000=oo`04001oogoo000IOol00`00Oomoo`02Ool01000Oomoo`000Woo00@0
07ooOol0009oo`04001oogoo000FOol00`00Oomoo`02Ool01000Oomoo`001Goo00@007ooOol0009o
o`03001oogoo01Aoo`03001oogoo009oo`04001oogoo0002Ool00`00Ool00003Ool01000Oomoo`00
C7oo0010Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo000IOol00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol0009oo`04001oogoo000FOol00`00Oomoo`02Ool01000Oomoo`00
0Woo00@007ooOol0009oo`04001oogoo000FOol00`00Oomoo`02Ool01000Oomoo`000Woo00<007oo
00000goo00@007ooOol004aoo`00@Goo0P0017oo0P0017oo0P006Goo0P001Goo0P0017oo0P0017oo
0P005Woo0P001Goo0P0017oo0P0017oo0P005Woo0P001Goo0P0017oo0P0017oo0P00:Goo10005goo
0`001Woo003nOol00`00Oomoo`0GOol00`00Oomoo`05Ool00>Qoo`@0009oo`@000=oo`@0009oo`@0
0003Ool0000000<0009oo`@00004Ool00000Ool20002Ool30003Ool00`00Oomoo`04Ool00>Uoo`03
001oogoo00=oo`03001oogoo009oo`03001oogoo00=oo`07001oogooOol007oo00000Woo00@007oo
Ool000Eoo`04001oogoo0002Ool01@00Oomoogoo00000Woo00<007ooOol017oo0007OooI0009Ool0
0`00Oomoo`03Ool00`00Oomoo`02Ool500000goo001oo`02Ool00`00Ool00002Ool00`00Oomoo`05
00001Goo001oogoo00000Woo00<007ooOol00goo00<007oo00001Goo0007Ool2000017oo00000000
0Woo10001Woo20001Woo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol0
27oo00<007ooOol01goo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol0
27oo00<007ooOol01goo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol0
27oo00<007ooOol01goo00<007ooOol027oo2@0037oo00<007ooOol00goo0P000goo00L007ooOomo
o`00Ool00003Ool00`00Ool00002Ool01000Oomoo`000goo00<007oo00000Woo00@007ooOol000=o
o`05001oo`00Ool00005Ool000Uoo`04001oogooOol20003Ool70004Ool01000Oomoogoo5@0017oo
0`002goo00<007ooOol0:7oo00<007ooOol0:7oo00<007ooOol04Woo1@0000=oo`00000010000goo
300000=oo`000000100027oo0`0027oo10000Woo0P0000=oo`0000000Woo0`000goo1P0000=oo`00
00000goo0`0000=oo`0000000`000goo1P0000=oo`00000017oo000MOol00`00Oomoo`0FOol40003
Ool?000017oo00000000EWoo3@001Goo00<007ooOol017oo0`0037oo00<007ooOol067oo00<007oo
Ool0=7oo000MOol00`00Oomoo`0/Ool01000Oomoogoo1`00AWoo2@00@goo0`00=7oo000MOol00`00
Oomoo`0gOol;000cOol80023Ool001eoo`03001oogoo049oo`@002aoo`<008]oo`007Goo00<007oo
Ool0AWoo0P009Woo1000SWoo000MOol00`00Oomoo`18Ool2000ROol2002BOol001eoo`03001oogoo
04Yoo`<001eoo`8009Aoo`007Goo00<007ooOol0CGoo00<007ooOol067oo0P00UWoo000MOol00`00
Oomoo`1>Ool00`00Oomoo`0FOol00`00Oomoo`2FOol001eoo`03001oogoo04moo`03001oogoo01Ao
o`03001oogoo09Moo`007Goo00<007ooOol0D7oo00<007ooOol04Woo00<007ooOol0V7oo000MOol0
0`00Oomoo`1AOol00`00Oomoo`0@Ool00`00Oomoo`2IOol001eoo`03001oogoo055oo`03001oogoo
011oo`03001oogoo09Uoo`007Goo00<007ooOol0DWoo00<007ooOol03Woo00<007ooOol0VWoo000M
Ool00`00Oomoo`1BOol00`00Oomoo`0>Ool00`00Oomoo`2JOol001eoo`03001oogoo05=oo`03001o
ogoo00aoo`03001oogoo09]oo`007Goo00<007ooOol0Dgoo00<007ooOol037oo00<007ooOol0Vgoo
000MOol00`00Oomoo`1COol00`00Oomoo`0<Ool00`00Oomoo`2KOol001eoo`03001oogoo05Aoo`03
001oogoo00Yoo`03001oogoo09aoo`007Goo00<007ooOol0E7oo00<007ooOol02Woo00<007ooOol0
W7oo000MOol00`00Oomoo`1DOol00`00Oomoo`0:Ool00`00Oomoo`2LOol001eoo`03001oogoo05Ao
o`03001oogoo00Yoo`03001oogoo09aoo`002Woo0P0017oo0P000goo100017oo00<007ooOol0EGoo
00<007ooOol027oo00<007ooOol0WGoo0009Ool01000Oomoo`000goo0P0017oo00<007ooOol017oo
00<007ooOol0EGoo00<007ooOol027oo00<007ooOol0WGoo0009Ool01000Oomoo`002Woo00<007oo
Ool00goo0P00EWoo00<007ooOol027oo00<007ooOol0WGoo0009Ool01000Oomoo`002goo00<007oo
Ool00Woo00<007ooOol0EGoo00<007ooOol027oo00<007ooOol0WGoo0009Ool01000Oomoo`0027oo
00@007ooOol000Aoo`03001oogoo05Eoo`03001oogoo00Qoo`03001oogoo09eoo`002Woo0P002Woo
0P001Goo00<007ooOol0EGoo00<007ooOol027oo00<007ooOol0WGoo000MOol00`00Oomoo`1FOol0
0`00Oomoo`07Ool00`00Oomoo`2MOol001eoo`03001oogoo05Ioo`03001oogoo00Moo`03001oogoo
09eoo`007Goo00<007ooOol0EWoo00<007ooOol01Woo00<007ooOol0WWoo000MOol00`00Oomoo`1F
Ool00`00Oomoo`06Ool00`00Oomoo`2NOol001eoo`03001oogoo05Ioo`03001oogoo00Ioo`03001o
ogoo09ioo`007Goo00<007ooOol0EWoo00<007ooOol01Woo00<007ooOol0WWoo000MOol00`00Oomo
o`1FOol00`00Oomoo`06Ool00`00Oomoo`2NOol001eoo`03001oogoo05Ioo`03001oogoo00Ioo`03
001oogoo09ioo`007Goo00<007ooOol0EWoo00<007ooOol01Woo00<007ooOol0WWoo000MOol00`00
Oomoo`1GOol00`00Oomoo`05Ool00`00Oomoo`2NOol001eoo`03001oogoo05Moo`03001oogoo00Eo
o`03001oogoo09ioo`007Goo00<007ooOol0Egoo00<007ooOol01Goo00<007ooOol0WWoo000MOol0
0`00Oomoo`1GOol00`00Oomoo`05Ool00`00Oomoo`2NOol001eoo`03001oogoo05Moo`03001oogoo
00Aoo`03001oogoo09moo`007Goo00<007ooOol0Egoo00<007ooOol017oo00<007ooOol0Wgoo000M
Ool00`00Oomoo`1GOol00`00Oomoo`04Ool00`00Oomoo`2OOol001eoo`03001oogoo05Moo`03001o
ogoo00Aoo`03001oogoo09moo`007Goo00<007ooOol0Egoo00<007ooOol017oo00<007ooOol0Wgoo
000MOol00`00Oomoo`1GOol00`00Oomoo`04Ool00`00Oomoo`2OOol001eoo`03001oogoo05Moo`03
001oogoo00Aoo`03001oogoo09moo`007Goo00<007ooOol0Egoo00<007ooOol017oo00<007ooOol0
Wgoo000:Ool20004Ool20004Ool30004Ool00`00Oomoo`1GOol00`00Oomoo`04Ool00`00Oomoo`2O
Ool000Uoo`04001oogoo0003Ool20005Ool00`00Oomoo`03Ool00`00Oomoo`1GOol00`00Oomoo`04
Ool00`00Oomoo`2OOol000Uoo`04001oogoo0008Ool40004Ool2001HOol00`00Oomoo`04Ool00`00
Oomoo`2OOol000Uoo`04001oogoo0008Ool00`00Ool00005Ool00`00Oomoo`1GOol00`00Oomoo`04
Ool00`00Oomoo`2OOol000Uoo`04001oogoo0008Ool00`00Ool00005Ool00`00Oomoo`1GOol00`00
Oomoo`04Ool00`00Oomoo`2OOol000Yoo`8000Yoo`8000Eoo`03001oogoo05Moo`03001oogoo00Ao
o`03001oogoo09moo`007Goo00<007ooOol0Egoo00<007ooOol017oo00<007ooOol0Wgoo000MOol0
0`00Oomoo`1GOol00`00Oomoo`04Ool00`00Oomoo`2OOol001eoo`03001oogoo05Moo`03001oogoo
00Aoo`03001oogoo09moo`007Goo00<007ooOol0F7oo00<007ooOol00goo00<007ooOol0Wgoo000M
Ool00`00Oomoo`1HOol00`00Oomoo`03Ool00`00Oomoo`2OOol001eoo`03001oogoo05Qoo`03001o
ogoo00=oo`03001oogoo09moo`007Goo00<007ooOol0F7oo00<007ooOol00goo00<007ooOol0Wgoo
000MOol00`00Oomoo`1HOol00`00Oomoo`03Ool00`00Oomoo`2OOol001eoo`03001oogoo05Qoo`03
001oogoo00=oo`03001oogoo09moo`007Goo00<007ooOol0F7oo00<007ooOol00goo00<007ooOol0
Wgoo000MOol00`00Oomoo`1HOol00`00Oomoo`03Ool00`00Oomoo`2OOol001eoo`03001oogoo05Qo
o`03001oogoo00=oo`03001oogoo09moo`007Goo00<007ooOol0F7oo00<007ooOol00goo00<007oo
Ool0Wgoo000MOol00`00Oomoo`1HOol00`00Oomoo`02Ool00`00Oomoo`2POol001eoo`03001oogoo
05Qoo`03001oogoo009oo`03001oogoo0:1oo`007Goo00<007ooOol0F7oo00<007ooOol00Woo00<0
07ooOol0X7oo000MOol00`00Oomoo`1HOol00`00Oomoo`02Ool00`00Oomoo`2POol001eoo`03001o
ogoo05Qoo`03001oogoo009oo`03001oogoo0:1oo`007Goo00<007ooOol0F7oo00<007ooOol00Woo
00<007ooOol0X7oo000MOol00`00Oomoo`1HOol00`00Oomoo`02Ool00`00Oomoo`2POol001eoo`03
001oogoo05Qoo`03001oogoo009oo`03001oogoo0:1oo`002Woo0P0017oo0P0017oo0P001Goo00<0
07ooOol0F7oo00<007ooOol00Woo00<007ooOol0X7oo0009Ool01000Oomoo`000goo0P000goo00@0
07ooOol000Aoo`03001oogoo05Qoo`03001oogoo009oo`03001oogoo0:1oo`002Goo00@007ooOol0
00Qoo`04001oogoo0004Ool2001IOol00`00Oomoo`02Ool00`00Oomoo`2POol000Uoo`04001oogoo
0008Ool30005Ool00`00Oomoo`1HOol00`00Oomoo`02Ool00`00Oomoo`2POol000Uoo`04001oogoo
0008Ool00`00Oomoo`05Ool00`00Oomoo`1HOol00`00Oomoo`02Ool00`00Oomoo`2POol000Yoo`80
00Yoo`<000Aoo`03001oogoo05Qoo`03001oogoo009oo`03001oogoo0:1oo`007Goo00<007ooOol0
F7oo00<007ooOol00Woo00<007ooOol0X7oo000MOol00`00Oomoo`1HOol00`00Oomoo`02Ool00`00
Oomoo`2POol001eoo`03001oogoo05Qoo`03001oogoo009oo`03001oogoo0:1oo`007Goo00<007oo
Ool0F7oo00<007ooOol00Woo00<007ooOol0X7oo000MOol00`00Oomoo`1HOol00`00Oomoo`02Ool0
0`00Oomoo`2POol001eoo`03001oogoo05Qoo`03001oogoo009oo`03001oogoo0:1oo`007Goo00<0
07ooOol0F7oo00<007ooOol00Woo00<007ooOol0X7oo000MOol00`00Oomoo`1HOol00`00Oomoo`02
Ool00`00Oomoo`2POol001eoo`03001oogoo05Qoo`03001oogoo009oo`03001oogoo0:1oo`007Goo
00<007ooOol0FGoo00D007ooOomoo`000:9oo`007Goo00<007ooOol0FGoo00D007ooOomoo`000:9o
o`007Goo00<007ooOol0FGoo00D007ooOomoo`000:9oo`007Goo00<007ooOol0FGoo00D007ooOomo
o`000:9oo`007Goo00<007ooOol0FGoo00D007ooOomoo`000:9oo`007Goo00<007ooOol0FGoo00D0
07ooOomoo`000:9oo`007Goo00<007ooOol0FGoo00D007ooOomoo`000:9oo`007Goo00<007ooOol0
FGoo00D007ooOomoo`000:9oo`007Goo00<007ooOol0FGoo00D007ooOomoo`000:9oo`007Goo00<0
07ooOol0FGoo00D007ooOomoo`000:9oo`007Goo00<007ooOol0FGoo00D007ooOomoo`000:9oo`00
2Woo0P0017oo0P0017oo0P001Goo00<007ooOol0FGoo00D007ooOomoo`000:9oo`002Goo00@007oo
Ool000=oo`8000=oo`04001oogoo0004Ool00`00Oomoo`1IOol01@00Oomoogoo0000XWoo0009Ool0
1000Oomoo`0027oo00@007ooOol000Aoo`8005Yoo`05001oogooOol0002ROol000Uoo`04001oogoo
0009Ool20005Ool00`00Oomoo`1IOol01@00Oomoogoo0000XWoo0009Ool01000Oomoo`0027oo00@0
07ooOol000Aoo`03001oogoo05Uoo`05001oogooOol0002ROol000Yoo`8000Yoo`8000Eoo`03001o
ogoo05Uoo`05001oogooOol0002ROol001eoo`03001oogoo05Uoo`05001oogooOol0002ROol001eo
o`03001oogoo05Uoo`05001oogooOol0002ROol001eoo`03001oogoo05Uoo`05001oogooOol0002R
Ool001eoo`03001oogoo05Yoo`03001oo`000:=oo`007Goo00<007ooOol0FWoo00<007oo0000Xgoo
000MOol00`00Oomoo`1JOol00`00Ool0002SOol001eoo`03001oogoo05Yoo`03001oo`000:=oo`00
7Goo00<007ooOol0FWoo00<007oo0000Xgoo000MOol00`00Oomoo`1JOol00`00Ool0002SOol001eo
o`03001oogoo05Yoo`03001oo`000:=oo`007Goo00<007ooOol0FWoo00<007oo0000Xgoo000MOol0
0`00Oomoo`1KOol2002SOol001eoo`03001oogoo05]oo`800:=oo`007Goo00<007ooOol0Fgoo0P00
Xgoo000MOol00`00Oomoo`1KOol2002SOol001eoo`03001oogoo05]oo`800:=oo`007Goo00<007oo
Ool0Fgoo0P00Xgoo000MOol00`00Oomoo`1KOol2002SOol001eoo`03001oogoo05]oo`800:=oo`00
7Goo00<007ooOol0Fgoo0P00Xgoo000MOol00`00Oomoo`1LOol00`00Oomoo`2QOol001Eoo`<000Eo
o`03001oogoo05aoo`03001oogoo0:5oo`005Woo00<007ooOol017oo00<007ooOol0G7oo00<007oo
Ool0XGoo000FOol00`00Oomoo`04Ool2001MOol00`00Oomoo`2QOol001Ioo`03001oogoo0?moo`Qo
o`005Woo00<007ooOol0ogoo27oo000EOol2003oOol:Ool00?moob5oo`00ogoo8Goo003oOolQOol0
00ioo`@0029oo`<000=oo`<000Eoo`<000Uoo`<0009oo`@000Moo`80009oo`80009oo`@0009oo`<0
00=oo`<0009oo`@000=oo`D00003Ool000000080009oo`D000Ioo`<000Aoo`<0009oo`D00004Ool0
0000Ool20002Ool5001]Ool000moo`03001oogoo02=oo`03001oogoo00=oo`03001oogoo00Eoo`03
001oogoo00Moo`05001oogooOol00002Ool00`00Oomoo`08Ool01000Ool000000Woo00<007ooOol0
0goo00L007ooOomoo`00Ool00003Ool01000Oomoo`0017oo00L007ooOomoo`00Ool00005Ool01@00
Oomoogoo00001goo00@007ooOol0009oo`07001oogooOol007oo00000Woo00@007ooOol0009oo`04
001oogoo0003Ool00`00Oomoo`1/Ool000=oo`D00007Ool007oo001oo`00Ool010000Woo1@0000=o
o`0000000`000Woo0`000Woo1@000Woo1@0000=oo`0000000P000goo00<007ooOol01Goo00<007oo
Ool01goo00D007ooOomoo`00009oo`03001oogoo00Qoo`<000=oo`D00003Ool007oo00Aoo`05001o
ogooOol00002Ool00`00Oomoo`02Ool01P00Oomoogoo001oo`D00003Ool007oo009oo`03001oogoo
00Moo`80009oo`07001oogooOol007oo00000Woo00@007ooOol0009oo`04001oogoo0003Ool00`00
Oomoo`1/Ool000=oo`04001oogoo0002Ool01`00Ool007oo001oo`0000=oo`05001oogooOol00005
Ool00`00Oomoo`02Ool01P00Oomoo`00Ool0009oo`04001oogoo0003Ool01000Ool007oo0`000goo
0`000goo00D007oo001oo`0000Moo`05001oogooOol00002Ool00`00Oomoo`08Ool01000Oomoo`00
0Woo00L007ooOomoo`00Ool00003Ool00`00Ool00003Ool00`00Oomoo`020003Ool01`00Oomoogoo
001oo`0000=oo`03001oo`0000=oo`03001oogoo00Eoo`8000Aoo`07001oogooOol007oo00000Woo
00@007ooOol0009oo`04001oogoo0003Ool00`00Oomoo`1/Ool000=oo`@0009oo`07001oo`00Ool0
07oo00000goo00D007ooOomoo`0000Eoo`03001oogoo009oo`03001oogoo009oo`04001oogoo0002
Ool01P00Oomoogoo001oo`D000=oo`03001oogoo00=oo`05001oo`00Ool00008Ool30002Ool40008
Ool01000Oomoo`000goo0`000goo10000Woo0`000Woo0P0000=oo`0000000Woo10000Woo0`000goo
10001goo00@007ooOol000=oo`<00004Ool00000Ool200000goo000000030003Ool4001^Ool000Io
o`0:001oogoo001oo`00Ool007oo0003Ool01@00Oomoogoo00001Goo00<007ooOol00Woo00<007oo
Ool00Woo00@007ooOol0009oo`06001oogooOol007oo1P0000=oo`0000000`000Woo1@003Woo00<0
07ooOol01goo10007goo00<007ooOol02Goo00<007ooOol01Woo0`0067oo00<007ooOol0K7oo0004
Ool300000goo000000090004Ool00`00Oomoo`02Ool20003Ool4000017oo000007oo0P000goo1000
0Woo0`007Goo0`00:Goo0P002Woo0P008Woo0P00KWoo000GOol00`00Oomoo`08Ool00`00Oomoo`0<
Ool00`00Oomoo`3/Ool001Eoo`<000Eoo`03001oogoo009oo`03001oogoo00]oo`800>ioo`00ogoo
8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol0
0?moob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {946.587, -0.14072, 0.462505, 
  0.00748348}}]
}, Closed]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Results", "Section"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0406053 0.0995303 0.320818 0.298943 [
[(2)] .23967 .32082 0 2 Msboxa
[(4)] .43873 .32082 0 2 Msboxa
[(6)] .63779 .32082 0 2 Msboxa
[(8)] .83685 .32082 0 2 Msboxa
[(v)] 1.025 .32082 -1 0 Msboxa
[(velocity vs time)] .5 .61803 0 -2 0 0 1 Mouter Mrotsboxa
[(-1)] .02811 .02188 1 0 Msboxa
[(-0.5)] .02811 .17135 1 0 Msboxa
[(0.5)] .02811 .47029 1 0 Msboxa
[(t)] .04061 .61803 0 -4 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 .61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.23967 .32082 m
.23967 .32707 L
s
P
[(2)] .23967 .32082 0 2 Mshowa
p
.002 w
.43873 .32082 m
.43873 .32707 L
s
P
[(4)] .43873 .32082 0 2 Mshowa
p
.002 w
.63779 .32082 m
.63779 .32707 L
s
P
[(6)] .63779 .32082 0 2 Mshowa
p
.002 w
.83685 .32082 m
.83685 .32707 L
s
P
[(8)] .83685 .32082 0 2 Mshowa
p
.001 w
.08042 .32082 m
.08042 .32457 L
s
P
p
.001 w
.12023 .32082 m
.12023 .32457 L
s
P
p
.001 w
.16004 .32082 m
.16004 .32457 L
s
P
p
.001 w
.19985 .32082 m
.19985 .32457 L
s
P
p
.001 w
.27948 .32082 m
.27948 .32457 L
s
P
p
.001 w
.31929 .32082 m
.31929 .32457 L
s
P
p
.001 w
.3591 .32082 m
.3591 .32457 L
s
P
p
.001 w
.39891 .32082 m
.39891 .32457 L
s
P
p
.001 w
.47854 .32082 m
.47854 .32457 L
s
P
p
.001 w
.51835 .32082 m
.51835 .32457 L
s
P
p
.001 w
.55816 .32082 m
.55816 .32457 L
s
P
p
.001 w
.59798 .32082 m
.59798 .32457 L
s
P
p
.001 w
.6776 .32082 m
.6776 .32457 L
s
P
p
.001 w
.71741 .32082 m
.71741 .32457 L
s
P
p
.001 w
.75722 .32082 m
.75722 .32457 L
s
P
p
.001 w
.79704 .32082 m
.79704 .32457 L
s
P
p
.001 w
.00079 .32082 m
.00079 .32457 L
s
P
p
.001 w
.87666 .32082 m
.87666 .32457 L
s
P
p
.001 w
.91647 .32082 m
.91647 .32457 L
s
P
p
.001 w
.95628 .32082 m
.95628 .32457 L
s
P
p
.001 w
.9961 .32082 m
.9961 .32457 L
s
P
[(v)] 1.025 .32082 -1 0 Mshowa
p
.002 w
0 .32082 m
1 .32082 L
s
P
[(velocity vs time)] .5 .61803 0 -2 0 0 1 Mouter Mrotshowa
p
.002 w
.04061 .02188 m
.04686 .02188 L
s
P
[(-1)] .02811 .02188 1 0 Mshowa
p
.002 w
.04061 .17135 m
.04686 .17135 L
s
P
[(-0.5)] .02811 .17135 1 0 Mshowa
p
.002 w
.04061 .47029 m
.04686 .47029 L
s
P
[(0.5)] .02811 .47029 1 0 Mshowa
p
.001 w
.04061 .05177 m
.04436 .05177 L
s
P
p
.001 w
.04061 .08166 m
.04436 .08166 L
s
P
p
.001 w
.04061 .11156 m
.04436 .11156 L
s
P
p
.001 w
.04061 .14145 m
.04436 .14145 L
s
P
p
.001 w
.04061 .20124 m
.04436 .20124 L
s
P
p
.001 w
.04061 .23114 m
.04436 .23114 L
s
P
p
.001 w
.04061 .26103 m
.04436 .26103 L
s
P
p
.001 w
.04061 .29092 m
.04436 .29092 L
s
P
p
.001 w
.04061 .35071 m
.04436 .35071 L
s
P
p
.001 w
.04061 .38061 m
.04436 .38061 L
s
P
p
.001 w
.04061 .4105 m
.04436 .4105 L
s
P
p
.001 w
.04061 .4404 m
.04436 .4404 L
s
P
p
.001 w
.04061 .50018 m
.04436 .50018 L
s
P
p
.001 w
.04061 .53008 m
.04436 .53008 L
s
P
p
.001 w
.04061 .55997 m
.04436 .55997 L
s
P
p
.001 w
.04061 .58987 m
.04436 .58987 L
s
P
[(t)] .04061 .61803 0 -4 Mshowa
p
.002 w
.04061 0 m
.04061 .61803 L
s
P
P
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
p
.004 w
.04558 .32769 m
.05056 .31992 L
.05553 .31334 L
.06051 .31633 L
.06549 .32441 L
.07046 .32949 L
.07544 .34713 L
.08042 .36835 L
.08539 .39227 L
.09037 .4114 L
.09535 .44099 L
.10032 .47687 L
.1053 .50766 L
.11028 .53636 L
.11525 .55728 L
.12023 .57492 L
.12521 .5806 L
.13018 .58239 L
.13516 .5803 L
.14014 .58718 L
.14511 .58269 L
.15009 .59435 L
.15507 .60332 L
.16004 .59913 L
.16502 .59256 L
.16999 .57432 L
.17497 .56535 L
.17995 .55011 L
.18492 .54891 L
.1899 .54981 L
.19488 .54951 L
.19985 .55638 L
.20483 .55878 L
.20981 .56386 L
.21478 .57044 L
.21976 .56834 L
.22474 .56476 L
.22971 .56027 L
.23469 .55818 L
.23967 .55848 L
.24464 .55011 L
.24962 .54891 L
.2546 .5519 L
.25957 .55668 L
.26455 .56206 L
.26953 .56505 L
.2745 .52888 L
.27948 .48793 L
.28445 .46192 L
.28943 .45624 L
Mistroke
.29441 .46999 L
.29938 .49959 L
.30436 .54383 L
.30934 .5516 L
.31431 .52948 L
.31929 .48733 L
.32427 .33487 L
.32924 .27179 L
.33422 .28196 L
.3392 .30796 L
.34417 .35759 L
.34915 .37463 L
.35413 .37044 L
.3591 .21768 L
.36408 .10618 L
.36906 .2129 L
.37403 .32171 L
.37901 .42993 L
.38398 .49361 L
.38896 .49988 L
.39394 .42963 L
.39891 .28106 L
.40389 .25774 L
.40887 .23891 L
.41384 .22396 L
.41882 .21948 L
.4238 .22217 L
.42877 .22366 L
.43375 .22276 L
.43873 .22217 L
.4437 .22247 L
.44868 .22306 L
.45366 .22516 L
.45863 .23233 L
.46361 .23741 L
.46859 .2422 L
.47356 .25146 L
.47854 .25684 L
.48352 .28883 L
.48849 .31065 L
.49347 .32201 L
.49844 .31753 L
.50342 .2987 L
.5084 .27329 L
.51337 .23711 L
.51835 .23084 L
.52333 .23054 L
.5283 .23114 L
.53328 .23143 L
.53826 .22934 L
Mistroke
.54323 .22785 L
.54821 .22336 L
.55319 .22097 L
.55816 .22516 L
.56314 .23203 L
.56812 .24279 L
.57309 .25176 L
.57807 .25565 L
.58305 .25206 L
.58802 .24578 L
.593 .2419 L
.59798 .23741 L
.60295 .23682 L
.60793 .23831 L
.6129 .2398 L
.61788 .23801 L
.62286 .23861 L
.62783 .23921 L
.63281 .23891 L
.63779 .23861 L
.64276 .23801 L
.64774 .23921 L
.65272 .23921 L
.65769 .2404 L
.66267 .23921 L
.66765 .23921 L
.67262 .23951 L
.6776 .23891 L
.68258 .2401 L
.68755 .2425 L
.69253 .24459 L
.69751 .241 L
.70248 .23921 L
.70746 .23951 L
.71244 .23801 L
.71741 .23921 L
.72239 .23921 L
.72736 .2413 L
.73234 .23891 L
.73732 .23652 L
.74229 .23891 L
.74727 .24429 L
.75225 .24937 L
.75722 .25057 L
.7622 .25356 L
.76718 .25206 L
.77215 .24788 L
.77713 .24339 L
.78211 .2401 L
.78708 .23741 L
Mistroke
.79206 .23951 L
.79704 .24907 L
.80201 .25565 L
.80699 .26372 L
.81197 .26492 L
.81694 .25625 L
.82192 .241 L
.82689 .23263 L
.83187 .22874 L
.83685 .22934 L
.84182 .2401 L
.8468 .23921 L
.85178 .23263 L
.85675 .23741 L
.86173 .23323 L
.86671 .23472 L
.87168 .24369 L
.87666 .25176 L
.88164 .24279 L
.88661 .23831 L
.89159 .23741 L
.89657 .22426 L
.90154 .22695 L
.90652 .23024 L
.9115 .23173 L
.91647 .23353 L
.92145 .24638 L
.92643 .24459 L
.9314 .2398 L
.93638 .2425 L
.94135 .23592 L
.94633 .23024 L
.95131 .23592 L
.95628 .241 L
.96126 .24429 L
.96624 .2419 L
.97121 .2422 L
.97619 .2416 L
Mfstroke
p
1 0 0 r
p
.01 w
.02381 .32082 Mdot
.0574 .21878 Mdot
.09099 .32082 Mdot
.12458 .42285 Mdot
.15818 .52489 Mdot
.19177 .52489 Mdot
.22536 .52489 Mdot
.25895 .52489 Mdot
.29254 .52489 Mdot
.32613 .52489 Mdot
.35972 .01472 Mdot
.39332 .11675 Mdot
.42691 .11675 Mdot
.4605 .11675 Mdot
.49409 .21878 Mdot
.52768 .11675 Mdot
.56127 .11675 Mdot
.59486 .11675 Mdot
.62846 .11675 Mdot
.66205 .11675 Mdot
.69564 .11675 Mdot
.72923 .11675 Mdot
.76282 .11675 Mdot
.79641 .11675 Mdot
.83001 .21878 Mdot
.8636 .11675 Mdot
.89719 .21878 Mdot
.93078 .11675 Mdot
P
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{370, 226},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005b0000hQ000`40O003h00OogooLgoo000TOol0
0`00Oomoo`3oOom<Ool002Aoo`03001oogoo0?moodaoo`0097oo00<007ooOol0ogooC7oo000TOol0
0`00Oomoo`3oOom<Ool002Aoo`03001oogoo06=oo`=l0>Eoo`006goo0`001Woo00<007ooOol0Hgoo
0g`0iGoo000LOol00`00Oomoo`05Ool00`00Oomoo`1SOol3O03UOol001Eoo`D0009oo`03001oogoo
00Eoo`<00?moodaoo`0077oo00<007ooOol01Goo00<007ooOol0ogooC7oo000LOol00`00Oomoo`05
Ool00`00Oomoo`3oOom<Ool001]oo`8000Moo`03001oogoo0?moodaoo`0097oo00<007ooOol0ogoo
C7oo000TOol00`00Oomoo`3oOom<Ool002Aoo`03001oogoo0?moodaoo`0097oo00<007ooOol0ogoo
C7oo000TOol00`00Oomoo`3oOom<Ool002Aoo`03001oogoo0?moodaoo`0097oo0P00ogooCGoo000T
Ool00`00Oomoo`3oOom<Ool002Aoo`03001oogoo0?moodaoo`0097oo00<007ooOol0ogooC7oo000T
Ool00`00Oomoo`3oOom<Ool002Aoo`03001oogoo0?moodaoo`0097oo00<007ooOol0ogooC7oo000T
Ool00`00Oomoo`3oOom<Ool002Aoo`03001oogoo0?moodaoo`0097oo0P00ogooCGoo000TOol00`00
Oomoo`3oOom<Ool002Aoo`03001oogoo0?moodaoo`0097oo00<007ooOol0ogooC7oo000TOol00`00
Oomoo`3oOom<Ool002Aoo`03001oogoo0?moodaoo`0097oo00<007ooOol0ogooC7oo000TOol00`00
Oomoo`3oOom<Ool002Aoo`03001oogoo06Ioo`03001oogoo0>9oo`0097oo00<007ooOol0IWoo00<0
07ooOol0hWoo000TOol2001WOol00`00Oomoo`3ROol002Aoo`03001oogoo06Ioo`03001oogoo00Eo
o`=l00Qoo`=l00Qoo`=l019oo`=l00Qoo`=l00Qoo`=l00Qoo`=l00Qoo`=l00Qoo`=l00Moo`=l00Qo
o`=l00Qoo`=l01=oo`=l01=oo`=l02aoo`0097oo00<007ooOol0IWoo00<007ooOol01Goo0g`027oo
0g`027oo0g`04Woo0g`027oo0g`027oo0g`027oo0g`027oo0g`027oo0g`01goo0g`027oo0g`027oo
0g`04goo0g`04goo0g`0;7oo000TOol00`00Oomoo`1VOol00`00Oomoo`05Ool3O008Ool3O008Ool3
O00BOol3O008Ool3O008Ool3O008Ool3O008Ool3O008Ool3O007Ool3O008Ool3O008Ool3O00COol3
O00COol3O00/Ool002Aoo`03001oogoo06Ioo`03001oogoo0>9oo`0097oo00<007ooOol0IWoo00<0
07ooOol0hWoo000TOol00`00Oomoo`1VOol00`00Oomoo`3ROol002Aoo`03001oogoo06Ioo`03001o
ogoo0>9oo`0097oo00<007ooOol0IGoo0P00i7oo000TOol00`00Oomoo`1UOol2003TOol002Aoo`80
06Ioo`800>Aoo`0097oo00<007ooOol0IGoo0P00i7oo000TOol00`00Oomoo`1UOol2003TOol002Ao
o`03001oogoo06Eoo`800>Aoo`0097oo00<007ooOol0IGoo0P00i7oo000TOol00`00Oomoo`1UOol2
003TOol002Aoo`03001oogoo06Eoo`03001oo`000>=oo`0047oo0P0017oo0P000goo0`001Woo00<0
07ooOol0IGoo00<007oo0000hgoo000?Ool01000Oomoo`000goo0P001Woo00<007ooOol00goo00<0
07ooOol0IGoo00<007oo0000hgoo0009Ool500001Goo001oogoo00002goo00<007ooOol00goo0`00
IGoo00<007oo0000hgoo000?Ool01000Oomoo`0027oo0`001Woo00<007ooOol0IGoo00<007oo0000
hgoo000?Ool01000Oomoo`0027oo00<007ooOol01Woo00<007ooOol0IGoo00<007oo0000hgoo000@
Ool20009Ool40005Ool00`00Oomoo`1UOol00`00Ool0003SOol002Aoo`03001oogoo06Eoo`03001o
o`000>=oo`0097oo00<007ooOol0IGoo00<007oo0000hgoo000TOol00`00Oomoo`1UOol00`00Ool0
003SOol002Aoo`03001oogoo06Aoo`04001oogoo003SOol002Aoo`03001oogoo06Aoo`04001oogoo
003SOol002Aoo`03001oogoo06Aoo`04001oogoo003SOol002Aoo`8006Eoo`04001oogoo003SOol0
02Aoo`03001oogoo06Aoo`04001oogoo003SOol002Aoo`03001oogoo06Aoo`04001oogoo003SOol0
02Aoo`03001oogoo06Aoo`04001oogoo003SOol002Aoo`03001oogoo06Aoo`04001oogoo003SOol0
02Aoo`04001oogooOol3O01POol01000Oomoo`009Woo0g`0JWoo0g`04goo0g`0=goo000TOol01000
Oomoogoo0g`0H7oo00@007ooOol000moo`8001Eoo`=l015oo`8005Moo`=l01=oo`=l03Moo`0097oo
00@007ooOomoo`=l061oo`04001oogoo000>Ool00`00Oomoo`09000<Ool3O00?Ool200000goo001o
o`1FOol3O00COol3O00gOol002Aoo`03001oogoo06Aoo`04001oogoo000>Ool00`00Oomoo`09Ool0
0`00Oomoo`0JOol00`00Oomoo`02Ool00`00Oomoo`1[Ool3000fOol002Aoo`8006Eoo`04001oogoo
000=Ool00`00Oomoo`0;Ool00`00Oomoo`0AOol500000goo00000006Ool00`00Oomoo`1DOol3000B
Ool01@00Oomoogoo000037oo00<007ooOol09Woo000TOol00`00Oomoo`1TOol01000Oomoo`003Goo
00<007ooOol037oo00<007ooOol047oo00<007ooOol00Woo00<007ooOol01goo00<007ooOol0DWoo
00@007ooOol000Aoo`03001oogoo008000Uoo`03001oogoo009oo`<000Qoo`8002Qoo`0097oo00<0
07ooOol0I7oo00@007ooOol000eoo`03001oogoo00eoo`03001oogoo00ioo`03001oogoo00eoo`03
001oogoo00Uoo`8002Uoo`<001]oo`05001oogooOol00002Ool01`00Ool007oo001oo`0000Qoo`03
001oogoo00Aoo`03001oogoo00Eoo`04001oogoo000WOol002Aoo`03001oogoo06Aoo`04001oogoo
000<Ool00`00Oomoo`0?Ool00`00Oomoo`0=Ool00`00Oomoo`0>Ool00`00Oomoo`06Ool20002OolJ
0004Ool900000goo001oo`02Ool00`00Oomoo`09Ool50009Ool00`00Oomoo`03Ool20003Ool01000
Oomoo`001Goo0`0027oo00L007ooOomoo`00Ool00004Ool00`00Oomoo`0TOol002Aoo`03001oogoo
06Aoo`04001oogoo000<Ool00`00Oomoo`0@Ool00`00Oomoo`0<Ool00`00Oomoo`0>Ool00`00Oomo
o`05Ool00`00Oomoo`0LOol200000goo001oo`08Ool00`00Oomoo`02Ool00`00Oomoo`08Ool00`00
Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`0=Ool01@00Oomoogoo00002goo00H007ooOol007oo
0006Ool00`00Ool00004000OOol002Aoo`03001oogoo06Aoo`05001oogooOol0000:Ool00`00Oomo
o`0AOol00`00Oomoo`0<Ool00`00Oomoo`0>Ool00`00Oomoo`04Ool00`00Oomoo`0OOol00`00Oomo
o`0>Ool20007Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`0>Ool01000Oomoo`0037oo
0P002Woo00<007ooOol08Woo000TOol00`00Oomoo`1TOol01@00Oomoogoo00002Woo00<007ooOol0
4Woo00<007ooOol02Woo00<007ooOol047oo00<007ooOol00Woo00<007ooOol0<goo0P0017oo00<0
07ooOol01Goo00<007ooOol01Goo00<007ooOol03Woo00<007oo0000?Woo000TOol00`00Oomoo`1T
Ool01@00Oomoogoo00002Woo00<007ooOol04goo00<007ooOol02Goo00<007ooOol04Goo0P0000=o
o`00Ool0=goo00@007oo000000Uoo`03001oogoo00=oo`03001oogoo011oo`03001oogoo03eoo`00
97oo00<007ooOol0I7oo00D007ooOomoo`0000Uoo`03001oogoo01Aoo`03001oogoo00Uoo`03001o
ogoo01=oo`03001oogoo03Qoo`03001oogoo00Yoo`03001oogoo009oo`03001oogoo051oo`0097oo
00<007ooOol0Hgoo00<007ooOol00Woo00<007ooOol01goo00<007ooOol05Goo00<007ooOol027oo
00<007ooOol0Fgoo00<007ooOol00Woo00<007ooOol0D7oo000TOol2001TOol00`00Oomoo`02Ool0
0`00Oomoo`07Ool00`00Oomoo`0EOol00`00Oomoo`08Ool00`00Oomoo`1LOol01000Oomoo`00Dgoo
000TOol00`00Oomoo`1SOol00`00Oomoo`02Ool00`00Oomoo`07Ool00`00Oomoo`0EOol00`00Oomo
o`08Ool00`00Oomoo`1MOol2001DOol002Aoo`03001oogoo06=oo`03001oogoo009oo`03001oogoo
00Moo`03001oogoo01Ioo`03001oogoo00Ioo`03001oogoo0;Aoo`0097oo00<007ooOol0Hgoo00<0
07ooOol00Woo00<007ooOol01goo00<007ooOol05Woo00<007ooOol01Woo00<007ooOol0]7oo000T
Ool00`00Oomoo`1JOol00`00Oomoo`06Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`0G
Ool00`00Oomoo`06Ool00`00Oomoo`2dOol002Aoo`03001oogoo05Yoo`03001oogoo00Ioo`03001o
ogoo009oo`03001oogoo00Ioo`03001oogoo01Moo`03001oogoo00Ioo`03001oogoo0;Aoo`0097oo
00<007ooOol0FWoo0P001goo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol05goo00<007oo
Ool01Woo00<007ooOol0]7oo000TOol00`00Oomoo`0kOol4000KOol00`00Ool00006Ool00`00Oomo
o`02Ool00`00Oomoo`06Ool00`00Oomoo`09Ool3000<Ool00`00Oomoo`05Ool00`00Oomoo`0VOol2
000nOol2001<Ool002Aoo`03001oogoo03aoo`03001oogoo01]oo`03001oo`0000Ioo`03001oogoo
009oo`03001oogoo00Ioo`03001oogoo00Yoo`03001oogoo00]oo`03001oogoo00Eoo`03001oogoo
02Eoo`04001oogoo000lOol01000Oomoo`00Bgoo000TOol00`00Oomoo`0mOol00`00Oomoo`0JOol0
0`00Ool00006Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`08Ool4000<Ool00`00Oomo
o`04Ool00`00Oomoo`0VOol01000Oomoo`00?7oo00@007ooOol004]oo`0097oo0P00?goo00<007oo
Ool06Goo00<007oo00001Woo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol027oo00<007oo
00003Goo00<007ooOol017oo00<007ooOol09Woo0`00?Woo0P00C7oo000TOol00`00Oomoo`0kOol0
1000Oomoo`006goo00<007oo00001Woo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol027oo
00<007oo00003Goo00<007ooOol017oo00<007ooOol09Woo00<007ooOol0?Goo00@007ooOol004]o
o`0097oo00<007ooOol0?7oo0P0077oo00@007ooOol000Eoo`03001oogoo00=oo`03001oogoo00Eo
o`03001oogoo00Uoo`8000ioo`03001oogoo00=oo`03001oogoo02Moo`<003eoo`8004aoo`0097oo
00<007ooOol0FWoo00@007ooOol000Eoo`03001oogoo00=oo`03001oogoo00Eoo`03001oogoo01Uo
o`03001oogoo00=oo`03001oogoo0;Eoo`0097oo00<007ooOol0FWoo00@007ooOol000Eoo`03001o
ogoo00=oo`03001oogoo00Eoo`03001oogoo01Uoo`03001oogoo009oo`03001oogoo0;Ioo`0097oo
00<007ooOol0FGoo00D007ooOomoo`0000Eoo`03001oogoo00=oo`03001oogoo00Eoo`03001oogoo
01Yoo`05001oogooOol0002hOol002Aoo`03001oogoo05Uoo`05001oogooOol00005Ool00`00Oomo
o`03Ool00`00Oomoo`05Ool00`00Oomoo`0JOol01@00Oomoogoo0000^7oo000TOol00`00Oomoo`02
Ool00`00Oomoo`1DOol01@00Oomoogoo00001Goo00<007ooOol00goo00<007ooOol01Goo00<007oo
Ool06Woo00@007ooOol00:]oo`8000aoo`0097oo00L007ooOomoo`00Ool0001EOol01@00Oomoogoo
00001Goo00<007ooOol00goo00<007ooOol01Goo00<007ooOol06Woo00@007ooOol00:]oo`8000ao
o`005goo1`000g`04P000g`0o`009P0027oo00@007oo000000]oo`005goo00<007ooOol017oo0g`0
0goo00@007ooOol000=oo`03001oogoo00=oo`03001oog`0009l00Qoo`03001oogoo00Yoo`03001o
ogoo00Uoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oo`0000Aoo`03001o
ogoo009oo`8000Aoo`03001oogoo00Aoo`8000aoo`03001oogoo00Uoo`03001oogoo009oo`03001o
ogoo00Eoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001o
ogoo00Yoo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Yoo`03001o
ogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Moo`04001oogoo000;Ool001Mo
o`03001oogoo00Aoo`=l00=oo`03001oo`0000Eoo`8000=oo`03001oog`0009l00Qoo`03001oogoo
00Yoo`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oo`00
00Aoo`03001oogoo009oo`8000Aoo`03001oogoo00Aoo`8000aoo`03001oogoo00Uoo`03001oogoo
00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo
00Yoo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo
00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Ioo`80009oo`8000Yoo`0097oo00<0
07oo00001goo00<007ooOol0Cgoo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol00goo00<0
07ooOol017oo00<007ooOol0f7oo000TOol00`00Oomoo`07Ool00`00Oomoo`1?Ool00`00Oomoo`02
Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`3HOol002Aoo`03001o
ogoo00Moo`03001oogoo04moo`03001oogoo009oo`05001oogooOol00006Ool00`00Oomoo`04Ool0
0`00Oomoo`3HOol002Aoo`03001oogoo00Moo`03001oogoo04moo`03001oogoo009oo`05001oogoo
Ool00006Ool00`00Oomoo`04Ool00`00Oomoo`3HOol002Aoo`03001oogoo00Qoo`03001oogoo04io
o`03001oogoo009oo`05001oogooOol00006Ool00`00Oomoo`04Ool00`00Oomoo`3HOol002Aoo`03
001oogoo00Qoo`03001oogoo04ioo`03001oogoo009oo`05001oogooOol00006Ool00`00Oomoo`04
Ool00`00Oomoo`3HOol002Aoo`03001oogoo00Qoo`03001oogoo04ioo`03001oogoo00=oo`04001o
ogoo0006Ool00`00Oomoo`04Ool00`00Oomoo`3HOol002Aoo`8000Uoo`03001oogoo04ioo`03001o
ogoo00=oo`04001oogoo0006Ool00`00Oomoo`04Ool00`00Oomoo`3HOol002Aoo`03001oogoo00Qo
o`03001oogoo04ioo`03001oogoo00=oo`04001oogoo0006Ool00`00Oomoo`04Ool00`00Oomoo`3H
Ool002Aoo`03001oogoo00Uoo`03001oogoo04eoo`03001oogoo00=oo`04001oogoo0006Ool00`00
Oomoo`04Ool00`00Oomoo`3HOol002Aoo`03001oogoo00Uoo`03001oogoo04eoo`03001oogoo00=o
o`04001oogoo0006Ool00`00Oomoo`04Ool00`00Oomoo`3HOol002Aoo`03001oogoo00Uoo`03001o
ogoo04eoo`03001oogoo00Aoo`03001oo`0000Ioo`03001oogoo00Aoo`03001oogoo0=Qoo`0097oo
00<007ooOol02Woo00<007ooOol0C7oo00<007ooOol017oo00<007oo00001Woo00<007ooOol017oo
00<007ooOol0f7oo000TOol00`00Oomoo`0:Ool00`00Oomoo`1<Ool00`00Oomoo`04Ool00`00Ool0
0006Ool00`00Oomoo`04Ool00`00Oomoo`3HOol002Aoo`03001oogoo00Yoo`03001oogoo04aoo`03
001oogoo00Eoo`8000Ioo`03001oogoo00Aoo`03001oogoo0=Qoo`0097oo00<007ooOol02Woo00<0
07ooOol0Bgoo00<007ooOol01Woo00<007ooOol01Goo00<007ooOol017oo00<007ooOol0f7oo000T
Ool00`00Oomoo`0:Ool00`00Oomoo`1;Ool00`00Oomoo`0?Ool00`00Oomoo`03Ool00`00Oomoo`3H
Ool002Aoo`8000]oo`03001oogoo04]oo`03001oogoo00moo`03001oogoo00=oo`03001oogoo0=Qo
o`0097oo00<007ooOol02goo00<007ooOol0BWoo00<007ooOol03goo00<007ooOol00goo00<007oo
Ool0f7oo000TOol00`00Oomoo`0;Ool00`00Oomoo`1:Ool00`00Oomoo`0?Ool00`00Oomoo`03Ool0
0`00Oomoo`3HOol002Aoo`03001oogoo00]oo`03001oogoo04Yoo`03001oogoo00moo`03001oogoo
00=oo`03001oogoo0=Qoo`0097oo00<007ooOol02goo00<007ooOol0BWoo00<007ooOol03goo00<0
07ooOol00goo00<007ooOol0f7oo000TOol00`00Oomoo`0;Ool00`00Oomoo`1:Ool00`00Oomoo`0?
Ool00`00Oomoo`02Ool00`00Oomoo`3IOol002Aoo`03001oogoo00aoo`03001oogoo04Uoo`03001o
ogoo00moo`03001oogoo009oo`03001oogoo0=Uoo`0097oo00<007ooOol037oo00<007ooOol0BGoo
00<007ooOol03goo00<007ooOol00Woo00<007ooOol0fGoo000TOol00`00Oomoo`0<Ool00`00Oomo
o`19Ool00`00Oomoo`0?Ool00`00Oomoo`02Ool00`00Oomoo`3IOol002Aoo`8000ioo`03001oogoo
04Qoo`03001oogoo00moo`03001oogoo009oo`03001oogoo0=Uoo`0097oo00<007ooOol03Goo00<0
07ooOol0B7oo00<007ooOol03goo00<007ooOol00Woo00<007ooOol0fGoo000TOol00`00Oomoo`0=
Ool00`00Oomoo`18Ool00`00Oomoo`0?Ool00`00Oomoo`02Ool00`00Oomoo`3IOol002Aoo`03001o
ogoo00eoo`03001oogoo04Qoo`03001oogoo00moo`03001oogoo009oo`03001oogoo0=Uoo`0097oo
00<007ooOol03Woo00<007ooOol01Woo0g`0?Woo00<007ooOol03goo00<007ooOol00Woo00<007oo
Ool0fGoo000TOol00`00Oomoo`0>Ool00`00Oomoo`06Ool3O00nOol00`00Oomoo`0?Ool00`00Oomo
o`02Ool00`00Oomoo`3IOol002Aoo`03001oogoo00ioo`03001oogoo00Ioo`=l03ioo`03001oogoo
00moo`03001oogoo009oo`03001oogoo0=Uoo`0097oo00<007ooOol03Woo00<007ooOol0Agoo00<0
07ooOol03goo00<007ooOol00Woo00<007ooOol0fGoo000TOol00`00Oomoo`0>Ool00`00Oomoo`17
Ool00`00Oomoo`0?Ool00`00Oomoo`02Ool00`00Oomoo`3IOol002Aoo`03001oogoo00moo`03001o
ogoo04Ioo`03001oogoo00moo`03001oogoo009oo`03001oogoo0=Uoo`0097oo0P0047oo00<007oo
Ool0AWoo00<007ooOol03goo00<007ooOol00Woo00<007ooOol0fGoo000TOol00`00Oomoo`0?Ool0
0`00Oomoo`16Ool00`00Oomoo`0?Ool00`00Oomoo`02Ool00`00Oomoo`3IOol002Aoo`03001oogoo
00moo`03001oogoo04Ioo`03001oogoo00moo`03001oogoo009oo`03001oogoo0=Uoo`0097oo00<0
07ooOol03goo00<007ooOol0AWoo00<007ooOol047oo00D007ooOomoo`000=]oo`0097oo00<007oo
Ool03goo00<007ooOol0AGoo00<007ooOol04Goo00D007ooOomoo`000=]oo`0097oo00<007ooOol0
3goo00<007ooOol0>goo00<007ooOol01goo00<007ooOol04Goo00D007ooOomoo`000=]oo`0097oo
00<007ooOol03goo00<007ooOol0>goo00<007ooOol01goo00<007ooOol04Goo00D007ooOomoo`00
0=]oo`0097oo00<007ooOol047oo00<007ooOol0>Goo00<007oo000027oo00<007ooOol04Goo00D0
07ooOomoo`000=]oo`0047oo0P0017oo0P000goo0`001Woo00<007ooOol047oo00<007ooOol0>Goo
00<007oo000027oo00<007ooOol04Goo00D007ooOomoo`000=]oo`003goo00@007ooOol000=oo`80
00Ioo`03001oogoo00=oo`03001oogoo011oo`03001oogoo03Uoo`03001oo`0000Qoo`03001oogoo
015oo`04001oogoo003LOol000moo`04001oogoo000;Ool00`00Oomoo`03Ool3000@Ool00`00Oomo
o`0hOol01@00Oomoogoo00001goo00<007ooOol04Goo00@007ooOol00=aoo`003goo00@007ooOol0
00Qoo`<000Ioo`03001oogoo011oo`03001oogoo03Qoo`05001oogooOol00007Ool00`00Oomoo`0A
Ool01000Oomoo`00g7oo000?Ool01000Oomoo`0027oo00<007ooOol01Woo00<007ooOol047oo00<0
07ooOol0>7oo00D007ooOomoo`0000Moo`03001oogoo015oo`04001oogoo003LOol0011oo`8000Uo
o`@000Eoo`03001oogoo011oo`03001oogoo03Qoo`03001oogoo009oo`03001oogoo00Aoo`03001o
ogoo019oo`03001oo`000=aoo`0097oo00<007ooOol047oo00<007ooOol0=goo00<007ooOol00goo
00<007ooOol017oo00<007ooOol04Woo00<007oo0000g7oo000TOol00`00Oomoo`0AOol00`00Oomo
o`0fOol00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`0BOol00`00Ool0003LOol002Aoo`03
001oogoo015oo`03001oogoo03Ioo`03001oogoo00=oo`03001oogoo00Aoo`03001oogoo019oo`03
001oo`000=aoo`0097oo00<007ooOol04Goo00<007ooOol0=Woo00<007ooOol00goo00<007ooOol0
17oo00<007ooOol04Woo00<007oo0000g7oo000TOol00`00Oomoo`0AOol00`00Oomoo`0fOol00`00
Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`0COol2003LOol002Aoo`80019oo`03001oogoo03Io
o`03001oogoo00Aoo`03001oogoo009oo`03001oogoo01Eoo`03001oogoo0=Yoo`0097oo00<007oo
Ool04Woo00<007ooOol0=Goo00<007ooOol017oo00<007ooOol00Woo00<007ooOol0lWoo000TOol0
0`00Oomoo`0BOol00`00Oomoo`0eOol00`00Oomoo`04Ool00`00Oomoo`02Ool00`00Oomoo`3bOol0
02Aoo`03001oogoo019oo`03001oogoo03Eoo`03001oogoo00Aoo`03001oogoo009oo`03001oogoo
0?9oo`0097oo00<007ooOol04Woo00<007ooOol0=7oo00<007ooOol01Goo00<007ooOol00Woo00<0
07ooOol0lWoo000TOol00`00Oomoo`0BOol00`00Oomoo`0dOol00`00Oomoo`05Ool00`00Oomoo`02
Ool00`00Oomoo`3bOol002Aoo`03001oogoo01=oo`03001oogoo03=oo`03001oogoo00Eoo`03001o
ogoo009oo`03001oogoo0?9oo`0097oo00<007ooOol04goo00<007ooOol037oo0g`027oo0g`027oo
0g`01goo0g`017oo00@007ooOomoo`=l0003Ool007oo009oo`03001oogoo00=l0?1oo`0097oo00<0
07ooOol04goo00<007ooOol037oo0g`027oo0g`027oo0g`01goo0g`017oo00@007ooOomoo`=l009o
o`04001oogoo0002Ool3O03`Ool002Aoo`03001oogoo01=oo`03001oogoo00aoo`=l00Qoo`=l00Qo
o`=l00Moo`=l00Aoo`04001oogooOol3O002Ool01000Oomoo`000Woo0g`0l7oo000TOol2000DOol0
0`00Oomoo`0cOol00`00Oomoo`06Ool01000Oomoo`00mGoo000TOol00`00Oomoo`0DOol00`00Oomo
o`0bOol00`00Oomoo`06Ool01000Oomoo`00mGoo000TOol00`00Oomoo`0DOol00`00Oomoo`0bOol0
0`00Oomoo`06Ool01000Oomoo`00mGoo000TOol00`00Oomoo`0DOol00`00Oomoo`0bOol00`00Oomo
o`06Ool01000Oomoo`00mGoo000TOol00`00Oomoo`0DOol00`00Oomoo`0aOol00`00Oomoo`07Ool0
0`00Ool0003fOol002Aoo`03001oogoo01Aoo`03001oogoo035oo`03001oogoo00Moo`03001oo`00
0?Ioo`0097oo00<007ooOol05Goo00<007ooOol04goo1@0047oo0P001Woo00<007ooOol027oo0P00
mWoo000TOol00`00Oomoo`0EOol00`00Oomoo`0BOol00`00Oomoo`02Ool00`00Oomoo`0=Ool01000
Oomoo`001Goo00<007ooOol02Goo00<007ooOol0m7oo000TOol00`00Oomoo`0EOol00`00Oomoo`0B
Ool00`00Oomoo`03Ool00`00Oomoo`0;Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`3o
Ool1Ool002Aoo`03001oogoo01Eoo`03001oogoo015oo`03001oogoo00Aoo`<000Qoo`<000Ioo`04
001oogoo003oOol4Ool002Aoo`8001Ioo`03001oogoo015oo`03001oogoo00Moo`03001oogoo00=o
o`8000Yoo`<00?moo`Aoo`0097oo00<007ooOol05Woo00<007ooOol03goo00<007ooOol02Goo00D0
07ooOomoo`0000ioo`03001oogoo0?moo`9oo`0097oo00<007ooOol05Woo00<007ooOol03goo00<0
07ooOol02Goo00@007oo00000?mooaAoo`0097oo00<007ooOol05Woo00<007ooOol03Woo00<007oo
Ool02goo00<007ooOol0ogoo57oo000TOol00`00Oomoo`0GOol00`00Oomoo`0=Ool00`00Oomoo`3o
OolROol002Aoo`03001oogoo01Moo`03001oogoo00eoo`03001oogoo0?moob9oo`0097oo00<007oo
Ool067oo0P0000=oo`0000002Goo00<007ooOol0ogoo8goo000TOol00`00Oomoo`0JOol00`00Ool0
0002Ool00`00Oomoo`04Ool00`00Oomoo`3oOolSOol002Aoo`03001oogoo01eoo`<000Ioo`03001o
ogoo0?moob=oo`0097oo0P007Woo00<007oo00001Goo00<007ooOol0ogoo97oo000TOol00`00Oomo
o`0POol00`00Oomoo`02Ool00`00Oomoo`3oOolTOol002Aoo`03001oogoo021oo`03001oogoo009o
o`03001oogoo0?moobAoo`0097oo00<007ooOol087oo00D007ooOomoo`000?moobMoo`0097oo00<0
07ooOol08Goo00<007oo0000ogoo:7oo000TOol00`00Oomoo`0ROol00`00Oomoo`3oOolWOol002Ao
o`03001oogoo0?moodaoo`0097oo00<007ooOol0ogooC7oo000TOol00`00Oomoo`3oOom<Ool002Ao
o`03001oogoo0?moodaoo`00ogooLgoo003oOomcOol00?moog=oo`00ogooLgoo003oOomcOol00;9o
o`<00;eoo`00/goo00<007ooOol0_7oo002:Ool20004Ool400000goo000000030002Ool30003Ool3
0002Ool50002Ool30003Ool00`00Oomoo`09Ool20003Ool40009Ool30002Ool500001Woo001oo`00
Ool0009oo`@008Yoo`00RWoo0P000goo00<007ooOol01Goo00D007ooOomoo`0000=oo`03001oo`00
00=oo`05001oogooOol00004Ool01000Oomoo`000Woo00<007ooOol02Goo0P001Woo00<007ooOol0
1goo00@007ooOol000=oo`0;001oogooOol007oo001oo`00Ool0002>Ool008Uoo`04001oo`000002
Ool50003Ool01@00Oomoogoo00000goo00<007oo00001goo00<007ooOol00Woo00<007ooOol00Woo
00<007oo00002Goo00@007oo0000009oo`@000Uoo`03001oogoo00Aoo`0:001oogooOol007oo001o
o`00Ool5002:Ool008Uoo`04001oogoo0002Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=o
o`03001oo`0000=oo`05001oogooOol00004Ool00`00Oomoo`02Ool00`00Ool00009Ool01000Oomo
o`000Woo00<007ooOol02Woo00<007ooOol017oo00/007ooOomoo`00Ool007oo001oo`0000=oo`03
001oogoo08Qoo`00R7oo0P000Woo0P000Woo0`0017oo00<007ooOol00Woo0`000goo10000Woo0P00
0goo100000Aoo`00001oo`8000Moo`80009oo`800003Ool00000008000Qoo`@000=oo`80009oo`H0
009oo`<008]oo`00Ugoo00<007ooOol057oo00<007ooOol08Goo00<007ooOol0WGoo002EOol3000A
Ool00`00Oomoo`02Ool00`00Oomoo`0QOol00`00Oomoo`04Ool00`00Oomoo`2FOol00?moog=oo`00
ogooLgoo003oOomcOol002=oo`<00?moodeoo`008goo00@007ooOol00?moodaoo`008goo00<007oo
Ool0ogooCGoo000SOol00`00Oomoo`3oOom=Ool0029oo`@00?moodeoo`008goo00<007ooOol0ogoo
CGoo000SOol00`00Oomoo`3oOom=Ool00?moog=oo`00\
\>"],
  ImageRangeCache->{{{0, 369}, {225, 0}} -> {-1.13501, -1.07653, 0.0310979, 
  0.0103537}}]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"Macintosh 3.0",
ScreenRectangle->{{0, 1152}, {0, 850}},
WindowToolbars->{"RulerBar", "EditBar"},
WindowSize->{520, 740},
WindowMargins->{{Automatic, 301}, {Automatic, 30}},
MacintoshSystemPageSetup->"\<\
00<0001804P000000]P2:?oQon82n@960dL5:0?l0080001804P000000]P2:001
0000I00000400`<300000BL?00400@00000000000000060801T1T000000@0000
00000000004000000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 80, 2, 98, "Title"],

Cell[CellGroupData[{
Cell[1836, 57, 25, 0, 50, "Section"],
Cell[1864, 59, 220, 4, 80, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2121, 68, 23, 0, 50, "Section"],
Cell[2147, 70, 813769, 11356, 184, 475743, 6213, "GraphicsData", 
"PostScript", "Graphics"]
}, Closed]],

Cell[CellGroupData[{
Cell[815953, 11431, 34, 0, 30, "Section"],
Cell[815990, 11433, 82779, 4668, 186, 71881, 4529, "GraphicsData", 
"PostScript", "Graphics"],

Cell[CellGroupData[{
Cell[898794, 16105, 297, 8, 132, "Input"],

Cell[CellGroupData[{
Cell[899116, 16117, 19907, 609, 186, 7511, 451, "GraphicsData", 
"PostScript", "Graphics"],
Cell[919026, 16728, 20050, 610, 186, 7513, 451, "GraphicsData", 
"PostScript", "Graphics"],
Cell[939079, 17340, 19550, 604, 186, 7511, 451, "GraphicsData", 
"PostScript", "Graphics"],
Cell[958632, 17946, 19812, 607, 186, 7514, 451, "GraphicsData", 
"PostScript", "Graphics"],
Cell[978447, 18555, 18803, 595, 186, 7509, 451, "GraphicsData", 
"PostScript", "Graphics"],
Cell[997253, 19152, 19378, 602, 186, 7513, 451, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1016634, 19756, 19070, 598, 186, 7513, 451, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1035707, 20356, 19514, 604, 186, 7515, 451, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1055224, 20962, 20578, 617, 186, 7514, 451, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1075805, 21581, 19319, 601, 186, 7507, 451, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1095127, 22184, 22187, 637, 186, 7511, 451, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1117317, 22823, 20192, 612, 186, 7513, 451, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1137512, 23437, 19463, 603, 186, 7513, 451, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1156978, 24042, 20349, 614, 186, 7516, 451, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1177330, 24658, 22155, 636, 186, 7504, 451, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1199488, 25296, 20442, 615, 186, 7512, 451, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1219933, 25913, 20000, 610, 186, 7507, 451, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1239936, 26525, 19873, 608, 186, 7506, 451, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1259812, 27135, 20012, 610, 186, 7511, 451, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1279827, 27747, 19834, 608, 186, 7503, 451, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1299664, 28357, 20347, 614, 186, 7510, 451, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1320014, 28973, 19912, 609, 186, 7516, 451, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1339929, 29584, 19825, 608, 186, 7510, 451, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1359757, 30194, 20116, 611, 186, 7506, 451, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1379876, 30807, 20449, 615, 186, 7507, 451, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1400328, 31424, 19999, 610, 186, 7514, 451, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1420330, 32036, 20425, 615, 186, 7511, 451, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1440758, 32653, 20162, 612, 186, 7515, 451, "GraphicsData", 
"PostScript", "Graphics"]
}, Closed]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[1460981, 33272, 26, 0, 30, "Section"],
Cell[1461010, 33274, 25623, 793, 234, 6756, 555, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False]
}, Closed]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

