(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    516421,      16372]*)
(*NotebookOutlinePosition[    517475,      16405]*)
(*  CellTagsIndexPosition[    517431,      16401]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Riemann Sums", "Title",
  TextAlignment->Center,
  TextJustification->0],

Cell["\<\
The code below implements the function RiemannSum. This is a \
function I wrote, not a built in function so you must run the code below for \
the function to be avaliable. The code that generates the graphics is too \
complicated for most students but the function  is easy to use.\
\>", "Text",
  FontSize->14],

Cell[CellGroupData[{

Cell["Code", "Subsection"],

Cell["\<\
Clear[RiemannSum]
Off[General::spell1]
Off[General::spell]
RiemannSum::usage=\"RiemannSum[f,{x,xmin,xmax},n] 
approximates the definite integral of f using n 
rectangles. The default method uses the left end point.
RiemannSum takes the option Method. Allowed vales for Method are 
LeftEndPoint,RightEndPoint,MidPoint and Random\";
Options[RiemannSum]={Method->LeftEndPoint};
Needs[\"Utilities`FilterOptions`\"];
Needs[\"Calculus`Limit`\"];
RiemannSum[g_[x_],{x_,a_,b_},number_,opts___Rule]:=
\tModule[{plot1,step,rectangles,opt1,h,outline,TrueArea,CurrentArea,
\tPercentError},
\topt1=Method/.{opts}/.Options[RiemannSum];
\tstep=(b-a)/number;
\tTrueArea=N[Integrate[g[x],{x,a,b}]];
\th=Which[opt1===MidPoint,1/2,opt1===LeftEndPoint,0,
\topt1===RightEndPoint,1,opt1===Random,Random[],True,0];
\trectangles=Map[Graphics,Map[
\t\t{RGBColor[1,0,0],#}&,Table[Polygon[{{a+i step,0},
\t\t{a+(i+1) step,0},{a+(i+1)step,g[a+(i+h) step]},
\t\t{a+i step,g[a+(i+h) step]}}],
\t\t{i,0,number-1,1}]]];
\toutline=Map[Graphics,
\t\tTable[{Line[{{a+i step,0},
\t\t{a+i step,g[a+(i+h) step]}}],
\t\tLine[{{a+(i+1)step,0},{a+(i+1)step,g[a+(i+h) step]}}],
\t\tLine[{{a+i step,g[a+(i+h) step]},{a+(i+1)step,g[a+(i+h) step]}}]},
\t\t\t{i,0,number-1,1}]];
\tCurrentArea=Sum[step g[a+(i+h) step],{i,0,number-1,1}];
\tPercentError=If[N[CurrentArea]==0 && N[TrueArea]==0,
\t\tUndefined,100 (1-
\t\tMin[Abs[CurrentArea],Abs[TrueArea]]/
\t\t\tMax[Abs[CurrentArea],Abs[TrueArea]])//N,Undefined];
\tplot1=Plot[g[x],{x,a,b},Evaluate[{FilterOptions[Plot,opts],
\t\tPlotStyle->{{RGBColor[0,0,1],Thickness[.007]}},PlotRange->All,
\t\tPlotLabel->If[TrueArea==0,
\t\t\tFontForm[StringJoin[\"Absolute Error = \",ToString[Chop[
\t\t\tN[CurrentArea],0.00000001]]],{\"Times\",18}],
\t\t\t\tFontForm[StringJoin[\"Percent Error = \",ToString[Chop[
\t\t\tN[PercentError],0.00000001]]] ,{\"Times\",18}],
\t\t\t\tFontForm[StringJoin[\"Percent Error = \",ToString[Chop[
\t\t\tN[PercentError],0.00000001]]],{\"Times\",18}]],
\t\tDisplayFunction->Identity}]];
\tShow[plot1,rectangles,outline,plot1,
\t\tDisplayFunction->$DisplayFunction]]
\t
\tRiemannSum[g_,{x_,a_,b_},number_,opts___Rule]:=
\tModule[{plot1,step,rectangles,outline,TrueArea,
\t\tCurrentArea,PercentError,opt1,h},
\topt1=Method/.{opts}/.Options[RiemannSum];
\tTrueArea=N[Integrate[g,{x,a,b}]];
\tstep=(b-a)/number;
\th=Which[opt1===MidPoint,1/2,opt1===LeftEndPoint,0,
\topt1===RightEndPoint,1,opt1===Random,Random[],True,0];
\trectangles=Map[Graphics,Map[
\t\t{RGBColor[1,0,0],#}&,Table[Polygon[{{a+i step,0},
\t\t{a+(i+1) step,0},{a+(i+1)step,g/.x->(a+(i+h) step)},
\t\t{a+i step,g/.x->(a+(i+h) step)}}],
\t\t{i,0,number-1,1}]]];
\toutline=Map[Graphics,
\t\tTable[{Line[{{a+i step,0},
\t\t{a+i step,g/.x->(a+(i+h) step)}}],
\t\tLine[{{a+(i+1)step,0},{a+(i+1)step,g/.x->(a+(i+h) step)}}],
\t\tLine[{{a+i step,g/.x->(a+(i+h) step)},
\t\t{a+(i+1)step,g/.x->(a+(i+h) step)}}]},
\t\t\t{i,0,number-1,1}]];
\tCurrentArea=Sum[step g/.x->(a+(i+h) step),{i,0,number-1,1}];
\tPercentError=If[N[CurrentArea]==0 && N[TrueArea]==0,Undefined,100 (1-
\t\tMin[Abs[CurrentArea],Abs[TrueArea]]/
\t\t\tMax[Abs[CurrentArea],Abs[TrueArea]])//N,Undefined];
\tplot1=Plot[g,{x,a,b},Evaluate[{FilterOptions[Plot,opts],
\t\tPlotStyle->{{RGBColor[0,0,1],Thickness[.007]}},PlotRange->All,
\t\tPlotLabel->If[TrueArea==0,
\t\t\tFontForm[StringJoin[\"Absolute Error = \",ToString[Chop[
\t\t\tN[CurrentArea],0.00000001]]],{\"Times\",18}],
\t\t\t\tFontForm[StringJoin[\"Percent Error = \",ToString[Chop[
\t\t\tN[PercentError],0.0000001]]] ,{\"Times\",18}],
\t\t\t\tFontForm[StringJoin[ \"Percent Error = \",ToString[Chop[
\t\t\tN[PercentError],0.00000001]]] ,{\"Times\",18}]],
\t\tDisplayFunction->Identity}]];
\tShow[plot1,rectangles,outline,plot1,
\t\tDisplayFunction->$DisplayFunction]]
\t\t
On[General::spell1]
On[General::spell]\
\>", "Input",
  AspectRatioFixed->True],

Cell["Typing ?RiemannSum gives the usage message.", "Text",
  FontSize->14],

Cell[CellGroupData[{

Cell["?RiemannSum", "Input"],

Cell[BoxData[
    \(TraditionalForm
    \`"RiemannSum[f,{x,xmin,xmax},n]  approximates the definite integral of f \
using n  rectangles. The default method uses the left end point. RiemannSum \
takes the option Method. Allowed vales for Method are  \
LeftEndPoint,RightEndPoint,MidPoint and Random"\)], "Print"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Using options with RiemannSum", "Subsection"],

Cell["\<\
The cells below illustrate the use of RiemannSum and the option \
Method. RiemannSum tries first to do the integral analytically and if that \
fails, switches to numerical methods.\
\>", "Text",
  FontSize->14],

Cell[CellGroupData[{

Cell[TextData["RiemannSum[x Sin[x],{x,0,2\[Pi]},6,Method->MidPoint]"], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.151576 0.44187 0.0887232 [
[.17539 .42937 -3 -9 ]
[.17539 .42937 3 0 ]
[.32696 .42937 -3 -9 ]
[.32696 .42937 3 0 ]
[.47854 .42937 -3 -9 ]
[.47854 .42937 3 0 ]
[.63011 .42937 -3 -9 ]
[.63011 .42937 3 0 ]
[.78169 .42937 -3 -9 ]
[.78169 .42937 3 0 ]
[.93327 .42937 -3 -9 ]
[.93327 .42937 3 0 ]
[.01131 .08698 -12 -4.5 ]
[.01131 .08698 0 4.5 ]
[.01131 .1757 -12 -4.5 ]
[.01131 .1757 0 4.5 ]
[.01131 .26442 -12 -4.5 ]
[.01131 .26442 0 4.5 ]
[.01131 .35315 -12 -4.5 ]
[.01131 .35315 0 4.5 ]
[.01131 .53059 -6 -4.5 ]
[.01131 .53059 0 4.5 ]
[.5 .63053 -89.5938 0 ]
[.5 .63053 89.5938 20 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.17539 .44187 m
.17539 .44812 L
s
[(1)] .17539 .42937 0 1 Mshowa
.32696 .44187 m
.32696 .44812 L
s
[(2)] .32696 .42937 0 1 Mshowa
.47854 .44187 m
.47854 .44812 L
s
[(3)] .47854 .42937 0 1 Mshowa
.63011 .44187 m
.63011 .44812 L
s
[(4)] .63011 .42937 0 1 Mshowa
.78169 .44187 m
.78169 .44812 L
s
[(5)] .78169 .42937 0 1 Mshowa
.93327 .44187 m
.93327 .44812 L
s
[(6)] .93327 .42937 0 1 Mshowa
.125 Mabswid
.05412 .44187 m
.05412 .44562 L
s
.08444 .44187 m
.08444 .44562 L
s
.11476 .44187 m
.11476 .44562 L
s
.14507 .44187 m
.14507 .44562 L
s
.2057 .44187 m
.2057 .44562 L
s
.23602 .44187 m
.23602 .44562 L
s
.26633 .44187 m
.26633 .44562 L
s
.29665 .44187 m
.29665 .44562 L
s
.35728 .44187 m
.35728 .44562 L
s
.38759 .44187 m
.38759 .44562 L
s
.41791 .44187 m
.41791 .44562 L
s
.44822 .44187 m
.44822 .44562 L
s
.50885 .44187 m
.50885 .44562 L
s
.53917 .44187 m
.53917 .44562 L
s
.56948 .44187 m
.56948 .44562 L
s
.5998 .44187 m
.5998 .44562 L
s
.66043 .44187 m
.66043 .44562 L
s
.69074 .44187 m
.69074 .44562 L
s
.72106 .44187 m
.72106 .44562 L
s
.75137 .44187 m
.75137 .44562 L
s
.81201 .44187 m
.81201 .44562 L
s
.84232 .44187 m
.84232 .44562 L
s
.87264 .44187 m
.87264 .44562 L
s
.90295 .44187 m
.90295 .44562 L
s
.96358 .44187 m
.96358 .44562 L
s
.9939 .44187 m
.9939 .44562 L
s
.25 Mabswid
0 .44187 m
1 .44187 L
s
.02381 .08698 m
.03006 .08698 L
s
[(-4)] .01131 .08698 1 0 Mshowa
.02381 .1757 m
.03006 .1757 L
s
[(-3)] .01131 .1757 1 0 Mshowa
.02381 .26442 m
.03006 .26442 L
s
[(-2)] .01131 .26442 1 0 Mshowa
.02381 .35315 m
.03006 .35315 L
s
[(-1)] .01131 .35315 1 0 Mshowa
.02381 .53059 m
.03006 .53059 L
s
[(1)] .01131 .53059 1 0 Mshowa
.125 Mabswid
.02381 .016 m
.02756 .016 L
s
.02381 .03374 m
.02756 .03374 L
s
.02381 .05149 m
.02756 .05149 L
s
.02381 .06923 m
.02756 .06923 L
s
.02381 .10472 m
.02756 .10472 L
s
.02381 .12247 m
.02756 .12247 L
s
.02381 .14021 m
.02756 .14021 L
s
.02381 .15796 m
.02756 .15796 L
s
.02381 .19344 m
.02756 .19344 L
s
.02381 .21119 m
.02756 .21119 L
s
.02381 .22893 m
.02756 .22893 L
s
.02381 .24668 m
.02756 .24668 L
s
.02381 .28217 m
.02756 .28217 L
s
.02381 .29991 m
.02756 .29991 L
s
.02381 .31766 m
.02756 .31766 L
s
.02381 .3354 m
.02756 .3354 L
s
.02381 .37089 m
.02756 .37089 L
s
.02381 .38864 m
.02756 .38864 L
s
.02381 .40638 m
.02756 .40638 L
s
.02381 .42413 m
.02756 .42413 L
s
.02381 .45961 m
.02756 .45961 L
s
.02381 .47736 m
.02756 .47736 L
s
.02381 .4951 m
.02756 .4951 L
s
.02381 .51285 m
.02756 .51285 L
s
.02381 .54834 m
.02756 .54834 L
s
.02381 .56608 m
.02756 .56608 L
s
.02381 .58383 m
.02756 .58383 L
s
.02381 .60157 m
.02756 .60157 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -150.594 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 24.000000 moveto
 558.000000 24.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 24.000000 lineto
closepath
clip newpath
63.000000 19.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 18.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 19.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 18.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Percent) show
121.250000 19.000000 moveto
(Error) show
163.625000 19.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 18.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(=) show
179.687500 19.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 18.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(4.50703) show
238.187500 19.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 18.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
0 0 1 r
.007 w
.02381 .44187 m
.02499 .44188 L
.02605 .44189 L
.02729 .44192 L
.02846 .44195 L
.03053 .44204 L
.03279 .44218 L
.03527 .44238 L
.0379 .44264 L
.04262 .44323 L
.04749 .44403 L
.05205 .44493 L
.06244 .44757 L
.07305 .45107 L
.08274 .45495 L
.10458 .46589 L
.14429 .4922 L
.18248 .52229 L
.22313 .55474 L
.26226 .58144 L
.27254 .5871 L
.28367 .59241 L
.29328 .59624 L
.29838 .59795 L
.30384 .59955 L
.30923 .60086 L
.31415 .60182 L
.31652 .6022 L
.31909 .60255 L
.32151 .60282 L
.32378 .60303 L
.32509 .60312 L
.3263 .60319 L
.32764 .60325 L
.32834 .60327 L
.32908 .60329 L
.32976 .60331 L
.33048 .60332 L
.33177 .60332 L
.33257 .60331 L
.33332 .6033 L
.33399 .60328 L
.33472 .60326 L
.33594 .60321 L
.33728 .60313 L
.33999 .60292 L
.34249 .60266 L
.34484 .60235 L
.34982 .60149 L
.35525 .60023 L
Mistroke
.36513 .59709 L
.37475 .59294 L
.38367 .58812 L
.40423 .57339 L
.42285 .55569 L
.46297 .50405 L
.50157 .43897 L
.54262 .35759 L
.58216 .27326 L
.62019 .19318 L
.66067 .11668 L
.69963 .05896 L
.70983 .04728 L
.72091 .03645 L
.73048 .02875 L
.73557 .02531 L
.74104 .02213 L
.74638 .01956 L
.75126 .01767 L
.75594 .01629 L
.75829 .01576 L
.76085 .0153 L
.76227 .01511 L
.76362 .01496 L
.76482 .01485 L
.76612 .01477 L
.7668 .01474 L
.76755 .01472 L
.76833 .01472 L
.76905 .01472 L
.77035 .01475 L
.77108 .01478 L
.77175 .01482 L
.77304 .01492 L
.77424 .01504 L
.77695 .01543 L
.77933 .0159 L
.78187 .01653 L
.78675 .0181 L
.79123 .01999 L
.80132 .02578 L
.81022 .03269 L
.81959 .04179 L
.83931 .06705 L
.85767 .09794 L
.89668 .18599 L
.93815 .30895 L
.97619 .44187 L
Mfstroke
1 0 0 r
.02381 .44187 m
.18254 .44187 L
.18254 .4651 L
.02381 .4651 L
F
.18254 .44187 m
.34127 .44187 L
.34127 .58124 L
.18254 .58124 L
F
.34127 .44187 m
.5 .44187 L
.5 .55801 L
.34127 .55801 L
F
.5 .44187 m
.65873 .44187 L
.65873 .27928 L
.5 .27928 L
F
.65873 .44187 m
.81746 .44187 L
.81746 .02377 L
.65873 .02377 L
F
.81746 .44187 m
.97619 .44187 L
.97619 .18637 L
.81746 .18637 L
F
0 g
.5 Mabswid
.02381 .44187 m
.02381 .4651 L
s
.18254 .44187 m
.18254 .4651 L
s
.02381 .4651 m
.18254 .4651 L
s
.18254 .44187 m
.18254 .58124 L
s
.34127 .44187 m
.34127 .58124 L
s
.18254 .58124 m
.34127 .58124 L
s
.34127 .44187 m
.34127 .55801 L
s
.5 .44187 m
.5 .55801 L
s
.34127 .55801 m
.5 .55801 L
s
.5 .44187 m
.5 .27928 L
s
.65873 .44187 m
.65873 .27928 L
s
.5 .27928 m
.65873 .27928 L
s
.65873 .44187 m
.65873 .02377 L
s
.81746 .44187 m
.81746 .02377 L
s
.65873 .02377 m
.81746 .02377 L
s
.81746 .44187 m
.81746 .18637 L
s
.97619 .44187 m
.97619 .18637 L
s
.81746 .18637 m
.97619 .18637 L
s
0 0 1 r
.007 w
.02381 .44187 m
.02499 .44188 L
.02605 .44189 L
.02729 .44192 L
.02846 .44195 L
.03053 .44204 L
.03279 .44218 L
.03527 .44238 L
.0379 .44264 L
.04262 .44323 L
.04749 .44403 L
.05205 .44493 L
.06244 .44757 L
.07305 .45107 L
.08274 .45495 L
.10458 .46589 L
.14429 .4922 L
.18248 .52229 L
.22313 .55474 L
.26226 .58144 L
.27254 .5871 L
.28367 .59241 L
.29328 .59624 L
.29838 .59795 L
.30384 .59955 L
.30923 .60086 L
.31415 .60182 L
.31652 .6022 L
.31909 .60255 L
.32151 .60282 L
.32378 .60303 L
.32509 .60312 L
.3263 .60319 L
.32764 .60325 L
.32834 .60327 L
.32908 .60329 L
.32976 .60331 L
.33048 .60332 L
.33177 .60332 L
.33257 .60331 L
.33332 .6033 L
.33399 .60328 L
.33472 .60326 L
.33594 .60321 L
.33728 .60313 L
.33999 .60292 L
.34249 .60266 L
.34484 .60235 L
.34982 .60149 L
.35525 .60023 L
Mistroke
.36513 .59709 L
.37475 .59294 L
.38367 .58812 L
.40423 .57339 L
.42285 .55569 L
.46297 .50405 L
.50157 .43897 L
.54262 .35759 L
.58216 .27326 L
.62019 .19318 L
.66067 .11668 L
.69963 .05896 L
.70983 .04728 L
.72091 .03645 L
.73048 .02875 L
.73557 .02531 L
.74104 .02213 L
.74638 .01956 L
.75126 .01767 L
.75594 .01629 L
.75829 .01576 L
.76085 .0153 L
.76227 .01511 L
.76362 .01496 L
.76482 .01485 L
.76612 .01477 L
.7668 .01474 L
.76755 .01472 L
.76833 .01472 L
.76905 .01472 L
.77035 .01475 L
.77108 .01478 L
.77175 .01482 L
.77304 .01492 L
.77424 .01504 L
.77695 .01543 L
.77933 .0159 L
.78187 .01653 L
.78675 .0181 L
.79123 .01999 L
.80132 .02578 L
.81022 .03269 L
.81959 .04179 L
.83931 .06705 L
.85767 .09794 L
.89668 .18599 L
.93815 .30895 L
.97619 .44187 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00O7Goo00<007ooOol0
ogoo0Goo000MOol00`00Oomoo`3oOol1Ool001eoo`03001oogoo0?moo`5oo`007Goo00<007ooOol0
]7oo1P0OAWoo000MOol2002bOol301l5Ool301m4Ool001eoo`03001oogoo09]ooa@000807`/000<0
7`D003aoo`007Goo00<007ooOol0Vgoo00<007`0O00047`000<07g`0O0003W`000D07g`0O01l0000
03aoo`007Goo00<007ooOol0Vgoo00<007`0O0003g`000<07g`0O00047`000@07g`0O00003aoo`00
7Goo0P00W7oo00<007`0O0003W`000<07g`0O0004W`000<07g`00000?7oo000MOol00`00Oomoo`2K
Ool00`00O01l000<O00201lFO0000`0O001oo`0kOol001eoo`03001oogoo09]oo`03001l07`000]l
000301ml07`001Ml000301moogoo03Yoo`007Goo00<007ooOol0Vgoo00<007`0O0002W`000<07g`0
O00067`000<07gooOol0>Woo000MOol2002LOol00`00O01l0009O0000`0OO01l000IO0000`0001mo
o`0jOol001eoo`03001oogoo09]oo`03001l07`000Ql000301ml07`001Yl0003001oo`0O03Yoo`00
7Goo00<007ooOol0Vgoo00<007`0O0001g`000<07g`0O0006g`000@007ooOol07cUoo`007Goo00<0
07ooOol0Vgoo00<007`0O0001g`000<07g`0O0006g`000D007ooOomoo`0O03Qoo`007Goo00<007oo
Ool0Vgoo00<007`0O0001W`000<07g`0O00077`000<007ooOol00Woo00<07gooOol0=Goo000MOol2
002LOol00`00O01l0005O0000`0OO01l000MO0000`00Oomoo`02Ool00`0OOomoo`0eOol001eoo`03
001oogoo09]oo`03001l07`000El000301ml07`001el0003001oogoo00=oo`0301moogoo03Aoo`00
5Woo0`0017oo00<007ooOol0Vgoo00<007`0O00017`000<07g`0O0007W`000<007ooOol017oo00<0
7gooOol0<goo000GOol00`00Oomoo`03Ool00`00Oomoo`2KOol00`00O01l0004O0000`0OO01l000N
O0000`00Oomoo`04Ool00`0OOomoo`0cOol000moo`D00003Ool00000008000Aoo`<009]oo`03001l
07`000=l000301ml07`001ml0003001oogoo00Eoo`0301moogoo039oo`005Goo00<007oo00001Goo
00<007ooOol0Vgoo00<007`0O0000W`000<07g`0O00087`000<007ooOol01Goo00<07gooOol0<Woo
000EOol00`00Ool00005Ool00`00Oomoo`2KOol00`00O01l0002O0000`0OO01l000PO0000`00Oomo
o`06Ool00`0OOomoo`0aOol001Ioo`8000Eoo`03001oogoo09]oo`05001l07`0O0007`0SO0000`00
Oomoo`07Ool00`0OOomoo`0`Ool001eoo`03001oogoo09]oo`05001l07`0O0007`0SO0000`00Oomo
o`07Ool00`0OOomoo`0`Ool001eoo`8009aoo`04001l07`001lTO0000`00Oomoo`08Ool00`0OOomo
o`0_Ool001eoo`03001oogoo09]oo`03001l000O02El0003001oogoo00Qoo`0301moogoo02moo`00
7Goo00<007ooOol0Vgoo00<007`001l09G`000<007ooOol027oo00<07gooOol0;goo000MOol00`00
Oomoo`2KOol00`0001ml000UO0000`00Oomoo`09Ool00`0OOomoo`0^Ool001eoo`8009aoo`030000
7g`002El0003001oogoo00Uoo`0301moogoo02ioo`007Goo00<007ooOol0Vgoo00<07g`0O0009G`0
00<007ooOol02Woo00<07gooOol0;Goo000MOol00`00Oomoo`2KOol00`0OO01l000UO0000`00Oomo
o`0:Ool00`0OOomoo`0]Ool001eoo`03001oogoo09Yoo`0301l007`002Il0003001oogoo00Yoo`03
01moogoo02eoo`007Goo0P00Vgoo00<07`00O0009W`000<007ooOol02goo00<07gooOol0;7oo000M
Ool00`00Oomoo`2IOol00`0OOol0000WO0000`00Oomoo`0;Ool00`0OOomoo`0/Ool001eoo`03001o
ogoo09Uoo`0301moo`0002Ml0003001oogoo00aoo`0301moogoo02]oo`007Goo00<007ooOol0V7oo
00@07gooOol002Ml0003001oogoo00aoo`0301moogoo02]oo`007Goo00<007ooOol0V7oo00@07goo
Ool002Ml0003001oogoo00eoo`0301moogoo02Yoo`007Goo0P00V7oo00D07gooOomoo`0002Ml0003
001oogoo00eoo`0301moogoo02Yoo`007Goo00<007ooOol0UWoo00<07gooOol00Woo00<007`0O000
9G`000<007ooOol03Goo00<07gooOol0:Woo000EOol30005Ool00`00Oomoo`2FOol00`0OOomoo`02
Ool00`00O01l000UO0000`00Oomoo`0>Ool00`0OOomoo`0YOol001Qoo`03001oogoo009oo`03001o
ogoo09Eoo`0301moogoo00=oo`03001l07`002El0003001oogoo00ioo`0301moogoo02Uoo`003goo
1@0017oo00<007ooOol00Woo0`00UGoo00<07gooOol00goo00<007`0O0009G`000<007ooOol03goo
00<07gooOol0:7oo000FOol20005Ool00`00Oomoo`2DOol00`0OOomoo`04Ool00`00O01l000UO000
0`00Oomoo`0?Ool00`0OOomoo`0XOol001Qoo`03001oogoo009oo`03001oogoo09Aoo`0301moogoo
00Aoo`03001l07`002El0003001oogoo00moo`0301moogoo02Qoo`005Goo0`001Goo00<007ooOol0
Tgoo00<07gooOol01Goo00<007`0O0009G`04`0000<07`0000004P005Goo000MOol00`00Oomoo`2C
Ool00`0OOomoo`05Ool00`00O01l000UO0000`00O01l000@O0000`0OO01l000AO0000`00Oomoo`0C
Ool001eoo`8009=oo`0301moogoo00Ioo`03001l07`002El0003001l07`0015l000301ml07`0011l
0003001oogoo01=oo`007Goo00<007ooOol0TWoo00<07gooOol01Woo00<007`0O0009G`000<007`0
O0004G`000<07g`0O00047`000<007ooOol04goo000MOol00`00Oomoo`2AOol00`0OOomoo`07Ool0
0`00O01l000UO0000`00O01l000AO0000`0OO01l000@O0000`00Oomoo`0COol001eoo`03001oogoo
095oo`0301moogoo00Moo`03001l07`002El0003001l07`0019l000301ml07`000ml0003001oogoo
01=oo`007Goo0P00TGoo00<07gooOol027oo00<007`0O0009G`000<007`0O0004W`000<07g`0O000
3g`000<007ooOol04goo000MOol00`00Oomoo`2@Ool00`0OOomoo`08Ool00`00O01l000UO0000`00
O01l000BO0000`0OO01l000?O0000`00Oomoo`0COol001eoo`03001oogoo08moo`0301moogoo00Uo
o`03001l07`002El0003001l07`001=l000301ml07`000il0003001oogoo01=oo`007Goo00<007oo
Ool0Sgoo00<07gooOol02Goo00<007`0O0009G`000<007`0O0004g`000<07g`0O0003W`000<007oo
Ool04goo000MOol00`00Oomoo`2>Ool00`0OOomoo`0:Ool00`00O01l000UO0000`00O01l000CO000
0`0OO01l000>O0000`00Oomoo`0COol001eoo`8008moo`0301moogoo00Yoo`03001l07`002El0003
001l07`001Al000301ml07`000el0003001oogoo01=oo`007Goo00<007ooOol0SGoo00<07gooOol0
2goo00<007`0O0009G`000<007`0O00057`000<07g`0O0003G`000<007ooOol04goo000MOol00`00
Oomoo`2=Ool00`0OOomoo`0;Ool00`00O01l000UO0000`00O01l000EO0000`0OO01l000<O0000`00
Oomoo`0COol001eoo`03001oogoo08aoo`0301moogoo00aoo`03001l07`002El0003001l07`001El
000301ml07`000al0003001oogoo01=oo`007Goo0P00SGoo00<07gooOol037oo00<007`0O0009G`0
00<007`0O0005G`000<07g`0O00037`000<007ooOol04goo000MOol00`00Oomoo`2;Ool00`0OOomo
o`0=Ool00`00O01l000UO0000`00O01l000FO0000`0OO01l000;O0000`00Oomoo`0COol001Eoo`@0
00Aoo`03001oogoo08]oo`0301moogoo00eoo`03001l07`002El0003001l07`001Il000301ml07`0
00]l0003001oogoo01=oo`005Woo00<007ooOol017oo00<007ooOol0RWoo00<07gooOol03Woo00<0
07`0O0009G`000<007`0O0005W`000<07g`0O0002g`000<007ooOol04goo000?Ool50003Ool00`00
Oomoo`03Ool3002:Ool00`0OOomoo`0>Ool00`00O01l000UO0000`00O01l000GO0000`0OO01l000:
O0000`00Oomoo`0COol001Qoo`03001oogoo009oo`03001oogoo08Uoo`0301moogoo00moo`03001l
07`002El0003001l07`001Ml000301ml07`000Yl0003001oogoo01=oo`005Goo00@007ooOol000Ao
o`03001oogoo08Uoo`0301moogoo00moo`03001l07`002El0003001l07`001Ql000301ml07`000Ul
0003001oogoo01=oo`005Woo0P001Goo00<007ooOol0R7oo00<07gooOol047oo00<007`0O0009G`0
00<007`0O00067`000<07g`0O0002G`000<007ooOol04goo000MOol00`00Oomoo`1dOolD00000`0O
0000000A000WO0000`00O01l000HO0000`0OO01l0009O0000`00Oomoo`0COol001eoo`8007Eoo`03
001l07`0011l000301ml07`0015l0003001l07`002El0003001l07`001Ul000301ml07`000Ql0003
001oogoo01=oo`007Goo00<007ooOol0M7oo00<007`0O00047`000<07g`0O0004G`000<007`0O000
9G`000<007`0O0006G`000<07g`0O00027`000<007ooOol04goo000MOol00`00Oomoo`1dOol00`00
O01l000?O0000`0OO01l000BO0000`00O01l000UO0000`00O01l000IO0000`0OO01l0008O0000`00
Oomoo`0COol001eoo`03001oogoo07Aoo`03001l07`000ml000301ml07`0019l0003001l07`002El
0003001l07`001Yl000301ml07`000Ml0003001oogoo01=oo`007Goo0P00MGoo00<007`0O0003W`0
00<07g`0O0004g`000<007`0O0009G`000<007`0O0006W`000<07g`0O0001g`000<007ooOol04goo
000MOol00`00Oomoo`1dOol00`00O01l000>O0000`0OO01l000CO0000`00O01l000UO0000`00O01l
000JO0000`0OO01l0007O0000`00Oomoo`0COol001eoo`03001oogoo07Aoo`03001l07`000el0003
01ml07`001Al0003001l07`002El0003001l07`001]l000301ml07`000Il0003001oogoo01=oo`00
7Goo00<007ooOol0M7oo00<007`0O0003G`000<07g`0O00057`000<007`0O0009G`000<007`0O000
6g`000<07g`0O0001W`000<007ooOol04goo000MOol00`00Oomoo`1dOol00`00O01l000<O0000`0O
O01l000EO0000`00O01l000UO0000`00O01l000KO0000`0OO01l0006O0000`00Oomoo`0COol001eo
o`8007Eoo`03001l07`000al000301ml07`001El0003001l07`002El0003001l07`001al000301ml
07`000El0003001oogoo01=oo`007Goo00<007ooOol0M7oo00<007`0O00037`000<07g`0O0005G`0
00<007`0O0009G`000<007`0O00077`000<07g`0O0001G`000<007ooOol04goo000MOol00`00Oomo
o`1dOol00`00O01l000;O0000`0OO01l000FO0000`00O01l000UO0000`00O01l000LO0000`0OO01l
0005O0000`00Oomoo`0COol001eoo`03001oogoo07Aoo`03001l07`000]l000301ml07`001Il0003
001l07`002El0003001l07`001al000301ml07`000El0003001oogoo01=oo`007Goo0P00MGoo00<0
07`0O0002W`000<07g`0O0005g`000<007`0O0009G`000<007`0O0007G`000<07g`0O00017`000<0
07ooOol04goo000MOol00`00Oomoo`1dOol00`00O01l000:O0000`0OO01l000GO0000`00O01l000U
O0000`00O01l000MO0000`0OO01l0004O0000`00Oomoo`0COol001Eoo`<000Eoo`03001oogoo07Ao
o`03001l07`000Ul000301ml07`001Ql0003001l07`002El0003001l07`001el000301ml07`000Al
0003001oogoo01=oo`005Woo00<007ooOol017oo00<007ooOol0M7oo00<007`0O0002G`000<07g`0
O00067`000<007`0O0009G`000<007`0O0007W`000<07g`0O0000g`000<007ooOol04goo000?Ool5
0002Ool00`00Oomoo`04Ool3001dOol00`00O01l0008O0000`0OO01l000IO0000`00O01l000UO000
0`00O01l000NO0000`0OO01l0003O0000`00Oomoo`0COol001Ioo`03001oogoo00Aoo`03001oogoo
07Aoo`03001l07`000Ql000301ml07`001Ul0003001l07`002El0003001l07`001il000301ml07`0
00=l0003001oogoo01=oo`005Woo00<007ooOol017oo00<007ooOol0M7oo00<007`0O0001g`000<0
7g`0O0006W`000<007`0O0009G`000<007`0O0007W`000<07g`0O0000g`000<007ooOol04goo000E
Ool20006Ool00`00Oomoo`1dOol00`00O01l0007O0000`0OO01l000JO0000`00O01l000UO0000`00
O01l000OO0000`0OO01l0002O0000`00Oomoo`0COol001eoo`03001oogoo07Aoo`03001l07`000Il
000301ml07`001]l0003001l07`002El0003001l07`001ml000301ml07`0009l0003001oogoo01=o
o`007Goo0P00MGoo00<007`0O0001W`000<07g`0O0006g`000<007`0O0009G`000<007`0O0007g`0
00<07g`0O0000W`000<007ooOol04goo000MOol00`00Oomoo`1dOol00`00O01l0005O0000`0OO01l
000LO0000`00O01l000UO0000`00O01l000OO0000`0OO01l0002O0000`00Oomoo`0COol001eoo`03
001oogoo07Aoo`03001l07`000El000301ml07`001al0003001l07`002El0003001l07`0021l0005
01ml07`0O000000EOol001eoo`03001oogoo07Aoo`03001l07`000Al000301ml07`001el0003001l
07`002El0003001l07`0021l000501ml07`0O000000EOol001eoo`8007Eoo`03001l07`000Al0003
01ml07`001el0003001l07`002El0003001l07`0021l000501ml07`0O000000EOol001eoo`03001o
ogoo07Aoo`03001l07`000=l000301ml07`001il0003001l07`002El0003001l07`0021l000501ml
07`0O000000EOol001eoo`03001oogoo07Aoo`03001l07`000=l000301ml07`001il0003001l07`0
02El0003001l07`0025l000401ml07`0000EOol001eoo`03001oogoo025oo`<002=oo`@0025oo`<0
00Eoo`03001l07`0009l000301ml07`001ml0003001l07`002El0003001l07`0025l000401ml07`0
000EOol001eoo`03001oogoo029oo`03001oogoo02=oo`03001oogoo02Aoo`03001oogoo009oo`03
001l07`0009l000301ml07`001ml0003001l07`002El0003001l07`0025l000401ml07`0000EOol0
01eoo`8002=oo`03001oogoo02Aoo`03001oogoo02=oo`03001oogoo009oo`05001l07`0O0007`0R
O0000`00O01l000UO0000`00O01l000QO000100OO01l00005Goo000MOol00`00Oomoo`0ROol00`00
Oomoo`0UOol00`00Oomoo`0POol20005Ool01@00O01l07`001l08W`000<007`0O0009G`000<007`0
O0008W`000<07g`000005Goo000MOol00`00Oomoo`0ROol00`00Oomoo`0ROol01000Oomoo`0097oo
00<007ooOol00Woo00@007`0O0007b=l0003001l07`002El0003001l07`0029l000301ml000001Eo
o`007Goo00<007ooOol08Goo0P009Goo0P008Woo0`001Goo00@007`0O0007b=l0003001l07`002El
0003001l07`0029l000301ml000001Eoo`007Goo0P00MGoo00<007`001l097`000<007`0O0009G`0
00<007`0O0008g`000<07`00Ool057oo000MOol00`00Oomoo`1dOol00`00O0007`0TO0000`00O01l
000UO0000`00O01l000SO0000`0O001oo`0DOol001eoo`03001oogoo07Aoo`0300007g`002Al0003
001l07`002El0003001l07`002=l000301l007oo01Aoo`007Goo00<007ooOol0M7oo00<0000OO000
97`000<007`0O0009G`000<007`0O0008g`000<07`00Ool057oo000MOol00`00Oomoo`1dOol00`0O
O01l000TO0000`00O01l000UO0000`00O01l000TO0000`0OOomoo`0COol001Moo`H000X07fd00003
01ml07`002Al0003001l07`002El0003001l07`002Al000301l0000000@000moo`007Goo00<007`0
O0001g`00P0O77`000<007`0O00097`000<007`0O00097`000<07`00Ool07Woo00<007ooOol08goo
00<007ooOol08Woo00<007ooOol07Woo000MOol00`00O01l0009O00301lIO0000`00O01l000TO000
0`00O01l000SO0000`0OO000002;Ool001eoo`03001l07`000al00807aMl0003001l07`002Al0003
001l07`002=l000301ml000008]oo`007Goo00<007`0O0003W`00P0O5G`000<007`0O00097`000<0
07`0O0008W`000@07g`0O00008]oo`007Goo4`0000<07`0000004`009W`000<007`0O0008W`000@0
7g`0O00008]oo`007Goo00<007ooOol04Goo0P0O4Woo00<007`0O00097`000<007`0O0008G`000D0
7g`0O01l000008]oo`007Goo00<007ooOol04goo0P0O47oo00<007`0O00097`000<007`0O00087`0
00<07g`0O0000W`000<007ooOol0RGoo000MOol2000FOol00`0OOomoo`0=Ool00`00O01l000TO000
0`00O01l000PO0000`0OO01l0002O0000`00Oomoo`29Ool001eoo`03001oogoo01Ioo`807`eoo`03
001l07`002Al0003001l07`001ml000301ml07`000=l0003001oogoo08Uoo`007Goo00<007ooOol0
67oo0P0O2goo00<007`0O00097`000<007`0O0007W`000<07g`0O00017`000<007ooOol0RGoo000M
Ool00`00Oomoo`0JOol00`0OOomoo`08Ool00`00O01l000TO0000`00O01l000NO0000`0OO01l0004
O0000`00Oomoo`29Ool001eoo`03001oogoo01]oo`807`Qoo`03001l07`002Al0003001l07`001el
000301ml07`000El0003001oogoo08Uoo`007Goo0P007Woo00<07gooOol01Goo00<007`0O00097`0
00<007`0O0007G`000<07g`0O0001G`000<007ooOol0RGoo000MOol00`00Oomoo`0NOol00`0OOomo
o`04Ool00`00O01l000TO0000`00O01l000LO0000`0OO01l0006O0000`00Oomoo`29Ool001eoo`03
001oogoo01moo`0301moogoo00=oo`03001l07`002Al0003001l07`001]l000301ml07`000Ml0003
001oogoo08Uoo`007Goo00<007ooOol087oo0P0O0goo00<007`0O00097`000<007`0O0006g`000<0
7g`0O0001g`000<007ooOol0RGoo000MOol2000SOol0100OOomoo`009W`000<007`0O0006W`000<0
7g`0O00027`000<007ooOol0RGoo000MOol00`00Oomoo`0SOol00`0OOol0000VO0000`00O01l000I
O0000`0OO01l0009O0000`00Oomoo`29Ool001eoo`03001oogoo02Aoo`0301l007`002El0003001l
07`001Ql000301ml07`000Yl0003001oogoo08Uoo`005Goo0`001Goo00<007ooOol09Goo0P0O9G`0
00<007`0O00067`000<07g`0O0002W`000<007ooOol0RGoo000FOol00`00Oomoo`04Ool00`00Oomo
o`0UOol00`00O0007`0TO0000`00O01l000GO0000`0OO01l000;O0000`00Oomoo`29Ool001Ioo`03
001oogoo00Aoo`<002Eoo`04001l07`001lSO0000`00O01l000FO0000`0OO01l000<O0000`00Oomo
o`29Ool001Ioo`03001oogoo00Aoo`03001oogoo02Eoo`05001l07`0O0007`0RO0000`00O01l000E
O0000`0OO01l000=O0000`00Oomoo`29Ool001Ioo`03001oogoo00Aoo`03001oogoo02Eoo`03001l
07`0009l00807b1l0003001l07`001Al000301ml07`000il0003001oogoo08Uoo`005Goo0P001Woo
00<007ooOol09Goo00<007`0O00017`000<07g`0O0007G`000<007`0O00057`000<07g`0O0003W`0
00<007ooOol0RGoo000MOol2000VOol00`00O01l0005O0000`0OO01l000LO0000`00O01l000CO000
0`0OO01l000?O0000`00Oomoo`29Ool001eoo`03001oogoo02Eoo`03001l07`000Il000301ml07`0
01]l0003001l07`0019l000301ml07`0011l0003001oogoo08Uoo`007Goo00<007ooOol09Goo00<0
07`0O0001g`00P0O6g`0500000<07`0000004P00Rgoo000MOol00`00Oomoo`0UOol00`00O01l0009
O0000`0OO01l000HO0000`00Oomoo`0@Ool00`0OOomoo`2NOol001eoo`8002Ioo`03001l07`000Yl
00807aQl0003001oogoo00moo`0301moogoo09moo`007Goo00<007ooOol09Goo00<007`0O00037`0
00<07g`0O0005G`000<007ooOol03Woo00<07gooOol0X7oo000MOol00`00Oomoo`0UOol00`00O01l
000=O00201lEO0000`00Oomoo`0<Ool201nSOol001eoo`03001oogoo02Eoo`03001l07`000ml0003
01ml07`0019l0003001oogoo00]oo`0301moogoo0:=oo`007Goo00<007ooOol09Goo4`000P0O4`00
37oo00<07gooOol0Y7oo000MOol2000kOol00`0OOomoo`0KOol00`0OOomoo`2UOol001eoo`03001o
ogoo03]oo`<07aQoo`807jQoo`007Goo00<007ooOol0?Woo0P0O4goo0`0OZWoo000MOol00`00Oomo
o`10Ool301l>Ool201n]Ool001eoo`8004Aoo`@07`Ioo`@07jmoo`007Goo00<007ooOol0Agoo1P0O
/goo000MOol00`00Oomoo`3oOol1Ool001eoo`03001oogoo0?moo`5oo`007Goo00<007ooOol0ogoo
0Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol0
0?moob5oo`00?7oo1P001Woo0`000goo100017oo0`001Goo0`000goo100000=oo`0000000P000Woo
0P001Goo2P0000=oo`0000000P000Woo100017oo10000goo100077oo0P000goo0P000Woo1@001Woo
10001Woo00<007ooOol01Goo10000goo1@00>7oo000nOol20007Ool20002Ool01000Oomoogoo0P00
17oo0P000Woo00@007ooOomoo`80009oo`04001oogooOol20003Ool20002Ool200000goo001oo`05
Ool20005Ool200000goo00000004Ool20004Ool20002Ool20003Ool2000MOol20003Ool20002Ool2
0003Ool20003Ool20002Ool20005Ool20005Ool20002Ool20002Ool20003Ool2000fOol003ioo`80
00Ioo`8000Aoo`03001oogoo008000=oo`8000Aoo`04001oo`000004Ool00`00Oomoo`020003Ool2
0002Ool20008Ool20006Ool01000Ool0000017oo0P000goo0P0017oo0P000Woo0P002Goo2@002goo
0P003Goo00D007ooOomoo`0000Aoo`03001oogoo00Aoo`03001oogoo00=oo`03001oogoo009oo`03
001oogoo00Ioo`03001oogoo03Aoo`00?Woo0P001Woo0P001goo0P000goo0P001Woo0P001goo0P00
0goo0P000Woo0P0027oo0P0027oo0P0017oo0P000goo0P0017oo0P000Woo0P0067oo2@002goo0P00
00=oo`00000017oo0P001Goo00<007ooOol00Woo0P0017oo0P001goo0P00=Goo000nOol20006Ool2
0007Ool20003Ool20006Ool20007Ool20003Ool20002Ool20008Ool20004Ool01000Oomoogoo0P00
17oo0P000goo0P0017oo0P000Woo0P0067oo00<007ooOol00Woo0P003Goo0P0000=oo`00000017oo
0P001Goo00<007ooOol00Woo0P0017oo0P001goo0P00=Goo000nOol60002Ool70002Ool20003Ool2
0004Ool00`00Ool000060002Ool20003Ool20002Ool20008Ool20004Ool01000Oomoogoo0P0017oo
0P000goo0P0017oo0P000Woo0P006Goo00@007ooOomoo`8000aoo`<00003Ool0000000Aoo`8000Io
o`04001oogooOol20004Ool20007Ool2000eOol003ioo`8000=oo`80009oo`04001oogooOol20000
0goo0000000400000goo00000002Ool20002Ool01000Oomoogoo0P0000=oo`0000000P000Woo0P00
0Woo0P0027oo1`000Woo300000=oo`0000000Woo0P000Woo1P001Woo2@0027oo00<007ooOol00P00
2Woo10000Woo0P0017oo0P001Woo00@007ooOomoo`8000Aoo`8000Ioo`<003Eoo`00?Woo0P0017oo
0P000Woo100017oo00@007oo0000009oo`@000Aoo`@000Aoo`03001oo`000080009oo`D000Ioo`80
00Aoo`03001oogoo009oo`04001oo`000002Ool01000Ool000000Woo10001Goo00@007oo000001Mo
o`03001oogoo008000Moo`H000=oo`8000Aoo`8000Ioo`04001oogooOol20004Ool20003Ool5000f
Ool003ioo`8000Aoo`8002Qoo`8000Qoo`8000Aoo`03001oogoo03=oo`04001oo`000008Ool40004
Ool20004Ool20007Ool00`00Oomoo`020004Ool20005Ool00`00Oomoo`0fOol003ioo`8000Aoo`80
02Uoo`03001oogoo00Ioo`8003]oo`<000Qoo`03001oogoo00Eoo`8000Aoo`8000Moo`03001oogoo
008000Aoo`8000Ioo`03001oogoo03Eoo`00?Woo0P0017oo0P00<Woo0P001Goo00<007ooOol0<goo
0`002Goo00<007ooOol01Goo00<007ooOol00Woo00<007ooOol00P0017oo00D007ooOomoo`0000Ao
o`04001oogoo0004Ool2000fOol003ioo`8000=oo`8003=oo`8000Eoo`03001oogoo03Aoo`8000Uo
o`D000=oo`80009oo`8000=oo`L0009oo`80009oo`8000=oo`03001oogoo00<003Ioo`00?7oo2000
<Woo2P00=Woo0P002Goo1P000goo100017oo1`000goo10001Goo1000=goo003oOolQOol00?moob5o
o`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.783823, -4.98036, 
  0.0265065, 0.0452841}}],

Cell[BoxData[
    FormBox[
      TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
        False,
        Editable->False], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"RiemannSum[x Sin[x],{x,0,2\[Pi]},6,Method->LeftEndPoint]"], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.151576 0.44187 0.0887232 [
[.17539 .42937 -3 -9 ]
[.17539 .42937 3 0 ]
[.32696 .42937 -3 -9 ]
[.32696 .42937 3 0 ]
[.47854 .42937 -3 -9 ]
[.47854 .42937 3 0 ]
[.63011 .42937 -3 -9 ]
[.63011 .42937 3 0 ]
[.78169 .42937 -3 -9 ]
[.78169 .42937 3 0 ]
[.93327 .42937 -3 -9 ]
[.93327 .42937 3 0 ]
[.01131 .08698 -12 -4.5 ]
[.01131 .08698 0 4.5 ]
[.01131 .1757 -12 -4.5 ]
[.01131 .1757 0 4.5 ]
[.01131 .26442 -12 -4.5 ]
[.01131 .26442 0 4.5 ]
[.01131 .35315 -12 -4.5 ]
[.01131 .35315 0 4.5 ]
[.01131 .53059 -6 -4.5 ]
[.01131 .53059 0 4.5 ]
[.5 .63053 -89.5938 0 ]
[.5 .63053 89.5938 20 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.17539 .44187 m
.17539 .44812 L
s
[(1)] .17539 .42937 0 1 Mshowa
.32696 .44187 m
.32696 .44812 L
s
[(2)] .32696 .42937 0 1 Mshowa
.47854 .44187 m
.47854 .44812 L
s
[(3)] .47854 .42937 0 1 Mshowa
.63011 .44187 m
.63011 .44812 L
s
[(4)] .63011 .42937 0 1 Mshowa
.78169 .44187 m
.78169 .44812 L
s
[(5)] .78169 .42937 0 1 Mshowa
.93327 .44187 m
.93327 .44812 L
s
[(6)] .93327 .42937 0 1 Mshowa
.125 Mabswid
.05412 .44187 m
.05412 .44562 L
s
.08444 .44187 m
.08444 .44562 L
s
.11476 .44187 m
.11476 .44562 L
s
.14507 .44187 m
.14507 .44562 L
s
.2057 .44187 m
.2057 .44562 L
s
.23602 .44187 m
.23602 .44562 L
s
.26633 .44187 m
.26633 .44562 L
s
.29665 .44187 m
.29665 .44562 L
s
.35728 .44187 m
.35728 .44562 L
s
.38759 .44187 m
.38759 .44562 L
s
.41791 .44187 m
.41791 .44562 L
s
.44822 .44187 m
.44822 .44562 L
s
.50885 .44187 m
.50885 .44562 L
s
.53917 .44187 m
.53917 .44562 L
s
.56948 .44187 m
.56948 .44562 L
s
.5998 .44187 m
.5998 .44562 L
s
.66043 .44187 m
.66043 .44562 L
s
.69074 .44187 m
.69074 .44562 L
s
.72106 .44187 m
.72106 .44562 L
s
.75137 .44187 m
.75137 .44562 L
s
.81201 .44187 m
.81201 .44562 L
s
.84232 .44187 m
.84232 .44562 L
s
.87264 .44187 m
.87264 .44562 L
s
.90295 .44187 m
.90295 .44562 L
s
.96358 .44187 m
.96358 .44562 L
s
.9939 .44187 m
.9939 .44562 L
s
.25 Mabswid
0 .44187 m
1 .44187 L
s
.02381 .08698 m
.03006 .08698 L
s
[(-4)] .01131 .08698 1 0 Mshowa
.02381 .1757 m
.03006 .1757 L
s
[(-3)] .01131 .1757 1 0 Mshowa
.02381 .26442 m
.03006 .26442 L
s
[(-2)] .01131 .26442 1 0 Mshowa
.02381 .35315 m
.03006 .35315 L
s
[(-1)] .01131 .35315 1 0 Mshowa
.02381 .53059 m
.03006 .53059 L
s
[(1)] .01131 .53059 1 0 Mshowa
.125 Mabswid
.02381 .016 m
.02756 .016 L
s
.02381 .03374 m
.02756 .03374 L
s
.02381 .05149 m
.02756 .05149 L
s
.02381 .06923 m
.02756 .06923 L
s
.02381 .10472 m
.02756 .10472 L
s
.02381 .12247 m
.02756 .12247 L
s
.02381 .14021 m
.02756 .14021 L
s
.02381 .15796 m
.02756 .15796 L
s
.02381 .19344 m
.02756 .19344 L
s
.02381 .21119 m
.02756 .21119 L
s
.02381 .22893 m
.02756 .22893 L
s
.02381 .24668 m
.02756 .24668 L
s
.02381 .28217 m
.02756 .28217 L
s
.02381 .29991 m
.02756 .29991 L
s
.02381 .31766 m
.02756 .31766 L
s
.02381 .3354 m
.02756 .3354 L
s
.02381 .37089 m
.02756 .37089 L
s
.02381 .38864 m
.02756 .38864 L
s
.02381 .40638 m
.02756 .40638 L
s
.02381 .42413 m
.02756 .42413 L
s
.02381 .45961 m
.02756 .45961 L
s
.02381 .47736 m
.02756 .47736 L
s
.02381 .4951 m
.02756 .4951 L
s
.02381 .51285 m
.02756 .51285 L
s
.02381 .54834 m
.02756 .54834 L
s
.02381 .56608 m
.02756 .56608 L
s
.02381 .58383 m
.02756 .58383 L
s
.02381 .60157 m
.02756 .60157 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -150.594 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 24.000000 moveto
 558.000000 24.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 24.000000 lineto
closepath
clip newpath
63.000000 19.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 18.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 19.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 18.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Percent) show
121.250000 19.000000 moveto
(Error) show
163.625000 19.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 18.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(=) show
179.687500 19.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 18.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(9.31003) show
238.187500 19.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 18.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
0 0 1 r
.007 w
.02381 .44187 m
.02499 .44188 L
.02605 .44189 L
.02729 .44192 L
.02846 .44195 L
.03053 .44204 L
.03279 .44218 L
.03527 .44238 L
.0379 .44264 L
.04262 .44323 L
.04749 .44403 L
.05205 .44493 L
.06244 .44757 L
.07305 .45107 L
.08274 .45495 L
.10458 .46589 L
.14429 .4922 L
.18248 .52229 L
.22313 .55474 L
.26226 .58144 L
.27254 .5871 L
.28367 .59241 L
.29328 .59624 L
.29838 .59795 L
.30384 .59955 L
.30923 .60086 L
.31415 .60182 L
.31652 .6022 L
.31909 .60255 L
.32151 .60282 L
.32378 .60303 L
.32509 .60312 L
.3263 .60319 L
.32764 .60325 L
.32834 .60327 L
.32908 .60329 L
.32976 .60331 L
.33048 .60332 L
.33177 .60332 L
.33257 .60331 L
.33332 .6033 L
.33399 .60328 L
.33472 .60326 L
.33594 .60321 L
.33728 .60313 L
.33999 .60292 L
.34249 .60266 L
.34484 .60235 L
.34982 .60149 L
.35525 .60023 L
Mistroke
.36513 .59709 L
.37475 .59294 L
.38367 .58812 L
.40423 .57339 L
.42285 .55569 L
.46297 .50405 L
.50157 .43897 L
.54262 .35759 L
.58216 .27326 L
.62019 .19318 L
.66067 .11668 L
.69963 .05896 L
.70983 .04728 L
.72091 .03645 L
.73048 .02875 L
.73557 .02531 L
.74104 .02213 L
.74638 .01956 L
.75126 .01767 L
.75594 .01629 L
.75829 .01576 L
.76085 .0153 L
.76227 .01511 L
.76362 .01496 L
.76482 .01485 L
.76612 .01477 L
.7668 .01474 L
.76755 .01472 L
.76833 .01472 L
.76905 .01472 L
.77035 .01475 L
.77108 .01478 L
.77175 .01482 L
.77304 .01492 L
.77424 .01504 L
.77695 .01543 L
.77933 .0159 L
.78187 .01653 L
.78675 .0181 L
.79123 .01999 L
.80132 .02578 L
.81022 .03269 L
.81959 .04179 L
.83931 .06705 L
.85767 .09794 L
.89668 .18599 L
.93815 .30895 L
.97619 .44187 L
Mfstroke
1 0 0 r
.02381 .44187 m
.18254 .44187 L
.18254 .44187 L
.02381 .44187 L
F
.18254 .44187 m
.34127 .44187 L
.34127 .52233 L
.18254 .52233 L
F
.34127 .44187 m
.5 .44187 L
.5 .6028 L
.34127 .6028 L
F
.5 .44187 m
.65873 .44187 L
.65873 .44187 L
.5 .44187 L
F
.65873 .44187 m
.81746 .44187 L
.81746 .12002 L
.65873 .12002 L
F
.81746 .44187 m
.97619 .44187 L
.97619 .03955 L
.81746 .03955 L
F
0 g
.5 Mabswid
.02381 .44187 m
.02381 .44187 L
s
.18254 .44187 m
.18254 .44187 L
s
.02381 .44187 m
.18254 .44187 L
s
.18254 .44187 m
.18254 .52233 L
s
.34127 .44187 m
.34127 .52233 L
s
.18254 .52233 m
.34127 .52233 L
s
.34127 .44187 m
.34127 .6028 L
s
.5 .44187 m
.5 .6028 L
s
.34127 .6028 m
.5 .6028 L
s
.5 .44187 m
.5 .44187 L
s
.65873 .44187 m
.65873 .44187 L
s
.5 .44187 m
.65873 .44187 L
s
.65873 .44187 m
.65873 .12002 L
s
.81746 .44187 m
.81746 .12002 L
s
.65873 .12002 m
.81746 .12002 L
s
.81746 .44187 m
.81746 .03955 L
s
.97619 .44187 m
.97619 .03955 L
s
.81746 .03955 m
.97619 .03955 L
s
0 0 1 r
.007 w
.02381 .44187 m
.02499 .44188 L
.02605 .44189 L
.02729 .44192 L
.02846 .44195 L
.03053 .44204 L
.03279 .44218 L
.03527 .44238 L
.0379 .44264 L
.04262 .44323 L
.04749 .44403 L
.05205 .44493 L
.06244 .44757 L
.07305 .45107 L
.08274 .45495 L
.10458 .46589 L
.14429 .4922 L
.18248 .52229 L
.22313 .55474 L
.26226 .58144 L
.27254 .5871 L
.28367 .59241 L
.29328 .59624 L
.29838 .59795 L
.30384 .59955 L
.30923 .60086 L
.31415 .60182 L
.31652 .6022 L
.31909 .60255 L
.32151 .60282 L
.32378 .60303 L
.32509 .60312 L
.3263 .60319 L
.32764 .60325 L
.32834 .60327 L
.32908 .60329 L
.32976 .60331 L
.33048 .60332 L
.33177 .60332 L
.33257 .60331 L
.33332 .6033 L
.33399 .60328 L
.33472 .60326 L
.33594 .60321 L
.33728 .60313 L
.33999 .60292 L
.34249 .60266 L
.34484 .60235 L
.34982 .60149 L
.35525 .60023 L
Mistroke
.36513 .59709 L
.37475 .59294 L
.38367 .58812 L
.40423 .57339 L
.42285 .55569 L
.46297 .50405 L
.50157 .43897 L
.54262 .35759 L
.58216 .27326 L
.62019 .19318 L
.66067 .11668 L
.69963 .05896 L
.70983 .04728 L
.72091 .03645 L
.73048 .02875 L
.73557 .02531 L
.74104 .02213 L
.74638 .01956 L
.75126 .01767 L
.75594 .01629 L
.75829 .01576 L
.76085 .0153 L
.76227 .01511 L
.76362 .01496 L
.76482 .01485 L
.76612 .01477 L
.7668 .01474 L
.76755 .01472 L
.76833 .01472 L
.76905 .01472 L
.77035 .01475 L
.77108 .01478 L
.77175 .01482 L
.77304 .01492 L
.77424 .01504 L
.77695 .01543 L
.77933 .0159 L
.78187 .01653 L
.78675 .0181 L
.79123 .01999 L
.80132 .02578 L
.81022 .03269 L
.81959 .04179 L
.83931 .06705 L
.85767 .09794 L
.89668 .18599 L
.93815 .30895 L
.97619 .44187 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00O7Goo00<007ooOol0
ogoo0Goo000MOol00`00Oomoo`3oOol1Ool001eoo`03001oogoo0?moo`5oo`007Goo00<007ooOol0
]7oo1P0OAWoo000MOol2002bOol301l5Ool301m4Ool001eoo`03001oogoo0:moo`807`]oo`<07d5o
o`007Goo00<007ooOol0[Woo00<07gooOol03Woo00<07gooOol0?Woo000MOol00`00Oomoo`2]Ool0
0`0OOomoo`0@Ool00`0OOomoo`0mOol001eoo`800:eoo`0301moogoo019oo`0301moogoo03aoo`00
7Goo00<007ooOol0ZWoo0P0O5Woo00<07`0000009P005Goo000MOol00`00Oomoo`2YOol00`0OOomo
o`0GOol00`0OO01l000TO0000`00Oomoo`0COol001eoo`03001oogoo0:Qoo`0301moogoo01Qoo`03
01ml07`002Al0003001oogoo01=oo`007Goo0P00Z7oo00<07gooOol06Goo00<0000OO00097`000<0
07ooOol04goo000MOol00`00Oomoo`2VOol00`0OOomoo`0JOol00`00O0007`0TO0000`00Oomoo`0C
Ool001eoo`03001oogoo0:Eoo`0301moogoo01]oo`04001l07`001lSO0000`00Oomoo`0COol001eo
o`03001oogoo0:Eoo`0301moogoo01]oo`05001l07`0O0007`0RO0000`00Oomoo`0COol001eoo`03
001oogoo0:Aoo`0301moogoo01aoo`03001l07`0009l000301ml07`001ml0003001oogoo01=oo`00
7Goo0P00Y7oo00<07gooOol07Goo00<007`0O0000W`000<07g`0O0007g`000<007ooOol04goo000M
Ool00`00Oomoo`2SOol00`0OOomoo`0MOol00`00O01l0003O0000`0OO01l000NO0000`00Oomoo`0C
Ool001Ioo`<000Aoo`03001oogoo0:9oo`0301moogoo01ioo`03001l07`000Al000301ml07`001el
0003001oogoo01=oo`005goo00<007ooOol00goo00<007ooOol0XWoo00<07gooOol07Woo00<007`0
O00017`000<07g`0O0007G`000<007ooOol04goo000?Ool500000goo000000020004Ool3002QOol0
0`0OOomoo`0OOol00`00O01l0005O0000`0OO01l000LO0000`00Oomoo`0COol001Eoo`03001oo`00
00Eoo`03001oogoo0:1oo`0301moogoo021oo`03001l07`000El000301ml07`001al0003001oogoo
01=oo`005Goo00<007oo00001Goo00<007ooOol0X7oo00<07gooOol087oo00<007`0O0001W`000<0
7g`0O0006g`000<007ooOol04goo000FOol20005Ool00`00Oomoo`2OOol00`0OOomoo`0QOol00`00
O01l0007O0000`0OO01l000JO0000`00Oomoo`0COol001eoo`03001oogoo09moo`0301moogoo025o
o`03001l07`000Ml000301ml07`001Yl0003001oogoo01=oo`007Goo0P00Wgoo00<07gooOol08Woo
00<007`0O00027`000<07g`0O0006G`000<007ooOol04goo000MOol00`00Oomoo`2MOol00`0OOomo
o`0SOol00`00O01l0008O0000`0OO01l000IO0000`00Oomoo`0COol001eoo`03001oogoo09eoo`03
01moogoo02=oo`03001l07`000Ql000301ml07`001Ul0003001oogoo01=oo`007Goo00<007ooOol0
Vgoo00<0000O00009P002g`000<07g`0O00067`000<007ooOol04goo000MOol2002LOol00`0001ml
000UO0000`00O01l0009O0000`0OO01l000HO0000`00Oomoo`0COol001eoo`03001oogoo09]oo`03
01ml07`002El0003001l07`000Yl000301ml07`001Ml0003001oogoo01=oo`007Goo00<007ooOol0
Vgoo00<07g`0O0009G`000<007`0O0002W`000<07g`0O0005g`000<007ooOol04goo000MOol00`00
Oomoo`2JOol00`0O001l000VO0000`00O01l000:O0000`0OO01l000GO0000`00Oomoo`0COol001eo
o`8009]oo`0301l007`002Il0003001l07`000]l000301ml07`001Il0003001oogoo01=oo`007Goo
00<007ooOol0VGoo00<07goo00009g`000<007`0O0002g`000<07g`0O0005W`000<007ooOol04goo
000MOol00`00Oomoo`2IOol00`0OOol0000WO0000`00O01l000<O0000`0OO01l000EO0000`00Oomo
o`0COol001eoo`03001oogoo09Qoo`0401moogoo000WO0000`00O01l000<O0000`0OO01l000EO000
0`00Oomoo`0COol001eoo`03001oogoo09Qoo`0401moogoo000WO0000`00O01l000=O0000`0OO01l
000DO0000`00Oomoo`0COol001eoo`8009Qoo`0501moogooOol0000WO0000`00O01l000=O0000`0O
O01l000DO0000`00Oomoo`0COol001eoo`03001oogoo09Ioo`0301moogoo009oo`03001l07`002El
0003001l07`000el000301ml07`001Al0003001oogoo01=oo`005Goo0`001Goo00<007ooOol0UWoo
00<07gooOol00Woo00<007`0O0009G`000<007`0O0003W`000<07g`0O0004g`000<007ooOol04goo
000HOol00`00Oomoo`02Ool00`00Oomoo`2EOol00`0OOomoo`03Ool00`00O01l000UO0000`00O01l
000>O0000`0OO01l000CO0000`00Oomoo`0COol000moo`D000Aoo`03001oogoo009oo`<009Eoo`03
01moogoo00=oo`03001l07`002El0003001l07`000ml000301ml07`0019l0003001oogoo01=oo`00
5Woo0P001Goo00<007ooOol0U7oo00<07gooOol017oo00<007`0O0009G`000<007`0O0003g`000<0
7g`0O0004W`000<007ooOol04goo000HOol00`00Oomoo`02Ool00`00Oomoo`2DOol00`0OOomoo`04
Ool00`00O01l000UO0000`00O01l000?O0000`0OO01l000BO0000`00Oomoo`0COol001Eoo`<000Eo
o`03001oogoo09=oo`0301moogoo00Eoo`03001l07`002El0003001l07`0011l000301ml07`0015l
0003001oogoo01=oo`007Goo00<007ooOol0Tgoo00<07gooOol01Goo00<007`0O0009G`000<007`0
O00047`000<07g`0O0004G`000<007ooOol04goo000MOol2002COol00`0OOomoo`06Ool00`00O01l
000UO0000`00O01l000AO0000`0OO01l000@O0000`00Oomoo`0COol001eoo`03001oogoo099oo`03
01moogoo00Ioo`03001l07`002El0003001l07`0015l000301ml07`0011l0003001oogoo01=oo`00
7Goo00<007ooOol0TGoo00<07gooOol01goo00<007`0O0009G`000<007`0O0004G`000<07g`0O000
47`000<007ooOol04goo000MOol00`00Oomoo`2AOol00`0OOomoo`07Ool00`00O01l000UO0000`00
O01l000BO0000`0OO01l000?O0000`00Oomoo`0COol001eoo`80095oo`0301moogoo00Qoo`03001l
07`002El0003001l07`0019l000301ml07`000ml0003001oogoo01=oo`007Goo00<007ooOol0T7oo
00<07gooOol027oo00<007`0O0009G`000<007`0O0004W`000<07g`0O0003g`000<007ooOol04goo
000MOol00`00Oomoo`2?Ool00`0OOomoo`09Ool00`00O01l000UO0000`00O01l000CO0000`0OO01l
000>O0000`00Oomoo`0COol001eoo`03001oogoo08moo`0301moogoo00Uoo`03001l07`002El0003
001l07`001=l000301ml07`000il0003001oogoo01=oo`007Goo00<007ooOol0SWoo00<07gooOol0
2Woo00<007`0O0009G`000<007`0O0004g`000<07g`0O0003W`000<007ooOol04goo000MOol2002?
Ool00`0OOomoo`0:Ool00`00O01l000UO0000`00O01l000DO0000`0OO01l000=O0000`00Oomoo`0C
Ool001eoo`03001oogoo08eoo`0301moogoo00]oo`03001l07`002El0003001l07`001Al000301ml
07`000el0003001oogoo01=oo`007Goo00<007ooOol0SGoo00<07gooOol02goo00<007`0O0009G`0
00<007`0O0005G`000<07g`0O00037`000<007ooOol04goo000MOol00`00Oomoo`2<Ool00`0OOomo
o`0<Ool00`00O01l000UO0000`00O01l000EO0000`0OO01l000<O0000`00Oomoo`0COol001eoo`80
08eoo`0301moogoo00aoo`03001l07`002El0003001l07`001El000301ml07`000al0003001oogoo
01=oo`007Goo00<007ooOol0Rgoo00<07gooOol03Goo00<007`0O0009G`000<007`0O0005W`000<0
7g`0O0002g`000<007ooOol04goo000EOol40004Ool00`00Oomoo`2;Ool00`0OOomoo`0=Ool00`00
O01l000UO0000`00O01l000FO0000`0OO01l000;O0000`00Oomoo`0COol001Ioo`03001oogoo00Ao
o`03001oogoo08Yoo`0301moogoo00ioo`03001l07`002El0003001l07`001Il000301ml07`000]l
0003001oogoo01=oo`003goo1@000goo00<007ooOol00goo0`00RWoo00<07gooOol03Woo00<007`0
O0009G`000<007`0O0005g`000<07g`0O0002W`000<007ooOol04goo000HOol00`00Oomoo`02Ool0
0`00Oomoo`29Ool00`0OOomoo`0?Ool00`00O01l000UO0000`00O01l000GO0000`0OO01l000:O000
0`00Oomoo`0COol001Eoo`04001oogoo0004Ool00`00Oomoo`29Ool00`0OOomoo`0?Ool00`00O01l
000UO0000`00O01l000HO0000`0OO01l0009O0000`00Oomoo`0COol001Ioo`8000Eoo`03001oogoo
08Qoo`0301moogoo011oo`03001l07`002El0003001l07`001Ql000301ml07`000Ul0003001oogoo
01=oo`007Goo00<007ooOol0R7oo00<07gooOol047oo00<007`0O0009G`000<007`0O00067`000<0
7g`0O0002G`000<007ooOol04goo000MOol20028Ool00`0OOomoo`0AOol00`00O01l000UO0000`00
O01l000IO0000`0OO01l0008O0000`00Oomoo`0COol001eoo`03001oogoo08Moo`0301moogoo015o
o`03001l07`002El0003001l07`001Ul000301ml07`000Ql0003001oogoo01=oo`007Goo00<007oo
Ool0QWoo00<07gooOol04Woo00<007`0O0009G`000<007`0O0006G`000<07g`0O00027`000<007oo
Ool04goo000MOol00`00Oomoo`26Ool00`0OOomoo`0BOol00`00O01l000UO0000`00O01l000JO000
0`0OO01l0007O0000`00Oomoo`0COol001eoo`8008Ioo`0301moogoo01=oo`03001l07`002El0003
001l07`001Yl000301ml07`000Ml0003001oogoo01=oo`007Goo00<007ooOol0QGoo00<07gooOol0
4goo00<007`0O0009G`000<007`0O0006W`000<07g`0O0001g`000<007ooOol04goo000MOol00`00
Oomoo`24Ool00`0OOomoo`0DOol00`00O01l000UO0000`00O01l000KO0000`0OO01l0006O0000`00
Oomoo`0COol001eoo`03001oogoo08Aoo`0301moogoo01Aoo`03001l07`002El0003001l07`001]l
000301ml07`000Il0003001oogoo01=oo`007Goo00<007ooOol0Pgoo00<07gooOol05Goo00<007`0
O0009G`000<007`0O0006g`000<07g`0O0001W`000<007ooOol04goo000MOol20024Ool00`0OOomo
o`0EOol00`00O01l000UO0000`00O01l000LO0000`0OO01l0005O0000`00Oomoo`0COol001eoo`03
001oogoo08=oo`0301moogoo01Eoo`03001l07`002El0003001l07`001al000301ml07`000El0003
001oogoo01=oo`007Goo00<007ooOol0PWoo00<07gooOol05Woo00<007`0O0009G`000<007`0O000
77`000<07g`0O0001G`000<007ooOol04goo000MOol00`00Oomoo`22Ool00`0OOomoo`0FOol00`00
O01l000UO0000`00O01l000LO0000`0OO01l0005O0000`00Oomoo`0COol001eoo`80089oo`0301mo
ogoo01Moo`03001l07`002El0003001l07`001el000301ml07`000Al0003001oogoo01=oo`007Goo
00<007ooOol0PGoo00<07gooOol05goo00<007`0O0009G`000<007`0O0007G`000<07g`0O00017`0
00<007ooOol04goo000EOol30005Ool00`00Oomoo`20Ool00`0OOomoo`0HOol00`00O01l000UO000
0`00O01l000MO0000`0OO01l0004O0000`00Oomoo`0COol001Ioo`03001oogoo00Aoo`03001oogoo
081oo`0301moogoo01Qoo`03001l07`002El0003001l07`001il000301ml07`000=l0003001oogoo
01=oo`003goo1@000Woo00<007ooOol017oo0`00Ogoo00<07gooOol06Goo00<007`0O0009G`000<0
07`0O0007W`000<07g`0O0000g`000<007ooOol04goo000FOol00`00Oomoo`04Ool00`00Oomoo`1o
Ool00`0OOomoo`0IOol00`00O01l000UO0000`00O01l000NO0000`0OO01l0003O0000`00Oomoo`0C
Ool001Ioo`03001oogoo00Aoo`03001oogoo07ioo`0301moogoo01Yoo`03001l07`002El0003001l
07`001il000301ml07`000=l0003001oogoo01=oo`005Goo0P001Woo00<007ooOol0OWoo00<07goo
Ool06Woo00<007`0O0009G`000<007`0O0007g`000<07g`0O0000W`000<007ooOol04goo000MOol0
0`00Oomoo`1mOol00`0OOomoo`0KOol00`00O01l000UO0000`00O01l000OO0000`0OO01l0002O000
0`00Oomoo`0COol001eoo`8007ioo`0301moogoo01]oo`03001l07`002El0003001l07`001ml0003
01ml07`0009l0003001oogoo01=oo`007Goo00<007ooOol0O7oo00<07gooOol077oo00<007`0O000
9G`000<007`0O0007g`000<07g`0O0000W`000<007ooOol04goo000MOol00`00Oomoo`1lOol00`0O
Oomoo`0LOol00`00O01l000UO0000`00O01l000PO0001@0OO01l07`000005Goo000MOol00`00Oomo
o`1kOol00`0OOomoo`0MOol00`00O01l000UO0000`00O01l000PO0001@0OO01l07`000005Goo000M
Ool2001lOol00`0OOomoo`0MOol00`00O01l000UO0000`00O01l000PO0001@0OO01l07`000005Goo
000MOol00`00Oomoo`1jOol00`0OOomoo`0NOol00`00O01l000UO0000`00O01l000PO0001@0OO01l
07`000005Goo000MOol00`00Oomoo`1jOol00`0OOomoo`0NOol00`00O01l000UO0000`00O01l000Q
O000100OO01l00005Goo000MOol00`00Oomoo`0QOol3000SOol4000QOol3000:Ool00`0OOomoo`0G
Ool30005Ool00`00O01l000UO0000`00O01l000QO000100OO01l00005Goo000MOol00`00Oomoo`0R
Ool00`00Oomoo`0SOol00`00Oomoo`0TOol00`00Oomoo`07Ool00`0OOomoo`0HOol00`00Oomoo`04
Ool00`00O01l000UO0000`00O01l000QO000100OO01l00005Goo000MOol2000SOol00`00Oomoo`0T
Ool00`00Oomoo`0SOol00`00Oomoo`06Ool00`0OOomoo`0GOol40005Ool00`00O01l000UO0000`00
O01l000QO000100OO01l00005Goo000MOol00`00Oomoo`0ROol00`00Oomoo`0UOol00`00Oomoo`0P
Ool20009Ool00`0OOomoo`0GOol00`00Ool00006Ool00`00O01l000UO0000`00O01l000RO0000`0O
O000000EOol001eoo`03001oogoo029oo`03001oogoo029oo`04001oogoo000TOol00`00Oomoo`05
Ool00`0OOomoo`0HOol00`00Ool00006Ool00`00O01l000UO0000`00O01l000RO0000`0OO000000E
Ool001eoo`03001oogoo025oo`8002Eoo`80029oo`<000Qoo`0301moogoo01Uoo`8000Ioo`03001l
07`002El0003001l07`0029l000301ml000001Eoo`007Goo0P00Mgoo00<07gooOol08Woo00<007`0
O0009G`000<007`0O0008g`000<07`00Ool057oo000MOol00`00Oomoo`1fOol00`0OOomoo`0ROol0
0`00O01l000UO0000`00O01l000SO0000`0O001oo`0DOol001eoo`03001oogoo07Eoo`0301moogoo
02=oo`03001l07`002El0003001l07`002=l000301l007oo01Aoo`007Goo00<007ooOol0MGoo00<0
7gooOol08goo00<007`0O0009G`000<007`0O0008g`000<07`00Ool057oo000MOol00`00Oomoo`0U
Ool00`00Oomoo`1<Ool00`0OOomoo`0TOol00`00O01l000UO0000`00O01l000TO0000`0OOomoo`0C
Ool001Moo`H000X07fd0000301l0000002D002Ml0003001l07`002Al000301l0000000@000moo`00
7Goo00<007ooOol01goo0P0O6Woo00<007oo00009W`000<007`0O00097`000<07`00Ool07Woo00<0
07ooOol08goo00<007ooOol08Woo00<007ooOol07Woo000MOol00`00Oomoo`09Ool301lIOol00`00
O01l000TO0000`00O01l000SO0000`0OO000002;Ool001eoo`03001oogoo00aoo`807aMoo`03001l
07`002Al0003001l07`002=l000301ml000008]oo`007Goo0P003goo0P0O5Goo00<007`0O00097`0
00<007`0O0008W`000@07g`0O00008]oo`007Goo00<007ooOol047oo00<07gooOol04Woo00<007`0
O00097`000<007`0O0008W`000@07g`0O00008]oo`007Goo00<007ooOol04Goo0P0O4Woo00<007`0
O00097`000<007`0O0008G`000D07g`0O01l000008]oo`007Goo00<007ooOol04goo0P0O47oo00<0
07`0O00097`000<007`0O00087`000<07g`0O0000W`000<007ooOol0RGoo000MOol2000FOol00`0O
Oomoo`0=Ool00`00O01l000TO0000`00O01l000PO0000`0OO01l0002O0000`00Oomoo`29Ool001eo
o`03001oogoo01Ioo`807`eoo`03001l07`002Al0003001l07`001ml000301ml07`000=l0003001o
ogoo08Uoo`007Goo00<007ooOol067oo0P0O2goo00<007`0O00097`000<007`0O0007W`000<07g`0
O00017`000<007ooOol0RGoo000MOol00`00Oomoo`0JOol00`0OOomoo`08Ool00`00O01l000TO000
0`00O01l000NO0000`0OO01l0004O0000`00Oomoo`29Ool001eoo`03001oogoo01]oo`807`Qoo`03
001l07`002Al0003001l07`001el000301ml07`000El0003001oogoo08Uoo`007Goo0P007Woo00<0
7gooOol01Goo00<007`0O00097`000<007`0O0007G`000<07g`0O0001G`000<007ooOol0RGoo000M
Ool00`00Oomoo`0NOol00`0OOomoo`04Ool00`00O01l000TO0000`00O01l000LO0000`0OO01l0006
O0000`00Oomoo`29Ool001eoo`03001oogoo01moo`0301moogoo00=oo`03001l07`002Al0003001l
07`001]l000301ml07`000Ml0003001oogoo08Uoo`007Goo00<007ooOol087oo0P0O0goo00<007`0
O00097`000<007`0O0006g`000<07g`0O0001g`000<007ooOol0RGoo000MOol2000SOol0100OOomo
o`009W`000<007`0O0006W`000<07g`0O00027`000<007ooOol0RGoo000MOol00`00Oomoo`0SOol0
0`0OOol0000VO0000`00O01l000IO0000`0OO01l0009O0000`00Oomoo`29Ool001eoo`03001oogoo
02Aoo`0301l007`002El0003001l07`001Ql000301ml07`000Yl0003001oogoo08Uoo`005Goo0`00
1Goo00<007ooOol09Goo0P0O9P006W`000<07g`0O0002W`000<007ooOol0RGoo000FOol00`00Oomo
o`04Ool00`00Oomoo`0WOol00`0OOomoo`0ROol00`00O01l000GO0000`0OO01l000;O0000`00Oomo
o`29Ool001Ioo`03001oogoo00Aoo`<002Qoo`0301moogoo025oo`03001l07`001Il000301ml07`0
00al0003001oogoo08Uoo`005Woo00<007ooOol017oo00<007ooOol0:Goo00<07gooOol087oo00<0
07`0O0005G`000<07g`0O0003G`000<007ooOol0RGoo000FOol00`00Oomoo`04Ool00`00Oomoo`0Z
Ool201lPOol00`00O01l000DO0000`0OO01l000>O0000`00Oomoo`29Ool001Eoo`8000Ioo`03001o
ogoo02aoo`0301moogoo01eoo`03001l07`001Al000301ml07`000il0003001oogoo08Uoo`007Goo
0P00;Woo00<07gooOol077oo00<007`0O0004g`000<07g`0O0003g`000<007ooOol0RGoo000MOol0
0`00Oomoo`0^Ool00`0OOomoo`0KOol00`00O01l000BO0000`0OO01l000@O0000`00Oomoo`29Ool0
01eoo`03001oogoo02moo`807a]oo`03001l07`0015l000301ml07`0015l0003001oogoo08Uoo`00
7Goo00<007ooOol0<Goo00<07gooOol067oo00<007`0O00047`000<07g`0O0004W`000<007ooOol0
RGoo000MOol2000cOol201lHOol00`00O01l000?O0000`0OO01l000CO0000`00Oomoo`29Ool001eo
o`03001oogoo03Aoo`0301moogoo01Eoo`03001l07`000il000301ml07`001Al0003001oogoo08Uo
o`007Goo00<007ooOol0=Goo0P0O5Goo00<007`0O00037`00P0O5g`000<007ooOol0RGoo000MOol0
0`00Oomoo`0gOol00`0OOomoo`0BOol00`00O01l000;O0000`0OO01l000GO0000`00Oomoo`29Ool0
01eoo`03001oogoo03Qoo`807a9oo`03001l07`000Yl000301ml07`001Ql0003001oogoo08Uoo`00
7Goo0P00>goo00<07gooOol03goo00<007`0O0002G`000<07g`0O0006G`000<007ooOol0RGoo000M
Ool00`00Oomoo`0kOol301l>Ool00`00O01l0007O00201lLO0000`00Oomoo`29Ool001eoo`03001o
ogoo03ioo`807`aoo`03001l07`000Al00<07ail0003001oogoo08Uoo`007Goo00<007ooOol0@7oo
0`0O2Goo00<007`0O0000W`00P0O8G`000<007ooOol0RGoo000MOol20014Ool401l5Ool00`0001l0
7`0201lSO0000`00Oomoo`29Ool001eoo`03001oogoo04Moo`H07bP008]oo`007Goo00<007ooOol0
ogoo0Goo000MOol00`00Oomoo`3oOol1Ool001eoo`03001oogoo0?moo`5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol003aoo`H000Io
o`<000=oo`@000Aoo`<000Eoo`<000=oo`@00003Ool000000080009oo`8000Eoo`X00003Ool00000
0080009oo`@000Aoo`@000=oo`@001Qoo`8000Moo`80009oo`D000Eoo`H000Aoo`@000Eoo`@000=o
o`D003Qoo`00?Woo0P001goo0P000Woo00@007ooOomoo`8000Aoo`80009oo`04001oogooOol20002
Ool01000Oomoogoo0P000goo0P000Woo0P0000=oo`00Ool01Goo0P001Goo0P0000=oo`00000017oo
0P0017oo0P000Woo0P000goo0P006goo0P001Goo0P000Woo0P000goo0P001Goo0P001Goo0P000Woo
0P000goo0P000Woo0P000Woo0P000goo0P00=Woo000nOol20006Ool20004Ool00`00Oomoo`020003
Ool20004Ool01000Ool0000017oo00<007ooOol00P000goo0P000Woo0P0027oo0P001Woo00@007oo
000000Aoo`8000=oo`8000Aoo`80009oo`8000Uoo`T000Yoo`8000ioo`03001oogoo00=oo`8000Eo
o`03001oogoo009oo`05001oogooOol00004Ool00`00Oomoo`06Ool00`00Oomoo`0dOol003ioo`80
00Ioo`8000Moo`8000=oo`8000Ioo`8000Moo`8000=oo`80009oo`8000Qoo`8000Qoo`8000Aoo`80
00=oo`8000Aoo`80009oo`8001eoo`8000eoo`8000Aoo`8000Aoo`8000Aoo`800003Ool0000000Ao
o`8000Moo`8003Eoo`00?Woo0P001Woo0P001goo0P000goo0P001Woo0P001goo0P000goo0P000Woo
0P0027oo0P0017oo00@007ooOomoo`8000Aoo`8000=oo`8000Aoo`80009oo`8001eoo`8000eoo`80
00Aoo`8000Aoo`8000Aoo`800003Ool0000000Aoo`8000Moo`8003Eoo`00?Woo1P000Woo1`000Woo
0P000goo0P0017oo00<007oo00001P000Woo0P000goo0P000Woo0P0027oo0P0017oo00@007ooOomo
o`8000Aoo`8000=oo`8000Aoo`80009oo`8001Yoo`H000aoo`8000Aoo`8000Aoo`8000Aoo`800003
Ool0000000Aoo`8000Moo`8003Eoo`00?Woo0P000goo0P000Woo00@007ooOomoo`800003Ool00000
00@00003Ool00000009oo`80009oo`04001oogooOol200000goo000000020002Ool20002Ool20008
Ool70002Ool<00000goo00000002Ool20002Ool60006Ool90007Ool20003Ool2000;Ool30004Ool2
0004Ool20004Ool200000goo00000004Ool20006Ool3000eOol003ioo`8000Aoo`80009oo`@000Ao
o`04001oo`000002Ool40004Ool40004Ool00`00Ool000020002Ool50006Ool20004Ool00`00Oomo
o`02Ool01000Ool000000Woo00@007oo0000009oo`@000Eoo`04001oo`00000EOol20004Ool20008
Ool50005Ool20004Ool20004Ool200000goo00000004Ool20003Ool5000fOol003ioo`8000Aoo`80
02Qoo`8000Qoo`8000Aoo`03001oogoo031oo`8000Aoo`8000Yoo`03001oogoo00Eoo`8000Aoo`80
00Aoo`800003Ool0000000Aoo`8000Eoo`03001oogoo03Ioo`00?Woo0P0017oo0P00:Goo00<007oo
Ool01Woo0P00=goo0P0017oo0P002goo00<007ooOol017oo0P0017oo0P0017oo0P0000=oo`000000
17oo0P001Woo00<007ooOol0=Goo000nOol20004Ool2000bOol20005Ool00`00Oomoo`0_Ool20004
Ool20006Ool00`00Oomoo`02Ool20005Ool20005Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo
00@007ooOol000Aoo`8003Ioo`00?Woo0P000goo0P00<goo0P001Goo00<007ooOol0<7oo0P000Woo
0P0027oo00<007ooOol00`000goo10001Goo0P000Woo0P000goo0P000Woo0P000goo00<007ooOol0
0`00=Woo000lOol8000bOol:000cOol4000:Ool40006Ool20006Ool40005Ool40005Ool4000gOol0
0?moob5oo`00ogoo8Goo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.783823, -4.98036, 
  0.0265065, 0.0452841}}],

Cell[BoxData[
    FormBox[
      TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
        False,
        Editable->False], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"RiemannSum[x Sin[x],{x,0,2\[Pi]},6,Method->RightEndPoint]"], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.151576 0.44187 0.0887232 [
[.17539 .42937 -3 -9 ]
[.17539 .42937 3 0 ]
[.32696 .42937 -3 -9 ]
[.32696 .42937 3 0 ]
[.47854 .42937 -3 -9 ]
[.47854 .42937 3 0 ]
[.63011 .42937 -3 -9 ]
[.63011 .42937 3 0 ]
[.78169 .42937 -3 -9 ]
[.78169 .42937 3 0 ]
[.93327 .42937 -3 -9 ]
[.93327 .42937 3 0 ]
[.01131 .08698 -12 -4.5 ]
[.01131 .08698 0 4.5 ]
[.01131 .1757 -12 -4.5 ]
[.01131 .1757 0 4.5 ]
[.01131 .26442 -12 -4.5 ]
[.01131 .26442 0 4.5 ]
[.01131 .35315 -12 -4.5 ]
[.01131 .35315 0 4.5 ]
[.01131 .53059 -6 -4.5 ]
[.01131 .53059 0 4.5 ]
[.5 .63053 -89.5938 0 ]
[.5 .63053 89.5938 20 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.17539 .44187 m
.17539 .44812 L
s
[(1)] .17539 .42937 0 1 Mshowa
.32696 .44187 m
.32696 .44812 L
s
[(2)] .32696 .42937 0 1 Mshowa
.47854 .44187 m
.47854 .44812 L
s
[(3)] .47854 .42937 0 1 Mshowa
.63011 .44187 m
.63011 .44812 L
s
[(4)] .63011 .42937 0 1 Mshowa
.78169 .44187 m
.78169 .44812 L
s
[(5)] .78169 .42937 0 1 Mshowa
.93327 .44187 m
.93327 .44812 L
s
[(6)] .93327 .42937 0 1 Mshowa
.125 Mabswid
.05412 .44187 m
.05412 .44562 L
s
.08444 .44187 m
.08444 .44562 L
s
.11476 .44187 m
.11476 .44562 L
s
.14507 .44187 m
.14507 .44562 L
s
.2057 .44187 m
.2057 .44562 L
s
.23602 .44187 m
.23602 .44562 L
s
.26633 .44187 m
.26633 .44562 L
s
.29665 .44187 m
.29665 .44562 L
s
.35728 .44187 m
.35728 .44562 L
s
.38759 .44187 m
.38759 .44562 L
s
.41791 .44187 m
.41791 .44562 L
s
.44822 .44187 m
.44822 .44562 L
s
.50885 .44187 m
.50885 .44562 L
s
.53917 .44187 m
.53917 .44562 L
s
.56948 .44187 m
.56948 .44562 L
s
.5998 .44187 m
.5998 .44562 L
s
.66043 .44187 m
.66043 .44562 L
s
.69074 .44187 m
.69074 .44562 L
s
.72106 .44187 m
.72106 .44562 L
s
.75137 .44187 m
.75137 .44562 L
s
.81201 .44187 m
.81201 .44562 L
s
.84232 .44187 m
.84232 .44562 L
s
.87264 .44187 m
.87264 .44562 L
s
.90295 .44187 m
.90295 .44562 L
s
.96358 .44187 m
.96358 .44562 L
s
.9939 .44187 m
.9939 .44562 L
s
.25 Mabswid
0 .44187 m
1 .44187 L
s
.02381 .08698 m
.03006 .08698 L
s
[(-4)] .01131 .08698 1 0 Mshowa
.02381 .1757 m
.03006 .1757 L
s
[(-3)] .01131 .1757 1 0 Mshowa
.02381 .26442 m
.03006 .26442 L
s
[(-2)] .01131 .26442 1 0 Mshowa
.02381 .35315 m
.03006 .35315 L
s
[(-1)] .01131 .35315 1 0 Mshowa
.02381 .53059 m
.03006 .53059 L
s
[(1)] .01131 .53059 1 0 Mshowa
.125 Mabswid
.02381 .016 m
.02756 .016 L
s
.02381 .03374 m
.02756 .03374 L
s
.02381 .05149 m
.02756 .05149 L
s
.02381 .06923 m
.02756 .06923 L
s
.02381 .10472 m
.02756 .10472 L
s
.02381 .12247 m
.02756 .12247 L
s
.02381 .14021 m
.02756 .14021 L
s
.02381 .15796 m
.02756 .15796 L
s
.02381 .19344 m
.02756 .19344 L
s
.02381 .21119 m
.02756 .21119 L
s
.02381 .22893 m
.02756 .22893 L
s
.02381 .24668 m
.02756 .24668 L
s
.02381 .28217 m
.02756 .28217 L
s
.02381 .29991 m
.02756 .29991 L
s
.02381 .31766 m
.02756 .31766 L
s
.02381 .3354 m
.02756 .3354 L
s
.02381 .37089 m
.02756 .37089 L
s
.02381 .38864 m
.02756 .38864 L
s
.02381 .40638 m
.02756 .40638 L
s
.02381 .42413 m
.02756 .42413 L
s
.02381 .45961 m
.02756 .45961 L
s
.02381 .47736 m
.02756 .47736 L
s
.02381 .4951 m
.02756 .4951 L
s
.02381 .51285 m
.02756 .51285 L
s
.02381 .54834 m
.02756 .54834 L
s
.02381 .56608 m
.02756 .56608 L
s
.02381 .58383 m
.02756 .58383 L
s
.02381 .60157 m
.02756 .60157 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -150.594 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 24.000000 moveto
 558.000000 24.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 24.000000 lineto
closepath
clip newpath
63.000000 19.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 18.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 19.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 18.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Percent) show
121.250000 19.000000 moveto
(Error) show
163.625000 19.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 18.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(=) show
179.687500 19.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 18.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(9.31003) show
238.187500 19.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 18.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
0 0 1 r
.007 w
.02381 .44187 m
.02499 .44188 L
.02605 .44189 L
.02729 .44192 L
.02846 .44195 L
.03053 .44204 L
.03279 .44218 L
.03527 .44238 L
.0379 .44264 L
.04262 .44323 L
.04749 .44403 L
.05205 .44493 L
.06244 .44757 L
.07305 .45107 L
.08274 .45495 L
.10458 .46589 L
.14429 .4922 L
.18248 .52229 L
.22313 .55474 L
.26226 .58144 L
.27254 .5871 L
.28367 .59241 L
.29328 .59624 L
.29838 .59795 L
.30384 .59955 L
.30923 .60086 L
.31415 .60182 L
.31652 .6022 L
.31909 .60255 L
.32151 .60282 L
.32378 .60303 L
.32509 .60312 L
.3263 .60319 L
.32764 .60325 L
.32834 .60327 L
.32908 .60329 L
.32976 .60331 L
.33048 .60332 L
.33177 .60332 L
.33257 .60331 L
.33332 .6033 L
.33399 .60328 L
.33472 .60326 L
.33594 .60321 L
.33728 .60313 L
.33999 .60292 L
.34249 .60266 L
.34484 .60235 L
.34982 .60149 L
.35525 .60023 L
Mistroke
.36513 .59709 L
.37475 .59294 L
.38367 .58812 L
.40423 .57339 L
.42285 .55569 L
.46297 .50405 L
.50157 .43897 L
.54262 .35759 L
.58216 .27326 L
.62019 .19318 L
.66067 .11668 L
.69963 .05896 L
.70983 .04728 L
.72091 .03645 L
.73048 .02875 L
.73557 .02531 L
.74104 .02213 L
.74638 .01956 L
.75126 .01767 L
.75594 .01629 L
.75829 .01576 L
.76085 .0153 L
.76227 .01511 L
.76362 .01496 L
.76482 .01485 L
.76612 .01477 L
.7668 .01474 L
.76755 .01472 L
.76833 .01472 L
.76905 .01472 L
.77035 .01475 L
.77108 .01478 L
.77175 .01482 L
.77304 .01492 L
.77424 .01504 L
.77695 .01543 L
.77933 .0159 L
.78187 .01653 L
.78675 .0181 L
.79123 .01999 L
.80132 .02578 L
.81022 .03269 L
.81959 .04179 L
.83931 .06705 L
.85767 .09794 L
.89668 .18599 L
.93815 .30895 L
.97619 .44187 L
Mfstroke
1 0 0 r
.02381 .44187 m
.18254 .44187 L
.18254 .52233 L
.02381 .52233 L
F
.18254 .44187 m
.34127 .44187 L
.34127 .6028 L
.18254 .6028 L
F
.34127 .44187 m
.5 .44187 L
.5 .44187 L
.34127 .44187 L
F
.5 .44187 m
.65873 .44187 L
.65873 .12002 L
.5 .12002 L
F
.65873 .44187 m
.81746 .44187 L
.81746 .03955 L
.65873 .03955 L
F
.81746 .44187 m
.97619 .44187 L
.97619 .44187 L
.81746 .44187 L
F
0 g
.5 Mabswid
.02381 .44187 m
.02381 .52233 L
s
.18254 .44187 m
.18254 .52233 L
s
.02381 .52233 m
.18254 .52233 L
s
.18254 .44187 m
.18254 .6028 L
s
.34127 .44187 m
.34127 .6028 L
s
.18254 .6028 m
.34127 .6028 L
s
.34127 .44187 m
.34127 .44187 L
s
.5 .44187 m
.5 .44187 L
s
.34127 .44187 m
.5 .44187 L
s
.5 .44187 m
.5 .12002 L
s
.65873 .44187 m
.65873 .12002 L
s
.5 .12002 m
.65873 .12002 L
s
.65873 .44187 m
.65873 .03955 L
s
.81746 .44187 m
.81746 .03955 L
s
.65873 .03955 m
.81746 .03955 L
s
.81746 .44187 m
.81746 .44187 L
s
.97619 .44187 m
.97619 .44187 L
s
.81746 .44187 m
.97619 .44187 L
s
0 0 1 r
.007 w
.02381 .44187 m
.02499 .44188 L
.02605 .44189 L
.02729 .44192 L
.02846 .44195 L
.03053 .44204 L
.03279 .44218 L
.03527 .44238 L
.0379 .44264 L
.04262 .44323 L
.04749 .44403 L
.05205 .44493 L
.06244 .44757 L
.07305 .45107 L
.08274 .45495 L
.10458 .46589 L
.14429 .4922 L
.18248 .52229 L
.22313 .55474 L
.26226 .58144 L
.27254 .5871 L
.28367 .59241 L
.29328 .59624 L
.29838 .59795 L
.30384 .59955 L
.30923 .60086 L
.31415 .60182 L
.31652 .6022 L
.31909 .60255 L
.32151 .60282 L
.32378 .60303 L
.32509 .60312 L
.3263 .60319 L
.32764 .60325 L
.32834 .60327 L
.32908 .60329 L
.32976 .60331 L
.33048 .60332 L
.33177 .60332 L
.33257 .60331 L
.33332 .6033 L
.33399 .60328 L
.33472 .60326 L
.33594 .60321 L
.33728 .60313 L
.33999 .60292 L
.34249 .60266 L
.34484 .60235 L
.34982 .60149 L
.35525 .60023 L
Mistroke
.36513 .59709 L
.37475 .59294 L
.38367 .58812 L
.40423 .57339 L
.42285 .55569 L
.46297 .50405 L
.50157 .43897 L
.54262 .35759 L
.58216 .27326 L
.62019 .19318 L
.66067 .11668 L
.69963 .05896 L
.70983 .04728 L
.72091 .03645 L
.73048 .02875 L
.73557 .02531 L
.74104 .02213 L
.74638 .01956 L
.75126 .01767 L
.75594 .01629 L
.75829 .01576 L
.76085 .0153 L
.76227 .01511 L
.76362 .01496 L
.76482 .01485 L
.76612 .01477 L
.7668 .01474 L
.76755 .01472 L
.76833 .01472 L
.76905 .01472 L
.77035 .01475 L
.77108 .01478 L
.77175 .01482 L
.77304 .01492 L
.77424 .01504 L
.77695 .01543 L
.77933 .0159 L
.78187 .01653 L
.78675 .0181 L
.79123 .01999 L
.80132 .02578 L
.81022 .03269 L
.81959 .04179 L
.83931 .06705 L
.85767 .09794 L
.89668 .18599 L
.93815 .30895 L
.97619 .44187 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00O7Goo00<007ooOol0
ogoo0Goo000MOol00`00Oomoo`3oOol1Ool001eoo`03001oogoo0?moo`5oo`007Goo00<007ooOol0
]7oo1P0OAWoo000MOol2002bOol301l5Ool301m4Ool001eoo`03001oogoo0:moo`807`]oo`<07d5o
o`007Goo00<007ooOol0[Woo00<07gooOol03Woo00<07gooOol0?Woo000MOol00`00Oomoo`2]Ool0
0`0OOomoo`0@Ool00`0OOomoo`0mOol001eoo`800:eoo`0301moogoo019oo`0301moogoo03aoo`00
7Goo00<007ooOol0Vgoo3`000P0O5P0000<07`00Ool0>goo000MOol00`00Oomoo`2KOol00`00O01l
000;O0000`0OO01l000GO0000`0OOomoo`0jOol001eoo`03001oogoo09]oo`03001l07`000Yl0003
01ml07`001Ql000301moogoo03Yoo`007Goo0P00W7oo00<007`0O0002G`000<07g`0O0006G`000<0
000OOol0>Woo000MOol00`00Oomoo`2KOol00`00O01l0008O0000`0OO01l000JO0000`00Ool07`0j
Ool001eoo`03001oogoo09]oo`03001l07`000Ml000301ml07`001]l0004001oogoo01liOol001eo
o`03001oogoo09]oo`03001l07`000Ml000301ml07`001]l0005001oogooOol07`0hOol001eoo`03
001oogoo09]oo`03001l07`000Il000301ml07`001al0003001oogoo009oo`0301moogoo03Eoo`00
7Goo0P00W7oo00<007`0O0001G`000<07g`0O0007G`000<007ooOol00Woo00<07gooOol0=Goo000M
Ool00`00Oomoo`2KOol00`00O01l0005O0000`0OO01l000MO0000`00Oomoo`03Ool00`0OOomoo`0d
Ool001Ioo`<000Aoo`03001oogoo09]oo`03001l07`000Al000301ml07`001il0003001oogoo00Ao
o`0301moogoo03=oo`005goo00<007ooOol00goo00<007ooOol0Vgoo00<007`0O00017`000<07g`0
O0007W`000<007ooOol017oo00<07gooOol0<goo000?Ool500000goo000000020004Ool3002KOol0
0`00O01l0003O0000`0OO01l000OO0000`00Oomoo`05Ool00`0OOomoo`0bOol001Eoo`03001oo`00
00Eoo`03001oogoo09]oo`03001l07`0009l000301ml07`0021l0003001oogoo00Eoo`0301moogoo
039oo`005Goo00<007oo00001Goo00<007ooOol0Vgoo00<007`0O0000W`000<07g`0O00087`000<0
07ooOol01Woo00<07gooOol0<Goo000FOol20005Ool00`00Oomoo`2KOol01@00O01l07`001l08g`0
00<007ooOol01goo00<07gooOol0<7oo000MOol00`00Oomoo`2KOol01@00O01l07`001l08g`000<0
07ooOol01goo00<07gooOol0<7oo000MOol2002LOol01000O01l000O97`000<007ooOol027oo00<0
7gooOol0;goo000MOol00`00Oomoo`2KOol00`00O0007`0UO0000`00Oomoo`08Ool00`0OOomoo`0_
Ool001eoo`03001oogoo09]oo`03001l000O02El0003001oogoo00Qoo`0301moogoo02moo`007Goo
00<007ooOol0M7oo:00000<07g`0O00097`000<007ooOol02Goo00<07gooOol0;Woo000MOol2001e
Ool00`00O01l000TO0000`0001ml000UO0000`00Oomoo`09Ool00`0OOomoo`0^Ool001eoo`03001o
ogoo07Aoo`03001l07`002Al000301ml07`002El0003001oogoo00Yoo`0301moogoo02eoo`007Goo
00<007ooOol0M7oo00<007`0O00097`000<07g`0O0009G`000<007ooOol02Woo00<07gooOol0;Goo
000MOol00`00Oomoo`1dOol00`00O01l000SO0000`0O001l000VO0000`00Oomoo`0:Ool00`0OOomo
o`0]Ool001eoo`8007Eoo`03001l07`002=l000301l007`002Il0003001oogoo00]oo`0301moogoo
02aoo`007Goo00<007ooOol0M7oo00<007`0O0008W`000<07g`000009g`000<007ooOol02goo00<0
7gooOol0;7oo000MOol00`00Oomoo`1dOol00`00O01l000RO0000`0OO000000WO0000`00Oomoo`0<
Ool00`0OOomoo`0[Ool001eoo`03001oogoo07Aoo`03001l07`0025l000401ml07`0000WO0000`00
Oomoo`0<Ool00`0OOomoo`0[Ool001eoo`03001oogoo07Aoo`03001l07`0025l000401ml07`0000W
O0000`00Oomoo`0=Ool00`0OOomoo`0ZOol001eoo`8007Eoo`03001l07`0021l000501ml07`0O000
000WO0000`00Oomoo`0=Ool00`0OOomoo`0ZOol001eoo`03001oogoo07Aoo`03001l07`001ml0003
01ml07`0009l0003001l07`002El0003001oogoo00eoo`0301moogoo02Yoo`005Goo0`001Goo00<0
07ooOol0M7oo00<007`0O0007g`000<07g`0O0000W`000<007`0O0009G`000<007ooOol03Woo00<0
7gooOol0:Goo000HOol00`00Oomoo`02Ool00`00Oomoo`1dOol00`00O01l000NO0000`0OO01l0003
O0000`00O01l000UO0000`00Oomoo`0>Ool00`0OOomoo`0YOol000moo`D000Aoo`03001oogoo009o
o`<007Aoo`03001l07`001il000301ml07`000=l0003001l07`002El0003001oogoo00moo`0301mo
ogoo02Qoo`005Woo0P001Goo00<007ooOol0M7oo00<007`0O0007G`000<07g`0O00017`000<007`0
O0009G`000<007ooOol03goo00<07gooOol0:7oo000HOol00`00Oomoo`02Ool00`00Oomoo`1dOol0
0`00O01l000MO0000`0OO01l0004O0000`00O01l000UO0000`00Oomoo`0?Ool00`0OOomoo`0XOol0
01Eoo`<000Eoo`03001oogoo07Aoo`03001l07`001al000301ml07`000El0003001l07`002El0003
001oogoo011oo`0301moogoo02Moo`007Goo00<007ooOol0M7oo00<007`0O00077`000<07g`0O000
1G`000<007`0O0009G`000<007ooOol047oo00<07gooOol09goo000MOol2001eOol00`00O01l000K
O0000`0OO01l0006O0000`00O01l000UO0000`00Oomoo`0AOol00`0OOomoo`0VOol001eoo`03001o
ogoo07Aoo`03001l07`001]l000301ml07`000Il0003001l07`002El0003001oogoo015oo`0301mo
ogoo02Ioo`007Goo00<007ooOol0M7oo00<007`0O0006W`000<07g`0O0001g`000<007`0O0009G`0
00<007ooOol04Goo00<07gooOol09Woo000MOol00`00Oomoo`1dOol00`00O01l000JO0000`0OO01l
0007O0000`00O01l000UO0000`00Oomoo`0BOol00`0OOomoo`0UOol001eoo`8007Eoo`03001l07`0
01Ul000301ml07`000Ql0003001l07`002El0003001oogoo019oo`0301moogoo02Eoo`007Goo00<0
07ooOol0M7oo00<007`0O0006G`000<07g`0O00027`000<007`0O0009G`000<007ooOol04Woo00<0
7gooOol09Goo000MOol00`00Oomoo`1dOol00`00O01l000HO0000`0OO01l0009O0000`00O01l000U
O0000`00Oomoo`0COol00`0OOomoo`0TOol001eoo`03001oogoo07Aoo`03001l07`001Ql000301ml
07`000Ul0003001l07`002El0003001oogoo01=oo`0301moogoo02Aoo`007Goo00<007ooOol0M7oo
00<007`0O0005g`000<07g`0O0002W`000<007`0O0009G`000<007ooOol04goo00<07gooOol097oo
000MOol2001eOol00`00O01l000GO0000`0OO01l000:O0000`00O01l000UO0000`00Oomoo`0DOol0
0`0OOomoo`0SOol001eoo`03001oogoo07Aoo`03001l07`001Il000301ml07`000]l0003001l07`0
02El0003001oogoo01Aoo`0301moogoo02=oo`007Goo00<007ooOol0M7oo00<007`0O0005W`000<0
7g`0O0002g`000<007`0O0009G`000<007ooOol05Goo00<07gooOol08Woo000MOol00`00Oomoo`1d
Ool00`00O01l000EO0000`0OO01l000<O0000`00O01l000UO0000`00Oomoo`0EOol00`0OOomoo`0R
Ool001eoo`8007Eoo`03001l07`001El000301ml07`000al0003001l07`002El0003001oogoo01Eo
o`0301moogoo029oo`007Goo00<007ooOol0M7oo00<007`0O00057`000<07g`0O0003G`000<007`0
O0009G`000<007ooOol05Woo00<07gooOol08Goo000EOol40004Ool00`00Oomoo`1dOol00`00O01l
000DO0000`0OO01l000=O0000`00O01l000UO0000`00Oomoo`0FOol00`0OOomoo`0QOol001Ioo`03
001oogoo00Aoo`03001oogoo07Aoo`03001l07`001=l000301ml07`000il0003001l07`002El0003
001oogoo01Ioo`0301moogoo025oo`003goo1@000goo00<007ooOol00goo0`00M7oo00<007`0O000
4g`000<07g`0O0003W`000<007`0O0009G`000<007ooOol05goo00<07gooOol087oo000HOol00`00
Oomoo`02Ool00`00Oomoo`1dOol00`00O01l000BO0000`0OO01l000?O0000`00O01l000UO0000`00
Oomoo`0GOol00`0OOomoo`0POol001Eoo`04001oogoo0004Ool00`00Oomoo`1dOol00`00O01l000B
O0000`0OO01l000?O0000`00O01l000UO0000`00Oomoo`0HOol00`0OOomoo`0OOol001Ioo`8000Eo
o`03001oogoo07Aoo`03001l07`0015l000301ml07`0011l0003001l07`002El0003001oogoo01Qo
o`0301moogoo01moo`007Goo00<007ooOol0M7oo00<007`0O0004G`000<07g`0O00047`000<007`0
O0009G`000<007ooOol067oo00<07gooOol07goo000MOol2001eOol00`00O01l000@O0000`0OO01l
000AO0000`00O01l000UO0000`00Oomoo`0IOol00`0OOomoo`0NOol001eoo`03001oogoo07Aoo`03
001l07`0011l000301ml07`0015l0003001l07`002El0003001oogoo01Uoo`0301moogoo01ioo`00
7Goo00<007ooOol0M7oo00<007`0O0003g`000<07g`0O0004W`000<007`0O0009G`000<007ooOol0
6Goo00<07gooOol07Woo000MOol00`00Oomoo`1dOol00`00O01l000?O0000`0OO01l000BO0000`00
O01l000UO0000`00Oomoo`0JOol00`0OOomoo`0MOol001eoo`8007Eoo`03001l07`000il000301ml
07`001=l0003001l07`002El0003001oogoo01Yoo`0301moogoo01eoo`007Goo00<007ooOol0M7oo
00<007`0O0003W`000<07g`0O0004g`000<007`0O0009G`000<007ooOol06Woo00<07gooOol07Goo
000MOol00`00Oomoo`1dOol00`00O01l000=O0000`0OO01l000DO0000`00O01l000UO0000`00Oomo
o`0KOol00`0OOomoo`0LOol001eoo`03001oogoo07Aoo`03001l07`000el000301ml07`001Al0003
001l07`002El0003001oogoo01]oo`0301moogoo01aoo`007Goo00<007ooOol0M7oo00<007`0O000
37`000<07g`0O0005G`000<007`0O0009G`000<007ooOol06goo00<07gooOol077oo000MOol2001e
Ool00`00O01l000<O0000`0OO01l000EO0000`00O01l000UO0000`00Oomoo`0LOol00`0OOomoo`0K
Ool001eoo`03001oogoo07Aoo`03001l07`000al000301ml07`001El0003001l07`002El0003001o
ogoo01aoo`0301moogoo01]oo`007Goo00<007ooOol0M7oo00<007`0O0002g`000<07g`0O0005W`0
00<007`0O0009G`000<007ooOol077oo00<07gooOol06goo000MOol00`00Oomoo`1dOol00`00O01l
000;O0000`0OO01l000FO0000`00O01l000UO0000`00Oomoo`0LOol00`0OOomoo`0KOol001eoo`80
07Eoo`03001l07`000Yl000301ml07`001Ml0003001l07`002El0003001oogoo01eoo`0301moogoo
01Yoo`007Goo00<007ooOol0M7oo00<007`0O0002W`000<07g`0O0005g`000<007`0O0009G`000<0
07ooOol07Goo00<07gooOol06Woo000EOol30005Ool00`00Oomoo`1dOol00`00O01l0009O0000`0O
O01l000HO0000`00O01l000UO0000`00Oomoo`0MOol00`0OOomoo`0JOol001Ioo`03001oogoo00Ao
o`03001oogoo07Aoo`03001l07`000Ul000301ml07`001Ql0003001l07`002El0003001oogoo01io
o`0301moogoo01Uoo`003goo1@000Woo00<007ooOol017oo0`00M7oo00<007`0O00027`000<07g`0
O0006G`000<007`0O0009G`000<007ooOol07Woo00<07gooOol06Goo000FOol00`00Oomoo`04Ool0
0`00Oomoo`1dOol00`00O01l0008O0000`0OO01l000IO0000`00O01l000UO0000`00Oomoo`0NOol0
0`0OOomoo`0IOol001Ioo`03001oogoo00Aoo`03001oogoo07Aoo`03001l07`000Ml000301ml07`0
01Yl0003001l07`002El0003001oogoo01ioo`0301moogoo01Uoo`005Goo0P001Woo00<007ooOol0
M7oo00<007`0O0001g`000<07g`0O0006W`000<007`0O0009G`000<007ooOol07goo00<07gooOol0
67oo000MOol00`00Oomoo`1dOol00`00O01l0006O0000`0OO01l000KO0000`00O01l000UO0000`00
Oomoo`0OOol00`0OOomoo`0HOol001eoo`8007Eoo`03001l07`000Il000301ml07`001]l0003001l
07`002El0003001oogoo01moo`0301moogoo01Qoo`007Goo00<007ooOol0M7oo00<007`0O0001G`0
00<07g`0O00077`000<007`0O0009G`000<007ooOol07goo00<07gooOol067oo000MOol00`00Oomo
o`1dOol00`00O01l0005O0000`0OO01l000LO0000`00O01l000UO0000`00Oomoo`0POol00`0OOomo
o`0GOol001eoo`03001oogoo07Aoo`03001l07`000Al000301ml07`001el0003001l07`002El0003
001oogoo021oo`0301moogoo01Moo`007Goo0P00MGoo00<007`0O00017`000<07g`0O0007G`000<0
07`0O0009G`000<007ooOol087oo00<07gooOol05goo000MOol00`00Oomoo`1dOol00`00O01l0003
O0000`0OO01l000NO0000`00O01l000UO0000`00Oomoo`0POol00`0OOomoo`0GOol001eoo`03001o
ogoo07Aoo`03001l07`000=l000301ml07`001il0003001l07`002El0003001oogoo025oo`0301mo
ogoo01Ioo`007Goo00<007ooOol08Goo0`008goo10008Goo0`001Goo00<007`0O0000W`000<07g`0
O0007g`000<007`0O0009G`000<007ooOol067oo0P001goo00<07gooOol05Woo000MOol00`00Oomo
o`0ROol00`00Oomoo`0SOol00`00Oomoo`0TOol00`00Oomoo`02Ool00`00O01l0002O0000`0OO01l
000OO0000`00O01l000UO0000`00Oomoo`0GOol01000Oomoo`001Woo00<07gooOol05Woo000MOol2
000SOol00`00Oomoo`0TOol00`00Oomoo`0SOol00`00Oomoo`02Ool01@00O01l07`001l08W`000<0
07`0O0009G`000<007ooOol05goo00@007ooOol000Ioo`0301moogoo01Ioo`007Goo00<007ooOol0
8Woo00<007ooOol09Goo00<007ooOol087oo0P001Goo00D007`0O01l000O029l0003001l07`002El
0003001oogoo01Moo`<000Qoo`0301moogoo01Eoo`007Goo00<007ooOol08Woo00<007ooOol08Woo
00@007ooOol002Aoo`03001oogoo009oo`04001l07`001lSO0000`00O01l000UO0000`00Oomoo`0G
Ool00`00Oomoo`08Ool00`0OOomoo`0EOol001eoo`03001oogoo025oo`8002Eoo`80029oo`<000Eo
o`04001l07`001lSO0000`00O01l000UO0000`00Oomoo`0HOol30007Ool00`0OOomoo`0EOol001eo
o`8007Eoo`03001l000O02Al0003001l07`002El0003001oogoo02=oo`0301moogoo01Aoo`007Goo
00<007ooOol0M7oo00<007`001l097`000<007`0O0009G`000<007ooOol08goo00<07gooOol057oo
000MOol00`00Oomoo`1dOol00`0001ml000TO0000`00O01l000UO0000`00Oomoo`0SOol00`0OOomo
o`0DOol001eoo`03001oogoo07Aoo`0300007g`002Al0003001l07`002El0003001oogoo02=oo`03
01moogoo01Aoo`007Goo00<007ooOol0C7oo00<007ooOol09Goo00<07g`0O00097`000<007`0O000
9G`000<007ooOol097oo00<07gooOol04goo000GOol6000:01m]00000`0OO01l000TO0000`00O01l
000UO00W00000`0O00000004000?Ool001eoo`03001l07`000Ml00807aal0003001l07`002Al0003
001oogoo01moo`03001oogoo009oo`0301moogoo01ioo`03001oogoo02=oo`03001oogoo029oo`03
001oogoo01ioo`007Goo00<007`0O0002G`00`0O6G`000<007`0O00097`000<007ooOol08goo00<0
7gooOol0Rgoo000MOol00`00O01l000<O00201lGO0000`00O01l000TO0000`00Oomoo`0SOol00`0O
Oomoo`2;Ool001eoo`03001l07`000il00807aEl0003001l07`002Al0003001oogoo029oo`0301mo
ogoo08aoo`007Goo00<007`0O00047`000<07g`0O0004W`000<007`0O00097`000<007ooOol08Woo
00<07gooOol0S7oo000MOol00`00O01l000AO00201lBO0000`00O01l000TO0000`00Oomoo`0QOol0
0`0OOomoo`2=Ool001eoo`03001l07`001=l00807a1l0003001l07`002Al0003001oogoo021oo`03
01moogoo08ioo`007Goo00<007`0O0005G`000<07g`0O0003G`000<007`0O00097`000<007ooOol0
87oo00<07gooOol0SWoo000MOol00`00O01l000FO00201l=O0000`00O01l000TO0000`00Oomoo`0O
Ool00`0OOomoo`2?Ool001eoo`03001l07`001Ql00807`]l0003001l07`002Al0003001oogoo01io
o`0301moogoo091oo`007Goo00<007`0O0006W`000<07g`0O00027`000<007`0O00097`000<007oo
Ool07Woo00<07gooOol0T7oo000MOol00`00O01l000KO00201l8O0000`00O01l000TO0000`00Oomo
o`0MOol00`0OOomoo`2AOol001eoo`03001l07`001el000301ml07`000El0003001l07`002Al0003
001oogoo01eoo`0301moogoo095oo`007Goo00<007`0O0007W`000<07g`0O00017`000<007`0O000
97`000<007ooOol077oo00<07gooOol0TWoo000MOol00`00O01l000OO0000`0OO01l0003O0000`00
O01l000TO0000`00Oomoo`0KOol00`0OOomoo`2COol001eoo`03001l07`0021l00807`=l0003001l
07`002Al0003001oogoo01]oo`0301moogoo09=oo`007Goo00<007`0O0008W`000@07g`0O00002Il
0003001oogoo01Yoo`0301moogoo09Aoo`007Goo00<007`0O0008g`000<07g`000009W`000<007oo
Ool06Goo00<07gooOol0UGoo000MOol00`00O01l000TO0000`0O001l000UO0000`00Oomoo`0HOol0
0`0OOomoo`2FOol001Eoo`<000EoobP000807bEl0003001oogoo01Qoo`0301moogoo09Ioo`005Woo
00<007ooOol017oo00<007ooOol09Goo00<007`001l097`000<007ooOol05goo00<07gooOol0Ugoo
000FOol00`00Oomoo`04Ool3000UOol01000O01l000O8g`000<007ooOol05Woo00<07gooOol0V7oo
000FOol00`00Oomoo`04Ool00`00Oomoo`0UOol01@00O01l07`001l08W`000<007ooOol05Goo00<0
7gooOol0VGoo000FOol00`00Oomoo`04Ool00`00Oomoo`0UOol00`00O01l0002O00201lPO0000`00
Oomoo`0DOol00`0OOomoo`2JOol001Eoo`8000Ioo`03001oogoo02Eoo`03001l07`000Al000301ml
07`001el0003001oogoo01Aoo`0301moogoo09Yoo`007Goo0P009Woo00<007`0O0001G`000<07g`0
O00077`000<007ooOol04goo00<07gooOol0Vgoo000MOol00`00Oomoo`0UOol00`00O01l0006O000
0`0OO01l000KO0000`00Oomoo`0BOol00`0OOomoo`2LOol001eoo`03001oogoo02Eoo`03001l07`0
00Ml00807a]l0003001oogoo015oo`0301moogoo09eoo`007Goo00<007ooOol09Goo00<007`0O000
2G`000<07g`0O00067`000<007ooOol047oo00<07gooOol0WWoo000MOol2000VOol00`00O01l000:
O00201lHO0000`00Oomoo`0?Ool00`0OOomoo`2OOol001eoo`03001oogoo02Eoo`03001l07`000al
000301ml07`001El0003001oogoo00ioo`0301moogoo0:1oo`007Goo00<007ooOol09Goo00<007`0
O0003G`00P0O5G`000<007ooOol037oo0P0OXgoo000MOol00`00Oomoo`0UOol00`00O01l000?O000
0`0OO01l000BO0000`00Oomoo`0;Ool00`0OOomoo`2SOol001eoo`03001oogoo02Eoo`03001l07`0
011l00807a9l0003001oogoo00Yoo`0301moogoo0:Aoo`007Goo0P009Woo00<007`0O0004W`000<0
7g`0O0003g`000<007ooOol02Goo00<07gooOol0YGoo000MOol00`00Oomoo`0UOol00`00O01l000C
O00301l>O0000`00Oomoo`07Ool201nXOol001eoo`03001oogoo02Eoo`03001l07`001Il00807`al
0003001oogoo00Aoo`<07jYoo`007Goo00<007ooOol09Goo00<007`0O00067`00`0O2G`000<007oo
Ool00Woo0P0O[Goo000MOol2000VOol00`00O01l000KO00401l5O0000`0001l07`0201n_Ool001eo
o`03001oogoo02Eoob8000H07k=oo`007Goo00<007ooOol0ogoo0Goo000MOol00`00Oomoo`3oOol1
Ool001eoo`03001oogoo0?moo`5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol003aoo`H000Ioo`<000=oo`@000Aoo`<000Eoo`<000=o
o`@00003Ool000000080009oo`8000Eoo`X00003Ool000000080009oo`@000Aoo`@000=oo`@001Qo
o`8000Moo`80009oo`D000Eoo`H000Aoo`@000Eoo`@000=oo`D003Qoo`00?Woo0P001goo0P000Woo
00@007ooOomoo`8000Aoo`80009oo`04001oogooOol20002Ool01000Oomoogoo0P000goo0P000Woo
0P0000=oo`00Ool01Goo0P001Goo0P0000=oo`00000017oo0P0017oo0P000Woo0P000goo0P006goo
0P001Goo0P000Woo0P000goo0P001Goo0P001Goo0P000Woo0P000goo0P000Woo0P000Woo0P000goo
0P00=Woo000nOol20006Ool20004Ool00`00Oomoo`020003Ool20004Ool01000Ool0000017oo00<0
07ooOol00P000goo0P000Woo0P0027oo0P001Woo00@007oo000000Aoo`8000=oo`8000Aoo`80009o
o`8000Uoo`T000Yoo`8000ioo`03001oogoo00=oo`8000Eoo`03001oogoo009oo`05001oogooOol0
0004Ool00`00Oomoo`06Ool00`00Oomoo`0dOol003ioo`8000Ioo`8000Moo`8000=oo`8000Ioo`80
00Moo`8000=oo`80009oo`8000Qoo`8000Qoo`8000Aoo`8000=oo`8000Aoo`80009oo`8001eoo`80
00eoo`8000Aoo`8000Aoo`8000Aoo`800003Ool0000000Aoo`8000Moo`8003Eoo`00?Woo0P001Woo
0P001goo0P000goo0P001Woo0P001goo0P000goo0P000Woo0P0027oo0P0017oo00@007ooOomoo`80
00Aoo`8000=oo`8000Aoo`80009oo`8001eoo`8000eoo`8000Aoo`8000Aoo`8000Aoo`800003Ool0
000000Aoo`8000Moo`8003Eoo`00?Woo1P000Woo1`000Woo0P000goo0P0017oo00<007oo00001P00
0Woo0P000goo0P000Woo0P0027oo0P0017oo00@007ooOomoo`8000Aoo`8000=oo`8000Aoo`80009o
o`8001Yoo`H000aoo`8000Aoo`8000Aoo`8000Aoo`800003Ool0000000Aoo`8000Moo`8003Eoo`00
?Woo0P000goo0P000Woo00@007ooOomoo`800003Ool0000000@00003Ool00000009oo`80009oo`04
001oogooOol200000goo000000020002Ool20002Ool20008Ool70002Ool<00000goo00000002Ool2
0002Ool60006Ool90007Ool20003Ool2000;Ool30004Ool20004Ool20004Ool200000goo00000004
Ool20006Ool3000eOol003ioo`8000Aoo`80009oo`@000Aoo`04001oo`000002Ool40004Ool40004
Ool00`00Ool000020002Ool50006Ool20004Ool00`00Oomoo`02Ool01000Ool000000Woo00@007oo
0000009oo`@000Eoo`04001oo`00000EOol20004Ool20008Ool50005Ool20004Ool20004Ool20000
0goo00000004Ool20003Ool5000fOol003ioo`8000Aoo`8002Qoo`8000Qoo`8000Aoo`03001oogoo
031oo`8000Aoo`8000Yoo`03001oogoo00Eoo`8000Aoo`8000Aoo`800003Ool0000000Aoo`8000Eo
o`03001oogoo03Ioo`00?Woo0P0017oo0P00:Goo00<007ooOol01Woo0P00=goo0P0017oo0P002goo
00<007ooOol017oo0P0017oo0P0017oo0P0000=oo`00000017oo0P001Woo00<007ooOol0=Goo000n
Ool20004Ool2000bOol20005Ool00`00Oomoo`0_Ool20004Ool20006Ool00`00Oomoo`02Ool20005
Ool20005Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00@007ooOol000Aoo`8003Ioo`00?Woo
0P000goo0P00<goo0P001Goo00<007ooOol0<7oo0P000Woo0P0027oo00<007ooOol00`000goo1000
1Goo0P000Woo0P000goo0P000Woo0P000goo00<007ooOol00`00=Woo000lOol8000bOol:000cOol4
000:Ool40006Ool20006Ool40005Ool40005Ool4000gOol00?moob5oo`00ogoo8Goo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.783823, -4.98036, 
  0.0265065, 0.0452841}}],

Cell[BoxData[
    FormBox[
      TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
        False,
        Editable->False], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["RiemannSum[x Sin[x],{x,0,2\[Pi]},6,Method->Random]"], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.151576 0.44187 0.0887232 [
[.17539 .42937 -3 -9 ]
[.17539 .42937 3 0 ]
[.32696 .42937 -3 -9 ]
[.32696 .42937 3 0 ]
[.47854 .42937 -3 -9 ]
[.47854 .42937 3 0 ]
[.63011 .42937 -3 -9 ]
[.63011 .42937 3 0 ]
[.78169 .42937 -3 -9 ]
[.78169 .42937 3 0 ]
[.93327 .42937 -3 -9 ]
[.93327 .42937 3 0 ]
[.01131 .08698 -12 -4.5 ]
[.01131 .08698 0 4.5 ]
[.01131 .1757 -12 -4.5 ]
[.01131 .1757 0 4.5 ]
[.01131 .26442 -12 -4.5 ]
[.01131 .26442 0 4.5 ]
[.01131 .35315 -12 -4.5 ]
[.01131 .35315 0 4.5 ]
[.01131 .53059 -6 -4.5 ]
[.01131 .53059 0 4.5 ]
[.5 .63053 -89.5938 0 ]
[.5 .63053 89.5938 20 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.17539 .44187 m
.17539 .44812 L
s
[(1)] .17539 .42937 0 1 Mshowa
.32696 .44187 m
.32696 .44812 L
s
[(2)] .32696 .42937 0 1 Mshowa
.47854 .44187 m
.47854 .44812 L
s
[(3)] .47854 .42937 0 1 Mshowa
.63011 .44187 m
.63011 .44812 L
s
[(4)] .63011 .42937 0 1 Mshowa
.78169 .44187 m
.78169 .44812 L
s
[(5)] .78169 .42937 0 1 Mshowa
.93327 .44187 m
.93327 .44812 L
s
[(6)] .93327 .42937 0 1 Mshowa
.125 Mabswid
.05412 .44187 m
.05412 .44562 L
s
.08444 .44187 m
.08444 .44562 L
s
.11476 .44187 m
.11476 .44562 L
s
.14507 .44187 m
.14507 .44562 L
s
.2057 .44187 m
.2057 .44562 L
s
.23602 .44187 m
.23602 .44562 L
s
.26633 .44187 m
.26633 .44562 L
s
.29665 .44187 m
.29665 .44562 L
s
.35728 .44187 m
.35728 .44562 L
s
.38759 .44187 m
.38759 .44562 L
s
.41791 .44187 m
.41791 .44562 L
s
.44822 .44187 m
.44822 .44562 L
s
.50885 .44187 m
.50885 .44562 L
s
.53917 .44187 m
.53917 .44562 L
s
.56948 .44187 m
.56948 .44562 L
s
.5998 .44187 m
.5998 .44562 L
s
.66043 .44187 m
.66043 .44562 L
s
.69074 .44187 m
.69074 .44562 L
s
.72106 .44187 m
.72106 .44562 L
s
.75137 .44187 m
.75137 .44562 L
s
.81201 .44187 m
.81201 .44562 L
s
.84232 .44187 m
.84232 .44562 L
s
.87264 .44187 m
.87264 .44562 L
s
.90295 .44187 m
.90295 .44562 L
s
.96358 .44187 m
.96358 .44562 L
s
.9939 .44187 m
.9939 .44562 L
s
.25 Mabswid
0 .44187 m
1 .44187 L
s
.02381 .08698 m
.03006 .08698 L
s
[(-4)] .01131 .08698 1 0 Mshowa
.02381 .1757 m
.03006 .1757 L
s
[(-3)] .01131 .1757 1 0 Mshowa
.02381 .26442 m
.03006 .26442 L
s
[(-2)] .01131 .26442 1 0 Mshowa
.02381 .35315 m
.03006 .35315 L
s
[(-1)] .01131 .35315 1 0 Mshowa
.02381 .53059 m
.03006 .53059 L
s
[(1)] .01131 .53059 1 0 Mshowa
.125 Mabswid
.02381 .016 m
.02756 .016 L
s
.02381 .03374 m
.02756 .03374 L
s
.02381 .05149 m
.02756 .05149 L
s
.02381 .06923 m
.02756 .06923 L
s
.02381 .10472 m
.02756 .10472 L
s
.02381 .12247 m
.02756 .12247 L
s
.02381 .14021 m
.02756 .14021 L
s
.02381 .15796 m
.02756 .15796 L
s
.02381 .19344 m
.02756 .19344 L
s
.02381 .21119 m
.02756 .21119 L
s
.02381 .22893 m
.02756 .22893 L
s
.02381 .24668 m
.02756 .24668 L
s
.02381 .28217 m
.02756 .28217 L
s
.02381 .29991 m
.02756 .29991 L
s
.02381 .31766 m
.02756 .31766 L
s
.02381 .3354 m
.02756 .3354 L
s
.02381 .37089 m
.02756 .37089 L
s
.02381 .38864 m
.02756 .38864 L
s
.02381 .40638 m
.02756 .40638 L
s
.02381 .42413 m
.02756 .42413 L
s
.02381 .45961 m
.02756 .45961 L
s
.02381 .47736 m
.02756 .47736 L
s
.02381 .4951 m
.02756 .4951 L
s
.02381 .51285 m
.02756 .51285 L
s
.02381 .54834 m
.02756 .54834 L
s
.02381 .56608 m
.02756 .56608 L
s
.02381 .58383 m
.02756 .58383 L
s
.02381 .60157 m
.02756 .60157 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -150.594 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 24.000000 moveto
 558.000000 24.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 24.000000 lineto
closepath
clip newpath
63.000000 19.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 18.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 19.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 18.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Percent) show
121.250000 19.000000 moveto
(Error) show
163.625000 19.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 18.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(=) show
179.687500 19.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 18.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1.60227) show
238.187500 19.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 18.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
0 0 1 r
.007 w
.02381 .44187 m
.02499 .44188 L
.02605 .44189 L
.02729 .44192 L
.02846 .44195 L
.03053 .44204 L
.03279 .44218 L
.03527 .44238 L
.0379 .44264 L
.04262 .44323 L
.04749 .44403 L
.05205 .44493 L
.06244 .44757 L
.07305 .45107 L
.08274 .45495 L
.10458 .46589 L
.14429 .4922 L
.18248 .52229 L
.22313 .55474 L
.26226 .58144 L
.27254 .5871 L
.28367 .59241 L
.29328 .59624 L
.29838 .59795 L
.30384 .59955 L
.30923 .60086 L
.31415 .60182 L
.31652 .6022 L
.31909 .60255 L
.32151 .60282 L
.32378 .60303 L
.32509 .60312 L
.3263 .60319 L
.32764 .60325 L
.32834 .60327 L
.32908 .60329 L
.32976 .60331 L
.33048 .60332 L
.33177 .60332 L
.33257 .60331 L
.33332 .6033 L
.33399 .60328 L
.33472 .60326 L
.33594 .60321 L
.33728 .60313 L
.33999 .60292 L
.34249 .60266 L
.34484 .60235 L
.34982 .60149 L
.35525 .60023 L
Mistroke
.36513 .59709 L
.37475 .59294 L
.38367 .58812 L
.40423 .57339 L
.42285 .55569 L
.46297 .50405 L
.50157 .43897 L
.54262 .35759 L
.58216 .27326 L
.62019 .19318 L
.66067 .11668 L
.69963 .05896 L
.70983 .04728 L
.72091 .03645 L
.73048 .02875 L
.73557 .02531 L
.74104 .02213 L
.74638 .01956 L
.75126 .01767 L
.75594 .01629 L
.75829 .01576 L
.76085 .0153 L
.76227 .01511 L
.76362 .01496 L
.76482 .01485 L
.76612 .01477 L
.7668 .01474 L
.76755 .01472 L
.76833 .01472 L
.76905 .01472 L
.77035 .01475 L
.77108 .01478 L
.77175 .01482 L
.77304 .01492 L
.77424 .01504 L
.77695 .01543 L
.77933 .0159 L
.78187 .01653 L
.78675 .0181 L
.79123 .01999 L
.80132 .02578 L
.81022 .03269 L
.81959 .04179 L
.83931 .06705 L
.85767 .09794 L
.89668 .18599 L
.93815 .30895 L
.97619 .44187 L
Mfstroke
1 0 0 r
.02381 .44187 m
.18254 .44187 L
.18254 .5012 L
.02381 .5012 L
F
.18254 .44187 m
.34127 .44187 L
.34127 .60194 L
.18254 .60194 L
F
.34127 .44187 m
.5 .44187 L
.5 .48754 L
.34127 .48754 L
F
.5 .44187 m
.65873 .44187 L
.65873 .16898 L
.5 .16898 L
F
.65873 .44187 m
.81746 .44187 L
.81746 .0199 L
.65873 .0199 L
F
.81746 .44187 m
.97619 .44187 L
.97619 .34785 L
.81746 .34785 L
F
0 g
.5 Mabswid
.02381 .44187 m
.02381 .5012 L
s
.18254 .44187 m
.18254 .5012 L
s
.02381 .5012 m
.18254 .5012 L
s
.18254 .44187 m
.18254 .60194 L
s
.34127 .44187 m
.34127 .60194 L
s
.18254 .60194 m
.34127 .60194 L
s
.34127 .44187 m
.34127 .48754 L
s
.5 .44187 m
.5 .48754 L
s
.34127 .48754 m
.5 .48754 L
s
.5 .44187 m
.5 .16898 L
s
.65873 .44187 m
.65873 .16898 L
s
.5 .16898 m
.65873 .16898 L
s
.65873 .44187 m
.65873 .0199 L
s
.81746 .44187 m
.81746 .0199 L
s
.65873 .0199 m
.81746 .0199 L
s
.81746 .44187 m
.81746 .34785 L
s
.97619 .44187 m
.97619 .34785 L
s
.81746 .34785 m
.97619 .34785 L
s
0 0 1 r
.007 w
.02381 .44187 m
.02499 .44188 L
.02605 .44189 L
.02729 .44192 L
.02846 .44195 L
.03053 .44204 L
.03279 .44218 L
.03527 .44238 L
.0379 .44264 L
.04262 .44323 L
.04749 .44403 L
.05205 .44493 L
.06244 .44757 L
.07305 .45107 L
.08274 .45495 L
.10458 .46589 L
.14429 .4922 L
.18248 .52229 L
.22313 .55474 L
.26226 .58144 L
.27254 .5871 L
.28367 .59241 L
.29328 .59624 L
.29838 .59795 L
.30384 .59955 L
.30923 .60086 L
.31415 .60182 L
.31652 .6022 L
.31909 .60255 L
.32151 .60282 L
.32378 .60303 L
.32509 .60312 L
.3263 .60319 L
.32764 .60325 L
.32834 .60327 L
.32908 .60329 L
.32976 .60331 L
.33048 .60332 L
.33177 .60332 L
.33257 .60331 L
.33332 .6033 L
.33399 .60328 L
.33472 .60326 L
.33594 .60321 L
.33728 .60313 L
.33999 .60292 L
.34249 .60266 L
.34484 .60235 L
.34982 .60149 L
.35525 .60023 L
Mistroke
.36513 .59709 L
.37475 .59294 L
.38367 .58812 L
.40423 .57339 L
.42285 .55569 L
.46297 .50405 L
.50157 .43897 L
.54262 .35759 L
.58216 .27326 L
.62019 .19318 L
.66067 .11668 L
.69963 .05896 L
.70983 .04728 L
.72091 .03645 L
.73048 .02875 L
.73557 .02531 L
.74104 .02213 L
.74638 .01956 L
.75126 .01767 L
.75594 .01629 L
.75829 .01576 L
.76085 .0153 L
.76227 .01511 L
.76362 .01496 L
.76482 .01485 L
.76612 .01477 L
.7668 .01474 L
.76755 .01472 L
.76833 .01472 L
.76905 .01472 L
.77035 .01475 L
.77108 .01478 L
.77175 .01482 L
.77304 .01492 L
.77424 .01504 L
.77695 .01543 L
.77933 .0159 L
.78187 .01653 L
.78675 .0181 L
.79123 .01999 L
.80132 .02578 L
.81022 .03269 L
.81959 .04179 L
.83931 .06705 L
.85767 .09794 L
.89668 .18599 L
.93815 .30895 L
.97619 .44187 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00O7Goo00<007ooOol0
ogoo0Goo000MOol00`00Oomoo`3oOol1Ool001eoo`03001oogoo0?moo`5oo`007Goo00<007ooOol0
]7oo1P0OAWoo000MOol2002bOol301l5Ool301m4Ool001eoo`03001oogoo09]ooa@000807`/000<0
7`D003aoo`007Goo00<007ooOol0Vgoo00<007`0O00047`000<07g`0O0003W`000D07g`0O01l0000
03aoo`007Goo00<007ooOol0Vgoo00<007`0O0003g`000<07g`0O00047`000@07g`0O00003aoo`00
7Goo0P00W7oo00<007`0O0003W`000<07g`0O0004W`000<07g`00000?7oo000MOol00`00Oomoo`2K
Ool00`00O01l000<O00201lFO0000`0O001oo`0kOol001eoo`03001oogoo09]oo`03001l07`000]l
000301ml07`001Ml000301moogoo03Yoo`007Goo00<007ooOol0Vgoo00<007`0O0002W`000<07g`0
O00067`000<07gooOol0>Woo000MOol2002LOol00`00O01l0009O0000`0OO01l000IO0000`0001mo
o`0jOol001eoo`03001oogoo09]oo`03001l07`000Ql000301ml07`001Yl0003001oo`0O03Yoo`00
7Goo00<007ooOol0Vgoo00<007`0O0001g`000<07g`0O0006g`000@007ooOol07cUoo`007Goo00<0
07ooOol0Vgoo00<007`0O0001g`000<07g`0O0006g`000D007ooOomoo`0O03Qoo`007Goo00<007oo
Ool0Vgoo00<007`0O0001W`000<07g`0O00077`000<007ooOol00Woo00<07gooOol0=Goo000MOol2
002LOol00`00O01l0005O0000`0OO01l000MO0000`00Oomoo`02Ool00`0OOomoo`0eOol001eoo`03
001oogoo09]oo`03001l07`000El000301ml07`001el0003001oogoo00=oo`0301moogoo03Aoo`00
5Woo0`0017oo00<007ooOol0Vgoo00<007`0O00017`000<07g`0O0007W`000<007ooOol017oo00<0
7gooOol0<goo000GOol00`00Oomoo`03Ool00`00Oomoo`2KOol00`00O01l0004O0000`0OO01l000N
O0000`00Oomoo`04Ool00`0OOomoo`0cOol000moo`D00003Ool00000008000Aoo`<009]oo`03001l
07`000=l000301ml07`001ml0003001oogoo00Eoo`0301moogoo039oo`005Goo00<007oo00001Goo
00<007ooOol0Vgoo00<007`0O0000W`000<07g`0O00087`000<007ooOol01Goo00<07gooOol0<Woo
000EOol00`00Ool00005Ool00`00Oomoo`2KOol00`00O01l0002O0000`0OO01l000PO0000`00Oomo
o`06Ool00`0OOomoo`0aOol001Ioo`8000Eoo`03001oogoo09]oo`05001l07`0O0007`0SO0000`00
Oomoo`07Ool00`0OOomoo`0`Ool001eoo`03001oogoo09]oo`05001l07`0O0007`0SO0000`00Oomo
o`07Ool00`0OOomoo`0`Ool001eoo`8009aoo`04001l07`001lTO0000`00Oomoo`08Ool00`0OOomo
o`0_Ool001eoo`03001oogoo09]oo`03001l000O02El0003001oogoo00Qoo`0301moogoo02moo`00
7Goo00<007ooOol0Vgoo00<007`001l09G`000<007ooOol027oo00<07gooOol0;goo000MOol00`00
Oomoo`2KOol00`0001ml000UO0000`00Oomoo`09Ool00`0OOomoo`0^Ool001eoo`8009aoo`030000
7g`002El0003001oogoo00Uoo`0301moogoo02ioo`007Goo00<007ooOol0Vgoo00<07g`0O0009G`0
00<007ooOol02Woo00<07gooOol0;Goo000MOol00`00Oomoo`2KOol00`0OO01l000UO0000`00Oomo
o`0:Ool00`0OOomoo`0]Ool001eoo`03001oogoo09Yoo`0301l007`002Il0003001oogoo00Yoo`03
01moogoo02eoo`007Goo0P00Vgoo00<07`00O0009W`000<007ooOol02goo00<07gooOol0;7oo000M
Ool00`00Oomoo`2IOol00`0OOol0000WO0000`00Oomoo`0;Ool00`0OOomoo`0/Ool001eoo`03001o
ogoo09Uoo`0301moo`0002Ml0003001oogoo00aoo`0301moogoo02]oo`007Goo00<007ooOol0V7oo
00@07gooOol002Ml0003001oogoo00aoo`0301moogoo02]oo`007Goo00<007ooOol0V7oo00@07goo
Ool002Ml0003001oogoo00eoo`0301moogoo02Yoo`007Goo0P00V7oo00D07gooOomoo`0002Ml0003
001oogoo00eoo`0301moogoo02Yoo`007Goo00<007ooOol0UWoo00<07gooOol00Woo00<007`0O000
9G`000<007ooOol03Goo00<07gooOol0:Woo000EOol30005Ool00`00Oomoo`2FOol00`0OOomoo`02
Ool00`00O01l000UO0000`00Oomoo`0>Ool00`0OOomoo`0YOol001Qoo`03001oogoo009oo`03001o
ogoo07Aoob40000301l0000000@002Ml0003001oogoo00ioo`0301moogoo02Uoo`003goo1@0017oo
00<007ooOol00Woo0`00M7oo00<007`0O0007W`000<07g`0O0000g`000<007`0O0009G`000<007oo
Ool03goo00<07gooOol0:7oo000FOol20005Ool00`00Oomoo`1dOol00`00O01l000MO0000`0OO01l
0004O0000`00O01l000UO0000`00Oomoo`0?Ool00`0OOomoo`0XOol001Qoo`03001oogoo009oo`03
001oogoo07Aoo`03001l07`001el000301ml07`000Al0003001l07`002El0003001oogoo00moo`03
01moogoo02Qoo`005Goo0`001Goo00<007ooOol0M7oo00<007`0O00077`000<07g`0O0001G`000<0
07`0O0009G`000<007ooOol047oo00<07gooOol09goo000MOol00`00Oomoo`1dOol00`00O01l000L
O0000`0OO01l0005O0000`00O01l000UO0000`00Oomoo`0@Ool00`0OOomoo`0WOol001eoo`8007Eo
o`03001l07`001]l000301ml07`000Il0003001l07`002El0003001oogoo015oo`0301moogoo02Io
o`007Goo00<007ooOol0M7oo00<007`0O0006g`000<07g`0O0001W`000<007`0O0009G`000<007oo
Ool04Goo00<07gooOol09Woo000MOol00`00Oomoo`1dOol00`00O01l000JO0000`0OO01l0007O000
0`00O01l000UO0000`00Oomoo`0AOol00`0OOomoo`0VOol001eoo`03001oogoo07Aoo`03001l07`0
01Yl000301ml07`000Ml0003001l07`002El0003001oogoo019oo`0301moogoo02Eoo`007Goo0P00
MGoo00<007`0O0006G`000<07g`0O00027`000<007`0O0009G`000<007ooOol04Woo00<07gooOol0
9Goo000MOol00`00Oomoo`1dOol00`00O01l000IO0000`0OO01l0008O0000`00O01l000UO0000`00
Oomoo`0BOol00`0OOomoo`0UOol001eoo`03001oogoo07Aoo`03001l07`001Ql000301ml07`000Ul
0003001l07`002El0003001oogoo01=oo`0301moogoo02Aoo`007Goo00<007ooOol0M7oo00<007`0
O00067`000<07g`0O0002G`000<007`0O0009G`000<007ooOol04goo00<07gooOol097oo000MOol0
0`00Oomoo`1dOol00`00O01l000GO0000`0OO01l000:O0000`00O01l000UO0000`00Oomoo`0COol0
0`0OOomoo`0TOol001eoo`8007Eoo`03001l07`001Ml000301ml07`000Yl0003001l07`002El0003
001oogoo01Aoo`0301moogoo02=oo`007Goo00<007ooOol0M7oo00<007`0O0005W`000<07g`0O000
2g`000<007`0O0009G`000<007ooOol057oo00<07gooOol08goo000MOol00`00Oomoo`1dOol00`00
O01l000FO0000`0OO01l000;O0000`00O01l000UO0000`00Oomoo`0EOol00`0OOomoo`0ROol001eo
o`03001oogoo07Aoo`03001l07`001El000301ml07`000al0003001l07`002El0003001oogoo01Eo
o`0301moogoo029oo`007Goo0P00MGoo00<007`0O0005G`000<07g`0O00037`000<007`0O0009G`0
00<007ooOol05Goo00<07gooOol08Woo000MOol00`00Oomoo`1dOol00`00O01l000DO0000`0OO01l
000=O0000`00O01l000UO0000`00Oomoo`0FOol00`0OOomoo`0QOol001Eoo`@000Aoo`03001oogoo
07Aoo`03001l07`001Al000301ml07`000el0003001l07`002El0003001oogoo01Ioo`0301moogoo
025oo`005Woo00<007ooOol017oo00<007ooOol0M7oo00<007`0O0004g`000<07g`0O0003W`000<0
07`0O0009G`000<007ooOol05Woo00<07gooOol08Goo000?Ool50003Ool00`00Oomoo`03Ool3001d
Ool00`00O01l000CO0000`0OO01l000>O0000`00O01l000UO0000`00Oomoo`0GOol00`0OOomoo`0P
Ool001Qoo`03001oogoo009oo`03001oogoo07Aoo`03001l07`0019l000301ml07`000ml0003001l
07`002El0003001oogoo01Moo`0301moogoo021oo`005Goo00@007ooOol000Aoo`03001oogoo07Ao
o`03001l07`0019l000301ml07`000ml0003001l07`002El0003001oogoo01Qoo`0301moogoo01mo
o`005Woo0P001Goo00<007ooOol0M7oo00<007`0O0004G`000<07g`0O00047`000<007`0O0009G`0
00<007ooOol067oo00<07gooOol07goo000MOol00`00Oomoo`1dOol00`00O01l000AO0000`0OO01l
000@O0000`00O01l000UO0000`00Oomoo`0HOol00`0OOomoo`0OOol001eoo`8007Eoo`03001l07`0
011l000301ml07`0015l0003001l07`002El0003001oogoo01Uoo`0301moogoo01ioo`007Goo00<0
07ooOol0M7oo00<007`0O00047`000<07g`0O0004G`000<007`0O0009G`000<007ooOol06Goo00<0
7gooOol07Woo000MOol00`00Oomoo`1dOol00`00O01l000?O0000`0OO01l000BO0000`00O01l000U
O0000`00Oomoo`0IOol00`0OOomoo`0NOol001eoo`03001oogoo07Aoo`03001l07`000ml000301ml
07`0019l0003001l07`002El0003001oogoo01Yoo`0301moogoo01eoo`007Goo0P00MGoo00<007`0
O0003W`000<07g`0O0004g`000<007`0O0009G`000<007ooOol06Woo00<07gooOol07Goo000MOol0
0`00Oomoo`1dOol00`00O01l000>O0000`0OO01l000CO0000`00O01l000UO0000`00Oomoo`0JOol0
0`0OOomoo`0MOol001eoo`03001oogoo07Aoo`03001l07`000el000301ml07`001Al0003001l07`0
02El0003001oogoo01]oo`0301moogoo01aoo`007Goo00<007ooOol0M7oo00<007`0O0003G`000<0
7g`0O00057`000<007`0O0009G`000<007ooOol06goo00<07gooOol077oo000MOol00`00Oomoo`1d
Ool00`00O01l000<O0000`0OO01l000EO0000`00O01l000UO0000`00Oomoo`0KOol00`0OOomoo`0L
Ool001eoo`8007Eoo`03001l07`000al000301ml07`001El0003001l07`002El0003001oogoo01ao
o`0301moogoo01]oo`007Goo00<007ooOol0M7oo00<007`0O00037`000<07g`0O0005G`000<007`0
O0009G`000<007ooOol077oo00<07gooOol06goo000MOol00`00Oomoo`1dOol00`00O01l000;O000
0`0OO01l000FO0000`00O01l000UO0000`00Oomoo`0LOol00`0OOomoo`0KOol001eoo`03001oogoo
07Aoo`03001l07`000]l000301ml07`001Il0003001l07`002El0003001oogoo01aoo`0301moogoo
01]oo`007Goo0P00MGoo00<007`0O0002W`000<07g`0O0005g`000<007`0O0009G`000<007ooOol0
7Goo00<07gooOol06Woo000MOol00`00Oomoo`1dOol00`00O01l000:O0000`0OO01l000GO0000`00
O01l000UO0000`00Oomoo`0MOol00`0OOomoo`0JOol001Eoo`<000Eoo`03001oogoo07Aoo`03001l
07`000Ul000301ml07`001Ql0003001l07`002El0003001oogoo01eoo`0301moogoo01Yoo`005Woo
00<007ooOol017oo00<007ooOol0M7oo00<007`0O0002G`000<07g`0O00067`000<007`0O0009G`0
8@0000<07`00000010005Goo000?Ool50002Ool00`00Oomoo`04Ool3001dOol00`00O01l0008O000
0`0OO01l000IO0000`00O01l000UO0000`00O01l000NO0000`0OO01l0003O0000`00Oomoo`0COol0
01Ioo`03001oogoo00Aoo`03001oogoo07Aoo`03001l07`000Ql000301ml07`001Ul0003001l07`0
02El0003001l07`001il000301ml07`000=l0003001oogoo01=oo`005Woo00<007ooOol017oo00<0
07ooOol0M7oo00<007`0O0001g`000<07g`0O0006W`000<007`0O0009G`000<007`0O0007W`000<0
7g`0O0000g`000<007ooOol04goo000EOol20006Ool00`00Oomoo`1dOol00`00O01l0007O0000`0O
O01l000JO0000`00O01l000UO0000`00O01l000OO0000`0OO01l0002O0000`00Oomoo`0COol001eo
o`03001oogoo07Aoo`03001l07`000Il000301ml07`001]l0003001l07`002El0003001l07`001ml
000301ml07`0009l0003001oogoo01=oo`007Goo0P00MGoo00<007`0O0001W`000<07g`0O0006g`0
00<007`0O0009G`000<007`0O0007g`000<07g`0O0000W`000<007ooOol04goo000MOol00`00Oomo
o`1dOol00`00O01l0005O0000`0OO01l000LO0000`00O01l000UO0000`00O01l000OO0000`0OO01l
0002O0000`00Oomoo`0COol001eoo`03001oogoo07Aoo`03001l07`000El000301ml07`001al0003
001l07`002El0003001l07`0021l000501ml07`0O000000EOol001eoo`03001oogoo07Aoo`03001l
07`000Al000301ml07`001el0003001l07`002El0003001l07`0021l000501ml07`0O000000EOol0
01eoo`8007Eoo`03001l07`000Al000301ml07`001el0003001l07`002El0003001l07`0021l0005
01ml07`0O000000EOol001eoo`03001oogoo07Aoo`03001l07`000=l000301ml07`001il0003001l
07`002El0003001l07`0021l000501ml07`0O000000EOol001eoo`03001oogoo07Aoo`03001l07`0
00=l000301ml07`001il0003001l07`002El0003001l07`0025l000401ml07`0000EOol001eoo`03
001oogoo025oo`<002=oo`@0025oo`<000Eoo`03001l07`0009l000301ml07`001ml0003001l07`0
02El0003001l07`0025l000401ml07`0000EOol001eoo`03001oogoo029oo`03001oogoo02=oo`03
001oogoo02Aoo`03001oogoo009oo`03001l07`0009l000301ml07`001ml0003001l07`002El0003
001l07`0025l000401ml07`0000EOol001eoo`8002=oo`03001oogoo02Aoo`03001oogoo02=oo`03
001oogoo009oo`05001l07`0O0007`0RO0000`00O01l000UO0000`00O01l000QO000100OO01l0000
5Goo000MOol00`00Oomoo`0ROol00`00Oomoo`0UOol00`00Oomoo`0POol20005Ool01@00O01l07`0
01l08W`000<007`0O0009G`000<007`0O0008W`000<07g`000005Goo000MOol00`00Oomoo`0ROol0
0`00Oomoo`0ROol01000Oomoo`0097oo00<007ooOol00Woo00@007`0O0007b=l0003001l07`002El
0003001l07`0029l000301ml000001Eoo`007Goo00<007ooOol08Goo0P009Goo0P008Woo0`001Goo
00@007`0O0007b=l0003001l07`002El0003001l07`0029l000301ml000001Eoo`007Goo0P00MGoo
00<007`001l097`000<007`0O0009G`000<007`0O0008g`000<07`00Ool057oo000MOol00`00Oomo
o`1dOol00`00O0007`0TO0000`00O01l000UO0000`00O01l000SO0000`0O001oo`0DOol001eoo`03
001oogoo07Aoo`0300007g`002Al0003001l07`002El0003001l07`002=l000301l007oo01Aoo`00
7Goo00<007ooOol0M7oo00<0000OO00097`000<007`0O0009G`000<007`0O0008g`000<07`00Ool0
57oo000MOol00`00Oomoo`1dOol00`0OO01l000TO0000`00O01l000UO0000`00O01l000TO0000`0O
Oomoo`0COol001Moo`H000X07fd0000301ml07`002Al0003001l07`002El0003001l07`002Al0003
01l0000000@000moo`007Goo00<007`0O0001g`00P0O77`000<007`0O00097`000<007`0O00097`0
00<07`00Ool07Woo00<007ooOol08goo00<007ooOol08Woo00<007ooOol07Woo000MOol00`00O01l
0009O00301lIO0000`00O01l000TO0000`00O01l000SO0000`0OO000002;Ool001eoo`03001l07`0
00al00807aMl0003001l07`002Al0003001l07`002=l000301ml000008]oo`007Goo00<007`0O000
3W`00P0O5G`000<007`0O00097`000<007`0O0008W`000@07g`0O00008]oo`007Goo00<007`0O000
47`000<07g`0O0004W`000<007`0O00097`000<007`0O0008W`000@07g`0O00008]oo`007Goo00<0
07`0O0004G`00P0O4W`000<007`0O00097`000<007`0O0008G`000D07g`0O01l000008]oo`007Goo
00<007`0O0004g`00P0O47`000<007`0O00097`000<007`0O00087`000<07g`0O0000W`000<007oo
Ool0RGoo000MOol00`00O01l000EO0000`0OO01l000=O0000`00O01l000TO0000`00O01l000PO000
0`0OO01l0002O0000`00Oomoo`29Ool001eoo`03001l07`001Il00807`el0003001l07`002Al0003
001l07`001ml000301ml07`000=l0003001oogoo08Uoo`007Goo00<007`0O00067`00P0O2g`000<0
07`0O00097`000<007`0O0007W`000<07g`0O00017`000<007ooOol0RGoo000MOol00`00O01l000J
O0000`0OO01l0008O0000`00O01l000TO00Q00000`0O00000005002;Ool001eoo`03001l07`001]l
00807`Ql0003001l07`002Al0003001oogoo01eoo`0301moogoo095oo`007Goo00<007`0O0007G`0
00<07g`0O0001G`000<007`0O00097`000<007ooOol07Goo00<07gooOol0TGoo000MOolQ00000`0O
00000005000VO0000`00Oomoo`0LOol00`0OOomoo`2BOol001eoo`03001oogoo01moo`0301moogoo
00=oo`03001l07`002Al0003001oogoo01]oo`0301moogoo09=oo`007Goo00<007ooOol087oo0P0O
0goo00<007`0O00097`000<007ooOol06goo00<07gooOol0Tgoo000MOol2000SOol0100OOomoo`00
9W`000<007ooOol06Woo00<07gooOol0U7oo000MOol00`00Oomoo`0SOol00`0OOol0000VO0000`00
Oomoo`0IOol00`0OOomoo`2EOol001eoo`03001oogoo02Aoo`0301l007`002El0003001oogoo01Qo
o`0301moogoo09Ioo`005Goo0`001Goo00<007ooOol09Goo0P0O9G`000<007ooOol067oo00<07goo
Ool0UWoo000FOol00`00Oomoo`04Ool00`00Oomoo`0UOol00`00O0007`0TO0000`00Oomoo`0GOol0
0`0OOomoo`2GOol001Ioo`03001oogoo00Aoo`<002Eoo`04001l07`001lSO0000`00Oomoo`0FOol0
0`0OOomoo`2HOol001Ioo`03001oogoo00Aoo`03001oogoo02Eoo`05001l07`0O0007`0RO0000`00
Oomoo`0EOol00`0OOomoo`2IOol001Ioo`03001oogoo00Aoo`03001oogoo02Eoo`03001l07`0009l
00807b1l0003001oogoo01Aoo`0301moogoo09Yoo`005Goo0P001Woo00<007ooOol09Goo00<007`0
O00017`000<07g`0O0007G`000<007ooOol057oo00<07gooOol0VWoo000MOol2000VOol00`00O01l
0005O0000`0OO01l000LO0000`00Oomoo`0COol00`0OOomoo`2KOol001eoo`03001oogoo02Eoo`03
001l07`000Il000301ml07`001]l0003001oogoo019oo`0301moogoo09aoo`007Goo00<007ooOol0
9Goo00<007`0O0001g`00P0O6g`000<007ooOol04Goo00<07gooOol0WGoo000MOol00`00Oomoo`0U
Ool00`00O01l0009O0000`0OO01l000HO0000`00Oomoo`0@Ool00`0OOomoo`2NOol001eoo`8002Io
o`03001l07`000Yl00807aQl0003001oogoo00moo`0301moogoo09moo`007Goo00<007ooOol09Goo
00<007`0O00037`000<07g`0O0005G`000<007ooOol03Woo00<07gooOol0X7oo000MOol00`00Oomo
o`0UOol00`00O01l000=O00201lEO0000`00Oomoo`0<Ool201nSOol001eoo`03001oogoo02Eoo`03
001l07`000ml000301ml07`0019l0003001oogoo00]oo`0301moogoo0:=oo`007Goo00<007ooOol0
9Goo00<007`0O00047`00P0O4W`000<007ooOol02Woo00<07gooOol0Y7oo000MOol2000VOol00`00
O01l000BO0000`0OO01l000?O0000`00Oomoo`09Ool00`0OOomoo`2UOol001eoo`03001oogoo02Eo
o`03001l07`001=l00<07`il0003001oogoo00Moo`807jQoo`007Goo00<007ooOol09Goo00<007`0
O0005W`00P0O37`000<007ooOol017oo0`0OZWoo000MOol00`00Oomoo`0UOol00`00O01l000HO003
01l9O0000`00Oomoo`02Ool201n]Ool001eoo`8002Iooah000@07`H000@07jmoo`007Goo00<007oo
Ool0Agoo1P0O/goo000MOol00`00Oomoo`3oOol1Ool001eoo`03001oogoo0?moo`5oo`007Goo00<0
07ooOol0ogoo0Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00?7oo1P001Woo0`000goo100017oo0`001Goo0`000goo100000=oo`00
00000P000Woo0P001Goo2P0000=oo`0000000P000Woo100017oo10000goo100067oo1P000goo0P00
1Goo0`001Goo10000goo1`000Woo1`001Goo00<007ooOol0=goo000nOol20007Ool20002Ool01000
Oomoogoo0P0017oo0P000Woo00@007ooOomoo`80009oo`04001oogooOol20003Ool20002Ool20000
0goo001oo`05Ool20005Ool200000goo00000004Ool20004Ool20002Ool20003Ool2000KOol20005
Ool20003Ool20002Ool20003Ool20002Ool20003Ool60003Ool60005Ool2000hOol003ioo`8000Io
o`8000Aoo`03001oogoo008000=oo`8000Aoo`04001oo`000004Ool00`00Oomoo`020003Ool20002
Ool20008Ool20006Ool01000Ool0000017oo0P000goo0P0017oo0P000Woo0P002Goo2@002Goo0P00
2Woo00<007ooOol00Woo0P000Woo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol00Woo00D0
07ooOomoo`0000Aoo`03001oogoo00=oo`03001oogoo03Ioo`00?Woo0P001Woo0P001goo0P000goo
0P001Woo0P001goo0P000goo0P000Woo0P0027oo0P0027oo0P0017oo0P000goo0P0017oo0P000Woo
0P006goo0P002Goo0P0017oo0P0000=oo`00000017oo0P000goo0P001goo0P002Goo00<007ooOol0
=Woo000nOol20006Ool20007Ool20003Ool20006Ool20007Ool20003Ool20002Ool20008Ool20004
Ool01000Oomoogoo0P0017oo0P000goo0P0017oo0P000Woo0P006goo0P002Goo0P0017oo0P0000=o
o`00000017oo0P0017oo00<007ooOol01Woo00<007ooOol01goo00<007ooOol0=Woo000nOol60002
Ool70002Ool20003Ool20004Ool00`00Ool000060002Ool20003Ool20002Ool20008Ool20004Ool0
1000Oomoogoo0P0017oo0P000goo0P0017oo0P000Woo0P006goo0P002Goo0P0017oo0P0000=oo`00
000017oo0P001Goo00<007ooOol01Woo00<007ooOol01goo00<007ooOol0=Goo000nOol20003Ool2
0002Ool01000Oomoogoo0P0000=oo`000000100000=oo`0000000Woo0P000Woo00@007ooOomoo`80
0003Ool000000080009oo`80009oo`8000Qoo`L0009oo``00003Ool00000009oo`80009oo`H000Io
o`T000Uoo`8000Uoo`<0009oo`80009oo`8000Aoo`8000Eoo`8000Moo`8000Qoo`03001oogoo03Eo
o`00?Woo0P0017oo0P000Woo100017oo00@007oo0000009oo`@000Aoo`@000Aoo`03001oo`000080
009oo`D000Ioo`8000Aoo`03001oogoo009oo`04001oo`000002Ool01000Ool000000Woo10001Goo
00@007oo000001Qoo`8000Uoo`800004Ool000000003Ool20004Ool20006Ool00`00Oomoo`06Ool0
0`00Oomoo`06Ool00`00Oomoo`0eOol003ioo`8000Aoo`8002Qoo`8000Qoo`8000Aoo`03001oogoo
03=oo`8000Yoo`8000Ioo`8000Aoo`8000Ioo`8000Moo`8000Qoo`03001oogoo03Aoo`00?Woo0P00
17oo0P00:Goo00<007ooOol01Woo0P00>Woo0P002Woo0P001Woo0P0017oo0P0000=oo`00Ool00goo
0P000Woo00<007ooOol00Woo0P0027oo00<007ooOol0=7oo000nOol20004Ool2000bOol20005Ool0
0`00Oomoo`0bOol2000;Ool20006Ool00`00Oomoo`02Ool00`00Oomoo`020002Ool30002Ool20002
Ool30002Ool20004Ool00`00Oomoo`0dOol003ioo`8000=oo`8003=oo`8000Eoo`03001oogoo031o
o`@000aoo`8000Eoo`80009oo`8000=oo`D000Aoo`D000Aoo`L003Eoo`00?7oo2000<Woo2P00=7oo
0P003Woo0`000goo10001Goo0`001Woo0`001Goo1`00=Goo003oOolQOol00?moob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.783823, -4.98036, 
  0.0265065, 0.0452841}}],

Cell[BoxData[
    FormBox[
      TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
        False,
        Editable->False], TraditionalForm]], "Output"]
}, Open  ]],

Cell[TextData[{
  "Using the ",
  StyleBox["Table",
    FontWeight->"Bold"],
  " command we can make an animation showing what happens as we take more and \
more rectangles. Information on animations can be found ",
  ButtonBox["here",
    ButtonData:>{"Mathematica_WorkShop.nb", "Animation"},
    ButtonStyle->"Hyperlink"],
  "."
}], "Text",
  FontSize->14]
}, Closed]],

Cell[CellGroupData[{

Cell["Animation", "Subsection"],

Cell[CellGroupData[{

Cell[TextData[
"Table[RiemannSum[x Sin[x],{x,0,2\[Pi]},i,Method->MidPoint],{i,2,15}]"], 
  "Input"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.151576 0.44187 0.0887232 [
[.17539 .42937 -3 -9 ]
[.17539 .42937 3 0 ]
[.32696 .42937 -3 -9 ]
[.32696 .42937 3 0 ]
[.47854 .42937 -3 -9 ]
[.47854 .42937 3 0 ]
[.63011 .42937 -3 -9 ]
[.63011 .42937 3 0 ]
[.78169 .42937 -3 -9 ]
[.78169 .42937 3 0 ]
[.93327 .42937 -3 -9 ]
[.93327 .42937 3 0 ]
[.01131 .08698 -12 -4.5 ]
[.01131 .08698 0 4.5 ]
[.01131 .1757 -12 -4.5 ]
[.01131 .1757 0 4.5 ]
[.01131 .26442 -12 -4.5 ]
[.01131 .26442 0 4.5 ]
[.01131 .35315 -12 -4.5 ]
[.01131 .35315 0 4.5 ]
[.01131 .53059 -6 -4.5 ]
[.01131 .53059 0 4.5 ]
[.5 .63053 -85.0938 0 ]
[.5 .63053 85.0938 20 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.17539 .44187 m
.17539 .44812 L
s
[(1)] .17539 .42937 0 1 Mshowa
.32696 .44187 m
.32696 .44812 L
s
[(2)] .32696 .42937 0 1 Mshowa
.47854 .44187 m
.47854 .44812 L
s
[(3)] .47854 .42937 0 1 Mshowa
.63011 .44187 m
.63011 .44812 L
s
[(4)] .63011 .42937 0 1 Mshowa
.78169 .44187 m
.78169 .44812 L
s
[(5)] .78169 .42937 0 1 Mshowa
.93327 .44187 m
.93327 .44812 L
s
[(6)] .93327 .42937 0 1 Mshowa
.125 Mabswid
.05412 .44187 m
.05412 .44562 L
s
.08444 .44187 m
.08444 .44562 L
s
.11476 .44187 m
.11476 .44562 L
s
.14507 .44187 m
.14507 .44562 L
s
.2057 .44187 m
.2057 .44562 L
s
.23602 .44187 m
.23602 .44562 L
s
.26633 .44187 m
.26633 .44562 L
s
.29665 .44187 m
.29665 .44562 L
s
.35728 .44187 m
.35728 .44562 L
s
.38759 .44187 m
.38759 .44562 L
s
.41791 .44187 m
.41791 .44562 L
s
.44822 .44187 m
.44822 .44562 L
s
.50885 .44187 m
.50885 .44562 L
s
.53917 .44187 m
.53917 .44562 L
s
.56948 .44187 m
.56948 .44562 L
s
.5998 .44187 m
.5998 .44562 L
s
.66043 .44187 m
.66043 .44562 L
s
.69074 .44187 m
.69074 .44562 L
s
.72106 .44187 m
.72106 .44562 L
s
.75137 .44187 m
.75137 .44562 L
s
.81201 .44187 m
.81201 .44562 L
s
.84232 .44187 m
.84232 .44562 L
s
.87264 .44187 m
.87264 .44562 L
s
.90295 .44187 m
.90295 .44562 L
s
.96358 .44187 m
.96358 .44562 L
s
.9939 .44187 m
.9939 .44562 L
s
.25 Mabswid
0 .44187 m
1 .44187 L
s
.02381 .08698 m
.03006 .08698 L
s
[(-4)] .01131 .08698 1 0 Mshowa
.02381 .1757 m
.03006 .1757 L
s
[(-3)] .01131 .1757 1 0 Mshowa
.02381 .26442 m
.03006 .26442 L
s
[(-2)] .01131 .26442 1 0 Mshowa
.02381 .35315 m
.03006 .35315 L
s
[(-1)] .01131 .35315 1 0 Mshowa
.02381 .53059 m
.03006 .53059 L
s
[(1)] .01131 .53059 1 0 Mshowa
.125 Mabswid
.02381 .016 m
.02756 .016 L
s
.02381 .03374 m
.02756 .03374 L
s
.02381 .05149 m
.02756 .05149 L
s
.02381 .06923 m
.02756 .06923 L
s
.02381 .10472 m
.02756 .10472 L
s
.02381 .12247 m
.02756 .12247 L
s
.02381 .14021 m
.02756 .14021 L
s
.02381 .15796 m
.02756 .15796 L
s
.02381 .19344 m
.02756 .19344 L
s
.02381 .21119 m
.02756 .21119 L
s
.02381 .22893 m
.02756 .22893 L
s
.02381 .24668 m
.02756 .24668 L
s
.02381 .28217 m
.02756 .28217 L
s
.02381 .29991 m
.02756 .29991 L
s
.02381 .31766 m
.02756 .31766 L
s
.02381 .3354 m
.02756 .3354 L
s
.02381 .37089 m
.02756 .37089 L
s
.02381 .38864 m
.02756 .38864 L
s
.02381 .40638 m
.02756 .40638 L
s
.02381 .42413 m
.02756 .42413 L
s
.02381 .45961 m
.02756 .45961 L
s
.02381 .47736 m
.02756 .47736 L
s
.02381 .4951 m
.02756 .4951 L
s
.02381 .51285 m
.02756 .51285 L
s
.02381 .54834 m
.02756 .54834 L
s
.02381 .56608 m
.02756 .56608 L
s
.02381 .58383 m
.02756 .58383 L
s
.02381 .60157 m
.02756 .60157 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -146.094 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 24.000000 moveto
 558.000000 24.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 24.000000 lineto
closepath
clip newpath
63.000000 19.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 18.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 19.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 18.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Percent) show
121.250000 19.000000 moveto
(Error) show
163.625000 19.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 18.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(=) show
179.687500 19.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 18.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(36.338) show
229.187500 19.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 18.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
0 0 1 r
.007 w
.02381 .44187 m
.02499 .44188 L
.02605 .44189 L
.02729 .44192 L
.02846 .44195 L
.03053 .44204 L
.03279 .44218 L
.03527 .44238 L
.0379 .44264 L
.04262 .44323 L
.04749 .44403 L
.05205 .44493 L
.06244 .44757 L
.07305 .45107 L
.08274 .45495 L
.10458 .46589 L
.14429 .4922 L
.18248 .52229 L
.22313 .55474 L
.26226 .58144 L
.27254 .5871 L
.28367 .59241 L
.29328 .59624 L
.29838 .59795 L
.30384 .59955 L
.30923 .60086 L
.31415 .60182 L
.31652 .6022 L
.31909 .60255 L
.32151 .60282 L
.32378 .60303 L
.32509 .60312 L
.3263 .60319 L
.32764 .60325 L
.32834 .60327 L
.32908 .60329 L
.32976 .60331 L
.33048 .60332 L
.33177 .60332 L
.33257 .60331 L
.33332 .6033 L
.33399 .60328 L
.33472 .60326 L
.33594 .60321 L
.33728 .60313 L
.33999 .60292 L
.34249 .60266 L
.34484 .60235 L
.34982 .60149 L
.35525 .60023 L
Mistroke
.36513 .59709 L
.37475 .59294 L
.38367 .58812 L
.40423 .57339 L
.42285 .55569 L
.46297 .50405 L
.50157 .43897 L
.54262 .35759 L
.58216 .27326 L
.62019 .19318 L
.66067 .11668 L
.69963 .05896 L
.70983 .04728 L
.72091 .03645 L
.73048 .02875 L
.73557 .02531 L
.74104 .02213 L
.74638 .01956 L
.75126 .01767 L
.75594 .01629 L
.75829 .01576 L
.76085 .0153 L
.76227 .01511 L
.76362 .01496 L
.76482 .01485 L
.76612 .01477 L
.7668 .01474 L
.76755 .01472 L
.76833 .01472 L
.76905 .01472 L
.77035 .01475 L
.77108 .01478 L
.77175 .01482 L
.77304 .01492 L
.77424 .01504 L
.77695 .01543 L
.77933 .0159 L
.78187 .01653 L
.78675 .0181 L
.79123 .01999 L
.80132 .02578 L
.81022 .03269 L
.81959 .04179 L
.83931 .06705 L
.85767 .09794 L
.89668 .18599 L
.93815 .30895 L
.97619 .44187 L
Mfstroke
1 0 0 r
.02381 .44187 m
.5 .44187 L
.5 .58124 L
.02381 .58124 L
F
.5 .44187 m
.97619 .44187 L
.97619 .02377 L
.5 .02377 L
F
0 g
.5 Mabswid
.02381 .44187 m
.02381 .58124 L
s
.5 .44187 m
.5 .58124 L
s
.02381 .58124 m
.5 .58124 L
s
.5 .44187 m
.5 .02377 L
s
.97619 .44187 m
.97619 .02377 L
s
.5 .02377 m
.97619 .02377 L
s
0 0 1 r
.007 w
.02381 .44187 m
.02499 .44188 L
.02605 .44189 L
.02729 .44192 L
.02846 .44195 L
.03053 .44204 L
.03279 .44218 L
.03527 .44238 L
.0379 .44264 L
.04262 .44323 L
.04749 .44403 L
.05205 .44493 L
.06244 .44757 L
.07305 .45107 L
.08274 .45495 L
.10458 .46589 L
.14429 .4922 L
.18248 .52229 L
.22313 .55474 L
.26226 .58144 L
.27254 .5871 L
.28367 .59241 L
.29328 .59624 L
.29838 .59795 L
.30384 .59955 L
.30923 .60086 L
.31415 .60182 L
.31652 .6022 L
.31909 .60255 L
.32151 .60282 L
.32378 .60303 L
.32509 .60312 L
.3263 .60319 L
.32764 .60325 L
.32834 .60327 L
.32908 .60329 L
.32976 .60331 L
.33048 .60332 L
.33177 .60332 L
.33257 .60331 L
.33332 .6033 L
.33399 .60328 L
.33472 .60326 L
.33594 .60321 L
.33728 .60313 L
.33999 .60292 L
.34249 .60266 L
.34484 .60235 L
.34982 .60149 L
.35525 .60023 L
Mistroke
.36513 .59709 L
.37475 .59294 L
.38367 .58812 L
.40423 .57339 L
.42285 .55569 L
.46297 .50405 L
.50157 .43897 L
.54262 .35759 L
.58216 .27326 L
.62019 .19318 L
.66067 .11668 L
.69963 .05896 L
.70983 .04728 L
.72091 .03645 L
.73048 .02875 L
.73557 .02531 L
.74104 .02213 L
.74638 .01956 L
.75126 .01767 L
.75594 .01629 L
.75829 .01576 L
.76085 .0153 L
.76227 .01511 L
.76362 .01496 L
.76482 .01485 L
.76612 .01477 L
.7668 .01474 L
.76755 .01472 L
.76833 .01472 L
.76905 .01472 L
.77035 .01475 L
.77108 .01478 L
.77175 .01482 L
.77304 .01492 L
.77424 .01504 L
.77695 .01543 L
.77933 .0159 L
.78187 .01653 L
.78675 .0181 L
.79123 .01999 L
.80132 .02578 L
.81022 .03269 L
.81959 .04179 L
.83931 .06705 L
.85767 .09794 L
.89668 .18599 L
.93815 .30895 L
.97619 .44187 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00O7Goo00<007ooOol0
ogoo0Goo000MOol00`00Oomoo`3oOol1Ool001eoo`03001oogoo0?moo`5oo`007Goo00<007ooOol0
]7oo1P0OAWoo000MOol2002bOol301l5Ool301m4Ool001eoo`03001oogoo07Aooc/000807`/000<0
7b`001Eoo`007Goo00<007ooOol0M7oo00<007`0O000=g`000<07g`0O0003W`000<07g`0O000:7`0
00<007ooOol04goo000MOol00`00Oomoo`1dOol00`00O01l000fO0000`0OO01l000@O0000`0OO01l
000WO0000`00Oomoo`0COol001eoo`8007Eoo`03001l07`003El000301ml07`0019l000301ml07`0
02Il0003001oogoo01=oo`007Goo00<007ooOol0M7oo00<007`0O000<g`00P0O5W`000<07g`0O000
9G`000<007ooOol04goo000MOol00`00Oomoo`1dOol00`00O01l000bO0000`0OO01l000GO0000`0O
O01l000TO0000`00Oomoo`0COol001eoo`03001oogoo07Aoo`03001l07`0035l000301ml07`001Ql
000301ml07`002Al0003001oogoo01=oo`007Goo0P00MGoo00<007`0O000<7`000<07g`0O0006W`0
00<07g`0O0008g`000<007ooOol04goo000MOol00`00Oomoo`1dOol00`00O01l000_O0000`0OO01l
000LO0000`0OO01l000RO0000`00Oomoo`0COol001eoo`03001oogoo07Aoo`03001l07`002il0003
01ml07`001il000301ml07`0025l0003001oogoo01=oo`007Goo00<007ooOol0M7oo00<007`0O000
;W`000<07g`0O0007g`000<07g`0O00087`000<007ooOol04goo000MOol00`00Oomoo`1dOol00`00
O01l000]O0000`0OO01l000QO0000`0OO01l000OO0000`00Oomoo`0COol001eoo`8007Eoo`03001l
07`002al000301ml07`0029l000301ml07`001ml0003001oogoo01=oo`007Goo00<007ooOol0M7oo
00<007`0O000;7`000<07g`0O0008g`000<07g`0O0007W`000<007ooOol04goo000FOol30004Ool0
0`00Oomoo`1dOol00`00O01l000[O0000`0OO01l000UO0000`0OO01l000MO0000`00Oomoo`0COol0
01Moo`03001oogoo00=oo`03001oogoo07Aoo`03001l07`002]l000301ml07`002El000301ml07`0
01el0003001oogoo01=oo`003goo1@0000=oo`0000000P0017oo0`00M7oo00<007`0O000:W`000<0
7g`0O0009g`000<07g`0O00077`000<007ooOol04goo000EOol00`00Ool00005Ool00`00Oomoo`1d
Ool00`00O01l000YO0000`0OO01l000XO0000`0OO01l000LO0000`00Oomoo`0COol001Eoo`03001o
o`0000Eoo`03001oogoo07Aoo`03001l07`002Ul000301ml07`002Ul000301ml07`001]l0003001o
ogoo01=oo`005Woo0P001Goo00<007ooOol0M7oo00<007`0O000:7`000<07g`0O000:g`000<07g`0
O0006W`000<007ooOol04goo000MOol00`00Oomoo`1dOol00`00O01l000XO0000`0OO01l000[O000
0`0OO01l000JO0000`00Oomoo`0COol001eoo`8007Eoo`03001l07`002Ml000301ml07`002el0003
01ml07`001Ul0003001oogoo01=oo`007Goo00<007ooOol0M7oo00<007`0O0009W`000<07g`0O000
;W`000<07g`0O0006G`000<007ooOol04goo000MOol00`00Oomoo`1dOol00`00O01l000VO0000`0O
O01l000^O0000`0OO01l000IO0000`00Oomoo`0COol001eoo`03001oogoo07Aoo`03001l07`002El
000301ml07`0031l000301ml07`001Ql0003001oogoo01=oo`007Goo0P00MGoo00<007`0O0009G`0
00<07g`0O000<7`000<07g`0O00067`000<007ooOol04goo000MOol00`00Oomoo`1dOol00`00O01l
000TO0000`0OO01l000bO0000`0OO01l000GO0000`00Oomoo`0COol001eoo`03001oogoo07Aoo`03
001l07`002Al000301ml07`0039l000301ml07`001Ml0003001oogoo01=oo`007Goo00<007ooOol0
M7oo00<007`0O0008g`000<07g`0O000<g`000<07g`0O0005g`000<007ooOol04goo000MOol2001e
Ool00`00O01l000SO0000`0OO01l000dO0000`0OO01l000FO0000`00Oomoo`0COol001eoo`03001o
ogoo07Aoo`03001l07`0029l000301ml07`003El000301ml07`001Il0003001oogoo01=oo`007Goo
00<007ooOol0M7oo00<007`0O0008W`000<07g`0O000=W`000<07g`0O0005G`000<007ooOol04goo
000MOol00`00Oomoo`1dOol00`00O01l000QO0000`0OO01l000gO0000`0OO01l000EO0000`00Oomo
o`0COol001eoo`03001oogoo07Aoo`03001l07`0025l000301ml07`003Ql000301ml07`001Al0003
001oogoo01=oo`007Goo0P00MGoo00<007`0O00087`000<07g`0O000>G`000<07g`0O00057`000<0
07ooOol04goo000MOol00`00Oomoo`1dOol00`00O01l000OO0000`0OO01l000jO0000`0OO01l000D
O0000`00Oomoo`0COol001Eoo`<000Eoo`03001oogoo07Aoo`03001l07`001ml000301ml07`003]l
000301ml07`001=l0003001oogoo01=oo`0067oo00<007ooOol00Woo00<007ooOol0M7oo00<007`0
O0007W`000<07g`0O000?7`000<07g`0O0004g`000<007ooOol04goo000?Ool50004Ool00`00Oomo
o`02Ool3001dOol00`00O01l000NO0000`0OO01l000mO0000`0OO01l000BO0000`00Oomoo`0COol0
01Ioo`8000Eoo`03001oogoo07Aoo`03001l07`001el000301ml07`003il000301ml07`0019l0003
001oogoo01=oo`0067oo00<007ooOol00Woo00<007ooOol0M7oo00<007`0O0007G`000<07g`0O000
?W`000<07g`0O0004W`000<007ooOol04goo000EOol30005Ool00`00Oomoo`1dOol00`00O01l000L
O0000`0OO01l0010O0000`0OO01l000AO0000`00Oomoo`0COol001eoo`03001oogoo07Aoo`03001l
07`001al000301ml07`0041l000301ml07`0015l0003001oogoo01=oo`007Goo0P00MGoo00<007`0
O0006g`000<07g`0O000@W`000<07g`0O00047`000<007ooOol04goo000MOol00`00Oomoo`1dOol0
0`00O01l000KO0000`0OO01l0012O0000`0OO01l000@O0000`00Oomoo`0COol001eoo`03001oogoo
07Aoo`03001l07`001Yl000301ml07`004=l000301ml07`0011l0003001oogoo01=oo`007Goo00<0
07ooOol0M7oo00<007`0O0006W`000<07g`0O000A7`000<07g`0O0003g`000<007ooOol04goo000M
Ool2001eOol00`00O01l000IO0000`0OO01l0015O0000`0OO01l000?O0000`00Oomoo`0COol001eo
o`03001oogoo07Aoo`03001l07`001Ul000301ml07`004El000301ml07`000ml0003001oogoo01=o
o`007Goo00<007ooOol0M7oo00<007`0O00067`000<07g`0O000Ag`000<07g`0O0003W`000<007oo
Ool04goo000MOol00`00Oomoo`1dOol00`00O01l000HO0000`0OO01l0017O0000`0OO01l000>O000
0`00Oomoo`0COol001eoo`03001oogoo07Aoo`03001l07`001Ml000301ml07`004Ql000301ml07`0
00il0003001oogoo01=oo`007Goo0P00MGoo00<007`0O0005g`000<07g`0O000BG`000<07g`0O000
3G`000<007ooOol04goo000MOol00`00Oomoo`1dOol00`00O01l000FO0000`0OO01l001:O0000`0O
O01l000=O0000`00Oomoo`0COol001eoo`03001oogoo07Aoo`03001l07`001Il000301ml07`004]l
000301ml07`000al0003001oogoo01=oo`007Goo00<007ooOol0M7oo00<007`0O0005G`000<07g`0
O000C7`000<07g`0O00037`000<007ooOol04goo000MOol2001eOol00`00O01l000EO0000`0OO01l
001<O0000`0OO01l000<O0000`00Oomoo`0COol001eoo`03001oogoo07Aoo`03001l07`001Al0003
01ml07`004il000301ml07`000]l0003001oogoo01=oo`005Goo100017oo00<007ooOol0M7oo00<0
07`0O00057`000<07g`0O000CW`000<07g`0O0002g`000<007ooOol04goo000FOol00`00Oomoo`04
Ool00`00Oomoo`1dOol00`00O01l000CO0000`0OO01l001?O0000`0OO01l000;O0000`00Oomoo`0C
Ool000moo`D000=oo`03001oogoo00=oo`<007Aoo`03001l07`001=l000301ml07`0051l000301ml
07`000Yl0003001oogoo01=oo`0067oo00<007ooOol00Woo00<007ooOol0M7oo00<007`0O0004W`0
00<07g`0O000DG`000<07g`0O0002W`000<007ooOol04goo000EOol01000Oomoo`0017oo00<007oo
Ool0M7oo00<007`0O0004W`000<07g`0O000DW`000<07g`0O0002G`000<007ooOol04goo000FOol2
0005Ool00`00Oomoo`1dOol00`00O01l000AO0000`0OO01l001CO0000`0OO01l0009O0000`00Oomo
o`0COol001eoo`03001oogoo07Aoo`03001l07`0015l000301ml07`005=l000301ml07`000Ul0003
001oogoo01=oo`007Goo0P00MGoo00<007`0O00047`000<07g`0O000EG`000<07g`0O00027`000<0
07ooOol04goo000MOol00`00Oomoo`1dOol00`00O01l000@O0000`0OO01l001EO0000`0OO01l0008
O0000`00Oomoo`0COol001eoo`03001oogoo07Aoo`03001l07`000ml000301ml07`005Il000301ml
07`000Ql0003001oogoo01=oo`007Goo00<007ooOol0M7oo00<007`0O0003g`000<07g`0O000Eg`0
00<07g`0O0001g`000<007ooOol04goo000MOol2001eOol00`00O01l000>O0000`0OO01l001HO000
0`0OO01l0007O0000`00Oomoo`0COol001eoo`03001oogoo07Aoo`03001l07`000il000301ml07`0
05Ql000301ml07`000Ml0003001oogoo01=oo`007Goo00<007ooOol0M7oo00<007`0O0003G`000<0
7g`0O000FW`000<07g`0O0001W`000<007ooOol04goo000MOol00`00Oomoo`1dOol00`00O01l000=
O0000`0OO01l001JO0000`0OO01l0006O0000`00Oomoo`0COol001eoo`03001oogoo07Aoo`03001l
07`000al000301ml07`005]l000301ml07`000Il0003001oogoo01=oo`007Goo0P00MGoo00<007`0
O00037`000<07g`0O000G7`000<07g`0O0001G`000<007ooOol04goo000MOol00`00Oomoo`1dOol0
0`00O01l000<O0000`0OO01l001LO0000`0OO01l0005O0000`00Oomoo`0COol001eoo`03001oogoo
07Aoo`03001l07`000]l000301ml07`005el000301ml07`000El0003001oogoo01=oo`007Goo00<0
07ooOol0M7oo00<007`0O0002g`000<07g`0O000GG`000<07g`0O0001G`000<007ooOol04goo000M
Ool2001eOol00`00O01l000:O0000`0OO01l001OO0000`0OO01l0004O0000`00Oomoo`0COol001eo
o`03001oogoo07Aoo`03001l07`000Yl000301ml07`005ml000301ml07`000Al0003001oogoo01=o
o`005Goo0`001Goo00<007ooOol0M7oo00<007`0O0002G`000<07g`0O000H7`000<07g`0O00017`0
00<007ooOol04goo000FOol00`00Oomoo`04Ool00`00Oomoo`1dOol00`00O01l0009O0000`0OO01l
001QO0000`0OO01l0003O0000`00Oomoo`0COol000moo`D0009oo`03001oogoo00Aoo`<007Aoo`03
001l07`000Ql000301ml07`0069l000301ml07`000=l0003001oogoo01=oo`005Woo00<007ooOol0
17oo00<007ooOol0M7oo00<007`0O00027`000<07g`0O000HW`000<07g`0O0000g`000<007ooOol0
4goo000FOol00`00Oomoo`04Ool00`00Oomoo`1dOol00`00O01l0007O0000`0OO01l001SO0000`0O
O01l0003O0000`00Oomoo`0COol001Eoo`8000Ioo`03001oogoo07Aoo`03001l07`000Ml000301ml
07`006Al000301ml07`0009l0003001oogoo01=oo`007Goo00<007ooOol0M7oo00<007`0O0001W`0
00<07g`0O000IG`000<07g`0O0000W`000<007ooOol04goo000MOol2001eOol00`00O01l0006O000
0`0OO01l001UO0000`0OO01l0002O0000`00Oomoo`0COol001eoo`03001oogoo07Aoo`03001l07`0
00El000301ml07`006Il000301ml07`0009l0003001oogoo01=oo`007Goo00<007ooOol0M7oo00<0
07`0O0001G`000<07g`0O000Ig`000D07g`0O01l000001Eoo`007Goo00<007ooOol0M7oo00<007`0
O00017`000<07g`0O000J7`000D07g`0O01l000001Eoo`007Goo0P00MGoo00<007`0O00017`000<0
7g`0O000J7`000D07g`0O01l000001Eoo`007Goo00<007ooOol0M7oo00<007`0O0000g`000<07g`0
O000JG`000D07g`0O01l000001Eoo`007Goo00<007ooOol0M7oo00<007`0O0000g`000<07g`0O000
JW`000@07g`0O00001Eoo`007Goo00<007ooOol08Goo0`008goo10008Goo0`001Goo00<007`0O000
0W`000<07g`0O000Jg`000@07g`0O00001Eoo`007Goo00<007ooOol08Woo00<007ooOol08goo00<0
07ooOol097oo00<007ooOol00Woo00<007`0O0000W`000<07g`0O000Jg`000@07g`0O00001Eoo`00
7Goo0P008goo00<007ooOol097oo00<007ooOol08goo00<007ooOol00Woo00D007`0O01l000O06il
000401ml07`0000EOol001eoo`03001oogoo029oo`03001oogoo02Eoo`03001oogoo021oo`8000Eo
o`05001l07`0O0007`1_O0000`0OO000000EOol001eoo`03001oogoo029oo`03001oogoo029oo`04
001oogoo000TOol00`00Oomoo`02Ool01000O01l000OL7`000<07g`000005Goo000MOol00`00Oomo
o`0QOol2000UOol2000ROol30005Ool01000O01l000OL7`000<07g`000005Goo000MOol2001eOol0
0`00O0007`1bO0000`0O001oo`0DOol001eoo`03001oogoo07Aoo`03001l000O079l000301l007oo
01Aoo`007Goo00<007ooOol0M7oo00<0000OO000LW`000<07`00Ool057oo000MOol00`00Oomoo`1d
Ool00`0001ml001bO0000`0O001oo`0DOol001eoo`03001oogoo07Aoo`0301ml07`007=l000301mo
ogoo01=oo`005goo1P002P0OK@0000<07g`0O000Lg`000<07`00000010003goo000MOol00`00O01l
0007O00201mZO0000`0O001oo`0NOol00`00Oomoo`0SOol00`00Oomoo`0ROol00`00Oomoo`0NOol0
01eoo`03001l07`000Ul00<07fIl000301ml000008]oo`007Goo00<007`0O00037`00P0OI7`000<0
7g`00000Rgoo000MOol00`00O01l000>O00201mQO000100OO01l0000Rgoo000MOol00`00O01l000@
O0000`0OO01l001NO000100OO01l0000Rgoo000MOol00`00O01l000AO00201mMO0001@0OO01l07`0
0000Rgoo000MOol00`00O01l000CO00201mJO0000`0OO01l0002O0000`00Oomoo`29Ool001eoo`03
001l07`001El000301ml07`005Ml000301ml07`0009l0003001oogoo08Uoo`007Goo00<007`0O000
5W`00P0OEW`000<07g`0O0000g`000<007ooOol0RGoo000MOol00`00O01l000HO00201mCO0000`0O
O01l0004O0000`00Oomoo`29Ool001eoo`03001l07`001Yl000301ml07`0051l000301ml07`000Al
0003001oogoo08Uoo`007Goo00<007`0O0006g`00P0OCg`000<07g`0O0001G`000<007ooOol0RGoo
000MOol00`00O01l000MO0000`0OO01l001<O0000`0OO01l0005O0000`00Oomoo`29Ool001eoo`03
001l07`001il000301ml07`004Yl000301ml07`000Il0003001oogoo08Uoo`007Goo00<007`0O000
7g`000<07g`0O000B7`000<07g`0O0001g`000<007ooOol0RGoo000MOol00`00O01l000PO00201m8
O0000`0OO01l0007O0000`00Oomoo`29Ool001eoo`03001l07`0029l000301ml07`004Al000301ml
07`000Ql0003001oogoo08Uoo`007Goo00<007`0O0008g`000<07g`0O000@W`000<07g`0O0002G`0
00<007ooOol0RGoo000MOol00`00O01l000TO0000`0OO01l0010O0000`0OO01l000:O0000`00Oomo
o`29Ool001Eoo`<000Eoo`03001l07`002El00807d1l000301ml07`000Yl0003001oogoo08Uoo`00
5Woo00<007ooOol017oo00<007`0O0009g`000<07g`0O000?7`000<07g`0O0002g`000<007ooOol0
RGoo000FOol00`00Oomoo`04Ool00`00O01l000XO0000`0OO01l000jO0000`0OO01l000<O0000`00
Oomoo`29Ool001Ioo`03001oogoo00Aoo`03001l07`002Ul000301ml07`003Ql000301ml07`000el
0003001oogoo08Uoo`005Woo00<007ooOol017oo00<007`0O000:W`00P0O=g`000<07g`0O0003W`0
00<007ooOol0RGoo000EOol20006Ool00`00O01l000/O0000`0OO01l000dO0000`0OO01l000>O000
0`00Oomoo`29Ool001eoo`03001l07`002el000301ml07`0039l000301ml07`000ml0003001oogoo
08Uoo`007Goo00<007`0O000;W`000<07g`0O000<7`000<07g`0O00047`000<007ooOol0RGoo000M
Ool00`00O01l000_O00201l_O0000`0OO01l000AO0000`00Oomoo`29Ool001eoo`03001l07`0035l
000301ml07`002]l000301ml07`0019l0003001oogoo08Uoo`007Goo00<007`0O000<W`00P0O:W`0
00<07g`0O0004g`000<007ooOol0RGoo000MOol00`00O01l000dO0000`0OO01l000VO0000`0OO01l
000DO0000`00Oomoo`29Ool001eoo`03001l07`003El00807bAl00807aMl0003001oogoo08Uoo`00
7Goo00<007`0O000=g`000<07g`0O00087`000<07g`0O0005g`000<007ooOol0RGoo000MOolk0002
01lO00000`0O0000000I002;Ool001eoo`8003]oo`0301moogoo01]oo`0301moogoo0:Eoo`007Goo
00<007ooOol0>goo0`0O67oo0P0OZ7oo000MOol00`00Oomoo`0nOol201lCOol301nZOol001eoo`03
001oogoo041oo`<07`ioo`807jeoo`007Goo0P00A7oo100O1Woo100O[goo000MOol00`00Oomoo`17
Ool601ncOol001eoo`03001oogoo0?moo`5oo`007Goo00<007ooOol0ogoo0Goo000MOol00`00Oomo
o`3oOol1Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00ogoo8Goo0011Ool60006Ool30003Ool40004Ool30005Ool30003Ool400000goo00000002
0002Ool20005Ool:00000goo000000020002Ool40004Ool40003Ool4000FOol50007Ool30004Ool2
0002Ool50004Ool50006Ool4000lOol004=oo`8000Moo`80009oo`04001oogooOol20004Ool20002
Ool01000Oomoogoo0P000Woo00@007ooOomoo`8000=oo`80009oo`800003Ool007oo00Eoo`8000Eo
o`800003Ool0000000Aoo`8000Aoo`80009oo`8000=oo`8001Moo`8000=oo`8000=oo`80009oo`80
00=oo`80009oo`8000=oo`80009oo`8000=oo`8000=oo`80009oo`8003]oo`00@goo0P001Woo0P00
17oo00<007ooOol00P000goo0P0017oo00@007oo000000Aoo`03001oogoo008000=oo`80009oo`80
00Qoo`8000Ioo`04001oo`000004Ool20003Ool20004Ool20002Ool20008Ool9000<Ool01@00Oomo
ogoo000017oo0P0037oo00<007ooOol01Woo00<007ooOol00P0017oo0P00>Woo0013Ool20006Ool2
0007Ool20003Ool20006Ool20007Ool20003Ool20002Ool20008Ool20008Ool20004Ool20003Ool2
0004Ool20002Ool2000MOol200000goo00000004Ool2000<Ool20007Ool200000goo00000004Ool2
000jOol004=oo`8000Ioo`8000Moo`8000=oo`8000Ioo`8000Moo`8000=oo`80009oo`8000Qoo`80
00Aoo`04001oogooOol20004Ool20003Ool20004Ool20002Ool2000MOol200000goo00000004Ool2
000<Ool20007Ool200000goo00000003Ool3000jOol004=oo`H0009oo`L0009oo`8000=oo`8000Ao
o`03001oo`0000H0009oo`8000=oo`80009oo`8000Qoo`8000Aoo`04001oogooOol20004Ool20003
Ool20004Ool20002Ool2000MOol200000goo00000004Ool2000<Ool20007Ool20002Ool2000017oo
00000000>goo0013Ool20003Ool20002Ool01000Oomoogoo0P0000=oo`000000100000=oo`000000
0Woo0P000Woo00@007ooOomoo`800003Ool000000080009oo`80009oo`8000Qoo`L0009oo``00003
Ool00000009oo`80009oo`H000Eoo`T000]oo`<00004Ool000000002Ool2000<Ool30006Ool30003
Ool4000lOol004=oo`8000Aoo`80009oo`@000Aoo`04001oo`000002Ool40004Ool40004Ool00`00
Ool000020002Ool50006Ool20004Ool00`00Oomoo`02Ool01000Ool000000Woo00@007oo0000009o
o`@000Eoo`04001oo`00000FOol50002Ool2000017oo000000002Woo1@0017oo1@000goo1@00?7oo
0013Ool20004Ool2000XOol20008Ool20004Ool00`00Oomoo`0cOol00`00Oomoo`03Ool2000?Ool0
0`00Oomoo`06Ool00`00Oomoo`03Ool20002Ool2000kOol004=oo`8000Aoo`8002Uoo`03001oogoo
00Ioo`8003]oo`03001oogoo009oo`80011oo`03001oogoo00Ioo`04001oogooOol20004Ool2000j
Ool004=oo`8000Aoo`80039oo`8000Eoo`03001oogoo02ioo`03001oogoo009oo`8000Aoo`8000Yo
o`03001oogoo009oo`80009oo`03001oogoo009oo`80009oo`8000Aoo`8003Yoo`00@goo0P000goo
0P00<goo0P001Goo00<007ooOol0;goo00<007ooOol00`001Goo0P002Woo00<007ooOol00`000goo
00<007ooOol00`000goo0P000Woo0P00>goo0011Ool8000bOol:000bOol40008Ool30008Ool40005
Ool40005Ool4000lOol00?moob5oo`00ogoo8Goo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.783823, -4.98036, 
  0.0265065, 0.0452841}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.151576 0.44187 0.0887232 [
[.17539 .42937 -3 -9 ]
[.17539 .42937 3 0 ]
[.32696 .42937 -3 -9 ]
[.32696 .42937 3 0 ]
[.47854 .42937 -3 -9 ]
[.47854 .42937 3 0 ]
[.63011 .42937 -3 -9 ]
[.63011 .42937 3 0 ]
[.78169 .42937 -3 -9 ]
[.78169 .42937 3 0 ]
[.93327 .42937 -3 -9 ]
[.93327 .42937 3 0 ]
[.01131 .08698 -12 -4.5 ]
[.01131 .08698 0 4.5 ]
[.01131 .1757 -12 -4.5 ]
[.01131 .1757 0 4.5 ]
[.01131 .26442 -12 -4.5 ]
[.01131 .26442 0 4.5 ]
[.01131 .35315 -12 -4.5 ]
[.01131 .35315 0 4.5 ]
[.01131 .53059 -6 -4.5 ]
[.01131 .53059 0 4.5 ]
[.5 .63053 -89.5938 0 ]
[.5 .63053 89.5938 20 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.17539 .44187 m
.17539 .44812 L
s
[(1)] .17539 .42937 0 1 Mshowa
.32696 .44187 m
.32696 .44812 L
s
[(2)] .32696 .42937 0 1 Mshowa
.47854 .44187 m
.47854 .44812 L
s
[(3)] .47854 .42937 0 1 Mshowa
.63011 .44187 m
.63011 .44812 L
s
[(4)] .63011 .42937 0 1 Mshowa
.78169 .44187 m
.78169 .44812 L
s
[(5)] .78169 .42937 0 1 Mshowa
.93327 .44187 m
.93327 .44812 L
s
[(6)] .93327 .42937 0 1 Mshowa
.125 Mabswid
.05412 .44187 m
.05412 .44562 L
s
.08444 .44187 m
.08444 .44562 L
s
.11476 .44187 m
.11476 .44562 L
s
.14507 .44187 m
.14507 .44562 L
s
.2057 .44187 m
.2057 .44562 L
s
.23602 .44187 m
.23602 .44562 L
s
.26633 .44187 m
.26633 .44562 L
s
.29665 .44187 m
.29665 .44562 L
s
.35728 .44187 m
.35728 .44562 L
s
.38759 .44187 m
.38759 .44562 L
s
.41791 .44187 m
.41791 .44562 L
s
.44822 .44187 m
.44822 .44562 L
s
.50885 .44187 m
.50885 .44562 L
s
.53917 .44187 m
.53917 .44562 L
s
.56948 .44187 m
.56948 .44562 L
s
.5998 .44187 m
.5998 .44562 L
s
.66043 .44187 m
.66043 .44562 L
s
.69074 .44187 m
.69074 .44562 L
s
.72106 .44187 m
.72106 .44562 L
s
.75137 .44187 m
.75137 .44562 L
s
.81201 .44187 m
.81201 .44562 L
s
.84232 .44187 m
.84232 .44562 L
s
.87264 .44187 m
.87264 .44562 L
s
.90295 .44187 m
.90295 .44562 L
s
.96358 .44187 m
.96358 .44562 L
s
.9939 .44187 m
.9939 .44562 L
s
.25 Mabswid
0 .44187 m
1 .44187 L
s
.02381 .08698 m
.03006 .08698 L
s
[(-4)] .01131 .08698 1 0 Mshowa
.02381 .1757 m
.03006 .1757 L
s
[(-3)] .01131 .1757 1 0 Mshowa
.02381 .26442 m
.03006 .26442 L
s
[(-2)] .01131 .26442 1 0 Mshowa
.02381 .35315 m
.03006 .35315 L
s
[(-1)] .01131 .35315 1 0 Mshowa
.02381 .53059 m
.03006 .53059 L
s
[(1)] .01131 .53059 1 0 Mshowa
.125 Mabswid
.02381 .016 m
.02756 .016 L
s
.02381 .03374 m
.02756 .03374 L
s
.02381 .05149 m
.02756 .05149 L
s
.02381 .06923 m
.02756 .06923 L
s
.02381 .10472 m
.02756 .10472 L
s
.02381 .12247 m
.02756 .12247 L
s
.02381 .14021 m
.02756 .14021 L
s
.02381 .15796 m
.02756 .15796 L
s
.02381 .19344 m
.02756 .19344 L
s
.02381 .21119 m
.02756 .21119 L
s
.02381 .22893 m
.02756 .22893 L
s
.02381 .24668 m
.02756 .24668 L
s
.02381 .28217 m
.02756 .28217 L
s
.02381 .29991 m
.02756 .29991 L
s
.02381 .31766 m
.02756 .31766 L
s
.02381 .3354 m
.02756 .3354 L
s
.02381 .37089 m
.02756 .37089 L
s
.02381 .38864 m
.02756 .38864 L
s
.02381 .40638 m
.02756 .40638 L
s
.02381 .42413 m
.02756 .42413 L
s
.02381 .45961 m
.02756 .45961 L
s
.02381 .47736 m
.02756 .47736 L
s
.02381 .4951 m
.02756 .4951 L
s
.02381 .51285 m
.02756 .51285 L
s
.02381 .54834 m
.02756 .54834 L
s
.02381 .56608 m
.02756 .56608 L
s
.02381 .58383 m
.02756 .58383 L
s
.02381 .60157 m
.02756 .60157 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -150.594 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 24.000000 moveto
 558.000000 24.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 24.000000 lineto
closepath
clip newpath
63.000000 19.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 18.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 19.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 18.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Percent) show
121.250000 19.000000 moveto
(Error) show
163.625000 19.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 18.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(=) show
179.687500 19.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 18.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(17.3007) show
238.187500 19.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 18.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
0 0 1 r
.007 w
.02381 .44187 m
.02499 .44188 L
.02605 .44189 L
.02729 .44192 L
.02846 .44195 L
.03053 .44204 L
.03279 .44218 L
.03527 .44238 L
.0379 .44264 L
.04262 .44323 L
.04749 .44403 L
.05205 .44493 L
.06244 .44757 L
.07305 .45107 L
.08274 .45495 L
.10458 .46589 L
.14429 .4922 L
.18248 .52229 L
.22313 .55474 L
.26226 .58144 L
.27254 .5871 L
.28367 .59241 L
.29328 .59624 L
.29838 .59795 L
.30384 .59955 L
.30923 .60086 L
.31415 .60182 L
.31652 .6022 L
.31909 .60255 L
.32151 .60282 L
.32378 .60303 L
.32509 .60312 L
.3263 .60319 L
.32764 .60325 L
.32834 .60327 L
.32908 .60329 L
.32976 .60331 L
.33048 .60332 L
.33177 .60332 L
.33257 .60331 L
.33332 .6033 L
.33399 .60328 L
.33472 .60326 L
.33594 .60321 L
.33728 .60313 L
.33999 .60292 L
.34249 .60266 L
.34484 .60235 L
.34982 .60149 L
.35525 .60023 L
Mistroke
.36513 .59709 L
.37475 .59294 L
.38367 .58812 L
.40423 .57339 L
.42285 .55569 L
.46297 .50405 L
.50157 .43897 L
.54262 .35759 L
.58216 .27326 L
.62019 .19318 L
.66067 .11668 L
.69963 .05896 L
.70983 .04728 L
.72091 .03645 L
.73048 .02875 L
.73557 .02531 L
.74104 .02213 L
.74638 .01956 L
.75126 .01767 L
.75594 .01629 L
.75829 .01576 L
.76085 .0153 L
.76227 .01511 L
.76362 .01496 L
.76482 .01485 L
.76612 .01477 L
.7668 .01474 L
.76755 .01472 L
.76833 .01472 L
.76905 .01472 L
.77035 .01475 L
.77108 .01478 L
.77175 .01482 L
.77304 .01492 L
.77424 .01504 L
.77695 .01543 L
.77933 .0159 L
.78187 .01653 L
.78675 .0181 L
.79123 .01999 L
.80132 .02578 L
.81022 .03269 L
.81959 .04179 L
.83931 .06705 L
.85767 .09794 L
.89668 .18599 L
.93815 .30895 L
.97619 .44187 L
Mfstroke
1 0 0 r
.02381 .44187 m
.34127 .44187 L
.34127 .52233 L
.02381 .52233 L
F
.34127 .44187 m
.65873 .44187 L
.65873 .44187 L
.34127 .44187 L
F
.65873 .44187 m
.97619 .44187 L
.97619 .03955 L
.65873 .03955 L
F
0 g
.5 Mabswid
.02381 .44187 m
.02381 .52233 L
s
.34127 .44187 m
.34127 .52233 L
s
.02381 .52233 m
.34127 .52233 L
s
.34127 .44187 m
.34127 .44187 L
s
.65873 .44187 m
.65873 .44187 L
s
.34127 .44187 m
.65873 .44187 L
s
.65873 .44187 m
.65873 .03955 L
s
.97619 .44187 m
.97619 .03955 L
s
.65873 .03955 m
.97619 .03955 L
s
0 0 1 r
.007 w
.02381 .44187 m
.02499 .44188 L
.02605 .44189 L
.02729 .44192 L
.02846 .44195 L
.03053 .44204 L
.03279 .44218 L
.03527 .44238 L
.0379 .44264 L
.04262 .44323 L
.04749 .44403 L
.05205 .44493 L
.06244 .44757 L
.07305 .45107 L
.08274 .45495 L
.10458 .46589 L
.14429 .4922 L
.18248 .52229 L
.22313 .55474 L
.26226 .58144 L
.27254 .5871 L
.28367 .59241 L
.29328 .59624 L
.29838 .59795 L
.30384 .59955 L
.30923 .60086 L
.31415 .60182 L
.31652 .6022 L
.31909 .60255 L
.32151 .60282 L
.32378 .60303 L
.32509 .60312 L
.3263 .60319 L
.32764 .60325 L
.32834 .60327 L
.32908 .60329 L
.32976 .60331 L
.33048 .60332 L
.33177 .60332 L
.33257 .60331 L
.33332 .6033 L
.33399 .60328 L
.33472 .60326 L
.33594 .60321 L
.33728 .60313 L
.33999 .60292 L
.34249 .60266 L
.34484 .60235 L
.34982 .60149 L
.35525 .60023 L
Mistroke
.36513 .59709 L
.37475 .59294 L
.38367 .58812 L
.40423 .57339 L
.42285 .55569 L
.46297 .50405 L
.50157 .43897 L
.54262 .35759 L
.58216 .27326 L
.62019 .19318 L
.66067 .11668 L
.69963 .05896 L
.70983 .04728 L
.72091 .03645 L
.73048 .02875 L
.73557 .02531 L
.74104 .02213 L
.74638 .01956 L
.75126 .01767 L
.75594 .01629 L
.75829 .01576 L
.76085 .0153 L
.76227 .01511 L
.76362 .01496 L
.76482 .01485 L
.76612 .01477 L
.7668 .01474 L
.76755 .01472 L
.76833 .01472 L
.76905 .01472 L
.77035 .01475 L
.77108 .01478 L
.77175 .01482 L
.77304 .01492 L
.77424 .01504 L
.77695 .01543 L
.77933 .0159 L
.78187 .01653 L
.78675 .0181 L
.79123 .01999 L
.80132 .02578 L
.81022 .03269 L
.81959 .04179 L
.83931 .06705 L
.85767 .09794 L
.89668 .18599 L
.93815 .30895 L
.97619 .44187 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00O7Goo00<007ooOol0
ogoo0Goo000MOol00`00Oomoo`3oOol1Ool001eoo`03001oogoo0?moo`5oo`007Goo00<007ooOol0
]7oo1P0OAWoo000MOol2002bOol301l5Ool301m4Ool001eoo`03001oogoo0:moo`807`]oo`<07d5o
o`007Goo00<007ooOol0[Woo00<07gooOol03Woo00<07gooOol0?Woo000MOol00`00Oomoo`2]Ool0
0`0OOomoo`0@Ool00`0OOomoo`0mOol001eoo`800:eoo`0301moogoo019oo`0301moogoo03aoo`00
7Goo00<007ooOol0Vgoo3`000P0O5P0000<07`0000009P005Goo000MOol00`00Oomoo`2KOol00`00
O01l000;O0000`0OO01l000GO0000`0OO01l000TO0000`00Oomoo`0COol001eoo`03001oogoo09]o
o`03001l07`000Yl000301ml07`001Ql000301ml07`002Al0003001oogoo01=oo`007Goo0P00W7oo
00<007`0O0002G`000<07g`0O0006W`000<07g`0O0008g`000<007ooOol04goo000MOol00`00Oomo
o`2KOol00`00O01l0008O0000`0OO01l000LO0000`0OO01l000RO0000`00Oomoo`0COol001eoo`03
001oogoo09]oo`03001l07`000Ml000301ml07`001il000301ml07`0025l0003001oogoo01=oo`00
7Goo00<007ooOol0Vgoo00<007`0O0001g`000<07g`0O0007g`000<07g`0O00087`000<007ooOol0
4goo000MOol00`00Oomoo`2KOol00`00O01l0006O0000`0OO01l000QO0000`0OO01l000OO0000`00
Oomoo`0COol001eoo`8009aoo`03001l07`000El000301ml07`0029l000301ml07`001ml0003001o
ogoo01=oo`007Goo00<007ooOol0Vgoo00<007`0O0001G`000<07g`0O0008g`000<07g`0O0007W`0
00<007ooOol04goo000FOol30004Ool00`00Oomoo`2KOol00`00O01l0004O0000`0OO01l000UO000
0`0OO01l000MO0000`00Oomoo`0COol001Moo`03001oogoo00=oo`03001oogoo09]oo`03001l07`0
00Al000301ml07`002El000301ml07`001el0003001oogoo01=oo`003goo1@0000=oo`0000000P00
17oo0`00Vgoo00<007`0O0000g`000<07g`0O0009g`000<07g`0O00077`000<007ooOol04goo000E
Ool00`00Ool00005Ool00`00Oomoo`2KOol00`00O01l0002O0000`0OO01l000XO0000`0OO01l000L
O0000`00Oomoo`0COol001Eoo`03001oo`0000Eoo`03001oogoo09]oo`03001l07`0009l000301ml
07`002Ul000301ml07`001]l0003001oogoo01=oo`005Woo0P001Goo00<007ooOol0Vgoo00D007`0
O01l000O02el000301ml07`001Yl0003001oogoo01=oo`007Goo00<007ooOol0Vgoo00D007`0O01l
000O02el000301ml07`001Yl0003001oogoo01=oo`007Goo0P00W7oo00@007`0O0007bml000301ml
07`001Ul0003001oogoo01=oo`007Goo00<007ooOol0Vgoo00<007`001l0<7`000<07g`0O0006G`0
00<007ooOol04goo000MOol00`00Oomoo`2KOol00`00O0007`0`O0000`0OO01l000IO0000`00Oomo
o`0COol001eoo`03001oogoo09]oo`0300007g`0035l000301ml07`001Ql0003001oogoo01=oo`00
7Goo0P00W7oo00<0000OO000<G`000<07g`0O00067`000<007ooOol04goo000MOol00`00Oomoo`2K
Ool00`0OO01l000bO0000`0OO01l000GO0000`00Oomoo`0COol001eoo`03001oogoo09]oo`0301ml
07`0039l000301ml07`001Ml0003001oogoo01=oo`007Goo00<007ooOol0VWoo00<07`00O000<g`0
00<07g`0O0005g`000<007ooOol04goo000MOol2002KOol00`0O001l000dO0000`0OO01l000FO000
0`00Oomoo`0COol001eoo`03001oogoo09Uoo`0301moo`0003El000301ml07`001Il0003001oogoo
01=oo`007Goo00<007ooOol0VGoo00<07goo0000=W`000<07g`0O0005G`000<007ooOol04goo000M
Ool00`00Oomoo`2HOol0100OOomoo`00=W`000<07g`0O0005G`000<007ooOol04goo000MOol00`00
Oomoo`2HOol0100OOomoo`00=g`000<07g`0O00057`000<007ooOol04goo000MOol2002HOol01@0O
Oomoogoo0000=g`000<07g`0O00057`000<007ooOol04goo000MOol00`00Oomoo`2FOol00`0OOomo
o`02Ool00`00O01l000eO0000`0OO01l000DO0000`00Oomoo`0COol001Eoo`<000Eoo`03001oogoo
09Ioo`0301moogoo009oo`03001l07`003Il000301ml07`001=l0003001oogoo01=oo`0067oo00<0
07ooOol00Woo00<007ooOol0UGoo00<07gooOol00goo00<007`0O000=W`000<07g`0O0004g`000<0
07ooOol04goo000?Ool50004Ool00`00Oomoo`02Ool3002EOol00`0OOomoo`03Ool00`00O01l000g
O0000`0OO01l000BO0000`00Oomoo`0COol001Ioo`8000Eoo`03001oogoo09Aoo`0301moogoo00Ao
o`03001l07`003Ml000301ml07`0019l0003001oogoo01=oo`0067oo00<007ooOol00Woo00<007oo
Ool0U7oo00<07gooOol017oo00<007`0O000=g`000<07g`0O0004W`000<007ooOol04goo000EOol3
0005Ool00`00Oomoo`2COol00`0OOomoo`05Ool00`00O01l000hO0000`0OO01l000AO0000`00Oomo
o`0COol001eoo`03001oogoo09=oo`0301moogoo00Eoo`03001l07`003Ql000301ml07`0015l0003
001oogoo01=oo`007Goo0P00Tgoo00<07gooOol01Woo00<007`0O000>G`000<07g`0O00047`000<0
07ooOol04goo000MOol00`00Oomoo`2BOol00`0OOomoo`06Ool00`00O01l000iO0000`0OO01l000@
O0000`00Oomoo`0COol001eoo`03001oogoo095oo`0301moogoo00Moo`03001l07`003Ul000301ml
07`0011l0003001oogoo01=oo`007Goo00<007ooOol0TGoo00<07gooOol01goo00<007`0O000>W`0
00<07g`0O0003g`000<007ooOol04goo000MOol2002AOol00`0OOomoo`08Ool00`00O01l000jO000
0`0OO01l000?O0000`00Oomoo`0COol001eoo`03001oogoo091oo`0301moogoo00Qoo`03001l07`0
03Yl000301ml07`000ml0003001oogoo01=oo`007Goo00<007ooOol0Sgoo00<07gooOol02Goo00<0
07`0O000>g`000<07g`0O0003W`000<007ooOol04goo000MOol00`00Oomoo`2?Ool00`0OOomoo`09
Ool00`00O01l000kO0000`0OO01l000>O0000`00Oomoo`0COol001eoo`03001oogoo08ioo`0301mo
ogoo00Yoo`03001l07`003]l000301ml07`000il0003001oogoo01=oo`007Goo0P00Sgoo00<07goo
Ool02Woo00<007`0O000?7`000<07g`0O0003G`000<007ooOol04goo000MOol00`00Oomoo`2=Ool0
0`0OOomoo`0;Ool00`00O01l000lO0000`0OO01l000=O0000`00Oomoo`0COol001eoo`03001oogoo
08eoo`0301moogoo00]oo`03001l07`003el000301ml07`000al0003001oogoo01=oo`007Goo00<0
07ooOol0S7oo00<07gooOol037oo00<007`0O000?G`000<07g`0O00037`000<007ooOol04goo000M
Ool2002=Ool00`0OOomoo`0<Ool00`00O01l000mO0000`0OO01l000<O0000`00Oomoo`0COol001eo
o`03001oogoo08]oo`0301moogoo00eoo`03001l07`003il000301ml07`000]l0003001oogoo01=o
o`005Goo100017oo00<007ooOol0Rgoo00<07gooOol03Goo00<007`0O000?W`000<07g`0O0002g`0
00<007ooOol04goo000FOol00`00Oomoo`04Ool00`00Oomoo`2:Ool00`0OOomoo`0>Ool00`00O01l
000nO0000`0OO01l000;O0000`00Oomoo`0COol000moo`D000=oo`03001oogoo00=oo`<008Yoo`03
01moogoo00ioo`03001l07`003ml000301ml07`000Yl0003001oogoo01=oo`0067oo00<007ooOol0
0Woo00<007ooOol0RGoo00<07gooOol03goo00<007`0O000?g`000<07g`0O0002W`000<007ooOol0
4goo000EOol01000Oomoo`0017oo00<007ooOol0RGoo00<07gooOol03goo00<007`0O000@7`000<0
7g`0O0002G`000<007ooOol04goo000FOol20005Ool00`00Oomoo`28Ool00`0OOomoo`0@Ool00`00
O01l0010O0000`0OO01l0009O0000`00Oomoo`0COol001eoo`03001oogoo08Qoo`0301moogoo011o
o`03001l07`0041l000301ml07`000Ul0003001oogoo01=oo`007Goo0P00R7oo00<07gooOol04Goo
00<007`0O000@G`000<07g`0O00027`000<007ooOol04goo000MOol00`00Oomoo`27Ool00`0OOomo
o`0AOol00`00O01l0011O0000`0OO01l0008O0000`00Oomoo`0COol001eoo`03001oogoo08Ioo`03
01moogoo019oo`03001l07`0045l000301ml07`000Ql0003001oogoo01=oo`007Goo00<007ooOol0
QWoo00<07gooOol04Woo00<007`0O000@W`000<07g`0O0001g`000<007ooOol04goo000MOol20026
Ool00`0OOomoo`0COol00`00O01l0012O0000`0OO01l0007O0000`00Oomoo`0COol001eoo`03001o
ogoo08Eoo`0301moogoo01=oo`03001l07`0049l000301ml07`000Ml0003001oogoo01=oo`007Goo
00<007ooOol0Q7oo00<07gooOol057oo00<007`0O000@g`000<07g`0O0001W`000<007ooOol04goo
000MOol00`00Oomoo`24Ool00`0OOomoo`0DOol00`00O01l0013O0000`0OO01l0006O0000`00Oomo
o`0COol001eoo`03001oogoo08=oo`0301moogoo01Eoo`03001l07`004=l000301ml07`000Il0003
001oogoo01=oo`007Goo0P00Q7oo00<07gooOol05Goo00<007`0O000A7`000<07g`0O0001G`000<0
07ooOol04goo000MOol00`00Oomoo`23Ool00`0OOomoo`0EOol00`00O01l0014O0000`0OO01l0005
O0000`00Oomoo`0COol001eoo`03001oogoo089oo`0301moogoo01Ioo`03001l07`004Al000301ml
07`000El0003001oogoo01=oo`007Goo00<007ooOol0PWoo00<07gooOol05Woo00<007`0O000A7`0
00<07g`0O0001G`000<007ooOol04goo000MOol20022Ool00`0OOomoo`0GOol00`00O01l0015O000
0`0OO01l0004O0000`00Oomoo`0COol001eoo`03001oogoo085oo`0301moogoo01Moo`03001l07`0
04El000301ml07`000Al0003001oogoo01=oo`005Goo0`001Goo00<007ooOol0P7oo00<07gooOol0
67oo00<007`0O000AG`000<07g`0O00017`000<007ooOol04goo000FOol00`00Oomoo`04Ool00`00
Oomoo`20Ool00`0OOomoo`0HOol00`00O01l0016O0000`0OO01l0003O0000`00Oomoo`0COol000mo
o`D0009oo`03001oogoo00Aoo`<007moo`0301moogoo01Uoo`03001l07`004Il000301ml07`000=l
0003001oogoo01=oo`005Woo00<007ooOol017oo00<007ooOol0Ogoo00<07gooOol06Goo00<007`0
O000AW`000<07g`0O0000g`000<007ooOol04goo000FOol00`00Oomoo`04Ool00`00Oomoo`1nOol0
0`0OOomoo`0JOol00`00O01l0016O0000`0OO01l0003O0000`00Oomoo`0COol001Eoo`8000Ioo`03
001oogoo07ioo`0301moogoo01Yoo`03001l07`004Ml000301ml07`0009l0003001oogoo01=oo`00
7Goo00<007ooOol0OGoo00<07gooOol06goo00<007`0O000Ag`000<07g`0O0000W`000<007ooOol0
4goo000MOol2001nOol00`0OOomoo`0KOol00`00O01l0017O0000`0OO01l0002O0000`00Oomoo`0C
Ool001eoo`03001oogoo07aoo`0301moogoo01aoo`03001l07`004Ml000301ml07`0009l0003001o
ogoo01=oo`007Goo00<007ooOol0O7oo00<07gooOol077oo00<007`0O000B7`000D07g`0O01l0000
01Eoo`007Goo00<007ooOol0Ngoo00<07gooOol07Goo00<007`0O000B7`000D07g`0O01l000001Eo
o`007Goo0P00O7oo00<07gooOol07Goo00<007`0O000B7`000D07g`0O01l000001Eoo`007Goo00<0
07ooOol0NWoo00<07gooOol07Woo00<007`0O000B7`000D07g`0O01l000001Eoo`007Goo00<007oo
Ool0NWoo00<07gooOol07Woo00<007`0O000BG`000@07g`0O00001Eoo`007Goo00<007ooOol08Goo
0`008goo10008Goo0`002Woo00<07gooOol05goo0`001Goo00<007`0O000BG`000@07g`0O00001Eo
o`007Goo00<007ooOol08Woo00<007ooOol08goo00<007ooOol097oo00<007ooOol01goo00<07goo
Ool067oo00<007ooOol017oo00<007`0O000BG`000@07g`0O00001Eoo`007Goo0P008goo00<007oo
Ool097oo00<007ooOol08goo00<007ooOol01Woo00<07gooOol05goo10001Goo00<007`0O000BG`0
00@07g`0O00001Eoo`007Goo00<007ooOol08Woo00<007ooOol09Goo00<007ooOol087oo0P002Goo
00<07gooOol05goo00<007oo00001Woo00<007`0O000BW`000<07g`000005Goo000MOol00`00Oomo
o`0ROol00`00Oomoo`0ROol01000Oomoo`0097oo00<007ooOol01Goo00<07gooOol067oo00<007oo
00001Woo00<007`0O000BW`000<07g`000005Goo000MOol00`00Oomoo`0QOol2000UOol2000ROol3
0008Ool00`0OOomoo`0IOol20006Ool00`00O01l001:O0000`0OO000000EOol001eoo`8007Moo`03
01moogoo029oo`03001l07`004]l000301l007oo01Aoo`007Goo00<007ooOol0MWoo00<07gooOol0
8Woo00<007`0O000Bg`000<07`00Ool057oo000MOol00`00Oomoo`1eOol00`0OOomoo`0SOol00`00
O01l001;O0000`0O001oo`0DOol001eoo`03001oogoo07Eoo`0301moogoo02=oo`03001l07`004]l
000301l007oo01Aoo`007Goo00<007ooOol0C7oo00<007ooOol09Goo00<07gooOol097oo00<007`0
O000C7`000<07gooOol04goo000GOol6000:01m]00000`0O0000000U001>O0000`0O00000004000?
Ool001eoo`03001l07`000Ml00807d=l0003001oogoo01moo`03001oogoo009oo`0301moogoo01io
o`03001oogoo02=oo`03001oogoo029oo`03001oogoo01ioo`007Goo00<007`0O0002G`00`0O@7`0
00<007ooOol08goo00<07gooOol0Rgoo000MOol00`00O01l000<O00201lnO0000`00Oomoo`0SOol0
0`0OOomoo`2;Ool001eoo`03001l07`000il00807cal0003001oogoo029oo`0301moogoo08aoo`00
7Goo00<007`0O00047`000<07g`0O000>G`000<007ooOol08Woo00<07gooOol0S7oo000MOol00`00
O01l000AO00201liO0000`00Oomoo`0QOol00`0OOomoo`2=Ool001eoo`03001l07`001=l00807cMl
0003001oogoo021oo`0301moogoo08ioo`007Goo00<007`0O0005G`000<07g`0O000=7`000<007oo
Ool087oo00<07gooOol0SWoo000MOol00`00O01l000FO00201ldO0000`00Oomoo`0OOol00`0OOomo
o`2?Ool001eoo`03001l07`001Ql00807c9l0003001oogoo01ioo`0301moogoo091oo`007Goo00<0
07`0O0006W`000<07g`0O000;g`000<007ooOol07Woo00<07gooOol0T7oo000MOol00`00O01l000K
O00201l_O0000`00Oomoo`0MOol00`0OOomoo`2AOol001eoo`03001l07`001el000301ml07`002al
0003001oogoo01eoo`0301moogoo095oo`007Goo00<007`0O0007W`000<07g`0O000:g`000<007oo
Ool077oo00<07gooOol0TWoo000MOol00`00O01l000OO0000`0OO01l000ZO0000`00Oomoo`0KOol0
0`0OOomoo`2COol001eoo`03001l07`0021l00807bYl0003001oogoo01]oo`0301moogoo09=oo`00
7Goo00<007`0O0008W`000<07g`0O0009g`000<007ooOol06Woo00<07gooOol0U7oo000MOol00`00
O01l000SO0000`0OO01l000VO0000`00Oomoo`0IOol00`0OOomoo`2EOol001eoo`03001l07`002Al
000301ml07`002El0003001oogoo01Qoo`0301moogoo09Ioo`005Goo0`001Goo:0000P0O9P006Woo
00<07gooOol0UWoo000FOol00`00Oomoo`04Ool00`00Oomoo`0WOol00`0OOomoo`0lOol00`0OOomo
o`2GOol001Ioo`03001oogoo00Aoo`<002Qoo`0301moogoo03Yoo`0301moogoo09Qoo`005Woo00<0
07ooOol017oo00<007ooOol0:Goo00<07gooOol0>7oo00<07gooOol0VGoo000FOol00`00Oomoo`04
Ool00`00Oomoo`0ZOol201lgOol00`0OOomoo`2JOol001Eoo`8000Ioo`03001oogoo02aoo`0301mo
ogoo03Aoo`0301moogoo09Yoo`007Goo0P00;Woo00<07gooOol0<Woo00<07gooOol0Vgoo000MOol0
0`00Oomoo`0^Ool00`0OOomoo`0`Ool00`0OOomoo`2LOol001eoo`03001oogoo02moo`807bmoo`03
01moogoo09eoo`007Goo00<007ooOol0<Goo00<07gooOol0:goo00<07gooOol0WWoo000MOol2000c
Ool201lZOol00`0OOomoo`2OOol001eoo`03001oogoo03Aoo`0301moogoo02Ioo`0301moogoo0:1o
o`007Goo00<007ooOol0=Goo0P0O97oo0P0OXgoo000MOol00`00Oomoo`0gOol00`0OOomoo`0POol0
0`0OOomoo`2SOol001eoo`03001oogoo03Qoo`807amoo`0301moogoo0:Aoo`007Goo0P00>goo00<0
7gooOol06goo00<07gooOol0YGoo000MOol00`00Oomoo`0kOol301lHOol201nXOol001eoo`03001o
ogoo03ioo`807a=oo`<07jYoo`007Goo00<007ooOol0@7oo0`0O3Woo0P0O[Goo000MOol20014Ool4
01l6Ool401n_Ool001eoo`03001oogoo04Moo`H07k=oo`007Goo00<007ooOol0ogoo0Goo000MOol0
0`00Oomoo`3oOol1Ool001eoo`03001oogoo0?moo`5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol003aoo`H000Ioo`<000=oo`@000Ao
o`<000Eoo`<000=oo`@00003Ool000000080009oo`8000Eoo`X00003Ool000000080009oo`@000Ao
o`@000=oo`@001Qoo`H000Eoo`03001oogoo00Aoo`80009oo`D000Ioo`@000Eoo`@000Ioo`03001o
ogoo03Moo`00?Woo0P001goo0P000Woo00@007ooOomoo`8000Aoo`80009oo`04001oogooOol20002
Ool01000Oomoogoo0P000goo0P000Woo0P0000=oo`00Ool01Goo0P001Goo0P0000=oo`00000017oo
0P0017oo0P000Woo0P000goo0P006goo0P001goo0P001Goo0P000Woo0P000goo0P000goo0P000Woo
0P000goo0P000Woo0P001Goo0P00>7oo000nOol20006Ool20004Ool00`00Oomoo`020003Ool20004
Ool01000Ool0000017oo00<007ooOol00P000goo0P000Woo0P0027oo0P001Woo00@007oo000000Ao
o`8000=oo`8000Aoo`80009oo`8000Uoo`T000Uoo`8000Qoo`03001oogoo00eoo`05001oogooOol0
0004Ool01@00Oomoogoo000017oo00<007ooOol017oo00<007ooOol0=Woo000nOol20006Ool20007
Ool20003Ool20006Ool20007Ool20003Ool20002Ool20008Ool20008Ool20004Ool20003Ool20004
Ool20002Ool2000KOol20008Ool00`00Oomoo`0=Ool200000goo00000004Ool200000goo00000004
Ool20005Ool00`00Oomoo`0fOol003ioo`8000Ioo`8000Moo`8000=oo`8000Ioo`8000Moo`8000=o
o`80009oo`8000Qoo`8000Aoo`04001oogooOol20004Ool20003Ool20004Ool20002Ool2000KOol2
0008Ool00`00Oomoo`0=Ool200000goo00000004Ool200000goo00000004Ool20005Ool00`00Oomo
o`0fOol003ioo`H0009oo`L0009oo`8000=oo`8000Aoo`03001oo`0000H0009oo`8000=oo`80009o
o`8000Qoo`8000Aoo`04001oogooOol20004Ool20003Ool20004Ool20002Ool2000KOol20009Ool0
0`00Oomoo`0<Ool200000goo00000004Ool200000goo00000004Ool20006Ool00`00Oomoo`0eOol0
03ioo`8000=oo`80009oo`04001oogooOol200000goo0000000400000goo00000002Ool20002Ool0
1000Oomoogoo0P0000=oo`0000000P000Woo0P000Woo0P0027oo1`000Woo300000=oo`0000000Woo
0P000Woo1P001Woo2@002Goo0P002Goo00<007ooOol02goo0`0000=oo`00000017oo0P0000=oo`00
000017oo0P001Woo00<007ooOol0=Goo000nOol20004Ool20002Ool40004Ool01000Ool000000Woo
100017oo100017oo00<007oo00000P000Woo1@001Woo0P0017oo00<007ooOol00Woo00@007oo0000
009oo`04001oo`000002Ool40005Ool01000Ool0000067oo0P002Goo00<007ooOol027oo1@000Woo
0P0017oo0P0000=oo`00000017oo0P001Woo00<007ooOol0=Goo000nOol20004Ool2000XOol20008
Ool20004Ool00`00Oomoo`0cOol2000:Ool00`00Oomoo`09Ool00`00Oomoo`02Ool20004Ool20000
0goo00000004Ool20007Ool00`00Oomoo`0dOol003ioo`8000Aoo`8002Uoo`03001oogoo00Ioo`80
03Yoo`8000Yoo`03001oogoo00Yoo`04001oogooOol20004Ool200000goo00000004Ool20007Ool0
0`00Oomoo`0dOol003ioo`8000Aoo`80039oo`8000Eoo`03001oogoo039oo`8000Aoo`8000Aoo`03
001oogoo00Eoo`03001oogoo009oo`8000=oo`03001oogoo009oo`05001oogooOol00004Ool00`00
Oomoo`020004Ool00`00Oomoo`0dOol003ioo`8000=oo`8003=oo`8000Eoo`03001oogoo031oo`@0
00Eoo`L000Moo`03001oogoo00<000=oo`80009oo`8000=oo`80009oo`8000=oo`L003Eoo`00?7oo
2000<Woo2P00=7oo0P001Goo1`0027oo10001Goo10001Goo100017oo1`00=Goo003oOolQOol00?mo
ob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.783823, -4.98036, 
  0.0265065, 0.0452841}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.151576 0.44187 0.0887232 [
[.17539 .42937 -3 -9 ]
[.17539 .42937 3 0 ]
[.32696 .42937 -3 -9 ]
[.32696 .42937 3 0 ]
[.47854 .42937 -3 -9 ]
[.47854 .42937 3 0 ]
[.63011 .42937 -3 -9 ]
[.63011 .42937 3 0 ]
[.78169 .42937 -3 -9 ]
[.78169 .42937 3 0 ]
[.93327 .42937 -3 -9 ]
[.93327 .42937 3 0 ]
[.01131 .08698 -12 -4.5 ]
[.01131 .08698 0 4.5 ]
[.01131 .1757 -12 -4.5 ]
[.01131 .1757 0 4.5 ]
[.01131 .26442 -12 -4.5 ]
[.01131 .26442 0 4.5 ]
[.01131 .35315 -12 -4.5 ]
[.01131 .35315 0 4.5 ]
[.01131 .53059 -6 -4.5 ]
[.01131 .53059 0 4.5 ]
[.5 .63053 -89.5938 0 ]
[.5 .63053 89.5938 20 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.17539 .44187 m
.17539 .44812 L
s
[(1)] .17539 .42937 0 1 Mshowa
.32696 .44187 m
.32696 .44812 L
s
[(2)] .32696 .42937 0 1 Mshowa
.47854 .44187 m
.47854 .44812 L
s
[(3)] .47854 .42937 0 1 Mshowa
.63011 .44187 m
.63011 .44812 L
s
[(4)] .63011 .42937 0 1 Mshowa
.78169 .44187 m
.78169 .44812 L
s
[(5)] .78169 .42937 0 1 Mshowa
.93327 .44187 m
.93327 .44812 L
s
[(6)] .93327 .42937 0 1 Mshowa
.125 Mabswid
.05412 .44187 m
.05412 .44562 L
s
.08444 .44187 m
.08444 .44562 L
s
.11476 .44187 m
.11476 .44562 L
s
.14507 .44187 m
.14507 .44562 L
s
.2057 .44187 m
.2057 .44562 L
s
.23602 .44187 m
.23602 .44562 L
s
.26633 .44187 m
.26633 .44562 L
s
.29665 .44187 m
.29665 .44562 L
s
.35728 .44187 m
.35728 .44562 L
s
.38759 .44187 m
.38759 .44562 L
s
.41791 .44187 m
.41791 .44562 L
s
.44822 .44187 m
.44822 .44562 L
s
.50885 .44187 m
.50885 .44562 L
s
.53917 .44187 m
.53917 .44562 L
s
.56948 .44187 m
.56948 .44562 L
s
.5998 .44187 m
.5998 .44562 L
s
.66043 .44187 m
.66043 .44562 L
s
.69074 .44187 m
.69074 .44562 L
s
.72106 .44187 m
.72106 .44562 L
s
.75137 .44187 m
.75137 .44562 L
s
.81201 .44187 m
.81201 .44562 L
s
.84232 .44187 m
.84232 .44562 L
s
.87264 .44187 m
.87264 .44562 L
s
.90295 .44187 m
.90295 .44562 L
s
.96358 .44187 m
.96358 .44562 L
s
.9939 .44187 m
.9939 .44562 L
s
.25 Mabswid
0 .44187 m
1 .44187 L
s
.02381 .08698 m
.03006 .08698 L
s
[(-4)] .01131 .08698 1 0 Mshowa
.02381 .1757 m
.03006 .1757 L
s
[(-3)] .01131 .1757 1 0 Mshowa
.02381 .26442 m
.03006 .26442 L
s
[(-2)] .01131 .26442 1 0 Mshowa
.02381 .35315 m
.03006 .35315 L
s
[(-1)] .01131 .35315 1 0 Mshowa
.02381 .53059 m
.03006 .53059 L
s
[(1)] .01131 .53059 1 0 Mshowa
.125 Mabswid
.02381 .016 m
.02756 .016 L
s
.02381 .03374 m
.02756 .03374 L
s
.02381 .05149 m
.02756 .05149 L
s
.02381 .06923 m
.02756 .06923 L
s
.02381 .10472 m
.02756 .10472 L
s
.02381 .12247 m
.02756 .12247 L
s
.02381 .14021 m
.02756 .14021 L
s
.02381 .15796 m
.02756 .15796 L
s
.02381 .19344 m
.02756 .19344 L
s
.02381 .21119 m
.02756 .21119 L
s
.02381 .22893 m
.02756 .22893 L
s
.02381 .24668 m
.02756 .24668 L
s
.02381 .28217 m
.02756 .28217 L
s
.02381 .29991 m
.02756 .29991 L
s
.02381 .31766 m
.02756 .31766 L
s
.02381 .3354 m
.02756 .3354 L
s
.02381 .37089 m
.02756 .37089 L
s
.02381 .38864 m
.02756 .38864 L
s
.02381 .40638 m
.02756 .40638 L
s
.02381 .42413 m
.02756 .42413 L
s
.02381 .45961 m
.02756 .45961 L
s
.02381 .47736 m
.02756 .47736 L
s
.02381 .4951 m
.02756 .4951 L
s
.02381 .51285 m
.02756 .51285 L
s
.02381 .54834 m
.02756 .54834 L
s
.02381 .56608 m
.02756 .56608 L
s
.02381 .58383 m
.02756 .58383 L
s
.02381 .60157 m
.02756 .60157 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -150.594 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 24.000000 moveto
 558.000000 24.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 24.000000 lineto
closepath
clip newpath
63.000000 19.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 18.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 19.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 18.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Percent) show
121.250000 19.000000 moveto
(Error) show
163.625000 19.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 18.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(=) show
179.687500 19.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 18.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(9.96837) show
238.187500 19.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 18.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
0 0 1 r
.007 w
.02381 .44187 m
.02499 .44188 L
.02605 .44189 L
.02729 .44192 L
.02846 .44195 L
.03053 .44204 L
.03279 .44218 L
.03527 .44238 L
.0379 .44264 L
.04262 .44323 L
.04749 .44403 L
.05205 .44493 L
.06244 .44757 L
.07305 .45107 L
.08274 .45495 L
.10458 .46589 L
.14429 .4922 L
.18248 .52229 L
.22313 .55474 L
.26226 .58144 L
.27254 .5871 L
.28367 .59241 L
.29328 .59624 L
.29838 .59795 L
.30384 .59955 L
.30923 .60086 L
.31415 .60182 L
.31652 .6022 L
.31909 .60255 L
.32151 .60282 L
.32378 .60303 L
.32509 .60312 L
.3263 .60319 L
.32764 .60325 L
.32834 .60327 L
.32908 .60329 L
.32976 .60331 L
.33048 .60332 L
.33177 .60332 L
.33257 .60331 L
.33332 .6033 L
.33399 .60328 L
.33472 .60326 L
.33594 .60321 L
.33728 .60313 L
.33999 .60292 L
.34249 .60266 L
.34484 .60235 L
.34982 .60149 L
.35525 .60023 L
Mistroke
.36513 .59709 L
.37475 .59294 L
.38367 .58812 L
.40423 .57339 L
.42285 .55569 L
.46297 .50405 L
.50157 .43897 L
.54262 .35759 L
.58216 .27326 L
.62019 .19318 L
.66067 .11668 L
.69963 .05896 L
.70983 .04728 L
.72091 .03645 L
.73048 .02875 L
.73557 .02531 L
.74104 .02213 L
.74638 .01956 L
.75126 .01767 L
.75594 .01629 L
.75829 .01576 L
.76085 .0153 L
.76227 .01511 L
.76362 .01496 L
.76482 .01485 L
.76612 .01477 L
.7668 .01474 L
.76755 .01472 L
.76833 .01472 L
.76905 .01472 L
.77035 .01475 L
.77108 .01478 L
.77175 .01482 L
.77304 .01492 L
.77424 .01504 L
.77695 .01543 L
.77933 .0159 L
.78187 .01653 L
.78675 .0181 L
.79123 .01999 L
.80132 .02578 L
.81022 .03269 L
.81959 .04179 L
.83931 .06705 L
.85767 .09794 L
.89668 .18599 L
.93815 .30895 L
.97619 .44187 L
Mfstroke
1 0 0 r
.02381 .44187 m
.2619 .44187 L
.2619 .49114 L
.02381 .49114 L
F
.2619 .44187 m
.5 .44187 L
.5 .58969 L
.2619 .58969 L
F
.5 .44187 m
.7381 .44187 L
.7381 .1955 L
.5 .1955 L
F
.7381 .44187 m
.97619 .44187 L
.97619 .09696 L
.7381 .09696 L
F
0 g
.5 Mabswid
.02381 .44187 m
.02381 .49114 L
s
.2619 .44187 m
.2619 .49114 L
s
.02381 .49114 m
.2619 .49114 L
s
.2619 .44187 m
.2619 .58969 L
s
.5 .44187 m
.5 .58969 L
s
.2619 .58969 m
.5 .58969 L
s
.5 .44187 m
.5 .1955 L
s
.7381 .44187 m
.7381 .1955 L
s
.5 .1955 m
.7381 .1955 L
s
.7381 .44187 m
.7381 .09696 L
s
.97619 .44187 m
.97619 .09696 L
s
.7381 .09696 m
.97619 .09696 L
s
0 0 1 r
.007 w
.02381 .44187 m
.02499 .44188 L
.02605 .44189 L
.02729 .44192 L
.02846 .44195 L
.03053 .44204 L
.03279 .44218 L
.03527 .44238 L
.0379 .44264 L
.04262 .44323 L
.04749 .44403 L
.05205 .44493 L
.06244 .44757 L
.07305 .45107 L
.08274 .45495 L
.10458 .46589 L
.14429 .4922 L
.18248 .52229 L
.22313 .55474 L
.26226 .58144 L
.27254 .5871 L
.28367 .59241 L
.29328 .59624 L
.29838 .59795 L
.30384 .59955 L
.30923 .60086 L
.31415 .60182 L
.31652 .6022 L
.31909 .60255 L
.32151 .60282 L
.32378 .60303 L
.32509 .60312 L
.3263 .60319 L
.32764 .60325 L
.32834 .60327 L
.32908 .60329 L
.32976 .60331 L
.33048 .60332 L
.33177 .60332 L
.33257 .60331 L
.33332 .6033 L
.33399 .60328 L
.33472 .60326 L
.33594 .60321 L
.33728 .60313 L
.33999 .60292 L
.34249 .60266 L
.34484 .60235 L
.34982 .60149 L
.35525 .60023 L
Mistroke
.36513 .59709 L
.37475 .59294 L
.38367 .58812 L
.40423 .57339 L
.42285 .55569 L
.46297 .50405 L
.50157 .43897 L
.54262 .35759 L
.58216 .27326 L
.62019 .19318 L
.66067 .11668 L
.69963 .05896 L
.70983 .04728 L
.72091 .03645 L
.73048 .02875 L
.73557 .02531 L
.74104 .02213 L
.74638 .01956 L
.75126 .01767 L
.75594 .01629 L
.75829 .01576 L
.76085 .0153 L
.76227 .01511 L
.76362 .01496 L
.76482 .01485 L
.76612 .01477 L
.7668 .01474 L
.76755 .01472 L
.76833 .01472 L
.76905 .01472 L
.77035 .01475 L
.77108 .01478 L
.77175 .01482 L
.77304 .01492 L
.77424 .01504 L
.77695 .01543 L
.77933 .0159 L
.78187 .01653 L
.78675 .0181 L
.79123 .01999 L
.80132 .02578 L
.81022 .03269 L
.81959 .04179 L
.83931 .06705 L
.85767 .09794 L
.89668 .18599 L
.93815 .30895 L
.97619 .44187 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00O7Goo00<007ooOol0
ogoo0Goo000MOol00`00Oomoo`3oOol1Ool001eoo`03001oogoo0?moo`5oo`007Goo00<007ooOol0
]7oo1P0OAWoo000MOol2002bOol301l5Ool301m4Ool001eoo`03001oogoo0:moo`807`]oo`<07d5o
o`007Goo00<007ooOol0[Woo00<07gooOol03Woo00<07gooOol0?Woo000MOol00`00Oomoo`2]Ool0
0`0OOomoo`0@Ool00`0OOomoo`0mOol001eoo`800:eoo`0301moogoo019oo`0301moogoo03aoo`00
7Goo00<007ooOol0ZWoo0P0O5Woo00<07gooOol0>goo000MOol00`00Oomoo`2YOol00`0OOomoo`0G
Ool00`0OOomoo`0jOol001eoo`03001oogoo0:Qoo`0301moogoo01Qoo`0301moogoo03Yoo`007Goo
0P00Z7oo00<07gooOol06Woo00<07gooOol0>Goo000MOol00`00Oomoo`2VOol00`0OOomoo`0LOol0
0`0OOomoo`0hOol001eoo`03001oogoo0:Eoo`0301moogoo01ioo`0301moogoo03Moo`007Goo00<0
07ooOol0YGoo00<07gooOol07goo00<07gooOol0=Woo000MOol00`00Oomoo`2TOol00`0OOomoo`0Q
Ool00`0OOomoo`0eOol001eoo`800:Aoo`0301moogoo029oo`0301moogoo03Eoo`007Goo00<007oo
Ool0Xgoo00<07gooOol08goo00<07gooOol0=7oo000FOol30004Ool00`00Oomoo`2ROol00`0OOomo
o`0UOol00`0OOomoo`0cOol001Moo`03001oogoo00=oo`03001oogoo0:9oo`0301moogoo02Eoo`03
01moogoo03=oo`003goo1@0000=oo`0000000P0017oo0`00XGoo00<07gooOol09goo00<07gooOol0
<Woo000EOol00`00Ool00005Ool00`00Oomoo`2POol00`0OOomoo`0XOol00`0OOomoo`0bOol001Eo
o`03001oo`0000Eoo`03001oogoo0:1oo`0301moogoo02Uoo`0301moogoo035oo`005Woo0P001Goo
00<007ooOol0Wgoo00<07gooOol03Goo7P0000<07`0000006`005Goo000MOol00`00Oomoo`2OOol0
0`0OOomoo`0=Ool00`00O01l000KO0000`0OO01l000JO0000`00Oomoo`0COol001eoo`8009moo`03
01moogoo00ioo`03001l07`001al000301ml07`001Ul0003001oogoo01=oo`007Goo00<007ooOol0
WGoo00<07gooOol03goo00<007`0O00077`000<07g`0O0006G`000<007ooOol04goo000MOol00`00
Oomoo`2MOol00`0OOomoo`0?Ool00`00O01l000LO0000`0OO01l000IO0000`00Oomoo`0COol001eo
o`03001oogoo09aoo`0301moogoo011oo`03001l07`001el000301ml07`001Ql0003001oogoo01=o
o`007Goo0P00WGoo00<07gooOol047oo00<007`0O0007G`000<07g`0O00067`000<007ooOol04goo
000MOol00`00Oomoo`2KOol00`0OOomoo`0AOol00`00O01l000NO0000`0OO01l000GO0000`00Oomo
o`0COol001eoo`03001oogoo09]oo`0301moogoo015oo`03001l07`001il000301ml07`001Ml0003
001oogoo01=oo`007Goo00<007ooOol0VWoo00<07gooOol04Woo00<007`0O0007W`000<07g`0O000
5g`000<007ooOol04goo000MOol2002KOol00`0OOomoo`0BOol00`00O01l000OO0000`0OO01l000F
O0000`00Oomoo`0COol001eoo`03001oogoo09Uoo`0301moogoo01=oo`03001l07`001ml000301ml
07`001Il0003001oogoo01=oo`007Goo00<007ooOol0VGoo00<07gooOol04goo00<007`0O00087`0
00<07g`0O0005G`000<007ooOol04goo000MOol00`00Oomoo`2HOol00`0OOomoo`0DOol00`00O01l
000PO0000`0OO01l000EO0000`00Oomoo`0COol001eoo`03001oogoo09Qoo`0301moogoo01Aoo`03
001l07`0025l000301ml07`001Al0003001oogoo01=oo`007Goo0P00V7oo00<07gooOol05Goo00<0
07`0O0008G`000<07g`0O00057`000<007ooOol04goo000MOol00`00Oomoo`2FOol00`0OOomoo`0F
Ool00`00O01l000QO0000`0OO01l000DO0000`00Oomoo`0COol001Eoo`<000Eoo`03001oogoo09Io
o`0301moogoo01Ioo`03001l07`0029l000301ml07`001=l0003001oogoo01=oo`0067oo00<007oo
Ool00Woo00<007ooOol0UGoo00<07gooOol05goo00<007`0O0008W`000<07g`0O0004g`000<007oo
Ool04goo000?Ool50004Ool00`00Oomoo`02Ool3002EOol00`0OOomoo`0GOol00`00O01l000SO000
0`0OO01l000BO0000`00Oomoo`0COol001Ioo`8000Eoo`03001oogoo09Aoo`0301moogoo01Qoo`03
001l07`002=l000301ml07`0019l0003001oogoo01=oo`0067oo00<007ooOol00Woo00<007ooOol0
U7oo00<07gooOol067oo00<007`0O0008g`000<07g`0O0004W`000<007ooOol04goo000EOol30005
Ool00`00Oomoo`2COol00`0OOomoo`0IOol00`00O01l000TO0000`0OO01l000AO0000`00Oomoo`0C
Ool001eoo`03001oogoo09=oo`0301moogoo01Uoo`03001l07`002Al000301ml07`0015l0003001o
ogoo01=oo`007Goo0P00MGoo7P0000<07`0000006`009g`000<07g`0O00047`000<007ooOol04goo
000MOol00`00Oomoo`1dOol00`00O01l000KO0000`0OO01l000JO0000`00O01l000UO0000`0OO01l
000@O0000`00Oomoo`0COol001eoo`03001oogoo07Aoo`03001l07`001Yl000301ml07`001]l0003
001l07`002El000301ml07`0011l0003001oogoo01=oo`007Goo00<007ooOol0M7oo00<007`0O000
6W`000<07g`0O0006g`000<007`0O0009W`000<07g`0O0003g`000<007ooOol04goo000MOol2001e
Ool00`00O01l000IO0000`0OO01l000LO0000`00O01l000VO0000`0OO01l000?O0000`00Oomoo`0C
Ool001eoo`03001oogoo07Aoo`03001l07`001Ul000301ml07`001al0003001l07`002Il000301ml
07`000ml0003001oogoo01=oo`007Goo00<007ooOol0M7oo00<007`0O00067`000<07g`0O0007G`0
00<007`0O0009g`000<07g`0O0003W`000<007ooOol04goo000MOol00`00Oomoo`1dOol00`00O01l
000HO0000`0OO01l000MO0000`00O01l000WO0000`0OO01l000>O0000`00Oomoo`0COol001eoo`03
001oogoo07Aoo`03001l07`001Ml000301ml07`001il0003001l07`002Ml000301ml07`000il0003
001oogoo01=oo`007Goo0P00MGoo00<007`0O0005g`000<07g`0O0007W`000<007`0O000:7`000<0
7g`0O0003G`000<007ooOol04goo000MOol00`00Oomoo`1dOol00`00O01l000FO0000`0OO01l000O
O0000`00O01l000XO0000`0OO01l000=O0000`00Oomoo`0COol001eoo`03001oogoo07Aoo`03001l
07`001Il000301ml07`001ml0003001l07`002Ul000301ml07`000al0003001oogoo01=oo`007Goo
00<007ooOol0M7oo00<007`0O0005G`000<07g`0O00087`000<007`0O000:G`000<07g`0O00037`0
00<007ooOol04goo000MOol2001eOol00`00O01l000EO0000`0OO01l000PO0000`00O01l000YO000
0`0OO01l000<O0000`00Oomoo`0COol001eoo`03001oogoo07Aoo`03001l07`001Al000301ml07`0
025l0003001l07`002Yl000301ml07`000]l0003001oogoo01=oo`005Goo100017oo00<007ooOol0
M7oo00<007`0O00057`000<07g`0O0008G`000<007`0O000:W`000<07g`0O0002g`000<007ooOol0
4goo000FOol00`00Oomoo`04Ool00`00Oomoo`1dOol00`00O01l000CO0000`0OO01l000RO0000`00
O01l000ZO0000`0OO01l000;O0000`00Oomoo`0COol000moo`D000=oo`03001oogoo00=oo`<007Ao
o`03001l07`001=l000301ml07`0029l0003001l07`002]l000301ml07`000Yl0003001oogoo01=o
o`0067oo00<007ooOol00Woo00<007ooOol0M7oo00<007`0O0004W`000<07g`0O0008g`000<007`0
O000:g`000<07g`0O0002W`000<007ooOol04goo000EOol01000Oomoo`0017oo00<007ooOol0M7oo
00<007`0O0004W`000<07g`0O0008g`000<007`0O000;7`000<07g`0O0002G`000<007ooOol04goo
000FOol20005Ool00`00Oomoo`1dOol00`00O01l000AO0000`0OO01l000TO0000`00O01l000/O000
0`0OO01l0009O0000`00Oomoo`0COol001eoo`03001oogoo07Aoo`03001l07`0015l000301ml07`0
02Al0003001l07`002al000301ml07`000Ul0003001oogoo01=oo`007Goo0P00MGoo00<007`0O000
47`000<07g`0O0009G`000<007`0O000;G`000<07g`0O00027`000<007ooOol04goo000MOol00`00
Oomoo`1dOol00`00O01l000@O0000`0OO01l000UO0000`00O01l000]O0000`0OO01l0008O0000`00
Oomoo`0COol001eoo`03001oogoo07Aoo`03001l07`000ml000301ml07`002Il0003001l07`002el
000301ml07`000Ql0003001oogoo01=oo`007Goo00<007ooOol0M7oo00<007`0O0003g`000<07g`0
O0009W`000<007`0O000;W`000<07g`0O0001g`000<007ooOol04goo000MOol2001eOol00`00O01l
000>O0000`0OO01l000WO0000`00O01l000^O0000`0OO01l0007O0000`00Oomoo`0COol001eoo`03
001oogoo07Aoo`03001l07`000il000301ml07`002Ml0003001l07`002il000301ml07`000Ml0003
001oogoo01=oo`007Goo00<007ooOol0M7oo00<007`0O0003G`000<07g`0O000:7`000<007`0O000
;g`000<07g`0O0001W`000<007ooOol04goo000MOol00`00Oomoo`1dOol00`00O01l000=O0000`0O
O01l000XO0000`00O01l000_O0000`0OO01l0006O0000`00Oomoo`0COol001eoo`03001oogoo07Ao
o`03001l07`000al000301ml07`002Ul0003001l07`002ml000301ml07`000Il0003001oogoo01=o
o`007Goo0P00MGoo00<007`0O00037`000<07g`0O000:G`000<007`0O000<7`000<07g`0O0001G`0
00<007ooOol04goo000MOol00`00Oomoo`1dOol00`00O01l000<O0000`0OO01l000YO0000`00O01l
000`O0000`0OO01l0005O0000`00Oomoo`0COol001eoo`03001oogoo07Aoo`03001l07`000]l0003
01ml07`002Yl0003001l07`0031l000301ml07`000El0003001oogoo01=oo`007Goo00<007ooOol0
M7oo00<007`0O0002g`000<07g`0O000:W`000<007`0O000<7`000<07g`0O0001G`000<007ooOol0
4goo000MOol2001eOol00`00O01l000:O0000`0OO01l000[O0000`00O01l000aO0000`0OO01l0004
O0000`00Oomoo`0COol001eoo`03001oogoo07Aoo`03001l07`000Yl000301ml07`002]l0003001l
07`0035l000301ml07`000Al0003001oogoo01=oo`005Goo0`001Goo00<007ooOol0M7oo00<007`0
O0002G`000<07g`0O000;7`000<007`0O000<G`000<07g`0O00017`000<007ooOol04goo000FOol0
0`00Oomoo`04Ool00`00Oomoo`1dOol00`00O01l0009O0000`0OO01l000/O0000`00O01l000bO000
0`0OO01l0003O0000`00Oomoo`0COol000moo`D0009oo`03001oogoo00Aoo`<007Aoo`03001l07`0
00Ql000301ml07`002el0003001l07`0039l000301ml07`000=l0003001oogoo01=oo`005Woo00<0
07ooOol017oo00<007ooOol0M7oo00<007`0O00027`000<07g`0O000;G`000<007`0O000<W`000<0
7g`0O0000g`000<007ooOol04goo000FOol00`00Oomoo`04Ool00`00Oomoo`1dOol00`00O01l0007
O0000`0OO01l000^O0000`00O01l000bO0000`0OO01l0003O0000`00Oomoo`0COol001Eoo`8000Io
o`03001oogoo07Aoo`03001l07`000Ml000301ml07`002il0003001l07`003=l000301ml07`0009l
0003001oogoo01=oo`007Goo00<007ooOol0M7oo00<007`0O0001W`000<07g`0O000;g`000<007`0
O000<g`000<07g`0O0000W`000<007ooOol04goo000MOol2001eOol00`00O01l0006O0000`0OO01l
000_O0000`00O01l000cO0000`0OO01l0002O0000`00Oomoo`0COol001eoo`03001oogoo07Aoo`03
001l07`000El000301ml07`0031l0003001l07`003=l000301ml07`0009l0003001oogoo01=oo`00
7Goo00<007ooOol0M7oo00<007`0O0001G`000<07g`0O000<7`000<007`0O000=7`000D07g`0O01l
000001Eoo`007Goo00<007ooOol0M7oo00<007`0O00017`000<07g`0O000<G`000<007`0O000=7`0
00D07g`0O01l000001Eoo`007Goo0P00MGoo00<007`0O00017`000<07g`0O000<G`000<007`0O000
=7`000D07g`0O01l000001Eoo`007Goo00<007ooOol0M7oo00<007`0O0000g`000<07g`0O000<W`0
00<007`0O000=7`000D07g`0O01l000001Eoo`007Goo00<007ooOol0M7oo00<007`0O0000g`000<0
7g`0O000<W`000<007`0O000=G`000@07g`0O00001Eoo`007Goo00<007ooOol08Goo0`008goo1000
8Goo0`001Goo00<007`0O0000W`000<07g`0O000<g`000<007`0O000=G`000@07g`0O00001Eoo`00
7Goo00<007ooOol08Woo00<007ooOol08goo00<007ooOol097oo00<007ooOol00Woo00<007`0O000
0W`000<07g`0O000<g`000<007`0O000=G`000@07g`0O00001Eoo`007Goo0P008goo00<007ooOol0
97oo00<007ooOol08goo00<007ooOol00Woo00D007`0O01l000O03Il0003001l07`003El000401ml
07`0000EOol001eoo`03001oogoo029oo`03001oogoo02Eoo`03001oogoo021oo`8000Eoo`05001l
07`0O0007`0fO0000`00O01l000fO0000`0OO000000EOol001eoo`03001oogoo029oo`03001oogoo
029oo`04001oogoo000TOol00`00Oomoo`02Ool01000O01l000O=g`000<007`0O000=W`000<07g`0
00005Goo000MOol00`00Oomoo`0QOol2000UOol2000ROol30005Ool01000O01l000O=g`000<007`0
O000=W`000<07g`000005Goo000MOol2001eOol00`00O0007`0hO0000`00O01l000gO0000`0O001o
o`0DOol001eoo`03001oogoo07Aoo`03001l000O03Ql0003001l07`003Ml000301l007oo01Aoo`00
7Goo00<007ooOol0M7oo00<0000OO000>7`000<007`0O000=g`000<07`00Ool057oo000MOol00`00
Oomoo`1dOol00`0001ml000hO0000`00O01l000gO0000`0O001oo`0DOol001eoo`03001oogoo07Ao
o`0301ml07`003Ql0003001l07`003Ql000301moogoo01=oo`005goo1P002P0OK@0000<07g`0O000
>7`000<007`0O000>7`000<07`00000010003goo000MOol00`00O01l0007O00201l_O0000`00O01l
000hO0000`0O001oo`0NOol00`00Oomoo`0SOol00`00Oomoo`0ROol00`00Oomoo`0NOol001eoo`03
001l07`000Ul00<07bal0003001l07`003Ml000301ml000008]oo`007Goo00<007`0O00037`00P0O
:W`000<007`0O000=g`000<07g`00000Rgoo000MOol00`00O01l000>O00201lXO0000`00O01l000f
O000100OO01l0000Rgoo000MOol00`00O01l000@O0000`0OO01l000UO0000`00O01l000fO000100O
O01l0000Rgoo000MOol00`00O01l000AO00201lUO0000`00O01l000eO0001@0OO01l07`00000Rgoo
000MOol00`00O01l000CO00201lSO0000`00O01l000dO0000`0OO01l0002O0000`00Oomoo`29Ool0
01eoo`03001l07`001El000301ml07`0021l0003001l07`003Al000301ml07`0009l0003001oogoo
08Uoo`007Goo00<007`0O0005W`00P0O87`000<007`0O000<g`000<07g`0O0000g`000<007ooOol0
RGoo000MOol00`00O01l000HO00201lNO0000`00O01l000bO0000`0OO01l0004O0000`00Oomoo`29
Ool001eoo`03001l07`001Yl000301ml07`001]l0003001l07`0039l000301ml07`000Al0003001o
ogoo08Uoo`007Goo7P000P0O7000<g`000<07g`0O0001G`000<007ooOol0RGoo000MOol2000NOol0
0`0OOomoo`0HOol00`00O01l000aO0000`0OO01l0005O0000`00Oomoo`29Ool001eoo`03001oogoo
01ioo`0301moogoo01Moo`03001l07`0031l000301ml07`000Il0003001oogoo08Uoo`007Goo00<0
07ooOol07goo00<07gooOol05Woo00<007`0O000;g`000<07g`0O0001g`000<007ooOol0RGoo000M
Ool00`00Oomoo`0POol201lFOol00`00O01l000_O0000`0OO01l0007O0000`00Oomoo`29Ool001eo
o`8002=oo`0301moogoo01=oo`03001l07`002il000301ml07`000Ql0003001oogoo08Uoo`007Goo
00<007ooOol08goo00<07gooOol04Woo00<007`0O000;G`000<07g`0O0002G`000<007ooOol0RGoo
000MOol00`00Oomoo`0TOol00`0OOomoo`0AOol00`00O01l000/O0000`0OO01l000:O0000`00Oomo
o`29Ool001Eoo`<000Eoo`03001oogoo02Eoo`807a5oo`03001l07`002al000301ml07`000Yl0003
001oogoo08Uoo`005Woo00<007ooOol017oo00<007ooOol09goo00<07gooOol03Woo00<007`0O000
:g`000<07g`0O0002g`000<007ooOol0RGoo000FOol00`00Oomoo`04Ool3000XOol00`0OOomoo`0=
Ool00`00O01l000ZO0000`0OO01l000<O0000`00Oomoo`29Ool001Ioo`03001oogoo00Aoo`03001o
ogoo02Uoo`0301moogoo00aoo`03001l07`002Ul000301ml07`000el0003001oogoo08Uoo`005Woo
00<007ooOol017oo00<007ooOol0:Woo0P0O37oo00<007`0O000:7`000<07g`0O0003W`000<007oo
Ool0RGoo000EOol20006Ool00`00Oomoo`0/Ool00`0OOomoo`09Ool00`00O01l000XO0000`0OO01l
000>O0000`00Oomoo`29Ool001eoo`8002ioo`0301moogoo00Qoo`03001l07`002Ml000301ml07`0
00ml0003001oogoo08Uoo`007Goo00<007ooOol0;Woo00<07gooOol01goo00<007`0O0009W`000<0
7g`0O00047`000<007ooOol0RGoo000MOol00`00Oomoo`0_Ool201l7Ool00`00O01l000UO0000`0O
O01l000AO0000`00Oomoo`29Ool001eoo`03001oogoo035oo`0301moogoo00Aoo`03001l07`002Al
000301ml07`0019l0003001oogoo08Uoo`007Goo0P00<goo0P0O17oo00<007`0O0008g`000<07g`0
O0004g`000<007ooOol0RGoo000MOol00`00Oomoo`0dOol01@0OOomoogoo000097`000<07g`0O000
57`000<007ooOol0RGoo000MOol00`00Oomoo`0eOol201l00goo001l000QO00201lGO0000`00Oomo
o`29Ool001eoo`03001oogoo03Moo`0301l007`0021l000301ml07`001Ml0003001oogoo08Uoo`00
7Goo00<007ooOol0>7oo0P0O7g`000<07g`0O00067`000<007ooOol0RGoo000MOol2000iOol00`00
O0007`0MO0000`0OO01l000IO0000`00Oomoo`29Ool001eoo`03001oogoo03Qoo`<000<07aP00080
7ad008]oo`007Goo00<007ooOol0?Woo0P0O4goo0`0OZWoo000MOol00`00Oomoo`10Ool301l>Ool2
01n]Ool001eoo`8004Aoo`@07`Ioo`@07jmoo`007Goo00<007ooOol0Agoo1P0O/goo000MOol00`00
Oomoo`3oOol1Ool001eoo`03001oogoo0?moo`5oo`007Goo00<007ooOol0ogoo0Goo003oOolQOol0
0?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00?7oo
1P001Woo0`000goo100017oo0`001Goo0`000goo100000=oo`0000000P000Woo0P001Goo2P0000=o
o`0000000P000Woo100017oo10000goo100067oo0P001goo0P000goo0P002Goo0`001Goo10000goo
1@001goo00<007ooOol0=goo000nOol20007Ool20002Ool01000Oomoogoo0P0017oo0P000Woo00@0
07ooOomoo`80009oo`04001oogooOol20003Ool20002Ool200000goo001oo`05Ool20005Ool20000
0goo00000004Ool20004Ool20002Ool20003Ool2000KOol20005Ool20005Ool20005Ool20002Ool2
0003Ool20002Ool20002Ool20003Ool20005Ool2000hOol003ioo`8000Ioo`8000Aoo`03001oogoo
008000=oo`8000Aoo`04001oo`000004Ool00`00Oomoo`020003Ool20002Ool20008Ool20006Ool0
1000Ool0000017oo0P000goo0P0017oo0P000Woo0P002Goo2@002Woo0P0037oo0P0017oo00<007oo
Ool00Woo0P0000=oo`00000017oo0P001goo00<007ooOol017oo00<007ooOol0=Woo000nOol20006
Ool20007Ool20003Ool20006Ool20007Ool20003Ool20002Ool20008Ool20008Ool20004Ool20003
Ool20004Ool20002Ool2000MOol2000<Ool20002Ool20004Ool200000goo00000004Ool20007Ool2
0005Ool00`00Oomoo`0fOol003ioo`8000Ioo`8000Moo`8000=oo`8000Ioo`8000Moo`8000=oo`80
009oo`8000Qoo`8000Aoo`04001oogooOol20004Ool20003Ool20004Ool20002Ool2000MOol2000<
Ool20002Ool20004Ool200000goo00000003Ool30007Ool20005Ool00`00Oomoo`0fOol003ioo`H0
009oo`L0009oo`8000=oo`8000Aoo`03001oo`0000H0009oo`8000=oo`80009oo`8000Qoo`8000Ao
o`04001oogooOol20004Ool20003Ool20004Ool20002Ool2000JOol60008Ool600000goo00000004
Ool20002Ool2000017oo0000000027oo0P001Woo00<007ooOol0=Goo000nOol20003Ool20002Ool0
1000Oomoogoo0P0000=oo`000000100000=oo`0000000Woo0P000Woo00@007ooOomoo`800003Ool0
00000080009oo`80009oo`8000Qoo`L0009oo``00003Ool00000009oo`80009oo`H000Ioo`T000Mo
o`8000=oo`8000Moo`8000=oo`800004Ool000000002Ool20004Ool40008Ool30006Ool00`00Oomo
o`0eOol003ioo`8000Aoo`80009oo`@000Aoo`04001oo`000002Ool40004Ool40004Ool00`00Ool0
00020002Ool50006Ool20004Ool00`00Oomoo`02Ool01000Ool000000Woo00@007oo0000009oo`@0
00Eoo`04001oo`00000EOol20004Ool20006Ool20004Ool2000017oo000007oo0`0017oo1@001Goo
1@001goo00<007ooOol0=Goo000nOol20004Ool2000XOol20008Ool20004Ool00`00Oomoo`0`Ool2
0004Ool20006Ool20004Ool20002Ool20007Ool20002Ool20006Ool00`00Oomoo`08Ool00`00Oomo
o`0dOol003ioo`8000Aoo`8002Uoo`03001oogoo00Ioo`8003Moo`8000Aoo`8000Ioo`8000Aoo`80
009oo`8000Ioo`8000Aoo`8000Ioo`03001oogoo00Moo`03001oogoo03Aoo`00?Woo0P0017oo0P00
<Woo0P001Goo00<007ooOol0;goo0P0017oo0P001Woo0P0017oo0P000goo0P001Goo0P0017oo0P00
00=oo`00Ool00goo0P000Woo0P0017oo00<007ooOol0=7oo000nOol20003Ool2000cOol20005Ool0
0`00Oomoo`0`Ool20002Ool20008Ool20002Ool20005Ool20005Ool20002Ool20003Ool00`00Oomo
o`030003Ool7000eOol003aoo`P0039oo`X003=oo`@000Yoo`@000Qoo`<000=oo`@000Eoo`@000Ao
o`L003Eoo`00ogoo8Goo003oOolQOol00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.783823, -4.98036, 
  0.0265065, 0.0452841}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.151576 0.44187 0.0887232 [
[.17539 .42937 -3 -9 ]
[.17539 .42937 3 0 ]
[.32696 .42937 -3 -9 ]
[.32696 .42937 3 0 ]
[.47854 .42937 -3 -9 ]
[.47854 .42937 3 0 ]
[.63011 .42937 -3 -9 ]
[.63011 .42937 3 0 ]
[.78169 .42937 -3 -9 ]
[.78169 .42937 3 0 ]
[.93327 .42937 -3 -9 ]
[.93327 .42937 3 0 ]
[.01131 .08698 -12 -4.5 ]
[.01131 .08698 0 4.5 ]
[.01131 .1757 -12 -4.5 ]
[.01131 .1757 0 4.5 ]
[.01131 .26442 -12 -4.5 ]
[.01131 .26442 0 4.5 ]
[.01131 .35315 -12 -4.5 ]
[.01131 .35315 0 4.5 ]
[.01131 .53059 -6 -4.5 ]
[.01131 .53059 0 4.5 ]
[.5 .63053 -89.5938 0 ]
[.5 .63053 89.5938 20 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.17539 .44187 m
.17539 .44812 L
s
[(1)] .17539 .42937 0 1 Mshowa
.32696 .44187 m
.32696 .44812 L
s
[(2)] .32696 .42937 0 1 Mshowa
.47854 .44187 m
.47854 .44812 L
s
[(3)] .47854 .42937 0 1 Mshowa
.63011 .44187 m
.63011 .44812 L
s
[(4)] .63011 .42937 0 1 Mshowa
.78169 .44187 m
.78169 .44812 L
s
[(5)] .78169 .42937 0 1 Mshowa
.93327 .44187 m
.93327 .44812 L
s
[(6)] .93327 .42937 0 1 Mshowa
.125 Mabswid
.05412 .44187 m
.05412 .44562 L
s
.08444 .44187 m
.08444 .44562 L
s
.11476 .44187 m
.11476 .44562 L
s
.14507 .44187 m
.14507 .44562 L
s
.2057 .44187 m
.2057 .44562 L
s
.23602 .44187 m
.23602 .44562 L
s
.26633 .44187 m
.26633 .44562 L
s
.29665 .44187 m
.29665 .44562 L
s
.35728 .44187 m
.35728 .44562 L
s
.38759 .44187 m
.38759 .44562 L
s
.41791 .44187 m
.41791 .44562 L
s
.44822 .44187 m
.44822 .44562 L
s
.50885 .44187 m
.50885 .44562 L
s
.53917 .44187 m
.53917 .44562 L
s
.56948 .44187 m
.56948 .44562 L
s
.5998 .44187 m
.5998 .44562 L
s
.66043 .44187 m
.66043 .44562 L
s
.69074 .44187 m
.69074 .44562 L
s
.72106 .44187 m
.72106 .44562 L
s
.75137 .44187 m
.75137 .44562 L
s
.81201 .44187 m
.81201 .44562 L
s
.84232 .44187 m
.84232 .44562 L
s
.87264 .44187 m
.87264 .44562 L
s
.90295 .44187 m
.90295 .44562 L
s
.96358 .44187 m
.96358 .44562 L
s
.9939 .44187 m
.9939 .44562 L
s
.25 Mabswid
0 .44187 m
1 .44187 L
s
.02381 .08698 m
.03006 .08698 L
s
[(-4)] .01131 .08698 1 0 Mshowa
.02381 .1757 m
.03006 .1757 L
s
[(-3)] .01131 .1757 1 0 Mshowa
.02381 .26442 m
.03006 .26442 L
s
[(-2)] .01131 .26442 1 0 Mshowa
.02381 .35315 m
.03006 .35315 L
s
[(-1)] .01131 .35315 1 0 Mshowa
.02381 .53059 m
.03006 .53059 L
s
[(1)] .01131 .53059 1 0 Mshowa
.125 Mabswid
.02381 .016 m
.02756 .016 L
s
.02381 .03374 m
.02756 .03374 L
s
.02381 .05149 m
.02756 .05149 L
s
.02381 .06923 m
.02756 .06923 L
s
.02381 .10472 m
.02756 .10472 L
s
.02381 .12247 m
.02756 .12247 L
s
.02381 .14021 m
.02756 .14021 L
s
.02381 .15796 m
.02756 .15796 L
s
.02381 .19344 m
.02756 .19344 L
s
.02381 .21119 m
.02756 .21119 L
s
.02381 .22893 m
.02756 .22893 L
s
.02381 .24668 m
.02756 .24668 L
s
.02381 .28217 m
.02756 .28217 L
s
.02381 .29991 m
.02756 .29991 L
s
.02381 .31766 m
.02756 .31766 L
s
.02381 .3354 m
.02756 .3354 L
s
.02381 .37089 m
.02756 .37089 L
s
.02381 .38864 m
.02756 .38864 L
s
.02381 .40638 m
.02756 .40638 L
s
.02381 .42413 m
.02756 .42413 L
s
.02381 .45961 m
.02756 .45961 L
s
.02381 .47736 m
.02756 .47736 L
s
.02381 .4951 m
.02756 .4951 L
s
.02381 .51285 m
.02756 .51285 L
s
.02381 .54834 m
.02756 .54834 L
s
.02381 .56608 m
.02756 .56608 L
s
.02381 .58383 m
.02756 .58383 L
s
.02381 .60157 m
.02756 .60157 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -150.594 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 24.000000 moveto
 558.000000 24.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 24.000000 lineto
closepath
clip newpath
63.000000 19.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 18.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 19.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 18.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Percent) show
121.250000 19.000000 moveto
(Error) show
163.625000 19.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 18.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(=) show
179.687500 19.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 18.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(6.45107) show
238.187500 19.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 18.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
0 0 1 r
.007 w
.02381 .44187 m
.02499 .44188 L
.02605 .44189 L
.02729 .44192 L
.02846 .44195 L
.03053 .44204 L
.03279 .44218 L
.03527 .44238 L
.0379 .44264 L
.04262 .44323 L
.04749 .44403 L
.05205 .44493 L
.06244 .44757 L
.07305 .45107 L
.08274 .45495 L
.10458 .46589 L
.14429 .4922 L
.18248 .52229 L
.22313 .55474 L
.26226 .58144 L
.27254 .5871 L
.28367 .59241 L
.29328 .59624 L
.29838 .59795 L
.30384 .59955 L
.30923 .60086 L
.31415 .60182 L
.31652 .6022 L
.31909 .60255 L
.32151 .60282 L
.32378 .60303 L
.32509 .60312 L
.3263 .60319 L
.32764 .60325 L
.32834 .60327 L
.32908 .60329 L
.32976 .60331 L
.33048 .60332 L
.33177 .60332 L
.33257 .60331 L
.33332 .6033 L
.33399 .60328 L
.33472 .60326 L
.33594 .60321 L
.33728 .60313 L
.33999 .60292 L
.34249 .60266 L
.34484 .60235 L
.34982 .60149 L
.35525 .60023 L
Mistroke
.36513 .59709 L
.37475 .59294 L
.38367 .58812 L
.40423 .57339 L
.42285 .55569 L
.46297 .50405 L
.50157 .43897 L
.54262 .35759 L
.58216 .27326 L
.62019 .19318 L
.66067 .11668 L
.69963 .05896 L
.70983 .04728 L
.72091 .03645 L
.73048 .02875 L
.73557 .02531 L
.74104 .02213 L
.74638 .01956 L
.75126 .01767 L
.75594 .01629 L
.75829 .01576 L
.76085 .0153 L
.76227 .01511 L
.76362 .01496 L
.76482 .01485 L
.76612 .01477 L
.7668 .01474 L
.76755 .01472 L
.76833 .01472 L
.76905 .01472 L
.77035 .01475 L
.77108 .01478 L
.77175 .01482 L
.77304 .01492 L
.77424 .01504 L
.77695 .01543 L
.77933 .0159 L
.78187 .01653 L
.78675 .0181 L
.79123 .01999 L
.80132 .02578 L
.81022 .03269 L
.81959 .04179 L
.83931 .06705 L
.85767 .09794 L
.89668 .18599 L
.93815 .30895 L
.97619 .44187 L
Mfstroke
1 0 0 r
.02381 .44187 m
.21429 .44187 L
.21429 .47464 L
.02381 .47464 L
F
.21429 .44187 m
.40476 .44187 L
.40476 .60092 L
.21429 .60092 L
F
.40476 .44187 m
.59524 .44187 L
.59524 .44187 L
.40476 .44187 L
F
.59524 .44187 m
.78571 .44187 L
.78571 .07074 L
.59524 .07074 L
F
.78571 .44187 m
.97619 .44187 L
.97619 .14697 L
.78571 .14697 L
F
0 g
.5 Mabswid
.02381 .44187 m
.02381 .47464 L
s
.21429 .44187 m
.21429 .47464 L
s
.02381 .47464 m
.21429 .47464 L
s
.21429 .44187 m
.21429 .60092 L
s
.40476 .44187 m
.40476 .60092 L
s
.21429 .60092 m
.40476 .60092 L
s
.40476 .44187 m
.40476 .44187 L
s
.59524 .44187 m
.59524 .44187 L
s
.40476 .44187 m
.59524 .44187 L
s
.59524 .44187 m
.59524 .07074 L
s
.78571 .44187 m
.78571 .07074 L
s
.59524 .07074 m
.78571 .07074 L
s
.78571 .44187 m
.78571 .14697 L
s
.97619 .44187 m
.97619 .14697 L
s
.78571 .14697 m
.97619 .14697 L
s
0 0 1 r
.007 w
.02381 .44187 m
.02499 .44188 L
.02605 .44189 L
.02729 .44192 L
.02846 .44195 L
.03053 .44204 L
.03279 .44218 L
.03527 .44238 L
.0379 .44264 L
.04262 .44323 L
.04749 .44403 L
.05205 .44493 L
.06244 .44757 L
.07305 .45107 L
.08274 .45495 L
.10458 .46589 L
.14429 .4922 L
.18248 .52229 L
.22313 .55474 L
.26226 .58144 L
.27254 .5871 L
.28367 .59241 L
.29328 .59624 L
.29838 .59795 L
.30384 .59955 L
.30923 .60086 L
.31415 .60182 L
.31652 .6022 L
.31909 .60255 L
.32151 .60282 L
.32378 .60303 L
.32509 .60312 L
.3263 .60319 L
.32764 .60325 L
.32834 .60327 L
.32908 .60329 L
.32976 .60331 L
.33048 .60332 L
.33177 .60332 L
.33257 .60331 L
.33332 .6033 L
.33399 .60328 L
.33472 .60326 L
.33594 .60321 L
.33728 .60313 L
.33999 .60292 L
.34249 .60266 L
.34484 .60235 L
.34982 .60149 L
.35525 .60023 L
Mistroke
.36513 .59709 L
.37475 .59294 L
.38367 .58812 L
.40423 .57339 L
.42285 .55569 L
.46297 .50405 L
.50157 .43897 L
.54262 .35759 L
.58216 .27326 L
.62019 .19318 L
.66067 .11668 L
.69963 .05896 L
.70983 .04728 L
.72091 .03645 L
.73048 .02875 L
.73557 .02531 L
.74104 .02213 L
.74638 .01956 L
.75126 .01767 L
.75594 .01629 L
.75829 .01576 L
.76085 .0153 L
.76227 .01511 L
.76362 .01496 L
.76482 .01485 L
.76612 .01477 L
.7668 .01474 L
.76755 .01472 L
.76833 .01472 L
.76905 .01472 L
.77035 .01475 L
.77108 .01478 L
.77175 .01482 L
.77304 .01492 L
.77424 .01504 L
.77695 .01543 L
.77933 .0159 L
.78187 .01653 L
.78675 .0181 L
.79123 .01999 L
.80132 .02578 L
.81022 .03269 L
.81959 .04179 L
.83931 .06705 L
.85767 .09794 L
.89668 .18599 L
.93815 .30895 L
.97619 .44187 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00O7Goo00<007ooOol0
ogoo0Goo000MOol00`00Oomoo`3oOol1Ool001eoo`03001oogoo0?moo`5oo`007Goo00<007ooOol0
]7oo1P0OAWoo000MOol2002bOol301l5Ool301m4Ool001eoo`03001oogoo0:moo`807`]oo`<07d5o
o`007Goo00<007ooOol0[Woo00<07gooOol03Woo00<07gooOol0?Woo000MOol00`00Oomoo`2]Ool0
0`0OOomoo`0@Ool00`0OOomoo`0mOol001eoo`800:eoo`0301moogoo019oo`0301moogoo03aoo`00
7Goo00<007ooOol0ZWoo0P0O5Woo00<07gooOol0>goo000MOol00`00Oomoo`2YOol00`0OOomoo`0G
Ool00`0OOomoo`0jOol001eoo`03001oogoo0:Qoo`0301moogoo01Qoo`0301moogoo03Yoo`007Goo
0P00Z7oo00<07gooOol06Woo00<07gooOol0>Goo000MOol00`00Oomoo`2VOol00`0OOomoo`0LOol0
0`0OOomoo`0hOol001eoo`03001oogoo0:Eoo`0301moogoo01ioo`0301moogoo03Moo`007Goo00<0
07ooOol0YGoo00<07gooOol07goo00<07gooOol0=Woo000MOol00`00Oomoo`2TOol00`0OOomoo`0Q
Ool00`0OOomoo`0eOol001eoo`8008aooaP0000301l0000001H000aoo`0301moogoo03Eoo`007Goo
00<007ooOol0Rgoo00<007`0O0005G`000<07g`0O0005G`000<007ooOol02goo00<07gooOol0=7oo
000FOol30004Ool00`00Oomoo`2;Ool00`00O01l000DO0000`0OO01l000FO0000`00Oomoo`0<Ool0
0`0OOomoo`0cOol001Moo`03001oogoo00=oo`03001oogoo08]oo`03001l07`001Al000301ml07`0
01Il0003001oogoo00aoo`0301moogoo03=oo`003goo1@0000=oo`0000000P0017oo0`00Rgoo00<0
07`0O0004g`000<07g`0O0005g`000<007ooOol03Goo00<07gooOol0<Woo000EOol00`00Ool00005
Ool00`00Oomoo`2;Ool00`00O01l000BO0000`0OO01l000HO0000`00Oomoo`0=Ool00`0OOomoo`0b
Ool001Eoo`03001oo`0000Eoo`03001oogoo08]oo`03001l07`0019l000301ml07`001Ql0003001o
ogoo00ioo`0301moogoo035oo`005Woo0P001Goo00<007ooOol0Rgoo00<007`0O0004G`000<07g`0
O0006G`000<007ooOol03goo00<07gooOol0<7oo000MOol00`00Oomoo`2;Ool00`00O01l000AO000
0`0OO01l000IO0000`00Oomoo`0?Ool00`0OOomoo`0`Ool001eoo`8008aoo`03001l07`0011l0003
01ml07`001Yl0003001oogoo011oo`0301moogoo02moo`007Goo00<007ooOol0Rgoo00<007`0O000
3g`000<07g`0O0006g`000<007ooOol047oo00<07gooOol0;goo000MOol00`00Oomoo`2;Ool00`00
O01l000?O0000`0OO01l000KO0000`00Oomoo`0@Ool00`0OOomoo`0_Ool001eoo`03001oogoo08]o
o`03001l07`000il000301ml07`001al0003001oogoo015oo`0301moogoo02ioo`007Goo0P00S7oo
00<007`0O0003W`000<07g`0O00077`000<007ooOol04Goo00<07gooOol0;Woo000MOol00`00Oomo
o`2;Ool00`00O01l000=O0000`0OO01l000MO0000`00Oomoo`0BOol00`0OOomoo`0]Ool001eoo`03
001oogoo08]oo`03001l07`000el000301ml07`001el0003001oogoo019oo`0301moogoo02eoo`00
7Goo00<007ooOol0Rgoo00<007`0O00037`000<07g`0O0007W`000<007ooOol04Woo00<07gooOol0
;Goo000MOol2002<Ool00`00O01l000<O0000`0OO01l000NO0000`00Oomoo`0COol00`0OOomoo`0/
Ool001eoo`03001oogoo08]oo`03001l07`000]l000301ml07`001ml0003001oogoo01=oo`0301mo
ogoo02aoo`007Goo00<007ooOol0Rgoo00<007`0O0002g`000<07g`0O0007g`05`0000<07`000000
5P005Goo000MOol00`00Oomoo`2;Ool00`00O01l000:O0000`0OO01l000PO0000`00O01l000DO000
0`0OO01l000EO0000`00Oomoo`0COol001eoo`03001oogoo08]oo`03001l07`000Yl000301ml07`0
021l0003001l07`001El000301ml07`001Al0003001oogoo01=oo`007Goo0P00S7oo00<007`0O000
2G`000<07g`0O0008G`000<007`0O0005G`000<07g`0O00057`000<007ooOol04goo000MOol00`00
Oomoo`2;Ool00`00O01l0008O0000`0OO01l000RO0000`00O01l000EO0000`0OO01l000DO0000`00
Oomoo`0COol001Eoo`<000Eoo`03001oogoo08]oo`03001l07`000Ql000301ml07`0029l0003001l
07`001Il000301ml07`001=l0003001oogoo01=oo`0067oo00<007ooOol00Woo00<007ooOol0Rgoo
00<007`0O0001g`000<07g`0O0008g`000<007`0O0005W`000<07g`0O0004g`000<007ooOol04goo
000?Ool50004Ool00`00Oomoo`02Ool3002;Ool00`00O01l0007O0000`0OO01l000SO0000`00O01l
000GO0000`0OO01l000BO0000`00Oomoo`0COol001Ioo`8000Eoo`03001oogoo08]oo`03001l07`0
00Il000301ml07`002Al0003001l07`001Ml000301ml07`0019l0003001oogoo01=oo`0067oo00<0
07ooOol00Woo00<007ooOol0Rgoo00<007`0O0001W`000<07g`0O00097`000<007`0O0005g`000<0
7g`0O0004W`000<007ooOol04goo000EOol30005Ool00`00Oomoo`2;Ool00`00O01l0005O0000`0O
O01l000UO0000`00O01l000HO0000`0OO01l000AO0000`00Oomoo`0COol001eoo`03001oogoo08]o
o`03001l07`000El000301ml07`002El0003001l07`001Ql000301ml07`0015l0003001oogoo01=o
o`007Goo0P00S7oo00<007`0O00017`000<07g`0O0009W`000<007`0O0006G`000<07g`0O00047`0
00<007ooOol04goo000MOol00`00Oomoo`2;Ool00`00O01l0004O0000`0OO01l000VO0000`00O01l
000IO0000`0OO01l000@O0000`00Oomoo`0COol001eoo`03001oogoo08]oo`03001l07`000=l0003
01ml07`002Ml0003001l07`001Ul000301ml07`0011l0003001oogoo01=oo`007Goo00<007ooOol0
Rgoo00<007`0O0000g`000<07g`0O0009g`000<007`0O0006W`000<07g`0O0003g`000<007ooOol0
4goo000MOol2002<Ool00`00O01l0002O0000`0OO01l000XO0000`00O01l000JO0000`0OO01l000?
O0000`00Oomoo`0COol001eoo`03001oogoo08]oo`03001l07`0009l000301ml07`002Ql0003001l
07`001Yl000301ml07`000ml0003001oogoo01=oo`007Goo00<007ooOol0Rgoo00D007`0O01l000O
02]l0003001l07`001]l000301ml07`000il0003001oogoo01=oo`007Goo00<007ooOol0Rgoo00D0
07`0O01l000O02]l0003001l07`001]l000301ml07`000il0003001oogoo01=oo`007Goo00<007oo
Ool0Rgoo00@007`0O0007bal0003001l07`001]l000301ml07`000il0003001oogoo01=oo`007Goo
0P00S7oo00@007`0O0007bal0003001l07`001al000301ml07`000el0003001oogoo01=oo`007Goo
00<007ooOol0Rgoo00<007`001l0;G`000<007`0O00077`000<07g`0O0003G`000<007ooOol04goo
000MOol00`00Oomoo`2;Ool00`00O0007`0]O0000`00O01l000MO0000`0OO01l000<O0000`00Oomo
o`0COol001eoo`03001oogoo08]oo`0300007g`002el0003001l07`001el000301ml07`000al0003
001oogoo01=oo`007Goo0P00S7oo00<0000OO000;G`000<007`0O0007G`000<07g`0O00037`000<0
07ooOol04goo000MOol00`00Oomoo`2;Ool00`0OO01l000]O0000`00O01l000NO0000`0OO01l000;
O0000`00Oomoo`0COol001Eoo`@000Aoo`03001oogoo08]oo`0301ml07`002el0003001l07`001il
000301ml07`000]l0003001oogoo01=oo`005Woo00<007ooOol017oo00<007ooOol0RWoo00<07`00
O000;W`000<007`0O0007W`000<07g`0O0002g`000<007ooOol04goo000?Ool50003Ool00`00Oomo
o`03Ool3002:Ool00`0O001l000^O0000`00O01l000OO0000`0OO01l000:O0000`00Oomoo`0COol0
01Qoo`03001oogoo009oo`03001oogoo08Uoo`0301moo`0002ml0003001l07`001ml000301ml07`0
00Yl0003001oogoo01=oo`005Goo00@007ooOol000Aoo`03001oogoo08Uoo`0301moo`0002ml0003
001l07`0021l000301ml07`000Ul0003001oogoo01=oo`005Woo0P001Goo00<007ooOol0R7oo00@0
7gooOol002ml0003001l07`0021l000301ml07`000Ul0003001oogoo01=oo`007Goo00<007ooOol0
R7oo00@07gooOol002ml0003001l07`0021l000301ml07`000Ul0003001oogoo01=oo`007Goo0P00
R7oo00D07gooOomoo`0002ml0003001l07`0025l000301ml07`000Ql0003001oogoo01=oo`007Goo
00<007ooOol0Qgoo00D07gooOomoo`0002ml0003001l07`0025l000301ml07`000Ql0003001oogoo
01=oo`007Goo00<007ooOol0QWoo00<07gooOol00Woo00<007`0O000;G`000<007`0O0008G`000<0
7g`0O00027`000<007ooOol04goo000MOol00`00Oomoo`26Ool00`0OOomoo`02Ool00`00O01l000]
O0000`00O01l000RO0000`0OO01l0007O0000`00Oomoo`0COol001eoo`8008Ioo`0301moogoo00=o
o`03001l07`002el0003001l07`0029l000301ml07`000Ml0003001oogoo01=oo`007Goo00<007oo
Ool0QGoo00<07gooOol00goo00<007`0O000;G`000<007`0O0008W`000<07g`0O0001g`000<007oo
Ool04goo000MOol00`00Oomoo`24Ool00`0OOomoo`04Ool00`00O01l000]O0000`00O01l000SO000
0`0OO01l0006O0000`00Oomoo`0COol001eoo`03001oogoo08Aoo`0301moogoo00Aoo`03001l07`0
02el0003001l07`002=l000301ml07`000Il0003001oogoo01=oo`007Goo00<007ooOol0Pgoo00<0
7gooOol01Goo00<007`0O000;G`000<007`0O0008g`000<07g`0O0001W`000<007ooOol04goo000M
Ool20024Ool00`0OOomoo`05Ool00`00O01l000]O0000`00O01l000TO0000`0OO01l0005O0000`00
Oomoo`0COol001eoo`03001oogoo08=oo`0301moogoo00Eoo`03001l07`002el0003001l07`002Al
000301ml07`000El0003001oogoo01=oo`007Goo00<007ooOol0PWoo00<07gooOol01Woo00<007`0
O000;G`000<007`0O00097`000<07g`0O0001G`000<007ooOol04goo000MOol00`00Oomoo`22Ool0
0`0OOomoo`06Ool00`00O01l000]O0000`00O01l000TO0000`0OO01l0005O0000`00Oomoo`0COol0
01eoo`80089oo`0301moogoo00Moo`03001l07`002el0003001l07`002El000301ml07`000Al0003
001oogoo01=oo`007Goo00<007ooOol0PGoo00<07gooOol01goo00<007`0O000;G`000<007`0O000
9G`000<07g`0O00017`000<007ooOol04goo000EOol30005Ool00`00Oomoo`20Ool00`0OOomoo`08
Ool00`00O01l000]O0000`00O01l000UO0000`0OO01l0004O0000`00Oomoo`0COol001Ioo`03001o
ogoo00Aoo`03001oogoo081oo`0301moogoo00Qoo`03001l07`002el0003001l07`002Il000301ml
07`000=l0003001oogoo01=oo`003goo1@000Woo00<007ooOol017oo0`00Ogoo00<07gooOol02Goo
00<007`0O000;G`000<007`0O0009W`000<07g`0O0000g`000<007ooOol04goo000FOol00`00Oomo
o`04Ool00`00Oomoo`1oOol00`0OOomoo`09Ool00`00O01l000]O0000`00O01l000VO0000`0OO01l
0003O0000`00Oomoo`0COol001Ioo`03001oogoo00Aoo`03001oogoo07ioo`0301moogoo00Yoo`03
001l07`002el0003001l07`002Il000301ml07`000=l0003001oogoo01=oo`005Goo0P001Woo00<0
07ooOol0OWoo00<07gooOol02Woo00<007`0O000;G`000<007`0O0009g`000<07g`0O0000W`000<0
07ooOol04goo000MOol00`00Oomoo`1mOol00`0OOomoo`0;Ool00`00O01l000]O0000`00O01l000W
O0000`0OO01l0002O0000`00Oomoo`0COol001eoo`8007ioo`0301moogoo00]oo`03001l07`002el
0003001l07`002Ml000301ml07`0009l0003001oogoo01=oo`007Goo00<007ooOol0O7oo00<07goo
Ool037oo00<007`0O000;G`000<007`0O0009g`000<07g`0O0000W`000<007ooOol04goo000MOol0
0`00Oomoo`1lOol00`0OOomoo`0<Ool00`00O01l000]O0000`00O01l000XO0001@0OO01l07`00000
5Goo000MOol00`00Oomoo`1kOol00`0OOomoo`0=Ool00`00O01l000]O0000`00O01l000XO0001@0O
O01l07`000005Goo000MOol2001lOol00`0OOomoo`0=Ool00`00O01l000]O0000`00O01l000XO000
1@0OO01l07`000005Goo000MOol00`00Oomoo`1jOol00`0OOomoo`0>Ool00`00O01l000]O0000`00
O01l000XO0001@0OO01l07`000005Goo000MOol00`00Oomoo`1jOol00`0OOomoo`0>Ool00`00O01l
000]O0000`00O01l000YO000100OO01l00005Goo000MOol00`00Oomoo`0QOol3000SOol4000QOol3
000:Ool00`0OOomoo`0?Ool00`00O01l000]O0000`00O01l000YO000100OO01l00005Goo000MOol0
0`00Oomoo`0ROol00`00Oomoo`0SOol00`00Oomoo`0TOol00`00Oomoo`07Ool00`0OOomoo`0?Ool0
0`00O01l000]O0000`00O01l000YO000100OO01l00005Goo000MOol2000SOol00`00Oomoo`0TOol0
0`00Oomoo`0SOol00`00Oomoo`06Ool00`0OOomoo`0@Ool00`00O01l000]O0000`00O01l000YO000
100OO01l00005Goo000MOol00`00Oomoo`0ROol00`00Oomoo`0UOol00`00Oomoo`0POol20009Ool0
0`0OOomoo`0@Ool00`00O01l000]O0000`00O01l000ZO0000`0OO000000EOol001eoo`03001oogoo
029oo`03001oogoo029oo`04001oogoo000TOol00`00Oomoo`05Ool00`0OOomoo`0AOol00`00O01l
000]O0000`00O01l000ZO0000`0OO000000EOol001eoo`03001oogoo025oo`8002Eoo`80029oo`<0
00Qoo`0301moogoo015oo`03001l07`002el0003001l07`002Yl000301ml000001Eoo`007Goo0P00
Mgoo00<07gooOol04Woo00<007`0O000;G`000<007`0O000:g`000<07`00Ool057oo000MOol00`00
Oomoo`1fOol00`0OOomoo`0BOol00`00O01l000]O0000`00O01l000[O0000`0O001oo`0DOol001eo
o`03001oogoo07Eoo`0301moogoo01=oo`03001l07`002el0003001l07`002]l000301l007oo01Ao
o`007Goo00<007ooOol0MGoo00<07gooOol04goo00<007`0O000;G`000<007`0O000:g`000<07`00
Ool057oo000MOol00`00Oomoo`1LOol00`00Oomoo`0EOol00`0OOomoo`0DOol2000^O0000`00O01l
000/O0000`0OOomoo`0COol001Moo`H000X07fd0000301l0000001D002ml0003001l07`002al0003
01l0000000@000moo`007Goo00<007`0O0001g`00P0O8g`000<007`0O000;G`000<007ooOol03goo
00<007ooOol00Woo00<07gooOol07Woo00<007ooOol08goo00<007ooOol08Woo00<007ooOol07Woo
000MOol00`00O01l0009O00301lPO0000`00O01l000]O0000`00Oomoo`0COol00`0OOomoo`2;Ool0
01eoo`03001l07`000al00807ail0003001l07`002el0003001oogoo01=oo`0301moogoo08]oo`00
7Goo00<007`0O0003W`00P0O77`000<007`0O000;G`000<007ooOol04Woo00<07gooOol0S7oo000M
Ool00`00O01l000@O0000`0OO01l000IO0000`00O01l000]O0000`00Oomoo`0BOol00`0OOomoo`2<
Ool001eoo`03001l07`0015l00807aUl0003001l07`002el0003001oogoo015oo`0301moogoo08eo
o`007Goo00<007`0O0004g`00P0O5g`000<007`0O000;G`000<007ooOol047oo00<07gooOol0SWoo
000MOolH00000`0O0000000E000_O0000`00Oomoo`0@Ool00`0OOomoo`2>Ool001eoo`03001oogoo
01Ioo`807aAoo`03001l07`002el0003001oogoo00moo`0301moogoo08moo`007Goo00<007ooOol0
67oo0P0O4Woo00<007`0O000;G`000<007ooOol03Woo00<07gooOol0T7oo000MOol00`00Oomoo`0J
Ool00`0OOomoo`0?Ool00`00O01l000]O0000`00Oomoo`0>Ool00`0OOomoo`2@Ool001eoo`03001o
ogoo01]oo`807`moo`03001l07`002el0003001oogoo00eoo`0301moogoo095oo`007Goo0P007Woo
00<07gooOol037oo00<007`0O000;G`000<007ooOol03Goo00<07gooOol0TGoo000MOol00`00Oomo
o`0NOol00`0OOomoo`0;Ool00`00O01l000]O0000`00Oomoo`0<Ool00`0OOomoo`2BOol001eoo`03
001oogoo01moo`0301moogoo00Yoo`03001l07`002el0003001oogoo00]oo`0301moogoo09=oo`00
7Goo00<007ooOol087oo0P0O2Woo00<007`0O000;G`000<007ooOol02goo00<07gooOol0Tgoo000M
Ool2000SOol00`0OOomoo`07Ool00`00O01l000]O0000`00Oomoo`0:Ool00`0OOomoo`2DOol001eo
o`03001oogoo02=oo`0301moogoo00Ioo`03001l07`002el0003001oogoo00Uoo`0301moogoo09Eo
o`007Goo00<007ooOol097oo00<07gooOol01Goo00<007`0O000;G`000<007ooOol027oo00<07goo
Ool0UWoo000EOol30005Ool00`00Oomoo`0UOol201l5Ool00`00O01l000]O0000`00Oomoo`08Ool0
0`0OOomoo`2FOol001Ioo`03001oogoo00Aoo`03001oogoo02Moo`0301moogoo009oo`03001l07`0
02el0003001oogoo00Moo`0301moogoo09Moo`005Woo00<007ooOol017oo0`00:7oo00D07gooOomo
o`0002ml0003001oogoo00Ioo`0301moogoo09Qoo`005Woo00<007ooOol017oo00<007ooOol0:Goo
00@07gooOol002ml0003001oogoo00Eoo`0301moogoo09Uoo`005Woo00<007ooOol017oo00<007oo
Ool0:Woo0P0O00<007`0O000;G`000<007ooOol017oo00<07gooOol0VWoo000EOol20006Ool00`00
Oomoo`0/Ool00`0OO01l000]O0000`00Oomoo`04Ool00`0OOomoo`2JOol001eoo`8002eoo`030000
7g`002el0003001oogoo00=oo`0301moogoo09]oo`007Goo00<007ooOol0;7oo00<007`001l0;G`0
00<007ooOol00Woo00<07gooOol0W7oo000MOol00`00Oomoo`0/Ool00`00O01l000201l[O0001@00
Oomoogoo01l0Wgoo000MOol00`00Oomoo`0/Ool00`00O01l0002O0000`0OO01l000XO0001000Oomo
o`0OX7oo000MOol2000]Ool00`00O01l0003O00201lXO0000`00Ool07`2QOol001eoo`03001oogoo
02aoo`03001l07`000El000301ml07`002El000300007goo0:5oo`007Goo00<007ooOol0;7oo00<0
07`0O0001W`00P0O97`00P0OXgoo000MOol00`00Oomoo`0/Ool00`00O01l0008O0000`0OO01l000P
O0000`0OO000002SOol001eoo`03001oogoo02aoo`03001l07`000Ul00807aml000401ml07`0002S
Ool001eoo`8002eoo`03001l07`000]l000301ml07`001]l000501ml07`0O000002SOol001eoo`03
001oogoo02aoo`03001l07`000al00<07aQl00807`Al0003001oogoo0:5oo`007Goo00<007ooOol0
;7oo00<007`0O0003g`00P0O4g`00`0O1W`000<007ooOol0XGoo000MOol00`00Oomoo`0/Ool00`00
O01l000AO00301l>O00201l9O0000`00Oomoo`2QOol001eoo`8002eooaL000@07`H000@07``00:=o
o`007Goo00<007ooOol0Agoo1P0O/goo000MOol00`00Oomoo`3oOol1Ool001eoo`03001oogoo0?mo
o`5oo`007Goo00<007ooOol0ogoo0Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00?7oo1P001Woo0`000goo100017oo0`001Goo0`00
0goo100000=oo`0000000P000Woo0P001Goo2P0000=oo`0000000P000Woo100017oo10000goo1000
6Woo0`0017oo0P001goo0P000Woo1@001Goo1P0017oo10001Woo00<007ooOol0=goo000nOol20007
Ool20002Ool01000Oomoogoo0P0017oo0P000Woo00@007ooOomoo`80009oo`04001oogooOol20003
Ool20002Ool200000goo001oo`05Ool20005Ool200000goo00000004Ool20004Ool20002Ool20003
Ool2000IOol20002Ool20003Ool20007Ool20002Ool20003Ool20005Ool20005Ool20002Ool20005
Ool2000hOol003ioo`8000Ioo`8000Aoo`03001oogoo008000=oo`8000Aoo`04001oo`000004Ool0
0`00Oomoo`020003Ool20002Ool20008Ool20006Ool01000Ool0000017oo0P000goo0P0017oo0P00
0Woo0P002Goo2@001goo00<007ooOol00Woo0P002goo0P0027oo00<007ooOol00goo0P001Goo00<0
07ooOol00Woo00<007ooOol017oo00<007ooOol0=Woo000nOol20006Ool20007Ool20003Ool20006
Ool20007Ool20003Ool20002Ool20008Ool20008Ool20004Ool20003Ool20004Ool20002Ool2000H
Ool20004Ool20006Ool90006Ool20004Ool20004Ool20004Ool20005Ool00`00Oomoo`0fOol003io
o`8000Ioo`8000Moo`8000=oo`8000Ioo`8000Moo`8000=oo`80009oo`8000Qoo`8000Aoo`04001o
ogooOol20004Ool20003Ool20004Ool20002Ool2000HOol20004Ool20006Ool00`00Oomoo`02Ool2
0008Ool20004Ool20004Ool20004Ool20005Ool00`00Oomoo`0fOol003ioo`H0009oo`L0009oo`80
00=oo`8000Aoo`03001oo`0000H0009oo`8000=oo`80009oo`8000Qoo`8000Aoo`04001oogooOol2
0004Ool20003Ool20004Ool20002Ool2000HOol20004Ool20007Ool01000Oomoogoo0P001goo0`00
17oo0P0017oo0P0017oo0P001Woo00<007ooOol0=Goo000nOol20003Ool20002Ool01000Oomoogoo
0P0000=oo`000000100000=oo`0000000Woo0P000Woo00@007ooOomoo`800003Ool000000080009o
o`80009oo`8000Qoo`L0009oo``00003Ool00000009oo`80009oo`H000Ioo`T000Ioo`<0009oo`80
00Uoo`03001oogoo008000Eoo`@000Eoo`8000Aoo`8000Aoo`8000Ioo`03001oogoo03Eoo`00?Woo
0P0017oo0P000Woo100017oo00@007oo0000009oo`@000Aoo`@000Aoo`03001oo`000080009oo`D0
00Ioo`8000Aoo`03001oogoo009oo`04001oo`000002Ool01000Ool000000Woo10001Goo00@007oo
000001Eoo`800004Ool00000000:Ool00`00Oomoo`020002Ool60006Ool20004Ool20004Ool20006
Ool00`00Oomoo`0eOol003ioo`8000Aoo`8002Qoo`8000Qoo`8000Aoo`03001oogoo035oo`8000io
o`04001oo`000003Ool40007Ool20004Ool20004Ool20007Ool00`00Oomoo`0dOol003ioo`8000Ao
o`8002Uoo`03001oogoo00Ioo`8003Qoo`8000moo`<000=oo`03001oogoo00Qoo`8000Aoo`8000Ao
o`8000Moo`03001oogoo03Aoo`00?Woo0P0017oo0P00<Woo0P001Goo00<007ooOol0<Goo0P003Woo
0`0017oo00<007ooOol01goo0P001Goo00<007ooOol00Woo00<007ooOol00P0017oo00<007ooOol0
=7oo000nOol20003Ool2000cOol20005Ool00`00Oomoo`0bOol2000>Ool20004Ool50003Ool40005
Ool20002Ool20003Ool7000eOol003aoo`P0039oo`X003Ioo`<000]oo`8000Aoo`H000Aoo`8000Io
o`@000Aoo`L003Eoo`00ogoo8Goo003oOolQOol00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.783823, -4.98036, 
  0.0265065, 0.0452841}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.151576 0.44187 0.0887232 [
[.17539 .42937 -3 -9 ]
[.17539 .42937 3 0 ]
[.32696 .42937 -3 -9 ]
[.32696 .42937 3 0 ]
[.47854 .42937 -3 -9 ]
[.47854 .42937 3 0 ]
[.63011 .42937 -3 -9 ]
[.63011 .42937 3 0 ]
[.78169 .42937 -3 -9 ]
[.78169 .42937 3 0 ]
[.93327 .42937 -3 -9 ]
[.93327 .42937 3 0 ]
[.01131 .08698 -12 -4.5 ]
[.01131 .08698 0 4.5 ]
[.01131 .1757 -12 -4.5 ]
[.01131 .1757 0 4.5 ]
[.01131 .26442 -12 -4.5 ]
[.01131 .26442 0 4.5 ]
[.01131 .35315 -12 -4.5 ]
[.01131 .35315 0 4.5 ]
[.01131 .53059 -6 -4.5 ]
[.01131 .53059 0 4.5 ]
[.5 .63053 -89.5938 0 ]
[.5 .63053 89.5938 20 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.17539 .44187 m
.17539 .44812 L
s
[(1)] .17539 .42937 0 1 Mshowa
.32696 .44187 m
.32696 .44812 L
s
[(2)] .32696 .42937 0 1 Mshowa
.47854 .44187 m
.47854 .44812 L
s
[(3)] .47854 .42937 0 1 Mshowa
.63011 .44187 m
.63011 .44812 L
s
[(4)] .63011 .42937 0 1 Mshowa
.78169 .44187 m
.78169 .44812 L
s
[(5)] .78169 .42937 0 1 Mshowa
.93327 .44187 m
.93327 .44812 L
s
[(6)] .93327 .42937 0 1 Mshowa
.125 Mabswid
.05412 .44187 m
.05412 .44562 L
s
.08444 .44187 m
.08444 .44562 L
s
.11476 .44187 m
.11476 .44562 L
s
.14507 .44187 m
.14507 .44562 L
s
.2057 .44187 m
.2057 .44562 L
s
.23602 .44187 m
.23602 .44562 L
s
.26633 .44187 m
.26633 .44562 L
s
.29665 .44187 m
.29665 .44562 L
s
.35728 .44187 m
.35728 .44562 L
s
.38759 .44187 m
.38759 .44562 L
s
.41791 .44187 m
.41791 .44562 L
s
.44822 .44187 m
.44822 .44562 L
s
.50885 .44187 m
.50885 .44562 L
s
.53917 .44187 m
.53917 .44562 L
s
.56948 .44187 m
.56948 .44562 L
s
.5998 .44187 m
.5998 .44562 L
s
.66043 .44187 m
.66043 .44562 L
s
.69074 .44187 m
.69074 .44562 L
s
.72106 .44187 m
.72106 .44562 L
s
.75137 .44187 m
.75137 .44562 L
s
.81201 .44187 m
.81201 .44562 L
s
.84232 .44187 m
.84232 .44562 L
s
.87264 .44187 m
.87264 .44562 L
s
.90295 .44187 m
.90295 .44562 L
s
.96358 .44187 m
.96358 .44562 L
s
.9939 .44187 m
.9939 .44562 L
s
.25 Mabswid
0 .44187 m
1 .44187 L
s
.02381 .08698 m
.03006 .08698 L
s
[(-4)] .01131 .08698 1 0 Mshowa
.02381 .1757 m
.03006 .1757 L
s
[(-3)] .01131 .1757 1 0 Mshowa
.02381 .26442 m
.03006 .26442 L
s
[(-2)] .01131 .26442 1 0 Mshowa
.02381 .35315 m
.03006 .35315 L
s
[(-1)] .01131 .35315 1 0 Mshowa
.02381 .53059 m
.03006 .53059 L
s
[(1)] .01131 .53059 1 0 Mshowa
.125 Mabswid
.02381 .016 m
.02756 .016 L
s
.02381 .03374 m
.02756 .03374 L
s
.02381 .05149 m
.02756 .05149 L
s
.02381 .06923 m
.02756 .06923 L
s
.02381 .10472 m
.02756 .10472 L
s
.02381 .12247 m
.02756 .12247 L
s
.02381 .14021 m
.02756 .14021 L
s
.02381 .15796 m
.02756 .15796 L
s
.02381 .19344 m
.02756 .19344 L
s
.02381 .21119 m
.02756 .21119 L
s
.02381 .22893 m
.02756 .22893 L
s
.02381 .24668 m
.02756 .24668 L
s
.02381 .28217 m
.02756 .28217 L
s
.02381 .29991 m
.02756 .29991 L
s
.02381 .31766 m
.02756 .31766 L
s
.02381 .3354 m
.02756 .3354 L
s
.02381 .37089 m
.02756 .37089 L
s
.02381 .38864 m
.02756 .38864 L
s
.02381 .40638 m
.02756 .40638 L
s
.02381 .42413 m
.02756 .42413 L
s
.02381 .45961 m
.02756 .45961 L
s
.02381 .47736 m
.02756 .47736 L
s
.02381 .4951 m
.02756 .4951 L
s
.02381 .51285 m
.02756 .51285 L
s
.02381 .54834 m
.02756 .54834 L
s
.02381 .56608 m
.02756 .56608 L
s
.02381 .58383 m
.02756 .58383 L
s
.02381 .60157 m
.02756 .60157 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -150.594 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 24.000000 moveto
 558.000000 24.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 24.000000 lineto
closepath
clip newpath
63.000000 19.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 18.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 19.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 18.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Percent) show
121.250000 19.000000 moveto
(Error) show
163.625000 19.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 18.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(=) show
179.687500 19.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 18.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(4.50703) show
238.187500 19.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 18.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
0 0 1 r
.007 w
.02381 .44187 m
.02499 .44188 L
.02605 .44189 L
.02729 .44192 L
.02846 .44195 L
.03053 .44204 L
.03279 .44218 L
.03527 .44238 L
.0379 .44264 L
.04262 .44323 L
.04749 .44403 L
.05205 .44493 L
.06244 .44757 L
.07305 .45107 L
.08274 .45495 L
.10458 .46589 L
.14429 .4922 L
.18248 .52229 L
.22313 .55474 L
.26226 .58144 L
.27254 .5871 L
.28367 .59241 L
.29328 .59624 L
.29838 .59795 L
.30384 .59955 L
.30923 .60086 L
.31415 .60182 L
.31652 .6022 L
.31909 .60255 L
.32151 .60282 L
.32378 .60303 L
.32509 .60312 L
.3263 .60319 L
.32764 .60325 L
.32834 .60327 L
.32908 .60329 L
.32976 .60331 L
.33048 .60332 L
.33177 .60332 L
.33257 .60331 L
.33332 .6033 L
.33399 .60328 L
.33472 .60326 L
.33594 .60321 L
.33728 .60313 L
.33999 .60292 L
.34249 .60266 L
.34484 .60235 L
.34982 .60149 L
.35525 .60023 L
Mistroke
.36513 .59709 L
.37475 .59294 L
.38367 .58812 L
.40423 .57339 L
.42285 .55569 L
.46297 .50405 L
.50157 .43897 L
.54262 .35759 L
.58216 .27326 L
.62019 .19318 L
.66067 .11668 L
.69963 .05896 L
.70983 .04728 L
.72091 .03645 L
.73048 .02875 L
.73557 .02531 L
.74104 .02213 L
.74638 .01956 L
.75126 .01767 L
.75594 .01629 L
.75829 .01576 L
.76085 .0153 L
.76227 .01511 L
.76362 .01496 L
.76482 .01485 L
.76612 .01477 L
.7668 .01474 L
.76755 .01472 L
.76833 .01472 L
.76905 .01472 L
.77035 .01475 L
.77108 .01478 L
.77175 .01482 L
.77304 .01492 L
.77424 .01504 L
.77695 .01543 L
.77933 .0159 L
.78187 .01653 L
.78675 .0181 L
.79123 .01999 L
.80132 .02578 L
.81022 .03269 L
.81959 .04179 L
.83931 .06705 L
.85767 .09794 L
.89668 .18599 L
.93815 .30895 L
.97619 .44187 L
Mfstroke
1 0 0 r
.02381 .44187 m
.18254 .44187 L
.18254 .4651 L
.02381 .4651 L
F
.18254 .44187 m
.34127 .44187 L
.34127 .58124 L
.18254 .58124 L
F
.34127 .44187 m
.5 .44187 L
.5 .55801 L
.34127 .55801 L
F
.5 .44187 m
.65873 .44187 L
.65873 .27928 L
.5 .27928 L
F
.65873 .44187 m
.81746 .44187 L
.81746 .02377 L
.65873 .02377 L
F
.81746 .44187 m
.97619 .44187 L
.97619 .18637 L
.81746 .18637 L
F
0 g
.5 Mabswid
.02381 .44187 m
.02381 .4651 L
s
.18254 .44187 m
.18254 .4651 L
s
.02381 .4651 m
.18254 .4651 L
s
.18254 .44187 m
.18254 .58124 L
s
.34127 .44187 m
.34127 .58124 L
s
.18254 .58124 m
.34127 .58124 L
s
.34127 .44187 m
.34127 .55801 L
s
.5 .44187 m
.5 .55801 L
s
.34127 .55801 m
.5 .55801 L
s
.5 .44187 m
.5 .27928 L
s
.65873 .44187 m
.65873 .27928 L
s
.5 .27928 m
.65873 .27928 L
s
.65873 .44187 m
.65873 .02377 L
s
.81746 .44187 m
.81746 .02377 L
s
.65873 .02377 m
.81746 .02377 L
s
.81746 .44187 m
.81746 .18637 L
s
.97619 .44187 m
.97619 .18637 L
s
.81746 .18637 m
.97619 .18637 L
s
0 0 1 r
.007 w
.02381 .44187 m
.02499 .44188 L
.02605 .44189 L
.02729 .44192 L
.02846 .44195 L
.03053 .44204 L
.03279 .44218 L
.03527 .44238 L
.0379 .44264 L
.04262 .44323 L
.04749 .44403 L
.05205 .44493 L
.06244 .44757 L
.07305 .45107 L
.08274 .45495 L
.10458 .46589 L
.14429 .4922 L
.18248 .52229 L
.22313 .55474 L
.26226 .58144 L
.27254 .5871 L
.28367 .59241 L
.29328 .59624 L
.29838 .59795 L
.30384 .59955 L
.30923 .60086 L
.31415 .60182 L
.31652 .6022 L
.31909 .60255 L
.32151 .60282 L
.32378 .60303 L
.32509 .60312 L
.3263 .60319 L
.32764 .60325 L
.32834 .60327 L
.32908 .60329 L
.32976 .60331 L
.33048 .60332 L
.33177 .60332 L
.33257 .60331 L
.33332 .6033 L
.33399 .60328 L
.33472 .60326 L
.33594 .60321 L
.33728 .60313 L
.33999 .60292 L
.34249 .60266 L
.34484 .60235 L
.34982 .60149 L
.35525 .60023 L
Mistroke
.36513 .59709 L
.37475 .59294 L
.38367 .58812 L
.40423 .57339 L
.42285 .55569 L
.46297 .50405 L
.50157 .43897 L
.54262 .35759 L
.58216 .27326 L
.62019 .19318 L
.66067 .11668 L
.69963 .05896 L
.70983 .04728 L
.72091 .03645 L
.73048 .02875 L
.73557 .02531 L
.74104 .02213 L
.74638 .01956 L
.75126 .01767 L
.75594 .01629 L
.75829 .01576 L
.76085 .0153 L
.76227 .01511 L
.76362 .01496 L
.76482 .01485 L
.76612 .01477 L
.7668 .01474 L
.76755 .01472 L
.76833 .01472 L
.76905 .01472 L
.77035 .01475 L
.77108 .01478 L
.77175 .01482 L
.77304 .01492 L
.77424 .01504 L
.77695 .01543 L
.77933 .0159 L
.78187 .01653 L
.78675 .0181 L
.79123 .01999 L
.80132 .02578 L
.81022 .03269 L
.81959 .04179 L
.83931 .06705 L
.85767 .09794 L
.89668 .18599 L
.93815 .30895 L
.97619 .44187 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00O7Goo00<007ooOol0
ogoo0Goo000MOol00`00Oomoo`3oOol1Ool001eoo`03001oogoo0?moo`5oo`007Goo00<007ooOol0
]7oo1P0OAWoo000MOol2002bOol301l5Ool301m4Ool001eoo`03001oogoo09]ooa@000807`/000<0
7`D003aoo`007Goo00<007ooOol0Vgoo00<007`0O00047`000<07g`0O0003W`000D07g`0O01l0000
03aoo`007Goo00<007ooOol0Vgoo00<007`0O0003g`000<07g`0O00047`000@07g`0O00003aoo`00
7Goo0P00W7oo00<007`0O0003W`000<07g`0O0004W`000<07g`00000?7oo000MOol00`00Oomoo`2K
Ool00`00O01l000<O00201lFO0000`0O001oo`0kOol001eoo`03001oogoo09]oo`03001l07`000]l
000301ml07`001Ml000301moogoo03Yoo`007Goo00<007ooOol0Vgoo00<007`0O0002W`000<07g`0
O00067`000<07gooOol0>Woo000MOol2002LOol00`00O01l0009O0000`0OO01l000IO0000`0001mo
o`0jOol001eoo`03001oogoo09]oo`03001l07`000Ql000301ml07`001Yl0003001oo`0O03Yoo`00
7Goo00<007ooOol0Vgoo00<007`0O0001g`000<07g`0O0006g`000@007ooOol07cUoo`007Goo00<0
07ooOol0Vgoo00<007`0O0001g`000<07g`0O0006g`000D007ooOomoo`0O03Qoo`007Goo00<007oo
Ool0Vgoo00<007`0O0001W`000<07g`0O00077`000<007ooOol00Woo00<07gooOol0=Goo000MOol2
002LOol00`00O01l0005O0000`0OO01l000MO0000`00Oomoo`02Ool00`0OOomoo`0eOol001eoo`03
001oogoo09]oo`03001l07`000El000301ml07`001el0003001oogoo00=oo`0301moogoo03Aoo`00
5Woo0`0017oo00<007ooOol0Vgoo00<007`0O00017`000<07g`0O0007W`000<007ooOol017oo00<0
7gooOol0<goo000GOol00`00Oomoo`03Ool00`00Oomoo`2KOol00`00O01l0004O0000`0OO01l000N
O0000`00Oomoo`04Ool00`0OOomoo`0cOol000moo`D00003Ool00000008000Aoo`<009]oo`03001l
07`000=l000301ml07`001ml0003001oogoo00Eoo`0301moogoo039oo`005Goo00<007oo00001Goo
00<007ooOol0Vgoo00<007`0O0000W`000<07g`0O00087`000<007ooOol01Goo00<07gooOol0<Woo
000EOol00`00Ool00005Ool00`00Oomoo`2KOol00`00O01l0002O0000`0OO01l000PO0000`00Oomo
o`06Ool00`0OOomoo`0aOol001Ioo`8000Eoo`03001oogoo09]oo`05001l07`0O0007`0SO0000`00
Oomoo`07Ool00`0OOomoo`0`Ool001eoo`03001oogoo09]oo`05001l07`0O0007`0SO0000`00Oomo
o`07Ool00`0OOomoo`0`Ool001eoo`8009aoo`04001l07`001lTO0000`00Oomoo`08Ool00`0OOomo
o`0_Ool001eoo`03001oogoo09]oo`03001l000O02El0003001oogoo00Qoo`0301moogoo02moo`00
7Goo00<007ooOol0Vgoo00<007`001l09G`000<007ooOol027oo00<07gooOol0;goo000MOol00`00
Oomoo`2KOol00`0001ml000UO0000`00Oomoo`09Ool00`0OOomoo`0^Ool001eoo`8009aoo`030000
7g`002El0003001oogoo00Uoo`0301moogoo02ioo`007Goo00<007ooOol0Vgoo00<07g`0O0009G`0
00<007ooOol02Woo00<07gooOol0;Goo000MOol00`00Oomoo`2KOol00`0OO01l000UO0000`00Oomo
o`0:Ool00`0OOomoo`0]Ool001eoo`03001oogoo09Yoo`0301l007`002Il0003001oogoo00Yoo`03
01moogoo02eoo`007Goo0P00Vgoo00<07`00O0009W`000<007ooOol02goo00<07gooOol0;7oo000M
Ool00`00Oomoo`2IOol00`0OOol0000WO0000`00Oomoo`0;Ool00`0OOomoo`0/Ool001eoo`03001o
ogoo09Uoo`0301moo`0002Ml0003001oogoo00aoo`0301moogoo02]oo`007Goo00<007ooOol0V7oo
00@07gooOol002Ml0003001oogoo00aoo`0301moogoo02]oo`007Goo00<007ooOol0V7oo00@07goo
Ool002Ml0003001oogoo00eoo`0301moogoo02Yoo`007Goo0P00V7oo00D07gooOomoo`0002Ml0003
001oogoo00eoo`0301moogoo02Yoo`007Goo00<007ooOol0UWoo00<07gooOol00Woo00<007`0O000
9G`000<007ooOol03Goo00<07gooOol0:Woo000EOol30005Ool00`00Oomoo`2FOol00`0OOomoo`02
Ool00`00O01l000UO0000`00Oomoo`0>Ool00`0OOomoo`0YOol001Qoo`03001oogoo009oo`03001o
ogoo09Eoo`0301moogoo00=oo`03001l07`002El0003001oogoo00ioo`0301moogoo02Uoo`003goo
1@0017oo00<007ooOol00Woo0`00UGoo00<07gooOol00goo00<007`0O0009G`000<007ooOol03goo
00<07gooOol0:7oo000FOol20005Ool00`00Oomoo`2DOol00`0OOomoo`04Ool00`00O01l000UO000
0`00Oomoo`0?Ool00`0OOomoo`0XOol001Qoo`03001oogoo009oo`03001oogoo09Aoo`0301moogoo
00Aoo`03001l07`002El0003001oogoo00moo`0301moogoo02Qoo`005Goo0`001Goo00<007ooOol0
Tgoo00<07gooOol01Goo00<007`0O0009G`04`0000<07`0000004P005Goo000MOol00`00Oomoo`2C
Ool00`0OOomoo`05Ool00`00O01l000UO0000`00O01l000@O0000`0OO01l000AO0000`00Oomoo`0C
Ool001eoo`8009=oo`0301moogoo00Ioo`03001l07`002El0003001l07`0015l000301ml07`0011l
0003001oogoo01=oo`007Goo00<007ooOol0TWoo00<07gooOol01Woo00<007`0O0009G`000<007`0
O0004G`000<07g`0O00047`000<007ooOol04goo000MOol00`00Oomoo`2AOol00`0OOomoo`07Ool0
0`00O01l000UO0000`00O01l000AO0000`0OO01l000@O0000`00Oomoo`0COol001eoo`03001oogoo
095oo`0301moogoo00Moo`03001l07`002El0003001l07`0019l000301ml07`000ml0003001oogoo
01=oo`007Goo0P00TGoo00<07gooOol027oo00<007`0O0009G`000<007`0O0004W`000<07g`0O000
3g`000<007ooOol04goo000MOol00`00Oomoo`2@Ool00`0OOomoo`08Ool00`00O01l000UO0000`00
O01l000BO0000`0OO01l000?O0000`00Oomoo`0COol001eoo`03001oogoo08moo`0301moogoo00Uo
o`03001l07`002El0003001l07`001=l000301ml07`000il0003001oogoo01=oo`007Goo00<007oo
Ool0Sgoo00<07gooOol02Goo00<007`0O0009G`000<007`0O0004g`000<07g`0O0003W`000<007oo
Ool04goo000MOol00`00Oomoo`2>Ool00`0OOomoo`0:Ool00`00O01l000UO0000`00O01l000CO000
0`0OO01l000>O0000`00Oomoo`0COol001eoo`8008moo`0301moogoo00Yoo`03001l07`002El0003
001l07`001Al000301ml07`000el0003001oogoo01=oo`007Goo00<007ooOol0SGoo00<07gooOol0
2goo00<007`0O0009G`000<007`0O00057`000<07g`0O0003G`000<007ooOol04goo000MOol00`00
Oomoo`2=Ool00`0OOomoo`0;Ool00`00O01l000UO0000`00O01l000EO0000`0OO01l000<O0000`00
Oomoo`0COol001eoo`03001oogoo08aoo`0301moogoo00aoo`03001l07`002El0003001l07`001El
000301ml07`000al0003001oogoo01=oo`007Goo0P00SGoo00<07gooOol037oo00<007`0O0009G`0
00<007`0O0005G`000<07g`0O00037`000<007ooOol04goo000MOol00`00Oomoo`2;Ool00`0OOomo
o`0=Ool00`00O01l000UO0000`00O01l000FO0000`0OO01l000;O0000`00Oomoo`0COol001Eoo`@0
00Aoo`03001oogoo08]oo`0301moogoo00eoo`03001l07`002El0003001l07`001Il000301ml07`0
00]l0003001oogoo01=oo`005Woo00<007ooOol017oo00<007ooOol0RWoo00<07gooOol03Woo00<0
07`0O0009G`000<007`0O0005W`000<07g`0O0002g`000<007ooOol04goo000?Ool50003Ool00`00
Oomoo`03Ool3002:Ool00`0OOomoo`0>Ool00`00O01l000UO0000`00O01l000GO0000`0OO01l000:
O0000`00Oomoo`0COol001Qoo`03001oogoo009oo`03001oogoo08Uoo`0301moogoo00moo`03001l
07`002El0003001l07`001Ml000301ml07`000Yl0003001oogoo01=oo`005Goo00@007ooOol000Ao
o`03001oogoo08Uoo`0301moogoo00moo`03001l07`002El0003001l07`001Ql000301ml07`000Ul
0003001oogoo01=oo`005Woo0P001Goo00<007ooOol0R7oo00<07gooOol047oo00<007`0O0009G`0
00<007`0O00067`000<07g`0O0002G`000<007ooOol04goo000MOol00`00Oomoo`1dOolD00000`0O
0000000A000WO0000`00O01l000HO0000`0OO01l0009O0000`00Oomoo`0COol001eoo`8007Eoo`03
001l07`0011l000301ml07`0015l0003001l07`002El0003001l07`001Ul000301ml07`000Ql0003
001oogoo01=oo`007Goo00<007ooOol0M7oo00<007`0O00047`000<07g`0O0004G`000<007`0O000
9G`000<007`0O0006G`000<07g`0O00027`000<007ooOol04goo000MOol00`00Oomoo`1dOol00`00
O01l000?O0000`0OO01l000BO0000`00O01l000UO0000`00O01l000IO0000`0OO01l0008O0000`00
Oomoo`0COol001eoo`03001oogoo07Aoo`03001l07`000ml000301ml07`0019l0003001l07`002El
0003001l07`001Yl000301ml07`000Ml0003001oogoo01=oo`007Goo0P00MGoo00<007`0O0003W`0
00<07g`0O0004g`000<007`0O0009G`000<007`0O0006W`000<07g`0O0001g`000<007ooOol04goo
000MOol00`00Oomoo`1dOol00`00O01l000>O0000`0OO01l000CO0000`00O01l000UO0000`00O01l
000JO0000`0OO01l0007O0000`00Oomoo`0COol001eoo`03001oogoo07Aoo`03001l07`000el0003
01ml07`001Al0003001l07`002El0003001l07`001]l000301ml07`000Il0003001oogoo01=oo`00
7Goo00<007ooOol0M7oo00<007`0O0003G`000<07g`0O00057`000<007`0O0009G`000<007`0O000
6g`000<07g`0O0001W`000<007ooOol04goo000MOol00`00Oomoo`1dOol00`00O01l000<O0000`0O
O01l000EO0000`00O01l000UO0000`00O01l000KO0000`0OO01l0006O0000`00Oomoo`0COol001eo
o`8007Eoo`03001l07`000al000301ml07`001El0003001l07`002El0003001l07`001al000301ml
07`000El0003001oogoo01=oo`007Goo00<007ooOol0M7oo00<007`0O00037`000<07g`0O0005G`0
00<007`0O0009G`000<007`0O00077`000<07g`0O0001G`000<007ooOol04goo000MOol00`00Oomo
o`1dOol00`00O01l000;O0000`0OO01l000FO0000`00O01l000UO0000`00O01l000LO0000`0OO01l
0005O0000`00Oomoo`0COol001eoo`03001oogoo07Aoo`03001l07`000]l000301ml07`001Il0003
001l07`002El0003001l07`001al000301ml07`000El0003001oogoo01=oo`007Goo0P00MGoo00<0
07`0O0002W`000<07g`0O0005g`000<007`0O0009G`000<007`0O0007G`000<07g`0O00017`000<0
07ooOol04goo000MOol00`00Oomoo`1dOol00`00O01l000:O0000`0OO01l000GO0000`00O01l000U
O0000`00O01l000MO0000`0OO01l0004O0000`00Oomoo`0COol001Eoo`<000Eoo`03001oogoo07Ao
o`03001l07`000Ul000301ml07`001Ql0003001l07`002El0003001l07`001el000301ml07`000Al
0003001oogoo01=oo`005Woo00<007ooOol017oo00<007ooOol0M7oo00<007`0O0002G`000<07g`0
O00067`000<007`0O0009G`000<007`0O0007W`000<07g`0O0000g`000<007ooOol04goo000?Ool5
0002Ool00`00Oomoo`04Ool3001dOol00`00O01l0008O0000`0OO01l000IO0000`00O01l000UO000
0`00O01l000NO0000`0OO01l0003O0000`00Oomoo`0COol001Ioo`03001oogoo00Aoo`03001oogoo
07Aoo`03001l07`000Ql000301ml07`001Ul0003001l07`002El0003001l07`001il000301ml07`0
00=l0003001oogoo01=oo`005Woo00<007ooOol017oo00<007ooOol0M7oo00<007`0O0001g`000<0
7g`0O0006W`000<007`0O0009G`000<007`0O0007W`000<07g`0O0000g`000<007ooOol04goo000E
Ool20006Ool00`00Oomoo`1dOol00`00O01l0007O0000`0OO01l000JO0000`00O01l000UO0000`00
O01l000OO0000`0OO01l0002O0000`00Oomoo`0COol001eoo`03001oogoo07Aoo`03001l07`000Il
000301ml07`001]l0003001l07`002El0003001l07`001ml000301ml07`0009l0003001oogoo01=o
o`007Goo0P00MGoo00<007`0O0001W`000<07g`0O0006g`000<007`0O0009G`000<007`0O0007g`0
00<07g`0O0000W`000<007ooOol04goo000MOol00`00Oomoo`1dOol00`00O01l0005O0000`0OO01l
000LO0000`00O01l000UO0000`00O01l000OO0000`0OO01l0002O0000`00Oomoo`0COol001eoo`03
001oogoo07Aoo`03001l07`000El000301ml07`001al0003001l07`002El0003001l07`0021l0005
01ml07`0O000000EOol001eoo`03001oogoo07Aoo`03001l07`000Al000301ml07`001el0003001l
07`002El0003001l07`0021l000501ml07`0O000000EOol001eoo`8007Eoo`03001l07`000Al0003
01ml07`001el0003001l07`002El0003001l07`0021l000501ml07`0O000000EOol001eoo`03001o
ogoo07Aoo`03001l07`000=l000301ml07`001il0003001l07`002El0003001l07`0021l000501ml
07`0O000000EOol001eoo`03001oogoo07Aoo`03001l07`000=l000301ml07`001il0003001l07`0
02El0003001l07`0025l000401ml07`0000EOol001eoo`03001oogoo025oo`<002=oo`@0025oo`<0
00Eoo`03001l07`0009l000301ml07`001ml0003001l07`002El0003001l07`0025l000401ml07`0
000EOol001eoo`03001oogoo029oo`03001oogoo02=oo`03001oogoo02Aoo`03001oogoo009oo`03
001l07`0009l000301ml07`001ml0003001l07`002El0003001l07`0025l000401ml07`0000EOol0
01eoo`8002=oo`03001oogoo02Aoo`03001oogoo02=oo`03001oogoo009oo`05001l07`0O0007`0R
O0000`00O01l000UO0000`00O01l000QO000100OO01l00005Goo000MOol00`00Oomoo`0ROol00`00
Oomoo`0UOol00`00Oomoo`0POol20005Ool01@00O01l07`001l08W`000<007`0O0009G`000<007`0
O0008W`000<07g`000005Goo000MOol00`00Oomoo`0ROol00`00Oomoo`0ROol01000Oomoo`0097oo
00<007ooOol00Woo00@007`0O0007b=l0003001l07`002El0003001l07`0029l000301ml000001Eo
o`007Goo00<007ooOol08Goo0P009Goo0P008Woo0`001Goo00@007`0O0007b=l0003001l07`002El
0003001l07`0029l000301ml000001Eoo`007Goo0P00MGoo00<007`001l097`000<007`0O0009G`0
00<007`0O0008g`000<07`00Ool057oo000MOol00`00Oomoo`1dOol00`00O0007`0TO0000`00O01l
000UO0000`00O01l000SO0000`0O001oo`0DOol001eoo`03001oogoo07Aoo`0300007g`002Al0003
001l07`002El0003001l07`002=l000301l007oo01Aoo`007Goo00<007ooOol0M7oo00<0000OO000
97`000<007`0O0009G`000<007`0O0008g`000<07`00Ool057oo000MOol00`00Oomoo`1dOol00`0O
O01l000TO0000`00O01l000UO0000`00O01l000TO0000`0OOomoo`0COol001Moo`H000X07fd00003
01ml07`002Al0003001l07`002El0003001l07`002Al000301l0000000@000moo`007Goo00<007`0
O0001g`00P0O77`000<007`0O00097`000<007`0O00097`000<07`00Ool07Woo00<007ooOol08goo
00<007ooOol08Woo00<007ooOol07Woo000MOol00`00O01l0009O00301lIO0000`00O01l000TO000
0`00O01l000SO0000`0OO000002;Ool001eoo`03001l07`000al00807aMl0003001l07`002Al0003
001l07`002=l000301ml000008]oo`007Goo00<007`0O0003W`00P0O5G`000<007`0O00097`000<0
07`0O0008W`000@07g`0O00008]oo`007Goo4`0000<07`0000004`009W`000<007`0O0008W`000@0
7g`0O00008]oo`007Goo00<007ooOol04Goo0P0O4Woo00<007`0O00097`000<007`0O0008G`000D0
7g`0O01l000008]oo`007Goo00<007ooOol04goo0P0O47oo00<007`0O00097`000<007`0O00087`0
00<07g`0O0000W`000<007ooOol0RGoo000MOol2000FOol00`0OOomoo`0=Ool00`00O01l000TO000
0`00O01l000PO0000`0OO01l0002O0000`00Oomoo`29Ool001eoo`03001oogoo01Ioo`807`eoo`03
001l07`002Al0003001l07`001ml000301ml07`000=l0003001oogoo08Uoo`007Goo00<007ooOol0
67oo0P0O2goo00<007`0O00097`000<007`0O0007W`000<07g`0O00017`000<007ooOol0RGoo000M
Ool00`00Oomoo`0JOol00`0OOomoo`08Ool00`00O01l000TO0000`00O01l000NO0000`0OO01l0004
O0000`00Oomoo`29Ool001eoo`03001oogoo01]oo`807`Qoo`03001l07`002Al0003001l07`001el
000301ml07`000El0003001oogoo08Uoo`007Goo0P007Woo00<07gooOol01Goo00<007`0O00097`0
00<007`0O0007G`000<07g`0O0001G`000<007ooOol0RGoo000MOol00`00Oomoo`0NOol00`0OOomo
o`04Ool00`00O01l000TO0000`00O01l000LO0000`0OO01l0006O0000`00Oomoo`29Ool001eoo`03
001oogoo01moo`0301moogoo00=oo`03001l07`002Al0003001l07`001]l000301ml07`000Ml0003
001oogoo08Uoo`007Goo00<007ooOol087oo0P0O0goo00<007`0O00097`000<007`0O0006g`000<0
7g`0O0001g`000<007ooOol0RGoo000MOol2000SOol0100OOomoo`009W`000<007`0O0006W`000<0
7g`0O00027`000<007ooOol0RGoo000MOol00`00Oomoo`0SOol00`0OOol0000VO0000`00O01l000I
O0000`0OO01l0009O0000`00Oomoo`29Ool001eoo`03001oogoo02Aoo`0301l007`002El0003001l
07`001Ql000301ml07`000Yl0003001oogoo08Uoo`005Goo0`001Goo00<007ooOol09Goo0P0O9G`0
00<007`0O00067`000<07g`0O0002W`000<007ooOol0RGoo000FOol00`00Oomoo`04Ool00`00Oomo
o`0UOol00`00O0007`0TO0000`00O01l000GO0000`0OO01l000;O0000`00Oomoo`29Ool001Ioo`03
001oogoo00Aoo`<002Eoo`04001l07`001lSO0000`00O01l000FO0000`0OO01l000<O0000`00Oomo
o`29Ool001Ioo`03001oogoo00Aoo`03001oogoo02Eoo`05001l07`0O0007`0RO0000`00O01l000E
O0000`0OO01l000=O0000`00Oomoo`29Ool001Ioo`03001oogoo00Aoo`03001oogoo02Eoo`03001l
07`0009l00807b1l0003001l07`001Al000301ml07`000il0003001oogoo08Uoo`005Goo0P001Woo
00<007ooOol09Goo00<007`0O00017`000<07g`0O0007G`000<007`0O00057`000<07g`0O0003W`0
00<007ooOol0RGoo000MOol2000VOol00`00O01l0005O0000`0OO01l000LO0000`00O01l000CO000
0`0OO01l000?O0000`00Oomoo`29Ool001eoo`03001oogoo02Eoo`03001l07`000Il000301ml07`0
01]l0003001l07`0019l000301ml07`0011l0003001oogoo08Uoo`007Goo00<007ooOol09Goo00<0
07`0O0001g`00P0O6g`0500000<07`0000004P00Rgoo000MOol00`00Oomoo`0UOol00`00O01l0009
O0000`0OO01l000HO0000`00Oomoo`0@Ool00`0OOomoo`2NOol001eoo`8002Ioo`03001l07`000Yl
00807aQl0003001oogoo00moo`0301moogoo09moo`007Goo00<007ooOol09Goo00<007`0O00037`0
00<07g`0O0005G`000<007ooOol03Woo00<07gooOol0X7oo000MOol00`00Oomoo`0UOol00`00O01l
000=O00201lEO0000`00Oomoo`0<Ool201nSOol001eoo`03001oogoo02Eoo`03001l07`000ml0003
01ml07`0019l0003001oogoo00]oo`0301moogoo0:=oo`007Goo00<007ooOol09Goo4`000P0O4`00
37oo00<07gooOol0Y7oo000MOol2000kOol00`0OOomoo`0KOol00`0OOomoo`2UOol001eoo`03001o
ogoo03]oo`<07aQoo`807jQoo`007Goo00<007ooOol0?Woo0P0O4goo0`0OZWoo000MOol00`00Oomo
o`10Ool301l>Ool201n]Ool001eoo`8004Aoo`@07`Ioo`@07jmoo`007Goo00<007ooOol0Agoo1P0O
/goo000MOol00`00Oomoo`3oOol1Ool001eoo`03001oogoo0?moo`5oo`007Goo00<007ooOol0ogoo
0Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol0
0?moob5oo`00?7oo1P001Woo0`000goo100017oo0`001Goo0`000goo100000=oo`0000000P000Woo
0P001Goo2P0000=oo`0000000P000Woo100017oo10000goo100077oo0P000goo0P000Woo1@001Woo
10001Woo00<007ooOol01Goo10000goo1@00>7oo000nOol20007Ool20002Ool01000Oomoogoo0P00
17oo0P000Woo00@007ooOomoo`80009oo`04001oogooOol20003Ool20002Ool200000goo001oo`05
Ool20005Ool200000goo00000004Ool20004Ool20002Ool20003Ool2000MOol20003Ool20002Ool2
0003Ool20003Ool20002Ool20005Ool20005Ool20002Ool20002Ool20003Ool2000fOol003ioo`80
00Ioo`8000Aoo`03001oogoo008000=oo`8000Aoo`04001oo`000004Ool00`00Oomoo`020003Ool2
0002Ool20008Ool20006Ool01000Ool0000017oo0P000goo0P0017oo0P000Woo0P002Goo2@002goo
0P003Goo00D007ooOomoo`0000Aoo`03001oogoo00Aoo`03001oogoo00=oo`03001oogoo009oo`03
001oogoo00Ioo`03001oogoo03Aoo`00?Woo0P001Woo0P001goo0P000goo0P001Woo0P001goo0P00
0goo0P000Woo0P0027oo0P0027oo0P0017oo0P000goo0P0017oo0P000Woo0P0067oo2@002goo0P00
00=oo`00000017oo0P001Goo00<007ooOol00Woo0P0017oo0P001goo0P00=Goo000nOol20006Ool2
0007Ool20003Ool20006Ool20007Ool20003Ool20002Ool20008Ool20004Ool01000Oomoogoo0P00
17oo0P000goo0P0017oo0P000Woo0P0067oo00<007ooOol00Woo0P003Goo0P0000=oo`00000017oo
0P001Goo00<007ooOol00Woo0P0017oo0P001goo0P00=Goo000nOol60002Ool70002Ool20003Ool2
0004Ool00`00Ool000060002Ool20003Ool20002Ool20008Ool20004Ool01000Oomoogoo0P0017oo
0P000goo0P0017oo0P000Woo0P006Goo00@007ooOomoo`8000aoo`<00003Ool0000000Aoo`8000Io
o`04001oogooOol20004Ool20007Ool2000eOol003ioo`8000=oo`80009oo`04001oogooOol20000
0goo0000000400000goo00000002Ool20002Ool01000Oomoogoo0P0000=oo`0000000P000Woo0P00
0Woo0P0027oo1`000Woo300000=oo`0000000Woo0P000Woo1P001Woo2@0027oo00<007ooOol00P00
2Woo10000Woo0P0017oo0P001Woo00@007ooOomoo`8000Aoo`8000Ioo`<003Eoo`00?Woo0P0017oo
0P000Woo100017oo00@007oo0000009oo`@000Aoo`@000Aoo`03001oo`000080009oo`D000Ioo`80
00Aoo`03001oogoo009oo`04001oo`000002Ool01000Ool000000Woo10001Goo00@007oo000001Mo
o`03001oogoo008000Moo`H000=oo`8000Aoo`8000Ioo`04001oogooOol20004Ool20003Ool5000f
Ool003ioo`8000Aoo`8002Qoo`8000Qoo`8000Aoo`03001oogoo03=oo`04001oo`000008Ool40004
Ool20004Ool20007Ool00`00Oomoo`020004Ool20005Ool00`00Oomoo`0fOol003ioo`8000Aoo`80
02Uoo`03001oogoo00Ioo`8003]oo`<000Qoo`03001oogoo00Eoo`8000Aoo`8000Moo`03001oogoo
008000Aoo`8000Ioo`03001oogoo03Eoo`00?Woo0P0017oo0P00<Woo0P001Goo00<007ooOol0<goo
0`002Goo00<007ooOol01Goo00<007ooOol00Woo00<007ooOol00P0017oo00D007ooOomoo`0000Ao
o`04001oogoo0004Ool2000fOol003ioo`8000=oo`8003=oo`8000Eoo`03001oogoo03Aoo`8000Uo
o`D000=oo`80009oo`8000=oo`L0009oo`80009oo`8000=oo`03001oogoo00<003Ioo`00?7oo2000
<Woo2P00=Woo0P002Goo1P000goo100017oo1`000goo10001Goo1000=goo003oOolQOol00?moob5o
o`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.783823, -4.98036, 
  0.0265065, 0.0452841}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.151576 0.44187 0.0887232 [
[.17539 .42937 -3 -9 ]
[.17539 .42937 3 0 ]
[.32696 .42937 -3 -9 ]
[.32696 .42937 3 0 ]
[.47854 .42937 -3 -9 ]
[.47854 .42937 3 0 ]
[.63011 .42937 -3 -9 ]
[.63011 .42937 3 0 ]
[.78169 .42937 -3 -9 ]
[.78169 .42937 3 0 ]
[.93327 .42937 -3 -9 ]
[.93327 .42937 3 0 ]
[.01131 .08698 -12 -4.5 ]
[.01131 .08698 0 4.5 ]
[.01131 .1757 -12 -4.5 ]
[.01131 .1757 0 4.5 ]
[.01131 .26442 -12 -4.5 ]
[.01131 .26442 0 4.5 ]
[.01131 .35315 -12 -4.5 ]
[.01131 .35315 0 4.5 ]
[.01131 .53059 -6 -4.5 ]
[.01131 .53059 0 4.5 ]
[.5 .63053 -89.5938 0 ]
[.5 .63053 89.5938 20 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.17539 .44187 m
.17539 .44812 L
s
[(1)] .17539 .42937 0 1 Mshowa
.32696 .44187 m
.32696 .44812 L
s
[(2)] .32696 .42937 0 1 Mshowa
.47854 .44187 m
.47854 .44812 L
s
[(3)] .47854 .42937 0 1 Mshowa
.63011 .44187 m
.63011 .44812 L
s
[(4)] .63011 .42937 0 1 Mshowa
.78169 .44187 m
.78169 .44812 L
s
[(5)] .78169 .42937 0 1 Mshowa
.93327 .44187 m
.93327 .44812 L
s
[(6)] .93327 .42937 0 1 Mshowa
.125 Mabswid
.05412 .44187 m
.05412 .44562 L
s
.08444 .44187 m
.08444 .44562 L
s
.11476 .44187 m
.11476 .44562 L
s
.14507 .44187 m
.14507 .44562 L
s
.2057 .44187 m
.2057 .44562 L
s
.23602 .44187 m
.23602 .44562 L
s
.26633 .44187 m
.26633 .44562 L
s
.29665 .44187 m
.29665 .44562 L
s
.35728 .44187 m
.35728 .44562 L
s
.38759 .44187 m
.38759 .44562 L
s
.41791 .44187 m
.41791 .44562 L
s
.44822 .44187 m
.44822 .44562 L
s
.50885 .44187 m
.50885 .44562 L
s
.53917 .44187 m
.53917 .44562 L
s
.56948 .44187 m
.56948 .44562 L
s
.5998 .44187 m
.5998 .44562 L
s
.66043 .44187 m
.66043 .44562 L
s
.69074 .44187 m
.69074 .44562 L
s
.72106 .44187 m
.72106 .44562 L
s
.75137 .44187 m
.75137 .44562 L
s
.81201 .44187 m
.81201 .44562 L
s
.84232 .44187 m
.84232 .44562 L
s
.87264 .44187 m
.87264 .44562 L
s
.90295 .44187 m
.90295 .44562 L
s
.96358 .44187 m
.96358 .44562 L
s
.9939 .44187 m
.9939 .44562 L
s
.25 Mabswid
0 .44187 m
1 .44187 L
s
.02381 .08698 m
.03006 .08698 L
s
[(-4)] .01131 .08698 1 0 Mshowa
.02381 .1757 m
.03006 .1757 L
s
[(-3)] .01131 .1757 1 0 Mshowa
.02381 .26442 m
.03006 .26442 L
s
[(-2)] .01131 .26442 1 0 Mshowa
.02381 .35315 m
.03006 .35315 L
s
[(-1)] .01131 .35315 1 0 Mshowa
.02381 .53059 m
.03006 .53059 L
s
[(1)] .01131 .53059 1 0 Mshowa
.125 Mabswid
.02381 .016 m
.02756 .016 L
s
.02381 .03374 m
.02756 .03374 L
s
.02381 .05149 m
.02756 .05149 L
s
.02381 .06923 m
.02756 .06923 L
s
.02381 .10472 m
.02756 .10472 L
s
.02381 .12247 m
.02756 .12247 L
s
.02381 .14021 m
.02756 .14021 L
s
.02381 .15796 m
.02756 .15796 L
s
.02381 .19344 m
.02756 .19344 L
s
.02381 .21119 m
.02756 .21119 L
s
.02381 .22893 m
.02756 .22893 L
s
.02381 .24668 m
.02756 .24668 L
s
.02381 .28217 m
.02756 .28217 L
s
.02381 .29991 m
.02756 .29991 L
s
.02381 .31766 m
.02756 .31766 L
s
.02381 .3354 m
.02756 .3354 L
s
.02381 .37089 m
.02756 .37089 L
s
.02381 .38864 m
.02756 .38864 L
s
.02381 .40638 m
.02756 .40638 L
s
.02381 .42413 m
.02756 .42413 L
s
.02381 .45961 m
.02756 .45961 L
s
.02381 .47736 m
.02756 .47736 L
s
.02381 .4951 m
.02756 .4951 L
s
.02381 .51285 m
.02756 .51285 L
s
.02381 .54834 m
.02756 .54834 L
s
.02381 .56608 m
.02756 .56608 L
s
.02381 .58383 m
.02756 .58383 L
s
.02381 .60157 m
.02756 .60157 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -150.594 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 24.000000 moveto
 558.000000 24.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 24.000000 lineto
closepath
clip newpath
63.000000 19.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 18.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 19.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 18.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Percent) show
121.250000 19.000000 moveto
(Error) show
163.625000 19.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 18.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(=) show
179.687500 19.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 18.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(3.32336) show
238.187500 19.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 18.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
0 0 1 r
.007 w
.02381 .44187 m
.02499 .44188 L
.02605 .44189 L
.02729 .44192 L
.02846 .44195 L
.03053 .44204 L
.03279 .44218 L
.03527 .44238 L
.0379 .44264 L
.04262 .44323 L
.04749 .44403 L
.05205 .44493 L
.06244 .44757 L
.07305 .45107 L
.08274 .45495 L
.10458 .46589 L
.14429 .4922 L
.18248 .52229 L
.22313 .55474 L
.26226 .58144 L
.27254 .5871 L
.28367 .59241 L
.29328 .59624 L
.29838 .59795 L
.30384 .59955 L
.30923 .60086 L
.31415 .60182 L
.31652 .6022 L
.31909 .60255 L
.32151 .60282 L
.32378 .60303 L
.32509 .60312 L
.3263 .60319 L
.32764 .60325 L
.32834 .60327 L
.32908 .60329 L
.32976 .60331 L
.33048 .60332 L
.33177 .60332 L
.33257 .60331 L
.33332 .6033 L
.33399 .60328 L
.33472 .60326 L
.33594 .60321 L
.33728 .60313 L
.33999 .60292 L
.34249 .60266 L
.34484 .60235 L
.34982 .60149 L
.35525 .60023 L
Mistroke
.36513 .59709 L
.37475 .59294 L
.38367 .58812 L
.40423 .57339 L
.42285 .55569 L
.46297 .50405 L
.50157 .43897 L
.54262 .35759 L
.58216 .27326 L
.62019 .19318 L
.66067 .11668 L
.69963 .05896 L
.70983 .04728 L
.72091 .03645 L
.73048 .02875 L
.73557 .02531 L
.74104 .02213 L
.74638 .01956 L
.75126 .01767 L
.75594 .01629 L
.75829 .01576 L
.76085 .0153 L
.76227 .01511 L
.76362 .01496 L
.76482 .01485 L
.76612 .01477 L
.7668 .01474 L
.76755 .01472 L
.76833 .01472 L
.76905 .01472 L
.77035 .01475 L
.77108 .01478 L
.77175 .01482 L
.77304 .01492 L
.77424 .01504 L
.77695 .01543 L
.77933 .0159 L
.78187 .01653 L
.78675 .0181 L
.79123 .01999 L
.80132 .02578 L
.81022 .03269 L
.81959 .04179 L
.83931 .06705 L
.85767 .09794 L
.89668 .18599 L
.93815 .30895 L
.97619 .44187 L
Mfstroke
1 0 0 r
.02381 .44187 m
.15986 .44187 L
.15986 .45915 L
.02381 .45915 L
F
.15986 .44187 m
.29592 .44187 L
.29592 .55833 L
.15986 .55833 L
F
.29592 .44187 m
.43197 .44187 L
.43197 .59753 L
.29592 .59753 L
F
.43197 .44187 m
.56803 .44187 L
.56803 .44187 L
.43197 .44187 L
F
.56803 .44187 m
.70408 .44187 L
.70408 .16168 L
.56803 .16168 L
F
.70408 .44187 m
.84014 .44187 L
.84014 .01484 L
.70408 .01484 L
F
.84014 .44187 m
.97619 .44187 L
.97619 .21727 L
.84014 .21727 L
F
0 g
.5 Mabswid
.02381 .44187 m
.02381 .45915 L
s
.15986 .44187 m
.15986 .45915 L
s
.02381 .45915 m
.15986 .45915 L
s
.15986 .44187 m
.15986 .55833 L
s
.29592 .44187 m
.29592 .55833 L
s
.15986 .55833 m
.29592 .55833 L
s
.29592 .44187 m
.29592 .59753 L
s
.43197 .44187 m
.43197 .59753 L
s
.29592 .59753 m
.43197 .59753 L
s
.43197 .44187 m
.43197 .44187 L
s
.56803 .44187 m
.56803 .44187 L
s
.43197 .44187 m
.56803 .44187 L
s
.56803 .44187 m
.56803 .16168 L
s
.70408 .44187 m
.70408 .16168 L
s
.56803 .16168 m
.70408 .16168 L
s
.70408 .44187 m
.70408 .01484 L
s
.84014 .44187 m
.84014 .01484 L
s
.70408 .01484 m
.84014 .01484 L
s
.84014 .44187 m
.84014 .21727 L
s
.97619 .44187 m
.97619 .21727 L
s
.84014 .21727 m
.97619 .21727 L
s
0 0 1 r
.007 w
.02381 .44187 m
.02499 .44188 L
.02605 .44189 L
.02729 .44192 L
.02846 .44195 L
.03053 .44204 L
.03279 .44218 L
.03527 .44238 L
.0379 .44264 L
.04262 .44323 L
.04749 .44403 L
.05205 .44493 L
.06244 .44757 L
.07305 .45107 L
.08274 .45495 L
.10458 .46589 L
.14429 .4922 L
.18248 .52229 L
.22313 .55474 L
.26226 .58144 L
.27254 .5871 L
.28367 .59241 L
.29328 .59624 L
.29838 .59795 L
.30384 .59955 L
.30923 .60086 L
.31415 .60182 L
.31652 .6022 L
.31909 .60255 L
.32151 .60282 L
.32378 .60303 L
.32509 .60312 L
.3263 .60319 L
.32764 .60325 L
.32834 .60327 L
.32908 .60329 L
.32976 .60331 L
.33048 .60332 L
.33177 .60332 L
.33257 .60331 L
.33332 .6033 L
.33399 .60328 L
.33472 .60326 L
.33594 .60321 L
.33728 .60313 L
.33999 .60292 L
.34249 .60266 L
.34484 .60235 L
.34982 .60149 L
.35525 .60023 L
Mistroke
.36513 .59709 L
.37475 .59294 L
.38367 .58812 L
.40423 .57339 L
.42285 .55569 L
.46297 .50405 L
.50157 .43897 L
.54262 .35759 L
.58216 .27326 L
.62019 .19318 L
.66067 .11668 L
.69963 .05896 L
.70983 .04728 L
.72091 .03645 L
.73048 .02875 L
.73557 .02531 L
.74104 .02213 L
.74638 .01956 L
.75126 .01767 L
.75594 .01629 L
.75829 .01576 L
.76085 .0153 L
.76227 .01511 L
.76362 .01496 L
.76482 .01485 L
.76612 .01477 L
.7668 .01474 L
.76755 .01472 L
.76833 .01472 L
.76905 .01472 L
.77035 .01475 L
.77108 .01478 L
.77175 .01482 L
.77304 .01492 L
.77424 .01504 L
.77695 .01543 L
.77933 .0159 L
.78187 .01653 L
.78675 .0181 L
.79123 .01999 L
.80132 .02578 L
.81022 .03269 L
.81959 .04179 L
.83931 .06705 L
.85767 .09794 L
.89668 .18599 L
.93815 .30895 L
.97619 .44187 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00O7Goo00<007ooOol0
ogoo0Goo000MOol00`00Oomoo`3oOol1Ool001eoo`03001oogoo0?moo`5oo`007Goo00<007ooOol0
YWoo3P001P0O3`00=goo000MOol2002WOol00`00O01l0008O00301l5O00301l<O0000`00Oomoo`0e
Ool001eoo`03001oogoo0:Ioo`03001l07`000Il00807`]l00<07`Ul0003001oogoo03Eoo`007Goo
00<007ooOol0YWoo00<007`0O0001G`000<07g`0O0003W`000<07g`0O0001W`000<007ooOol0=Goo
000MOol00`00Oomoo`2VOol00`00O01l0004O0000`0OO01l000@O0000`0OO01l0005O0000`00Oomo
o`0eOol001eoo`800:Moo`03001l07`000=l000301ml07`0019l000301ml07`000Al0003001oogoo
03Eoo`007Goo00<007ooOol0YWoo00@007`0O01l00807aIl000301ml07`000=l0003001oogoo03Eo
o`007Goo00<007ooOol0YWoo00@007`0O0007aUl000301ml07`0009l0003001oogoo03Eoo`007Goo
00<007ooOol0YWoo00<007`001l06W`000<07g`0O0000W`000<007ooOol0=Goo000MOol2002WOol0
0`0001ml000KO0001@0OO01l07`00000=goo000MOol00`00Oomoo`2VOol00`0OO01l000LO000100O
O01l0000=goo000MOol00`00Oomoo`2UOol00`0O001l000NO0000`0OO000000gOol001eoo`03001o
ogoo0:Eoo`0301l007`001ml000301l007oo03Ioo`007Goo00<007ooOol0Y7oo00<07goo00008G`0
00<07gooOol0=Goo000MOol2002TOol0100OOomoo`008G`000<07gooOol0=Goo000MOol00`00Oomo
o`2SOol0100OOomoo`008G`000<0000OOol0=Goo000FOol30004Ool00`00Oomoo`2ROol01@0OOomo
ogoo00008G`000<007oo01l0=Goo000GOol00`00Oomoo`03Ool00`00Oomoo`2ROol01@0OOomoogoo
00008G`000<007oo01l0=Goo000?Ool500000goo000000020004Ool3002QOol00`0OOomoo`02Ool0
0`00O01l000OO0001000Oomoo`0O=7oo000EOol00`00Ool00005Ool00`00Oomoo`2POol00`0OOomo
o`03Ool00`00O01l000OO0001000Oomoo`0O=7oo000EOol00`00Ool00005Ool00`00Oomoo`2POol0
0`0OOomoo`03Ool00`00O01l000OO0001@00Oomoogoo01l0<goo000FOol20005Ool00`00Oomoo`2O
Ool00`0OOomoo`04Ool00`00O01l000OO0000`00Oomoo`02Ool00`0OOomoo`0`Ool001eoo`03001o
ogoo09moo`0301moogoo00Aoo`03001l07`001ml0003001oogoo009oo`0301moogoo031oo`007Goo
0P00Wgoo00<07gooOol01Goo00<007`0O0007g`000<007ooOol00goo00<07gooOol0;goo000MOol0
0`00Oomoo`2MOol00`0OOomoo`06Ool00`00O01l000OO0000`00Oomoo`03Ool00`0OOomoo`0_Ool0
01eoo`03001oogoo09eoo`0301moogoo00Ioo`03001l07`001ml0003001oogoo00=oo`0301moogoo
02moo`007Goo00<007ooOol0W7oo00<07gooOol01goo00<007`0O0007g`000<007ooOol017oo00<0
7gooOol0;Woo000MOol2002MOol00`0OOomoo`07Ool00`00O01l000OO0000`00Oomoo`04Ool00`0O
Oomoo`0^Ool001eoo`03001oogoo09]oo`0301moogoo00Qoo`03001l07`001ml0003001oogoo00Eo
o`0301moogoo02eoo`007Goo00<007ooOol0Vgoo00<07gooOol027oo00<007`0O0007g`000<007oo
Ool01Goo00<07gooOol0;Goo000MOol00`00Oomoo`2JOol00`0OOomoo`09Ool00`00O01l000OO000
0`00Oomoo`05Ool00`0OOomoo`0]Ool001eoo`8009]oo`0301moogoo00Uoo`03001l07`001ml0003
001oogoo00Ioo`0301moogoo02aoo`007Goo00<007ooOol0VGoo00<07gooOol02Woo00<007`0O000
7g`000<007ooOol01Woo00<07gooOol0;7oo000MOol00`00Oomoo`2IOol00`0OOomoo`0:Ool00`00
O01l000OO0000`00Oomoo`07Ool00`0OOomoo`0[Ool001eoo`03001oogoo09Qoo`0301moogoo00]o
o`03001l07`001ml0003001oogoo00Moo`0301moogoo02]oo`007Goo00<007ooOol0V7oo00<07goo
Ool02goo00<007`0O0007g`000<007ooOol027oo00<07gooOol0:Woo000MOol2002HOol00`0OOomo
o`0<Ool00`00O01l000OO0000`00Oomoo`08Ool00`0OOomoo`0ZOol001eoo`03001oogoo08Eooa40
000301l0000000h0025l0003001oogoo00Qoo`0301moogoo02Yoo`005Goo0`001Goo00<007ooOol0
QGoo00<007`0O0003W`000<07g`0O0003G`000<007`0O0007g`000<007ooOol02Goo00<07gooOol0
:Goo000HOol00`00Oomoo`02Ool00`00Oomoo`25Ool00`00O01l000=O0000`0OO01l000>O0000`00
O01l000OO0000`00Oomoo`09Ool00`0OOomoo`0YOol000moo`D000Aoo`03001oogoo009oo`<008Eo
o`03001l07`000el000301ml07`000il0003001l07`001ml0003001oogoo00Yoo`0301moogoo02Qo
o`005Woo0P001Goo00<007ooOol0QGoo00<007`0O00037`000<07g`0O0003g`000<007`0O0007g`0
00<007ooOol02Woo00<07gooOol0:7oo000HOol00`00Oomoo`02Ool00`00Oomoo`25Ool00`00O01l
000<O0000`0OO01l000?O0000`00O01l000OO0000`00Oomoo`0:Ool00`0OOomoo`0XOol001Eoo`<0
00Eoo`03001oogoo08Eoo`03001l07`000]l000301ml07`0011l0003001l07`001ml0003001oogoo
00]oo`0301moogoo02Moo`007Goo00<007ooOol0QGoo00<007`0O0002g`000<07g`0O00047`000<0
07`0O0007g`000<007ooOol02goo00<07gooOol09goo000MOol20026Ool00`00O01l000:O0000`0O
O01l000AO0000`00O01l000OO0000`00Oomoo`0<Ool00`0OOomoo`0VOol001eoo`03001oogoo08Eo
o`03001l07`000Yl000301ml07`0015l0003001l07`001ml0003001oogoo00aoo`0301moogoo02Io
o`007Goo00<007ooOol0QGoo00<007`0O0002G`000<07g`0O0004W`000<007`0O0007g`000<007oo
Ool037oo00<07gooOol09Woo000MOol00`00Oomoo`25Ool00`00O01l0009O0000`0OO01l000BO000
0`00O01l000OO0000`00Oomoo`0=Ool00`0OOomoo`0UOol001eoo`8008Ioo`03001l07`000Ql0003
01ml07`001=l0003001l07`001ml0003001oogoo00eoo`0301moogoo02Eoo`007Goo00<007ooOol0
QGoo00<007`0O00027`000<07g`0O0004g`000<007`0O0007g`000<007ooOol03Goo00<07gooOol0
9Goo000MOol00`00Oomoo`25Ool00`00O01l0007O0000`0OO01l000DO0000`00O01l000OO00A0000
0`0O0000000?000EOol001eoo`03001oogoo08Eoo`03001l07`000Ml000301ml07`001Al0003001l
07`001ml0003001l07`000il000301ml07`000il0003001oogoo01=oo`007Goo00<007ooOol0QGoo
00<007`0O0001W`000<07g`0O0005G`000<007`0O0007g`000<007`0O0003W`000<07g`0O0003W`0
00<007ooOol04goo000MOol20026Ool00`00O01l0006O0000`0OO01l000EO0000`00O01l000OO000
0`00O01l000?O0000`0OO01l000=O0000`00Oomoo`0COol001eoo`03001oogoo08Eoo`03001l07`0
00El000301ml07`001Il0003001l07`001ml0003001l07`000ml000301ml07`000el0003001oogoo
01=oo`007Goo00<007ooOol0QGoo00<007`0O0001G`000<07g`0O0005W`000<007`0O0007g`000<0
07`0O00047`000<07g`0O00037`000<007ooOol04goo000MOol00`00Oomoo`25Ool00`00O01l0004
O0000`0OO01l000GO0000`00O01l000OO0000`00O01l000@O0000`0OO01l000<O0000`00Oomoo`0C
Ool001eoo`8008Ioo`03001l07`000Al000301ml07`001Ml0003001l07`001ml0003001l07`0011l
000301ml07`000al0003001oogoo01=oo`007Goo00<007ooOol0QGoo00<007`0O0000g`000<07g`0
O00067`000<007`0O0007g`000<007`0O0004G`000<07g`0O0002g`000<007ooOol04goo000EOol4
0004Ool00`00Oomoo`25Ool00`00O01l0003O0000`0OO01l000HO0000`00O01l000OO0000`00O01l
000AO0000`0OO01l000;O0000`00Oomoo`0COol001Ioo`03001oogoo00Aoo`03001oogoo08Eoo`03
001l07`0009l000301ml07`001Ul0003001l07`001ml0003001l07`0015l000301ml07`000]l0003
001oogoo01=oo`003goo1@000goo00<007ooOol00goo0`00QGoo00<007`0O0000W`000<07g`0O000
6G`000<007`0O0007g`000<007`0O0004W`000<07g`0O0002W`000<007ooOol04goo000HOol00`00
Oomoo`02Ool00`00Oomoo`25Ool01@00O01l07`001l077`000<007`0O0007g`000<007`0O0004W`0
00<07g`0O0002W`000<007ooOol04goo000EOol01000Oomoo`0017oo00<007ooOol0QGoo00D007`0
O01l000O01al0003001l07`001ml0003001l07`001=l000301ml07`000Ul0003001oogoo01=oo`00
5Woo0P001Goo00<007ooOol0QGoo00@007`0O0007ael0003001l07`001ml0003001l07`001=l0003
01ml07`000Ul0003001oogoo01=oo`007Goo00<007ooOol0QGoo00@007`0O0007ael0003001l07`0
01ml0003001l07`001=l000301ml07`000Ul0003001oogoo01=oo`007Goo0P00QWoo00<007`001l0
7W`000<007`0O0007g`000<007`0O00057`000<07g`0O00027`000<007ooOol04goo000MOol00`00
Oomoo`25Ool00`00O0007`0NO0000`00O01l000OO0000`00O01l000DO0000`0OO01l0008O0000`00
Oomoo`0COol001eoo`03001oogoo08Eoo`0300007g`001il0003001l07`001ml0003001l07`001Al
000301ml07`000Ql0003001oogoo01=oo`007Goo00<007ooOol0QGoo00<0000OO0007W`000<007`0
O0007g`000<007`0O0005G`000<07g`0O0001g`000<007ooOol04goo000MOol20026Ool00`0OO01l
000NO0000`00O01l000OO0000`00O01l000EO0000`0OO01l0007O0000`00Oomoo`0COol001eoo`03
001oogoo08Eoo`0301ml07`001il0003001l07`001ml0003001l07`001El000301ml07`000Ml0003
001oogoo01=oo`007Goo00<007ooOol0Q7oo00<07`00O0007g`000<007`0O0007g`000<007`0O000
5W`000<07g`0O0001W`000<007ooOol04goo000MOol00`00Oomoo`24Ool00`0O001l000OO0000`00
O01l000OO0000`00O01l000FO0000`0OO01l0006O0000`00Oomoo`0COol001eoo`03001oogoo08=o
o`0301moo`00021l0003001l07`001ml0003001l07`001Il000301ml07`000Il0003001oogoo01=o
o`007Goo0P00Q7oo00<07goo000087`000<007`0O0007g`000<007`0O0005g`000<07g`0O0001G`0
00<007ooOol04goo000MOol00`00Oomoo`23Ool00`0OOol0000PO0000`00O01l000OO0000`00O01l
000GO0000`0OO01l0005O0000`00Oomoo`0COol001eoo`03001oogoo089oo`0401moogoo000PO000
0`00O01l000OO0000`00O01l000GO0000`0OO01l0005O0000`00Oomoo`0COol001eoo`03001oogoo
089oo`0401moogoo000PO0000`00O01l000OO0000`00O01l000GO0000`0OO01l0005O0000`00Oomo
o`0COol001eoo`80089oo`0501moogooOol0000PO0000`00O01l000OO0000`00O01l000HO0000`0O
O01l0004O0000`00Oomoo`0COol001eoo`03001oogoo085oo`0501moogooOol0000PO0000`00O01l
000OO0000`00O01l000HO0000`0OO01l0004O0000`00Oomoo`0COol001Eoo`<000Eoo`03001oogoo
081oo`0301moogoo009oo`03001l07`001il0003001l07`001ml0003001l07`001Ql000301ml07`0
00Al0003001oogoo01=oo`005Woo00<007ooOol017oo00<007ooOol0P7oo00<07gooOol00Woo00<0
07`0O0007W`000<007`0O0007g`000<007`0O0006G`000<07g`0O0000g`000<007ooOol04goo000?
Ool50002Ool00`00Oomoo`04Ool3001oOol00`0OOomoo`03Ool00`00O01l000NO0000`00O01l000O
O0000`00O01l000IO0000`0OO01l0003O0000`00Oomoo`0COol001Ioo`03001oogoo00Aoo`03001o
ogoo07moo`0301moogoo00=oo`03001l07`001il0003001l07`001ml0003001l07`001Ul000301ml
07`000=l0003001oogoo01=oo`005Woo00<007ooOol017oo00<007ooOol0OWoo00<07gooOol017oo
00<007`0O0007W`000<007`0O0007g`000<007`0O0006G`000<07g`0O0000g`000<007ooOol04goo
000EOol20006Ool00`00Oomoo`1nOol00`0OOomoo`04Ool00`00O01l000NO0000`00O01l000OO000
0`00O01l000JO0000`0OO01l0002O0000`00Oomoo`0COol001eoo`03001oogoo07eoo`0301moogoo
00Eoo`03001l07`001il0003001l07`001ml0003001l07`001Yl000301ml07`0009l0003001oogoo
01=oo`007Goo0P00OWoo00<07gooOol01Goo00<007`0O0007W`000<007`0O0007g`000<007`0O000
6W`000<07g`0O0000W`000<007ooOol04goo000MOol00`00Oomoo`1lOol00`0OOomoo`06Ool00`00
O01l000NO0000`00O01l000OO0000`00O01l000JO0000`0OO01l0002O0000`00Oomoo`0COol001eo
o`03001oogoo07aoo`0301moogoo00Ioo`03001l07`001il0003001l07`001ml0003001l07`001]l
000501ml07`0O000000EOol001eoo`03001oogoo07]oo`0301moogoo00Moo`03001l07`001il0003
001l07`001ml0003001l07`001]l000501ml07`0O000000EOol001eoo`8007aoo`0301moogoo00Mo
o`03001l07`001il0003001l07`001ml0003001l07`001]l000501ml07`0O000000EOol001eoo`03
001oogoo07Yoo`0301moogoo00Qoo`03001l07`001il0003001l07`001ml0003001l07`001]l0005
01ml07`0O000000EOol001eoo`03001oogoo07Yoo`0301moogoo00Qoo`03001l07`001il0003001l
07`001ml0003001l07`001al000401ml07`0000EOol001eoo`03001oogoo025oo`<002=oo`@0025o
o`<000Yoo`0301moogoo00Uoo`03001l07`001il0003001l07`001ml0003001l07`001al000401ml
07`0000EOol001eoo`03001oogoo029oo`03001oogoo02=oo`03001oogoo02Aoo`03001oogoo00Mo
o`0301moogoo00Uoo`03001l07`001il0003001l07`001ml0003001l07`001al000401ml07`0000E
Ool001eoo`8002=oo`03001oogoo02Aoo`03001oogoo02=oo`03001oogoo00Ioo`0301moogoo00Yo
o`03001l07`001il0003001l07`001ml0003001l07`001al000401ml07`0000EOol001eoo`03001o
ogoo029oo`03001oogoo02Eoo`03001oogoo021oo`8000Uoo`0301moogoo00Yoo`03001l07`001il
0003001l07`001ml0003001l07`001el000301ml000001Eoo`007Goo00<007ooOol08Woo00<007oo
Ool08Woo00@007ooOol002Aoo`03001oogoo00Eoo`0301moogoo00]oo`03001l07`001il0003001l
07`001ml0003001l07`001el000301ml000001Eoo`007Goo00<007ooOol08Goo0P009Goo0P008Woo
0`0027oo00<07gooOol02goo00<007`0O0007W`000<007`0O0007g`000<007`0O0007G`000<07g`0
00005Goo000MOol2001gOol00`0OOomoo`0<Ool00`00O01l000NO0000`00O01l000OO0000`00O01l
000NO0000`0O001oo`0DOol001eoo`03001oogoo07Ioo`0301moogoo00aoo`03001l07`001il0003
001l07`001ml0003001l07`001il000301l007oo01Aoo`007Goo00<007ooOol0MGoo00<07gooOol0
3Goo00<007`0O0007W`000<007`0O0007g`000<007`0O0007W`000<07`00Ool057oo000MOol00`00
Oomoo`1eOol00`0OOomoo`0=Ool00`00O01l000NO0000`00O01l000OO0000`00O01l000NO0000`0O
001oo`0DOol001eoo`03001oogoo06=oo`03001oogoo00ioo`0301moogoo00ioo`03001l07`001il
0003001l07`001ml0003001l07`001ml000301moogoo01=oo`005goo1P002P0OK@0000<07`000000
3`0087`000<007`0O0007g`000<007`0O0007g`000<07`00000010003goo000MOol00`00O01l0007
O00201lFO0000`00O01l000OO0000`00O01l000OO0000`00Oomoo`08Ool00`00Oomoo`02Ool00`0O
Oomoo`0NOol00`00Oomoo`0SOol00`00Oomoo`0ROol00`00Oomoo`0NOol001eoo`03001l07`000Ul
00<07a=l0003001l07`001ml0003001l07`001ml0003001oogoo00aoo`0301moogoo08]oo`007Goo
00<007`0O00037`00P0O4G`000<007`0O0007g`000<007`0O0007g`000<007ooOol037oo00<07goo
Ool0Rgoo000MOolA000201l@000QO0000`00O01l000OO0000`00Oomoo`0;Ool00`0OOomoo`2<Ool0
01eoo`03001oogoo011oo`0301moogoo00aoo`03001l07`001ml0003001l07`001ml0003001oogoo
00]oo`0301moogoo08aoo`007Goo00<007ooOol04Goo0P0O37oo00<007`0O0007g`000<007`0O000
7g`000<007ooOol02Woo00<07gooOol0SGoo000MOol00`00Oomoo`0COol201l:Ool00`00O01l000O
O0000`00O01l000OO0000`00Oomoo`09Ool00`0OOomoo`2>Ool001eoo`8001Ioo`0301moogoo00Mo
o`03001l07`001ml0003001l07`001ml0003001oogoo00Uoo`0301moogoo08ioo`007Goo00<007oo
Ool05Woo0P0O1goo00<007`0O0007g`000<007`0O0007g`000<007ooOol027oo00<07gooOol0Sgoo
000MOol00`00Oomoo`0HOol201l5Ool00`00O01l000OO0000`00O01l000OO0000`00Oomoo`07Ool0
0`0OOomoo`2@Ool001eoo`03001oogoo01Yoo`0301moogoo009oo`03001l07`001ml0003001l07`0
01ml0003001oogoo00Moo`0301moogoo091oo`007Goo00<007ooOol06goo0P0O0Woo00<007`0O000
7g`000<007`0O0007g`000<007ooOol01Woo00<07gooOol0TGoo000MOol2000NOol00`0OOol0000Q
O0000`00O01l000OO0000`00Oomoo`06Ool00`0OOomoo`2AOol001eoo`03001oogoo01ioo`0301l0
07`0021l0003001l07`001ml0003001oogoo00Eoo`0301moogoo099oo`007Goo00<007ooOol07goo
00<07g`0O0007g`000<007`0O0007g`000<007ooOol017oo00<07gooOol0Tgoo000MOol00`00Oomo
o`0OOol00`0001l07`0OO0000`00O01l000OO0000`00Oomoo`04Ool00`0OOomoo`2COol001eoo`80
021oo`04001l07`001lNO0000`00O01l000OO0000`00Oomoo`03Ool00`0OOomoo`2DOol001eoo`03
001oogoo01moo`05001l07`0O0007`0MO0000`00O01l000OO0000`00Oomoo`02Ool00`0OOomoo`2E
Ool001eoo`03001oogoo01moo`03001l07`0009l000301ml07`001Yl0003001l07`001ml0005001o
ogooOol07`2HOol001Eoo`<000Eoo`03001oogoo01moo`03001l07`000=l00807aYl0003001l07`0
01ml0005001oogooOol07`2HOol001Ioo`03001oogoo00Aoo`03001oogoo01moo`03001l07`000El
000301ml07`001Ml0003001l07`001ml0004001oogoo01nIOol001Ioo`03001oogoo00Aoo`<001mo
o`03001l07`000Il000301ml07`001Il0003001l07`001ml0003001oo`0O09Yoo`005Woo00<007oo
Ool017oo00<007ooOol07goo00<007`0O0001g`000<07g`0O0005G`000<007`0O0007g`000<0000O
Ool0VWoo000FOol00`00Oomoo`04Ool00`00Oomoo`0OOol00`00O01l0008O00201lEO0000`00O01l
000OO0000`0OOomoo`2JOol001Eoo`8000Ioo`03001oogoo01moo`03001l07`000Yl000301ml07`0
019l0003001l07`001ml000301moogoo09Yoo`007Goo0P0087oo00<007`0O0002g`000<07g`0O000
4G`000<007`0O0007W`000<07`00Ool0Vgoo000MOol00`00Oomoo`0OOol00`00O01l000<O0000`0O
O01l000@O0000`00O01l000MO0000`0OO000002LOol001eoo`03001oogoo01moo`03001l07`000el
00807a1l0003001l07`001al000401ml07`0002LOol001eoo`03001oogoo01mooa80000301l00000
00h001el000501ml07`0O000002LOol001eoo`8003=oo`807`eoo`03001l07`001Yl000301ml07`0
009l0003001oogoo09Yoo`007Goo00<007ooOol0=7oo00<07gooOol02Woo00<007`0O0006G`000<0
7g`0O0000g`000<007ooOol0VWoo000MOol00`00Oomoo`0eOol201l:Ool00`00O01l000GO00201l6
O0000`00Oomoo`2JOol001eoo`03001oogoo03Moo`0301moogoo00Moo`03001l07`001Il000301ml
07`000Il0003001oogoo09Yoo`007Goo00<007ooOol0>7oo0P0O1goo00<007`0O0005G`000<07g`0
O0001g`000<007ooOol0VWoo000MOol2000kOol00`0OOomoo`04Ool00`00O01l000DO0000`0OO01l
0008O0000`00Oomoo`2JOol001eoo`03001oogoo03]oo`<07`=oo`03001l07`0019l00807`]l0003
001oogoo09Yoo`007Goo00<007ooOol0?Woo0P0O00=oo`00O00047`00`0O3G`000<007ooOol0VWoo
000MOol00`00Oomoo`10Ool301l>000201lA002LOol001eoo`8004Aoo`@07`Ioo`@07jmoo`007Goo
00<007ooOol0Agoo1P0O/goo000MOol00`00Oomoo`3oOol1Ool001eoo`03001oogoo0?moo`5oo`00
7Goo00<007ooOol0ogoo0Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00?7oo1P001Woo0`000goo100017oo0`001Goo0`000goo1000
00=oo`0000000P000Woo0P001Goo2P0000=oo`0000000P000Woo100017oo10000goo10005goo1@00
1Goo0P000Woo1@0017oo1`000Woo1@0017oo1@001goo0`00=goo000nOol20007Ool20002Ool01000
Oomoogoo0P0017oo0P000Woo00@007ooOomoo`80009oo`04001oogooOol20003Ool20002Ool20000
0goo001oo`05Ool20005Ool200000goo00000004Ool20004Ool20002Ool20003Ool2000HOol20003
Ool20003Ool20002Ool20003Ool20003Ool60002Ool20003Ool20002Ool20003Ool20003Ool20002
Ool2000fOol003ioo`8000Ioo`8000Aoo`03001oogoo008000=oo`8000Aoo`04001oo`000004Ool0
0`00Oomoo`020003Ool20002Ool20008Ool20006Ool01000Ool0000017oo0P000goo0P0017oo0P00
0Woo0P002Goo2@0037oo00<007ooOol02goo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol0
1Goo00<007ooOol01Woo00D007ooOomoo`0000Aoo`8003Eoo`00?Woo0P001Woo0P001goo0P000goo
0P001Woo0P001goo0P000goo0P000Woo0P0027oo0P0027oo0P0017oo0P000goo0P0017oo0P000Woo
0P007Woo0P0037oo0P000goo0P002goo0P001goo0P0000=oo`00000017oo0P00=Goo000nOol20006
Ool20007Ool20003Ool20006Ool20007Ool20003Ool20002Ool20008Ool20004Ool01000Oomoogoo
0P0017oo0P000goo0P0017oo0P000Woo0P007Woo0P0037oo0P0017oo00<007ooOol02Goo0P001goo
0P0000=oo`00000017oo0P00=Goo000nOol60002Ool70002Ool20003Ool20004Ool00`00Ool00006
0002Ool20003Ool20002Ool20008Ool20004Ool01000Oomoogoo0P0017oo0P000goo0P0017oo0P00
0Woo0P007Woo0P0037oo0P001Goo00<007ooOol027oo0P001goo0P0000=oo`00000017oo0P00=Goo
000nOol20003Ool20002Ool01000Oomoogoo0P0000=oo`000000100000=oo`0000000Woo0P000Woo
00@007ooOomoo`800003Ool000000080009oo`80009oo`8000Qoo`L0009oo``00003Ool00000009o
o`80009oo`H000Ioo`T000]oo`<000]oo`<000Eoo`8000Qoo`<000Ioo`<00004Ool000000002Ool2
000fOol003ioo`8000Aoo`80009oo`@000Aoo`04001oo`000002Ool40004Ool40004Ool00`00Ool0
00020002Ool50006Ool20004Ool00`00Oomoo`02Ool01000Ool000000Woo00@007oo0000009oo`@0
00Eoo`04001oo`00000GOol50009Ool50007Ool00`00Oomoo`03Ool50004Ool50002Ool2000017oo
00000000=goo000nOol20004Ool2000XOol20008Ool20004Ool00`00Oomoo`0dOol00`00Oomoo`0;
Ool00`00Oomoo`07Ool20006Ool00`00Oomoo`06Ool00`00Oomoo`03Ool2000jOol003ioo`8000Ao
o`8002Uoo`03001oogoo00Ioo`8003aoo`03001oogoo00]oo`05001oogooOol00004Ool20007Ool0
0`00Oomoo`06Ool00`00Oomoo`02Ool2000jOol003ioo`8000Aoo`80039oo`8000Eoo`03001oogoo
02moo`03001oogoo009oo`8000Moo`03001oogoo009oo`80009oo`80009oo`<0009oo`03001oogoo
009oo`80009oo`03001oogoo009oo`8000Aoo`8003Uoo`00?Woo0P000goo0P00<goo0P001Goo00<0
07ooOol0<7oo00<007ooOol00`0027oo00<007ooOol00`000goo1@0017oo00<007ooOol00`000goo
00<007ooOol00`001Goo0P00>7oo000lOol8000bOol:000cOol4000:Ool40005Ool30006Ool40005
Ool40008Ool3000eOol00?moob5oo`00ogoo8Goo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.783823, -4.98036, 
  0.0265065, 0.0452841}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.151576 0.44187 0.0887232 [
[.17539 .42937 -3 -9 ]
[.17539 .42937 3 0 ]
[.32696 .42937 -3 -9 ]
[.32696 .42937 3 0 ]
[.47854 .42937 -3 -9 ]
[.47854 .42937 3 0 ]
[.63011 .42937 -3 -9 ]
[.63011 .42937 3 0 ]
[.78169 .42937 -3 -9 ]
[.78169 .42937 3 0 ]
[.93327 .42937 -3 -9 ]
[.93327 .42937 3 0 ]
[.01131 .08698 -12 -4.5 ]
[.01131 .08698 0 4.5 ]
[.01131 .1757 -12 -4.5 ]
[.01131 .1757 0 4.5 ]
[.01131 .26442 -12 -4.5 ]
[.01131 .26442 0 4.5 ]
[.01131 .35315 -12 -4.5 ]
[.01131 .35315 0 4.5 ]
[.01131 .53059 -6 -4.5 ]
[.01131 .53059 0 4.5 ]
[.5 .63053 -89.5938 0 ]
[.5 .63053 89.5938 20 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.17539 .44187 m
.17539 .44812 L
s
[(1)] .17539 .42937 0 1 Mshowa
.32696 .44187 m
.32696 .44812 L
s
[(2)] .32696 .42937 0 1 Mshowa
.47854 .44187 m
.47854 .44812 L
s
[(3)] .47854 .42937 0 1 Mshowa
.63011 .44187 m
.63011 .44812 L
s
[(4)] .63011 .42937 0 1 Mshowa
.78169 .44187 m
.78169 .44812 L
s
[(5)] .78169 .42937 0 1 Mshowa
.93327 .44187 m
.93327 .44812 L
s
[(6)] .93327 .42937 0 1 Mshowa
.125 Mabswid
.05412 .44187 m
.05412 .44562 L
s
.08444 .44187 m
.08444 .44562 L
s
.11476 .44187 m
.11476 .44562 L
s
.14507 .44187 m
.14507 .44562 L
s
.2057 .44187 m
.2057 .44562 L
s
.23602 .44187 m
.23602 .44562 L
s
.26633 .44187 m
.26633 .44562 L
s
.29665 .44187 m
.29665 .44562 L
s
.35728 .44187 m
.35728 .44562 L
s
.38759 .44187 m
.38759 .44562 L
s
.41791 .44187 m
.41791 .44562 L
s
.44822 .44187 m
.44822 .44562 L
s
.50885 .44187 m
.50885 .44562 L
s
.53917 .44187 m
.53917 .44562 L
s
.56948 .44187 m
.56948 .44562 L
s
.5998 .44187 m
.5998 .44562 L
s
.66043 .44187 m
.66043 .44562 L
s
.69074 .44187 m
.69074 .44562 L
s
.72106 .44187 m
.72106 .44562 L
s
.75137 .44187 m
.75137 .44562 L
s
.81201 .44187 m
.81201 .44562 L
s
.84232 .44187 m
.84232 .44562 L
s
.87264 .44187 m
.87264 .44562 L
s
.90295 .44187 m
.90295 .44562 L
s
.96358 .44187 m
.96358 .44562 L
s
.9939 .44187 m
.9939 .44562 L
s
.25 Mabswid
0 .44187 m
1 .44187 L
s
.02381 .08698 m
.03006 .08698 L
s
[(-4)] .01131 .08698 1 0 Mshowa
.02381 .1757 m
.03006 .1757 L
s
[(-3)] .01131 .1757 1 0 Mshowa
.02381 .26442 m
.03006 .26442 L
s
[(-2)] .01131 .26442 1 0 Mshowa
.02381 .35315 m
.03006 .35315 L
s
[(-1)] .01131 .35315 1 0 Mshowa
.02381 .53059 m
.03006 .53059 L
s
[(1)] .01131 .53059 1 0 Mshowa
.125 Mabswid
.02381 .016 m
.02756 .016 L
s
.02381 .03374 m
.02756 .03374 L
s
.02381 .05149 m
.02756 .05149 L
s
.02381 .06923 m
.02756 .06923 L
s
.02381 .10472 m
.02756 .10472 L
s
.02381 .12247 m
.02756 .12247 L
s
.02381 .14021 m
.02756 .14021 L
s
.02381 .15796 m
.02756 .15796 L
s
.02381 .19344 m
.02756 .19344 L
s
.02381 .21119 m
.02756 .21119 L
s
.02381 .22893 m
.02756 .22893 L
s
.02381 .24668 m
.02756 .24668 L
s
.02381 .28217 m
.02756 .28217 L
s
.02381 .29991 m
.02756 .29991 L
s
.02381 .31766 m
.02756 .31766 L
s
.02381 .3354 m
.02756 .3354 L
s
.02381 .37089 m
.02756 .37089 L
s
.02381 .38864 m
.02756 .38864 L
s
.02381 .40638 m
.02756 .40638 L
s
.02381 .42413 m
.02756 .42413 L
s
.02381 .45961 m
.02756 .45961 L
s
.02381 .47736 m
.02756 .47736 L
s
.02381 .4951 m
.02756 .4951 L
s
.02381 .51285 m
.02756 .51285 L
s
.02381 .54834 m
.02756 .54834 L
s
.02381 .56608 m
.02756 .56608 L
s
.02381 .58383 m
.02756 .58383 L
s
.02381 .60157 m
.02756 .60157 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -150.594 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 24.000000 moveto
 558.000000 24.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 24.000000 lineto
closepath
clip newpath
63.000000 19.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 18.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 19.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 18.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Percent) show
121.250000 19.000000 moveto
(Error) show
163.625000 19.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 18.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(=) show
179.687500 19.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 18.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2.55046) show
238.187500 19.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 18.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
0 0 1 r
.007 w
.02381 .44187 m
.02499 .44188 L
.02605 .44189 L
.02729 .44192 L
.02846 .44195 L
.03053 .44204 L
.03279 .44218 L
.03527 .44238 L
.0379 .44264 L
.04262 .44323 L
.04749 .44403 L
.05205 .44493 L
.06244 .44757 L
.07305 .45107 L
.08274 .45495 L
.10458 .46589 L
.14429 .4922 L
.18248 .52229 L
.22313 .55474 L
.26226 .58144 L
.27254 .5871 L
.28367 .59241 L
.29328 .59624 L
.29838 .59795 L
.30384 .59955 L
.30923 .60086 L
.31415 .60182 L
.31652 .6022 L
.31909 .60255 L
.32151 .60282 L
.32378 .60303 L
.32509 .60312 L
.3263 .60319 L
.32764 .60325 L
.32834 .60327 L
.32908 .60329 L
.32976 .60331 L
.33048 .60332 L
.33177 .60332 L
.33257 .60331 L
.33332 .6033 L
.33399 .60328 L
.33472 .60326 L
.33594 .60321 L
.33728 .60313 L
.33999 .60292 L
.34249 .60266 L
.34484 .60235 L
.34982 .60149 L
.35525 .60023 L
Mistroke
.36513 .59709 L
.37475 .59294 L
.38367 .58812 L
.40423 .57339 L
.42285 .55569 L
.46297 .50405 L
.50157 .43897 L
.54262 .35759 L
.58216 .27326 L
.62019 .19318 L
.66067 .11668 L
.69963 .05896 L
.70983 .04728 L
.72091 .03645 L
.73048 .02875 L
.73557 .02531 L
.74104 .02213 L
.74638 .01956 L
.75126 .01767 L
.75594 .01629 L
.75829 .01576 L
.76085 .0153 L
.76227 .01511 L
.76362 .01496 L
.76482 .01485 L
.76612 .01477 L
.7668 .01474 L
.76755 .01472 L
.76833 .01472 L
.76905 .01472 L
.77035 .01475 L
.77108 .01478 L
.77175 .01482 L
.77304 .01492 L
.77424 .01504 L
.77695 .01543 L
.77933 .0159 L
.78187 .01653 L
.78675 .0181 L
.79123 .01999 L
.80132 .02578 L
.81022 .03269 L
.81959 .04179 L
.83931 .06705 L
.85767 .09794 L
.89668 .18599 L
.93815 .30895 L
.97619 .44187 L
Mfstroke
1 0 0 r
.02381 .44187 m
.14286 .44187 L
.14286 .4552 L
.02381 .4552 L
F
.14286 .44187 m
.2619 .44187 L
.2619 .53844 L
.14286 .53844 L
F
.2619 .44187 m
.38095 .44187 L
.38095 .60282 L
.2619 .60282 L
F
.38095 .44187 m
.5 .44187 L
.5 .5352 L
.38095 .5352 L
F
.5 .44187 m
.61905 .44187 L
.61905 .32187 L
.5 .32187 L
F
.61905 .44187 m
.7381 .44187 L
.7381 .08779 L
.61905 .08779 L
F
.7381 .44187 m
.85714 .44187 L
.85714 .02341 L
.7381 .02341 L
F
.85714 .44187 m
.97619 .44187 L
.97619 .24187 L
.85714 .24187 L
F
0 g
.5 Mabswid
.02381 .44187 m
.02381 .4552 L
s
.14286 .44187 m
.14286 .4552 L
s
.02381 .4552 m
.14286 .4552 L
s
.14286 .44187 m
.14286 .53844 L
s
.2619 .44187 m
.2619 .53844 L
s
.14286 .53844 m
.2619 .53844 L
s
.2619 .44187 m
.2619 .60282 L
s
.38095 .44187 m
.38095 .60282 L
s
.2619 .60282 m
.38095 .60282 L
s
.38095 .44187 m
.38095 .5352 L
s
.5 .44187 m
.5 .5352 L
s
.38095 .5352 m
.5 .5352 L
s
.5 .44187 m
.5 .32187 L
s
.61905 .44187 m
.61905 .32187 L
s
.5 .32187 m
.61905 .32187 L
s
.61905 .44187 m
.61905 .08779 L
s
.7381 .44187 m
.7381 .08779 L
s
.61905 .08779 m
.7381 .08779 L
s
.7381 .44187 m
.7381 .02341 L
s
.85714 .44187 m
.85714 .02341 L
s
.7381 .02341 m
.85714 .02341 L
s
.85714 .44187 m
.85714 .24187 L
s
.97619 .44187 m
.97619 .24187 L
s
.85714 .24187 m
.97619 .24187 L
s
0 0 1 r
.007 w
.02381 .44187 m
.02499 .44188 L
.02605 .44189 L
.02729 .44192 L
.02846 .44195 L
.03053 .44204 L
.03279 .44218 L
.03527 .44238 L
.0379 .44264 L
.04262 .44323 L
.04749 .44403 L
.05205 .44493 L
.06244 .44757 L
.07305 .45107 L
.08274 .45495 L
.10458 .46589 L
.14429 .4922 L
.18248 .52229 L
.22313 .55474 L
.26226 .58144 L
.27254 .5871 L
.28367 .59241 L
.29328 .59624 L
.29838 .59795 L
.30384 .59955 L
.30923 .60086 L
.31415 .60182 L
.31652 .6022 L
.31909 .60255 L
.32151 .60282 L
.32378 .60303 L
.32509 .60312 L
.3263 .60319 L
.32764 .60325 L
.32834 .60327 L
.32908 .60329 L
.32976 .60331 L
.33048 .60332 L
.33177 .60332 L
.33257 .60331 L
.33332 .6033 L
.33399 .60328 L
.33472 .60326 L
.33594 .60321 L
.33728 .60313 L
.33999 .60292 L
.34249 .60266 L
.34484 .60235 L
.34982 .60149 L
.35525 .60023 L
Mistroke
.36513 .59709 L
.37475 .59294 L
.38367 .58812 L
.40423 .57339 L
.42285 .55569 L
.46297 .50405 L
.50157 .43897 L
.54262 .35759 L
.58216 .27326 L
.62019 .19318 L
.66067 .11668 L
.69963 .05896 L
.70983 .04728 L
.72091 .03645 L
.73048 .02875 L
.73557 .02531 L
.74104 .02213 L
.74638 .01956 L
.75126 .01767 L
.75594 .01629 L
.75829 .01576 L
.76085 .0153 L
.76227 .01511 L
.76362 .01496 L
.76482 .01485 L
.76612 .01477 L
.7668 .01474 L
.76755 .01472 L
.76833 .01472 L
.76905 .01472 L
.77035 .01475 L
.77108 .01478 L
.77175 .01482 L
.77304 .01492 L
.77424 .01504 L
.77695 .01543 L
.77933 .0159 L
.78187 .01653 L
.78675 .0181 L
.79123 .01999 L
.80132 .02578 L
.81022 .03269 L
.81959 .04179 L
.83931 .06705 L
.85767 .09794 L
.89668 .18599 L
.93815 .30895 L
.97619 .44187 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00O7Goo00<007ooOol0
ogoo0Goo000MOol00`00Oomoo`3oOol1Ool001eoo`03001oogoo0?moo`5oo`007Goo00<007ooOol0
]7oo1P0OAWoo000MOol2002bOol301l5Ool301m4Ool001eoo`03001oogoo0:moo`807`/000<07`h0
03=oo`007Goo00<007ooOol0[Woo00<07`00O0003W`000<07g`0O0002W`000<007ooOol0<Goo000M
Ool00`00Oomoo`2]Ool00`0OOol0000@O0000`0OO01l0009O0000`00Oomoo`0aOol001eoo`800:eo
o`0401moogoo000AO0000`0OO01l0008O0000`00Oomoo`0aOol001eoo`03001oogoo0:Yoo`807`=o
o`03001l07`0011l000301ml07`000Ml0003001oogoo035oo`007Goo00<007ooOol0ZGoo00<07goo
Ool00goo00<007`0O0004G`000<07g`0O0001W`000<007ooOol0<Goo000MOol00`00Oomoo`2XOol0
0`0OOomoo`04Ool00`00O01l000AO0000`0OO01l0006O0000`00Oomoo`0aOol001eoo`800:Qoo`03
01moogoo00Eoo`03001l07`0019l000301ml07`000El0003001oogoo035oo`007Goo00<007ooOol0
YWoo00<07gooOol01Woo00<007`0O0004g`000<07g`0O00017`000<007ooOol0<Goo000MOol00`00
Oomoo`2UOol00`0OOomoo`07Ool00`00O01l000DO0000`0OO01l0003O0000`00Oomoo`0aOol001eo
o`03001oogoo0:Eoo`0301moogoo00Moo`03001l07`001El000301ml07`0009l0003001oogoo035o
o`007Goo00<007ooOol0Y7oo00<07gooOol027oo00<007`0O0005W`000D07g`0O01l000003=oo`00
7Goo0P00Y7oo00<07gooOol02Goo00<007`0O0005W`000D07g`0O01l000003=oo`007Goo00<007oo
Ool0Xgoo00<07gooOol02Goo00<007`0O0005g`000@07g`0O00003=oo`005Woo0`0017oo00<007oo
Ool0XWoo00<07gooOol02Woo00<007`0O00067`000<07g`00000<goo000GOol00`00Oomoo`03Ool0
0`00Oomoo`2ROol00`0OOomoo`0:Ool00`00O01l000HO0000`0OO000000cOol000moo`D00003Ool0
0000008000Aoo`<0095ooa00000301l0000000`001]l000301l007oo039oo`005Goo00<007oo0000
1Goo00<007ooOol0TGoo00<007`0O00037`000<07g`0O00037`000<007`0O0006G`000<07`00Ool0
<Woo000EOol00`00Ool00005Ool00`00Oomoo`2AOol00`00O01l000<O0000`0OO01l000<O0000`00
O01l000JO0000`0OOomoo`0aOol001Ioo`8000Eoo`03001oogoo095oo`03001l07`000]l000301ml
07`000el0003001l07`001Yl000300007goo035oo`007Goo00<007ooOol0TGoo00<007`0O0002g`0
00<07g`0O0003G`000<007`0O0006W`000<0000OOol0<Goo000MOol2002BOol00`00O01l000:O000
0`0OO01l000>O0000`00O01l000JO0000`00Ool07`0aOol001eoo`03001oogoo095oo`03001l07`0
00Ul000301ml07`000ml0003001l07`001Yl0003001oo`0O035oo`007Goo00<007ooOol0TGoo00<0
07`0O0002G`000<07g`0O0003g`000<007`0O0006W`000<007oo01l0<Goo000MOol00`00Oomoo`2A
Ool00`00O01l0008O0000`0OO01l000@O0000`00O01l000JO0001000Oomoo`0O<7oo000MOol2002B
Ool00`00O01l0008O0000`0OO01l000@O0000`00O01l000JO0001000Oomoo`0O<7oo000MOol00`00
Oomoo`2AOol00`00O01l0007O0000`0OO01l000AO0000`00O01l000JO0001@00Oomoogoo01l0;goo
000MOol00`00Oomoo`2AOol00`00O01l0007O0000`0OO01l000AO0000`00O01l000JO0001@00Oomo
ogoo01l0;goo000MOol00`00Oomoo`2AOol00`00O01l0006O0000`0OO01l000BO0000`00O01l000J
O0001@00Oomoogoo01l0;goo000MOol2002BOol00`00O01l0006O0000`0OO01l000BO0000`00O01l
000JO0000`00Oomoo`02Ool00`0OOomoo`0/Ool001eoo`03001oogoo095oo`03001l07`000El0003
01ml07`001=l0003001l07`001Yl0003001oogoo009oo`0301moogoo02aoo`007Goo00<007ooOol0
TGoo00<007`0O0001G`000<07g`0O0004g`000<007`0O0006W`000<007ooOol00goo00<07gooOol0
:goo000MOol00`00Oomoo`2AOol00`00O01l0004O0000`0OO01l000DO0000`00O01l000JO0000`00
Oomoo`03Ool00`0OOomoo`0[Ool001eoo`03001oogoo095oo`03001l07`000Al000301ml07`001Al
0003001l07`001Yl0003001oogoo00Aoo`0301moogoo02Yoo`007Goo0P00TWoo00<007`0O0000g`0
00<07g`0O0005G`000<007`0O0006W`000<007ooOol017oo00<07gooOol0:Woo000MOol00`00Oomo
o`2AOol00`00O01l0002O0000`0OO01l000FO0000`00O01l000JO0000`00Oomoo`04Ool00`0OOomo
o`0ZOol001Eoo`<000Eoo`03001oogoo095oo`03001l07`0009l000301ml07`001Il0003001l07`0
01Yl0003001oogoo00Eoo`0301moogoo02Uoo`0067oo00<007ooOol00Woo00<007ooOol0TGoo00D0
07`0O01l000O01Ul0003001l07`001Yl0003001oogoo00Eoo`0301moogoo02Uoo`003goo1@0017oo
00<007ooOol00Woo0`00TGoo00D007`0O01l000O01Ul0003001l07`001Yl0003001oogoo00Ioo`03
01moogoo02Qoo`005Woo0P001Goo00<007ooOol0TGoo00@007`0O0007aYl0003001l07`001Yl0003
001oogoo00Ioo`0301moogoo02Qoo`0067oo00<007ooOol00Woo00<007ooOol0TGoo00@007`0O000
7aYl0003001l07`001Yl0003001oogoo00Ioo`0301moogoo02Qoo`005Goo0`001Goo00<007ooOol0
TGoo00<007`001l06g`000<007`0O0006W`000<007ooOol01goo00<07gooOol09goo000MOol00`00
Oomoo`2AOol00`00O0007`0KO0000`00O01l000JO0000`00Oomoo`07Ool00`0OOomoo`0WOol001eo
o`80099oo`0300007g`001]l0003001l07`001Yl0003001oogoo00Qoo`0301moogoo02Ioo`007Goo
00<007ooOol0TGoo00<0000OO0006g`000<007`0O0006W`000<007ooOol027oo00<07gooOol09Woo
000MOol00`00Oomoo`2AOol00`0OO01l000KO0000`00O01l000JO0000`00Oomoo`08Ool00`0OOomo
o`0VOol001eoo`03001oogoo095oo`0301ml07`001]l0003001l07`001Yl0003001oogoo00Uoo`03
01moogoo02Eoo`007Goo0P00TGoo00<07`00O00077`000<007`0O0006W`000<007ooOol02Goo00<0
7gooOol09Goo000MOol00`00Oomoo`2@Ool00`0O001l000LO0000`00O01l000JO0000`00Oomoo`09
Ool00`0OOomoo`0UOol001eoo`03001oogoo08moo`0301moo`0001el0003001l07`001Yl0003001o
ogoo00Yoo`0301moogoo02Aoo`007Goo00<007ooOol0Sgoo00<07goo00007G`000<007`0O0006W`0
00<007ooOol02Woo00<07gooOol097oo000MOol00`00Oomoo`2>Ool0100OOomoo`007G`000<007`0
O0006W`000<007ooOol02Woo00<07gooOol097oo000MOol2002?Ool0100OOomoo`007G`000<007`0
O0006W`000<007ooOol02goo00<07gooOol08goo000MOol00`00Oomoo`2=Ool01@0OOomoogoo0000
7G`000<007`0O0006W`000<007ooOol02goo00<07gooOol08goo000MOol00`00Oomoo`2=Ool01@0O
Oomoogoo00007G`000<007`0O0006W`000<007ooOol037oo00<07gooOol08Woo000MOol00`00Oomo
o`2<Ool00`0OOomoo`02Ool00`00O01l000KO0000`00O01l000JO00?00000`0O0000000=000EOol0
01eoo`8008eoo`0301moogoo009oo`03001l07`001]l0003001l07`001Yl0003001l07`000al0003
01ml07`000al0003001oogoo01=oo`007Goo00<007ooOol0Rgoo00<07gooOol00goo00<007`0O000
6g`000<007`0O0006W`000<007`0O0003G`000<07g`0O0002g`000<007ooOol04goo000EOol40004
Ool00`00Oomoo`2;Ool00`0OOomoo`03Ool00`00O01l000KO0000`00O01l000JO0000`00O01l000=
O0000`0OO01l000;O0000`00Oomoo`0COol001Ioo`03001oogoo00Aoo`03001oogoo08Yoo`0301mo
ogoo00Aoo`03001l07`001]l0003001l07`001Yl0003001l07`000el000301ml07`000]l0003001o
ogoo01=oo`003goo1@000goo00<007ooOol00goo0`00RWoo00<07gooOol017oo00<007`0O0006g`0
00<007`0O0006W`000<007`0O0003W`000<07g`0O0002W`000<007ooOol04goo000HOol00`00Oomo
o`02Ool00`00Oomoo`29Ool00`0OOomoo`05Ool00`00O01l000KO0000`00O01l000JO0000`00O01l
000>O0000`0OO01l000:O0000`00Oomoo`0COol001Eoo`04001oogoo0004Ool00`00Oomoo`29Ool0
0`0OOomoo`05Ool00`00O01l000KO0000`00O01l000JO0000`00O01l000?O0000`0OO01l0009O000
0`00Oomoo`0COol001Ioo`8000Eoo`03001oogoo08Qoo`0301moogoo00Ioo`03001l07`001]l0003
001l07`001Yl0003001l07`000ml000301ml07`000Ul0003001oogoo01=oo`007Goo00<007ooOol0
R7oo00<07gooOol01Woo00<007`0O0006g`000<007`0O0006W`000<007`0O0003g`000<07g`0O000
2G`000<007ooOol04goo000MOol20028Ool00`0OOomoo`07Ool00`00O01l000KO0000`00O01l000J
O0000`00O01l000@O0000`0OO01l0008O0000`00Oomoo`0COol001eoo`03001oogoo08Moo`0301mo
ogoo00Moo`03001l07`001]l0003001l07`001Yl0003001l07`0011l000301ml07`000Ql0003001o
ogoo01=oo`007Goo00<007ooOol0QWoo00<07gooOol027oo00<007`0O0006g`000<007`0O0006W`0
00<007`0O00047`000<07g`0O00027`000<007ooOol04goo000MOol00`00Oomoo`26Ool00`0OOomo
o`08Ool00`00O01l000KO0000`00O01l000JO0000`00O01l000AO0000`0OO01l0007O0000`00Oomo
o`0COol001eoo`8008Ioo`0301moogoo00Uoo`03001l07`001]l0003001l07`001Yl0003001l07`0
015l000301ml07`000Ml0003001oogoo01=oo`007Goo00<007ooOol0QGoo00<07gooOol02Goo00<0
07`0O0006g`000<007`0O0006W`000<007`0O0004G`000<07g`0O0001g`000<007ooOol04goo000M
Ool00`00Oomoo`24Ool00`0OOomoo`0:Ool00`00O01l000KO0000`00O01l000JO0000`00O01l000B
O0000`0OO01l0006O0000`00Oomoo`0COol001eoo`03001oogoo08Aoo`0301moogoo00Yoo`03001l
07`001]l0003001l07`001Yl0003001l07`0019l000301ml07`000Il0003001oogoo01=oo`007Goo
00<007ooOol0Pgoo00<07gooOol02goo00<007`0O0006g`000<007`0O0006W`000<007`0O0004W`0
00<07g`0O0001W`000<007ooOol04goo000MOol20024Ool00`0OOomoo`0;Ool00`00O01l000KO000
0`00O01l000JO0000`00O01l000CO0000`0OO01l0005O0000`00Oomoo`0COol001eoo`03001oogoo
07Aoo`l0000301l0000000`001el0003001l07`001Yl0003001l07`001=l000301ml07`000El0003
001oogoo01=oo`007Goo00<007ooOol0M7oo00<007`0O0002g`000<07g`0O00037`000<007`0O000
6g`000<007`0O0006W`000<007`0O0004g`000<07g`0O0001G`000<007ooOol04goo000MOol00`00
Oomoo`1dOol00`00O01l000;O0000`0OO01l000<O0000`00O01l000KO0000`00O01l000JO0000`00
O01l000CO0000`0OO01l0005O0000`00Oomoo`0COol001eoo`8007Eoo`03001l07`000Yl000301ml
07`000el0003001l07`001]l0003001l07`001Yl0003001l07`001Al000301ml07`000Al0003001o
ogoo01=oo`007Goo00<007ooOol0M7oo00<007`0O0002W`000<07g`0O0003G`000<007`0O0006g`0
00<007`0O0006W`000<007`0O00057`000<07g`0O00017`000<007ooOol04goo000EOol30005Ool0
0`00Oomoo`1dOol00`00O01l0009O0000`0OO01l000>O0000`00O01l000KO0000`00O01l000JO000
0`00O01l000DO0000`0OO01l0004O0000`00Oomoo`0COol001Ioo`03001oogoo00Aoo`03001oogoo
07Aoo`03001l07`000Ul000301ml07`000il0003001l07`001]l0003001l07`001Yl0003001l07`0
01El000301ml07`000=l0003001oogoo01=oo`003goo1@000Woo00<007ooOol017oo0`00M7oo00<0
07`0O00027`000<07g`0O0003g`000<007`0O0006g`000<007`0O0006W`000<007`0O0005G`000<0
7g`0O0000g`000<007ooOol04goo000FOol00`00Oomoo`04Ool00`00Oomoo`1dOol00`00O01l0008
O0000`0OO01l000?O0000`00O01l000KO0000`00O01l000JO0000`00O01l000EO0000`0OO01l0003
O0000`00Oomoo`0COol001Ioo`03001oogoo00Aoo`03001oogoo07Aoo`03001l07`000Ml000301ml
07`0011l0003001l07`001]l0003001l07`001Yl0003001l07`001El000301ml07`000=l0003001o
ogoo01=oo`005Goo0P001Woo00<007ooOol0M7oo00<007`0O0001g`000<07g`0O00047`000<007`0
O0006g`000<007`0O0006W`000<007`0O0005W`000<07g`0O0000W`000<007ooOol04goo000MOol0
0`00Oomoo`1dOol00`00O01l0006O0000`0OO01l000AO0000`00O01l000KO0000`00O01l000JO000
0`00O01l000FO0000`0OO01l0002O0000`00Oomoo`0COol001eoo`8007Eoo`03001l07`000Il0003
01ml07`0015l0003001l07`001]l0003001l07`001Yl0003001l07`001Il000301ml07`0009l0003
001oogoo01=oo`007Goo00<007ooOol0M7oo00<007`0O0001G`000<07g`0O0004W`000<007`0O000
6g`000<007`0O0006W`000<007`0O0005W`000<07g`0O0000W`000<007ooOol04goo000MOol00`00
Oomoo`1dOol00`00O01l0005O0000`0OO01l000BO0000`00O01l000KO0000`00O01l000JO0000`00
O01l000GO0001@0OO01l07`000005Goo000MOol00`00Oomoo`1dOol00`00O01l0004O0000`0OO01l
000CO0000`00O01l000KO0000`00O01l000JO0000`00O01l000GO0001@0OO01l07`000005Goo000M
Ool2001eOol00`00O01l0004O0000`0OO01l000CO0000`00O01l000KO0000`00O01l000JO0000`00
O01l000GO0001@0OO01l07`000005Goo000MOol00`00Oomoo`1dOol00`00O01l0003O0000`0OO01l
000DO0000`00O01l000KO0000`00O01l000JO0000`00O01l000GO0001@0OO01l07`000005Goo000M
Ool00`00Oomoo`1dOol00`00O01l0003O0000`0OO01l000DO0000`00O01l000KO0000`00O01l000J
O0000`00O01l000HO000100OO01l00005Goo000MOol00`00Oomoo`0QOol3000SOol4000QOol30005
Ool00`00O01l0002O0000`0OO01l000EO0000`00O01l000KO0000`00O01l000JO0000`00O01l000H
O000100OO01l00005Goo000MOol00`00Oomoo`0ROol00`00Oomoo`0SOol00`00Oomoo`0TOol00`00
Oomoo`02Ool00`00O01l0002O0000`0OO01l000EO0000`00O01l000KO0000`00O01l000JO0000`00
O01l000HO000100OO01l00005Goo000MOol2000SOol00`00Oomoo`0TOol00`00Oomoo`0SOol00`00
Oomoo`02Ool01@00O01l07`001l067`000<007`0O0006g`000<007`0O0006W`000<007`0O00067`0
00@07g`0O00001Eoo`007Goo00<007ooOol08Woo00<007ooOol09Goo00<007ooOol087oo0P001Goo
00D007`0O01l000O01Ql0003001l07`001]l0003001l07`001Yl0003001l07`001Ul000301ml0000
01Eoo`007Goo00<007ooOol08Woo00<007ooOol08Woo00@007ooOol002Aoo`03001oogoo009oo`04
001l07`001lIO0000`00O01l000KO0000`00O01l000JO0000`00O01l000IO0000`0OO000000EOol0
01eoo`03001oogoo025oo`8002Eoo`80029oo`<000Eoo`04001l07`001lIO0000`00O01l000KO000
0`00O01l000JO0000`00O01l000IO0000`0OO000000EOol001eoo`8007Eoo`03001l000O01Yl0003
001l07`001]l0003001l07`001Yl0003001l07`001Yl000301l007oo01Aoo`007Goo00<007ooOol0
M7oo00<007`001l06W`000<007`0O0006g`000<007`0O0006W`000<007`0O0006W`000<07`00Ool0
57oo000MOol00`00Oomoo`1dOol00`0001ml000JO0000`00O01l000KO0000`00O01l000JO0000`00
O01l000JO0000`0O001oo`0DOol001eoo`03001oogoo07Aoo`0300007g`001Yl0003001l07`001]l
0003001l07`001Yl0003001l07`001Yl000301l007oo01Aoo`007Goo00<007ooOol0M7oo00<07g`0
O0006W`000<007`0O0006g`000<007`0O0006W`000<007`0O0006g`000<07gooOol04goo000GOol6
000:01m]00000`0OO01l000JO0000`00O01l000KO0000`00O01l000JO0000`00O01l000KO0000`0O
00000004000?Ool001eoo`03001l07`000Ml00807a9l0003001l07`001Yl0003001l07`001]l0003
001l07`001Yl000301l007oo01ioo`03001oogoo02=oo`03001oogoo029oo`03001oogoo01ioo`00
7Goo00<007`0O0002G`00`0O3g`000<007`0O0006W`000<007`0O0006g`000<007`0O0006G`000<0
7g`00000Rgoo000MOol?000201l>000LO0000`00O01l000KO0000`00O01l000IO0000`0OO000002;
Ool001eoo`8000moo`807`]oo`03001l07`001Yl0003001l07`001]l0003001l07`001Ql000401ml
07`0002;Ool001eoo`03001oogoo011oo`0301moogoo00Qoo`03001l07`001Yl0003001l07`001]l
0003001l07`001Ql000401ml07`0002;Ool001eoo`03001oogoo015oo`807`Qoo`03001l07`001Yl
0003001l07`001]l0003001l07`001Ml000501ml07`0O000002;Ool001eoo`03001oogoo01=oo`80
7`Ioo`03001l07`001Yl0003001l07`001]l0003001l07`001Il000301ml07`0009l0003001oogoo
08Uoo`007Goo0P005Woo00<07gooOol00goo00<007`0O0006W`000<007`0O0006g`000<007`0O000
5W`000<07g`0O0000W`000<007ooOol0RGoo000MOol00`00Oomoo`0FOol201l3Ool00`00O01l000J
O0000`00O01l000KO0000`00O01l000EO0000`0OO01l0003O0000`00Oomoo`29Ool001eoo`03001o
ogoo01Qoo`807`03Ool007`001]l0003001l07`001]l0003001l07`001Al000301ml07`000Al0003
001oogoo08Uoo`007Goo00<007ooOol06Woo00<07`00O0006g`000<007`0O0006g`000<007`0O000
57`000<07g`0O00017`000<007ooOol0RGoo000MOol00`00Oomoo`0KOol201lKO0000`00O01l000K
O0000`00O01l000CO0000`0OO01l0005O0000`00Oomoo`29Ool001eoo`8001aoo`03001l000O01Yl
0003001l07`001]l0003001l07`001=l000301ml07`000El0003001oogoo08Uoo`007Goo00<007oo
Ool06goo00@007`0O0007aUl0003001l07`001]l0003001l07`0019l000301ml07`000Il0003001o
ogoo08Uoo`007Goo00<007ooOol06goo00D007`0O01l000O01Ql0003001l07`001]l0003001l07`0
015l000301ml07`000Ml0003001oogoo08Uoo`007Goo00<007ooOol06goo00<007`0O0000W`00P0O
5W`000<007`0O0006g`000<007`0O0004G`000<07g`0O0001g`000<007ooOol0RGoo000MOol2000L
Ool00`00O01l0004O0000`0OO01l000CO0000`00O01l000KO0000`00O01l000@O0000`0OO01l0008
O0000`00Oomoo`29Ool001eoo`03001oogoo01]oo`03001l07`000El000301ml07`0019l0003001l
07`001]l0003001l07`000ml000301ml07`000Ul0003001oogoo08Uoo`007Goo00<007ooOol06goo
00<007`0O0001W`000<07g`0O0004G`000<007`0O0006g`000<007`0O0003W`000<07g`0O0002W`0
00<007ooOol0RGoo000EOol30005Ool00`00Oomoo`0KOol00`00O01l0007O00201lAO0000`00O01l
000KO0000`00O01l000>O0000`0OO01l000:O0000`00Oomoo`29Ool001Ioo`03001oogoo00Aoo`03
001oogoo01]oo`03001l07`000Ul000301ml07`000il0003001l07`001]l0003001l07`000el0003
01ml07`000]l0003001oogoo08Uoo`005Woo00<007ooOol017oo0`006goo00<007`0O0002W`000<0
7g`0O0003G`000<007`0O0006g`000<007`0O00037`000<07g`0O00037`000<007ooOol0RGoo000F
Ool00`00Oomoo`04Ool00`00Oomoo`0KOol00`00O01l000;O0000`0OO01l000<O0000`00O01l000K
O00>00000`0O0000000>002;Ool001Ioo`03001oogoo00Aoo`03001oogoo01]oo`l000807`d001el
0003001oogoo00Yoo`0301moogoo09Yoo`005Goo0P001Woo00<007ooOol0;7oo00<07gooOol02Goo
00<007`0O0006g`000<007ooOol02Woo00<07gooOol0VWoo000MOol2000^Ool00`0OOomoo`08Ool0
0`00O01l000KO0000`00Oomoo`09Ool00`0OOomoo`2KOol001eoo`03001oogoo02ioo`0301moogoo
00Moo`03001l07`001]l0003001oogoo00Qoo`0301moogoo09aoo`007Goo00<007ooOol0;goo0P0O
1goo00<007`0O0006g`000<007ooOol01goo00<07gooOol0WGoo000MOol00`00Oomoo`0aOol00`0O
Oomoo`04Ool00`00O01l000KO0000`00Oomoo`06Ool00`0OOomoo`2NOol001eoo`8003=oo`807`Ao
o`03001l07`001]l0003001oogoo00Eoo`0301moogoo09moo`007Goo00<007ooOol0=7oo00D07goo
Oomoo`0001el0003001oogoo00Aoo`0301moogoo0:1oo`007Goo00<007ooOol0=Goo0P0O00=oo`00
O00077`000<007ooOol00Woo0P0OXgoo000MOol00`00Oomoo`0gOol00`0O001l000LO0001@00Oomo
ogoo01l0YGoo000MOol00`00Oomoo`0hOol201lLO0001000Oomoo`0OYWoo000MOol2000iOol00`00
O0007`0KO0000`00Ool07`2WOol001eoo`03001oogoo03Qoo`03001l07`000<07aQl00807jQoo`00
7Goo00<007ooOol0>7oo00<007`0O0000g`00P0O4g`00`0O00<007ooOol0Ygoo000MOol00`00Oomo
o`0hOol00`00O01l0005O00301l>O00201l3O0000`00Oomoo`2WOol001eoo`8003Uoo`03001l07`0
00Ql00@07`Il00@07`El0003001oogoo0:Moo`007Goo00<007ooOol0>7oo3`001P0O2P00ZGoo000M
Ool00`00Oomoo`3oOol1Ool001eoo`03001oogoo0?moo`5oo`007Goo00<007ooOol0ogoo0Goo003o
OolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5o
o`00?7oo1P001Woo0`000goo100017oo0`001Goo0`000goo100000=oo`0000000P000Woo0P001Goo
2P0000=oo`0000000P000Woo100017oo10000goo10005goo1`000goo0P000Woo1@0017oo1@001Woo
100027oo0P001Goo0`00=goo000nOol20007Ool20002Ool01000Oomoogoo0P0017oo0P000Woo00@0
07ooOomoo`80009oo`04001oogooOol20003Ool20002Ool200000goo001oo`05Ool20005Ool20000
0goo00000004Ool20004Ool20002Ool20003Ool2000IOol60003Ool20002Ool20003Ool20002Ool2
0003Ool20003Ool20002Ool20007Ool20003Ool20002Ool2000fOol003ioo`8000Ioo`8000Aoo`03
001oogoo008000=oo`8000Aoo`04001oo`000004Ool00`00Oomoo`020003Ool20002Ool20008Ool2
0006Ool01000Ool0000017oo0P000goo0P0017oo0P000Woo0P002Goo2@0027oo00<007ooOol00Woo
00<007ooOol02Woo00<007ooOol01Woo00D007ooOomoo`0000Aoo`03001oogoo00Eoo`8000=oo`03
001oogoo009oo`8003Eoo`00?Woo0P001Woo0P001goo0P000goo0P001Woo0P001goo0P000goo0P00
0Woo0P0027oo0P0027oo0P0017oo0P000goo0P0017oo0P000Woo0P006Woo0P0047oo0P001goo0P00
00=oo`00000017oo0P0000=oo`0000002@0017oo0P00=Goo000nOol20006Ool20007Ool20003Ool2
0006Ool20007Ool20003Ool20002Ool20008Ool20004Ool01000Oomoogoo0P0017oo0P000goo0P00
17oo0P000Woo0P006goo00<007ooOol03Woo0P001goo0P0000=oo`00000017oo0P0000=oo`00Ool0
0goo0P000Woo0P0017oo0P00=Goo000nOol60002Ool70002Ool20003Ool20004Ool00`00Ool00006
0002Ool20003Ool20002Ool20008Ool20004Ool01000Oomoogoo0P0017oo0P000goo0P0017oo0P00
0Woo0P0077oo00<007ooOol037oo0`001Woo0`0000=oo`00000017oo0P000Woo00@007ooOomoo`80
009oo`8000Aoo`8003Eoo`00?Woo0P000goo0P000Woo00@007ooOomoo`800003Ool0000000@00003
Ool00000009oo`80009oo`04001oogooOol200000goo000000020002Ool20002Ool20008Ool70002
Ool<00000goo00000002Ool20002Ool60006Ool9000:Ool2000;Ool40005Ool40002Ool20004Ool2
0003Ool00`00Oomoo`020002Ool30002Ool2000fOol003ioo`8000Aoo`80009oo`@000Aoo`04001o
o`000002Ool40004Ool40004Ool00`00Ool000020002Ool50006Ool20004Ool00`00Oomoo`02Ool0
1000Ool000000Woo00@007oo0000009oo`@000Eoo`04001oo`00000JOol00`00Oomoo`06Ool60003
Ool60003Ool20004Ool20003Ool00`00Oomoo`020002Ool2000017oo00000000=goo000nOol20004
Ool2000XOol20008Ool20004Ool00`00Oomoo`0eOol20008Ool40005Ool40004Ool20004Ool20004
Ool01000Ool000000goo0P00>Woo000nOol20004Ool2000YOol00`00Oomoo`06Ool2000gOol00`00
Oomoo`02Ool20008Ool00`00Oomoo`06Ool00`00Oomoo`05Ool20004Ool20005Ool30003Ool2000j
Ool003ioo`8000Aoo`80039oo`8000Eoo`03001oogoo02moo`80009oo`<000Uoo`03001oogoo00Io
o`03001oogoo00Eoo`03001oogoo009oo`03001oogoo00Aoo`<000Aoo`8003Uoo`00?Woo0P000goo
0P00<goo0P001Goo00<007ooOol0<7oo1@002Woo1@0017oo1@000goo0P000Woo0P001goo0P001Goo
0P00>7oo000lOol8000bOol:000cOol3000;Ool60003Ool60003Ool40008Ool20007Ool3000eOol0
0?moob5oo`00ogoo8Goo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.783823, -4.98036, 
  0.0265065, 0.0452841}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.151576 0.44187 0.0887232 [
[.17539 .42937 -3 -9 ]
[.17539 .42937 3 0 ]
[.32696 .42937 -3 -9 ]
[.32696 .42937 3 0 ]
[.47854 .42937 -3 -9 ]
[.47854 .42937 3 0 ]
[.63011 .42937 -3 -9 ]
[.63011 .42937 3 0 ]
[.78169 .42937 -3 -9 ]
[.78169 .42937 3 0 ]
[.93327 .42937 -3 -9 ]
[.93327 .42937 3 0 ]
[.01131 .08698 -12 -4.5 ]
[.01131 .08698 0 4.5 ]
[.01131 .1757 -12 -4.5 ]
[.01131 .1757 0 4.5 ]
[.01131 .26442 -12 -4.5 ]
[.01131 .26442 0 4.5 ]
[.01131 .35315 -12 -4.5 ]
[.01131 .35315 0 4.5 ]
[.01131 .53059 -6 -4.5 ]
[.01131 .53059 0 4.5 ]
[.5 .63053 -89.5938 0 ]
[.5 .63053 89.5938 20 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.17539 .44187 m
.17539 .44812 L
s
[(1)] .17539 .42937 0 1 Mshowa
.32696 .44187 m
.32696 .44812 L
s
[(2)] .32696 .42937 0 1 Mshowa
.47854 .44187 m
.47854 .44812 L
s
[(3)] .47854 .42937 0 1 Mshowa
.63011 .44187 m
.63011 .44812 L
s
[(4)] .63011 .42937 0 1 Mshowa
.78169 .44187 m
.78169 .44812 L
s
[(5)] .78169 .42937 0 1 Mshowa
.93327 .44187 m
.93327 .44812 L
s
[(6)] .93327 .42937 0 1 Mshowa
.125 Mabswid
.05412 .44187 m
.05412 .44562 L
s
.08444 .44187 m
.08444 .44562 L
s
.11476 .44187 m
.11476 .44562 L
s
.14507 .44187 m
.14507 .44562 L
s
.2057 .44187 m
.2057 .44562 L
s
.23602 .44187 m
.23602 .44562 L
s
.26633 .44187 m
.26633 .44562 L
s
.29665 .44187 m
.29665 .44562 L
s
.35728 .44187 m
.35728 .44562 L
s
.38759 .44187 m
.38759 .44562 L
s
.41791 .44187 m
.41791 .44562 L
s
.44822 .44187 m
.44822 .44562 L
s
.50885 .44187 m
.50885 .44562 L
s
.53917 .44187 m
.53917 .44562 L
s
.56948 .44187 m
.56948 .44562 L
s
.5998 .44187 m
.5998 .44562 L
s
.66043 .44187 m
.66043 .44562 L
s
.69074 .44187 m
.69074 .44562 L
s
.72106 .44187 m
.72106 .44562 L
s
.75137 .44187 m
.75137 .44562 L
s
.81201 .44187 m
.81201 .44562 L
s
.84232 .44187 m
.84232 .44562 L
s
.87264 .44187 m
.87264 .44562 L
s
.90295 .44187 m
.90295 .44562 L
s
.96358 .44187 m
.96358 .44562 L
s
.9939 .44187 m
.9939 .44562 L
s
.25 Mabswid
0 .44187 m
1 .44187 L
s
.02381 .08698 m
.03006 .08698 L
s
[(-4)] .01131 .08698 1 0 Mshowa
.02381 .1757 m
.03006 .1757 L
s
[(-3)] .01131 .1757 1 0 Mshowa
.02381 .26442 m
.03006 .26442 L
s
[(-2)] .01131 .26442 1 0 Mshowa
.02381 .35315 m
.03006 .35315 L
s
[(-1)] .01131 .35315 1 0 Mshowa
.02381 .53059 m
.03006 .53059 L
s
[(1)] .01131 .53059 1 0 Mshowa
.125 Mabswid
.02381 .016 m
.02756 .016 L
s
.02381 .03374 m
.02756 .03374 L
s
.02381 .05149 m
.02756 .05149 L
s
.02381 .06923 m
.02756 .06923 L
s
.02381 .10472 m
.02756 .10472 L
s
.02381 .12247 m
.02756 .12247 L
s
.02381 .14021 m
.02756 .14021 L
s
.02381 .15796 m
.02756 .15796 L
s
.02381 .19344 m
.02756 .19344 L
s
.02381 .21119 m
.02756 .21119 L
s
.02381 .22893 m
.02756 .22893 L
s
.02381 .24668 m
.02756 .24668 L
s
.02381 .28217 m
.02756 .28217 L
s
.02381 .29991 m
.02756 .29991 L
s
.02381 .31766 m
.02756 .31766 L
s
.02381 .3354 m
.02756 .3354 L
s
.02381 .37089 m
.02756 .37089 L
s
.02381 .38864 m
.02756 .38864 L
s
.02381 .40638 m
.02756 .40638 L
s
.02381 .42413 m
.02756 .42413 L
s
.02381 .45961 m
.02756 .45961 L
s
.02381 .47736 m
.02756 .47736 L
s
.02381 .4951 m
.02756 .4951 L
s
.02381 .51285 m
.02756 .51285 L
s
.02381 .54834 m
.02756 .54834 L
s
.02381 .56608 m
.02756 .56608 L
s
.02381 .58383 m
.02756 .58383 L
s
.02381 .60157 m
.02756 .60157 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -150.594 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 24.000000 moveto
 558.000000 24.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 24.000000 lineto
closepath
clip newpath
63.000000 19.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 18.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 19.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 18.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Percent) show
121.250000 19.000000 moveto
(Error) show
163.625000 19.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 18.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(=) show
179.687500 19.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 18.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2.01845) show
238.187500 19.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 18.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
0 0 1 r
.007 w
.02381 .44187 m
.02499 .44188 L
.02605 .44189 L
.02729 .44192 L
.02846 .44195 L
.03053 .44204 L
.03279 .44218 L
.03527 .44238 L
.0379 .44264 L
.04262 .44323 L
.04749 .44403 L
.05205 .44493 L
.06244 .44757 L
.07305 .45107 L
.08274 .45495 L
.10458 .46589 L
.14429 .4922 L
.18248 .52229 L
.22313 .55474 L
.26226 .58144 L
.27254 .5871 L
.28367 .59241 L
.29328 .59624 L
.29838 .59795 L
.30384 .59955 L
.30923 .60086 L
.31415 .60182 L
.31652 .6022 L
.31909 .60255 L
.32151 .60282 L
.32378 .60303 L
.32509 .60312 L
.3263 .60319 L
.32764 .60325 L
.32834 .60327 L
.32908 .60329 L
.32976 .60331 L
.33048 .60332 L
.33177 .60332 L
.33257 .60331 L
.33332 .6033 L
.33399 .60328 L
.33472 .60326 L
.33594 .60321 L
.33728 .60313 L
.33999 .60292 L
.34249 .60266 L
.34484 .60235 L
.34982 .60149 L
.35525 .60023 L
Mistroke
.36513 .59709 L
.37475 .59294 L
.38367 .58812 L
.40423 .57339 L
.42285 .55569 L
.46297 .50405 L
.50157 .43897 L
.54262 .35759 L
.58216 .27326 L
.62019 .19318 L
.66067 .11668 L
.69963 .05896 L
.70983 .04728 L
.72091 .03645 L
.73048 .02875 L
.73557 .02531 L
.74104 .02213 L
.74638 .01956 L
.75126 .01767 L
.75594 .01629 L
.75829 .01576 L
.76085 .0153 L
.76227 .01511 L
.76362 .01496 L
.76482 .01485 L
.76612 .01477 L
.7668 .01474 L
.76755 .01472 L
.76833 .01472 L
.76905 .01472 L
.77035 .01475 L
.77108 .01478 L
.77175 .01482 L
.77304 .01492 L
.77424 .01504 L
.77695 .01543 L
.77933 .0159 L
.78187 .01653 L
.78675 .0181 L
.79123 .01999 L
.80132 .02578 L
.81022 .03269 L
.81959 .04179 L
.83931 .06705 L
.85767 .09794 L
.89668 .18599 L
.93815 .30895 L
.97619 .44187 L
Mfstroke
1 0 0 r
.02381 .44187 m
.12963 .44187 L
.12963 .45246 L
.02381 .45246 L
F
.12963 .44187 m
.23545 .44187 L
.23545 .52233 L
.12963 .52233 L
F
.23545 .44187 m
.34127 .44187 L
.34127 .59437 L
.23545 .59437 L
F
.34127 .44187 m
.44709 .44187 L
.44709 .58122 L
.34127 .58122 L
F
.44709 .44187 m
.55291 .44187 L
.55291 .44187 L
.44709 .44187 L
F
.55291 .44187 m
.65873 .44187 L
.65873 .22289 L
.55291 .22289 L
F
.65873 .44187 m
.76455 .44187 L
.76455 .04537 L
.65873 .04537 L
F
.76455 .44187 m
.87037 .44187 L
.87037 .03955 L
.76455 .03955 L
F
.87037 .44187 m
.97619 .44187 L
.97619 .2618 L
.87037 .2618 L
F
0 g
.5 Mabswid
.02381 .44187 m
.02381 .45246 L
s
.12963 .44187 m
.12963 .45246 L
s
.02381 .45246 m
.12963 .45246 L
s
.12963 .44187 m
.12963 .52233 L
s
.23545 .44187 m
.23545 .52233 L
s
.12963 .52233 m
.23545 .52233 L
s
.23545 .44187 m
.23545 .59437 L
s
.34127 .44187 m
.34127 .59437 L
s
.23545 .59437 m
.34127 .59437 L
s
.34127 .44187 m
.34127 .58122 L
s
.44709 .44187 m
.44709 .58122 L
s
.34127 .58122 m
.44709 .58122 L
s
.44709 .44187 m
.44709 .44187 L
s
.55291 .44187 m
.55291 .44187 L
s
.44709 .44187 m
.55291 .44187 L
s
.55291 .44187 m
.55291 .22289 L
s
.65873 .44187 m
.65873 .22289 L
s
.55291 .22289 m
.65873 .22289 L
s
.65873 .44187 m
.65873 .04537 L
s
.76455 .44187 m
.76455 .04537 L
s
.65873 .04537 m
.76455 .04537 L
s
.76455 .44187 m
.76455 .03955 L
s
.87037 .44187 m
.87037 .03955 L
s
.76455 .03955 m
.87037 .03955 L
s
.87037 .44187 m
.87037 .2618 L
s
.97619 .44187 m
.97619 .2618 L
s
.87037 .2618 m
.97619 .2618 L
s
0 0 1 r
.007 w
.02381 .44187 m
.02499 .44188 L
.02605 .44189 L
.02729 .44192 L
.02846 .44195 L
.03053 .44204 L
.03279 .44218 L
.03527 .44238 L
.0379 .44264 L
.04262 .44323 L
.04749 .44403 L
.05205 .44493 L
.06244 .44757 L
.07305 .45107 L
.08274 .45495 L
.10458 .46589 L
.14429 .4922 L
.18248 .52229 L
.22313 .55474 L
.26226 .58144 L
.27254 .5871 L
.28367 .59241 L
.29328 .59624 L
.29838 .59795 L
.30384 .59955 L
.30923 .60086 L
.31415 .60182 L
.31652 .6022 L
.31909 .60255 L
.32151 .60282 L
.32378 .60303 L
.32509 .60312 L
.3263 .60319 L
.32764 .60325 L
.32834 .60327 L
.32908 .60329 L
.32976 .60331 L
.33048 .60332 L
.33177 .60332 L
.33257 .60331 L
.33332 .6033 L
.33399 .60328 L
.33472 .60326 L
.33594 .60321 L
.33728 .60313 L
.33999 .60292 L
.34249 .60266 L
.34484 .60235 L
.34982 .60149 L
.35525 .60023 L
Mistroke
.36513 .59709 L
.37475 .59294 L
.38367 .58812 L
.40423 .57339 L
.42285 .55569 L
.46297 .50405 L
.50157 .43897 L
.54262 .35759 L
.58216 .27326 L
.62019 .19318 L
.66067 .11668 L
.69963 .05896 L
.70983 .04728 L
.72091 .03645 L
.73048 .02875 L
.73557 .02531 L
.74104 .02213 L
.74638 .01956 L
.75126 .01767 L
.75594 .01629 L
.75829 .01576 L
.76085 .0153 L
.76227 .01511 L
.76362 .01496 L
.76482 .01485 L
.76612 .01477 L
.7668 .01474 L
.76755 .01472 L
.76833 .01472 L
.76905 .01472 L
.77035 .01475 L
.77108 .01478 L
.77175 .01482 L
.77304 .01492 L
.77424 .01504 L
.77695 .01543 L
.77933 .0159 L
.78187 .01653 L
.78675 .0181 L
.79123 .01999 L
.80132 .02578 L
.81022 .03269 L
.81959 .04179 L
.83931 .06705 L
.85767 .09794 L
.89668 .18599 L
.93815 .30895 L
.97619 .44187 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00O7Goo00<007ooOol0
ogoo0Goo000MOol00`00Oomoo`3oOol1Ool001eoo`03001oogoo0?moo`5oo`007Goo00<007ooOol0
]7oo1P0OAWoo000MOol2002bOol301l5Ool301m4Ool001eoo`03001oogoo0:moo`807`]oo`<07d5o
o`007Goo00<007ooOol0[Woo00<07gooOol03Woo00<07gooOol0?Woo000MOol00`00Oomoo`2]Ool0
0`0OOomoo`0@Ool00`0OOomoo`0mOol001eoo`800:eoo`0301moogoo019oo`0301moogoo03aoo`00
7Goo00<007ooOol0ZWoo0P0O2Goo3@0000<07`0000003000;goo000MOol00`00Oomoo`2YOol00`0O
Oomoo`09Ool00`00O01l000;O0000`0OO01l000:O0000`00Oomoo`0]Ool001eoo`03001oogoo09]o
o`d0000301l0000000/000el000301ml07`000Yl0003001oogoo02eoo`007Goo0P00W7oo00<007`0
O0002G`000<07g`0O0002g`000<007`0O00037`000<07g`0O0002G`000<007ooOol0;Goo000MOol0
0`00Oomoo`2KOol00`00O01l0008O0000`0OO01l000<O0000`00O01l000=O0000`0OO01l0008O000
0`00Oomoo`0]Ool001eoo`03001oogoo09]oo`03001l07`000Ml000301ml07`000el0003001l07`0
00il000301ml07`000Ml0003001oogoo02eoo`007Goo00<007ooOol0Vgoo00<007`0O0001g`000<0
7g`0O0003G`000<007`0O0003g`000<07g`0O0001W`000<007ooOol0;Goo000MOol00`00Oomoo`2K
Ool00`00O01l0006O0000`0OO01l000>O0000`00O01l000@O0000`0OO01l0005O0000`00Oomoo`0]
Ool001eoo`8009aoo`03001l07`000El000301ml07`000ml0003001l07`0011l000301ml07`000El
0003001oogoo02eoo`007Goo00<007ooOol0Vgoo00<007`0O0001G`000<07g`0O0003g`000<007`0
O0004G`000<07g`0O00017`000<007ooOol0;Goo000FOol30004Ool00`00Oomoo`2KOol00`00O01l
0004O0000`0OO01l000@O0000`00O01l000BO0000`0OO01l0003O0000`00Oomoo`0]Ool001Moo`03
001oogoo00=oo`03001oogoo09]oo`03001l07`000Al000301ml07`0011l0003001l07`0019l0003
01ml07`000=l0003001oogoo02eoo`003goo1@0000=oo`0000000P0017oo0`00Vgoo00<007`0O000
0g`000<07g`0O0004G`000<007`0O0004g`000<07g`0O0000W`000<007ooOol0;Goo000EOol00`00
Ool00005Ool00`00Oomoo`2KOol00`00O01l0002O0000`0OO01l000BO0000`00O01l000CO0000`0O
O01l0002O0000`00Oomoo`0]Ool001Eoo`03001oo`0000Eoo`03001oogoo09]oo`03001l07`0009l
000301ml07`0019l0003001l07`001Al000501ml07`0O000000_Ool001Ioo`8000Eoo`03001oogoo
09]oo`05001l07`0O0007`0EO0000`00O01l000EO000100OO01l0000;goo000MOol00`00Oomoo`2K
Ool01@00O01l07`001l05G`000<007`0O0005G`000@07g`0O00002moo`007Goo0P00W7oo00@007`0
O0007aIl0003001l07`001Il000301ml000002moo`007Goo00<007ooOol0Vgoo00<007`001l05g`0
00<007`0O0005W`000<07g`00000;goo000MOol00`00Oomoo`2KOol00`00O0007`0GO0000`00O01l
000FO0000`0OO000000_Ool001eoo`03001oogoo09]oo`0300007g`001Ml0003001l07`001Ml0003
01l007oo02ioo`007Goo0P00W7oo00<0000OO0005g`000<007`0O0005g`000<07`00Ool0;Woo000M
Ool00`00Oomoo`2KOol00`0OO01l000GO0000`00O01l000HO0000`0OOomoo`0]Ool001eoo`03001o
ogoo09]oo`0301ml07`001Ml0003001l07`001Ql000301moogoo02eoo`007Goo00<007ooOol0VWoo
00<07`00O00067`000<007`0O00067`000<07gooOol0;Goo000MOol2002KOol00`0O001l000HO000
0`00O01l000HO0000`0001moo`0]Ool001eoo`03001oogoo09Uoo`0301moo`0001Ul0003001l07`0
01Ql000300007goo02eoo`007Goo00<007ooOol0VGoo00<07goo00006G`000<007`0O00067`000<0
07oo01l0;Goo000MOol00`00Oomoo`2HOol0100OOomoo`006G`000<007`0O00067`000<007oo01l0
;Goo000MOol00`00Oomoo`2HOol0100OOomoo`006G`000<007`0O00067`000@007ooOol07baoo`00
7Goo0P00V7oo00D07gooOomoo`0001Ul0003001l07`001Ql0004001oogoo01l/Ool001eoo`03001o
ogoo09Ioo`0301moogoo009oo`03001l07`001Ml0003001l07`001Ql0004001oogoo01l/Ool001Eo
o`<000Eoo`03001oogoo09Ioo`0301moogoo009oo`03001l07`001Ml0003001l07`001Ql0005001o
ogooOol07`0[Ool001Qoo`03001oogoo009oo`03001oogoo09Eoo`0301moogoo00=oo`03001l07`0
01Ml0003001l07`001Ql0005001oogooOol07`0[Ool000moo`D000Aoo`03001oogoo009oo`<009Eo
o`0301moogoo00=oo`03001l07`001Ml0003001l07`001Ql0003001oogoo009oo`0301moogoo02Qo
o`005Woo0P001Goo00<007ooOol0U7oo00<07gooOol017oo00<007`0O0005g`000<007`0O00067`0
00<007ooOol00Woo00<07gooOol0:7oo000HOol00`00Oomoo`02Ool00`00Oomoo`2DOol00`0OOomo
o`04Ool00`00O01l000GO0000`00O01l000HO0000`00Oomoo`02Ool00`0OOomoo`0XOol001Eoo`<0
00Eoo`03001oogoo09=oo`0301moogoo00Eoo`03001l07`001Ml0003001l07`001Ql0003001oogoo
00=oo`0301moogoo02Moo`007Goo00<007ooOol0Tgoo00<07gooOol01Goo00<007`0O0005g`000<0
07`0O00067`000<007ooOol00goo00<07gooOol09goo000MOol2002COol00`0OOomoo`06Ool00`00
O01l000GO0000`00O01l000HO0000`00Oomoo`04Ool00`0OOomoo`0VOol001eoo`03001oogoo099o
o`0301moogoo00Ioo`03001l07`001Ml0003001l07`001Ql0003001oogoo00Aoo`0301moogoo02Io
o`007Goo00<007ooOol0TGoo00<07gooOol01goo00<007`0O0005g`000<007`0O00067`000<007oo
Ool017oo00<07gooOol09Woo000MOol00`00Oomoo`2AOol00`0OOomoo`07Ool00`00O01l000GO000
0`00O01l000HO0000`00Oomoo`05Ool00`0OOomoo`0UOol001eoo`80095oo`0301moogoo00Qoo`03
001l07`001Ml0003001l07`001Ql0003001oogoo00Eoo`0301moogoo02Eoo`007Goo00<007ooOol0
T7oo00<07gooOol027oo00<007`0O0005g`000<007`0O00067`000<007ooOol01Goo00<07gooOol0
9Goo000MOol00`00Oomoo`2?Ool00`0OOomoo`09Ool00`00O01l000GO0000`00O01l000HO0000`00
Oomoo`06Ool00`0OOomoo`0TOol001eoo`03001oogoo085oo`h0000301l0000000X001Ul0003001l
07`001Ql0003001oogoo00Ioo`0301moogoo02Aoo`007Goo00<007ooOol0PGoo00<007`0O0002W`0
00<07g`0O0002W`000<007`0O0005g`000<007`0O00067`000<007ooOol01Woo00<07gooOol097oo
000MOol20022Ool00`00O01l000:O0000`0OO01l000:O0000`00O01l000GO0000`00O01l000HO000
0`00Oomoo`07Ool00`0OOomoo`0SOol001eoo`03001oogoo085oo`03001l07`000Ul000301ml07`0
00]l0003001l07`001Ml0003001l07`001Ql0003001oogoo00Moo`0301moogoo02=oo`007Goo00<0
07ooOol0PGoo00<007`0O0002G`000<07g`0O0002g`000<007`0O0005g`000<007`0O00067`000<0
07ooOol027oo00<07gooOol08Woo000MOol00`00Oomoo`21Ool00`00O01l0008O0000`0OO01l000<
O0000`00O01l000GO0000`00O01l000HO0000`00Oomoo`08Ool00`0OOomoo`0ROol001eoo`80089o
o`03001l07`000Ql000301ml07`000al0003001l07`001Ml0003001l07`001Ql0003001oogoo00Qo
o`0301moogoo029oo`007Goo00<007ooOol0PGoo00<007`0O0001g`000<07g`0O0003G`000<007`0
O0005g`000<007`0O00067`000<007ooOol02Goo00<07gooOol08Goo000EOol40004Ool00`00Oomo
o`21Ool00`00O01l0007O0000`0OO01l000=O0000`00O01l000GO0000`00O01l000HO0000`00Oomo
o`09Ool00`0OOomoo`0QOol001Ioo`03001oogoo00Aoo`03001oogoo085oo`03001l07`000Il0003
01ml07`000il0003001l07`001Ml0003001l07`001Ql0003001oogoo00Uoo`0301moogoo025oo`00
3goo1@000goo00<007ooOol00goo0`00PGoo00<007`0O0001W`000<07g`0O0003W`000<007`0O000
5g`000<007`0O00067`03@0000<07`0000002`005Goo000HOol00`00Oomoo`02Ool00`00Oomoo`21
Ool00`00O01l0005O0000`0OO01l000?O0000`00O01l000GO0000`00O01l000HO0000`00O01l000:
O0000`0OO01l000:O0000`00Oomoo`0COol001Eoo`04001oogoo0004Ool00`00Oomoo`21Ool00`00
O01l0005O0000`0OO01l000?O0000`00O01l000GO0000`00O01l000HO0000`00O01l000;O0000`0O
O01l0009O0000`00Oomoo`0COol001Ioo`8000Eoo`03001oogoo085oo`03001l07`000Al000301ml
07`0011l0003001l07`001Ml0003001l07`001Ql0003001l07`000]l000301ml07`000Ul0003001o
ogoo01=oo`007Goo00<007ooOol0PGoo00<007`0O00017`000<07g`0O00047`000<007`0O0005g`0
00<007`0O00067`000<007`0O0002g`000<07g`0O0002G`000<007ooOol04goo000MOol20022Ool0
0`00O01l0003O0000`0OO01l000AO0000`00O01l000GO0000`00O01l000HO0000`00O01l000<O000
0`0OO01l0008O0000`00Oomoo`0COol001eoo`03001oogoo085oo`03001l07`000=l000301ml07`0
015l0003001l07`001Ml0003001l07`001Ql0003001l07`000al000301ml07`000Ql0003001oogoo
01=oo`007Goo00<007ooOol0PGoo00<007`0O0000W`000<07g`0O0004W`000<007`0O0005g`000<0
07`0O00067`000<007`0O00037`000<07g`0O00027`000<007ooOol04goo000MOol00`00Oomoo`21
Ool00`00O01l0002O0000`0OO01l000BO0000`00O01l000GO0000`00O01l000HO0000`00O01l000=
O0000`0OO01l0007O0000`00Oomoo`0COol001eoo`80089oo`05001l07`0O0007`0EO0000`00O01l
000GO0000`00O01l000HO0000`00O01l000=O0000`0OO01l0007O0000`00Oomoo`0COol001eoo`03
001oogoo085oo`05001l07`0O0007`0EO0000`00O01l000GO0000`00O01l000HO0000`00O01l000=
O0000`0OO01l0007O0000`00Oomoo`0COol001eoo`03001oogoo085oo`04001l07`001lFO0000`00
O01l000GO0000`00O01l000HO0000`00O01l000>O0000`0OO01l0006O0000`00Oomoo`0COol001eo
o`03001oogoo085oo`04001l07`001lFO0000`00O01l000GO0000`00O01l000HO0000`00O01l000>
O0000`0OO01l0006O0000`00Oomoo`0COol001eoo`03001oogoo085oo`03001l000O01Ml0003001l
07`001Ml0003001l07`001Ql0003001l07`000il000301ml07`000Il0003001oogoo01=oo`007Goo
0P00PWoo00<007`001l05g`000<007`0O0005g`000<007`0O00067`000<007`0O0003g`000<07g`0
O0001G`000<007ooOol04goo000MOol00`00Oomoo`21Ool00`00O0007`0GO0000`00O01l000GO000
0`00O01l000HO0000`00O01l000?O0000`0OO01l0005O0000`00Oomoo`0COol001eoo`03001oogoo
085oo`0300007g`001Ml0003001l07`001Ml0003001l07`001Ql0003001l07`000ml000301ml07`0
00El0003001oogoo01=oo`007Goo00<007ooOol0PGoo00<0000OO0005g`000<007`0O0005g`000<0
07`0O00067`000<007`0O0003g`000<07g`0O0001G`000<007ooOol04goo000MOol20022Ool00`0O
O01l000GO0000`00O01l000GO0000`00O01l000HO0000`00O01l000@O0000`0OO01l0004O0000`00
Oomoo`0COol001eoo`03001oogoo085oo`0301ml07`001Ml0003001l07`001Ml0003001l07`001Ql
0003001l07`0011l000301ml07`000Al0003001oogoo01=oo`005Goo0`001Goo00<007ooOol0P7oo
00<07`00O00067`000<007`0O0005g`000<007`0O00067`000<007`0O00047`000<07g`0O00017`0
00<007ooOol04goo000FOol00`00Oomoo`04Ool00`00Oomoo`20Ool00`0O001l000HO0000`00O01l
000GO0000`00O01l000HO0000`00O01l000AO0000`0OO01l0003O0000`00Oomoo`0COol000moo`D0
009oo`03001oogoo00Aoo`<007moo`0301moo`0001Ul0003001l07`001Ml0003001l07`001Ql0003
001l07`0015l000301ml07`000=l0003001oogoo01=oo`005Woo00<007ooOol017oo00<007ooOol0
Ogoo00<07goo00006G`000<007`0O0005g`000<007`0O00067`000<007`0O0004G`000<07g`0O000
0g`000<007ooOol04goo000FOol00`00Oomoo`04Ool00`00Oomoo`1nOol0100OOomoo`006G`000<0
07`0O0005g`000<007`0O00067`000<007`0O0004G`000<07g`0O0000g`000<007ooOol04goo000E
Ool20006Ool00`00Oomoo`1nOol0100OOomoo`006G`000<007`0O0005g`000<007`0O00067`000<0
07`0O0004W`000<07g`0O0000W`000<007ooOol04goo000MOol00`00Oomoo`1mOol01@0OOomoogoo
00006G`000<007`0O0005g`000<007`0O00067`000<007`0O0004W`000<07g`0O0000W`000<007oo
Ool04goo000MOol2001nOol01@0OOomoogoo00006G`000<007`0O0005g`000<007`0O00067`000<0
07`0O0004W`000<07g`0O0000W`000<007ooOol04goo000MOol00`00Oomoo`1lOol00`0OOomoo`02
Ool00`00O01l000GO0000`00O01l000GO0000`00O01l000HO0000`00O01l000BO0000`0OO01l0002
O0000`00Oomoo`0COol001eoo`03001oogoo07aoo`0301moogoo009oo`03001l07`001Ml0003001l
07`001Ml0003001l07`001Ql0003001l07`001=l000501ml07`0O000000EOol001eoo`03001oogoo
07]oo`0301moogoo00=oo`03001l07`001Ml0003001l07`001Ml0003001l07`001Ql0003001l07`0
01=l000501ml07`0O000000EOol001eoo`8007aoo`0301moogoo00=oo`03001l07`001Ml0003001l
07`001Ml0003001l07`001Ql0003001l07`001=l000501ml07`0O000000EOol001eoo`03001oogoo
07Yoo`0301moogoo00Aoo`03001l07`001Ml0003001l07`001Ml0003001l07`001Ql0003001l07`0
01=l000501ml07`0O000000EOol001eoo`03001oogoo07Yoo`0301moogoo00Aoo`03001l07`001Ml
0003001l07`001Ml0003001l07`001Ql0003001l07`001Al000401ml07`0000EOol001eoo`03001o
ogoo025oo`<002=oo`@0025oo`<000Yoo`0301moogoo00Eoo`03001l07`001Ml0003001l07`001Ml
0003001l07`001Ql0003001l07`001Al000401ml07`0000EOol001eoo`03001oogoo029oo`03001o
ogoo02=oo`03001oogoo02Aoo`03001oogoo00Moo`0301moogoo00Eoo`03001l07`001Ml0003001l
07`001Ml0003001l07`001Ql0003001l07`001Al000401ml07`0000EOol001eoo`8002=oo`03001o
ogoo02Aoo`03001oogoo02=oo`03001oogoo00Ioo`0301moogoo00Ioo`03001l07`001Ml0003001l
07`001Ml0003001l07`001Ql0003001l07`001Al000401ml07`0000EOol001eoo`03001oogoo029o
o`03001oogoo02Eoo`03001oogoo021oo`8000Uoo`0301moogoo00Ioo`03001l07`001Ml0003001l
07`001Ml0003001l07`001Ql0003001l07`001El000301ml000001Eoo`007Goo00<007ooOol08Woo
00<007ooOol08Woo00@007ooOol002Aoo`03001oogoo00Eoo`0301moogoo00Moo`03001l07`001Ml
0003001l07`001Ml0003001l07`001Ql0003001l07`001El000301ml000001Eoo`007Goo00<007oo
Ool08Goo0P009Goo0P008Woo0`0027oo00<07gooOol01goo00<007`0O0005g`000<007`0O0005g`0
00<007`0O00067`000<007`0O0005G`000<07g`000005Goo000MOol2001gOol00`0OOomoo`08Ool0
0`00O01l000GO0000`00O01l000GO0000`00O01l000HO0000`00O01l000FO0000`0O001oo`0DOol0
01eoo`03001oogoo07Ioo`0301moogoo00Qoo`03001l07`001Ml0003001l07`001Ml0003001l07`0
01Ql0003001l07`001Il000301l007oo01Aoo`007Goo00<007ooOol0MGoo00<07gooOol02Goo00<0
07`0O0005g`000<007`0O0005g`000<007`0O00067`000<007`0O0005W`000<07`00Ool057oo000M
Ool00`00Oomoo`1eOol00`0OOomoo`09Ool00`00O01l000GO0000`00O01l000GO0000`00O01l000H
O0000`00O01l000FO0000`0O001oo`0DOol001eoo`03001oogoo06Moo`03001oogoo00Yoo`0301mo
ogoo00Yoo`03001l07`001Ml0003001l07`001Ml0003001l07`001Ql0003001l07`001Ml000301mo
ogoo01=oo`005goo1P002P0OK@0000<07`0000002`006G`000<007`0O0005g`000<007`0O00067`0
00<007`0O0005g`000<07`00000010003goo000MOol00`00O01l0007O00201l>O0000`00O01l000H
O0000`00O01l000GO0000`00O01l000GO0000`00Oomoo`05Ool00`00Oomoo`02Ool00`0OOomoo`0N
Ool00`00Oomoo`0SOol00`00Oomoo`0ROol00`00Oomoo`0NOol001eoo``000<07``001Yl0003001l
07`001Ml0003001l07`001Ml0003001oogoo00Uoo`0301moogoo08]oo`007Goo00<007ooOol037oo
0P0O2Goo00<007`0O00067`000<007`0O0005g`000<007`0O0005g`000<007ooOol02Goo00<07goo
Ool0Rgoo000MOol2000?Ool201l7Ool00`00O01l000HO0000`00O01l000GO0000`00O01l000GO000
0`00Oomoo`08Ool00`0OOomoo`2<Ool001eoo`03001oogoo011oo`0301moogoo00Aoo`03001l07`0
01Ql0003001l07`001Ml0003001l07`001Ml0003001oogoo00Qoo`0301moogoo08aoo`007Goo00<0
07ooOol04Goo0P0O17oo00<007`0O00067`000<007`0O0005g`000<007`0O0005g`000<007ooOol0
1goo00<07gooOol0SGoo000MOol00`00Oomoo`0COol201l2Ool00`00O01l000HO0000`00O01l000G
O0000`00O01l000GO0000`00Oomoo`06Ool00`0OOomoo`2>Ool001eoo`8001Ioo`0301moo`0001Yl
0003001l07`001Ml0003001l07`001Ml0003001oogoo00Ioo`0301moogoo08ioo`007Goo00<007oo
Ool05Woo0P0O6W`000<007`0O0005g`000<007`0O0005g`000<007ooOol01Goo00<07gooOol0Sgoo
000MOol00`00Oomoo`0GOol00`0001l07`0HO0000`00O01l000GO0000`00O01l000GO0000`00Oomo
o`04Ool00`0OOomoo`2@Ool001eoo`03001oogoo01Moo`04001l07`001lGO0000`00O01l000GO000
0`00O01l000GO0000`00Oomoo`04Ool00`0OOomoo`2@Ool001eoo`03001oogoo01Moo`04001l07`0
O00201lEO0000`00O01l000GO0000`00O01l000GO0000`00Oomoo`03Ool00`0OOomoo`2AOol001eo
o`8001Qoo`03001l07`000=l000301ml07`0019l0003001l07`001Ml0003001l07`001Ml0003001o
ogoo00=oo`0301moogoo095oo`007Goo00<007ooOol05goo00<007`0O00017`000<07g`0O0004G`0
00<007`0O0005g`000<007`0O0005g`000<007ooOol00Woo00<07gooOol0TWoo000MOol00`00Oomo
o`0GOol00`00O01l0005O0000`0OO01l000@O0000`00O01l000GO0000`00O01l000GO0001@00Oomo
ogoo01l0UGoo000MOol00`00Oomoo`0GOol00`00O01l0006O00201l@O0000`00O01l000GO0000`00
O01l000GO0001@00Oomoogoo01l0UGoo000MOol2000HOol00`00O01l0008O0000`0OO01l000=O000
0`00O01l000GO0000`00O01l000GO0001000Oomoo`0OUWoo000MOol00`00Oomoo`0GOol00`00O01l
0009O0000`0OO01l000<O0000`00O01l000GO0000`00O01l000GO0000`00Ool07`2GOol001eoo`03
001oogoo01Moo`03001l07`000Yl000301ml07`000]l0003001l07`001Ml0003001l07`001Ml0003
00007goo09Moo`005Goo0`001Goo00<007ooOol05goo3P000P0O30006G`000<007`0O0005g`000<0
000OOol0Ugoo000FOol00`00Oomoo`04Ool00`00Oomoo`0WOol00`0OOomoo`08Ool00`00O01l000G
O0000`00O01l000GO0000`0OOomoo`2GOol001Ioo`03001oogoo00Aoo`<002Qoo`0301moogoo00Mo
o`03001l07`001Ml0003001l07`001Il000301l007oo09Qoo`005Woo00<007ooOol017oo00<007oo
Ool0:Goo00<07gooOol01Woo00<007`0O0005g`000<007`0O0005G`000<07g`00000VGoo000FOol0
0`00Oomoo`04Ool00`00Oomoo`0ZOol201l6Ool00`00O01l000GO0000`00O01l000DO000100OO01l
0000VGoo000EOol20006Ool00`00Oomoo`0/Ool00`0OOomoo`03Ool00`00O01l000GO0000`00O01l
000DO000100OO01l0000VGoo000MOol2000^Ool00`0OOomoo`02Ool00`00O01l000GO0000`00O01l
000CO0001@0OO01l07`00000VGoo000MOol00`00Oomoo`0^Ool01@0OOomoogoo00006G`000<007`0
O0004W`000<07g`0O0000W`000<007ooOol0Ugoo000MOol00`00Oomoo`0_Ool201l00goo001l000H
O0000`00O01l000AO0000`0OO01l0003O0000`00Oomoo`2GOol001eoo`03001oogoo035oo`0301l0
07`001Ql0003001l07`0011l000301ml07`000Al0003001oogoo09Moo`007Goo0P00<goo0P0O67`0
00<007`0O0003g`000<07g`0O0001G`000<007ooOol0Ugoo000MOol00`00Oomoo`0bOol00`00O000
7`0GO0000`00O01l000>O0000`0OO01l0006O0000`00Oomoo`2GOol001eoo`03001oogoo039oo`03
001l07`000807aEl0003001l07`000al00807`Ul0003001oogoo09Moo`007Goo00<007ooOol0<Woo
00<007`0O0000W`000<07g`0O0004W`000<007`0O0002g`000<07g`0O0002G`000<007ooOol0Ugoo
000MOol00`00Oomoo`0bOol00`00O01l0003O00201lBO00=00000`0O0000000;002IOol001eoo`80
03=oo`03001l07`000El000301ml07`000ml0003001oogoo00Uoo`0301moogoo0:Eoo`007Goo00<0
07ooOol0<Woo00<007`0O0001W`00`0O3W`000<007ooOol01goo0P0OZ7oo000MOol00`00Oomoo`0b
Ool<000201l=0006Ool301nZOol001eoo`03001oogoo041oo`<07`ioo`807jeoo`007Goo0P00A7oo
100O1Woo100O[goo000MOol00`00Oomoo`17Ool601ncOol001eoo`03001oogoo0?moo`5oo`007Goo
00<007ooOol0ogoo0Goo000MOol00`00Oomoo`3oOol1Ool00?moob5oo`00ogoo8Goo003oOolQOol0
0?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo000lOol60006Ool30003Ool40004
Ool30005Ool30003Ool400000goo000000020002Ool20005Ool:00000goo000000020002Ool40004
Ool40003Ool4000GOol70003Ool20004Ool40004Ool60004Ool40008Ool20002Ool5000hOol003io
o`8000Moo`80009oo`04001oogooOol20004Ool20002Ool01000Oomoogoo0P000Woo00@007ooOomo
o`8000=oo`80009oo`800003Ool007oo00Eoo`8000Eoo`800003Ool0000000Aoo`8000Aoo`80009o
o`8000=oo`8001Uoo`H000=oo`8000=oo`80009oo`8000Eoo`8000Eoo`80009oo`8000Moo`80009o
o`8000=oo`8003Ioo`00?Woo0P001Woo0P0017oo00<007ooOol00P000goo0P0017oo00@007oo0000
00Aoo`03001oogoo008000=oo`80009oo`8000Qoo`8000Ioo`04001oo`000004Ool20003Ool20004
Ool20002Ool20009Ool90008Ool00`00Oomoo`02Ool00`00Oomoo`05Ool00`00Oomoo`02Ool00`00
Oomoo`03Ool20004Ool20004Ool20006Ool20008Ool00`00Oomoo`0dOol003ioo`8000Ioo`8000Mo
o`8000=oo`8000Ioo`8000Moo`8000=oo`80009oo`8000Qoo`8000Qoo`8000Aoo`8000=oo`8000Ao
o`80009oo`8001Yoo`8000Yoo`8000Aoo`8000Aoo`8000Aoo`8000Aoo`800003Ool0000000L000Io
o`8003Eoo`00?Woo0P001Woo0P001goo0P000goo0P001Woo0P001goo0P000goo0P000Woo0P0027oo
0P0017oo00@007ooOomoo`8000Aoo`8000=oo`8000Aoo`80009oo`8001]oo`03001oogoo00Qoo`80
00Aoo`8000Aoo`8000Aoo`8000=oo`<00003Ool007oo00=oo`8000Qoo`8003Eoo`00?Woo1P000Woo
1`000Woo0P000goo0P0017oo00<007oo00001P000Woo0P000goo0P000Woo0P0027oo0P0017oo00@0
07ooOomoo`8000Aoo`8000=oo`8000Aoo`80009oo`8001aoo`03001oogoo00Moo`8000Aoo`8000Ao
o`8000Eoo`800004Ool000000003Ool01000Oomoogoo0P001goo0`00=Goo000nOol20003Ool20002
Ool01000Oomoogoo0P0000=oo`000000100000=oo`0000000Woo0P000Woo00@007ooOomoo`800003
Ool000000080009oo`80009oo`8000Qoo`L0009oo``00003Ool00000009oo`80009oo`H000Ioo`T0
00Yoo`8000Qoo`8000Aoo`8000Aoo`8000Ioo`@000Eoo`03001oogoo008000Eoo`@003Ioo`00?Woo
0P0017oo0P000Woo100017oo00@007oo0000009oo`@000Aoo`@000Aoo`03001oo`000080009oo`D0
00Ioo`8000Aoo`03001oogoo009oo`04001oo`000002Ool01000Ool000000Woo10001Goo00@007oo
000001Yoo`03001oogoo00Ioo`8000Aoo`8000Aoo`8000Eoo`D000Eoo`03001oogoo0080009oo`H0
03Moo`00?Woo0P0017oo0P00:7oo0P0027oo0P0017oo00<007ooOol0=Goo0P001goo0P0017oo0P00
17oo0P001Goo0P000Woo0P001Goo00@007oo000000=oo`@003Qoo`00?Woo0P0017oo0P00:Goo00<0
07ooOol01Woo0P00=goo00<007ooOol00Woo0P001goo0P0017oo0P0017oo0P0017oo0P0017oo0P00
1Goo0`000goo00<007ooOol0>Goo000nOol20004Ool2000bOol20005Ool00`00Oomoo`0_Ool20002
Ool30008Ool00`00Oomoo`02Ool00`00Oomoo`03Ool20004Ool20004Ool20005Ool30004Ool00`00
Oomoo`0hOol003ioo`8000=oo`8003=oo`8000Eoo`03001oogoo031oo`D000Uoo`80009oo`8000=o
o`@000Eoo`80009oo`8000Moo`8000Aoo`D003Ioo`00?7oo2000<Woo2P00<goo0`002goo10001Woo
0P001Woo100027oo0P0017oo1P00=Goo003oOolQOol00?moob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.783823, -4.98036, 
  0.0265065, 0.0452841}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.151576 0.44187 0.0887232 [
[.17539 .42937 -3 -9 ]
[.17539 .42937 3 0 ]
[.32696 .42937 -3 -9 ]
[.32696 .42937 3 0 ]
[.47854 .42937 -3 -9 ]
[.47854 .42937 3 0 ]
[.63011 .42937 -3 -9 ]
[.63011 .42937 3 0 ]
[.78169 .42937 -3 -9 ]
[.78169 .42937 3 0 ]
[.93327 .42937 -3 -9 ]
[.93327 .42937 3 0 ]
[.01131 .08698 -12 -4.5 ]
[.01131 .08698 0 4.5 ]
[.01131 .1757 -12 -4.5 ]
[.01131 .1757 0 4.5 ]
[.01131 .26442 -12 -4.5 ]
[.01131 .26442 0 4.5 ]
[.01131 .35315 -12 -4.5 ]
[.01131 .35315 0 4.5 ]
[.01131 .53059 -6 -4.5 ]
[.01131 .53059 0 4.5 ]
[.5 .63053 -89.5938 0 ]
[.5 .63053 89.5938 20 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.17539 .44187 m
.17539 .44812 L
s
[(1)] .17539 .42937 0 1 Mshowa
.32696 .44187 m
.32696 .44812 L
s
[(2)] .32696 .42937 0 1 Mshowa
.47854 .44187 m
.47854 .44812 L
s
[(3)] .47854 .42937 0 1 Mshowa
.63011 .44187 m
.63011 .44812 L
s
[(4)] .63011 .42937 0 1 Mshowa
.78169 .44187 m
.78169 .44812 L
s
[(5)] .78169 .42937 0 1 Mshowa
.93327 .44187 m
.93327 .44812 L
s
[(6)] .93327 .42937 0 1 Mshowa
.125 Mabswid
.05412 .44187 m
.05412 .44562 L
s
.08444 .44187 m
.08444 .44562 L
s
.11476 .44187 m
.11476 .44562 L
s
.14507 .44187 m
.14507 .44562 L
s
.2057 .44187 m
.2057 .44562 L
s
.23602 .44187 m
.23602 .44562 L
s
.26633 .44187 m
.26633 .44562 L
s
.29665 .44187 m
.29665 .44562 L
s
.35728 .44187 m
.35728 .44562 L
s
.38759 .44187 m
.38759 .44562 L
s
.41791 .44187 m
.41791 .44562 L
s
.44822 .44187 m
.44822 .44562 L
s
.50885 .44187 m
.50885 .44562 L
s
.53917 .44187 m
.53917 .44562 L
s
.56948 .44187 m
.56948 .44562 L
s
.5998 .44187 m
.5998 .44562 L
s
.66043 .44187 m
.66043 .44562 L
s
.69074 .44187 m
.69074 .44562 L
s
.72106 .44187 m
.72106 .44562 L
s
.75137 .44187 m
.75137 .44562 L
s
.81201 .44187 m
.81201 .44562 L
s
.84232 .44187 m
.84232 .44562 L
s
.87264 .44187 m
.87264 .44562 L
s
.90295 .44187 m
.90295 .44562 L
s
.96358 .44187 m
.96358 .44562 L
s
.9939 .44187 m
.9939 .44562 L
s
.25 Mabswid
0 .44187 m
1 .44187 L
s
.02381 .08698 m
.03006 .08698 L
s
[(-4)] .01131 .08698 1 0 Mshowa
.02381 .1757 m
.03006 .1757 L
s
[(-3)] .01131 .1757 1 0 Mshowa
.02381 .26442 m
.03006 .26442 L
s
[(-2)] .01131 .26442 1 0 Mshowa
.02381 .35315 m
.03006 .35315 L
s
[(-1)] .01131 .35315 1 0 Mshowa
.02381 .53059 m
.03006 .53059 L
s
[(1)] .01131 .53059 1 0 Mshowa
.125 Mabswid
.02381 .016 m
.02756 .016 L
s
.02381 .03374 m
.02756 .03374 L
s
.02381 .05149 m
.02756 .05149 L
s
.02381 .06923 m
.02756 .06923 L
s
.02381 .10472 m
.02756 .10472 L
s
.02381 .12247 m
.02756 .12247 L
s
.02381 .14021 m
.02756 .14021 L
s
.02381 .15796 m
.02756 .15796 L
s
.02381 .19344 m
.02756 .19344 L
s
.02381 .21119 m
.02756 .21119 L
s
.02381 .22893 m
.02756 .22893 L
s
.02381 .24668 m
.02756 .24668 L
s
.02381 .28217 m
.02756 .28217 L
s
.02381 .29991 m
.02756 .29991 L
s
.02381 .31766 m
.02756 .31766 L
s
.02381 .3354 m
.02756 .3354 L
s
.02381 .37089 m
.02756 .37089 L
s
.02381 .38864 m
.02756 .38864 L
s
.02381 .40638 m
.02756 .40638 L
s
.02381 .42413 m
.02756 .42413 L
s
.02381 .45961 m
.02756 .45961 L
s
.02381 .47736 m
.02756 .47736 L
s
.02381 .4951 m
.02756 .4951 L
s
.02381 .51285 m
.02756 .51285 L
s
.02381 .54834 m
.02756 .54834 L
s
.02381 .56608 m
.02756 .56608 L
s
.02381 .58383 m
.02756 .58383 L
s
.02381 .60157 m
.02756 .60157 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -150.594 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 24.000000 moveto
 558.000000 24.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 24.000000 lineto
closepath
clip newpath
63.000000 19.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 18.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 19.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 18.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Percent) show
121.250000 19.000000 moveto
(Error) show
163.625000 19.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 18.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(=) show
179.687500 19.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 18.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1.63684) show
238.187500 19.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 18.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
0 0 1 r
.007 w
.02381 .44187 m
.02499 .44188 L
.02605 .44189 L
.02729 .44192 L
.02846 .44195 L
.03053 .44204 L
.03279 .44218 L
.03527 .44238 L
.0379 .44264 L
.04262 .44323 L
.04749 .44403 L
.05205 .44493 L
.06244 .44757 L
.07305 .45107 L
.08274 .45495 L
.10458 .46589 L
.14429 .4922 L
.18248 .52229 L
.22313 .55474 L
.26226 .58144 L
.27254 .5871 L
.28367 .59241 L
.29328 .59624 L
.29838 .59795 L
.30384 .59955 L
.30923 .60086 L
.31415 .60182 L
.31652 .6022 L
.31909 .60255 L
.32151 .60282 L
.32378 .60303 L
.32509 .60312 L
.3263 .60319 L
.32764 .60325 L
.32834 .60327 L
.32908 .60329 L
.32976 .60331 L
.33048 .60332 L
.33177 .60332 L
.33257 .60331 L
.33332 .6033 L
.33399 .60328 L
.33472 .60326 L
.33594 .60321 L
.33728 .60313 L
.33999 .60292 L
.34249 .60266 L
.34484 .60235 L
.34982 .60149 L
.35525 .60023 L
Mistroke
.36513 .59709 L
.37475 .59294 L
.38367 .58812 L
.40423 .57339 L
.42285 .55569 L
.46297 .50405 L
.50157 .43897 L
.54262 .35759 L
.58216 .27326 L
.62019 .19318 L
.66067 .11668 L
.69963 .05896 L
.70983 .04728 L
.72091 .03645 L
.73048 .02875 L
.73557 .02531 L
.74104 .02213 L
.74638 .01956 L
.75126 .01767 L
.75594 .01629 L
.75829 .01576 L
.76085 .0153 L
.76227 .01511 L
.76362 .01496 L
.76482 .01485 L
.76612 .01477 L
.7668 .01474 L
.76755 .01472 L
.76833 .01472 L
.76905 .01472 L
.77035 .01475 L
.77108 .01478 L
.77175 .01482 L
.77304 .01492 L
.77424 .01504 L
.77695 .01543 L
.77933 .0159 L
.78187 .01653 L
.78675 .0181 L
.79123 .01999 L
.80132 .02578 L
.81022 .03269 L
.81959 .04179 L
.83931 .06705 L
.85767 .09794 L
.89668 .18599 L
.93815 .30895 L
.97619 .44187 L
Mfstroke
1 0 0 r
.02381 .44187 m
.11905 .44187 L
.11905 .45048 L
.02381 .45048 L
F
.11905 .44187 m
.21429 .44187 L
.21429 .50952 L
.11905 .50952 L
F
.21429 .44187 m
.30952 .44187 L
.30952 .58124 L
.21429 .58124 L
F
.30952 .44187 m
.40476 .44187 L
.40476 .59972 L
.30952 .59972 L
F
.40476 .44187 m
.5 .44187 L
.5 .51939 L
.40476 .51939 L
F
.5 .44187 m
.59524 .44187 L
.59524 .34712 L
.5 .34712 L
F
.59524 .44187 m
.69048 .44187 L
.69048 .14872 L
.59524 .14872 L
F
.69048 .44187 m
.78571 .44187 L
.78571 .02377 L
.69048 .02377 L
F
.78571 .44187 m
.88095 .44187 L
.88095 .05852 L
.78571 .05852 L
F
.88095 .44187 m
.97619 .44187 L
.97619 .27822 L
.88095 .27822 L
F
0 g
.5 Mabswid
.02381 .44187 m
.02381 .45048 L
s
.11905 .44187 m
.11905 .45048 L
s
.02381 .45048 m
.11905 .45048 L
s
.11905 .44187 m
.11905 .50952 L
s
.21429 .44187 m
.21429 .50952 L
s
.11905 .50952 m
.21429 .50952 L
s
.21429 .44187 m
.21429 .58124 L
s
.30952 .44187 m
.30952 .58124 L
s
.21429 .58124 m
.30952 .58124 L
s
.30952 .44187 m
.30952 .59972 L
s
.40476 .44187 m
.40476 .59972 L
s
.30952 .59972 m
.40476 .59972 L
s
.40476 .44187 m
.40476 .51939 L
s
.5 .44187 m
.5 .51939 L
s
.40476 .51939 m
.5 .51939 L
s
.5 .44187 m
.5 .34712 L
s
.59524 .44187 m
.59524 .34712 L
s
.5 .34712 m
.59524 .34712 L
s
.59524 .44187 m
.59524 .14872 L
s
.69048 .44187 m
.69048 .14872 L
s
.59524 .14872 m
.69048 .14872 L
s
.69048 .44187 m
.69048 .02377 L
s
.78571 .44187 m
.78571 .02377 L
s
.69048 .02377 m
.78571 .02377 L
s
.78571 .44187 m
.78571 .05852 L
s
.88095 .44187 m
.88095 .05852 L
s
.78571 .05852 m
.88095 .05852 L
s
.88095 .44187 m
.88095 .27822 L
s
.97619 .44187 m
.97619 .27822 L
s
.88095 .27822 m
.97619 .27822 L
s
0 0 1 r
.007 w
.02381 .44187 m
.02499 .44188 L
.02605 .44189 L
.02729 .44192 L
.02846 .44195 L
.03053 .44204 L
.03279 .44218 L
.03527 .44238 L
.0379 .44264 L
.04262 .44323 L
.04749 .44403 L
.05205 .44493 L
.06244 .44757 L
.07305 .45107 L
.08274 .45495 L
.10458 .46589 L
.14429 .4922 L
.18248 .52229 L
.22313 .55474 L
.26226 .58144 L
.27254 .5871 L
.28367 .59241 L
.29328 .59624 L
.29838 .59795 L
.30384 .59955 L
.30923 .60086 L
.31415 .60182 L
.31652 .6022 L
.31909 .60255 L
.32151 .60282 L
.32378 .60303 L
.32509 .60312 L
.3263 .60319 L
.32764 .60325 L
.32834 .60327 L
.32908 .60329 L
.32976 .60331 L
.33048 .60332 L
.33177 .60332 L
.33257 .60331 L
.33332 .6033 L
.33399 .60328 L
.33472 .60326 L
.33594 .60321 L
.33728 .60313 L
.33999 .60292 L
.34249 .60266 L
.34484 .60235 L
.34982 .60149 L
.35525 .60023 L
Mistroke
.36513 .59709 L
.37475 .59294 L
.38367 .58812 L
.40423 .57339 L
.42285 .55569 L
.46297 .50405 L
.50157 .43897 L
.54262 .35759 L
.58216 .27326 L
.62019 .19318 L
.66067 .11668 L
.69963 .05896 L
.70983 .04728 L
.72091 .03645 L
.73048 .02875 L
.73557 .02531 L
.74104 .02213 L
.74638 .01956 L
.75126 .01767 L
.75594 .01629 L
.75829 .01576 L
.76085 .0153 L
.76227 .01511 L
.76362 .01496 L
.76482 .01485 L
.76612 .01477 L
.7668 .01474 L
.76755 .01472 L
.76833 .01472 L
.76905 .01472 L
.77035 .01475 L
.77108 .01478 L
.77175 .01482 L
.77304 .01492 L
.77424 .01504 L
.77695 .01543 L
.77933 .0159 L
.78187 .01653 L
.78675 .0181 L
.79123 .01999 L
.80132 .02578 L
.81022 .03269 L
.81959 .04179 L
.83931 .06705 L
.85767 .09794 L
.89668 .18599 L
.93815 .30895 L
.97619 .44187 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00O7Goo00<007ooOol0
ogoo0Goo000MOol00`00Oomoo`3oOol1Ool001eoo`03001oogoo0?moo`5oo`007Goo00<007ooOol0
]7oo1P0OAWoo000MOol2002bOol301l5Ool301m4Ool001eoo`03001oogoo0:=oo``000807`/000<0
7d5oo`007Goo00<007ooOol0Xgoo00<007`0O00027`000<07g`0O0002W`000D007ooOomoo`0O041o
o`007Goo00<007ooOol0Xgoo00<007`0O0001g`000<07g`0O0002g`000<007ooOol00Woo00<07goo
Ool0?Goo000MOol2002TOol00`00O01l0006O0000`0OO01l000<O0000`00Oomoo`03Ool00`0OOomo
o`0lOol001eoo`03001oogoo0:=oo`03001l07`000Al00807`ml0003001oogoo00Aoo`0301moogoo
03]oo`007Goo00<007ooOol0Xgoo00<007`0O0000g`000<07g`0O0003g`000<007ooOol01Goo00<0
7gooOol0>Woo000MOol00`00Oomoo`2SOol00`00O01l0002O0000`0OO01l000@O0000`00Oomoo`05
Ool00`0OOomoo`0jOol001eoo`800:Aoo`05001l07`0O0007`0CO0000`00Oomoo`06Ool00`0OOomo
o`0iOol001eoo`03001oogoo0:=oo`04001l07`001lDO0000`00Oomoo`07Ool00`0OOomoo`0hOol0
01eoo`03001oogoo0:=oo`03001l000O01El00/0000301l0000000X002eoo`007Goo00<007ooOol0
Xgoo00<007`001l05G`000<007`0O0002G`000<07g`0O00027`000<007ooOol0:goo000MOol00`00
Oomoo`2SOol00`0001ml000EO0000`00O01l000:O0000`0OO01l0007O0000`00Oomoo`0[Ool001eo
o`800:Aoo`0301ml07`001El0003001l07`000Yl000301ml07`000Ml0003001oogoo02]oo`007Goo
00<007ooOol0Xgoo00<07g`0O0005G`000<007`0O0002g`000<07g`0O0001W`000<007ooOol0:goo
000FOol30004Ool00`00Oomoo`2ROol00`0O001l000FO0000`00O01l000<O0000`0OO01l0005O000
0`00Oomoo`0[Ool001Moo`03001oogoo00=oo`03001oogoo0:9oo`0301l007`001Il0003001l07`0
00al000301ml07`000El0003001oogoo02]oo`003goo1@0000=oo`0000000P0017oo0`00XGoo00<0
7goo00005g`000<007`0O0003G`000<07g`0O00017`000<007ooOol0:goo000EOol00`00Ool00005
Ool00`00Oomoo`2POol0100OOomoo`005g`000<007`0O0003G`000<07g`0O00017`000<007ooOol0
:goo000EOol00`00Ool00005Ool00`00Oomoo`2POol0100OOomoo`005g`000<007`0O0003W`000<0
7g`0O0000g`000<007ooOol0:goo000FOol20005Ool00`00Oomoo`2OOol01@0OOomoogoo00005g`0
00<007`0O0003g`000<07g`0O0000W`000<007ooOol0:goo000MOol00`00Oomoo`2OOol01@0OOomo
ogoo00005g`000<007`0O0003g`000<07g`0O0000W`000<007ooOol0:goo000MOol2002OOol00`0O
Oomoo`02Ool00`00O01l000EO0000`00O01l000@O0001@0OO01l07`00000;Goo000MOol00`00Oomo
o`2MOol00`0OOomoo`03Ool00`00O01l000EO0000`00O01l000@O0001@0OO01l07`00000;Goo000M
Ool00`00Oomoo`2MOol00`0OOomoo`03Ool00`00O01l000EO0000`00O01l000@O0001@0OO01l07`0
0000;Goo000MOol00`00Oomoo`2LOol00`0OOomoo`04Ool00`00O01l000EO0000`00O01l000AO000
100OO01l0000;Goo000MOol2002MOol00`0OOomoo`04Ool00`00O01l000EO0000`00O01l000AO000
100OO01l0000;Goo000MOol00`00Oomoo`2KOol00`0OOomoo`05Ool00`00O01l000EO0000`00O01l
000BO0000`0OO000000]Ool001eoo`03001oogoo09]oo`0301moogoo00Eoo`03001l07`001El0003
001l07`0019l000301ml000002eoo`007Goo00<007ooOol0VWoo00<07gooOol01Woo00<007`0O000
5G`000<007`0O0004W`000<07g`00000;Goo000MOol2002KOol00`0OOomoo`06Ool00`00O01l000E
O0000`00O01l000CO0000`0O001oo`0/Ool001eoo`03001oogoo09Uoo`0301moogoo00Moo`03001l
07`001El0003001l07`001=l000301l007oo02aoo`007Goo00<007ooOol0VGoo00<07gooOol01goo
00<007`0O0005G`000<007`0O00057`000<07gooOol0:goo000MOol00`00Oomoo`2;Ool=00000`0O
00000009000GO0000`00O01l000DO0000`0OOomoo`0[Ool001eoo`03001oogoo08]oo`03001l07`0
00Yl000301ml07`000Ql0003001l07`001El0003001l07`001Al000300007goo02]oo`007Goo0P00
S7oo00<007`0O0002G`000<07g`0O0002G`000<007`0O0005G`000<007`0O00057`000<0000OOol0
:goo000MOol00`00Oomoo`2;Ool00`00O01l0008O0000`0OO01l000:O0000`00O01l000EO0000`00
O01l000DO0000`0001moo`0[Ool001Eoo`<000Eoo`03001oogoo08]oo`03001l07`000Ql000301ml
07`000Yl0003001l07`001El0003001l07`001Al0003001oo`0O02]oo`0067oo00<007ooOol00Woo
00<007ooOol0Rgoo00<007`0O0001g`000<07g`0O0002g`000<007`0O0005G`000<007`0O00057`0
00<007oo01l0:goo000?Ool50004Ool00`00Oomoo`02Ool3002;Ool00`00O01l0007O0000`0OO01l
000;O0000`00O01l000EO0000`00O01l000DO0001000Oomoo`0O:Woo000FOol20005Ool00`00Oomo
o`2;Ool00`00O01l0006O0000`0OO01l000<O0000`00O01l000EO0000`00O01l000DO0001000Oomo
o`0O:Woo000HOol00`00Oomoo`02Ool00`00Oomoo`2;Ool00`00O01l0006O0000`0OO01l000<O000
0`00O01l000EO0000`00O01l000DO0001000Oomoo`0O:Woo000EOol30005Ool00`00Oomoo`2;Ool0
0`00O01l0005O0000`0OO01l000=O0000`00O01l000EO0000`00O01l000DO0001@00Oomoogoo01l0
:Goo000MOol00`00Oomoo`2;Ool00`00O01l0005O0000`0OO01l000=O0000`00O01l000EO0000`00
O01l000DO0001@00Oomoogoo01l0:Goo000MOol2002<Ool00`00O01l0004O0000`0OO01l000>O000
0`00O01l000EO0000`00O01l000DO0000`00Oomoo`02Ool00`0OOomoo`0VOol001eoo`03001oogoo
08]oo`03001l07`000Al000301ml07`000il0003001l07`001El0003001l07`001Al0003001oogoo
009oo`0301moogoo02Ioo`007Goo00<007ooOol0Rgoo00<007`0O0000g`000<07g`0O0003g`000<0
07`0O0005G`000<007`0O00057`000<007ooOol00Woo00<07gooOol09Woo000MOol00`00Oomoo`2;
Ool00`00O01l0003O0000`0OO01l000?O0000`00O01l000EO0000`00O01l000DO0000`00Oomoo`03
Ool00`0OOomoo`0UOol001eoo`8008aoo`03001l07`0009l000301ml07`0011l0003001l07`001El
0003001l07`001Al0003001oogoo00=oo`0301moogoo02Eoo`007Goo00<007ooOol0Rgoo00<007`0
O0000W`000<07g`0O00047`000<007`0O0005G`000<007`0O00057`000<007ooOol00goo00<07goo
Ool09Goo000MOol00`00Oomoo`2;Ool01@00O01l07`001l04g`000<007`0O0005G`000<007`0O000
57`000<007ooOol017oo00<07gooOol097oo000MOol00`00Oomoo`2;Ool01@00O01l07`001l04g`0
00<007`0O0005G`000<007`0O00057`000<007ooOol017oo00<07gooOol097oo000MOol00`00Oomo
o`2;Ool01000O01l000O57`000<007`0O0005G`000<007`0O00057`000<007ooOol017oo00<07goo
Ool097oo000MOol2002<Ool01000O01l000O57`000<007`0O0005G`000<007`0O00057`000<007oo
Ool01Goo00<07gooOol08goo000MOol00`00Oomoo`2;Ool00`00O0007`0EO0000`00O01l000EO000
0`00O01l000DO0000`00Oomoo`05Ool00`0OOomoo`0SOol001eoo`03001oogoo08]oo`03001l000O
01El0003001l07`001El0003001l07`001Al0003001oogoo00Ioo`0301moogoo029oo`007Goo00<0
07ooOol0Rgoo00<0000OO0005G`000<007`0O0005G`000<007`0O00057`000<007ooOol01Woo00<0
7gooOol08Woo000MOol2002<Ool00`0001ml000EO0000`00O01l000EO0000`00O01l000DO0000`00
Oomoo`06Ool00`0OOomoo`0ROol001eoo`03001oogoo08]oo`0301ml07`001El0003001l07`001El
0003001l07`001Al0003001oogoo00Moo`0301moogoo025oo`005Goo100017oo00<007ooOol0Rgoo
00<07g`0O0005G`000<007`0O0005G`000<007`0O00057`000<007ooOol01goo00<07gooOol08Goo
000FOol00`00Oomoo`04Ool00`00Oomoo`2:Ool00`0O001l000FO0000`00O01l000EO0000`00O01l
000DO0000`00Oomoo`07Ool00`0OOomoo`0QOol000moo`D000=oo`03001oogoo00=oo`<008Yoo`03
01l007`001Il0003001l07`001El0003001l07`001Al0003001oogoo00Qoo`0301moogoo021oo`00
67oo00<007ooOol00Woo00<007ooOol0RGoo00<07goo00005g`000<007`0O0005G`000<007`0O000
57`000<007ooOol027oo00<07gooOol087oo000EOol01000Oomoo`0017oo00<007ooOol0RGoo00<0
7goo00005g`000<007`0O0005G`000<007`0O00057`000<007ooOol02Goo00<07gooOol07goo000F
Ool20005Ool00`00Oomoo`28Ool0100OOomoo`005g`000<007`0O0005G`000<007`0O00057`000<0
07ooOol02Goo00<07gooOol07goo000MOol00`00Oomoo`28Ool0100OOomoo`005g`000<007`0O000
5G`000<007`0O00057`0300000<07`0000002P005Goo000MOol20028Ool01@0OOomoogoo00005g`0
00<007`0O0005G`000<007`0O00057`000<007`0O0002W`000<07g`0O00027`000<007ooOol04goo
000MOol00`00Oomoo`27Ool01@0OOomoogoo00005g`000<007`0O0005G`000<007`0O00057`000<0
07`0O0002W`000<07g`0O00027`000<007ooOol04goo000MOol00`00Oomoo`26Ool00`0OOomoo`02
Ool00`00O01l000EO0000`00O01l000EO0000`00O01l000DO0000`00O01l000:O0000`0OO01l0008
O0000`00Oomoo`0COol001eoo`03001oogoo08Ioo`0301moogoo009oo`03001l07`001El0003001l
07`001El0003001l07`001Al0003001l07`000]l000301ml07`000Ml0003001oogoo01=oo`007Goo
0P00QWoo00<07gooOol00goo00<007`0O0005G`000<007`0O0005G`000<007`0O00057`000<007`0
O0002g`000<07g`0O0001g`000<007ooOol04goo000MOol00`00Oomoo`25Ool00`0OOomoo`03Ool0
0`00O01l000EO0000`00O01l000EO0000`00O01l000DO0000`00O01l000;O0000`0OO01l0007O000
0`00Oomoo`0COol001eoo`03001oogoo08Aoo`0301moogoo00Aoo`03001l07`001El0003001l07`0
01El0003001l07`001Al0003001l07`000al000301ml07`000Il0003001oogoo01=oo`007Goo00<0
07ooOol0Q7oo00<07gooOol017oo00<007`0O0005G`000<007`0O0005G`000<007`0O00057`000<0
07`0O00037`000<07g`0O0001W`000<007ooOol04goo000MOol00`00Oomoo`23Ool00`0OOomoo`05
Ool00`00O01l000EO0000`00O01l000EO0000`00O01l000DO0000`00O01l000<O0000`0OO01l0006
O0000`00Oomoo`0COol001eoo`8008Aoo`0301moogoo00Eoo`03001l07`001El0003001l07`001El
0003001l07`001Al0003001l07`000el000301ml07`000El0003001oogoo01=oo`007Goo00<007oo
Ool0Pgoo00<07gooOol01Goo00<007`0O0005G`000<007`0O0005G`000<007`0O00057`000<007`0
O0003G`000<07g`0O0001G`000<007ooOol04goo000MOol00`00Oomoo`22Ool00`0OOomoo`06Ool0
0`00O01l000EO0000`00O01l000EO0000`00O01l000DO0000`00O01l000=O0000`0OO01l0005O000
0`00Oomoo`0COol001eoo`03001oogoo089oo`0301moogoo00Ioo`03001l07`001El0003001l07`0
01El0003001l07`001Al0003001l07`000el000301ml07`000El0003001oogoo01=oo`007Goo0P00
PWoo00<07gooOol01goo00<007`0O0005G`000<007`0O0005G`000<007`0O00057`000<007`0O000
3W`000<07g`0O00017`000<007ooOol04goo000MOol00`00Oomoo`21Ool00`0OOomoo`07Ool00`00
O01l000EO0000`00O01l000EO0000`00O01l000DO0000`00O01l000>O0000`0OO01l0004O0000`00
Oomoo`0COol001Eoo`<000Eoo`03001oogoo081oo`0301moogoo00Qoo`03001l07`001El0003001l
07`001El0003001l07`001Al0003001l07`000il000301ml07`000Al0003001oogoo01=oo`005Woo
00<007ooOol017oo00<007ooOol0M7oo300000<07`0000002@005g`000<007`0O0005G`000<007`0
O00057`000<007`0O0003g`000<07g`0O0000g`000<007ooOol04goo000?Ool50002Ool00`00Oomo
o`04Ool3001dOol00`00O01l0008O0000`0OO01l0009O0000`00O01l000EO0000`00O01l000EO000
0`00O01l000DO0000`00O01l000?O0000`0OO01l0003O0000`00Oomoo`0COol001Ioo`03001oogoo
00Aoo`03001oogoo07Aoo`03001l07`000Ql000301ml07`000Ul0003001l07`001El0003001l07`0
01El0003001l07`001Al0003001l07`000ml000301ml07`000=l0003001oogoo01=oo`005Woo00<0
07ooOol017oo00<007ooOol0M7oo00<007`0O0001g`000<07g`0O0002W`000<007`0O0005G`000<0
07`0O0005G`000<007`0O00057`000<007`0O0003g`000<07g`0O0000g`000<007ooOol04goo000E
Ool20006Ool00`00Oomoo`1dOol00`00O01l0007O0000`0OO01l000:O0000`00O01l000EO0000`00
O01l000EO0000`00O01l000DO0000`00O01l000@O0000`0OO01l0002O0000`00Oomoo`0COol001eo
o`03001oogoo07Aoo`03001l07`000Il000301ml07`000]l0003001l07`001El0003001l07`001El
0003001l07`001Al0003001l07`0011l000301ml07`0009l0003001oogoo01=oo`007Goo0P00MGoo
00<007`0O0001W`000<07g`0O0002g`000<007`0O0005G`000<007`0O0005G`000<007`0O00057`0
00<007`0O00047`000<07g`0O0000W`000<007ooOol04goo000MOol00`00Oomoo`1dOol00`00O01l
0005O0000`0OO01l000<O0000`00O01l000EO0000`00O01l000EO0000`00O01l000DO0000`00O01l
000@O0000`0OO01l0002O0000`00Oomoo`0COol001eoo`03001oogoo07Aoo`03001l07`000El0003
01ml07`000al0003001l07`001El0003001l07`001El0003001l07`001Al0003001l07`0015l0005
01ml07`0O000000EOol001eoo`03001oogoo07Aoo`03001l07`000Al000301ml07`000el0003001l
07`001El0003001l07`001El0003001l07`001Al0003001l07`0015l000501ml07`0O000000EOol0
01eoo`8007Eoo`03001l07`000Al000301ml07`000el0003001l07`001El0003001l07`001El0003
001l07`001Al0003001l07`0015l000501ml07`0O000000EOol001eoo`03001oogoo07Aoo`03001l
07`000=l000301ml07`000il0003001l07`001El0003001l07`001El0003001l07`001Al0003001l
07`0015l000501ml07`0O000000EOol001eoo`03001oogoo07Aoo`03001l07`000=l000301ml07`0
00il0003001l07`001El0003001l07`001El0003001l07`001Al0003001l07`0019l000401ml07`0
000EOol001eoo`03001oogoo025oo`<002=oo`@0025oo`<000Eoo`03001l07`0009l000301ml07`0
00ml0003001l07`001El0003001l07`001El0003001l07`001Al0003001l07`0019l000401ml07`0
000EOol001eoo`03001oogoo029oo`03001oogoo02=oo`03001oogoo02Aoo`03001oogoo009oo`03
001l07`0009l000301ml07`000ml0003001l07`001El0003001l07`001El0003001l07`001Al0003
001l07`0019l000401ml07`0000EOol001eoo`8002=oo`03001oogoo02Aoo`03001oogoo02=oo`03
001oogoo009oo`05001l07`0O0007`0BO0000`00O01l000EO0000`00O01l000EO0000`00O01l000D
O0000`00O01l000BO000100OO01l00005Goo000MOol00`00Oomoo`0ROol00`00Oomoo`0UOol00`00
Oomoo`0POol20005Ool01@00O01l07`001l04W`000<007`0O0005G`000<007`0O0005G`000<007`0
O00057`000<007`0O0004g`000<07g`000005Goo000MOol00`00Oomoo`0ROol00`00Oomoo`0ROol0
1000Oomoo`0097oo00<007ooOol00Woo00@007`0O0007a=l0003001l07`001El0003001l07`001El
0003001l07`001Al0003001l07`001=l000301ml000001Eoo`007Goo00<007ooOol08Goo0P009Goo
0P008Woo0`001Goo00@007`0O0007a=l0003001l07`001El0003001l07`001El0003001l07`001Al
0003001l07`001=l000301ml000001Eoo`007Goo0P00MGoo00<007`001l057`000<007`0O0005G`0
00<007`0O0005G`000<007`0O00057`000<007`0O00057`000<07`00Ool057oo000MOol00`00Oomo
o`1dOol00`00O0007`0DO0000`00O01l000EO0000`00O01l000EO0000`00O01l000DO0000`00O01l
000DO0000`0O001oo`0DOol001eoo`03001oogoo07Aoo`0300007g`001Al0003001l07`001El0003
001l07`001El0003001l07`001Al0003001l07`001Al000301l007oo01Aoo`007Goo00<007ooOol0
M7oo00<0000OO00057`000<007`0O0005G`000<007`0O0005G`000<007`0O00057`000<007`0O000
57`000<07`00Ool057oo000MOol00`00Oomoo`1dOol00`0OO01l000DO0000`00O01l000EO0000`00
O01l000EO0000`00O01l000DO0000`00O01l000EO0000`0OOomoo`0COol001Moo`H000X07fd00003
01ml07`001Al0003001l07`001El0003001l07`001El0003001l07`001Al0003001l07`001El0003
01l0000000@000moo`007Goo00<007`0O0001g`00P0O37`000<007`0O00057`000<007`0O0005G`0
00<007`0O0005G`000<007`0O00057`000<07`00Ool07Woo00<007ooOol08goo00<007ooOol08Woo
00<007ooOol07Woo000MOol<000301l:000FO0000`00O01l000EO0000`00O01l000EO0000`00O01l
000CO0000`0OO000002;Ool001eoo`03001oogoo00aoo`807`Moo`03001l07`001Al0003001l07`0
01El0003001l07`001El0003001l07`001=l000301ml000008]oo`007Goo0P003goo0P0O1Goo00<0
07`0O00057`000<007`0O0005G`000<007`0O0005G`000<007`0O0004W`000@07g`0O00008]oo`00
7Goo00<007ooOol047oo00<07gooOol00Woo00<007`0O00057`000<007`0O0005G`000<007`0O000
5G`000<007`0O0004W`000@07g`0O00008]oo`007Goo00<007ooOol04Goo0P0O0Woo00<007`0O000
57`000<007`0O0005G`000<007`0O0005G`000<007`0O0004G`000D07g`0O01l000008]oo`007Goo
00<007ooOol04goo0P0O00<007`0O00057`000<007`0O0005G`000<007`0O0005G`000<007`0O000
47`000<07g`0O0000W`000<007ooOol0RGoo000MOol2000FOol00`0OO01l000DO0000`00O01l000E
O0000`00O01l000EO0000`00O01l000@O0000`0OO01l0002O0000`00Oomoo`29Ool001eoo`03001o
ogoo01Eoo`0300007`0O01Al0003001l07`001El0003001l07`001El0003001l07`000ml000301ml
07`000=l0003001oogoo08Uoo`007Goo00<007ooOol05Goo00<007`0O0000P0O4W`000<007`0O000
5G`000<007`0O0005G`000<007`0O0003W`000<07g`0O00017`000<007ooOol0RGoo000MOol00`00
Oomoo`0EOol00`00O01l0002O0000`0OO01l000?O0000`00O01l000EO0000`00O01l000EO0000`00
O01l000>O0000`0OO01l0004O0000`00Oomoo`29Ool001eoo`03001oogoo01Eoo`03001l07`000=l
00807`ml0003001l07`001El0003001l07`001El0003001l07`000el000301ml07`000El0003001o
ogoo08Uoo`007Goo0P005Woo00<007`0O0001G`000<07g`0O00037`000<007`0O0005G`000<007`0
O0005G`000<007`0O0003G`000<07g`0O0001G`000<007ooOol0RGoo000MOol00`00Oomoo`0EOol0
0`00O01l0006O0000`0OO01l000;O0000`00O01l000EO0000`00O01l000EO0000`00O01l000<O000
0`0OO01l0006O0000`00Oomoo`29Ool001eoo`03001oogoo01Eoo`03001l07`000Ml000301ml07`0
00Yl0003001l07`001El0003001l07`001El0003001l07`000]l000301ml07`000Ml0003001oogoo
08Uoo`007Goo00<007ooOol05Goo2`000P0O2`005g`000<007`0O0005G`000<007`0O0002g`000<0
7g`0O0001g`000<007ooOol0RGoo000MOol2000SOol00`0OOomoo`07Ool00`00O01l000EO0000`00
O01l000EO0000`00O01l000:O0000`0OO01l0008O0000`00Oomoo`29Ool001eoo`03001oogoo02=o
o`0301moogoo00Ioo`03001l07`001El0003001l07`001El0003001l07`000Ul000301ml07`000Ul
0003001oogoo08Uoo`007Goo00<007ooOol097oo00<07gooOol01Goo00<007`0O0005G`000<007`0
O0005G`02`0000<07`0000002`00Rgoo000EOol30005Ool00`00Oomoo`0UOol201l5Ool00`00O01l
000EO0000`00O01l000EO0000`00Oomoo`08Ool00`0OOomoo`2FOol001Ioo`03001oogoo00Aoo`03
001oogoo02Moo`0301moogoo009oo`03001l07`001El0003001l07`001El0003001oogoo00Moo`03
01moogoo09Moo`005Woo00<007ooOol017oo0`00:7oo00D07gooOomoo`0001Ml0003001l07`001El
0003001oogoo00Ioo`0301moogoo09Qoo`005Woo00<007ooOol017oo00<007ooOol0:Goo00@07goo
Ool001Ml0003001l07`001El0003001oogoo00Eoo`0301moogoo09Uoo`005Woo00<007ooOol017oo
00<007ooOol0:Woo0P0O00<007`0O0005G`000<007`0O0005G`000<007ooOol017oo00<07gooOol0
VWoo000EOol20006Ool00`00Oomoo`0/Ool00`0OO01l000EO0000`00O01l000EO0000`00Oomoo`04
Ool00`0OOomoo`2JOol001eoo`8002eoo`0300007g`001El0003001l07`001El0003001oogoo00=o
o`0301moogoo09]oo`007Goo00<007ooOol0;7oo00<007`001l05G`000<007`0O0005G`000<007oo
Ool00Woo00<07gooOol0W7oo000MOol00`00Oomoo`0/Ool00`00O01l000201lCO0000`00O01l000E
O0001@00Oomoogoo01l0Wgoo000MOol00`00Oomoo`0/Ool00`00O01l0002O0000`0OO01l000@O000
0`00O01l000EO0001000Oomoo`0OX7oo000MOol2000]Ool00`00O01l0003O00201l@O0000`00O01l
000EO0000`00Ool07`2QOol001eoo`03001oogoo02aoo`03001l07`000El000301ml07`000el0003
001l07`001El000300007goo0:5oo`007Goo00<007ooOol0;7oo00<007`0O0001W`00P0O3G`000<0
07`0O00057`00P0OXgoo000MOol00`00Oomoo`0/Ool00`00O01l0008O0000`0OO01l000:O0000`00
O01l000CO0000`0OO000002SOol001eoo`03001oogoo02aoo``000807`/001Al000401ml07`0002S
Ool001eoo`8003]oo`0301moogoo00Moo`03001l07`0015l000501ml07`0O000002SOol001eoo`03
001oogoo03]oo`<07`Ioo`03001l07`000ml00807`Al0003001oogoo0:5oo`007Goo00<007ooOol0
?Woo0P0O17oo00<007`0O00037`00`0O1W`000<007ooOol0XGoo000MOol00`00Oomoo`10Ool301l0
0goo001l000;O00201l9O0000`00Oomoo`2QOol001eoo`8004Aoo`@07`H000@07``00:=oo`007Goo
00<007ooOol0Agoo1P0O/goo000MOol00`00Oomoo`3oOol1Ool001eoo`03001oogoo0?moo`5oo`00
7Goo00<007ooOol0ogoo0Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00?7oo1P001Woo0`000goo100017oo0`001Goo0`000goo1000
00=oo`0000000P000Woo0P001Goo2P0000=oo`0000000P000Woo100017oo10000goo100067oo1P00
0goo0P001Goo0`000goo1@001goo0`001Goo100027oo0P00=Woo000nOol20007Ool20002Ool01000
Oomoogoo0P0017oo0P000Woo00@007ooOomoo`80009oo`04001oogooOol20003Ool20002Ool20000
0goo001oo`05Ool20005Ool200000goo00000004Ool20004Ool20002Ool20003Ool2000KOol20005
Ool20003Ool20002Ool20002Ool20003Ool20003Ool20002Ool20003Ool20002Ool20007Ool2000f
Ool003ioo`8000Ioo`8000Aoo`03001oogoo008000=oo`8000Aoo`04001oo`000004Ool00`00Oomo
o`020003Ool20002Ool20008Ool20006Ool01000Ool0000017oo0P000goo0P0017oo0P000Woo0P00
2Goo2@002Goo0P002Woo00<007ooOol00Woo0P001goo00D007ooOomoo`0000Aoo`800003Ool00000
00Aoo`8000Ioo`8003Ioo`00?Woo0P001Woo0P001goo0P000goo0P001Woo0P001goo0P000goo0P00
0Woo0P0027oo0P0027oo0P0017oo0P000goo0P0017oo0P000Woo0P006goo0P002Goo0P0017oo0P00
1goo0P0000=oo`00000017oo0P0000=oo`00000017oo0P0000=oo`0000001`00=7oo000nOol20006
Ool20007Ool20003Ool20006Ool20007Ool20003Ool20002Ool20008Ool20004Ool01000Oomoogoo
0P0017oo0P000goo0P0017oo0P000Woo0P006goo0P002Goo0P0017oo0P001goo0P0000=oo`000000
17oo0P0000=oo`0000000goo0`0000=oo`00Ool00goo0P00=Woo000nOol60002Ool70002Ool20003
Ool20004Ool00`00Ool000060002Ool20003Ool20002Ool20008Ool20004Ool01000Oomoogoo0P00
17oo0P000goo0P0017oo0P000Woo0P006goo0P002Goo0P0017oo0P001goo0P0000=oo`00000017oo
0P000Woo0P0000Aoo`00000000=oo`04001oogooOol2000fOol003ioo`8000=oo`80009oo`04001o
ogooOol200000goo0000000400000goo00000002Ool20002Ool01000Oomoogoo0P0000=oo`000000
0P000Woo0P000Woo0P0027oo1`000Woo300000=oo`0000000Woo0P000Woo1P001Woo2@002Goo0P00
2Goo0`000Woo0P001goo0`0000Aoo`000000009oo`8000Aoo`@000Eoo`03001oogoo008003Ioo`00
?Woo0P0017oo0P000Woo100017oo00@007oo0000009oo`@000Aoo`@000Aoo`03001oo`000080009o
o`D000Ioo`8000Aoo`03001oogoo009oo`04001oo`000002Ool01000Ool000000Woo10001Goo00@0
07oo000001Qoo`8000Uoo`800004Ool000000005Ool50002Ool2000017oo0000000017oo1@001Goo
00<007ooOol00P00=Woo000nOol20004Ool2000XOol20008Ool20004Ool00`00Oomoo`0cOol2000:
Ool2000:Ool00`00Oomoo`03Ool20007Ool20002Ool20005Ool01000Ool00000=Woo000nOol20004
Ool2000YOol00`00Oomoo`06Ool2000jOol2000:Ool2000;Ool00`00Oomoo`02Ool20006Ool20004
Ool20005Ool3000fOol003ioo`8000Aoo`80039oo`8000Eoo`03001oogoo039oo`8000]oo`8000Eo
o`03001oogoo009oo`8000Aoo`8000Eoo`8000Aoo`8000Eoo`<003Ioo`00?Woo0P000goo0P00<goo
0P001Goo00<007ooOol0<7oo100037oo0P001Goo00<007ooOol00`001Goo0P001Goo0P000Woo0P00
1goo0P00=Woo000lOol8000bOol:000dOol2000>Ool30003Ool40008Ool30003Ool40008Ool2000f
Ool00?moob5oo`00ogoo8Goo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.783823, -4.98036, 
  0.0265065, 0.0452841}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.151576 0.44187 0.0887232 [
[.17539 .42937 -3 -9 ]
[.17539 .42937 3 0 ]
[.32696 .42937 -3 -9 ]
[.32696 .42937 3 0 ]
[.47854 .42937 -3 -9 ]
[.47854 .42937 3 0 ]
[.63011 .42937 -3 -9 ]
[.63011 .42937 3 0 ]
[.78169 .42937 -3 -9 ]
[.78169 .42937 3 0 ]
[.93327 .42937 -3 -9 ]
[.93327 .42937 3 0 ]
[.01131 .08698 -12 -4.5 ]
[.01131 .08698 0 4.5 ]
[.01131 .1757 -12 -4.5 ]
[.01131 .1757 0 4.5 ]
[.01131 .26442 -12 -4.5 ]
[.01131 .26442 0 4.5 ]
[.01131 .35315 -12 -4.5 ]
[.01131 .35315 0 4.5 ]
[.01131 .53059 -6 -4.5 ]
[.01131 .53059 0 4.5 ]
[.5 .63053 -89.5938 0 ]
[.5 .63053 89.5938 20 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.17539 .44187 m
.17539 .44812 L
s
[(1)] .17539 .42937 0 1 Mshowa
.32696 .44187 m
.32696 .44812 L
s
[(2)] .32696 .42937 0 1 Mshowa
.47854 .44187 m
.47854 .44812 L
s
[(3)] .47854 .42937 0 1 Mshowa
.63011 .44187 m
.63011 .44812 L
s
[(4)] .63011 .42937 0 1 Mshowa
.78169 .44187 m
.78169 .44812 L
s
[(5)] .78169 .42937 0 1 Mshowa
.93327 .44187 m
.93327 .44812 L
s
[(6)] .93327 .42937 0 1 Mshowa
.125 Mabswid
.05412 .44187 m
.05412 .44562 L
s
.08444 .44187 m
.08444 .44562 L
s
.11476 .44187 m
.11476 .44562 L
s
.14507 .44187 m
.14507 .44562 L
s
.2057 .44187 m
.2057 .44562 L
s
.23602 .44187 m
.23602 .44562 L
s
.26633 .44187 m
.26633 .44562 L
s
.29665 .44187 m
.29665 .44562 L
s
.35728 .44187 m
.35728 .44562 L
s
.38759 .44187 m
.38759 .44562 L
s
.41791 .44187 m
.41791 .44562 L
s
.44822 .44187 m
.44822 .44562 L
s
.50885 .44187 m
.50885 .44562 L
s
.53917 .44187 m
.53917 .44562 L
s
.56948 .44187 m
.56948 .44562 L
s
.5998 .44187 m
.5998 .44562 L
s
.66043 .44187 m
.66043 .44562 L
s
.69074 .44187 m
.69074 .44562 L
s
.72106 .44187 m
.72106 .44562 L
s
.75137 .44187 m
.75137 .44562 L
s
.81201 .44187 m
.81201 .44562 L
s
.84232 .44187 m
.84232 .44562 L
s
.87264 .44187 m
.87264 .44562 L
s
.90295 .44187 m
.90295 .44562 L
s
.96358 .44187 m
.96358 .44562 L
s
.9939 .44187 m
.9939 .44562 L
s
.25 Mabswid
0 .44187 m
1 .44187 L
s
.02381 .08698 m
.03006 .08698 L
s
[(-4)] .01131 .08698 1 0 Mshowa
.02381 .1757 m
.03006 .1757 L
s
[(-3)] .01131 .1757 1 0 Mshowa
.02381 .26442 m
.03006 .26442 L
s
[(-2)] .01131 .26442 1 0 Mshowa
.02381 .35315 m
.03006 .35315 L
s
[(-1)] .01131 .35315 1 0 Mshowa
.02381 .53059 m
.03006 .53059 L
s
[(1)] .01131 .53059 1 0 Mshowa
.125 Mabswid
.02381 .016 m
.02756 .016 L
s
.02381 .03374 m
.02756 .03374 L
s
.02381 .05149 m
.02756 .05149 L
s
.02381 .06923 m
.02756 .06923 L
s
.02381 .10472 m
.02756 .10472 L
s
.02381 .12247 m
.02756 .12247 L
s
.02381 .14021 m
.02756 .14021 L
s
.02381 .15796 m
.02756 .15796 L
s
.02381 .19344 m
.02756 .19344 L
s
.02381 .21119 m
.02756 .21119 L
s
.02381 .22893 m
.02756 .22893 L
s
.02381 .24668 m
.02756 .24668 L
s
.02381 .28217 m
.02756 .28217 L
s
.02381 .29991 m
.02756 .29991 L
s
.02381 .31766 m
.02756 .31766 L
s
.02381 .3354 m
.02756 .3354 L
s
.02381 .37089 m
.02756 .37089 L
s
.02381 .38864 m
.02756 .38864 L
s
.02381 .40638 m
.02756 .40638 L
s
.02381 .42413 m
.02756 .42413 L
s
.02381 .45961 m
.02756 .45961 L
s
.02381 .47736 m
.02756 .47736 L
s
.02381 .4951 m
.02756 .4951 L
s
.02381 .51285 m
.02756 .51285 L
s
.02381 .54834 m
.02756 .54834 L
s
.02381 .56608 m
.02756 .56608 L
s
.02381 .58383 m
.02756 .58383 L
s
.02381 .60157 m
.02756 .60157 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -150.594 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 24.000000 moveto
 558.000000 24.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 24.000000 lineto
closepath
clip newpath
63.000000 19.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 18.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 19.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 18.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Percent) show
121.250000 19.000000 moveto
(Error) show
163.625000 19.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 18.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(=) show
179.687500 19.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 18.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1.35392) show
238.187500 19.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 18.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
0 0 1 r
.007 w
.02381 .44187 m
.02499 .44188 L
.02605 .44189 L
.02729 .44192 L
.02846 .44195 L
.03053 .44204 L
.03279 .44218 L
.03527 .44238 L
.0379 .44264 L
.04262 .44323 L
.04749 .44403 L
.05205 .44493 L
.06244 .44757 L
.07305 .45107 L
.08274 .45495 L
.10458 .46589 L
.14429 .4922 L
.18248 .52229 L
.22313 .55474 L
.26226 .58144 L
.27254 .5871 L
.28367 .59241 L
.29328 .59624 L
.29838 .59795 L
.30384 .59955 L
.30923 .60086 L
.31415 .60182 L
.31652 .6022 L
.31909 .60255 L
.32151 .60282 L
.32378 .60303 L
.32509 .60312 L
.3263 .60319 L
.32764 .60325 L
.32834 .60327 L
.32908 .60329 L
.32976 .60331 L
.33048 .60332 L
.33177 .60332 L
.33257 .60331 L
.33332 .6033 L
.33399 .60328 L
.33472 .60326 L
.33594 .60321 L
.33728 .60313 L
.33999 .60292 L
.34249 .60266 L
.34484 .60235 L
.34982 .60149 L
.35525 .60023 L
Mistroke
.36513 .59709 L
.37475 .59294 L
.38367 .58812 L
.40423 .57339 L
.42285 .55569 L
.46297 .50405 L
.50157 .43897 L
.54262 .35759 L
.58216 .27326 L
.62019 .19318 L
.66067 .11668 L
.69963 .05896 L
.70983 .04728 L
.72091 .03645 L
.73048 .02875 L
.73557 .02531 L
.74104 .02213 L
.74638 .01956 L
.75126 .01767 L
.75594 .01629 L
.75829 .01576 L
.76085 .0153 L
.76227 .01511 L
.76362 .01496 L
.76482 .01485 L
.76612 .01477 L
.7668 .01474 L
.76755 .01472 L
.76833 .01472 L
.76905 .01472 L
.77035 .01475 L
.77108 .01478 L
.77175 .01482 L
.77304 .01492 L
.77424 .01504 L
.77695 .01543 L
.77933 .0159 L
.78187 .01653 L
.78675 .0181 L
.79123 .01999 L
.80132 .02578 L
.81022 .03269 L
.81959 .04179 L
.83931 .06705 L
.85767 .09794 L
.89668 .18599 L
.93815 .30895 L
.97619 .44187 L
Mfstroke
1 0 0 r
.02381 .44187 m
.11039 .44187 L
.11039 .44901 L
.02381 .44901 L
F
.11039 .44187 m
.19697 .44187 L
.19697 .49932 L
.11039 .49932 L
F
.19697 .44187 m
.28355 .44187 L
.28355 .56728 L
.19697 .56728 L
F
.28355 .44187 m
.37013 .44187 L
.37013 .60322 L
.28355 .60322 L
F
.37013 .44187 m
.45671 .44187 L
.45671 .56516 L
.37013 .56516 L
F
.45671 .44187 m
.54329 .44187 L
.54329 .44187 L
.45671 .44187 L
F
.54329 .44187 m
.62987 .44187 L
.62987 .26378 L
.54329 .26378 L
F
.62987 .44187 m
.71645 .44187 L
.71645 .09613 L
.62987 .09613 L
F
.71645 .44187 m
.80303 .44187 L
.80303 .01549 L
.71645 .01549 L
F
.80303 .44187 m
.88961 .44187 L
.88961 .07802 L
.80303 .07802 L
F
.88961 .44187 m
.97619 .44187 L
.97619 .29195 L
.88961 .29195 L
F
0 g
.5 Mabswid
.02381 .44187 m
.02381 .44901 L
s
.11039 .44187 m
.11039 .44901 L
s
.02381 .44901 m
.11039 .44901 L
s
.11039 .44187 m
.11039 .49932 L
s
.19697 .44187 m
.19697 .49932 L
s
.11039 .49932 m
.19697 .49932 L
s
.19697 .44187 m
.19697 .56728 L
s
.28355 .44187 m
.28355 .56728 L
s
.19697 .56728 m
.28355 .56728 L
s
.28355 .44187 m
.28355 .60322 L
s
.37013 .44187 m
.37013 .60322 L
s
.28355 .60322 m
.37013 .60322 L
s
.37013 .44187 m
.37013 .56516 L
s
.45671 .44187 m
.45671 .56516 L
s
.37013 .56516 m
.45671 .56516 L
s
.45671 .44187 m
.45671 .44187 L
s
.54329 .44187 m
.54329 .44187 L
s
.45671 .44187 m
.54329 .44187 L
s
.54329 .44187 m
.54329 .26378 L
s
.62987 .44187 m
.62987 .26378 L
s
.54329 .26378 m
.62987 .26378 L
s
.62987 .44187 m
.62987 .09613 L
s
.71645 .44187 m
.71645 .09613 L
s
.62987 .09613 m
.71645 .09613 L
s
.71645 .44187 m
.71645 .01549 L
s
.80303 .44187 m
.80303 .01549 L
s
.71645 .01549 m
.80303 .01549 L
s
.80303 .44187 m
.80303 .07802 L
s
.88961 .44187 m
.88961 .07802 L
s
.80303 .07802 m
.88961 .07802 L
s
.88961 .44187 m
.88961 .29195 L
s
.97619 .44187 m
.97619 .29195 L
s
.88961 .29195 m
.97619 .29195 L
s
0 0 1 r
.007 w
.02381 .44187 m
.02499 .44188 L
.02605 .44189 L
.02729 .44192 L
.02846 .44195 L
.03053 .44204 L
.03279 .44218 L
.03527 .44238 L
.0379 .44264 L
.04262 .44323 L
.04749 .44403 L
.05205 .44493 L
.06244 .44757 L
.07305 .45107 L
.08274 .45495 L
.10458 .46589 L
.14429 .4922 L
.18248 .52229 L
.22313 .55474 L
.26226 .58144 L
.27254 .5871 L
.28367 .59241 L
.29328 .59624 L
.29838 .59795 L
.30384 .59955 L
.30923 .60086 L
.31415 .60182 L
.31652 .6022 L
.31909 .60255 L
.32151 .60282 L
.32378 .60303 L
.32509 .60312 L
.3263 .60319 L
.32764 .60325 L
.32834 .60327 L
.32908 .60329 L
.32976 .60331 L
.33048 .60332 L
.33177 .60332 L
.33257 .60331 L
.33332 .6033 L
.33399 .60328 L
.33472 .60326 L
.33594 .60321 L
.33728 .60313 L
.33999 .60292 L
.34249 .60266 L
.34484 .60235 L
.34982 .60149 L
.35525 .60023 L
Mistroke
.36513 .59709 L
.37475 .59294 L
.38367 .58812 L
.40423 .57339 L
.42285 .55569 L
.46297 .50405 L
.50157 .43897 L
.54262 .35759 L
.58216 .27326 L
.62019 .19318 L
.66067 .11668 L
.69963 .05896 L
.70983 .04728 L
.72091 .03645 L
.73048 .02875 L
.73557 .02531 L
.74104 .02213 L
.74638 .01956 L
.75126 .01767 L
.75594 .01629 L
.75829 .01576 L
.76085 .0153 L
.76227 .01511 L
.76362 .01496 L
.76482 .01485 L
.76612 .01477 L
.7668 .01474 L
.76755 .01472 L
.76833 .01472 L
.76905 .01472 L
.77035 .01475 L
.77108 .01478 L
.77175 .01482 L
.77304 .01492 L
.77424 .01504 L
.77695 .01543 L
.77933 .0159 L
.78187 .01653 L
.78675 .0181 L
.79123 .01999 L
.80132 .02578 L
.81022 .03269 L
.81959 .04179 L
.83931 .06705 L
.85767 .09794 L
.89668 .18599 L
.93815 .30895 L
.97619 .44187 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00O7Goo00<007ooOol0
ogoo0Goo000MOol00`00Oomoo`3oOol1Ool001eoo`03001oogoo0?moo`5oo`007Goo00<007ooOol0
ZGoo2`001P0O1P00@7oo000MOol2002ZOol00`00O01l0005O00301l5O00301l3O0000`00Oomoo`0n
Ool001eoo`03001oogoo0:Uoo`03001l07`000=l00807`]l00<07`03001oogoo03ioo`007Goo00<0
07ooOol0ZGoo00<007`0O0000W`000<07g`0O0003W`000<07gooOol0?Woo000MOol00`00Oomoo`2Y
Ool01@00O01l07`001l04G`000<0000OOol0?Woo000MOol2002ZOol01000O01l000O4W`000<007oo
01l0?Woo000MOol00`00Oomoo`2YOol00`0001l07`0CO0001000Oomoo`0O?Goo000MOol00`00Oomo
o`2YOol00`0OO01l000CO0001@00Oomoogoo01l0?7oo000MOol00`00Oomoo`2XOol00`0O001l000D
O0001@00Oomoogoo01l0?7oo000MOol2002XOol00`0OOol0000EO0000`00Oomoo`02Ool00`0OOomo
o`0iOol001eoo`03001oogoo0:Ioo`0401moogoo000EO0000`00Oomoo`03Ool00`0OOomoo`0hOol0
01eoo`03001oogoo0:Eoo`0501moogooOol0000EO0000`00Oomoo`04Ool00`0OOomoo`0gOol001eo
o`03001oogoo0:Eoo`0501moogooOol0000EO0000`00Oomoo`05Ool00`0OOomoo`0fOol001eoo`03
001oogoo0:Aoo`0301moogoo009oo`03001l07`001=l0003001oogoo00Ioo`0301moogoo03Eoo`00
7Goo0P00Y7oo00<07gooOol00goo00<007`0O0004g`000<007ooOol01Woo00<07gooOol0=Goo000M
Ool00`00Oomoo`2SOol00`0OOomoo`03Ool00`00O01l000CO0000`00Oomoo`07Ool00`0OOomoo`0d
Ool001Ioo`<000Aoo`03001oogoo0:9oo`0301moogoo00Aoo`03001l07`001=l00/0000301l00000
00T002Yoo`005goo00<007ooOol00goo00<007ooOol0XWoo00<07gooOol017oo00<007`0O0004g`0
00<007`0O00027`000<07g`0O00027`000<007ooOol0:7oo000?Ool500000goo000000020004Ool3
002QOol00`0OOomoo`05Ool00`00O01l000CO0000`00O01l0009O0000`0OO01l0007O0000`00Oomo
o`0XOol001Eoo`03001oo`0000Eoo`03001oogoo0:1oo`0301moogoo00Ioo`03001l07`001=l0003
001l07`000Ul000301ml07`000Ml0003001oogoo02Qoo`005Goo00<007oo00001Goo00<007ooOol0
U7oo300000<07`0000001`005G`000<007`0O0002W`000<07g`0O0001W`000<007ooOol0:7oo000F
Ool20005Ool00`00Oomoo`2DOol00`00O01l0008O0000`0OO01l0007O0000`00O01l000CO0000`00
O01l000;O0000`0OO01l0005O0000`00Oomoo`0XOol001eoo`03001oogoo09Aoo`03001l07`000Ql
000301ml07`000Ml0003001l07`001=l0003001l07`000]l000301ml07`000El0003001oogoo02Qo
o`007Goo0P00UGoo00<007`0O0001g`000<07g`0O00027`000<007`0O0004g`000<007`0O00037`0
00<07g`0O00017`000<007ooOol0:7oo000MOol00`00Oomoo`2DOol00`00O01l0006O0000`0OO01l
0009O0000`00O01l000CO0000`00O01l000<O0000`0OO01l0004O0000`00Oomoo`0XOol001eoo`03
001oogoo09Aoo`03001l07`000Il000301ml07`000Ul0003001l07`001=l0003001l07`000al0003
01ml07`000Al0003001oogoo02Qoo`007Goo00<007ooOol0U7oo00<007`0O0001G`000<07g`0O000
2W`000<007`0O0004g`000<007`0O0003G`000<07g`0O0000g`000<007ooOol0:7oo000MOol2002E
Ool00`00O01l0005O0000`0OO01l000:O0000`00O01l000CO0000`00O01l000=O0000`0OO01l0003
O0000`00Oomoo`0XOol001eoo`03001oogoo09Aoo`03001l07`000Al000301ml07`000]l0003001l
07`001=l0003001l07`000il000301ml07`0009l0003001oogoo02Qoo`007Goo00<007ooOol0U7oo
00<007`0O00017`000<07g`0O0002g`000<007`0O0004g`000<007`0O0003W`000<07g`0O0000W`0
00<007ooOol0:7oo000MOol00`00Oomoo`2DOol00`00O01l0003O0000`0OO01l000<O0000`00O01l
000CO0000`00O01l000>O0000`0OO01l0002O0000`00Oomoo`0XOol001eoo`8009Eoo`03001l07`0
00=l000301ml07`000al0003001l07`001=l0003001l07`000ml000501ml07`0O000000ZOol001eo
o`03001oogoo09Aoo`03001l07`0009l000301ml07`000el0003001l07`001=l0003001l07`000ml
000501ml07`0O000000ZOol001eoo`03001oogoo09Aoo`03001l07`0009l000301ml07`000el0003
001l07`001=l0003001l07`0011l000401ml07`0000ZOol001eoo`03001oogoo09Aoo`05001l07`0
O0007`0@O0000`00O01l000CO0000`00O01l000@O000100OO01l0000:Woo000MOol00`00Oomoo`2D
Ool01@00O01l07`001l047`000<007`0O0004g`000<007`0O0004G`000<07g`00000:Woo000MOol2
002EOol01000O01l000O4G`000<007`0O0004g`000<007`0O0004G`000<07g`00000:Woo000MOol0
0`00Oomoo`2DOol00`00O0007`0BO0000`00O01l000CO0000`00O01l000AO0000`0OO000000ZOol0
01Eoo`<000Eoo`03001oogoo09Aoo`03001l000O019l0003001l07`001=l0003001l07`0019l0003
01l007oo02Uoo`0067oo00<007ooOol00Woo00<007ooOol0U7oo00<0000OO0004W`000<007`0O000
4g`000<007`0O0004W`000<07`00Ool0:Goo000?Ool50004Ool00`00Oomoo`02Ool3002DOol00`00
01ml000BO0000`00O01l000CO0000`00O01l000CO0000`0OOomoo`0XOol001Ioo`8000Eoo`03001o
ogoo09Aoo`0301ml07`0019l0003001l07`001=l0003001l07`001=l000301moogoo02Qoo`0067oo
00<007ooOol00Woo00<007ooOol0U7oo00<07g`0O0004W`000<007`0O0004g`000<007`0O0004g`0
00<07gooOol0:7oo000EOol30005Ool00`00Oomoo`2COol00`0O001l000CO0000`00O01l000CO000
0`00O01l000CO0000`0001moo`0XOol001eoo`03001oogoo09=oo`0301l007`001=l0003001l07`0
01=l0003001l07`001=l000300007goo02Qoo`007Goo0P00Tgoo00<07goo000057`000<007`0O000
4g`000<007`0O0004g`000<007oo01l0:7oo000MOol00`00Oomoo`2BOol00`0OOol0000DO0000`00
O01l000CO0000`00O01l000CO0000`00Ool07`0XOol001eoo`03001oogoo095oo`0401moogoo000D
O0000`00O01l000CO0000`00O01l000CO0000`00Ool07`0XOol001eoo`03001oogoo095oo`0401mo
ogoo000DO0000`00O01l000CO0000`00O01l000CO0001000Oomoo`0O9goo000MOol2002AOol01@0O
Oomoogoo000057`000<007`0O0004g`000<007`0O0004g`000@007ooOol07bMoo`007Goo00<007oo
Ool0T7oo00D07gooOomoo`0001Al0003001l07`001=l0003001l07`001=l0004001oogoo01lWOol0
01eoo`03001oogoo08moo`0301moogoo009oo`03001l07`0019l0003001l07`001=l0003001l07`0
01=l0005001oogooOol07`0VOol001eoo`03001oogoo08moo`0301moogoo009oo`03001l07`0019l
0003001l07`001=l0003001l07`001=l0005001oogooOol07`0VOol001eoo`03001oogoo08ioo`03
01moogoo00=oo`03001l07`0019l0003001l07`001=l0003001l07`001=l0005001oogooOol07`0V
Ool001eoo`8008moo`0301moogoo00=oo`03001l07`0019l0003001l07`001=l0003001l07`001=l
0003001oogoo009oo`0301moogoo02=oo`007Goo00<007ooOol0SGoo00<07gooOol017oo00<007`0
O0004W`000<007`0O0004g`000<007`0O0004g`000<007ooOol00Woo00<07gooOol08goo000MOol0
0`00Oomoo`2=Ool00`0OOomoo`04Ool00`00O01l000BO0000`00O01l000CO0000`00O01l000CO000
0`00Oomoo`03Ool00`0OOomoo`0ROol001eoo`03001oogoo08aoo`0301moogoo00Eoo`03001l07`0
019l0003001l07`001=l0003001l07`001=l0003001oogoo00=oo`0301moogoo029oo`007Goo0P00
SGoo00<07gooOol01Goo00<007`0O0004W`000<007`0O0004g`000<007`0O0004g`000<007ooOol0
0goo00<07gooOol08Woo000MOol00`00Oomoo`2;Ool00`0OOomoo`06Ool00`00O01l000BO0000`00
O01l000CO0000`00O01l000CO0000`00Oomoo`04Ool00`0OOomoo`0QOol001Eoo`@000Aoo`03001o
ogoo08]oo`0301moogoo00Ioo`03001l07`0019l0003001l07`001=l0003001l07`001=l0003001o
ogoo00Aoo`0301moogoo025oo`005Woo00<007ooOol017oo00<007ooOol0RWoo00<07gooOol01goo
00<007`0O0004W`000<007`0O0004g`000<007`0O0004g`000<007ooOol017oo00<07gooOol08Goo
000?Ool50003Ool00`00Oomoo`03Ool3001nOol<00000`0O00000008000DO0000`00O01l000CO000
0`00O01l000CO0000`00Oomoo`05Ool00`0OOomoo`0POol001Qoo`03001oogoo009oo`03001oogoo
07ioo`03001l07`000Ql000301ml07`000Ql0003001l07`0019l0003001l07`001=l0003001l07`0
01=l0003001oogoo00Eoo`0301moogoo021oo`005Goo00@007ooOol000Aoo`03001oogoo07ioo`03
001l07`000Ql000301ml07`000Ql0003001l07`0019l0003001l07`001=l0003001l07`001=l0003
001oogoo00Ioo`0301moogoo01moo`005Woo0P001Goo00<007ooOol0OWoo00<007`0O0001g`000<0
7g`0O0002G`000<007`0O0004W`000<007`0O0004g`000<007`0O0004g`000<007ooOol01Woo00<0
7gooOol07goo000MOol00`00Oomoo`1nOol00`00O01l0007O0000`0OO01l0009O0000`00O01l000B
O0000`00O01l000CO0000`00O01l000CO0000`00Oomoo`06Ool00`0OOomoo`0OOol001eoo`8007mo
o`03001l07`000Il000301ml07`000Yl0003001l07`0019l0003001l07`001=l0003001l07`001=l
0003001oogoo00Moo`0301moogoo01ioo`007Goo00<007ooOol0OWoo00<007`0O0001W`000<07g`0
O0002W`000<007`0O0004W`000<007`0O0004g`000<007`0O0004g`000<007ooOol01goo00<07goo
Ool07Woo000MOol00`00Oomoo`1nOol00`00O01l0005O0000`0OO01l000;O0000`00O01l000BO000
0`00O01l000CO0000`00O01l000CO00:00000`0O00000009000EOol001eoo`03001oogoo07ioo`03
001l07`000El000301ml07`000]l0003001l07`0019l0003001l07`001=l0003001l07`001=l0003
001l07`000Ql000301ml07`000Ml0003001oogoo01=oo`007Goo0P00Ogoo00<007`0O00017`000<0
7g`0O00037`000<007`0O0004W`000<007`0O0004g`000<007`0O0004g`000<007`0O00027`000<0
7g`0O0001g`000<007ooOol04goo000MOol00`00Oomoo`1nOol00`00O01l0004O0000`0OO01l000<
O0000`00O01l000BO0000`00O01l000CO0000`00O01l000CO0000`00O01l0008O0000`0OO01l0007
O0000`00Oomoo`0COol001eoo`03001oogoo07ioo`03001l07`000=l000301ml07`000el0003001l
07`0019l0003001l07`001=l0003001l07`001=l0003001l07`000Ul000301ml07`000Il0003001o
ogoo01=oo`007Goo00<007ooOol0OWoo00<007`0O0000g`000<07g`0O0003G`000<007`0O0004W`0
00<007`0O0004g`000<007`0O0004g`000<007`0O0002G`000<07g`0O0001W`000<007ooOol04goo
000MOol00`00Oomoo`1nOol00`00O01l0002O0000`0OO01l000>O0000`00O01l000BO0000`00O01l
000CO0000`00O01l000CO0000`00O01l0009O0000`0OO01l0006O0000`00Oomoo`0COol001eoo`80
07moo`03001l07`0009l000301ml07`000il0003001l07`0019l0003001l07`001=l0003001l07`0
01=l0003001l07`000Yl000301ml07`000El0003001oogoo01=oo`007Goo00<007ooOol0OWoo00<0
07`0O0000W`000<07g`0O0003W`000<007`0O0004W`000<007`0O0004g`000<007`0O0004g`000<0
07`0O0002W`000<07g`0O0001G`000<007ooOol04goo000MOol00`00Oomoo`1nOol01@00O01l07`0
01l04G`000<007`0O0004W`000<007`0O0004g`000<007`0O0004g`000<007`0O0002W`000<07g`0
O0001G`000<007ooOol04goo000MOol00`00Oomoo`1nOol01@00O01l07`001l04G`000<007`0O000
4W`000<007`0O0004g`000<007`0O0004g`000<007`0O0002W`000<07g`0O0001G`000<007ooOol0
4goo000MOol2001oOol01000O01l000O4W`000<007`0O0004W`000<007`0O0004g`000<007`0O000
4g`000<007`0O0002g`000<07g`0O00017`000<007ooOol04goo000MOol00`00Oomoo`1nOol01000
O01l000O4W`000<007`0O0004W`000<007`0O0004g`000<007`0O0004g`000<007`0O0002g`000<0
7g`0O00017`000<007ooOol04goo000EOol30005Ool00`00Oomoo`1nOol00`00O0007`0CO0000`00
O01l000BO0000`00O01l000CO0000`00O01l000CO0000`00O01l000;O0000`0OO01l0004O0000`00
Oomoo`0COol001Ioo`03001oogoo00Aoo`03001oogoo07ioo`03001l000O01=l0003001l07`0019l
0003001l07`001=l0003001l07`001=l0003001l07`000al000301ml07`000=l0003001oogoo01=o
o`003goo1@000Woo00<007ooOol017oo0`00OWoo00<0000OO0004g`000<007`0O0004W`000<007`0
O0004g`000<007`0O0004g`000<007`0O00037`000<07g`0O0000g`000<007ooOol04goo000FOol0
0`00Oomoo`04Ool00`00Oomoo`1nOol00`0001ml000CO0000`00O01l000BO0000`00O01l000CO000
0`00O01l000CO0000`00O01l000<O0000`0OO01l0003O0000`00Oomoo`0COol001Ioo`03001oogoo
00Aoo`03001oogoo07ioo`0301ml07`001=l0003001l07`0019l0003001l07`001=l0003001l07`0
01=l0003001l07`000al000301ml07`000=l0003001oogoo01=oo`005Goo0P001Woo00<007ooOol0
OWoo00<07g`0O0004g`000<007`0O0004W`000<007`0O0004g`000<007`0O0004g`000<007`0O000
3G`000<07g`0O0000W`000<007ooOol04goo000MOol00`00Oomoo`1mOol00`0O001l000DO0000`00
O01l000BO0000`00O01l000CO0000`00O01l000CO0000`00O01l000=O0000`0OO01l0002O0000`00
Oomoo`0COol001eoo`8007ioo`0301l007`001Al0003001l07`0019l0003001l07`001=l0003001l
07`001=l0003001l07`000el000301ml07`0009l0003001oogoo01=oo`007Goo00<007ooOol0O7oo
00<07goo00005G`000<007`0O0004W`000<007`0O0004g`000<007`0O0004g`000<007`0O0003G`0
00<07g`0O0000W`000<007ooOol04goo000MOol00`00Oomoo`1lOol00`0OOol0000EO0000`00O01l
000BO0000`00O01l000CO0000`00O01l000CO0000`00O01l000>O0001@0OO01l07`000005Goo000M
Ool00`00Oomoo`1kOol0100OOomoo`005G`000<007`0O0004W`000<007`0O0004g`000<007`0O000
4g`000<007`0O0003W`000D07g`0O01l000001Eoo`007Goo0P00O7oo00@07gooOol001El0003001l
07`0019l0003001l07`001=l0003001l07`001=l0003001l07`000il000501ml07`0O000000EOol0
01eoo`03001oogoo07Yoo`0501moogooOol0000EO0000`00O01l000BO0000`00O01l000CO0000`00
O01l000CO0000`00O01l000>O0001@0OO01l07`000005Goo000MOol00`00Oomoo`1jOol01@0OOomo
ogoo00005G`000<007`0O0004W`000<007`0O0004g`000<007`0O0004g`000<007`0O0003g`000@0
7g`0O00001Eoo`007Goo00<007ooOol08Goo0`008goo10008Goo0`002Woo00<07gooOol00Woo00<0
07`0O0004g`000<007`0O0004W`000<007`0O0004g`000<007`0O0004g`000<007`0O0003g`000@0
7g`0O00001Eoo`007Goo00<007ooOol08Woo00<007ooOol08goo00<007ooOol097oo00<007ooOol0
1goo00<07gooOol00Woo00<007`0O0004g`000<007`0O0004W`000<007`0O0004g`000<007`0O000
4g`000<007`0O0003g`000@07g`0O00001Eoo`007Goo0P008goo00<007ooOol097oo00<007ooOol0
8goo00<007ooOol01Woo00<07gooOol00goo00<007`0O0004g`000<007`0O0004W`000<007`0O000
4g`000<007`0O0004g`000<007`0O0003g`000@07g`0O00001Eoo`007Goo00<007ooOol08Woo00<0
07ooOol09Goo00<007ooOol087oo0P002Goo00<07gooOol00goo00<007`0O0004g`000<007`0O000
4W`000<007`0O0004g`000<007`0O0004g`000<007`0O00047`000<07g`000005Goo000MOol00`00
Oomoo`0ROol00`00Oomoo`0ROol01000Oomoo`0097oo00<007ooOol01Goo00<07gooOol017oo00<0
07`0O0004g`000<007`0O0004W`000<007`0O0004g`000<007`0O0004g`000<007`0O00047`000<0
7g`000005Goo000MOol00`00Oomoo`0QOol2000UOol2000ROol30008Ool00`0OOomoo`04Ool00`00
O01l000CO0000`00O01l000BO0000`00O01l000CO0000`00O01l000CO0000`00O01l000@O0000`0O
O000000EOol001eoo`8007Moo`0301moogoo00Eoo`03001l07`001=l0003001l07`0019l0003001l
07`001=l0003001l07`001=l0003001l07`0015l000301l007oo01Aoo`007Goo00<007ooOol0MWoo
00<07gooOol01Goo00<007`0O0004g`000<007`0O0004W`000<007`0O0004g`000<007`0O0004g`0
00<007`0O0004G`000<07`00Ool057oo000MOol00`00Oomoo`1eOol00`0OOomoo`06Ool00`00O01l
000CO0000`00O01l000BO0000`00O01l000CO0000`00O01l000CO0000`00O01l000AO0000`0O001o
o`0DOol001eoo`03001oogoo07Eoo`0301moogoo00Ioo`03001l07`001=l0003001l07`0019l0003
001l07`001=l0003001l07`001=l0003001l07`0015l000301l007oo01Aoo`007Goo00<007ooOol0
JGoo00<007ooOol027oo00<07gooOol01goo0P0057`000<007`0O0004W`000<007`0O0004g`000<0
07`0O0004g`000<007`0O0004W`000<07gooOol04goo000GOol6000:01m]00000`0O00000008000E
O0000`00O01l000BO0000`00O01l000CO0000`00O01l000CO0000`00O01l000BO0000`0O00000004
000?Ool001eoo`X000807`/001Al0003001l07`001=l0003001l07`0019l0003001l07`001=l0003
001oogoo009oo`03001oogoo009oo`0301moogoo01ioo`03001oogoo02=oo`03001oogoo029oo`03
001oogoo01ioo`007Goo00<007ooOol02Goo0`0O1goo00<007`0O0004W`000<007`0O0004g`000<0
07`0O0004W`000<007`0O0004g`000<007ooOol01Woo00<07gooOol0Rgoo000MOol00`00Oomoo`0<
Ool201l5Ool00`00O01l000BO0000`00O01l000CO0000`00O01l000BO0000`00O01l000CO0000`00
Oomoo`06Ool00`0OOomoo`2;Ool001eoo`8000moo`807`=oo`03001l07`0019l0003001l07`001=l
0003001l07`0019l0003001l07`001=l0003001oogoo00Eoo`0301moogoo08aoo`007Goo00<007oo
Ool047oo00@07gooOol001Al0003001l07`001=l0003001l07`0019l0003001l07`001=l0003001o
ogoo00Eoo`0301moogoo08aoo`007Goo00<007ooOol04Goo0P0O00<007`0O0004W`000<007`0O000
4g`000<007`0O0004W`000<007`0O0004g`000<007ooOol017oo00<07gooOol0SGoo000MOol00`00
Oomoo`0COol201lCO0000`00O01l000CO0000`00O01l000BO0000`00O01l000CO0000`00Oomoo`03
Ool00`0OOomoo`2>Ool001eoo`8001Aoo`03001l000O019l0003001l07`001=l0003001l07`0019l
0003001l07`001=l0003001oogoo00=oo`0301moogoo08ioo`007Goo00<007ooOol04goo00<007`0
O0000P0O47`000<007`0O0004g`000<007`0O0004W`000<007`0O0004g`000<007ooOol00Woo00<0
7gooOol0Sgoo000MOol00`00Oomoo`0COol00`00O01l0002O00201l>O0000`00O01l000CO0000`00
O01l000BO0000`00O01l000CO0001@00Oomoogoo01l0TWoo000MOol00`00Oomoo`0COol00`00O01l
0004O0000`0OO01l000;O0000`00O01l000CO0000`00O01l000BO0000`00O01l000CO0001@00Oomo
ogoo01l0TWoo000MOol00`00Oomoo`0COol00`00O01l0005O00201l;O0000`00O01l000CO0000`00
O01l000BO0000`00O01l000CO0001000Oomoo`0OTgoo000MOol2000DOol00`00O01l0007O0000`0O
O01l0008O0000`00O01l000CO0000`00O01l000BO0000`00O01l000CO0001000Oomoo`0OTgoo000M
Ool00`00Oomoo`0COol;00000`0O00000008000EO0000`00O01l000BO0000`00O01l000CO0000`00
Ool07`2DOol001eoo`03001oogoo01moo`0301moogoo00Ioo`03001l07`001=l0003001l07`0019l
0003001l07`001=l000300007goo09Aoo`007Goo00<007ooOol087oo0P0O1Woo00<007`0O0004g`0
00<007`0O0004W`000<007`0O0004g`000<0000OOol0U7oo000MOol2000SOol00`0OOomoo`03Ool0
0`00O01l000CO0000`00O01l000BO0000`00O01l000CO0000`0OOomoo`2DOol001eoo`03001oogoo
02=oo`0301moogoo009oo`03001l07`001=l0003001l07`0019l0003001l07`0019l000301l007oo
09Eoo`007Goo00<007ooOol097oo00D07gooOomoo`0001El0003001l07`0019l0003001l07`0015l
000301ml000009Ioo`005Goo0`001Goo00<007ooOol09Goo0P0O00=oo`00O00057`000<007`0O000
4W`000<007`0O0004G`000<07g`00000UWoo000FOol00`00Oomoo`04Ool00`00Oomoo`0WOol00`0O
001l000DO0000`00O01l000BO0000`00O01l000@O000100OO01l0000UWoo000FOol00`00Oomoo`04
Ool3000XOol00`0OO01l000CO0000`00O01l000BO0000`00O01l000?O0001@0OO01l07`00000UWoo
000FOol00`00Oomoo`04Ool00`00Oomoo`0XOol00`0001ml000CO0000`00O01l000BO0000`00O01l
000>O0000`0OO01l0002O0000`00Oomoo`2DOol001Ioo`03001oogoo00Aoo`03001oogoo02Qoo`04
001l000O01lBO0000`00O01l000BO0000`00O01l000=O0000`0OO01l0003O0000`00Oomoo`2DOol0
01Eoo`8000Ioo`03001oogoo02Qoo`05001l07`0O0007`0AO0000`00O01l000BO0000`00O01l000=
O0000`0OO01l0003O0000`00Oomoo`2DOol001eoo`8002Uoo`03001l07`0009l000301ml07`000il
0003001l07`0019l0003001l07`000al000301ml07`000Al0003001oogoo09Aoo`007Goo00<007oo
Ool0:7oo00<007`0O0000g`000<07g`0O0003G`000<007`0O0004W`000<007`0O0002g`000<07g`0
O0001G`000<007ooOol0U7oo000MOol00`00Oomoo`0XOol00`00O01l0004O00201l=O0000`00O01l
000BO0000`00O01l000:O0000`0OO01l0006O0000`00Oomoo`2DOol001eoo`03001oogoo02Qoo`03
001l07`000Il000301ml07`000Yl0003001l07`0019l0003001l07`000Ul000301ml07`000Ml0003
001oogoo09Aoo`007Goo0P00:Goo00<007`0O0001g`00P0O2W`000<007`0O0004W`02`0000<07`00
00002@00UWoo000MOol00`00Oomoo`0XOol<00000`0O00000008000DO0000`00Oomoo`07Ool00`0O
Oomoo`2POol001eoo`03001oogoo03Eoo`807`Moo`03001l07`0019l0003001oogoo00Eoo`807j=o
o`007Goo00<007ooOol0=goo00<07gooOol017oo00<007`0O0004W`000<007ooOol017oo00<07goo
Ool0Xgoo000MOol00`00Oomoo`0hOol201l4Ool00`00O01l000BO0000`00Oomoo`03Ool00`0OOomo
o`2TOol001eoo`8003]oo`0501moogooOol0000DO0000`00Oomoo`02Ool00`0OOomoo`2UOol001eo
o`03001oogoo03]oo`<07`03001l07`0019l0003001oogoo00807jQoo`007Goo00<007ooOol0?Woo
0P0O4g`00`0OZWoo000MOol00`00Oomoo`0nOol00`00O0007`0201l>O00201l00`00Oomoo`2ZOol0
01eoo`8003moo`03001l07`0009l00@07`Il00@07`9l0003001oogoo0:Yoo`007Goo00<007ooOol0
?Woo2@001P0O1`00[7oo000MOol00`00Oomoo`3oOol1Ool001eoo`03001oogoo0?moo`5oo`007Goo
00<007ooOol0ogoo0Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo
8Goo003oOolQOol00?moob5oo`00?7oo1P001Woo0`000goo100017oo0`001Goo0`000goo100000=o
o`0000000P000Woo0P001Goo2P0000=oo`0000000P000Woo100017oo10000goo100067oo1P000goo
0P000Woo1@0017oo1@0017oo1@001Goo0P001Woo1`00=Woo000nOol20007Ool20002Ool01000Oomo
ogoo0P0017oo0P000Woo00@007ooOomoo`80009oo`04001oogooOol20003Ool20002Ool200000goo
001oo`05Ool20005Ool200000goo00000004Ool20004Ool20002Ool20003Ool2000KOol20005Ool2
0002Ool20003Ool20002Ool20003Ool20002Ool20003Ool20005Ool20005Ool6000fOol003ioo`80
00Ioo`8000Aoo`03001oogoo008000=oo`8000Aoo`04001oo`000004Ool00`00Oomoo`020003Ool2
0002Ool20008Ool20006Ool01000Ool0000017oo0P000goo0P0017oo0P000Woo0P002Goo2@002Goo
0P003goo00<007ooOol01Woo00<007ooOol01Woo00<007ooOol017oo0P001Goo00<007ooOol00Woo
00<007ooOol0<goo000nOol20006Ool20007Ool20003Ool20006Ool20007Ool20003Ool20002Ool2
0008Ool20008Ool20004Ool20003Ool20004Ool20002Ool2000KOol2000?Ool20007Ool20007Ool2
0006Ool20004Ool2000iOol003ioo`8000Ioo`8000Moo`8000=oo`8000Ioo`8000Moo`8000=oo`80
009oo`8000Qoo`8000Aoo`04001oogooOol20004Ool20003Ool20004Ool20002Ool2000KOol2000?
Ool20007Ool20007Ool20006Ool20005Ool00`00Oomoo`0gOol003ioo`H0009oo`L0009oo`8000=o
o`8000Aoo`03001oo`0000H0009oo`8000=oo`80009oo`8000Qoo`8000Aoo`04001oogooOol20004
Ool20003Ool20004Ool20002Ool2000KOol2000?Ool20006Ool30007Ool20003Ool60005Ool00`00
Oomoo`0fOol003ioo`8000=oo`80009oo`04001oogooOol200000goo0000000400000goo00000002
Ool20002Ool01000Oomoogoo0P0000=oo`0000000P000Woo0P000Woo0P0027oo1`000Woo300000=o
o`0000000Woo0P000Woo1P001Woo2@002Goo0P003Woo0`0017oo10001goo0`000Woo0P000goo0P00
1Goo0P00=goo000nOol20004Ool20002Ool40004Ool01000Ool000000Woo100017oo100017oo00<0
07oo00000P000Woo1@001Woo0P0017oo00<007ooOol00Woo00@007oo0000009oo`04001oo`000002
Ool40005Ool01000Ool0000067oo0P002goo1@000Woo1P001Goo1@000Woo0P0017oo0P001Woo00<0
07ooOol0=Goo000nOol20004Ool2000XOol20008Ool20004Ool00`00Oomoo`0cOol2000=Ool00`00
Oomoo`03Ool40008Ool00`00Oomoo`02Ool20004Ool20006Ool2000fOol003ioo`8000Aoo`8002Uo
o`03001oogoo00Ioo`8003Yoo`8000ioo`03001oogoo009oo`03001oogoo00Yoo`04001oogooOol2
0004Ool200000goo001oo`03Ool2000fOol003ioo`8000Aoo`80039oo`8000Eoo`03001oogoo039o
o`8000Uoo`03001oogoo009oo`8000Aoo`03001oogoo00Aoo`03001oogoo009oo`80009oo`8000Ao
o`800003Ool00000009oo`<003Ioo`00?Woo0P000goo0P00<goo0P001Goo00<007ooOol0<7oo1000
2Woo00<007ooOol00`0017oo1@000goo00<007ooOol00`000goo0P000Woo0P000goo1@00=goo000l
Ool8000bOol:000dOol2000;Ool40005Ool60003Ool40005Ool40005Ool3000hOol00?moob5oo`00
ogoo8Goo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.783823, -4.98036, 
  0.0265065, 0.0452841}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.151576 0.44187 0.0887232 [
[.17539 .42937 -3 -9 ]
[.17539 .42937 3 0 ]
[.32696 .42937 -3 -9 ]
[.32696 .42937 3 0 ]
[.47854 .42937 -3 -9 ]
[.47854 .42937 3 0 ]
[.63011 .42937 -3 -9 ]
[.63011 .42937 3 0 ]
[.78169 .42937 -3 -9 ]
[.78169 .42937 3 0 ]
[.93327 .42937 -3 -9 ]
[.93327 .42937 3 0 ]
[.01131 .08698 -12 -4.5 ]
[.01131 .08698 0 4.5 ]
[.01131 .1757 -12 -4.5 ]
[.01131 .1757 0 4.5 ]
[.01131 .26442 -12 -4.5 ]
[.01131 .26442 0 4.5 ]
[.01131 .35315 -12 -4.5 ]
[.01131 .35315 0 4.5 ]
[.01131 .53059 -6 -4.5 ]
[.01131 .53059 0 4.5 ]
[.5 .63053 -89.5938 0 ]
[.5 .63053 89.5938 20 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.17539 .44187 m
.17539 .44812 L
s
[(1)] .17539 .42937 0 1 Mshowa
.32696 .44187 m
.32696 .44812 L
s
[(2)] .32696 .42937 0 1 Mshowa
.47854 .44187 m
.47854 .44812 L
s
[(3)] .47854 .42937 0 1 Mshowa
.63011 .44187 m
.63011 .44812 L
s
[(4)] .63011 .42937 0 1 Mshowa
.78169 .44187 m
.78169 .44812 L
s
[(5)] .78169 .42937 0 1 Mshowa
.93327 .44187 m
.93327 .44812 L
s
[(6)] .93327 .42937 0 1 Mshowa
.125 Mabswid
.05412 .44187 m
.05412 .44562 L
s
.08444 .44187 m
.08444 .44562 L
s
.11476 .44187 m
.11476 .44562 L
s
.14507 .44187 m
.14507 .44562 L
s
.2057 .44187 m
.2057 .44562 L
s
.23602 .44187 m
.23602 .44562 L
s
.26633 .44187 m
.26633 .44562 L
s
.29665 .44187 m
.29665 .44562 L
s
.35728 .44187 m
.35728 .44562 L
s
.38759 .44187 m
.38759 .44562 L
s
.41791 .44187 m
.41791 .44562 L
s
.44822 .44187 m
.44822 .44562 L
s
.50885 .44187 m
.50885 .44562 L
s
.53917 .44187 m
.53917 .44562 L
s
.56948 .44187 m
.56948 .44562 L
s
.5998 .44187 m
.5998 .44562 L
s
.66043 .44187 m
.66043 .44562 L
s
.69074 .44187 m
.69074 .44562 L
s
.72106 .44187 m
.72106 .44562 L
s
.75137 .44187 m
.75137 .44562 L
s
.81201 .44187 m
.81201 .44562 L
s
.84232 .44187 m
.84232 .44562 L
s
.87264 .44187 m
.87264 .44562 L
s
.90295 .44187 m
.90295 .44562 L
s
.96358 .44187 m
.96358 .44562 L
s
.9939 .44187 m
.9939 .44562 L
s
.25 Mabswid
0 .44187 m
1 .44187 L
s
.02381 .08698 m
.03006 .08698 L
s
[(-4)] .01131 .08698 1 0 Mshowa
.02381 .1757 m
.03006 .1757 L
s
[(-3)] .01131 .1757 1 0 Mshowa
.02381 .26442 m
.03006 .26442 L
s
[(-2)] .01131 .26442 1 0 Mshowa
.02381 .35315 m
.03006 .35315 L
s
[(-1)] .01131 .35315 1 0 Mshowa
.02381 .53059 m
.03006 .53059 L
s
[(1)] .01131 .53059 1 0 Mshowa
.125 Mabswid
.02381 .016 m
.02756 .016 L
s
.02381 .03374 m
.02756 .03374 L
s
.02381 .05149 m
.02756 .05149 L
s
.02381 .06923 m
.02756 .06923 L
s
.02381 .10472 m
.02756 .10472 L
s
.02381 .12247 m
.02756 .12247 L
s
.02381 .14021 m
.02756 .14021 L
s
.02381 .15796 m
.02756 .15796 L
s
.02381 .19344 m
.02756 .19344 L
s
.02381 .21119 m
.02756 .21119 L
s
.02381 .22893 m
.02756 .22893 L
s
.02381 .24668 m
.02756 .24668 L
s
.02381 .28217 m
.02756 .28217 L
s
.02381 .29991 m
.02756 .29991 L
s
.02381 .31766 m
.02756 .31766 L
s
.02381 .3354 m
.02756 .3354 L
s
.02381 .37089 m
.02756 .37089 L
s
.02381 .38864 m
.02756 .38864 L
s
.02381 .40638 m
.02756 .40638 L
s
.02381 .42413 m
.02756 .42413 L
s
.02381 .45961 m
.02756 .45961 L
s
.02381 .47736 m
.02756 .47736 L
s
.02381 .4951 m
.02756 .4951 L
s
.02381 .51285 m
.02756 .51285 L
s
.02381 .54834 m
.02756 .54834 L
s
.02381 .56608 m
.02756 .56608 L
s
.02381 .58383 m
.02756 .58383 L
s
.02381 .60157 m
.02756 .60157 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -150.594 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 24.000000 moveto
 558.000000 24.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 24.000000 lineto
closepath
clip newpath
63.000000 19.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 18.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 19.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 18.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Percent) show
121.250000 19.000000 moveto
(Error) show
163.625000 19.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 18.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(=) show
179.687500 19.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 18.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1.13841) show
238.187500 19.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 18.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
0 0 1 r
.007 w
.02381 .44187 m
.02499 .44188 L
.02605 .44189 L
.02729 .44192 L
.02846 .44195 L
.03053 .44204 L
.03279 .44218 L
.03527 .44238 L
.0379 .44264 L
.04262 .44323 L
.04749 .44403 L
.05205 .44493 L
.06244 .44757 L
.07305 .45107 L
.08274 .45495 L
.10458 .46589 L
.14429 .4922 L
.18248 .52229 L
.22313 .55474 L
.26226 .58144 L
.27254 .5871 L
.28367 .59241 L
.29328 .59624 L
.29838 .59795 L
.30384 .59955 L
.30923 .60086 L
.31415 .60182 L
.31652 .6022 L
.31909 .60255 L
.32151 .60282 L
.32378 .60303 L
.32509 .60312 L
.3263 .60319 L
.32764 .60325 L
.32834 .60327 L
.32908 .60329 L
.32976 .60331 L
.33048 .60332 L
.33177 .60332 L
.33257 .60331 L
.33332 .6033 L
.33399 .60328 L
.33472 .60326 L
.33594 .60321 L
.33728 .60313 L
.33999 .60292 L
.34249 .60266 L
.34484 .60235 L
.34982 .60149 L
.35525 .60023 L
Mistroke
.36513 .59709 L
.37475 .59294 L
.38367 .58812 L
.40423 .57339 L
.42285 .55569 L
.46297 .50405 L
.50157 .43897 L
.54262 .35759 L
.58216 .27326 L
.62019 .19318 L
.66067 .11668 L
.69963 .05896 L
.70983 .04728 L
.72091 .03645 L
.73048 .02875 L
.73557 .02531 L
.74104 .02213 L
.74638 .01956 L
.75126 .01767 L
.75594 .01629 L
.75829 .01576 L
.76085 .0153 L
.76227 .01511 L
.76362 .01496 L
.76482 .01485 L
.76612 .01477 L
.7668 .01474 L
.76755 .01472 L
.76833 .01472 L
.76905 .01472 L
.77035 .01475 L
.77108 .01478 L
.77175 .01482 L
.77304 .01492 L
.77424 .01504 L
.77695 .01543 L
.77933 .0159 L
.78187 .01653 L
.78675 .0181 L
.79123 .01999 L
.80132 .02578 L
.81022 .03269 L
.81959 .04179 L
.83931 .06705 L
.85767 .09794 L
.89668 .18599 L
.93815 .30895 L
.97619 .44187 L
Mfstroke
1 0 0 r
.02381 .44187 m
.10317 .44187 L
.10317 .44788 L
.02381 .44788 L
F
.10317 .44187 m
.18254 .44187 L
.18254 .49114 L
.10317 .49114 L
F
.18254 .44187 m
.2619 .44187 L
.2619 .55405 L
.18254 .55405 L
F
.2619 .44187 m
.34127 .44187 L
.34127 .59892 L
.2619 .59892 L
F
.34127 .44187 m
.42063 .44187 L
.42063 .58969 L
.34127 .58969 L
F
.42063 .44187 m
.5 .44187 L
.5 .508 L
.42063 .508 L
F
.5 .44187 m
.57937 .44187 L
.57937 .36372 L
.5 .36372 L
F
.57937 .44187 m
.65873 .44187 L
.65873 .1955 L
.57937 .1955 L
F
.65873 .44187 m
.7381 .44187 L
.7381 .06045 L
.65873 .06045 L
F
.7381 .44187 m
.81746 .44187 L
.81746 .01558 L
.7381 .01558 L
F
.81746 .44187 m
.89683 .44187 L
.89683 .09696 L
.81746 .09696 L
F
.89683 .44187 m
.97619 .44187 L
.97619 .3036 L
.89683 .3036 L
F
0 g
.5 Mabswid
.02381 .44187 m
.02381 .44788 L
s
.10317 .44187 m
.10317 .44788 L
s
.02381 .44788 m
.10317 .44788 L
s
.10317 .44187 m
.10317 .49114 L
s
.18254 .44187 m
.18254 .49114 L
s
.10317 .49114 m
.18254 .49114 L
s
.18254 .44187 m
.18254 .55405 L
s
.2619 .44187 m
.2619 .55405 L
s
.18254 .55405 m
.2619 .55405 L
s
.2619 .44187 m
.2619 .59892 L
s
.34127 .44187 m
.34127 .59892 L
s
.2619 .59892 m
.34127 .59892 L
s
.34127 .44187 m
.34127 .58969 L
s
.42063 .44187 m
.42063 .58969 L
s
.34127 .58969 m
.42063 .58969 L
s
.42063 .44187 m
.42063 .508 L
s
.5 .44187 m
.5 .508 L
s
.42063 .508 m
.5 .508 L
s
.5 .44187 m
.5 .36372 L
s
.57937 .44187 m
.57937 .36372 L
s
.5 .36372 m
.57937 .36372 L
s
.57937 .44187 m
.57937 .1955 L
s
.65873 .44187 m
.65873 .1955 L
s
.57937 .1955 m
.65873 .1955 L
s
.65873 .44187 m
.65873 .06045 L
s
.7381 .44187 m
.7381 .06045 L
s
.65873 .06045 m
.7381 .06045 L
s
.7381 .44187 m
.7381 .01558 L
s
.81746 .44187 m
.81746 .01558 L
s
.7381 .01558 m
.81746 .01558 L
s
.81746 .44187 m
.81746 .09696 L
s
.89683 .44187 m
.89683 .09696 L
s
.81746 .09696 m
.89683 .09696 L
s
.89683 .44187 m
.89683 .3036 L
s
.97619 .44187 m
.97619 .3036 L
s
.89683 .3036 m
.97619 .3036 L
s
0 0 1 r
.007 w
.02381 .44187 m
.02499 .44188 L
.02605 .44189 L
.02729 .44192 L
.02846 .44195 L
.03053 .44204 L
.03279 .44218 L
.03527 .44238 L
.0379 .44264 L
.04262 .44323 L
.04749 .44403 L
.05205 .44493 L
.06244 .44757 L
.07305 .45107 L
.08274 .45495 L
.10458 .46589 L
.14429 .4922 L
.18248 .52229 L
.22313 .55474 L
.26226 .58144 L
.27254 .5871 L
.28367 .59241 L
.29328 .59624 L
.29838 .59795 L
.30384 .59955 L
.30923 .60086 L
.31415 .60182 L
.31652 .6022 L
.31909 .60255 L
.32151 .60282 L
.32378 .60303 L
.32509 .60312 L
.3263 .60319 L
.32764 .60325 L
.32834 .60327 L
.32908 .60329 L
.32976 .60331 L
.33048 .60332 L
.33177 .60332 L
.33257 .60331 L
.33332 .6033 L
.33399 .60328 L
.33472 .60326 L
.33594 .60321 L
.33728 .60313 L
.33999 .60292 L
.34249 .60266 L
.34484 .60235 L
.34982 .60149 L
.35525 .60023 L
Mistroke
.36513 .59709 L
.37475 .59294 L
.38367 .58812 L
.40423 .57339 L
.42285 .55569 L
.46297 .50405 L
.50157 .43897 L
.54262 .35759 L
.58216 .27326 L
.62019 .19318 L
.66067 .11668 L
.69963 .05896 L
.70983 .04728 L
.72091 .03645 L
.73048 .02875 L
.73557 .02531 L
.74104 .02213 L
.74638 .01956 L
.75126 .01767 L
.75594 .01629 L
.75829 .01576 L
.76085 .0153 L
.76227 .01511 L
.76362 .01496 L
.76482 .01485 L
.76612 .01477 L
.7668 .01474 L
.76755 .01472 L
.76833 .01472 L
.76905 .01472 L
.77035 .01475 L
.77108 .01478 L
.77175 .01482 L
.77304 .01492 L
.77424 .01504 L
.77695 .01543 L
.77933 .0159 L
.78187 .01653 L
.78675 .0181 L
.79123 .01999 L
.80132 .02578 L
.81022 .03269 L
.81959 .04179 L
.83931 .06705 L
.85767 .09794 L
.89668 .18599 L
.93815 .30895 L
.97619 .44187 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00O7Goo00<007ooOol0
ogoo0Goo000MOol00`00Oomoo`3oOol1Ool001eoo`03001oogoo0?moo`5oo`007Goo00<007ooOol0
[goo1@001P0O2P00?7oo000MOol2002`Ool00`00O0007`0201l5O00301l7O0000`00Oomoo`0jOol0
01eoo`03001oogoo0:moo`807`]l00<07`Al0003001oogoo03Yoo`007Goo00<007ooOol0[Woo00<0
7`00O0003W`000D07g`0O01l000003aoo`007Goo00<007ooOol0[Goo00<07goo000047`000@07g`0
O00003aoo`007Goo0P00[Goo00@07gooOol0015l000301ml000003aoo`007Goo00<007ooOol0ZWoo
0P0O0goo00<007`0O00047`000<07`00Ool0>goo000MOol00`00Oomoo`2YOol00`0OOomoo`03Ool0
0`00O01l000AO0000`0OOomoo`0jOol001eoo`03001oogoo0:Qoo`0301moogoo00Aoo`03001l07`0
015l000301moogoo03Yoo`007Goo0P00Z7oo00<07gooOol01Goo00<007`0O0004G`000<0000OOol0
>Woo000MOol00`00Oomoo`2VOol00`0OOomoo`06Ool00`00O01l000AO0000`00Ool07`0jOol001eo
o`03001oogoo0:Eoo`0301moogoo00Moo`03001l07`0015l0004001oogoo01liOol001eoo`03001o
ogoo09]oo`X0000301l0000000P001=l0005001oogooOol07`0hOol001eoo`03001oogoo09]oo`03
001l07`000Il000301ml07`000Ql0003001l07`0015l0003001oogoo009oo`0301moogoo03Eoo`00
7Goo0P00W7oo00<007`0O0001G`000<07g`0O0002G`000<007`0O0004G`000<007ooOol00Woo00<0
7gooOol0=Goo000MOol00`00Oomoo`2KOol00`00O01l0005O0000`0OO01l0009O0000`00O01l000A
O0000`00Oomoo`03Ool00`0OOomoo`0dOol001Ioo`<000Aoo`03001oogoo09]oo`03001l07`000Al
000301ml07`000Yl0003001l07`0015l0003001oogoo00Aoo`0301moogoo03=oo`005goo00<007oo
Ool00goo00<007ooOol0Vgoo00<007`0O00017`000<07g`0O0002W`000<007`0O0004G`000<007oo
Ool017oo00<07gooOol0<goo000?Ool500000goo000000020004Ool3002KOol00`00O01l0003O000
0`0OO01l000;O0000`00O01l000AO0000`00Oomoo`05Ool00`0OOomoo`0bOol001Eoo`03001oo`00
00Eoo`03001oogoo09]oo`03001l07`0009l000301ml07`000al0003001l07`0015l0003001oogoo
00Eoo`0301moogoo039oo`005Goo00<007oo00001Goo00<007ooOol0Vgoo00<007`0O0000W`000<0
7g`0O00037`000<007`0O0004G`000<007ooOol01Woo00<07gooOol0<Goo000FOol20005Ool00`00
Oomoo`2KOol01@00O01l07`001l03g`000<007`0O0004G`02P0000<07`0000001`00:Goo000MOol0
0`00Oomoo`2KOol01@00O01l07`001l03g`000<007`0O0004G`000<007`0O0001g`000<07g`0O000
1W`000<007ooOol09goo000MOol2002LOol01000O01l000O47`000<007`0O0004G`000<007`0O000
27`000<07g`0O0001G`000<007ooOol09goo000MOol00`00Oomoo`2KOol00`00O0007`0AO0000`00
O01l000AO0000`00O01l0008O0000`0OO01l0005O0000`00Oomoo`0WOol001eoo`03001oogoo09]o
o`03001l000O015l0003001l07`0015l0003001l07`000Ql000301ml07`000El0003001oogoo02Mo
o`007Goo00<007ooOol0Vgoo00<0000OO0004G`000<007`0O0004G`000<007`0O0002G`000<07g`0
O00017`000<007ooOol09goo000MOol2002LOol00`0001ml000AO0000`00O01l000AO0000`00O01l
0009O0000`0OO01l0004O0000`00Oomoo`0WOol001eoo`03001oogoo09]oo`0301ml07`0015l0003
001l07`0015l0003001l07`000Yl000301ml07`000=l0003001oogoo02Moo`007Goo00<007ooOol0
Vgoo00<07g`0O0004G`000<007`0O0004G`000<007`0O0002W`000<07g`0O0000g`000<007ooOol0
9goo000MOol00`00Oomoo`2JOol00`0O001l000BO0000`00O01l000AO0000`00O01l000:O0000`0O
O01l0003O0000`00Oomoo`0WOol001eoo`8009]oo`0301l007`0019l0003001l07`0015l0003001l
07`000]l000301ml07`0009l0003001oogoo02Moo`007Goo00<007ooOol0VGoo00<07goo00004g`0
00<007`0O0004G`000<007`0O0002g`000<07g`0O0000W`000<007ooOol09goo000MOol00`00Oomo
o`2IOol00`0OOol0000CO0000`00O01l000AO0000`00O01l000<O0001@0OO01l07`00000:Goo000M
Ool00`00Oomoo`2HOol0100OOomoo`004g`000<007`0O0004G`000<007`0O00037`000D07g`0O01l
000002Uoo`007Goo00<007ooOol0V7oo00@07gooOol001=l0003001l07`0015l0003001l07`000el
000401ml07`0000YOol001eoo`8009Qoo`0501moogooOol0000CO0000`00O01l000AO0000`00O01l
000=O000100OO01l0000:Goo000MOol00`00Oomoo`2FOol00`0OOomoo`02Ool00`00O01l000AO000
0`00O01l000AO0000`00O01l000=O000100OO01l0000:Goo000EOol30005Ool00`00Oomoo`2FOol0
0`0OOomoo`02Ool00`00O01l000AO0000`00O01l000AO0000`00O01l000>O0000`0OO000000YOol0
01Qoo`03001oogoo009oo`03001oogoo09Eoo`0301moogoo00=oo`03001l07`0015l0003001l07`0
015l0003001l07`000il000301ml000002Uoo`003goo1@0017oo00<007ooOol00Woo0`00UGoo00<0
7gooOol00goo00<007`0O0004G`000<007`0O0004G`000<007`0O0003g`000<07`00Ool0:7oo000F
Ool20005Ool00`00Oomoo`2DOol00`0OOomoo`04Ool00`00O01l000AO0000`00O01l000AO0000`00
O01l000?O0000`0O001oo`0XOol001Qoo`03001oogoo009oo`03001oogoo09Aoo`0301moogoo00Ao
o`03001l07`0015l0003001l07`0015l0003001l07`000ml000301l007oo02Qoo`005Goo0`001Goo
00<007ooOol0Tgoo00<07gooOol01Goo00<007`0O0004G`000<007`0O0004G`000<007`0O00047`0
00<07gooOol09goo000MOol00`00Oomoo`2COol00`0OOomoo`05Ool00`00O01l000AO0000`00O01l
000AO0000`00O01l000@O0000`0OOomoo`0WOol001eoo`8008Qoo`/0000301l0000000L001=l0003
001l07`0015l0003001l07`0011l000300007goo02Moo`007Goo00<007ooOol0Qgoo00<007`0O000
27`000<07g`0O0001W`000<007`0O0004G`000<007`0O0004G`000<007`0O00047`000<0000OOol0
9goo000MOol00`00Oomoo`27Ool00`00O01l0007O0000`0OO01l0007O0000`00O01l000AO0000`00
O01l000AO0000`00O01l000@O0000`0001moo`0WOol001eoo`03001oogoo08Moo`03001l07`000Ml
000301ml07`000Ml0003001l07`0015l0003001l07`0015l0003001l07`0011l0003001oo`0O02Mo
o`007Goo0P00R7oo00<007`0O0001W`000<07g`0O00027`000<007`0O0004G`000<007`0O0004G`0
00<007`0O00047`000<007oo01l09goo000MOol00`00Oomoo`27Ool00`00O01l0006O0000`0OO01l
0008O0000`00O01l000AO0000`00O01l000AO0000`00O01l000@O0000`00Ool07`0WOol001eoo`03
001oogoo08Moo`03001l07`000El000301ml07`000Ul0003001l07`0015l0003001l07`0015l0003
001l07`0011l0004001oogoo01lVOol001eoo`03001oogoo08Moo`03001l07`000El000301ml07`0
00Ul0003001l07`0015l0003001l07`0015l0003001l07`0011l0004001oogoo01lVOol001eoo`03
001oogoo08Moo`03001l07`000Al000301ml07`000Yl0003001l07`0015l0003001l07`0015l0003
001l07`0011l0004001oogoo01lVOol001eoo`8008Qoo`03001l07`000Al000301ml07`000Yl0003
001l07`0015l0003001l07`0015l0003001l07`0011l0005001oogooOol07`0UOol001eoo`03001o
ogoo08Moo`03001l07`000=l000301ml07`000]l0003001l07`0015l0003001l07`0015l0003001l
07`0011l0005001oogooOol07`0UOol001eoo`03001oogoo08Moo`03001l07`000=l000301ml07`0
00]l0003001l07`0015l0003001l07`0015l0003001l07`0011l0003001oogoo009oo`0301moogoo
029oo`007Goo00<007ooOol0Qgoo00<007`0O0000W`000<07g`0O00037`000<007`0O0004G`000<0
07`0O0004G`000<007`0O00047`000<007ooOol00Woo00<07gooOol08Woo000MOol20028Ool00`00
O01l0002O0000`0OO01l000<O0000`00O01l000AO0000`00O01l000AO0000`00O01l000@O0000`00
Oomoo`02Ool00`0OOomoo`0ROol001eoo`03001oogoo08Moo`05001l07`0O0007`0?O0000`00O01l
000AO0000`00O01l000AO0000`00O01l000@O0000`00Oomoo`03Ool00`0OOomoo`0QOol001Eoo`@0
00Aoo`03001oogoo08Moo`05001l07`0O0007`0?O0000`00O01l000AO0000`00O01l000AO0000`00
O01l000@O0000`00Oomoo`03Ool00`0OOomoo`0QOol001Ioo`03001oogoo00Aoo`03001oogoo08Mo
o`04001l07`001l@O0000`00O01l000AO0000`00O01l000AO0000`00O01l000@O0000`00Oomoo`03
Ool00`0OOomoo`0QOol000moo`D000=oo`03001oogoo00=oo`<008Moo`04001l07`001l@O0000`00
O01l000AO0000`00O01l000AO0000`00O01l000@O0000`00Oomoo`04Ool00`0OOomoo`0POol001Qo
o`03001oogoo009oo`03001oogoo08Moo`03001l000O015l0003001l07`0015l0003001l07`0015l
0003001l07`0011l0003001oogoo00Aoo`0301moogoo021oo`005Goo00@007ooOol000Aoo`03001o
ogoo08Moo`03001l000O015l0003001l07`0015l0003001l07`0015l0003001l07`0011l0003001o
ogoo00Eoo`0301moogoo01moo`005Woo0P001Goo00<007ooOol0Qgoo00<0000OO0004G`000<007`0
O0004G`000<007`0O0004G`000<007`0O00047`000<007ooOol01Goo00<07gooOol07goo000MOol0
0`00Oomoo`27Ool00`0001ml000AO0000`00O01l000AO0000`00O01l000AO0000`00O01l000@O000
0`00Oomoo`05Ool00`0OOomoo`0OOol001eoo`8008Qoo`0301ml07`0015l0003001l07`0015l0003
001l07`0015l0003001l07`0011l0003001oogoo00Ioo`0301moogoo01ioo`007Goo00<007ooOol0
Qgoo00<07g`0O0004G`000<007`0O0004G`000<007`0O0004G`000<007`0O00047`000<007ooOol0
1Woo00<07gooOol07Woo000MOol00`00Oomoo`26Ool00`0O001l000BO0000`00O01l000AO0000`00
O01l000AO0000`00O01l000@O0000`00Oomoo`06Ool00`0OOomoo`0NOol001eoo`03001oogoo08Io
o`0301l007`0019l0003001l07`0015l0003001l07`0015l0003001l07`0011l0003001oogoo00Mo
o`0301moogoo01eoo`007Goo0P00QWoo00<07goo00004g`000<007`0O0004G`000<007`0O0004G`0
00<007`0O00047`000<007ooOol01goo00<07gooOol07Goo000MOol00`00Oomoo`25Ool00`0OOol0
000CO0000`00O01l000AO0000`00O01l000AO0000`00O01l000@O00:00000`0O00000008000EOol0
01eoo`03001oogoo08Aoo`0401moogoo000CO0000`00O01l000AO0000`00O01l000AO0000`00O01l
000@O0000`00O01l0008O0000`0OO01l0006O0000`00Oomoo`0COol001eoo`03001oogoo08Aoo`04
01moogoo000CO0000`00O01l000AO0000`00O01l000AO0000`00O01l000@O0000`00O01l0008O000
0`0OO01l0006O0000`00Oomoo`0COol001eoo`03001oogoo08=oo`0501moogooOol0000CO0000`00
O01l000AO0000`00O01l000AO0000`00O01l000@O0000`00O01l0008O0000`0OO01l0006O0000`00
Oomoo`0COol001eoo`8008Aoo`0501moogooOol0000CO0000`00O01l000AO0000`00O01l000AO000
0`00O01l000@O0000`00O01l0009O0000`0OO01l0005O0000`00Oomoo`0COol001eoo`03001oogoo
08=oo`0501moogooOol0000CO0000`00O01l000AO0000`00O01l000AO0000`00O01l000@O0000`00
O01l0009O0000`0OO01l0005O0000`00Oomoo`0COol001eoo`03001oogoo089oo`0301moogoo009o
o`03001l07`0015l0003001l07`0015l0003001l07`0015l0003001l07`0011l0003001l07`000Ul
000301ml07`000El0003001oogoo01=oo`007Goo00<007ooOol0PWoo00<07gooOol00Woo00<007`0
O0004G`000<007`0O0004G`000<007`0O0004G`000<007`0O00047`000<007`0O0002G`000<07g`0
O0001G`000<007ooOol04goo000MOol20022Ool00`0OOomoo`03Ool00`00O01l000AO0000`00O01l
000AO0000`00O01l000AO0000`00O01l000@O0000`00O01l000:O0000`0OO01l0004O0000`00Oomo
o`0COol001eoo`03001oogoo085oo`0301moogoo00=oo`03001l07`0015l0003001l07`0015l0003
001l07`0015l0003001l07`0011l0003001l07`000Yl000301ml07`000Al0003001oogoo01=oo`00
5Goo0`001Goo00<007ooOol0P7oo00<07gooOol017oo00<007`0O0004G`000<007`0O0004G`000<0
07`0O0004G`000<007`0O00047`000<007`0O0002W`000<07g`0O00017`000<007ooOol04goo000F
Ool00`00Oomoo`04Ool00`00Oomoo`20Ool00`0OOomoo`04Ool00`00O01l000AO0000`00O01l000A
O0000`00O01l000AO0000`00O01l000@O0000`00O01l000;O0000`0OO01l0003O0000`00Oomoo`0C
Ool000moo`D0009oo`03001oogoo00Aoo`<007moo`0301moogoo00Eoo`03001l07`0015l0003001l
07`0015l0003001l07`0015l0003001l07`0011l0003001l07`000]l000301ml07`000=l0003001o
ogoo01=oo`005Woo00<007ooOol017oo00<007ooOol0Ogoo00<07gooOol01Goo00<007`0O0004G`0
00<007`0O0004G`000<007`0O0004G`000<007`0O00047`000<007`0O0002g`000<07g`0O0000g`0
00<007ooOol04goo000FOol00`00Oomoo`04Ool00`00Oomoo`1nOol00`0OOomoo`06Ool00`00O01l
000AO0000`00O01l000AO0000`00O01l000AO0000`00O01l000@O0000`00O01l000;O0000`0OO01l
0003O0000`00Oomoo`0COol001Eoo`8000Ioo`03001oogoo07Aoo`X0000301l0000000L001=l0003
001l07`0015l0003001l07`0015l0003001l07`0011l0003001l07`000al000301ml07`0009l0003
001oogoo01=oo`007Goo00<007ooOol0M7oo00<007`0O0001W`000<07g`0O0001g`000<007`0O000
4G`000<007`0O0004G`000<007`0O0004G`000<007`0O00047`000<007`0O00037`000<07g`0O000
0W`000<007ooOol04goo000MOol2001eOol00`00O01l0006O0000`0OO01l0007O0000`00O01l000A
O0000`00O01l000AO0000`00O01l000AO0000`00O01l000@O0000`00O01l000<O0000`0OO01l0002
O0000`00Oomoo`0COol001eoo`03001oogoo07Aoo`03001l07`000El000301ml07`000Ql0003001l
07`0015l0003001l07`0015l0003001l07`0015l0003001l07`0011l0003001l07`000al000301ml
07`0009l0003001oogoo01=oo`007Goo00<007ooOol0M7oo00<007`0O0001G`000<07g`0O00027`0
00<007`0O0004G`000<007`0O0004G`000<007`0O0004G`000<007`0O00047`000<007`0O0003G`0
00D07g`0O01l000001Eoo`007Goo00<007ooOol0M7oo00<007`0O00017`000<07g`0O0002G`000<0
07`0O0004G`000<007`0O0004G`000<007`0O0004G`000<007`0O00047`000<007`0O0003G`000D0
7g`0O01l000001Eoo`007Goo0P00MGoo00<007`0O00017`000<07g`0O0002G`000<007`0O0004G`0
00<007`0O0004G`000<007`0O0004G`000<007`0O00047`000<007`0O0003G`000D07g`0O01l0000
01Eoo`007Goo00<007ooOol0M7oo00<007`0O0000g`000<07g`0O0002W`000<007`0O0004G`000<0
07`0O0004G`000<007`0O0004G`000<007`0O00047`000<007`0O0003G`000D07g`0O01l000001Eo
o`007Goo00<007ooOol0M7oo00<007`0O0000g`000<07g`0O0002W`000<007`0O0004G`000<007`0
O0004G`000<007`0O0004G`000<007`0O00047`000<007`0O0003W`000@07g`0O00001Eoo`007Goo
00<007ooOol08Goo0`008goo10008Goo0`001Goo00<007`0O0000W`000<07g`0O0002g`000<007`0
O0004G`000<007`0O0004G`000<007`0O0004G`000<007`0O00047`000<007`0O0003W`000@07g`0
O00001Eoo`007Goo00<007ooOol08Woo00<007ooOol08goo00<007ooOol097oo00<007ooOol00Woo
00<007`0O0000W`000<07g`0O0002g`000<007`0O0004G`000<007`0O0004G`000<007`0O0004G`0
00<007`0O00047`000<007`0O0003W`000@07g`0O00001Eoo`007Goo0P008goo00<007ooOol097oo
00<007ooOol08goo00<007ooOol00Woo00D007`0O01l000O00il0003001l07`0015l0003001l07`0
015l0003001l07`0015l0003001l07`0011l0003001l07`000il000401ml07`0000EOol001eoo`03
001oogoo029oo`03001oogoo02Eoo`03001oogoo021oo`8000Eoo`05001l07`0O0007`0>O0000`00
O01l000AO0000`00O01l000AO0000`00O01l000AO0000`00O01l000@O0000`00O01l000?O0000`0O
O000000EOol001eoo`03001oogoo029oo`03001oogoo029oo`04001oogoo000TOol00`00Oomoo`02
Ool01000O01l000O3g`000<007`0O0004G`000<007`0O0004G`000<007`0O0004G`000<007`0O000
47`000<007`0O0003g`000<07g`000005Goo000MOol00`00Oomoo`0QOol2000UOol2000ROol30005
Ool01000O01l000O3g`000<007`0O0004G`000<007`0O0004G`000<007`0O0004G`000<007`0O000
47`000<007`0O0003g`000<07g`000005Goo000MOol2001eOol00`00O0007`0@O0000`00O01l000A
O0000`00O01l000AO0000`00O01l000AO0000`00O01l000@O0000`00O01l000@O0000`0O001oo`0D
Ool001eoo`03001oogoo07Aoo`03001l000O011l0003001l07`0015l0003001l07`0015l0003001l
07`0015l0003001l07`0011l0003001l07`0011l000301l007oo01Aoo`007Goo00<007ooOol0M7oo
00<0000OO00047`000<007`0O0004G`000<007`0O0004G`000<007`0O0004G`000<007`0O00047`0
00<007`0O00047`000<07`00Ool057oo000MOol00`00Oomoo`1dOol00`0001ml000@O0000`00O01l
000AO0000`00O01l000AO0000`00O01l000AO0000`00O01l000@O0000`00O01l000@O0000`0O001o
o`0DOol001eoo`03001oogoo07Aoo`0301ml07`0011l0003001l07`0015l0003001l07`0015l0003
001l07`0015l0003001l07`0011l0003001l07`0015l000301moogoo01=oo`005goo1P002P0OK@00
00<07g`0O00047`000<007`0O0004G`000<007`0O0004G`000<007`0O0004G`000<007`0O00047`0
00<007`0O0004G`000<07`00000010003goo000MOol:000201l9000CO0000`00O01l000@O0000`00
O01l000AO0000`00O01l000AO0000`00O01l000@O0000`0O001oo`0NOol00`00Oomoo`0SOol00`00
Oomoo`0ROol00`00Oomoo`0NOol001eoo`03001oogoo00Uoo`<07`Eoo`03001l07`0015l0003001l
07`0011l0003001l07`0015l0003001l07`0015l0003001l07`000ml000301ml000008]oo`007Goo
00<007ooOol037oo0P0O0goo00<007`0O0004G`000<007`0O00047`000<007`0O0004G`000<007`0
O0004G`000<007`0O0003g`000<07g`00000Rgoo000MOol2000?Ool201l00goo001l000BO0000`00
O01l000@O0000`00O01l000AO0000`00O01l000AO0000`00O01l000>O000100OO01l0000Rgoo000M
Ool00`00Oomoo`0@Ool00`0O001l000BO0000`00O01l000@O0000`00O01l000AO0000`00O01l000A
O0000`00O01l000>O000100OO01l0000Rgoo000MOol00`00Oomoo`0AOol201lBO0000`00O01l000@
O0000`00O01l000AO0000`00O01l000AO0000`00O01l000=O0001@0OO01l07`00000Rgoo000MOol0
0`00Oomoo`0AOol01000O0007`0O47`000<007`0O00047`000<007`0O0004G`000<007`0O0004G`0
00<007`0O00037`000<07g`0O0000W`000<007ooOol0RGoo000MOol2000BOol01@00O01l07`001l0
3g`000<007`0O00047`000<007`0O0004G`000<007`0O0004G`000<007`0O00037`000<07g`0O000
0W`000<007ooOol0RGoo000MOol00`00Oomoo`0AOol00`00O01l0002O00201l=O0000`00O01l000@
O0000`00O01l000AO0000`00O01l000AO0000`00O01l000;O0000`0OO01l0003O0000`00Oomoo`29
Ool001eoo`03001oogoo015oo`03001l07`000Al00807`]l0003001l07`0011l0003001l07`0015l
0003001l07`0015l0003001l07`000Yl000301ml07`000Al0003001oogoo08Uoo`007Goo00<007oo
Ool04Goo00<007`0O0001W`000<07g`0O00027`000<007`0O00047`000<007`0O0004G`000<007`0
O0004G`000<007`0O0002W`000<07g`0O00017`000<007ooOol0RGoo000MOol00`00Oomoo`0AOol:
000201l9000BO0000`00O01l000AO0000`00O01l000AO0000`00O01l0009O0000`0OO01l0005O000
0`00Oomoo`29Ool001eoo`8001ioo`0301moogoo00Eoo`03001l07`0011l0003001l07`0015l0003
001l07`0015l0003001l07`000Ul000301ml07`000El0003001oogoo08Uoo`007Goo00<007ooOol0
7Woo00<07gooOol017oo00<007`0O00047`000<007`0O0004G`000<007`0O0004G`000<007`0O000
27`000<07g`0O0001W`000<007ooOol0RGoo000MOol00`00Oomoo`0OOol00`0OOomoo`03Ool00`00
O01l000@O0000`00O01l000AO0000`00O01l000AO0000`00O01l0007O0000`0OO01l0007O0000`00
Oomoo`29Ool001eoo`03001oogoo021oo`807`=oo`03001l07`0011l0003001l07`0015l0003001l
07`0015l00X0000301l0000000P008]oo`007Goo0P008goo00@07gooOol0019l0003001l07`0015l
0003001l07`0015l0003001oogoo00Ioo`0301moogoo09Aoo`007Goo00<007ooOol08goo00<07goo
00004W`000<007`0O0004G`000<007`0O0004G`000<007ooOol01Goo00<07gooOol0UGoo000MOol0
0`00Oomoo`0TOol00`0O001l000AO0000`00O01l000AO0000`00O01l000AO0000`00Oomoo`04Ool0
0`0OOomoo`2FOol001Eoo`<000Eoo`03001oogoo02Eoo`807a5l0003001l07`0015l0003001l07`0
015l0003001oogoo00Aoo`0301moogoo09Ioo`005Woo00<007ooOol017oo00<007ooOol09Goo00<0
07`001l047`000<007`0O0004G`000<007`0O0004G`000<007ooOol00goo00<07gooOol0Ugoo000F
Ool00`00Oomoo`04Ool3000UOol01000O01l000O3g`000<007`0O0004G`000<007`0O0004G`000<0
07ooOol00Woo00<07gooOol0V7oo000FOol00`00Oomoo`04Ool00`00Oomoo`0UOol01@00O01l07`0
01l03W`000<007`0O0004G`000<007`0O0004G`000D007ooOomoo`0O09]oo`005Woo00<007ooOol0
17oo00<007ooOol09Goo00<007`0O0000W`00P0O37`000<007`0O0004G`000<007`0O0004G`000@0
07ooOol07iaoo`005Goo0P001Woo00<007ooOol09Goo00<007`0O00017`000<07g`0O0002G`000<0
07`0O0004G`000<007`0O0004G`000@007ooOol07iaoo`007Goo0P009Woo00<007`0O0001G`000<0
7g`0O00027`000<007`0O0004G`000<007`0O0004G`000<007oo01l0WGoo000MOol00`00Oomoo`0U
Ool900000`0O00000008000CO0000`00O01l000AO0000`0001moo`2MOol001eoo`03001oogoo02mo
o`807`Moo`03001l07`0015l0003001l07`0015l000301moogoo09eoo`007Goo00<007ooOol0<Goo
00<07gooOol017oo00<007`0O0004G`000<007`0O00047`000<07`00Ool0WWoo000MOol2000cOol2
01l4Ool00`00O01l000AO0000`00O01l000?O0000`0OO000002OOol001eoo`03001oogoo03Aoo`05
01moogooOol0000CO0000`00O01l000>O000100OO01l0000Wgoo000MOol00`00Oomoo`0eOol201l0
0goo001l000BO0000`00O01l000<O00201l3O0000`00Oomoo`2MOol001eoo`03001oogoo03Moo`03
01l007`0019l0003001l07`000]l000301ml07`000=l0003001oogoo09eoo`007Goo00<007ooOol0
>7oo0P0O4W`000<007`0O0002W`000<07g`0O00017`000<007ooOol0WGoo000MOol2000iOol00`00
O0007`0AO0000`00O01l0009O0000`0OO01l0005O0000`00Oomoo`2MOol001eoo`03001oogoo03Qo
o`03001l07`000<07`il00X000807`T009moo`007Goo00<007ooOol0>7oo00<007`0O0000g`00P0O
37`000<007ooOol017oo0`0OZWoo000MOol00`00Oomoo`0hOol00`00O01l0005O00301l9O0000`00
Oomoo`02Ool201n]Ool001eoo`8003Uoo`/000@07`H000@07jmoo`007Goo00<007ooOol0Agoo1P0O
/goo000MOol00`00Oomoo`3oOol1Ool001eoo`03001oogoo0?moo`5oo`007Goo00<007ooOol0ogoo
0Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol0
0?moob5oo`00?7oo1P001Woo0`000goo100017oo0`001Goo0`000goo100000=oo`0000000P000Woo
0P001Goo2P0000=oo`0000000P000Woo100017oo10000goo100067oo1P000goo0P000goo1P000Woo
1@001Woo100027oo0P000goo1P00=Woo000nOol20007Ool20002Ool01000Oomoogoo0P0017oo0P00
0Woo00@007ooOomoo`80009oo`04001oogooOol20003Ool20002Ool200000goo001oo`05Ool20005
Ool200000goo00000004Ool20004Ool20002Ool20003Ool2000KOol20005Ool20005Ool20004Ool2
0003Ool20003Ool20002Ool20007Ool20005Ool2000hOol003ioo`8000Ioo`8000Aoo`03001oogoo
008000=oo`8000Aoo`04001oo`000004Ool00`00Oomoo`020003Ool20002Ool20008Ool20006Ool0
1000Ool0000017oo0P000goo0P0017oo0P000Woo0P002Goo2@002Goo0P0037oo0P002Woo00<007oo
Ool00P0017oo0P001Woo0P001Goo0P00>7oo000nOol20006Ool20007Ool20003Ool20006Ool20007
Ool20003Ool20002Ool20008Ool20008Ool20004Ool20003Ool20004Ool20002Ool2000KOol2000<
Ool2000:Ool200000goo00000004Ool200000goo000000070003Ool2000hOol003ioo`8000Ioo`80
00Moo`8000=oo`8000Ioo`8000Moo`8000=oo`80009oo`8000Qoo`8000Aoo`04001oogooOol20004
Ool20003Ool20004Ool20002Ool2000KOol2000<Ool2000:Ool200000goo00000003Ool300000goo
001oo`03Ool20005Ool2000hOol003ioo`H0009oo`L0009oo`8000=oo`8000Aoo`03001oo`0000H0
009oo`8000=oo`80009oo`8000Qoo`8000Aoo`04001oogooOol20004Ool20003Ool20004Ool20002
Ool2000KOol2000<Ool2000:Ool20002Ool2000017oo000000000goo00@007ooOomoo`8000Eoo`80
03Qoo`00?Woo0P000goo0P000Woo00@007ooOomoo`800003Ool0000000@00003Ool00000009oo`80
009oo`04001oogooOol200000goo000000020002Ool20002Ool20008Ool70002Ool<00000goo0000
0002Ool20002Ool60006Ool90009Ool2000<Ool20009Ool30003Ool40005Ool00`00Oomoo`020005
Ool2000hOol003ioo`8000Aoo`80009oo`@000Aoo`04001oo`000002Ool40004Ool40004Ool00`00
Ool000020002Ool50006Ool20004Ool00`00Oomoo`02Ool01000Ool000000Woo00@007oo0000009o
o`@000Eoo`04001oo`00000HOol2000<Ool20006Ool50003Ool50005Ool00`00Oomoo`020005Ool2
000hOol003ioo`8000Aoo`8002Qoo`8000Qoo`8000Aoo`03001oogoo03=oo`8000aoo`8000Qoo`03
001oogoo00=oo`80009oo`8000Eoo`04001oo`000005Ool2000hOol003ioo`8000Aoo`8002Uoo`03
001oogoo00Ioo`8003Yoo`8000aoo`8000Uoo`04001oogooOol20004Ool20005Ool30005Ool2000h
Ool003ioo`8000Aoo`80039oo`8000Eoo`03001oogoo039oo`8000aoo`8000Aoo`03001oogoo009o
o`80009oo`8000Aoo`8000Eoo`<000Eoo`8003Qoo`00?Woo0P000goo0P00<goo0P001Goo00<007oo
Ool0<7oo10002Woo10001Goo00<007ooOol00`000goo0P000Woo0P001goo0P000goo1000>7oo000l
Ool8000bOol:000dOol2000<Ool20006Ool40005Ool40008Ool20005Ool2000hOol00?moob5oo`00
ogoo8Goo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.783823, -4.98036, 
  0.0265065, 0.0452841}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.151576 0.44187 0.0887232 [
[.17539 .42937 -3 -9 ]
[.17539 .42937 3 0 ]
[.32696 .42937 -3 -9 ]
[.32696 .42937 3 0 ]
[.47854 .42937 -3 -9 ]
[.47854 .42937 3 0 ]
[.63011 .42937 -3 -9 ]
[.63011 .42937 3 0 ]
[.78169 .42937 -3 -9 ]
[.78169 .42937 3 0 ]
[.93327 .42937 -3 -9 ]
[.93327 .42937 3 0 ]
[.01131 .08698 -12 -4.5 ]
[.01131 .08698 0 4.5 ]
[.01131 .1757 -12 -4.5 ]
[.01131 .1757 0 4.5 ]
[.01131 .26442 -12 -4.5 ]
[.01131 .26442 0 4.5 ]
[.01131 .35315 -12 -4.5 ]
[.01131 .35315 0 4.5 ]
[.01131 .53059 -6 -4.5 ]
[.01131 .53059 0 4.5 ]
[.5 .63053 -94.0938 0 ]
[.5 .63053 94.0938 20 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.17539 .44187 m
.17539 .44812 L
s
[(1)] .17539 .42937 0 1 Mshowa
.32696 .44187 m
.32696 .44812 L
s
[(2)] .32696 .42937 0 1 Mshowa
.47854 .44187 m
.47854 .44812 L
s
[(3)] .47854 .42937 0 1 Mshowa
.63011 .44187 m
.63011 .44812 L
s
[(4)] .63011 .42937 0 1 Mshowa
.78169 .44187 m
.78169 .44812 L
s
[(5)] .78169 .42937 0 1 Mshowa
.93327 .44187 m
.93327 .44812 L
s
[(6)] .93327 .42937 0 1 Mshowa
.125 Mabswid
.05412 .44187 m
.05412 .44562 L
s
.08444 .44187 m
.08444 .44562 L
s
.11476 .44187 m
.11476 .44562 L
s
.14507 .44187 m
.14507 .44562 L
s
.2057 .44187 m
.2057 .44562 L
s
.23602 .44187 m
.23602 .44562 L
s
.26633 .44187 m
.26633 .44562 L
s
.29665 .44187 m
.29665 .44562 L
s
.35728 .44187 m
.35728 .44562 L
s
.38759 .44187 m
.38759 .44562 L
s
.41791 .44187 m
.41791 .44562 L
s
.44822 .44187 m
.44822 .44562 L
s
.50885 .44187 m
.50885 .44562 L
s
.53917 .44187 m
.53917 .44562 L
s
.56948 .44187 m
.56948 .44562 L
s
.5998 .44187 m
.5998 .44562 L
s
.66043 .44187 m
.66043 .44562 L
s
.69074 .44187 m
.69074 .44562 L
s
.72106 .44187 m
.72106 .44562 L
s
.75137 .44187 m
.75137 .44562 L
s
.81201 .44187 m
.81201 .44562 L
s
.84232 .44187 m
.84232 .44562 L
s
.87264 .44187 m
.87264 .44562 L
s
.90295 .44187 m
.90295 .44562 L
s
.96358 .44187 m
.96358 .44562 L
s
.9939 .44187 m
.9939 .44562 L
s
.25 Mabswid
0 .44187 m
1 .44187 L
s
.02381 .08698 m
.03006 .08698 L
s
[(-4)] .01131 .08698 1 0 Mshowa
.02381 .1757 m
.03006 .1757 L
s
[(-3)] .01131 .1757 1 0 Mshowa
.02381 .26442 m
.03006 .26442 L
s
[(-2)] .01131 .26442 1 0 Mshowa
.02381 .35315 m
.03006 .35315 L
s
[(-1)] .01131 .35315 1 0 Mshowa
.02381 .53059 m
.03006 .53059 L
s
[(1)] .01131 .53059 1 0 Mshowa
.125 Mabswid
.02381 .016 m
.02756 .016 L
s
.02381 .03374 m
.02756 .03374 L
s
.02381 .05149 m
.02756 .05149 L
s
.02381 .06923 m
.02756 .06923 L
s
.02381 .10472 m
.02756 .10472 L
s
.02381 .12247 m
.02756 .12247 L
s
.02381 .14021 m
.02756 .14021 L
s
.02381 .15796 m
.02756 .15796 L
s
.02381 .19344 m
.02756 .19344 L
s
.02381 .21119 m
.02756 .21119 L
s
.02381 .22893 m
.02756 .22893 L
s
.02381 .24668 m
.02756 .24668 L
s
.02381 .28217 m
.02756 .28217 L
s
.02381 .29991 m
.02756 .29991 L
s
.02381 .31766 m
.02756 .31766 L
s
.02381 .3354 m
.02756 .3354 L
s
.02381 .37089 m
.02756 .37089 L
s
.02381 .38864 m
.02756 .38864 L
s
.02381 .40638 m
.02756 .40638 L
s
.02381 .42413 m
.02756 .42413 L
s
.02381 .45961 m
.02756 .45961 L
s
.02381 .47736 m
.02756 .47736 L
s
.02381 .4951 m
.02756 .4951 L
s
.02381 .51285 m
.02756 .51285 L
s
.02381 .54834 m
.02756 .54834 L
s
.02381 .56608 m
.02756 .56608 L
s
.02381 .58383 m
.02756 .58383 L
s
.02381 .60157 m
.02756 .60157 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -155.094 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 24.000000 moveto
 558.000000 24.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 24.000000 lineto
closepath
clip newpath
63.000000 19.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 18.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 19.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 18.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Percent) show
121.250000 19.000000 moveto
(Error) show
163.625000 19.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 18.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(=) show
179.687500 19.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 18.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.970496) show
247.187500 19.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 18.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
0 0 1 r
.007 w
.02381 .44187 m
.02499 .44188 L
.02605 .44189 L
.02729 .44192 L
.02846 .44195 L
.03053 .44204 L
.03279 .44218 L
.03527 .44238 L
.0379 .44264 L
.04262 .44323 L
.04749 .44403 L
.05205 .44493 L
.06244 .44757 L
.07305 .45107 L
.08274 .45495 L
.10458 .46589 L
.14429 .4922 L
.18248 .52229 L
.22313 .55474 L
.26226 .58144 L
.27254 .5871 L
.28367 .59241 L
.29328 .59624 L
.29838 .59795 L
.30384 .59955 L
.30923 .60086 L
.31415 .60182 L
.31652 .6022 L
.31909 .60255 L
.32151 .60282 L
.32378 .60303 L
.32509 .60312 L
.3263 .60319 L
.32764 .60325 L
.32834 .60327 L
.32908 .60329 L
.32976 .60331 L
.33048 .60332 L
.33177 .60332 L
.33257 .60331 L
.33332 .6033 L
.33399 .60328 L
.33472 .60326 L
.33594 .60321 L
.33728 .60313 L
.33999 .60292 L
.34249 .60266 L
.34484 .60235 L
.34982 .60149 L
.35525 .60023 L
Mistroke
.36513 .59709 L
.37475 .59294 L
.38367 .58812 L
.40423 .57339 L
.42285 .55569 L
.46297 .50405 L
.50157 .43897 L
.54262 .35759 L
.58216 .27326 L
.62019 .19318 L
.66067 .11668 L
.69963 .05896 L
.70983 .04728 L
.72091 .03645 L
.73048 .02875 L
.73557 .02531 L
.74104 .02213 L
.74638 .01956 L
.75126 .01767 L
.75594 .01629 L
.75829 .01576 L
.76085 .0153 L
.76227 .01511 L
.76362 .01496 L
.76482 .01485 L
.76612 .01477 L
.7668 .01474 L
.76755 .01472 L
.76833 .01472 L
.76905 .01472 L
.77035 .01475 L
.77108 .01478 L
.77175 .01482 L
.77304 .01492 L
.77424 .01504 L
.77695 .01543 L
.77933 .0159 L
.78187 .01653 L
.78675 .0181 L
.79123 .01999 L
.80132 .02578 L
.81022 .03269 L
.81959 .04179 L
.83931 .06705 L
.85767 .09794 L
.89668 .18599 L
.93815 .30895 L
.97619 .44187 L
Mfstroke
1 0 0 r
.02381 .44187 m
.09707 .44187 L
.09707 .447 L
.02381 .447 L
F
.09707 .44187 m
.17033 .44187 L
.17033 .48452 L
.09707 .48452 L
F
.17033 .44187 m
.24359 .44187 L
.24359 .54211 L
.17033 .54211 L
F
.24359 .44187 m
.31685 .44187 L
.31685 .59086 L
.24359 .59086 L
F
.31685 .44187 m
.39011 .44187 L
.39011 .60068 L
.31685 .60068 L
F
.39011 .44187 m
.46337 .44187 L
.46337 .55147 L
.39011 .55147 L
F
.46337 .44187 m
.53663 .44187 L
.53663 .44187 L
.46337 .44187 L
F
.53663 .44187 m
.60989 .44187 L
.60989 .29241 L
.53663 .29241 L
F
.60989 .44187 m
.68315 .44187 L
.68315 .1419 L
.60989 .1419 L
F
.68315 .44187 m
.75641 .44187 L
.75641 .03746 L
.68315 .03746 L
F
.75641 .44187 m
.82967 .44187 L
.82967 .02087 L
.75641 .02087 L
F
.82967 .44187 m
.90293 .44187 L
.90293 .11486 L
.82967 .11486 L
F
.90293 .44187 m
.97619 .44187 L
.97619 .31359 L
.90293 .31359 L
F
0 g
.5 Mabswid
.02381 .44187 m
.02381 .447 L
s
.09707 .44187 m
.09707 .447 L
s
.02381 .447 m
.09707 .447 L
s
.09707 .44187 m
.09707 .48452 L
s
.17033 .44187 m
.17033 .48452 L
s
.09707 .48452 m
.17033 .48452 L
s
.17033 .44187 m
.17033 .54211 L
s
.24359 .44187 m
.24359 .54211 L
s
.17033 .54211 m
.24359 .54211 L
s
.24359 .44187 m
.24359 .59086 L
s
.31685 .44187 m
.31685 .59086 L
s
.24359 .59086 m
.31685 .59086 L
s
.31685 .44187 m
.31685 .60068 L
s
.39011 .44187 m
.39011 .60068 L
s
.31685 .60068 m
.39011 .60068 L
s
.39011 .44187 m
.39011 .55147 L
s
.46337 .44187 m
.46337 .55147 L
s
.39011 .55147 m
.46337 .55147 L
s
.46337 .44187 m
.46337 .44187 L
s
.53663 .44187 m
.53663 .44187 L
s
.46337 .44187 m
.53663 .44187 L
s
.53663 .44187 m
.53663 .29241 L
s
.60989 .44187 m
.60989 .29241 L
s
.53663 .29241 m
.60989 .29241 L
s
.60989 .44187 m
.60989 .1419 L
s
.68315 .44187 m
.68315 .1419 L
s
.60989 .1419 m
.68315 .1419 L
s
.68315 .44187 m
.68315 .03746 L
s
.75641 .44187 m
.75641 .03746 L
s
.68315 .03746 m
.75641 .03746 L
s
.75641 .44187 m
.75641 .02087 L
s
.82967 .44187 m
.82967 .02087 L
s
.75641 .02087 m
.82967 .02087 L
s
.82967 .44187 m
.82967 .11486 L
s
.90293 .44187 m
.90293 .11486 L
s
.82967 .11486 m
.90293 .11486 L
s
.90293 .44187 m
.90293 .31359 L
s
.97619 .44187 m
.97619 .31359 L
s
.90293 .31359 m
.97619 .31359 L
s
0 0 1 r
.007 w
.02381 .44187 m
.02499 .44188 L
.02605 .44189 L
.02729 .44192 L
.02846 .44195 L
.03053 .44204 L
.03279 .44218 L
.03527 .44238 L
.0379 .44264 L
.04262 .44323 L
.04749 .44403 L
.05205 .44493 L
.06244 .44757 L
.07305 .45107 L
.08274 .45495 L
.10458 .46589 L
.14429 .4922 L
.18248 .52229 L
.22313 .55474 L
.26226 .58144 L
.27254 .5871 L
.28367 .59241 L
.29328 .59624 L
.29838 .59795 L
.30384 .59955 L
.30923 .60086 L
.31415 .60182 L
.31652 .6022 L
.31909 .60255 L
.32151 .60282 L
.32378 .60303 L
.32509 .60312 L
.3263 .60319 L
.32764 .60325 L
.32834 .60327 L
.32908 .60329 L
.32976 .60331 L
.33048 .60332 L
.33177 .60332 L
.33257 .60331 L
.33332 .6033 L
.33399 .60328 L
.33472 .60326 L
.33594 .60321 L
.33728 .60313 L
.33999 .60292 L
.34249 .60266 L
.34484 .60235 L
.34982 .60149 L
.35525 .60023 L
Mistroke
.36513 .59709 L
.37475 .59294 L
.38367 .58812 L
.40423 .57339 L
.42285 .55569 L
.46297 .50405 L
.50157 .43897 L
.54262 .35759 L
.58216 .27326 L
.62019 .19318 L
.66067 .11668 L
.69963 .05896 L
.70983 .04728 L
.72091 .03645 L
.73048 .02875 L
.73557 .02531 L
.74104 .02213 L
.74638 .01956 L
.75126 .01767 L
.75594 .01629 L
.75829 .01576 L
.76085 .0153 L
.76227 .01511 L
.76362 .01496 L
.76482 .01485 L
.76612 .01477 L
.7668 .01474 L
.76755 .01472 L
.76833 .01472 L
.76905 .01472 L
.77035 .01475 L
.77108 .01478 L
.77175 .01482 L
.77304 .01492 L
.77424 .01504 L
.77695 .01543 L
.77933 .0159 L
.78187 .01653 L
.78675 .0181 L
.79123 .01999 L
.80132 .02578 L
.81022 .03269 L
.81959 .04179 L
.83931 .06705 L
.85767 .09794 L
.89668 .18599 L
.93815 .30895 L
.97619 .44187 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00O7Goo00<007ooOol0
ogoo0Goo000MOol00`00Oomoo`3oOol1Ool001eoo`03001oogoo0?moo`5oo`007Goo00<007ooOol0
]7oo1P0OAWoo000MOol2002bOol301l5Ool301m4Ool001eoo`03001oogoo0:moo`807`9oo`T000<0
7`P003Uoo`007Goo00<007ooOol0[Woo00<07gooOol00Woo00<007`0O0002G`000<07g`0O00017`0
00<007ooOol0=goo000MOol00`00Oomoo`2]Ool00`0OOomoo`03Ool00`00O01l000:O0000`0OO01l
0003O0000`00Oomoo`0gOol001eoo`800:eoo`0301moogoo00Aoo`03001l07`000]l000301ml07`0
009l0003001oogoo03Moo`007Goo00<007ooOol0XGoo2@000P0O20003W`000D07g`0O01l000003Uo
o`007Goo00<007ooOol0XGoo00<007`0O0001G`000<07g`0O0001g`000<007`0O0003G`000@07g`0
O00003Uoo`007Goo00<007ooOol0XGoo00<007`0O00017`000<07g`0O00027`000<007`0O0003G`0
00@07g`0O00003Uoo`007Goo0P00XWoo00<007`0O0000g`000<07g`0O0002G`000<007`0O0003W`0
00<07g`00000>Goo000MOol00`00Oomoo`2QOol00`00O01l0002O0000`0OO01l000:O0000`00O01l
000?O0000`0O001oo`0hOol001eoo`03001oogoo0:5oo`05001l07`0O0007`0=O0000`00O01l000@
O0000`0OOomoo`0gOol001eoo`03001oogoo0:5oo`05001l07`0O0007`0=O0000`00O01l000@O000
0`0001moo`0gOol001eoo`03001oogoo0:5oo`04001l07`001l>O0000`00O01l000@O0000`00Ool0
7`0gOol001eoo`800:9oo`03001l000O00ml0003001l07`0011l0003001oo`0O03Moo`007Goo00<0
07ooOol0XGoo00<007`001l03g`000<007`0O00047`000@007ooOol07cIoo`005Woo0`0017oo00<0
07ooOol0XGoo00<0000OO0003g`000<007`0O00047`000D007ooOomoo`0O03Eoo`005goo00<007oo
Ool00goo00<007ooOol0XGoo00<0000OO0003g`000<007`0O00047`000D007ooOomoo`0O03Eoo`00
3goo1@0000=oo`0000000P0017oo0`00XGoo00<07g`0O0003g`000<007`0O00047`000<007ooOol0
0Woo00<07gooOol0<Woo000EOol00`00Ool00005Ool00`00Oomoo`2POol00`0O001l000@O0000`00
O01l000@O0000`00Oomoo`02Ool00`0OOomoo`0bOol001Eoo`03001oo`0000Eoo`03001oogoo0:1o
o`0301l007`0011l0003001l07`0011l0003001oogoo00=oo`0301moogoo035oo`005Woo0P001Goo
00<007ooOol0Wgoo00<07goo00004G`000<007`0O00047`000<007ooOol017oo00<07gooOol0<7oo
000MOol00`00Oomoo`2OOol00`0OOol0000AO0000`00O01l000@O0000`00Oomoo`04Ool00`0OOomo
o`0`Ool001eoo`8009moo`0401moogoo000AO0000`00O01l000@O0000`00Oomoo`05Ool00`0OOomo
o`0_Ool001eoo`03001oogoo09eoo`0501moogooOol0000AO0000`00O01l000@O0000`00Oomoo`05
Ool00`0OOomoo`0_Ool001eoo`03001oogoo09eoo`0501moogooOol0000AO0000`00O01l000@O008
00000`0O00000008000WOol001eoo`03001oogoo09aoo`0301moogoo009oo`03001l07`000ml0003
001l07`0011l0003001l07`000Il000301ml07`000Il0003001oogoo02Eoo`007Goo0P00WGoo00<0
7gooOol00Woo00<007`0O0003g`000<007`0O00047`000<007`0O0001W`000<07g`0O0001W`000<0
07ooOol09Goo000MOol00`00Oomoo`2KOol00`0OOomoo`03Ool00`00O01l000?O0000`00O01l000@
O0000`00O01l0007O0000`0OO01l0005O0000`00Oomoo`0UOol001eoo`03001oogoo09]oo`0301mo
ogoo00=oo`03001l07`000ml0003001l07`0011l0003001l07`000Ml000301ml07`000El0003001o
ogoo02Eoo`007Goo00<007ooOol0VWoo00<07gooOol017oo00<007`0O0003g`000<007`0O00047`0
00<007`0O0001g`000<07g`0O0001G`000<007ooOol09Goo000MOol2002KOol00`0OOomoo`04Ool0
0`00O01l000?O0000`00O01l000@O0000`00O01l0008O0000`0OO01l0004O0000`00Oomoo`0UOol0
01eoo`03001oogoo08moo`X0000301l0000000H0015l0003001l07`0011l0003001l07`000Ql0003
01ml07`000Al0003001oogoo02Eoo`007Goo00<007ooOol0Sgoo00<007`0O0001g`000<07g`0O000
1G`000<007`0O0003g`000<007`0O00047`000<007`0O0002G`000<07g`0O0000g`000<007ooOol0
9Goo000MOol00`00Oomoo`2?Ool00`00O01l0006O0000`0OO01l0006O0000`00O01l000?O0000`00
O01l000@O0000`00O01l0009O0000`0OO01l0003O0000`00Oomoo`0UOol001eoo`03001oogoo08mo
o`03001l07`000Il000301ml07`000Il0003001l07`000ml0003001l07`0011l0003001l07`000Yl
000301ml07`0009l0003001oogoo02Eoo`007Goo0P00T7oo00<007`0O0001G`000<07g`0O0001g`0
00<007`0O0003g`000<007`0O00047`000<007`0O0002W`000<07g`0O0000W`000<007ooOol09Goo
000MOol00`00Oomoo`2?Ool00`00O01l0004O0000`0OO01l0008O0000`00O01l000?O0000`00O01l
000@O0000`00O01l000:O0000`0OO01l0002O0000`00Oomoo`0UOol001Eoo`<000Eoo`03001oogoo
08moo`03001l07`000Al000301ml07`000Ql0003001l07`000ml0003001l07`0011l0003001l07`0
00]l000501ml07`0O000000WOol001Qoo`03001oogoo009oo`03001oogoo08moo`03001l07`000=l
000301ml07`000Ul0003001l07`000ml0003001l07`0011l0003001l07`000]l000501ml07`0O000
000WOol000moo`D000Aoo`03001oogoo009oo`<008moo`03001l07`000=l000301ml07`000Ul0003
001l07`000ml0003001l07`0011l0003001l07`000al000401ml07`0000WOol001Ioo`8000Eoo`03
001oogoo08moo`03001l07`0009l000301ml07`000Yl0003001l07`000ml0003001l07`0011l0003
001l07`000al000401ml07`0000WOol001Qoo`03001oogoo009oo`03001oogoo08moo`03001l07`0
009l000301ml07`000Yl0003001l07`000ml0003001l07`0011l0003001l07`000al000401ml07`0
000WOol001Eoo`<000Eoo`03001oogoo08moo`05001l07`0O0007`0=O0000`00O01l000?O0000`00
O01l000@O0000`00O01l000=O0000`0OO000000WOol001eoo`03001oogoo08moo`05001l07`0O000
7`0=O0000`00O01l000?O0000`00O01l000@O0000`00O01l000=O0000`0OO000000WOol001eoo`80
091oo`04001l07`001l>O0000`00O01l000?O0000`00O01l000@O0000`00O01l000>O0000`0O001o
o`0VOol001eoo`03001oogoo08moo`04001l07`001l>O0000`00O01l000?O0000`00O01l000@O000
0`00O01l000>O0000`0O001oo`0VOol001eoo`03001oogoo08moo`03001l000O00ml0003001l07`0
00ml0003001l07`0011l0003001l07`000il000301l007oo02Ioo`007Goo00<007ooOol0Sgoo00<0
07`001l03g`000<007`0O0003g`000<007`0O00047`000<007`0O0003g`000<07gooOol09Goo000M
Ool2002@Ool00`0001ml000?O0000`00O01l000?O0000`00O01l000@O0000`00O01l000?O0000`0O
Oomoo`0UOol001eoo`03001oogoo08moo`0300007g`000ml0003001l07`000ml0003001l07`0011l
0003001l07`000ml000301moogoo02Eoo`007Goo00<007ooOol0Sgoo00<07g`0O0003g`000<007`0
O0003g`000<007`0O00047`000<007`0O0003g`000<0000OOol09Goo000MOol00`00Oomoo`2?Ool0
0`0OO01l000?O0000`00O01l000?O0000`00O01l000@O0000`00O01l000?O0000`0001moo`0UOol0
01eoo`03001oogoo08ioo`0301l007`0011l0003001l07`000ml0003001l07`0011l0003001l07`0
00ml000300007goo02Eoo`007Goo0P00Sgoo00<07`00O00047`000<007`0O0003g`000<007`0O000
47`000<007`0O0003g`000<007oo01l09Goo000MOol00`00Oomoo`2=Ool00`0OOol0000AO0000`00
O01l000?O0000`00O01l000@O0000`00O01l000?O0000`00Ool07`0UOol001eoo`03001oogoo08eo
o`0301moo`00015l0003001l07`000ml0003001l07`0011l0003001l07`000ml0004001oogoo01lT
Ool001eoo`03001oogoo08aoo`0401moogoo000AO0000`00O01l000?O0000`00O01l000@O0000`00
O01l000?O0001000Oomoo`0O97oo000MOol2002=Ool0100OOomoo`004G`000<007`0O0003g`000<0
07`0O00047`000<007`0O0003g`000@007ooOol07bAoo`007Goo00<007ooOol0Rgoo00D07gooOomo
o`00015l0003001l07`000ml0003001l07`0011l0003001l07`000ml0005001oogooOol07`0SOol0
01Eoo`@000Aoo`03001oogoo08]oo`0501moogooOol0000AO0000`00O01l000?O0000`00O01l000@
O0000`00O01l000?O0001@00Oomoogoo01l08goo000FOol00`00Oomoo`04Ool00`00Oomoo`2:Ool0
0`0OOomoo`02Ool00`00O01l000?O0000`00O01l000?O0000`00O01l000@O0000`00O01l000?O000
1@00Oomoogoo01l08goo000?Ool50003Ool00`00Oomoo`03Ool3002:Ool00`0OOomoo`02Ool00`00
O01l000?O0000`00O01l000?O0000`00O01l000@O0000`00O01l000?O0000`00Oomoo`02Ool00`0O
Oomoo`0POol001Qoo`03001oogoo009oo`03001oogoo08Uoo`0301moogoo00=oo`03001l07`000ml
0003001l07`000ml0003001l07`0011l0003001l07`000ml0003001oogoo009oo`0301moogoo021o
o`005Goo00@007ooOol000Aoo`03001oogoo08Uoo`0301moogoo00=oo`03001l07`000ml0003001l
07`000ml0003001l07`0011l0003001l07`000ml0003001oogoo00=oo`0301moogoo01moo`005Woo
0P001Goo00<007ooOol0R7oo00<07gooOol017oo00<007`0O0003g`000<007`0O0003g`000<007`0
O00047`000<007`0O0003g`000<007ooOol00goo00<07gooOol07goo000MOol00`00Oomoo`28Ool0
0`0OOomoo`04Ool00`00O01l000?O0000`00O01l000?O0000`00O01l000@O0000`00O01l000?O000
0`00Oomoo`03Ool00`0OOomoo`0OOol001eoo`8008Qoo`0301moogoo00Eoo`03001l07`000ml0003
001l07`000ml0003001l07`0011l0003001l07`000ml0003001oogoo00Aoo`0301moogoo01ioo`00
7Goo00<007ooOol0Qgoo00<07gooOol01Goo00<007`0O0003g`000<007`0O0003g`000<007`0O000
47`000<007`0O0003g`000<007ooOol017oo00<07gooOol07Woo000MOol00`00Oomoo`1mOol90000
0`0O00000007000AO0000`00O01l000?O0000`00O01l000@O0000`00O01l000?O0000`00Oomoo`04
Ool00`0OOomoo`0NOol001eoo`03001oogoo07eoo`03001l07`000Il000301ml07`000Il0003001l
07`000ml0003001l07`000ml0003001l07`0011l0003001l07`000ml0003001oogoo00Eoo`0301mo
ogoo01eoo`007Goo0P00OWoo00<007`0O0001G`000<07g`0O0001g`000<007`0O0003g`000<007`0
O0003g`000<007`0O00047`000<007`0O0003g`000<007ooOol01Goo00<07gooOol07Goo000MOol0
0`00Oomoo`1mOol00`00O01l0005O0000`0OO01l0007O0000`00O01l000?O0000`00O01l000?O000
0`00O01l000@O0000`00O01l000?O0000`00Oomoo`05Ool00`0OOomoo`0MOol001eoo`03001oogoo
07eoo`03001l07`000Al000301ml07`000Ql0003001l07`000ml0003001l07`000ml0003001l07`0
011l0003001l07`000ml0003001oogoo00Ioo`0301moogoo01aoo`007Goo00<007ooOol0OGoo00<0
07`0O00017`000<07g`0O00027`000<007`0O0003g`000<007`0O0003g`000<007`0O00047`000<0
07`0O0003g`000<007ooOol01Woo00<07gooOol077oo000MOol00`00Oomoo`1mOol00`00O01l0003
O0000`0OO01l0009O0000`00O01l000?O0000`00O01l000?O0000`00O01l000@O0000`00O01l000?
O00900000`0O00000007000EOol001eoo`8007ioo`03001l07`000=l000301ml07`000Ul0003001l
07`000ml0003001l07`000ml0003001l07`0011l0003001l07`000ml0003001l07`000Ml000301ml
07`000El0003001oogoo01=oo`007Goo00<007ooOol0OGoo00<007`0O0000g`000<07g`0O0002G`0
00<007`0O0003g`000<007`0O0003g`000<007`0O00047`000<007`0O0003g`000<007`0O0001g`0
00<07g`0O0001G`000<007ooOol04goo000MOol00`00Oomoo`1mOol00`00O01l0002O0000`0OO01l
000:O0000`00O01l000?O0000`00O01l000?O0000`00O01l000@O0000`00O01l000?O0000`00O01l
0007O0000`0OO01l0005O0000`00Oomoo`0COol001eoo`03001oogoo07eoo`03001l07`0009l0003
01ml07`000Yl0003001l07`000ml0003001l07`000ml0003001l07`0011l0003001l07`000ml0003
001l07`000Ml000301ml07`000El0003001oogoo01=oo`007Goo0P00OWoo00D007`0O01l000O00el
0003001l07`000ml0003001l07`000ml0003001l07`0011l0003001l07`000ml0003001l07`000Ql
000301ml07`000Al0003001oogoo01=oo`007Goo00<007ooOol0OGoo00D007`0O01l000O00el0003
001l07`000ml0003001l07`000ml0003001l07`0011l0003001l07`000ml0003001l07`000Ql0003
01ml07`000Al0003001oogoo01=oo`005Goo0`001Goo00<007ooOol0OGoo00@007`0O0007`il0003
001l07`000ml0003001l07`000ml0003001l07`0011l0003001l07`000ml0003001l07`000Ql0003
01ml07`000Al0003001oogoo01=oo`005Woo00<007ooOol017oo00<007ooOol0OGoo00@007`0O000
7`il0003001l07`000ml0003001l07`000ml0003001l07`0011l0003001l07`000ml0003001l07`0
00Ul000301ml07`000=l0003001oogoo01=oo`003goo1@000Woo00<007ooOol017oo0`00OGoo00<0
07`001l03g`000<007`0O0003g`000<007`0O0003g`000<007`0O00047`000<007`0O0003g`000<0
07`0O0002G`000<07g`0O0000g`000<007ooOol04goo000FOol00`00Oomoo`04Ool00`00Oomoo`1m
Ool00`00O0007`0?O0000`00O01l000?O0000`00O01l000?O0000`00O01l000@O0000`00O01l000?
O0000`00O01l0009O0000`0OO01l0003O0000`00Oomoo`0COol001Ioo`03001oogoo00Aoo`03001o
ogoo07eoo`0300007g`000ml0003001l07`000ml0003001l07`000ml0003001l07`0011l0003001l
07`000ml0003001l07`000Ul000301ml07`000=l0003001oogoo01=oo`005Goo0P001Woo00<007oo
Ool0OGoo00<0000OO0003g`000<007`0O0003g`000<007`0O0003g`000<007`0O00047`000<007`0
O0003g`000<007`0O0002W`000<07g`0O0000W`000<007ooOol04goo000MOol00`00Oomoo`1mOol0
0`0OO01l000?O0000`00O01l000?O0000`00O01l000?O0000`00O01l000@O0000`00O01l000?O000
0`00O01l000:O0000`0OO01l0002O0000`00Oomoo`0COol001eoo`8007ioo`0301ml07`000ml0003
001l07`000ml0003001l07`000ml0003001l07`0011l0003001l07`000ml0003001l07`000Yl0003
01ml07`0009l0003001oogoo01=oo`007Goo00<007ooOol0O7oo00<07`00O00047`000<007`0O000
3g`000<007`0O0003g`000<007`0O00047`000<007`0O0003g`000<007`0O0002W`000<07g`0O000
0W`000<007ooOol04goo000MOol00`00Oomoo`1lOol00`0O001l000@O0000`00O01l000?O0000`00
O01l000?O0000`00O01l000@O0000`00O01l000?O0000`00O01l000;O0001@0OO01l07`000005Goo
000MOol00`00Oomoo`1kOol00`0OOol0000AO0000`00O01l000?O0000`00O01l000?O0000`00O01l
000@O0000`00O01l000?O0000`00O01l000;O0001@0OO01l07`000005Goo000MOol2001lOol00`0O
Ool0000AO0000`00O01l000?O0000`00O01l000?O0000`00O01l000@O0000`00O01l000?O0000`00
O01l000;O0001@0OO01l07`000005Goo000MOol00`00Oomoo`1jOol0100OOomoo`004G`000<007`0
O0003g`000<007`0O0003g`000<007`0O00047`000<007`0O0003g`000<007`0O0002g`000D07g`0
O01l000001Eoo`007Goo00<007ooOol0NWoo00@07gooOol0015l0003001l07`000ml0003001l07`0
00ml0003001l07`0011l0003001l07`000ml0003001l07`000al000401ml07`0000EOol001eoo`03
001oogoo025oo`<002=oo`@0025oo`<000Yoo`0501moogooOol0000AO0000`00O01l000?O0000`00
O01l000?O0000`00O01l000@O0000`00O01l000?O0000`00O01l000<O000100OO01l00005Goo000M
Ool00`00Oomoo`0ROol00`00Oomoo`0SOol00`00Oomoo`0TOol00`00Oomoo`07Ool01@0OOomoogoo
00004G`000<007`0O0003g`000<007`0O0003g`000<007`0O00047`000<007`0O0003g`000<007`0
O00037`000@07g`0O00001Eoo`007Goo0P008goo00<007ooOol097oo00<007ooOol08goo00<007oo
Ool01Woo00<07gooOol00Woo00<007`0O0003g`000<007`0O0003g`000<007`0O0003g`000<007`0
O00047`000<007`0O0003g`000<007`0O00037`000@07g`0O00001Eoo`007Goo00<007ooOol08Woo
00<007ooOol09Goo00<007ooOol087oo0P002Goo00<07gooOol00Woo00<007`0O0003g`000<007`0
O0003g`000<007`0O0003g`000<007`0O00047`000<007`0O0003g`000<007`0O0003G`000<07g`0
00005Goo000MOol00`00Oomoo`0ROol00`00Oomoo`0ROol01000Oomoo`0097oo00<007ooOol01Goo
00<07gooOol00goo00<007`0O0003g`000<007`0O0003g`000<007`0O0003g`000<007`0O00047`0
00<007`0O0003g`000<007`0O0003G`000<07g`000005Goo000MOol00`00Oomoo`0QOol2000UOol2
000ROol30008Ool00`0OOomoo`03Ool00`00O01l000?O0000`00O01l000?O0000`00O01l000?O000
0`00O01l000@O0000`00O01l000?O0000`00O01l000=O0000`0OO000000EOol001eoo`8007Moo`03
01moogoo00Aoo`03001l07`000ml0003001l07`000ml0003001l07`000ml0003001l07`0011l0003
001l07`000ml0003001l07`000il000301l007oo01Aoo`007Goo00<007ooOol0MWoo00<07gooOol0
17oo00<007`0O0003g`000<007`0O0003g`000<007`0O0003g`000<007`0O00047`000<007`0O000
3g`000<007`0O0003W`000<07`00Ool057oo000MOol00`00Oomoo`1eOol00`0OOomoo`05Ool00`00
O01l000?O0000`00O01l000?O0000`00O01l000?O0000`00O01l000@O0000`00O01l000?O0000`00
O01l000>O0000`0O001oo`0DOol001eoo`03001oogoo07Eoo`0301moogoo00Eoo`03001l07`000ml
0003001l07`000ml0003001l07`000ml0003001l07`0011l0003001l07`000ml0003001l07`000il
000301l007oo01Aoo`007Goo00<007ooOol0Jgoo00<007ooOol01Woo00<07gooOol01Woo00<007`0
O0003g`000<007`0O0003g`000<007`0O0003g`000<007`0O00047`000<007`0O0003g`000<007`0
O0003g`000<07gooOol04goo000GOol6000:01m]00000`0O00000007000AO0000`00O01l000?O000
0`00O01l000?O0000`00O01l000@O0000`00O01l000?O0000`00O01l000?O0000`0O00000004000?
Ool001eoo`X000807`L0019l0003001l07`000ml0003001l07`000ml0003001l07`000ml0003001l
07`000ml0005001oogooOol00004Ool00`0OOomoo`0NOol00`00Oomoo`0SOol00`00Oomoo`0ROol0
0`00Oomoo`0NOol001eoo`03001oogoo00Uoo`<07`=oo`03001l07`0011l0003001l07`000ml0003
001l07`000ml0003001l07`000ml0003001l07`000ml0003001oogoo00Eoo`0301moogoo08]oo`00
7Goo00<007ooOol037oo0P0O00=oo`00O0004G`000<007`0O0003g`000<007`0O0003g`000<007`0
O0003g`000<007`0O0003g`000<007ooOol01Goo00<07gooOol0Rgoo000MOol2000?Ool201lBO000
0`00O01l000?O0000`00O01l000?O0000`00O01l000?O0000`00O01l000?O0000`00Oomoo`04Ool0
0`0OOomoo`2<Ool001eoo`03001oogoo00moo`0300007g`0011l0003001l07`000ml0003001l07`0
00ml0003001l07`000ml0003001l07`000ml0003001oogoo00Aoo`0301moogoo08aoo`007Goo00<0
07ooOol03goo00@007`001l07`ml0003001l07`000ml0003001l07`000ml0003001l07`000ml0003
001l07`000ml0003001oogoo00=oo`0301moogoo08eoo`007Goo00<007ooOol03goo00@007`0O01l
00807`el0003001l07`000ml0003001l07`000ml0003001l07`000ml0003001l07`000ml0003001o
ogoo009oo`0301moogoo08ioo`007Goo0P0047oo00<007`0O0000g`000<07g`0O0002W`000<007`0
O0003g`000<007`0O0003g`000<007`0O0003g`000<007`0O0003g`000<007ooOol00Woo00<07goo
Ool0SWoo000MOol00`00Oomoo`0?Ool00`00O01l0004O00201l:O0000`00O01l000?O0000`00O01l
000?O0000`00O01l000?O0000`00O01l000?O0001@00Oomoogoo01l0TGoo000MOol00`00Oomoo`0?
Ool9000201l9000AO0000`00O01l000?O0000`00O01l000?O0000`00O01l000?O0001000Oomoo`0O
TWoo000MOol00`00Oomoo`0JOol00`0OOomoo`05Ool00`00O01l000?O0000`00O01l000?O0000`00
O01l000?O0000`00O01l000?O0001000Oomoo`0OTWoo000MOol00`00Oomoo`0KOol201l5Ool00`00
O01l000?O0000`00O01l000?O0000`00O01l000?O0000`00O01l000?O0000`00Ool07`2COol001eo
o`8001ioo`0301moogoo009oo`03001l07`000ml0003001l07`000ml0003001l07`000ml0003001l
07`000ml0003001oo`0O09=oo`007Goo00<007ooOol07Woo00D07gooOomoo`00015l0003001l07`0
00ml0003001l07`000ml0003001l07`000ml000300007goo09=oo`007Goo00<007ooOol07goo00@0
7gooOol0015l0003001l07`000ml0003001l07`000ml0003001l07`000ml000301moogoo09=oo`00
7Goo00<007ooOol087oo0P0O00<007`0O0003g`000<007`0O0003g`000<007`0O0003g`000<007`0
O0003g`000<07gooOol0Tgoo000MOol2000SOol00`0OO01l000?O0000`00O01l000?O0000`00O01l
000?O0000`00O01l000>O0000`0O001oo`2DOol001eoo`03001oogoo029oo`0300007g`000ml0003
001l07`000ml0003001l07`000ml0003001l07`000el000301ml000009Eoo`007Goo00<007ooOol0
8Woo00<007`001l03g`000<007`0O0003g`000<007`0O0003g`000<007`0O00037`000@07g`0O000
09Eoo`005Goo0`001Goo00<007ooOol08Woo00<007`0O0000P0O3G`000<007`0O0003g`000<007`0
O0003g`000<007`0O00037`000@07g`0O00009Eoo`005Woo00<007ooOol017oo00<007ooOol08Woo
00<007`0O0000W`000<07g`0O0002W`000<007`0O0003g`000<007`0O0003g`000<007`0O0002g`0
00D07g`0O01l000009Eoo`005Woo00<007ooOol017oo0`008Woo00<007`0O0000g`000<07g`0O000
2G`000<007`0O0003g`000<007`0O0003g`000<007`0O0002W`000<07g`0O0000W`000<007ooOol0
Tgoo000FOol00`00Oomoo`04Ool00`00Oomoo`0ROol00`00O01l0004O0000`0OO01l0008O0000`00
O01l000?O0000`00O01l000?O0000`00O01l0009O0000`0OO01l0003O0000`00Oomoo`2COol001Io
o`03001oogoo00Aoo`03001oogoo029oo`P000807`T0015l0003001l07`000ml0003001l07`000Ql
000301ml07`000Al0003001oogoo09=oo`005Goo0P001Woo00<007ooOol0;7oo00<07gooOol01Goo
00<007`0O0003g`000<007`0O0003g`000<007`0O00027`000<07g`0O00017`000<007ooOol0Tgoo
000MOol2000^Ool00`0OOomoo`04Ool00`00O01l000?O0000`00O01l000?O0000`00O01l0007O000
0`0OO01l0005O0000`00Oomoo`2COol001eoo`03001oogoo02ioo`0301moogoo00=oo`03001l07`0
00ml0003001l07`000ml00T0000301l0000000L009Eoo`007Goo00<007ooOol0;goo0P0O0goo00<0
07`0O0003g`000<007`0O0003g`000<007ooOol01Goo00<07gooOol0WGoo000MOol00`00Oomoo`0a
Ool0100OOomoo`004G`000<007`0O0003g`000<007ooOol017oo00<07gooOol0WWoo000MOol2000c
Ool201l00`00O01l000?O0000`00O01l000?O0000`00Oomoo`03Ool00`0OOomoo`2OOol001eoo`03
001oogoo03Aoo`0301ml07`000ml0003001l07`000ml0003001oogoo009oo`0301moogoo0:1oo`00
7Goo00<007ooOol0=7oo00<0000O01l03g`000<007`0O0003g`000<007ooOol00P0OXgoo000MOol0
0`00Oomoo`0dOol01000O01l000O3W`000<007`0O0003g`000<007oo01l0YGoo000MOol00`00Oomo
o`0dOol01000O01l07`00P0O37`000<007`0O0003g`000<0000OOol0YGoo000MOol2000eOol00`00
O01l0003O0000`0OO01l0009O0000`00O01l000?O0000`0OOomoo`2UOol001eoo`03001oogoo03Ao
o`03001l07`000Al00<07`Ql0003001l07`000el00807`03001oogoo0:Eoo`007Goo00<007ooOol0
=7oo2P000P0O1`0037`00`0O0W`000<007ooOol0YGoo000MOol00`00Oomoo`10Ool301l3Ool00`00
O01l0008O00201l5O0000`00Oomoo`2UOol001eoo`8004Aoo`@07`H000@07`P00:Moo`007Goo00<0
07ooOol0Agoo1P0O/goo000MOol00`00Oomoo`3oOol1Ool001eoo`03001oogoo0?moo`5oo`007Goo
00<007ooOol0ogoo0Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo
8Goo003oOolQOol00?moob5oo`00>7oo1P001Woo0`000goo100017oo0`001Goo0`000goo100000=o
o`0000000P000Woo0P001Goo2P0000=oo`0000000P000Woo100017oo10000goo100067oo100017oo
0P000goo0P002Goo00<007ooOol01Goo100027oo0P000goo0P002Goo0`00<goo000jOol20007Ool2
0002Ool01000Oomoogoo0P0017oo0P000Woo00@007ooOomoo`80009oo`04001oogooOol20003Ool2
0002Ool200000goo001oo`05Ool20005Ool200000goo00000004Ool20004Ool20002Ool20003Ool2
000HOol20002Ool20003Ool20005Ool20007Ool20005Ool20002Ool20007Ool20005Ool20005Ool2
0002Ool2000bOol003Yoo`8000Ioo`8000Aoo`03001oogoo008000=oo`8000Aoo`04001oo`000004
Ool00`00Oomoo`020003Ool20002Ool20008Ool20006Ool01000Ool0000017oo0P000goo0P0017oo
0P000Woo0P0027oo2@001goo00<007ooOol00Woo00<007ooOol02Goo0P001goo00<007ooOol00goo
00<007ooOol00Woo00<007ooOol01Goo0P001Woo0P0017oo00<007ooOol00Woo0P00<Goo000jOol2
0006Ool20007Ool20003Ool20006Ool20007Ool20003Ool20002Ool20008Ool20008Ool20004Ool2
0003Ool20004Ool20002Ool2000GOol20004Ool2000;Ool20006Ool00`00Oomoo`02Ool20004Ool2
00000goo000000070005Ool20002Ool20004Ool2000aOol003Yoo`8000Ioo`8000Moo`8000=oo`80
00Ioo`8000Moo`8000=oo`80009oo`8000Qoo`8000Aoo`04001oogooOol20004Ool20003Ool20004
Ool20002Ool2000GOol20004Ool2000;Ool20006Ool00`00Oomoo`02Ool20004Ool200000goo001o
o`03Ool20007Ool20002Ool20004Ool2000aOol003Yoo`H0009oo`L0009oo`8000=oo`8000Aoo`03
001oo`0000H0009oo`8000=oo`80009oo`8000Qoo`8000Aoo`04001oogooOol20004Ool20003Ool2
0004Ool20002Ool2000GOol20004Ool20008Ool60006Ool01000Oomoogoo0P0017oo0P000Woo00@0
07ooOomoo`8000Aoo`H00003Ool0000000Aoo`80035oo`00>Woo0P000goo0P000Woo00@007ooOomo
o`800003Ool0000000@00003Ool00000009oo`80009oo`04001oogooOol200000goo000000020002
Ool20002Ool20008Ool70002Ool<00000goo00000002Ool20002Ool60005Ool90006Ool20004Ool2
0007Ool20003Ool20006Ool01000Oomoogoo0P0017oo0P000goo00<007ooOol00P000goo0P000goo
0P0000Aoo`000000009oo`80039oo`00>Woo0P0017oo0P000Woo100017oo00@007oo0000009oo`@0
00Aoo`@000Aoo`03001oo`000080009oo`D000Ioo`8000Aoo`03001oogoo009oo`04001oo`000002
Ool01000Ool000000Woo10001Goo00@007oo000001Aoo`8000Aoo`8000Ioo`8000Aoo`8000Ioo`04
001oogooOol20004Ool20003Ool00`00Oomoo`020002Ool20004Ool2000017oo000007oo0`00<goo
000jOol20004Ool2000XOol20008Ool20004Ool00`00Oomoo`0_Ool20004Ool20006Ool20004Ool2
0007Ool00`00Oomoo`020004Ool20004Ool01000Ool000000Woo0P0017oo0P000Woo0P00=Woo000j
Ool20004Ool2000YOol00`00Oomoo`06Ool2000fOol20004Ool20006Ool20004Ool20007Ool00`00
Oomoo`020004Ool20005Ool30002Ool20004Ool20002Ool2000fOol003Yoo`8000Aoo`80039oo`80
00Eoo`03001oogoo02moo`03001oogoo009oo`03001oogoo00Eoo`8000Aoo`800003Ool0000000Ao
o`05001oogooOol00004Ool00`00Oomoo`04Ool30002Ool20004Ool20003Ool2000eOol003Yoo`80
00=oo`8003=oo`8000Eoo`03001oogoo02moo`80009oo`8000Qoo`80009oo`8000=oo`L0009oo`80
009oo`8000Moo`8000=oo`80009oo`8000Eoo`8003Aoo`00>7oo2000<Woo2P00<Woo10002Woo1000
17oo1`000goo100027oo0P0017oo100027oo0`00<Goo003oOolQOol00?moob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.783823, -4.98036, 
  0.0265065, 0.0452841}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.151576 0.44187 0.0887232 [
[.17539 .42937 -3 -9 ]
[.17539 .42937 3 0 ]
[.32696 .42937 -3 -9 ]
[.32696 .42937 3 0 ]
[.47854 .42937 -3 -9 ]
[.47854 .42937 3 0 ]
[.63011 .42937 -3 -9 ]
[.63011 .42937 3 0 ]
[.78169 .42937 -3 -9 ]
[.78169 .42937 3 0 ]
[.93327 .42937 -3 -9 ]
[.93327 .42937 3 0 ]
[.01131 .08698 -12 -4.5 ]
[.01131 .08698 0 4.5 ]
[.01131 .1757 -12 -4.5 ]
[.01131 .1757 0 4.5 ]
[.01131 .26442 -12 -4.5 ]
[.01131 .26442 0 4.5 ]
[.01131 .35315 -12 -4.5 ]
[.01131 .35315 0 4.5 ]
[.01131 .53059 -6 -4.5 ]
[.01131 .53059 0 4.5 ]
[.5 .63053 -94.0938 0 ]
[.5 .63053 94.0938 20 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.17539 .44187 m
.17539 .44812 L
s
[(1)] .17539 .42937 0 1 Mshowa
.32696 .44187 m
.32696 .44812 L
s
[(2)] .32696 .42937 0 1 Mshowa
.47854 .44187 m
.47854 .44812 L
s
[(3)] .47854 .42937 0 1 Mshowa
.63011 .44187 m
.63011 .44812 L
s
[(4)] .63011 .42937 0 1 Mshowa
.78169 .44187 m
.78169 .44812 L
s
[(5)] .78169 .42937 0 1 Mshowa
.93327 .44187 m
.93327 .44812 L
s
[(6)] .93327 .42937 0 1 Mshowa
.125 Mabswid
.05412 .44187 m
.05412 .44562 L
s
.08444 .44187 m
.08444 .44562 L
s
.11476 .44187 m
.11476 .44562 L
s
.14507 .44187 m
.14507 .44562 L
s
.2057 .44187 m
.2057 .44562 L
s
.23602 .44187 m
.23602 .44562 L
s
.26633 .44187 m
.26633 .44562 L
s
.29665 .44187 m
.29665 .44562 L
s
.35728 .44187 m
.35728 .44562 L
s
.38759 .44187 m
.38759 .44562 L
s
.41791 .44187 m
.41791 .44562 L
s
.44822 .44187 m
.44822 .44562 L
s
.50885 .44187 m
.50885 .44562 L
s
.53917 .44187 m
.53917 .44562 L
s
.56948 .44187 m
.56948 .44562 L
s
.5998 .44187 m
.5998 .44562 L
s
.66043 .44187 m
.66043 .44562 L
s
.69074 .44187 m
.69074 .44562 L
s
.72106 .44187 m
.72106 .44562 L
s
.75137 .44187 m
.75137 .44562 L
s
.81201 .44187 m
.81201 .44562 L
s
.84232 .44187 m
.84232 .44562 L
s
.87264 .44187 m
.87264 .44562 L
s
.90295 .44187 m
.90295 .44562 L
s
.96358 .44187 m
.96358 .44562 L
s
.9939 .44187 m
.9939 .44562 L
s
.25 Mabswid
0 .44187 m
1 .44187 L
s
.02381 .08698 m
.03006 .08698 L
s
[(-4)] .01131 .08698 1 0 Mshowa
.02381 .1757 m
.03006 .1757 L
s
[(-3)] .01131 .1757 1 0 Mshowa
.02381 .26442 m
.03006 .26442 L
s
[(-2)] .01131 .26442 1 0 Mshowa
.02381 .35315 m
.03006 .35315 L
s
[(-1)] .01131 .35315 1 0 Mshowa
.02381 .53059 m
.03006 .53059 L
s
[(1)] .01131 .53059 1 0 Mshowa
.125 Mabswid
.02381 .016 m
.02756 .016 L
s
.02381 .03374 m
.02756 .03374 L
s
.02381 .05149 m
.02756 .05149 L
s
.02381 .06923 m
.02756 .06923 L
s
.02381 .10472 m
.02756 .10472 L
s
.02381 .12247 m
.02756 .12247 L
s
.02381 .14021 m
.02756 .14021 L
s
.02381 .15796 m
.02756 .15796 L
s
.02381 .19344 m
.02756 .19344 L
s
.02381 .21119 m
.02756 .21119 L
s
.02381 .22893 m
.02756 .22893 L
s
.02381 .24668 m
.02756 .24668 L
s
.02381 .28217 m
.02756 .28217 L
s
.02381 .29991 m
.02756 .29991 L
s
.02381 .31766 m
.02756 .31766 L
s
.02381 .3354 m
.02756 .3354 L
s
.02381 .37089 m
.02756 .37089 L
s
.02381 .38864 m
.02756 .38864 L
s
.02381 .40638 m
.02756 .40638 L
s
.02381 .42413 m
.02756 .42413 L
s
.02381 .45961 m
.02756 .45961 L
s
.02381 .47736 m
.02756 .47736 L
s
.02381 .4951 m
.02756 .4951 L
s
.02381 .51285 m
.02756 .51285 L
s
.02381 .54834 m
.02756 .54834 L
s
.02381 .56608 m
.02756 .56608 L
s
.02381 .58383 m
.02756 .58383 L
s
.02381 .60157 m
.02756 .60157 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -155.094 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 24.000000 moveto
 558.000000 24.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 24.000000 lineto
closepath
clip newpath
63.000000 19.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 18.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 19.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 18.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Percent) show
121.250000 19.000000 moveto
(Error) show
163.625000 19.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 18.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(=) show
179.687500 19.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 18.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.837142) show
247.187500 19.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 18.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
0 0 1 r
.007 w
.02381 .44187 m
.02499 .44188 L
.02605 .44189 L
.02729 .44192 L
.02846 .44195 L
.03053 .44204 L
.03279 .44218 L
.03527 .44238 L
.0379 .44264 L
.04262 .44323 L
.04749 .44403 L
.05205 .44493 L
.06244 .44757 L
.07305 .45107 L
.08274 .45495 L
.10458 .46589 L
.14429 .4922 L
.18248 .52229 L
.22313 .55474 L
.26226 .58144 L
.27254 .5871 L
.28367 .59241 L
.29328 .59624 L
.29838 .59795 L
.30384 .59955 L
.30923 .60086 L
.31415 .60182 L
.31652 .6022 L
.31909 .60255 L
.32151 .60282 L
.32378 .60303 L
.32509 .60312 L
.3263 .60319 L
.32764 .60325 L
.32834 .60327 L
.32908 .60329 L
.32976 .60331 L
.33048 .60332 L
.33177 .60332 L
.33257 .60331 L
.33332 .6033 L
.33399 .60328 L
.33472 .60326 L
.33594 .60321 L
.33728 .60313 L
.33999 .60292 L
.34249 .60266 L
.34484 .60235 L
.34982 .60149 L
.35525 .60023 L
Mistroke
.36513 .59709 L
.37475 .59294 L
.38367 .58812 L
.40423 .57339 L
.42285 .55569 L
.46297 .50405 L
.50157 .43897 L
.54262 .35759 L
.58216 .27326 L
.62019 .19318 L
.66067 .11668 L
.69963 .05896 L
.70983 .04728 L
.72091 .03645 L
.73048 .02875 L
.73557 .02531 L
.74104 .02213 L
.74638 .01956 L
.75126 .01767 L
.75594 .01629 L
.75829 .01576 L
.76085 .0153 L
.76227 .01511 L
.76362 .01496 L
.76482 .01485 L
.76612 .01477 L
.7668 .01474 L
.76755 .01472 L
.76833 .01472 L
.76905 .01472 L
.77035 .01475 L
.77108 .01478 L
.77175 .01482 L
.77304 .01492 L
.77424 .01504 L
.77695 .01543 L
.77933 .0159 L
.78187 .01653 L
.78675 .0181 L
.79123 .01999 L
.80132 .02578 L
.81022 .03269 L
.81959 .04179 L
.83931 .06705 L
.85767 .09794 L
.89668 .18599 L
.93815 .30895 L
.97619 .44187 L
Mfstroke
1 0 0 r
.02381 .44187 m
.09184 .44187 L
.09184 .4463 L
.02381 .4463 L
F
.09184 .44187 m
.15986 .44187 L
.15986 .47911 L
.09184 .47911 L
F
.15986 .44187 m
.22789 .44187 L
.22789 .53156 L
.15986 .53156 L
F
.22789 .44187 m
.29592 .44187 L
.29592 .58124 L
.22789 .58124 L
F
.29592 .44187 m
.36395 .44187 L
.36395 .60331 L
.29592 .60331 L
F
.36395 .44187 m
.43197 .44187 L
.43197 .57842 L
.36395 .57842 L
F
.43197 .44187 m
.5 .44187 L
.5 .49946 L
.43197 .49946 L
F
.5 .44187 m
.56803 .44187 L
.56803 .37542 L
.5 .37542 L
F
.56803 .44187 m
.63605 .44187 L
.63605 .23084 L
.56803 .23084 L
F
.63605 .44187 m
.70408 .44187 L
.70408 .10105 L
.63605 .10105 L
F
.70408 .44187 m
.77211 .44187 L
.77211 .02377 L
.70408 .02377 L
F
.77211 .44187 m
.84014 .44187 L
.84014 .0293 L
.77211 .0293 L
F
.84014 .44187 m
.90816 .44187 L
.90816 .13154 L
.84014 .13154 L
F
.90816 .44187 m
.97619 .44187 L
.97619 .32225 L
.90816 .32225 L
F
0 g
.5 Mabswid
.02381 .44187 m
.02381 .4463 L
s
.09184 .44187 m
.09184 .4463 L
s
.02381 .4463 m
.09184 .4463 L
s
.09184 .44187 m
.09184 .47911 L
s
.15986 .44187 m
.15986 .47911 L
s
.09184 .47911 m
.15986 .47911 L
s
.15986 .44187 m
.15986 .53156 L
s
.22789 .44187 m
.22789 .53156 L
s
.15986 .53156 m
.22789 .53156 L
s
.22789 .44187 m
.22789 .58124 L
s
.29592 .44187 m
.29592 .58124 L
s
.22789 .58124 m
.29592 .58124 L
s
.29592 .44187 m
.29592 .60331 L
s
.36395 .44187 m
.36395 .60331 L
s
.29592 .60331 m
.36395 .60331 L
s
.36395 .44187 m
.36395 .57842 L
s
.43197 .44187 m
.43197 .57842 L
s
.36395 .57842 m
.43197 .57842 L
s
.43197 .44187 m
.43197 .49946 L
s
.5 .44187 m
.5 .49946 L
s
.43197 .49946 m
.5 .49946 L
s
.5 .44187 m
.5 .37542 L
s
.56803 .44187 m
.56803 .37542 L
s
.5 .37542 m
.56803 .37542 L
s
.56803 .44187 m
.56803 .23084 L
s
.63605 .44187 m
.63605 .23084 L
s
.56803 .23084 m
.63605 .23084 L
s
.63605 .44187 m
.63605 .10105 L
s
.70408 .44187 m
.70408 .10105 L
s
.63605 .10105 m
.70408 .10105 L
s
.70408 .44187 m
.70408 .02377 L
s
.77211 .44187 m
.77211 .02377 L
s
.70408 .02377 m
.77211 .02377 L
s
.77211 .44187 m
.77211 .0293 L
s
.84014 .44187 m
.84014 .0293 L
s
.77211 .0293 m
.84014 .0293 L
s
.84014 .44187 m
.84014 .13154 L
s
.90816 .44187 m
.90816 .13154 L
s
.84014 .13154 m
.90816 .13154 L
s
.90816 .44187 m
.90816 .32225 L
s
.97619 .44187 m
.97619 .32225 L
s
.90816 .32225 m
.97619 .32225 L
s
0 0 1 r
.007 w
.02381 .44187 m
.02499 .44188 L
.02605 .44189 L
.02729 .44192 L
.02846 .44195 L
.03053 .44204 L
.03279 .44218 L
.03527 .44238 L
.0379 .44264 L
.04262 .44323 L
.04749 .44403 L
.05205 .44493 L
.06244 .44757 L
.07305 .45107 L
.08274 .45495 L
.10458 .46589 L
.14429 .4922 L
.18248 .52229 L
.22313 .55474 L
.26226 .58144 L
.27254 .5871 L
.28367 .59241 L
.29328 .59624 L
.29838 .59795 L
.30384 .59955 L
.30923 .60086 L
.31415 .60182 L
.31652 .6022 L
.31909 .60255 L
.32151 .60282 L
.32378 .60303 L
.32509 .60312 L
.3263 .60319 L
.32764 .60325 L
.32834 .60327 L
.32908 .60329 L
.32976 .60331 L
.33048 .60332 L
.33177 .60332 L
.33257 .60331 L
.33332 .6033 L
.33399 .60328 L
.33472 .60326 L
.33594 .60321 L
.33728 .60313 L
.33999 .60292 L
.34249 .60266 L
.34484 .60235 L
.34982 .60149 L
.35525 .60023 L
Mistroke
.36513 .59709 L
.37475 .59294 L
.38367 .58812 L
.40423 .57339 L
.42285 .55569 L
.46297 .50405 L
.50157 .43897 L
.54262 .35759 L
.58216 .27326 L
.62019 .19318 L
.66067 .11668 L
.69963 .05896 L
.70983 .04728 L
.72091 .03645 L
.73048 .02875 L
.73557 .02531 L
.74104 .02213 L
.74638 .01956 L
.75126 .01767 L
.75594 .01629 L
.75829 .01576 L
.76085 .0153 L
.76227 .01511 L
.76362 .01496 L
.76482 .01485 L
.76612 .01477 L
.7668 .01474 L
.76755 .01472 L
.76833 .01472 L
.76905 .01472 L
.77035 .01475 L
.77108 .01478 L
.77175 .01482 L
.77304 .01492 L
.77424 .01504 L
.77695 .01543 L
.77933 .0159 L
.78187 .01653 L
.78675 .0181 L
.79123 .01999 L
.80132 .02578 L
.81022 .03269 L
.81959 .04179 L
.83931 .06705 L
.85767 .09794 L
.89668 .18599 L
.93815 .30895 L
.97619 .44187 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00O7Goo00<007ooOol0
ogoo0Goo000MOol00`00Oomoo`3oOol1Ool001eoo`03001oogoo0?moo`5oo`007Goo00<007ooOol0
]7oo1P0OAWoo000MOol2002bOol301l5Ool301m4Ool001eoo`03001oogoo0:Ioo`T000807`L000Ao
o`<07d5oo`007Goo00<007ooOol0YWoo00<007`0O0001G`000<07g`0O0001W`000<007ooOol01Goo
00<07gooOol0?Woo000MOol00`00Oomoo`2VOol00`00O01l0004O0000`0OO01l0007O00900000`0O
00000006000gOol001eoo`800:Moo`03001l07`000=l000301ml07`000Ql0003001l07`000Ml0003
01ml07`000Al0003001oogoo03Eoo`007Goo00<007ooOol0YWoo00@007`0O01l00807`]l0003001l
07`000Ql000301ml07`000=l0003001oogoo03Eoo`007Goo00<007ooOol0YWoo00@007`0O0007`el
0003001l07`000Ul000301ml07`0009l0003001oogoo03Eoo`007Goo00<007ooOol0YWoo00<007`0
01l03W`000<007`0O0002G`000<07g`0O0000W`000<007ooOol0=Goo000MOol2002WOol00`0001ml
000>O0000`00O01l000:O0001@0OO01l07`00000=goo000MOol00`00Oomoo`2VOol00`0OO01l000>
O0000`00O01l000;O000100OO01l0000=goo000MOol00`00Oomoo`2UOol00`0O001l000?O0000`00
O01l000<O0000`0OO000000gOol001eoo`03001oogoo0:Eoo`0301l007`000ml0003001l07`000el
000301l007oo03Ioo`007Goo00<007ooOol0Y7oo00<07goo000047`000<007`0O0003W`000<07goo
Ool0=Goo000MOol2002TOol0100OOomoo`0047`000<007`0O0003W`000<07gooOol0=Goo000MOol0
0`00Oomoo`2SOol0100OOomoo`0047`000<007`0O0003W`000<0000OOol0=Goo000FOol30004Ool0
0`00Oomoo`2ROol01@0OOomoogoo000047`000<007`0O0003W`000<007oo01l0=Goo000GOol00`00
Oomoo`03Ool00`00Oomoo`2ROol01@0OOomoogoo000047`000<007`0O0003W`000<007oo01l0=Goo
000?Ool500000goo000000020004Ool3002QOol00`0OOomoo`02Ool00`00O01l000>O0000`00O01l
000>O0001000Oomoo`0O=7oo000EOol00`00Ool00005Ool00`00Oomoo`2POol00`0OOomoo`03Ool0
0`00O01l000>O0000`00O01l000>O0001000Oomoo`0O=7oo000EOol00`00Ool00005Ool00`00Oomo
o`2POol00`0OOomoo`03Ool00`00O01l000>O0000`00O01l000>O0001@00Oomoogoo01l0<goo000F
Ool20005Ool00`00Oomoo`2OOol00`0OOomoo`04Ool00`00O01l000>O0000`00O01l000>O0000`00
Oomoo`02Ool00`0OOomoo`0`Ool001eoo`03001oogoo09Eoo`X0000301l0000000D0011l0003001l
07`000il0003001oogoo009oo`0301moogoo031oo`007Goo0P00UWoo00<007`0O0001W`000<07g`0
O0001G`000<007`0O0003W`000<007`0O0003W`000<007ooOol00goo00<07gooOol0;goo000MOol0
0`00Oomoo`2EOol00`00O01l0005O0000`0OO01l0006O0000`00O01l000>O0000`00O01l000>O000
0`00Oomoo`03Ool00`0OOomoo`0_Ool001eoo`03001oogoo09Eoo`03001l07`000El000301ml07`0
00Il0003001l07`000il0003001l07`000il0003001oogoo00=oo`0301moogoo02moo`007Goo00<0
07ooOol0UGoo00<007`0O00017`000<07g`0O0001g`000<007`0O0003W`000<007`0O0003W`000<0
07ooOol017oo00<07gooOol0;Woo000MOol2002FOol00`00O01l0004O0000`0OO01l0007O0000`00
O01l000>O0000`00O01l000>O0000`00Oomoo`04Ool00`0OOomoo`0^Ool001eoo`03001oogoo09Eo
o`03001l07`000=l000301ml07`000Ql0003001l07`000il0003001l07`000il0003001oogoo00Eo
o`0301moogoo02eoo`007Goo00<007ooOol0UGoo00<007`0O0000g`000<07g`0O00027`000<007`0
O0003W`000<007`0O0003W`0200000<07`0000001`009Woo000MOol00`00Oomoo`2EOol00`00O01l
0002O0000`0OO01l0009O0000`00O01l000>O0000`00O01l000>O0000`00O01l0005O0000`0OO01l
0006O0000`00Oomoo`0TOol001eoo`8009Ioo`03001l07`0009l000301ml07`000Ul0003001l07`0
00il0003001l07`000il0003001l07`000Il000301ml07`000El0003001oogoo02Aoo`007Goo00<0
07ooOol0UGoo00D007`0O01l000O00al0003001l07`000il0003001l07`000il0003001l07`000Il
000301ml07`000El0003001oogoo02Aoo`007Goo00<007ooOol0UGoo00D007`0O01l000O00al0003
001l07`000il0003001l07`000il0003001l07`000Ml000301ml07`000Al0003001oogoo02Aoo`00
7Goo00<007ooOol0UGoo00@007`0O0007`el0003001l07`000il0003001l07`000il0003001l07`0
00Ml000301ml07`000Al0003001oogoo02Aoo`007Goo00<007ooOol0UGoo00@007`0O0007`el0003
001l07`000il0003001l07`000il0003001l07`000Ql000301ml07`000=l0003001oogoo02Aoo`00
7Goo0P00UWoo00<007`001l03W`000<007`0O0003W`000<007`0O0003W`000<007`0O00027`000<0
7g`0O0000g`000<007ooOol097oo000MOol00`00Oomoo`2EOol00`0001ml000>O0000`00O01l000>
O0000`00O01l000>O0000`00O01l0008O0000`0OO01l0003O0000`00Oomoo`0TOol001Eoo`<000Eo
o`03001oogoo09Eoo`0300007g`000il0003001l07`000il0003001l07`000il0003001l07`000Ul
000301ml07`0009l0003001oogoo02Aoo`0067oo00<007ooOol00Woo00<007ooOol0UGoo00<07g`0
O0003W`000<007`0O0003W`000<007`0O0003W`000<007`0O0002G`000<07g`0O0000W`000<007oo
Ool097oo000?Ool50004Ool00`00Oomoo`02Ool3002EOol00`0OO01l000>O0000`00O01l000>O000
0`00O01l000>O0000`00O01l000:O0001@0OO01l07`000009Woo000FOol20005Ool00`00Oomoo`2D
Ool00`0O001l000?O0000`00O01l000>O0000`00O01l000>O0000`00O01l000:O0001@0OO01l07`0
00009Woo000HOol00`00Oomoo`02Ool00`00Oomoo`2DOol00`0O001l000?O0000`00O01l000>O000
0`00O01l000>O0000`00O01l000:O0001@0OO01l07`000009Woo000EOol30005Ool00`00Oomoo`2C
Ool00`0OOol0000@O0000`00O01l000>O0000`00O01l000>O0000`00O01l000;O000100OO01l0000
9Woo000MOol00`00Oomoo`2COol00`0OOol0000@O0000`00O01l000>O0000`00O01l000>O0000`00
O01l000;O000100OO01l00009Woo000MOol2002COol0100OOomoo`0047`000<007`0O0003W`000<0
07`0O0003W`000<007`0O00037`000<07g`000009Woo000MOol00`00Oomoo`2BOol0100OOomoo`00
47`000<007`0O0003W`000<007`0O0003W`000<007`0O00037`000<07g`000009Woo000MOol00`00
Oomoo`2AOol01@0OOomoogoo000047`000<007`0O0003W`000<007`0O0003W`000<007`0O00037`0
00<07g`000009Woo000MOol00`00Oomoo`2AOol01@0OOomoogoo000047`000<007`0O0003W`000<0
07`0O0003W`000<007`0O0003G`000<07`00Ool09Goo000MOol2002AOol00`0OOomoo`02Ool00`00
O01l000>O0000`00O01l000>O0000`00O01l000>O0000`00O01l000=O0000`0O001oo`0UOol001eo
o`03001oogoo091oo`0301moogoo009oo`03001l07`000il0003001l07`000il0003001l07`000il
0003001l07`000el000301l007oo02Eoo`007Goo00<007ooOol0Sgoo00<07gooOol00goo00<007`0
O0003W`000<007`0O0003W`000<007`0O0003W`000<007`0O0003W`000<07gooOol097oo000MOol0
0`00Oomoo`2?Ool00`0OOomoo`03Ool00`00O01l000>O0000`00O01l000>O0000`00O01l000>O000
0`00O01l000>O0000`0OOomoo`0TOol001eoo`03001oogoo08ioo`0301moogoo00Aoo`03001l07`0
00il0003001l07`000il0003001l07`000il0003001l07`000il000301moogoo02Aoo`007Goo0P00
QWoo2@0000<07`0000001@0047`000<007`0O0003W`000<007`0O0003W`000<007`0O0003W`000<0
000OOol097oo000MOol00`00Oomoo`25Ool00`00O01l0005O0000`0OO01l0005O0000`00O01l000>
O0000`00O01l000>O0000`00O01l000>O0000`00O01l000>O0000`0001moo`0TOol001eoo`03001o
ogoo08Eoo`03001l07`000El000301ml07`000El0003001l07`000il0003001l07`000il0003001l
07`000il0003001l07`000il0003001oo`0O02Aoo`007Goo00<007ooOol0QGoo00<007`0O00017`0
00<07g`0O0001W`000<007`0O0003W`000<007`0O0003W`000<007`0O0003W`000<007`0O0003W`0
00<007oo01l097oo000MOol20026Ool00`00O01l0004O0000`0OO01l0006O0000`00O01l000>O000
0`00O01l000>O0000`00O01l000>O0000`00O01l000>O0000`00Ool07`0TOol001eoo`03001oogoo
08Eoo`03001l07`000=l000301ml07`000Ml0003001l07`000il0003001l07`000il0003001l07`0
00il0003001l07`000il0004001oogoo01lSOol001Eoo`@000Aoo`03001oogoo08Eoo`03001l07`0
00=l000301ml07`000Ml0003001l07`000il0003001l07`000il0003001l07`000il0003001l07`0
00il0004001oogoo01lSOol001Ioo`03001oogoo00Aoo`03001oogoo08Eoo`03001l07`0009l0003
01ml07`000Ql0003001l07`000il0003001l07`000il0003001l07`000il0003001l07`000il0004
001oogoo01lSOol000moo`D000=oo`03001oogoo00=oo`<008Eoo`03001l07`0009l000301ml07`0
00Ql0003001l07`000il0003001l07`000il0003001l07`000il0003001l07`000il0005001oogoo
Ool07`0ROol001Qoo`03001oogoo009oo`03001oogoo08Eoo`05001l07`0O0007`0;O0000`00O01l
000>O0000`00O01l000>O0000`00O01l000>O0000`00O01l000>O0001@00Oomoogoo01l08Woo000E
Ool01000Oomoo`0017oo00<007ooOol0QGoo00D007`0O01l000O00]l0003001l07`000il0003001l
07`000il0003001l07`000il0003001l07`000il0003001oogoo009oo`0301moogoo01moo`005Woo
0P001Goo00<007ooOol0QGoo00@007`0O0007`al0003001l07`000il0003001l07`000il0003001l
07`000il0003001l07`000il0003001oogoo009oo`0301moogoo01moo`007Goo00<007ooOol0QGoo
00@007`0O0007`al0003001l07`000il0003001l07`000il0003001l07`000il0003001l07`000il
0003001oogoo009oo`0301moogoo01moo`007Goo0P00QWoo00<007`001l03G`000<007`0O0003W`0
00<007`0O0003W`000<007`0O0003W`000<007`0O0003W`000<007ooOol00goo00<07gooOol07Woo
000MOol00`00Oomoo`25Ool00`00O0007`0=O0000`00O01l000>O0000`00O01l000>O0000`00O01l
000>O0000`00O01l000>O0000`00Oomoo`03Ool00`0OOomoo`0NOol001eoo`03001oogoo08Eoo`03
00007g`000el0003001l07`000il0003001l07`000il0003001l07`000il0003001l07`000il0003
001oogoo00=oo`0301moogoo01ioo`007Goo00<007ooOol0QGoo00<0000OO0003G`000<007`0O000
3W`000<007`0O0003W`000<007`0O0003W`000<007`0O0003W`000<007ooOol017oo00<07gooOol0
7Goo000MOol20026Ool00`0OO01l000=O0000`00O01l000>O0000`00O01l000>O0000`00O01l000>
O0000`00O01l000>O0000`00Oomoo`04Ool00`0OOomoo`0MOol001eoo`03001oogoo08Eoo`0301ml
07`000el0003001l07`000il0003001l07`000il0003001l07`000il0003001l07`000il0003001o
ogoo00Aoo`0301moogoo01eoo`007Goo00<007ooOol0Q7oo00<07`00O0003W`000<007`0O0003W`0
00<007`0O0003W`000<007`0O0003W`000<007`0O0003W`000<007ooOol01Goo00<07gooOol077oo
000MOol00`00Oomoo`24Ool00`0O001l000>O0000`00O01l000>O0000`00O01l000>O0000`00O01l
000>O0000`00O01l000>O0000`00Oomoo`05Ool00`0OOomoo`0LOol001eoo`03001oogoo08=oo`03
01moo`0000ml0003001l07`000il0003001l07`000il0003001l07`000il0003001l07`000il0003
001oogoo00Eoo`0301moogoo01aoo`007Goo0P00Q7oo00<07goo00003g`000<007`0O0003W`000<0
07`0O0003W`000<007`0O0003W`000<007`0O0003W`000<007ooOol01Woo00<07gooOol06goo000M
Ool00`00Oomoo`23Ool00`0OOol0000?O0000`00O01l000>O0000`00O01l000>O0000`00O01l000>
O0000`00O01l000>O00900000`0O00000006000EOol001eoo`03001oogoo089oo`0401moogoo000?
O0000`00O01l000>O0000`00O01l000>O0000`00O01l000>O0000`00O01l000>O0000`00O01l0006
O0000`0OO01l0005O0000`00Oomoo`0COol001eoo`03001oogoo089oo`0401moogoo000?O0000`00
O01l000>O0000`00O01l000>O0000`00O01l000>O0000`00O01l000>O0000`00O01l0006O0000`0O
O01l0005O0000`00Oomoo`0COol001eoo`80089oo`0501moogooOol0000?O0000`00O01l000>O000
0`00O01l000>O0000`00O01l000>O0000`00O01l000>O0000`00O01l0007O0000`0OO01l0004O000
0`00Oomoo`0COol001eoo`03001oogoo085oo`0501moogooOol0000?O0000`00O01l000>O0000`00
O01l000>O0000`00O01l000>O0000`00O01l000>O0000`00O01l0007O0000`0OO01l0004O0000`00
Oomoo`0COol001Eoo`<000Eoo`03001oogoo081oo`0301moogoo009oo`03001l07`000el0003001l
07`000il0003001l07`000il0003001l07`000il0003001l07`000il0003001l07`000Ml000301ml
07`000Al0003001oogoo01=oo`005Woo00<007ooOol017oo00<007ooOol0P7oo00<07gooOol00Woo
00<007`0O0003G`000<007`0O0003W`000<007`0O0003W`000<007`0O0003W`000<007`0O0003W`0
00<007`0O00027`000<07g`0O0000g`000<007ooOol04goo000?Ool50002Ool00`00Oomoo`04Ool3
001oOol00`0OOomoo`03Ool00`00O01l000=O0000`00O01l000>O0000`00O01l000>O0000`00O01l
000>O0000`00O01l000>O0000`00O01l0008O0000`0OO01l0003O0000`00Oomoo`0COol001Ioo`03
001oogoo00Aoo`03001oogoo07moo`0301moogoo00=oo`03001l07`000el0003001l07`000il0003
001l07`000il0003001l07`000il0003001l07`000il0003001l07`000Ql000301ml07`000=l0003
001oogoo01=oo`005Woo00<007ooOol017oo00<007ooOol0OWoo00<07gooOol017oo00<007`0O000
3G`000<007`0O0003W`000<007`0O0003W`000<007`0O0003W`000<007`0O0003W`000<007`0O000
27`000<07g`0O0000g`000<007ooOol04goo000EOol20006Ool00`00Oomoo`1nOol00`0OOomoo`04
Ool00`00O01l000=O0000`00O01l000>O0000`00O01l000>O0000`00O01l000>O0000`00O01l000>
O0000`00O01l0009O0000`0OO01l0002O0000`00Oomoo`0COol001eoo`03001oogoo07eoo`0301mo
ogoo00Eoo`03001l07`000el0003001l07`000il0003001l07`000il0003001l07`000il0003001l
07`000il0003001l07`000Ul000301ml07`0009l0003001oogoo01=oo`007Goo0P00OWoo00<07goo
Ool01Goo00<007`0O0003G`000<007`0O0003W`000<007`0O0003W`000<007`0O0003W`000<007`0
O0003W`000<007`0O0002G`000<07g`0O0000W`000<007ooOol04goo000MOol00`00Oomoo`1dOol8
00000`0O00000007000?O0000`00O01l000>O0000`00O01l000>O0000`00O01l000>O0000`00O01l
000>O0000`00O01l0009O0000`0OO01l0002O0000`00Oomoo`0COol001eoo`03001oogoo07Aoo`03
001l07`000El000301ml07`000Il0003001l07`000el0003001l07`000il0003001l07`000il0003
001l07`000il0003001l07`000il0003001l07`000Yl000501ml07`0O000000EOol001eoo`03001o
ogoo07Aoo`03001l07`000Al000301ml07`000Ml0003001l07`000el0003001l07`000il0003001l
07`000il0003001l07`000il0003001l07`000il0003001l07`000Yl000501ml07`0O000000EOol0
01eoo`8007Eoo`03001l07`000Al000301ml07`000Ml0003001l07`000el0003001l07`000il0003
001l07`000il0003001l07`000il0003001l07`000il0003001l07`000Yl000501ml07`0O000000E
Ool001eoo`03001oogoo07Aoo`03001l07`000=l000301ml07`000Ql0003001l07`000el0003001l
07`000il0003001l07`000il0003001l07`000il0003001l07`000il0003001l07`000Yl000501ml
07`0O000000EOol001eoo`03001oogoo07Aoo`03001l07`000=l000301ml07`000Ql0003001l07`0
00el0003001l07`000il0003001l07`000il0003001l07`000il0003001l07`000il0003001l07`0
00]l000401ml07`0000EOol001eoo`03001oogoo025oo`<002=oo`@0025oo`<000Eoo`03001l07`0
009l000301ml07`000Ul0003001l07`000el0003001l07`000il0003001l07`000il0003001l07`0
00il0003001l07`000il0003001l07`000]l000401ml07`0000EOol001eoo`03001oogoo029oo`03
001oogoo02=oo`03001oogoo02Aoo`03001oogoo009oo`03001l07`0009l000301ml07`000Ul0003
001l07`000el0003001l07`000il0003001l07`000il0003001l07`000il0003001l07`000il0003
001l07`000]l000401ml07`0000EOol001eoo`8002=oo`03001oogoo02Aoo`03001oogoo02=oo`03
001oogoo009oo`05001l07`0O0007`0<O0000`00O01l000=O0000`00O01l000>O0000`00O01l000>
O0000`00O01l000>O0000`00O01l000>O0000`00O01l000;O000100OO01l00005Goo000MOol00`00
Oomoo`0ROol00`00Oomoo`0UOol00`00Oomoo`0POol20005Ool01@00O01l07`001l037`000<007`0
O0003G`000<007`0O0003W`000<007`0O0003W`000<007`0O0003W`000<007`0O0003W`000<007`0
O00037`000<07g`000005Goo000MOol00`00Oomoo`0ROol00`00Oomoo`0ROol01000Oomoo`0097oo
00<007ooOol00Woo00@007`0O0007`el0003001l07`000el0003001l07`000il0003001l07`000il
0003001l07`000il0003001l07`000il0003001l07`000al000301ml000001Eoo`007Goo00<007oo
Ool08Goo0P009Goo0P008Woo0`001Goo00@007`0O0007`el0003001l07`000el0003001l07`000il
0003001l07`000il0003001l07`000il0003001l07`000il0003001l07`000al000301ml000001Eo
o`007Goo0P00MGoo00<007`001l03W`000<007`0O0003G`000<007`0O0003W`000<007`0O0003W`0
00<007`0O0003W`000<007`0O0003W`000<007`0O0003G`000<07`00Ool057oo000MOol00`00Oomo
o`1dOol00`00O0007`0>O0000`00O01l000=O0000`00O01l000>O0000`00O01l000>O0000`00O01l
000>O0000`00O01l000>O0000`00O01l000=O0000`0O001oo`0DOol001eoo`03001oogoo07Aoo`03
00007g`000il0003001l07`000el0003001l07`000il0003001l07`000il0003001l07`000il0003
001l07`000il0003001l07`000el000301l007oo01Aoo`007Goo00<007ooOol0M7oo00<0000OO000
3W`000<007`0O0003G`000<007`0O0003W`000<007`0O0003W`000<007`0O0003W`000<007`0O000
3W`000<007`0O0003G`000<07`00Ool057oo000MOol00`00Oomoo`1dOol00`0OO01l000>O0000`00
O01l000=O0000`00O01l000>O0000`00O01l000>O0000`00O01l000>O0000`00O01l000>O0000`00
O01l000>O0000`0OOomoo`0COol001Moo`H000X07fd0000301ml07`000il0003001l07`000el0003
001l07`000il0003001l07`000il0003001l07`000il0003001l07`000il0003001l07`000il0003
01l0000000@000moo`007Goo2P000P0O1P0047`000<007`0O0003W`000<007`0O0003W`000<007`0
O0003W`000<007`0O0003W`000<007`0O0003G`000<07`00Ool07Woo00<007ooOol08goo00<007oo
Ool08Woo00<007ooOol07Woo000MOol00`00Oomoo`09Ool301l2Ool00`00O01l000>O0000`00O01l
000>O0000`00O01l000>O0000`00O01l000>O0000`00O01l000>O0000`00O01l000<O0000`0OO000
002;Ool001eoo`03001oogoo00aoo`807`03001l07`000il0003001l07`000il0003001l07`000il
0003001l07`000il0003001l07`000il0003001l07`000al000301ml000008]oo`007Goo0P003goo
0P0O3g`000<007`0O0003W`000<007`0O0003W`000<007`0O0003W`000<007`0O0003W`000<007`0
O0002g`000@07g`0O00008]oo`007Goo00<007ooOol03Woo00<007`001l03W`000<007`0O0003W`0
00<007`0O0003W`000<007`0O0003W`000<007`0O0003W`000<007`0O0002g`000@07g`0O00008]o
o`007Goo00<007ooOol03Woo00<007`0O0000P0O37`000<007`0O0003W`000<007`0O0003W`000<0
07`0O0003W`000<007`0O0003W`000<007`0O0002W`000D07g`0O01l000008]oo`007Goo00<007oo
Ool03Woo00<007`0O0000W`00P0O2W`000<007`0O0003W`000<007`0O0003W`000<007`0O0003W`0
00<007`0O0003W`000<007`0O0002G`000<07g`0O0000W`000<007ooOol0RGoo000MOol2000?Ool0
0`00O01l0004O0000`0OO01l0007O0000`00O01l000>O0000`00O01l000>O0000`00O01l000>O000
0`00O01l000>O0000`00O01l0009O0000`0OO01l0002O0000`00Oomoo`29Ool001eoo`03001oogoo
00ioo`P000807`P0011l0003001l07`000il0003001l07`000il0003001l07`000il0003001l07`0
00Ql000301ml07`000=l0003001oogoo08Uoo`007Goo00<007ooOol067oo0P0O1Goo00<007`0O000
3W`000<007`0O0003W`000<007`0O0003W`000<007`0O0003W`000<007`0O0001g`000<07g`0O000
17`000<007ooOol0RGoo000MOol00`00Oomoo`0JOol00`0OOomoo`02Ool00`00O01l000>O0000`00
O01l000>O0000`00O01l000>O0000`00O01l000>O0000`00O01l0007O0000`0OO01l0004O0000`00
Oomoo`29Ool001eoo`03001oogoo01]oo`807`9oo`03001l07`000il0003001l07`000il0003001l
07`000il0003001l07`000il0003001l07`000Il000301ml07`000El0003001oogoo08Uoo`007Goo
0P007Woo00<07goo000047`000<007`0O0003W`000<007`0O0003W`000<007`0O0003W`000<007`0
O0001W`000<07g`0O0001G`000<007ooOol0RGoo000MOol00`00Oomoo`0NOol00`0O001l000?O000
0`00O01l000>O0000`00O01l000>O0000`00O01l000>O00800000`0O00000007002;Ool001eoo`03
001oogoo01moo`0301ml07`000il0003001l07`000il0003001l07`000il0003001l07`000il0003
001oogoo00Aoo`0301moogoo09=oo`007Goo00<007ooOol07goo00<0000O01l03W`000<007`0O000
3W`000<007`0O0003W`000<007`0O0003W`000<007ooOol017oo00<07gooOol0Tgoo000MOol2000P
Ool01000O01l000O3G`000<007`0O0003W`000<007`0O0003W`000<007`0O0003W`000<007ooOol0
0goo00<07gooOol0U7oo000MOol00`00Oomoo`0OOol01@00O01l07`001l037`000<007`0O0003W`0
00<007`0O0003W`000<007`0O0003W`000<007ooOol00Woo00<07gooOol0UGoo000MOol00`00Oomo
o`0OOol00`00O01l0002O0000`0OO01l0009O0000`00O01l000>O0000`00O01l000>O0000`00O01l
000>O0001@00Oomoogoo01l0V7oo000EOol30005Ool00`00Oomoo`0OOol00`00O01l0003O00201l9
O0000`00O01l000>O0000`00O01l000>O0000`00O01l000>O0001@00Oomoogoo01l0V7oo000FOol0
0`00Oomoo`04Ool00`00Oomoo`0OOol00`00O01l0005O0000`0OO01l0006O0000`00O01l000>O000
0`00O01l000>O0000`00O01l000>O0001000Oomoo`0OVGoo000FOol00`00Oomoo`04Ool3000OOol9
00000`0O00000006000@O0000`00O01l000>O0000`00O01l000>O0000`00Ool07`2JOol001Ioo`03
001oogoo00Aoo`03001oogoo02Uoo`0301moogoo00Aoo`03001l07`000il0003001l07`000il0003
001l07`000il000300007goo09Yoo`005Woo00<007ooOol017oo00<007ooOol0:Woo0P0O17oo00<0
07`0O0003W`000<007`0O0003W`000<007`0O0003W`000<07gooOol0VWoo000EOol20006Ool00`00
Oomoo`0/Ool01@0OOomoogoo000047`000<007`0O0003W`000<007`0O0003W`000<07gooOol0VWoo
000MOol2000^Ool0100OOomoo`0047`000<007`0O0003W`000<007`0O0003G`000<07`00Ool0Vgoo
000MOol00`00Oomoo`0^Ool00`0OOol0000@O0000`00O01l000>O0000`00O01l000<O0000`0OO000
002LOol001eoo`03001oogoo02moo`807a1l0003001l07`000il0003001l07`000]l000401ml07`0
002LOol001eoo`03001oogoo031oo`0300007g`000il0003001l07`000il0003001l07`000Yl0005
01ml07`0O000002LOol001eoo`80035oo`04001l000O01l=O0000`00O01l000>O0000`00O01l0009
O0000`0OO01l0002O0000`00Oomoo`2JOol001eoo`03001oogoo031oo`05001l07`0O0007`0<O000
0`00O01l000>O0000`00O01l0008O0000`0OO01l0003O0000`00Oomoo`2JOol001eoo`03001oogoo
031oo`03001l07`0009l00807`Yl0003001l07`000il0003001l07`000Il00807`Il0003001oogoo
09Yoo`007Goo00<007ooOol0<7oo00<007`0O00017`000<07g`0O0001g`000<007`0O0003W`000<0
07`0O0001G`000<07g`0O0001W`000<007ooOol0VWoo000MOol00`00Oomoo`0`Ool8000201l8000@
O00700000`0O00000008002LOol001eoo`8003]oo`0301moogoo00Aoo`03001l07`000il0003001o
ogoo00=oo`0301moogoo0:Eoo`007Goo00<007ooOol0>goo0`0O0goo00<007`0O0003W`000@007oo
Oomoo`807jQoo`007Goo00<007ooOol0?Woo0P0O00=oo`00O0003g`000@0000O01l07jYoo`007Goo
00<007ooOol0@7oo0`0O3W`00P0O[Goo000MOol20012Ool00`00O0007`0301l6O00401l00g`0001o
o`2/Ool001eoo`03001oogoo045oo`H000H07`H00:eoo`007Goo00<007ooOol0ogoo0Goo000MOol0
0`00Oomoo`3oOol1Ool001eoo`03001oogoo0?moo`5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol003Qoo`H000Ioo`<000=oo`@000Ao
o`<000Eoo`<000=oo`@00003Ool000000080009oo`8000Eoo`X00003Ool000000080009oo`@000Ao
o`@000=oo`@001Qoo`@000Aoo`8000Aoo`@000=oo`D000Moo`03001oogoo00Aoo`H000Moo`80009o
o`L0039oo`00>Woo0P001goo0P000Woo00@007ooOomoo`8000Aoo`80009oo`04001oogooOol20002
Ool01000Oomoogoo0P000goo0P000Woo0P0000=oo`00Ool01Goo0P001Goo0P0000=oo`00000017oo
0P0017oo0P000Woo0P000goo0P0067oo0P000Woo0P000goo0P000goo0P000Woo0P000Woo0P000goo
0P001Goo0P001goo0P002Goo0P000goo1P00<Woo000jOol20006Ool20004Ool00`00Oomoo`020003
Ool20004Ool01000Ool0000017oo00<007ooOol00P000goo0P000Woo0P0027oo0P001Woo00@007oo
000000Aoo`8000=oo`8000Aoo`80009oo`8000Qoo`T000Moo`03001oogoo009oo`03001oogoo00Eo
o`8000Aoo`8000Moo`03001oogoo00Aoo`03001oogoo00Eoo`8000Uoo`8000Aoo`03001oogoo009o
o`03001oogoo02moo`00>Woo0P001Woo0P001goo0P000goo0P001Woo0P001goo0P000goo0P000Woo
0P0027oo0P0027oo0P0017oo0P000goo0P0017oo0P000Woo0P005goo0P0017oo0P001Woo0P0017oo
0P001goo0P001Goo00<007ooOol01Goo0P0017oo2@000Woo0P00=Goo000jOol20006Ool20007Ool2
0003Ool20006Ool20007Ool20003Ool20002Ool20008Ool20004Ool01000Oomoogoo0P0017oo0P00
0goo0P0017oo0P000Woo0P005goo0P0017oo0P001Woo0P000goo0`001goo0P001Goo00<007ooOol0
1Goo0P0017oo00<007ooOol00Woo0P001Goo00<007ooOol0<goo000jOol60002Ool70002Ool20003
Ool20004Ool00`00Ool000060002Ool20003Ool20002Ool20008Ool20004Ool01000Oomoogoo0P00
17oo0P000goo0P0017oo0P000Woo0P005goo0P0017oo0P001goo0P0000Aoo`00000000Qoo`8000Io
o`03001oogoo00Aoo`8000Eoo`04001oogooOol20006Ool00`00Oomoo`0bOol003Yoo`8000=oo`80
009oo`04001oogooOol200000goo0000000400000goo00000002Ool20002Ool01000Oomoogoo0P00
00=oo`0000000P000Woo0P000Woo0P0027oo1`000Woo300000=oo`0000000Woo0P000Woo1P001Goo
2@001Woo0P0017oo0P0027oo100027oo0`001Woo00<007ooOol017oo0P001Woo00<007ooOol00P00
1Woo0P00<goo000jOol20004Ool20002Ool40004Ool01000Ool000000Woo100017oo100017oo00<0
07oo00000P000Woo1@001Woo0P0017oo00<007ooOol00Woo00@007oo0000009oo`04001oo`000002
Ool40005Ool01000Ool0000057oo0P0017oo0P001goo1@001Goo1@001goo00<007ooOol017oo0P00
1Woo00<007ooOol00P001goo00<007ooOol0<Goo000jOol20004Ool2000XOol20008Ool20004Ool0
0`00Oomoo`0_Ool20004Ool20007Ool20002Ool20006Ool00`00Oomoo`08Ool00`00Oomoo`03Ool2
0007Ool01000Ool000001goo0P00<Woo000jOol20004Ool2000YOol00`00Oomoo`06Ool2000fOol2
0004Ool20006Ool20004Ool20006Ool00`00Oomoo`07Ool00`00Oomoo`03Ool20008Ool30002Ool0
0`00Oomoo`02Ool2000bOol003Yoo`8000Aoo`80039oo`8000Eoo`03001oogoo02moo`03001oogoo
009oo`03001oogoo00Eoo`8000Aoo`800003Ool007oo00=oo`80009oo`8000Aoo`03001oogoo00=o
o`8000Qoo`<0009oo`80009oo`<0039oo`00>Woo0P000goo0P00<goo0P001Goo00<007ooOol0;goo
0P000Woo0P0027oo0P000Woo0P000goo00<007ooOol00`000goo1`000Woo10002Goo0P000goo1@00
<goo000hOol8000bOol:000bOol4000:Ool40005Ool40004Ool70004Ool20009Ool20004Ool3000d
Ool00?moob5oo`00ogoo8Goo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.783823, -4.98036, 
  0.0265065, 0.0452841}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.151576 0.44187 0.0887232 [
[.17539 .42937 -3 -9 ]
[.17539 .42937 3 0 ]
[.32696 .42937 -3 -9 ]
[.32696 .42937 3 0 ]
[.47854 .42937 -3 -9 ]
[.47854 .42937 3 0 ]
[.63011 .42937 -3 -9 ]
[.63011 .42937 3 0 ]
[.78169 .42937 -3 -9 ]
[.78169 .42937 3 0 ]
[.93327 .42937 -3 -9 ]
[.93327 .42937 3 0 ]
[.01131 .08698 -12 -4.5 ]
[.01131 .08698 0 4.5 ]
[.01131 .1757 -12 -4.5 ]
[.01131 .1757 0 4.5 ]
[.01131 .26442 -12 -4.5 ]
[.01131 .26442 0 4.5 ]
[.01131 .35315 -12 -4.5 ]
[.01131 .35315 0 4.5 ]
[.01131 .53059 -6 -4.5 ]
[.01131 .53059 0 4.5 ]
[.5 .63053 -89.5938 0 ]
[.5 .63053 89.5938 20 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.17539 .44187 m
.17539 .44812 L
s
[(1)] .17539 .42937 0 1 Mshowa
.32696 .44187 m
.32696 .44812 L
s
[(2)] .32696 .42937 0 1 Mshowa
.47854 .44187 m
.47854 .44812 L
s
[(3)] .47854 .42937 0 1 Mshowa
.63011 .44187 m
.63011 .44812 L
s
[(4)] .63011 .42937 0 1 Mshowa
.78169 .44187 m
.78169 .44812 L
s
[(5)] .78169 .42937 0 1 Mshowa
.93327 .44187 m
.93327 .44812 L
s
[(6)] .93327 .42937 0 1 Mshowa
.125 Mabswid
.05412 .44187 m
.05412 .44562 L
s
.08444 .44187 m
.08444 .44562 L
s
.11476 .44187 m
.11476 .44562 L
s
.14507 .44187 m
.14507 .44562 L
s
.2057 .44187 m
.2057 .44562 L
s
.23602 .44187 m
.23602 .44562 L
s
.26633 .44187 m
.26633 .44562 L
s
.29665 .44187 m
.29665 .44562 L
s
.35728 .44187 m
.35728 .44562 L
s
.38759 .44187 m
.38759 .44562 L
s
.41791 .44187 m
.41791 .44562 L
s
.44822 .44187 m
.44822 .44562 L
s
.50885 .44187 m
.50885 .44562 L
s
.53917 .44187 m
.53917 .44562 L
s
.56948 .44187 m
.56948 .44562 L
s
.5998 .44187 m
.5998 .44562 L
s
.66043 .44187 m
.66043 .44562 L
s
.69074 .44187 m
.69074 .44562 L
s
.72106 .44187 m
.72106 .44562 L
s
.75137 .44187 m
.75137 .44562 L
s
.81201 .44187 m
.81201 .44562 L
s
.84232 .44187 m
.84232 .44562 L
s
.87264 .44187 m
.87264 .44562 L
s
.90295 .44187 m
.90295 .44562 L
s
.96358 .44187 m
.96358 .44562 L
s
.9939 .44187 m
.9939 .44562 L
s
.25 Mabswid
0 .44187 m
1 .44187 L
s
.02381 .08698 m
.03006 .08698 L
s
[(-4)] .01131 .08698 1 0 Mshowa
.02381 .1757 m
.03006 .1757 L
s
[(-3)] .01131 .1757 1 0 Mshowa
.02381 .26442 m
.03006 .26442 L
s
[(-2)] .01131 .26442 1 0 Mshowa
.02381 .35315 m
.03006 .35315 L
s
[(-1)] .01131 .35315 1 0 Mshowa
.02381 .53059 m
.03006 .53059 L
s
[(1)] .01131 .53059 1 0 Mshowa
.125 Mabswid
.02381 .016 m
.02756 .016 L
s
.02381 .03374 m
.02756 .03374 L
s
.02381 .05149 m
.02756 .05149 L
s
.02381 .06923 m
.02756 .06923 L
s
.02381 .10472 m
.02756 .10472 L
s
.02381 .12247 m
.02756 .12247 L
s
.02381 .14021 m
.02756 .14021 L
s
.02381 .15796 m
.02756 .15796 L
s
.02381 .19344 m
.02756 .19344 L
s
.02381 .21119 m
.02756 .21119 L
s
.02381 .22893 m
.02756 .22893 L
s
.02381 .24668 m
.02756 .24668 L
s
.02381 .28217 m
.02756 .28217 L
s
.02381 .29991 m
.02756 .29991 L
s
.02381 .31766 m
.02756 .31766 L
s
.02381 .3354 m
.02756 .3354 L
s
.02381 .37089 m
.02756 .37089 L
s
.02381 .38864 m
.02756 .38864 L
s
.02381 .40638 m
.02756 .40638 L
s
.02381 .42413 m
.02756 .42413 L
s
.02381 .45961 m
.02756 .45961 L
s
.02381 .47736 m
.02756 .47736 L
s
.02381 .4951 m
.02756 .4951 L
s
.02381 .51285 m
.02756 .51285 L
s
.02381 .54834 m
.02756 .54834 L
s
.02381 .56608 m
.02756 .56608 L
s
.02381 .58383 m
.02756 .58383 L
s
.02381 .60157 m
.02756 .60157 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -150.594 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 24.000000 moveto
 558.000000 24.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 24.000000 lineto
closepath
clip newpath
63.000000 19.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 18.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 19.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 18.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Percent) show
121.250000 19.000000 moveto
(Error) show
163.625000 19.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 18.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(=) show
179.687500 19.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 18.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.72948) show
238.187500 19.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 18.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
0 0 1 r
.007 w
.02381 .44187 m
.02499 .44188 L
.02605 .44189 L
.02729 .44192 L
.02846 .44195 L
.03053 .44204 L
.03279 .44218 L
.03527 .44238 L
.0379 .44264 L
.04262 .44323 L
.04749 .44403 L
.05205 .44493 L
.06244 .44757 L
.07305 .45107 L
.08274 .45495 L
.10458 .46589 L
.14429 .4922 L
.18248 .52229 L
.22313 .55474 L
.26226 .58144 L
.27254 .5871 L
.28367 .59241 L
.29328 .59624 L
.29838 .59795 L
.30384 .59955 L
.30923 .60086 L
.31415 .60182 L
.31652 .6022 L
.31909 .60255 L
.32151 .60282 L
.32378 .60303 L
.32509 .60312 L
.3263 .60319 L
.32764 .60325 L
.32834 .60327 L
.32908 .60329 L
.32976 .60331 L
.33048 .60332 L
.33177 .60332 L
.33257 .60331 L
.33332 .6033 L
.33399 .60328 L
.33472 .60326 L
.33594 .60321 L
.33728 .60313 L
.33999 .60292 L
.34249 .60266 L
.34484 .60235 L
.34982 .60149 L
.35525 .60023 L
Mistroke
.36513 .59709 L
.37475 .59294 L
.38367 .58812 L
.40423 .57339 L
.42285 .55569 L
.46297 .50405 L
.50157 .43897 L
.54262 .35759 L
.58216 .27326 L
.62019 .19318 L
.66067 .11668 L
.69963 .05896 L
.70983 .04728 L
.72091 .03645 L
.73048 .02875 L
.73557 .02531 L
.74104 .02213 L
.74638 .01956 L
.75126 .01767 L
.75594 .01629 L
.75829 .01576 L
.76085 .0153 L
.76227 .01511 L
.76362 .01496 L
.76482 .01485 L
.76612 .01477 L
.7668 .01474 L
.76755 .01472 L
.76833 .01472 L
.76905 .01472 L
.77035 .01475 L
.77108 .01478 L
.77175 .01482 L
.77304 .01492 L
.77424 .01504 L
.77695 .01543 L
.77933 .0159 L
.78187 .01653 L
.78675 .0181 L
.79123 .01999 L
.80132 .02578 L
.81022 .03269 L
.81959 .04179 L
.83931 .06705 L
.85767 .09794 L
.89668 .18599 L
.93815 .30895 L
.97619 .44187 L
Mfstroke
1 0 0 r
.02381 .44187 m
.0873 .44187 L
.0873 .44573 L
.02381 .44573 L
F
.0873 .44187 m
.15079 .44187 L
.15079 .47464 L
.0873 .47464 L
F
.15079 .44187 m
.21429 .44187 L
.21429 .52233 L
.15079 .52233 L
F
.21429 .44187 m
.27778 .44187 L
.27778 .57123 L
.21429 .57123 L
F
.27778 .44187 m
.34127 .44187 L
.34127 .60092 L
.27778 .60092 L
F
.34127 .44187 m
.40476 .44187 L
.40476 .59377 L
.34127 .59377 L
F
.40476 .44187 m
.46825 .44187 L
.46825 .54012 L
.40476 .54012 L
F
.46825 .44187 m
.53175 .44187 L
.53175 .44187 L
.46825 .44187 L
F
.53175 .44187 m
.59524 .44187 L
.59524 .31338 L
.53175 .31338 L
F
.59524 .44187 m
.65873 .44187 L
.65873 .17949 L
.59524 .17949 L
F
.65873 .44187 m
.72222 .44187 L
.72222 .07074 L
.65873 .07074 L
F
.72222 .44187 m
.78571 .44187 L
.78571 .01682 L
.72222 .01682 L
F
.78571 .44187 m
.84921 .44187 L
.84921 .03955 L
.78571 .03955 L
F
.84921 .44187 m
.9127 .44187 L
.9127 .14697 L
.84921 .14697 L
F
.9127 .44187 m
.97619 .44187 L
.97619 .32983 L
.9127 .32983 L
F
0 g
.5 Mabswid
.02381 .44187 m
.02381 .44573 L
s
.0873 .44187 m
.0873 .44573 L
s
.02381 .44573 m
.0873 .44573 L
s
.0873 .44187 m
.0873 .47464 L
s
.15079 .44187 m
.15079 .47464 L
s
.0873 .47464 m
.15079 .47464 L
s
.15079 .44187 m
.15079 .52233 L
s
.21429 .44187 m
.21429 .52233 L
s
.15079 .52233 m
.21429 .52233 L
s
.21429 .44187 m
.21429 .57123 L
s
.27778 .44187 m
.27778 .57123 L
s
.21429 .57123 m
.27778 .57123 L
s
.27778 .44187 m
.27778 .60092 L
s
.34127 .44187 m
.34127 .60092 L
s
.27778 .60092 m
.34127 .60092 L
s
.34127 .44187 m
.34127 .59377 L
s
.40476 .44187 m
.40476 .59377 L
s
.34127 .59377 m
.40476 .59377 L
s
.40476 .44187 m
.40476 .54012 L
s
.46825 .44187 m
.46825 .54012 L
s
.40476 .54012 m
.46825 .54012 L
s
.46825 .44187 m
.46825 .44187 L
s
.53175 .44187 m
.53175 .44187 L
s
.46825 .44187 m
.53175 .44187 L
s
.53175 .44187 m
.53175 .31338 L
s
.59524 .44187 m
.59524 .31338 L
s
.53175 .31338 m
.59524 .31338 L
s
.59524 .44187 m
.59524 .17949 L
s
.65873 .44187 m
.65873 .17949 L
s
.59524 .17949 m
.65873 .17949 L
s
.65873 .44187 m
.65873 .07074 L
s
.72222 .44187 m
.72222 .07074 L
s
.65873 .07074 m
.72222 .07074 L
s
.72222 .44187 m
.72222 .01682 L
s
.78571 .44187 m
.78571 .01682 L
s
.72222 .01682 m
.78571 .01682 L
s
.78571 .44187 m
.78571 .03955 L
s
.84921 .44187 m
.84921 .03955 L
s
.78571 .03955 m
.84921 .03955 L
s
.84921 .44187 m
.84921 .14697 L
s
.9127 .44187 m
.9127 .14697 L
s
.84921 .14697 m
.9127 .14697 L
s
.9127 .44187 m
.9127 .32983 L
s
.97619 .44187 m
.97619 .32983 L
s
.9127 .32983 m
.97619 .32983 L
s
0 0 1 r
.007 w
.02381 .44187 m
.02499 .44188 L
.02605 .44189 L
.02729 .44192 L
.02846 .44195 L
.03053 .44204 L
.03279 .44218 L
.03527 .44238 L
.0379 .44264 L
.04262 .44323 L
.04749 .44403 L
.05205 .44493 L
.06244 .44757 L
.07305 .45107 L
.08274 .45495 L
.10458 .46589 L
.14429 .4922 L
.18248 .52229 L
.22313 .55474 L
.26226 .58144 L
.27254 .5871 L
.28367 .59241 L
.29328 .59624 L
.29838 .59795 L
.30384 .59955 L
.30923 .60086 L
.31415 .60182 L
.31652 .6022 L
.31909 .60255 L
.32151 .60282 L
.32378 .60303 L
.32509 .60312 L
.3263 .60319 L
.32764 .60325 L
.32834 .60327 L
.32908 .60329 L
.32976 .60331 L
.33048 .60332 L
.33177 .60332 L
.33257 .60331 L
.33332 .6033 L
.33399 .60328 L
.33472 .60326 L
.33594 .60321 L
.33728 .60313 L
.33999 .60292 L
.34249 .60266 L
.34484 .60235 L
.34982 .60149 L
.35525 .60023 L
Mistroke
.36513 .59709 L
.37475 .59294 L
.38367 .58812 L
.40423 .57339 L
.42285 .55569 L
.46297 .50405 L
.50157 .43897 L
.54262 .35759 L
.58216 .27326 L
.62019 .19318 L
.66067 .11668 L
.69963 .05896 L
.70983 .04728 L
.72091 .03645 L
.73048 .02875 L
.73557 .02531 L
.74104 .02213 L
.74638 .01956 L
.75126 .01767 L
.75594 .01629 L
.75829 .01576 L
.76085 .0153 L
.76227 .01511 L
.76362 .01496 L
.76482 .01485 L
.76612 .01477 L
.7668 .01474 L
.76755 .01472 L
.76833 .01472 L
.76905 .01472 L
.77035 .01475 L
.77108 .01478 L
.77175 .01482 L
.77304 .01492 L
.77424 .01504 L
.77695 .01543 L
.77933 .0159 L
.78187 .01653 L
.78675 .0181 L
.79123 .01999 L
.80132 .02578 L
.81022 .03269 L
.81959 .04179 L
.83931 .06705 L
.85767 .09794 L
.89668 .18599 L
.93815 .30895 L
.97619 .44187 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00O7Goo00<007ooOol0
ogoo0Goo000MOol00`00Oomoo`3oOol1Ool001eoo`03001oogoo0?moo`5oo`007Goo00<007ooOol0
]7oo1P0OAWoo000MOol2002/Ool6000301l5000301m4Ool001eoo`03001oogoo0:]oo`04001l07`0
O00201l:O000100001l07`0O@Goo000MOol00`00Oomoo`2[Ool01000O01l000O37`000D007ooOomo
o`0O041oo`007Goo00<007ooOol0Zgoo00<007`001l03G`000<007ooOol00Woo00<07gooOol0?Goo
000MOol2002/Ool00`0001ml000=O0000`00Oomoo`03Ool00`0OOomoo`0lOol001eoo`03001oogoo
0:Yoo`807`ml00L0000301l0000000L003Aoo`007Goo00<007ooOol0ZGoo00<07goo00003g`000<0
07`0O0001G`000<07g`0O0001G`000<007ooOol0<Woo000MOol00`00Oomoo`2XOol0100OOomoo`00
3g`000<007`0O0001G`000<07g`0O0001G`000<007ooOol0<Woo000MOol2002XOol01@0OOomoogoo
00003g`000<007`0O0001W`000<07g`0O00017`000<007ooOol0<Woo000MOol00`00Oomoo`2VOol0
0`0OOomoo`02Ool00`00O01l000=O0000`00O01l0007O0000`0OO01l0003O0000`00Oomoo`0bOol0
01eoo`03001oogoo0:Eoo`0301moogoo00=oo`03001l07`000el0003001l07`000Ql000301ml07`0
009l0003001oogoo039oo`007Goo00<007ooOol0YGoo00<07gooOol00goo00<007`0O0003G`000<0
07`0O0002G`000D07g`0O01l000003Aoo`007Goo00<007ooOol0Y7oo00<07gooOol017oo00<007`0
O0003G`000<007`0O0002W`000@07g`0O00003Aoo`007Goo0P00W7oo200000<07`0000001P003g`0
00<007`0O0002W`000@07g`0O00003Aoo`007Goo00<007ooOol0Vgoo00<007`0O0001G`000<07g`0
O0001G`000<007`0O0003G`000<007`0O0002g`000<07g`00000=7oo000FOol30004Ool00`00Oomo
o`2KOol00`00O01l0004O0000`0OO01l0006O0000`00O01l000=O0000`00O01l000<O0000`0O001o
o`0cOol001Moo`03001oogoo00=oo`03001oogoo09]oo`03001l07`000Al000301ml07`000Il0003
001l07`000el0003001l07`000al000301l007oo03=oo`003goo1@0000=oo`0000000P0017oo0`00
Vgoo00<007`0O0000g`000<07g`0O0001g`000<007`0O0003G`000<007`0O0003G`000<07gooOol0
<Woo000EOol00`00Ool00005Ool00`00Oomoo`2KOol00`00O01l0002O0000`0OO01l0008O0000`00
O01l000=O0000`00O01l000=O0000`0OOomoo`0bOol001Eoo`03001oo`0000Eoo`03001oogoo09]o
o`03001l07`0009l000301ml07`000Ql0003001l07`000el0003001l07`000el000300007goo039o
o`005Woo0P001Goo00<007ooOol0Vgoo00D007`0O01l000O00]l0003001l07`000el0003001l07`0
00el0003001oo`0O039oo`007Goo00<007ooOol0Vgoo00D007`0O01l000O00]l0003001l07`000el
0003001l07`000el0003001oo`0O039oo`007Goo0P00W7oo00@007`0O0007`al0003001l07`000el
0003001l07`000el0004001oogoo01laOol001eoo`03001oogoo09]oo`03001l000O00el0003001l
07`000el0003001l07`000el0004001oogoo01laOol001eoo`03001oogoo09]oo`03001l000O00el
0003001l07`000el0003001l07`000el0004001oogoo01laOol001eoo`03001oogoo09]oo`030000
7g`000el0003001l07`000el0003001l07`000el0005001oogooOol07`0`Ool001eoo`8009aoo`03
00007g`000el0003001l07`000el0003001l07`000el0005001oogooOol07`0`Ool001eoo`03001o
ogoo09]oo`0301ml07`000el0003001l07`000el0003001l07`000el0003001oogoo009oo`0301mo
ogoo02eoo`007Goo00<007ooOol0Vgoo00<07g`0O0003G`000<007`0O0003G`000<007`0O0003G`0
00<007ooOol00Woo00<07gooOol0;Goo000MOol00`00Oomoo`2JOol00`0O001l000>O0000`00O01l
000=O0000`00O01l000=O0000`00Oomoo`02Ool00`0OOomoo`0]Ool001eoo`8009]oo`0301l007`0
00il0003001l07`000el0003001l07`000el0003001oogoo00=oo`0301moogoo02aoo`007Goo00<0
07ooOol0VGoo00<07goo00003g`000<007`0O0003G`000<007`0O0003G`000<007ooOol00goo00<0
7gooOol0;7oo000MOol00`00Oomoo`2IOol00`0OOol0000?O0000`00O01l000=O0000`00O01l000=
O00700000`0O00000006000UOol001eoo`03001oogoo09Qoo`0401moogoo000?O0000`00O01l000=
O0000`00O01l000=O0000`00O01l0004O0000`0OO01l0005O0000`00Oomoo`0SOol001eoo`03001o
ogoo09Qoo`0401moogoo000?O0000`00O01l000=O0000`00O01l000=O0000`00O01l0005O0000`0O
O01l0004O0000`00Oomoo`0SOol001eoo`8009Qoo`0501moogooOol0000?O0000`00O01l000=O000
0`00O01l000=O0000`00O01l0005O0000`0OO01l0004O0000`00Oomoo`0SOol001eoo`03001oogoo
09Ioo`0301moogoo009oo`03001l07`000el0003001l07`000el0003001l07`000el0003001l07`0
00El000301ml07`000Al0003001oogoo02=oo`005Goo0`001Goo00<007ooOol0UWoo00<07gooOol0
0Woo00<007`0O0003G`000<007`0O0003G`000<007`0O0003G`000<007`0O0001W`000<07g`0O000
0g`000<007ooOol08goo000HOol00`00Oomoo`02Ool00`00Oomoo`2EOol00`0OOomoo`03Ool00`00
O01l000=O0000`00O01l000=O0000`00O01l000=O0000`00O01l0006O0000`0OO01l0003O0000`00
Oomoo`0SOol000moo`D000Aoo`03001oogoo009oo`<009Eoo`0301moogoo00=oo`03001l07`000el
0003001l07`000el0003001l07`000el0003001l07`000Ml000301ml07`0009l0003001oogoo02=o
o`005Woo0P001Goo00<007ooOol0Rgoo2@0000<07`0000001@003g`000<007`0O0003G`000<007`0
O0003G`000<007`0O0001g`000<07g`0O0000W`000<007ooOol08goo000HOol00`00Oomoo`02Ool0
0`00Oomoo`2;Ool00`00O01l0006O0000`0OO01l0004O0000`00O01l000=O0000`00O01l000=O000
0`00O01l000=O0000`00O01l0007O0000`0OO01l0002O0000`00Oomoo`0SOol001Eoo`<000Eoo`03
001oogoo08]oo`03001l07`000El000301ml07`000El0003001l07`000el0003001l07`000el0003
001l07`000el0003001l07`000Ql000501ml07`0O000000UOol001eoo`03001oogoo08]oo`03001l
07`000El000301ml07`000El0003001l07`000el0003001l07`000el0003001l07`000el0003001l
07`000Ql000501ml07`0O000000UOol001eoo`8008aoo`03001l07`000Al000301ml07`000Il0003
001l07`000el0003001l07`000el0003001l07`000el0003001l07`000Ul000401ml07`0000UOol0
01eoo`03001oogoo08]oo`03001l07`000Al000301ml07`000Il0003001l07`000el0003001l07`0
00el0003001l07`000el0003001l07`000Ul000401ml07`0000UOol001eoo`03001oogoo08]oo`03
001l07`000=l000301ml07`000Ml0003001l07`000el0003001l07`000el0003001l07`000el0003
001l07`000Ul000401ml07`0000UOol001eoo`03001oogoo08]oo`03001l07`000=l000301ml07`0
00Ml0003001l07`000el0003001l07`000el0003001l07`000el0003001l07`000Yl000301ml0000
02Eoo`007Goo0P00S7oo00<007`0O0000W`000<07g`0O00027`000<007`0O0003G`000<007`0O000
3G`000<007`0O0003G`000<007`0O0002W`000<07g`000009Goo000MOol00`00Oomoo`2;Ool00`00
O01l0002O0000`0OO01l0008O0000`00O01l000=O0000`00O01l000=O0000`00O01l000=O0000`00
O01l000:O0000`0OO000000UOol001eoo`03001oogoo08]oo`05001l07`0O0007`0;O0000`00O01l
000=O0000`00O01l000=O0000`00O01l000=O0000`00O01l000;O0000`0O001oo`0TOol001eoo`03
001oogoo08]oo`05001l07`0O0007`0;O0000`00O01l000=O0000`00O01l000=O0000`00O01l000=
O0000`00O01l000;O0000`0O001oo`0TOol001eoo`03001oogoo08]oo`04001l07`001l<O0000`00
O01l000=O0000`00O01l000=O0000`00O01l000=O0000`00O01l000;O0000`0O001oo`0TOol001eo
o`8008aoo`04001l07`001l<O0000`00O01l000=O0000`00O01l000=O0000`00O01l000=O0000`00
O01l000<O0000`0OOomoo`0SOol001eoo`03001oogoo08]oo`03001l000O00el0003001l07`000el
0003001l07`000el0003001l07`000el0003001l07`000al000301moogoo02=oo`007Goo00<007oo
Ool0Rgoo00<007`001l03G`000<007`0O0003G`000<007`0O0003G`000<007`0O0003G`000<007`0
O00037`000<0000OOol08goo000MOol00`00Oomoo`2;Ool00`0001ml000=O0000`00O01l000=O000
0`00O01l000=O0000`00O01l000=O0000`00O01l000<O0000`0001moo`0SOol001eoo`8008aoo`03
00007g`000el0003001l07`000el0003001l07`000el0003001l07`000el0003001l07`000al0003
00007goo02=oo`007Goo00<007ooOol0Rgoo00<07g`0O0003G`000<007`0O0003G`000<007`0O000
3G`000<007`0O0003G`000<007`0O00037`000<007oo01l08goo000EOol40004Ool00`00Oomoo`2;
Ool00`0OO01l000=O0000`00O01l000=O0000`00O01l000=O0000`00O01l000=O0000`00O01l000<
O0000`00Ool07`0SOol001Ioo`03001oogoo00Aoo`03001oogoo08Yoo`0301l007`000il0003001l
07`000el0003001l07`000el0003001l07`000el0003001l07`000al0003001oo`0O02=oo`003goo
1@000goo00<007ooOol00goo0`00RWoo00<07`00O0003W`000<007`0O0003G`000<007`0O0003G`0
00<007`0O0003G`000<007`0O00037`000@007ooOol07b9oo`0067oo00<007ooOol00Woo00<007oo
Ool0RGoo00<07goo00003g`000<007`0O0003G`000<007`0O0003G`000<007`0O0003G`000<007`0
O00037`000@007ooOol07b9oo`005Goo00@007ooOol000Aoo`03001oogoo08Uoo`0301moo`0000ml
0003001l07`000el0003001l07`000el0003001l07`000el0003001l07`000al0005001oogooOol0
7`0QOol001Ioo`8000Eoo`03001oogoo08Qoo`0401moogoo000?O0000`00O01l000=O0000`00O01l
000=O0000`00O01l000=O0000`00O01l000<O0001@00Oomoogoo01l08Goo000MOol00`00Oomoo`28
Ool0100OOomoo`003g`000<007`0O0003G`000<007`0O0003G`000<007`0O0003G`000<007`0O000
37`000D007ooOomoo`0O025oo`007Goo0P00R7oo00D07gooOomoo`0000ml0003001l07`000el0003
001l07`000el0003001l07`000el0003001l07`000al0003001oogoo009oo`0301moogoo01ioo`00
7Goo00<007ooOol0Qgoo00D07gooOomoo`0000ml0003001l07`000el0003001l07`000el0003001l
07`000el0003001l07`000al0003001oogoo009oo`0301moogoo01ioo`007Goo00<007ooOol0QWoo
00<07gooOol00Woo00<007`0O0003G`000<007`0O0003G`000<007`0O0003G`000<007`0O0003G`0
00<007`0O00037`000<007ooOol00Woo00<07gooOol07Woo000MOol00`00Oomoo`26Ool00`0OOomo
o`02Ool00`00O01l000=O0000`00O01l000=O0000`00O01l000=O0000`00O01l000=O0000`00O01l
000<O0000`00Oomoo`03Ool00`0OOomoo`0MOol001eoo`8008Ioo`0301moogoo00=oo`03001l07`0
00el0003001l07`000el0003001l07`000el0003001l07`000el0003001l07`000al0003001oogoo
00=oo`0301moogoo01eoo`007Goo00<007ooOol0QGoo00<07gooOol00goo00<007`0O0003G`000<0
07`0O0003G`000<007`0O0003G`000<007`0O0003G`000<007`0O00037`000<007ooOol00goo00<0
7gooOol07Goo000MOol00`00Oomoo`24Ool00`0OOomoo`04Ool00`00O01l000=O0000`00O01l000=
O0000`00O01l000=O0000`00O01l000=O0000`00O01l000<O0000`00Oomoo`04Ool00`0OOomoo`0L
Ool001eoo`03001oogoo08Aoo`0301moogoo00Aoo`03001l07`000el0003001l07`000el0003001l
07`000el0003001l07`000el0003001l07`000al0003001oogoo00Aoo`0301moogoo01aoo`007Goo
00<007ooOol0Ngoo200000<07`0000001P003g`000<007`0O0003G`000<007`0O0003G`000<007`0
O0003G`000<007`0O00037`000<007ooOol017oo00<07gooOol077oo000MOol2001lOol00`00O01l
0005O0000`0OO01l0005O0000`00O01l000=O0000`00O01l000=O0000`00O01l000=O0000`00O01l
000=O0000`00O01l000<O0000`00Oomoo`05Ool00`0OOomoo`0KOol001eoo`03001oogoo07]oo`03
001l07`000El000301ml07`000El0003001l07`000el0003001l07`000el0003001l07`000el0003
001l07`000el0003001l07`000al0003001oogoo00Eoo`0301moogoo01]oo`007Goo00<007ooOol0
Ngoo00<007`0O00017`000<07g`0O0001W`000<007`0O0003G`000<007`0O0003G`000<007`0O000
3G`000<007`0O0003G`000<007`0O00037`000<007ooOol01Goo00<07gooOol06goo000MOol00`00
Oomoo`1kOol00`00O01l0004O0000`0OO01l0006O0000`00O01l000=O0000`00O01l000=O0000`00
O01l000=O0000`00O01l000=O0000`00O01l000<O00800000`0O00000006000EOol001eoo`8007ao
o`03001l07`000=l000301ml07`000Ml0003001l07`000el0003001l07`000el0003001l07`000el
0003001l07`000el0003001l07`000al0003001l07`000Il000301ml07`000Al0003001oogoo01=o
o`007Goo00<007ooOol0Ngoo00<007`0O0000g`000<07g`0O0001g`000<007`0O0003G`000<007`0
O0003G`000<007`0O0003G`000<007`0O0003G`000<007`0O00037`000<007`0O0001W`000<07g`0
O00017`000<007ooOol04goo000EOol30005Ool00`00Oomoo`1kOol00`00O01l0002O0000`0OO01l
0008O0000`00O01l000=O0000`00O01l000=O0000`00O01l000=O0000`00O01l000=O0000`00O01l
000<O0000`00O01l0006O0000`0OO01l0004O0000`00Oomoo`0COol001Ioo`03001oogoo00Aoo`03
001oogoo07]oo`03001l07`0009l000301ml07`000Ql0003001l07`000el0003001l07`000el0003
001l07`000el0003001l07`000el0003001l07`000al0003001l07`000Ml000301ml07`000=l0003
001oogoo01=oo`003goo1@000Woo00<007ooOol017oo0`00Ngoo00D007`0O01l000O00]l0003001l
07`000el0003001l07`000el0003001l07`000el0003001l07`000el0003001l07`000al0003001l
07`000Ml000301ml07`000=l0003001oogoo01=oo`005Woo00<007ooOol017oo00<007ooOol0Ngoo
00D007`0O01l000O00]l0003001l07`000el0003001l07`000el0003001l07`000el0003001l07`0
00el0003001l07`000al0003001l07`000Ml000301ml07`000=l0003001oogoo01=oo`005Woo00<0
07ooOol017oo00<007ooOol0Ngoo00@007`0O0007`al0003001l07`000el0003001l07`000el0003
001l07`000el0003001l07`000el0003001l07`000al0003001l07`000Ml000301ml07`000=l0003
001oogoo01=oo`005Goo0P001Woo00<007ooOol0Ngoo00@007`0O0007`al0003001l07`000el0003
001l07`000el0003001l07`000el0003001l07`000el0003001l07`000al0003001l07`000Ql0003
01ml07`0009l0003001oogoo01=oo`007Goo00<007ooOol0Ngoo00<007`001l03G`000<007`0O000
3G`000<007`0O0003G`000<007`0O0003G`000<007`0O0003G`000<007`0O00037`000<007`0O000
27`000<07g`0O0000W`000<007ooOol04goo000MOol2001lOol00`00O0007`0=O0000`00O01l000=
O0000`00O01l000=O0000`00O01l000=O0000`00O01l000=O0000`00O01l000<O0000`00O01l0008
O0000`0OO01l0002O0000`00Oomoo`0COol001eoo`03001oogoo07]oo`0300007g`000el0003001l
07`000el0003001l07`000el0003001l07`000el0003001l07`000el0003001l07`000al0003001l
07`000Ql000301ml07`0009l0003001oogoo01=oo`007Goo00<007ooOol0Ngoo00<0000OO0003G`0
00<007`0O0003G`000<007`0O0003G`000<007`0O0003G`000<007`0O0003G`000<007`0O00037`0
00<007`0O0002G`000D07g`0O01l000001Eoo`007Goo00<007ooOol0Ngoo00<07g`0O0003G`000<0
07`0O0003G`000<007`0O0003G`000<007`0O0003G`000<007`0O0003G`000<007`0O00037`000<0
07`0O0002G`000D07g`0O01l000001Eoo`007Goo0P00O7oo00<07g`0O0003G`000<007`0O0003G`0
00<007`0O0003G`000<007`0O0003G`000<007`0O0003G`000<007`0O00037`000<007`0O0002G`0
00D07g`0O01l000001Eoo`007Goo00<007ooOol0NWoo00<07`00O0003W`000<007`0O0003G`000<0
07`0O0003G`000<007`0O0003G`000<007`0O0003G`000<007`0O00037`000<007`0O0002G`000D0
7g`0O01l000001Eoo`007Goo00<007ooOol0NWoo00<07`00O0003W`000<007`0O0003G`000<007`0
O0003G`000<007`0O0003G`000<007`0O0003G`000<007`0O00037`000<007`0O0002W`000@07g`0
O00001Eoo`007Goo00<007ooOol08Goo0`008goo10008Goo0`002Woo00<07goo00003g`000<007`0
O0003G`000<007`0O0003G`000<007`0O0003G`000<007`0O0003G`000<007`0O00037`000<007`0
O0002W`000@07g`0O00001Eoo`007Goo00<007ooOol08Woo00<007ooOol08goo00<007ooOol097oo
00<007ooOol01goo00<07goo00003g`000<007`0O0003G`000<007`0O0003G`000<007`0O0003G`0
00<007`0O0003G`000<007`0O00037`000<007`0O0002W`000@07g`0O00001Eoo`007Goo0P008goo
00<007ooOol097oo00<007ooOol08goo00<007ooOol01Woo00@07gooOol000ml0003001l07`000el
0003001l07`000el0003001l07`000el0003001l07`000el0003001l07`000al0003001l07`000Yl
000401ml07`0000EOol001eoo`03001oogoo029oo`03001oogoo02Eoo`03001oogoo021oo`8000Uo
o`0401moogoo000?O0000`00O01l000=O0000`00O01l000=O0000`00O01l000=O0000`00O01l000=
O0000`00O01l000<O0000`00O01l000;O0000`0OO000000EOol001eoo`03001oogoo029oo`03001o
ogoo029oo`04001oogoo000TOol00`00Oomoo`05Ool01@0OOomoogoo00003g`000<007`0O0003G`0
00<007`0O0003G`000<007`0O0003G`000<007`0O0003G`000<007`0O00037`000<007`0O0002g`0
00<07g`000005Goo000MOol00`00Oomoo`0QOol2000UOol2000ROol30008Ool01@0OOomoogoo0000
3g`000<007`0O0003G`000<007`0O0003G`000<007`0O0003G`000<007`0O0003G`000<007`0O000
37`000<007`0O0002g`000<07g`000005Goo000MOol2001gOol00`0OOomoo`02Ool00`00O01l000=
O0000`00O01l000=O0000`00O01l000=O0000`00O01l000=O0000`00O01l000=O0000`00O01l000<
O0000`00O01l000<O0000`0O001oo`0DOol001eoo`03001oogoo07Ioo`0301moogoo009oo`03001l
07`000el0003001l07`000el0003001l07`000el0003001l07`000el0003001l07`000el0003001l
07`000al0003001l07`000al000301l007oo01Aoo`007Goo00<007ooOol0MGoo00<07gooOol00goo
00<007`0O0003G`000<007`0O0003G`000<007`0O0003G`000<007`0O0003G`000<007`0O0003G`0
00<007`0O00037`000<007`0O00037`000<07`00Ool057oo000MOol00`00Oomoo`1eOol00`0OOomo
o`03Ool00`00O01l000=O0000`00O01l000=O0000`00O01l000=O0000`00O01l000=O0000`00O01l
000=O0000`00O01l000<O0000`00O01l000<O0000`0O001oo`0DOol001eoo`03001oogoo06aoo`03
001oogoo00Eoo`0301moogoo00Aoo`8000il0003001l07`000el0003001l07`000el0003001l07`0
00el0003001l07`000el0003001l07`000al0003001l07`000el000301moogoo01=oo`005goo1P00
2P0OK@0000<07`0000001@003g`000<007`0O0003G`000<007`0O0003G`000<007`0O0003G`000<0
07`0O0003G`000<007`0O00037`000<007`0O0003G`000<07`00000010003goo000MOol:000201l5
000?O0000`00O01l000<O0000`00O01l000=O0000`00O01l000=O0000`00O01l000=O0000`00O01l
000=O0000`00Ool00004Ool00`0OOomoo`0NOol00`00Oomoo`0SOol00`00Oomoo`0ROol00`00Oomo
o`0NOol001eoo`03001oogoo00Uoo`<07`03Ool007`000il0003001l07`000al0003001l07`000el
0003001l07`000el0003001l07`000el0003001l07`000el0003001oogoo00=oo`0301moogoo08]o
o`007Goo00<007ooOol037oo0P0O3g`000<007`0O00037`000<007`0O0003G`000<007`0O0003G`0
00<007`0O0003G`000<007`0O0003G`000<007ooOol00goo00<07gooOol0Rgoo000MOol2000>Ool0
0`0001l07`0=O0000`00O01l000<O0000`00O01l000=O0000`00O01l000=O0000`00O01l000=O000
0`00O01l000=O0000`00Oomoo`02Ool00`0OOomoo`2<Ool001eoo`03001oogoo00eoo`04001l07`0
01l<O0000`00O01l000<O0000`00O01l000=O0000`00O01l000=O0000`00O01l000=O0000`00O01l
000=O0000`00Oomoo`02Ool00`0OOomoo`2<Ool001eoo`03001oogoo00eoo`04001l07`0O00201l:
O0000`00O01l000<O0000`00O01l000=O0000`00O01l000=O0000`00O01l000=O0000`00O01l000=
O0001@00Oomoogoo01l0Sgoo000MOol00`00Oomoo`0=Ool00`00O01l0003O00201l8O0000`00O01l
000<O0000`00O01l000=O0000`00O01l000=O0000`00O01l000=O0000`00O01l000=O0001000Oomo
o`0OT7oo000MOol2000>Ool800000`0O00000006000>O0000`00O01l000=O0000`00O01l000=O000
0`00O01l000=O0000`00O01l000=O0001000Oomoo`0OT7oo000MOol00`00Oomoo`0FOol201l5Ool0
0`00O01l000<O0000`00O01l000=O0000`00O01l000=O0000`00O01l000=O0000`00O01l000=O000
0`00Ool07`2AOol001eoo`03001oogoo01Qoo`807`=oo`03001l07`000al0003001l07`000el0003
001l07`000el0003001l07`000el0003001l07`000el000300007goo095oo`007Goo00<007ooOol0
6Woo00@07gooOol000il0003001l07`000el0003001l07`000el0003001l07`000el0003001l07`0
00el000300007goo095oo`007Goo00<007ooOol06goo0P0O00<007`0O00037`000<007`0O0003G`0
00<007`0O0003G`000<007`0O0003G`000<007`0O0003G`000<07gooOol0TGoo000MOol2000NOol0
0`0OO01l000<O0000`00O01l000=O0000`00O01l000=O0000`00O01l000=O0000`00O01l000=O000
0`0OOomoo`2AOol001eoo`03001oogoo01eoo`0300007g`000al0003001l07`000el0003001l07`0
00el0003001l07`000el0003001l07`000al000301l007oo099oo`007Goo00<007ooOol07Goo00<0
07`001l037`000<007`0O0003G`000<007`0O0003G`000<007`0O0003G`000<007`0O0002g`000<0
7g`00000Tgoo000MOol00`00Oomoo`0MOol00`00O01l000201l:O0000`00O01l000=O0000`00O01l
000=O0000`00O01l000=O0000`00O01l000;O0000`0OO000002COol001eoo`8001ioo`03001l07`0
009l000301ml07`000Ml0003001l07`000el0003001l07`000el0003001l07`000el0003001l07`0
00Yl000401ml07`0002COol001eoo`03001oogoo01eoo`03001l07`000=l000301ml07`000Il0003
001l07`000el0003001l07`000el0003001l07`000el0003001l07`000Ul000501ml07`0O000002C
Ool001eoo`03001oogoo01eoo`03001l07`000Al000301ml07`000El0003001l07`000el0003001l
07`000el0003001l07`000el0003001l07`000Ql000301ml07`0009l0003001oogoo095oo`005Goo
0`001Goo00<007ooOol07Goo20000P0O1P003g`000<007`0O0003G`000<007`0O0003G`000<007`0
O00027`000<07g`0O0000W`000<007ooOol0TGoo000FOol00`00Oomoo`04Ool00`00Oomoo`0WOol0
0`0OOomoo`02Ool00`00O01l000=O0000`00O01l000=O0000`00O01l000=O0000`00O01l0007O000
0`0OO01l0003O0000`00Oomoo`2AOol001Ioo`03001oogoo00Aoo`<002Qoo`0501moogooOol0000?
O0000`00O01l000=O0000`00O01l000=O0000`00O01l0006O0000`0OO01l0004O0000`00Oomoo`2A
Ool001Ioo`03001oogoo00Aoo`03001oogoo02Uoo`0401moogoo000?O0000`00O01l000=O0000`00
O01l000=O0000`00O01l0005O0000`0OO01l0005O0000`00Oomoo`2AOol001Ioo`03001oogoo00Ao
o`03001oogoo02Yoo`807`03001l07`000el0003001l07`000el0003001l07`000el00L0000301l0
000000L009=oo`005Goo0P001Woo00<007ooOol0;7oo00<07g`0O0003G`000<007`0O0003G`000<0
07`0O0003G`000<007ooOol017oo00<07gooOol0VWoo000MOol2000]Ool00`0001ml000=O0000`00
O01l000=O0000`00O01l000=O0000`00Oomoo`03Ool00`0OOomoo`2KOol001eoo`03001oogoo02ao
o`03001l000O00el0003001l07`000el0003001l07`000el0003001oogoo009oo`0301moogoo09ao
o`007Goo00<007ooOol0;7oo00<007`0O0000P0O2g`000<007`0O0003G`000<007`0O0003G`000D0
07ooOomoo`0O09moo`007Goo00<007ooOol0;7oo00<007`0O0000W`000<07g`0O00027`000<007`0
O0003G`000<007`0O0003G`000@007ooOol07j1oo`007Goo0P00;Goo00<007`0O0000g`00P0O27`0
00<007`0O0003G`000<007`0O0003G`000<007oo01l0XGoo000MOol00`00Oomoo`0/Ool00`00O01l
0005O0000`0OO01l0005O0000`00O01l000=O0000`00O01l000=O0000`0001moo`2QOol001eoo`03
001oogoo02aoo`T000807`H000ml0003001l07`000al00807j=oo`007Goo00<007ooOol0=goo00<0
7gooOol00Woo00<007`0O0003G`000<007`0O0002g`000<07g`00000Xgoo000MOol00`00Oomoo`0h
Ool201l2Ool00`00O01l000=O0000`00O01l000:O000100OO01l0000Xgoo000MOol2000kOol00`0O
Ool0000?O0000`00O01l0009O0001@0OO01l07`00000Xgoo000MOol00`00Oomoo`0kOol301l>O000
0`00O01l0007O00201l4O0000`00Oomoo`2QOol001eoo`03001oogoo03aoo`04001l000O01l<O007
000301l7002SOol001eoo`03001oogoo03aoo`04001l07`0O00301l9O0000`00Oomoo`02Ool201n]
Ool001eoo`8003eoo`L000@07`H000@07jmoo`007Goo00<007ooOol0Agoo1P0O/goo000MOol00`00
Oomoo`3oOol1Ool001eoo`03001oogoo0?moo`5oo`007Goo00<007ooOol0ogoo0Goo003oOolQOol0
0?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00?7oo
1P001Woo0`000goo100017oo0`001Goo0`000goo100000=oo`0000000P000Woo0P001Goo2P0000=o
o`0000000P000Woo100017oo10000goo10006Goo100017oo0P001Goo00<007ooOol00goo1`000goo
0P002goo0P0017oo1000=goo000nOol20007Ool20002Ool01000Oomoogoo0P0017oo0P000Woo00@0
07ooOomoo`80009oo`04001oogooOol20003Ool20002Ool200000goo001oo`05Ool20005Ool20000
0goo00000004Ool20004Ool20002Ool20003Ool2000IOol20002Ool20003Ool20005Ool20005Ool6
0005Ool20009Ool20003Ool20002Ool2000fOol003ioo`8000Ioo`8000Aoo`03001oogoo008000=o
o`8000Aoo`04001oo`000004Ool00`00Oomoo`020003Ool20002Ool20008Ool20006Ool01000Ool0
000017oo0P000goo0P0017oo0P000Woo0P002Goo2@001goo00<007ooOol00Woo00<007ooOol02Goo
00<007ooOol017oo00<007ooOol00Woo00<007ooOol00goo0P0027oo0P000Woo0P0017oo0P00=Goo
000nOol20006Ool20007Ool20003Ool20006Ool20007Ool20003Ool20002Ool20008Ool20008Ool2
0004Ool20003Ool20004Ool20002Ool2000HOol20004Ool2000:Ool00`00Oomoo`04Ool2000:Ool2
0002Ool;0004Ool2000eOol003ioo`8000Ioo`8000Moo`8000=oo`8000Ioo`8000Moo`8000=oo`80
009oo`8000Qoo`8000Aoo`04001oogooOol20004Ool20003Ool20004Ool20002Ool2000HOol20004
Ool2000:Ool00`00Oomoo`05Ool00`00Oomoo`08Ool20002Ool00`00Oomoo`02Ool20002Ool20003
Ool3000eOol003ioo`H0009oo`L0009oo`8000=oo`8000Aoo`03001oo`0000H0009oo`8000=oo`80
009oo`8000Qoo`8000Aoo`04001oogooOol20004Ool20003Ool20004Ool20002Ool2000HOol20004
Ool2000;Ool00`00Oomoo`05Ool00`00Oomoo`04Ool60002Ool01000Oomoogoo0P000goo0P0000Ao
o`00000003Ioo`00?Woo0P000goo0P000Woo00@007ooOomoo`800003Ool0000000@00003Ool00000
009oo`80009oo`04001oogooOol200000goo000000020002Ool20002Ool20008Ool70002Ool<0000
0goo00000002Ool20002Ool60006Ool90006Ool20004Ool2000;Ool00`00Oomoo`05Ool20004Ool2
0003Ool20003Ool00`00Oomoo`020004Ool4000gOol003ioo`8000Aoo`80009oo`@000Aoo`04001o
o`000002Ool40004Ool40004Ool00`00Ool000020002Ool50006Ool20004Ool00`00Oomoo`02Ool0
1000Ool000000Woo00@007oo0000009oo`@000Eoo`04001oo`00000EOol20004Ool2000;Ool00`00
Oomoo`06Ool01000Oomoogoo0P0017oo0P000goo00<007ooOol00P000goo1@00=goo000nOol20004
Ool2000XOol20008Ool20004Ool00`00Oomoo`0`Ool20004Ool2000<Ool00`00Oomoo`05Ool20002
Ool20004Ool20004Ool01000Ool000000goo0P000Woo0P00=Woo000nOol20004Ool2000YOol00`00
Oomoo`06Ool2000gOol20004Ool2000<Ool01000Oomoo`0017oo0P000Woo0P0017oo0P001Goo0`00
0Woo0P0017oo0P00=Goo000nOol20004Ool2000bOol20005Ool00`00Oomoo`0`Ool00`00Oomoo`02
Ool00`00Oomoo`05Ool20004Ool00`00Oomoo`020002Ool30002Ool20004Ool20005Ool30002Ool2
0004Ool2000eOol003ioo`8000=oo`8003=oo`8000Eoo`03001oogoo031oo`80009oo`8000Qoo`L0
009oo`D000Aoo`80009oo`8000Moo`8000=oo`80009oo`8003Ioo`00?7oo2000<Woo2P00<goo1000
2Goo1`000goo0`001Woo100027oo0P0017oo1000=goo003oOolQOol00?moob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.783823, -4.98036, 
  0.0265065, 0.0452841}}]
}, Closed]],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{
          TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
            False,
            Editable->False], ",", 
          TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
            False,
            Editable->False], ",", 
          TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
            False,
            Editable->False], ",", 
          TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
            False,
            Editable->False], ",", 
          TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
            False,
            Editable->False], ",", 
          TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
            False,
            Editable->False], ",", 
          TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
            False,
            Editable->False], ",", 
          TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
            False,
            Editable->False], ",", 
          TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
            False,
            Editable->False], ",", 
          TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
            False,
            Editable->False], ",", 
          TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
            False,
            Editable->False], ",", 
          TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
            False,
            Editable->False], ",", 
          TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
            False,
            Editable->False], ",", 
          TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
            False,
            Editable->False]}], "}"}], TraditionalForm]], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"Macintosh 3.0",
ScreenRectangle->{{0, 1152}, {0, 850}},
WindowToolbars->{"RulerBar", "EditBar"},
WindowSize->{520, 740},
WindowMargins->{{Automatic, 189}, {Automatic, 27}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
MacintoshSystemPageSetup->"\<\
00<0001804P000000]P2:?oQon82n@960dL5:0?l0080001804P000000]P2:001
0000I00000400`<300000BL?00400@00000000000000060801T1T000000@0000
00000000004000000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 78, 2, 98, "Title"],
Cell[1812, 55, 321, 6, 90, "Text"],

Cell[CellGroupData[{
Cell[2158, 65, 26, 0, 46, "Subsection"],
Cell[2187, 67, 3869, 89, 1977, "Input"],
Cell[6059, 158, 75, 1, 33, "Text"],

Cell[CellGroupData[{
Cell[6159, 163, 28, 0, 27, "Input"],
Cell[6190, 165, 311, 5, 67, "Print"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[6550, 176, 51, 0, 30, "Subsection"],
Cell[6604, 178, 220, 5, 71, "Text"],

Cell[CellGroupData[{
Cell[6849, 187, 79, 0, 27, "Input"],
Cell[6931, 189, 26824, 852, 186, 9728, 636, "GraphicsData", 
"PostScript", "Graphics"],
Cell[33758, 1043, 167, 4, 26, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[33962, 1052, 84, 1, 27, "Input"],
Cell[34049, 1055, 26763, 851, 186, 9728, 636, "GraphicsData", 
"PostScript", "Graphics"],
Cell[60815, 1908, 167, 4, 26, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[61019, 1917, 85, 1, 42, "Input"],
Cell[61107, 1920, 26568, 848, 186, 9728, 636, "GraphicsData", 
"PostScript", "Graphics"],
Cell[87678, 2770, 167, 4, 26, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[87882, 2779, 77, 0, 27, "Input"],
Cell[87962, 2781, 26481, 847, 186, 9722, 636, "GraphicsData", 
"PostScript", "Graphics"],
Cell[114446, 3630, 167, 4, 26, "Output"]
}, Open  ]],
Cell[114628, 3637, 358, 11, 72, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[115023, 3653, 31, 0, 30, "Subsection"],

Cell[CellGroupData[{
Cell[115079, 3657, 99, 2, 42, "Input"],

Cell[CellGroupData[{
Cell[115203, 3663, 23848, 767, 186, 9061, 580, "GraphicsData", 
"PostScript", "Graphics"],
Cell[139054, 4432, 24021, 781, 186, 9270, 594, "GraphicsData", 
"PostScript", "Graphics"],
Cell[163078, 5215, 25204, 808, 186, 9372, 608, "GraphicsData", 
"PostScript", "Graphics"],
Cell[188285, 6025, 25770, 826, 186, 9606, 622, "GraphicsData", 
"PostScript", "Graphics"],
Cell[214058, 6853, 26824, 852, 186, 9728, 636, "GraphicsData", 
"PostScript", "Graphics"],
Cell[240885, 7707, 27402, 870, 186, 9942, 650, "GraphicsData", 
"PostScript", "Graphics"],
Cell[268290, 8579, 28288, 894, 186, 10038, 664, "GraphicsData", 
"PostScript", "Graphics"],
Cell[296581, 9475, 28797, 911, 186, 10272, 678, "GraphicsData", 
"PostScript", "Graphics"],
Cell[325381, 10388, 29713, 935, 186, 10406, 692, "GraphicsData", 
"PostScript", "Graphics"],
Cell[355097, 11325, 30310, 954, 186, 10614, 706, "GraphicsData", 
"PostScript", "Graphics"],
Cell[385410, 12281, 30880, 974, 186, 10698, 720, "GraphicsData", 
"PostScript", "Graphics"],
Cell[416293, 13257, 32062, 999, 186, 10933, 734, "GraphicsData", 
"PostScript", "Graphics"],
Cell[448358, 14258, 32804, 1021, 186, 11067, 748, "GraphicsData", 
"PostScript", "Graphics"],
Cell[481165, 15281, 33286, 1038, 186, 11266, 762, "GraphicsData", 
"PostScript", "Graphics"]
}, Closed]],
Cell[514466, 16322, 1915, 45, 55, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

