(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the
word CacheID, otherwise Mathematica-compatible applications may try to
use invalid cache data.

For more information on notebooks and Mathematica-compatible
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    126818,       4749]*)
(*NotebookOutlinePosition[    127873,       4783]*)
(*  CellTagsIndexPosition[    127829,       4779]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["Code", "Section"],

Cell[TextData[{
  "Off[General::spell1];\nOff[General::spell];\nClear[ShowTangentLines]\n\
ShowTangentLines::usage=\"ShowTangentLines[function,{x,xmain,xmax},\n\tn] \
draws n+1 lines tangent to the function over the interval [xmin,xmax]. The \n\
\targument n is optional. The default value of n is 10.\";\n\t\n\
TangentLineStyle::usage=\"TangentLineStyle is an option for\n\
ShowTangentLines. TangentLineStyle controls the style of the tangent lines \
and can be set to any valid graphics style.\";\n\
Needs[\"Utilities`FilterOptions`\"];\n\
Options[ShowTangentLines]={TangentLineStyle->RGBColor[1,0,0]};\n\
ShowTangentLines[f_[x_],{x_,xmin_,xmax_},n_,opts___Rule",
  StyleBox["]",
    FontWeight->"Plain"],
  ":=\n\tModule[{dplots,plot2,fprime,dplot},\n\t\
plotOptions=FilterOptions[Plot,opts];\n\tOptionList=opts;\n\t\
plot2=Plot[f[x],{x,xmin,xmax},Evaluate[plotOptions,\n\t\t\
PlotStyle->Thickness[.007],DisplayFunction->Identity]];\n\
fprime[y_]=D[f[y],y];\nstyle={RGBColor[1,0,0]};\n\tstyle=Flatten[Join[style,\n\
\t\t{If[Intersection[{TangentLineStyle/.{OptionList}},\n\t\t\t\
{TangentLineStyle}]=={},\n\t\t\tTangentLineStyle/.{OptionList},{}]}]];\n\
dplot[x1_,step_]:=\n\tPlot[fprime[x1](x-x1)+f[x1],{x,x1-step,x1+step},\n\
PlotStyle->style,DisplayFunction->Identity];\n\
dplots=Table[dplot[x1,1],{x1,xmin,xmax,(xmax-xmin)/n}];\nShow[plot2,dplots,\n\
\tDisplayFunction->$DisplayFunction]]\n\t\n\
ShowTangentLines[f_[x_],{x_,xmin_,xmax_},opts___Rule]:=\n\t\
ShowTangentLines[f[x],{x,xmin,xmax},10,opts]\n\t\n\
ShowTangentLines[f_,{x_,xmin_,xmax_},n_,opts___Rule]:=\n\t\
Module[{dplots,plot2,fprime,dplot},\n\tplotOptions=FilterOptions[Plot,opts];\n\
\tOptionList=opts;\n\tplot2=Plot[f,{x,xmin,xmax},Evaluate[plotOptions,\n\t\
PlotStyle->Thickness[.007],\n\tDisplayFunction->Identity]];\n\
fprime[y_]=D[f/.x->y,y];\nstyle={RGBColor[1,0,0]};\n\t\
style=Flatten[Join[style,\n\t\t\
{If[Intersection[{TangentLineStyle/.{OptionList}},\n\t\t\t\
{TangentLineStyle}]=={},\n\t\t\tTangentLineStyle/.{OptionList},{}]}]];\n\
dplot[x1_,step_]:=\n\t\
Plot[Evaluate[fprime[x1](x-x1)+(f/.x->x1)],{x,x1-step,x1+step},\n\
PlotStyle->style,DisplayFunction->Identity];\n\
dplots=Table[dplot[x1,1],{x1,xmin,xmax,(xmax-xmin)/n}];\n\
Show[dplots,plot2,DisplayFunction->$DisplayFunction]]\n\t\n\
ShowTangentLines[f_,{x_,xmin_,xmax_},opts___Rule]:=\n\t\
ShowTangentLines[f,{x,xmin,xmax},10,opts]\nOn[General::spell1];\n\
On[General::spell];"
}], "Input",
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?ShowTangentLines\)\)], "Input"],

Cell[BoxData[
    \(TraditionalForm
    \`"ShowTangentLines[function,{x,xmain,xmax}, n] draws n+1 lines tangent \
to the function over the interval [xmin,xmax]. The  argument n is optional. \
The default value of n is 10."\)], "Print"]
}, Open  ]],

Cell["Several examples are given below.", "Text",
  FontSize->14],

Cell[CellGroupData[{

Cell[BoxData[
    \(ShowTangentLines[\(-x\^2\)\  + 2, {x, \(-3\), 3}]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.494154 0.0368799 [
[.02381 .48165 -6 -9 ]
[.02381 .48165 6 0 ]
[.2619 .48165 -6 -9 ]
[.2619 .48165 6 0 ]
[.7381 .48165 -3 -9 ]
[.7381 .48165 3 0 ]
[.97619 .48165 -3 -9 ]
[.97619 .48165 3 0 ]
[.4875 .03316 -30 -4.5 ]
[.4875 .03316 0 4.5 ]
[.4875 .12535 -18 -4.5 ]
[.4875 .12535 0 4.5 ]
[.4875 .21755 -24 -4.5 ]
[.4875 .21755 0 4.5 ]
[.4875 .30975 -12 -4.5 ]
[.4875 .30975 0 4.5 ]
[.4875 .40195 -24 -4.5 ]
[.4875 .40195 0 4.5 ]
[.4875 .58635 -18 -4.5 ]
[.4875 .58635 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .49415 m
.02381 .5004 L
s
[(-4)] .02381 .48165 0 1 Mshowa
.2619 .49415 m
.2619 .5004 L
s
[(-2)] .2619 .48165 0 1 Mshowa
.7381 .49415 m
.7381 .5004 L
s
[(2)] .7381 .48165 0 1 Mshowa
.97619 .49415 m
.97619 .5004 L
s
[(4)] .97619 .48165 0 1 Mshowa
.125 Mabswid
.08333 .49415 m
.08333 .4979 L
s
.14286 .49415 m
.14286 .4979 L
s
.20238 .49415 m
.20238 .4979 L
s
.32143 .49415 m
.32143 .4979 L
s
.38095 .49415 m
.38095 .4979 L
s
.44048 .49415 m
.44048 .4979 L
s
.55952 .49415 m
.55952 .4979 L
s
.61905 .49415 m
.61905 .4979 L
s
.67857 .49415 m
.67857 .4979 L
s
.79762 .49415 m
.79762 .4979 L
s
.85714 .49415 m
.85714 .4979 L
s
.91667 .49415 m
.91667 .4979 L
s
.25 Mabswid
0 .49415 m
1 .49415 L
s
.5 .03316 m
.50625 .03316 L
s
[(-12.5)] .4875 .03316 1 0 Mshowa
.5 .12535 m
.50625 .12535 L
s
[(-10)] .4875 .12535 1 0 Mshowa
.5 .21755 m
.50625 .21755 L
s
[(-7.5)] .4875 .21755 1 0 Mshowa
.5 .30975 m
.50625 .30975 L
s
[(-5)] .4875 .30975 1 0 Mshowa
.5 .40195 m
.50625 .40195 L
s
[(-2.5)] .4875 .40195 1 0 Mshowa
.5 .58635 m
.50625 .58635 L
s
[(2.5)] .4875 .58635 1 0 Mshowa
.125 Mabswid
.5 .0516 m
.50375 .0516 L
s
.5 .07003 m
.50375 .07003 L
s
.5 .08847 m
.50375 .08847 L
s
.5 .10691 m
.50375 .10691 L
s
.5 .14379 m
.50375 .14379 L
s
.5 .16223 m
.50375 .16223 L
s
.5 .18067 m
.50375 .18067 L
s
.5 .19911 m
.50375 .19911 L
s
.5 .23599 m
.50375 .23599 L
s
.5 .25443 m
.50375 .25443 L
s
.5 .27287 m
.50375 .27287 L
s
.5 .29131 m
.50375 .29131 L
s
.5 .32819 m
.50375 .32819 L
s
.5 .34663 m
.50375 .34663 L
s
.5 .36507 m
.50375 .36507 L
s
.5 .38351 m
.50375 .38351 L
s
.5 .42039 m
.50375 .42039 L
s
.5 .43883 m
.50375 .43883 L
s
.5 .45727 m
.50375 .45727 L
s
.5 .47571 m
.50375 .47571 L
s
.5 .51259 m
.50375 .51259 L
s
.5 .53103 m
.50375 .53103 L
s
.5 .54947 m
.50375 .54947 L
s
.5 .56791 m
.50375 .56791 L
s
.5 .01472 m
.50375 .01472 L
s
.5 .60479 m
.50375 .60479 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.02381 .01472 m
.03347 .03267 L
.044 .05225 L
.0539 .07064 L
.06341 .08832 L
.07354 .10714 L
.08328 .12526 L
.09365 .14452 L
.10363 .16308 L
.11323 .18093 L
.12345 .19992 L
.13329 .2182 L
.14275 .23579 L
.15282 .25451 L
.16251 .27252 L
.17282 .29168 L
.18274 .31013 L
.19229 .32788 L
.20245 .34677 L
.21224 .36495 L
.22263 .38427 L
.23265 .40289 L
.24229 .42081 L
.25254 .43986 L
.2619 .45727 L
s
.09524 .17846 m
.1049 .19282 L
.11543 .20849 L
.12532 .2232 L
.13484 .23735 L
.14496 .25241 L
.15471 .2669 L
.16507 .28231 L
.17506 .29715 L
.18466 .31143 L
.19488 .32663 L
.20471 .34125 L
.21417 .35532 L
.22425 .3703 L
.23394 .38471 L
.24424 .40003 L
.25417 .4148 L
.26372 .42899 L
.27388 .4441 L
.28366 .45865 L
.29406 .47411 L
.30408 .489 L
.31371 .50333 L
.32396 .51858 L
.33333 .53251 L
s
.16667 .31566 m
.17633 .32643 L
.18686 .33818 L
.19675 .34921 L
.20627 .35982 L
.21639 .37111 L
.22614 .38198 L
.2365 .39354 L
.24649 .40467 L
.25609 .41538 L
.26631 .42678 L
.27614 .43775 L
.2856 .4483 L
.29567 .45953 L
.30537 .47034 L
.31567 .48183 L
.3256 .49291 L
.33515 .50355 L
.34531 .51489 L
.35509 .5258 L
.36549 .53739 L
.3755 .54856 L
.38514 .55931 L
.39539 .57074 L
.40476 .58119 L
s
.2381 .4263 m
.24775 .43348 L
.25829 .44131 L
.26818 .44866 L
.27769 .45574 L
.28782 .46327 L
.29757 .47051 L
.30793 .47822 L
.31791 .48564 L
.32752 .49278 L
.33773 .50038 L
.34757 .50769 L
.35703 .51472 L
.3671 .52221 L
.3768 .52942 L
.3871 .53708 L
.39703 .54446 L
.40658 .55156 L
.41674 .55912 L
.42652 .56639 L
.43692 .57412 L
.44693 .58157 L
.45657 .58873 L
.46682 .59635 L
.47619 .60332 L
s
.30952 .51038 m
.31918 .51397 L
.32972 .51789 L
.33961 .52157 L
.34912 .5251 L
.35925 .52887 L
.369 .53249 L
.37936 .53634 L
.38934 .54005 L
.39895 .54362 L
.40916 .54742 L
.419 .55108 L
.42846 .5546 L
.43853 .55834 L
.44822 .56194 L
.45853 .56577 L
.46846 .56947 L
.47801 .57301 L
.48817 .57679 L
.49795 .58043 L
.50834 .58429 L
.51836 .58802 L
.528 .5916 L
.53825 .59541 L
.54762 .59889 L
s
.38095 .56791 m
.39061 .56791 L
.40114 .56791 L
.41104 .56791 L
.42055 .56791 L
.43068 .56791 L
.44043 .56791 L
.45079 .56791 L
.46077 .56791 L
.47037 .56791 L
.48059 .56791 L
.49043 .56791 L
.49989 .56791 L
.50996 .56791 L
.51965 .56791 L
.52996 .56791 L
.53989 .56791 L
.54943 .56791 L
.5596 .56791 L
.56938 .56791 L
.57977 .56791 L
.58979 .56791 L
.59943 .56791 L
.60968 .56791 L
.61905 .56791 L
s
.45238 .59889 m
.46204 .5953 L
.47257 .59139 L
.48247 .58771 L
.49198 .58417 L
.50211 .58041 L
.51186 .57678 L
.52222 .57293 L
.5322 .56922 L
.5418 .56565 L
.55202 .56185 L
.56186 .5582 L
.57132 .55468 L
.58139 .55093 L
.59108 .54733 L
.60139 .5435 L
.61131 .53981 L
.62086 .53626 L
.63102 .53248 L
.64081 .52885 L
.6512 .52498 L
.66122 .52126 L
.67086 .51768 L
.68111 .51386 L
.69048 .51038 L
s
.52381 .60332 m
.53347 .59614 L
.544 .58831 L
.5539 .58095 L
.56341 .57388 L
.57354 .56635 L
.58328 .5591 L
.59365 .5514 L
.60363 .54397 L
.61323 .53683 L
.62345 .52924 L
.63329 .52192 L
.64275 .51489 L
.65282 .5074 L
.66251 .5002 L
.67282 .49253 L
.68274 .48515 L
.69229 .47805 L
.70245 .4705 L
.71224 .46322 L
.72263 .4555 L
.73265 .44805 L
.74229 .44088 L
.75254 .43326 L
.7619 .4263 L
s
.59524 .58119 m
.6049 .57042 L
.61543 .55867 L
.62532 .54764 L
.63484 .53703 L
.64496 .52573 L
.65471 .51486 L
.66507 .50331 L
.67506 .49217 L
.68466 .48146 L
.69488 .47007 L
.70471 .4591 L
.71417 .44855 L
.72425 .43732 L
.73394 .42651 L
.74424 .41501 L
.75417 .40394 L
.76372 .39329 L
.77388 .38196 L
.78366 .37105 L
.79406 .35946 L
.80408 .34828 L
.81371 .33754 L
.82396 .3261 L
.83333 .31566 L
s
.66667 .53251 m
.67633 .51815 L
.68686 .50248 L
.69675 .48777 L
.70627 .47362 L
.71639 .45857 L
.72614 .44407 L
.7365 .42866 L
.74649 .41382 L
.75609 .39954 L
.76631 .38435 L
.77614 .36972 L
.7856 .35565 L
.79567 .34068 L
.80537 .32626 L
.81567 .31094 L
.8256 .29618 L
.83515 .28198 L
.84531 .26687 L
.85509 .25232 L
.86549 .23686 L
.8755 .22197 L
.88514 .20764 L
.89539 .19239 L
.90476 .17846 L
s
.7381 .45727 m
.74775 .43932 L
.75829 .41974 L
.76818 .40135 L
.77769 .38367 L
.78782 .36484 L
.79757 .34673 L
.80793 .32747 L
.81791 .30891 L
.82752 .29106 L
.83773 .27207 L
.84757 .25378 L
.85703 .2362 L
.8671 .21748 L
.8768 .19947 L
.8871 .18031 L
.89703 .16186 L
.90658 .14411 L
.91674 .12522 L
.92652 .10704 L
.93692 .08772 L
.94693 .0691 L
.95657 .05118 L
.96682 .03213 L
.97619 .01472 L
s
0 g
.007 w
.14286 .23599 m
.17183 .28767 L
.20343 .33904 L
.23311 .38256 L
.26166 .42009 L
.29204 .45537 L
.32128 .4848 L
.35237 .5112 L
.38231 .53187 L
.41112 .54736 L
.42571 .55355 L
.44177 .55909 L
.45701 .56311 L
.46384 .56451 L
.47129 .56577 L
.47532 .56633 L
.47907 .56677 L
.48295 .56716 L
.48647 .56744 L
.48994 .56765 L
.49152 .56773 L
.4932 .56779 L
.49499 .56785 L
.49579 .56787 L
.49664 .56788 L
.49756 .5679 L
.49842 .56791 L
.49894 .56791 L
.49944 .56791 L
.50037 .56791 L
.50122 .56791 L
.50214 .5679 L
.50301 .56789 L
.50381 .56788 L
.50566 .56783 L
.50761 .56776 L
.50951 .56768 L
.51128 .56758 L
.5153 .56731 L
.52198 .56666 L
.52911 .56571 L
.5368 .56439 L
.54512 .56262 L
.56024 .55847 L
.57514 .55322 L
.59093 .5464 L
.61934 .53085 L
.6496 .50968 L
.67871 .4848 L
.70967 .45351 L
Mistroke
.73949 .41866 L
.76818 .38076 L
.7987 .33574 L
.82809 .28781 L
.85714 .23599 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00OSgoo00<007ooOol0
SWoo002?Ool00`00Oomoo`2>Ool008moo`03001oogoo08ioo`00Sgoo00<007ooOol0SWoo0007Ool0
0g`0Oomoo`25Ool20026Ool00g`0Oomoo`06Ool000Moo`03O01oogoo08Eoo`03001oogoo08Eoo`03
O01oogoo00Ioo`0027oo00=l07ooOol0Q7oo00<007ooOol0Q7oo00=l07ooOol01goo0008Ool00g`0
Oomoo`1YOol30003Ool40003Ool20003Ool30006Ool00`00Oomoo`24Ool00g`0Oomoo`07Ool000Qo
o`03O01oogoo06Yoo`03001oogoo00=oo`03001oogoo00=oo`8000Ioo`03001oogoo00=oo`03001o
ogoo08Aoo`03O01oogoo00Moo`002Goo00=l07ooOol0HWoo1@000Woo00<007ooOol017oo00<007oo
Ool02Woo00<007ooOol00goo0`00Pgoo00=l07ooOol027oo0009Ool00g`0Oomoo`1YOol00`00Oomo
o`05Ool00`00Oomoo`06Ool30006Ool00`00Oomoo`23Ool00g`0Oomoo`08Ool000Yoo`03O01oogoo
06Qoo`03001oogoo009oo`04001oogoo0008Ool00`00Oomoo`06Ool00`00Oomoo`22Ool00g`0Oomo
o`09Ool000Yoo`03O01oogoo06Moo`8000Eoo`8000Uoo`@000Eoo`03001oogoo085oo`03O01oogoo
00Yoo`002goo00=l07ooOol0PGoo00<007ooOol0PGoo00=l07ooOol02Woo000;Ool00g`0Oomoo`21
Ool20021Ool00g`0Oomoo`0;Ool000aoo`03O01oogoo081oo`03001oogoo081oo`03O01oogoo00]o
o`0037oo00=l07ooOol0P7oo00<007ooOol0Ogoo00=l07ooOol037oo000=Ool00g`0Oomoo`1oOol0
0`00Oomoo`1nOol00g`0Oomoo`0=Ool000ioo`03O01oogoo07ioo`03001oogoo07ioo`03O01oogoo
00eoo`003Woo00=l07ooOol0OWoo00<007ooOol0OGoo00=l07ooOol03Woo000?Ool00g`0Oomoo`1m
Ool2001nOol00g`0Oomoo`0>Ool000moo`03O01oogoo07eoo`03001oogoo07aoo`03O01oogoo00mo
o`0047oo00=l07ooOol0O7oo00<007ooOol0O7oo00=l07ooOol03goo000AOol00g`0Oomoo`1kOol0
0`00Oomoo`1kOol00g`0Oomoo`0@Ool0015oo`03O01oogoo07]oo`03001oogoo07]oo`03O01oogoo
011oo`004Woo00=l07ooOol0NWoo0P00Ngoo00=l07ooOol04Goo000BOol00g`0Oomoo`1jOol00`00
Oomoo`1jOol00g`0Oomoo`0AOol001=oo`03O01oogoo07Uoo`03001oogoo07Uoo`03O01oogoo019o
o`0057oo00=l07ooOol0N7oo00<007ooOol0N7oo00=l07ooOol04goo000DOol00g`0Oomoo`1hOol0
0`00Oomoo`1hOol00g`0Oomoo`0COol001Eoo`03O01oogoo07Moo`8007Qoo`03O01oogoo01Aoo`00
5Goo00=l07ooOol0Mgoo00<007ooOol0Mgoo00=l07ooOol057oo000FOol00g`0Oomoo`1fOol00`00
Oomoo`1fOol00g`0Oomoo`0EOol001Moo`03O01oogoo06Ioo`<000Aoo`8000Ioo`03001oogoo07Eo
o`03O01oogoo01Ioo`005goo00=l07ooOol0Igoo00<007ooOol00Woo00@007ooOol000Eoo`03001o
ogoo07Eoo`03O01oogoo01Ioo`0067oo00=l07ooOol0Ggoo1@000Woo00<007ooOol00Woo00@007oo
Ool000Eoo`<007Aoo`03O01oogoo01Moo`0067oo00=l07ooOol0IWoo00<007ooOol00Woo00@007oo
Ool000Eoo`03001oogoo07Aoo`03O01oogoo01Moo`006Goo00=l07ooOol0IGoo00<007ooOol00Woo
00@007ooOol000Eoo`03001oogoo07=oo`03O01oogoo01Qoo`006Goo00=l07ooOol0I7oo0P001Goo
0P001Woo00<007ooOol0Lgoo00=l07ooOol067oo000JOol00g`0Oomoo`1bOol00`00Oomoo`1bOol0
0g`0Oomoo`0IOol001Yoo`03O01oogoo079oo`03001oogoo079oo`03O01oogoo01Uoo`006goo00=l
07ooOol0LGoo0P00LWoo00=l07ooOol06Woo000KOol00g`0Oomoo`1aOol00`00Oomoo`1aOol00g`0
Oomoo`0JOol001aoo`03O01oogoo071oo`03001oogoo071oo`03O01oogoo01]oo`007Goo00=l07oo
Ool0Kgoo00<007ooOol0L7oo00=l07ooOol06goo000MOol00g`0Oomoo`1_Ool00`00Oomoo`1`Ool0
0g`0Oomoo`0KOol001ioo`03O01oogoo06ioo`80071oo`03O01oogoo01aoo`007Woo00=l07ooOol0
KWoo00<007ooOol0Kgoo00=l07ooOol077oo000OOol00g`0Oomoo`1]Ool00`00Oomoo`1^Ool00g`0
Oomoo`0MOol001moo`03O01oogoo06eoo`03001oogoo06eoo`03O01oogoo01ioo`007goo00=l07oo
Ool0KGoo00<007ooOol0KGoo00=l07ooOol07Woo000KOol00g`0Oomoo`02Ool00g`0Oomoo`1/Ool2
001]Ool00g`0Oomoo`02Ool00g`0Oomoo`0JOol001]oo`03O01oogoo009oo`03O01oogoo06aoo`03
001oogoo06aoo`03O01oogoo009oo`03O01oogoo01Yoo`0077oo00=l07ooOol00Woo00=l07ooOol0
Jgoo00<007ooOol0Jgoo00=l07ooOol00Woo00=l07ooOol06goo00
0MOol01G`0OomoogooO000KGoo
00<007ooOol0Jgoo00El07ooOomoog`001ioo`007Woo00El07ooOomoog`006aoo`03001oogoo06Yo
o`05O01oogooOoml000OOol001ioo`05O01oogooOoml001/Ool00`00Oomoo`1ZOol01G`0Oomoogoo
O0007goo000OOol01G`0OomoogooO000Jgoo0P00JWoo00El07ooOomoog`0021oo`0087oo00Al07oo
Ooml06]oo`03001oogoo06Uoo`04O01oogooO00QOol0025oo`04O01oogooO01ZOol00`00Oomoo`1X
Ool017`0Oomoog`08Woo000QOol01G`0OomoogooO000EGoo00<007ooOol00goo0P000goo0`001Woo
00<007ooOol0Igoo00El07ooOomoog`0029oo`008Woo00Al07ooOoml05Eoo`03001oogoo00=oo`80
00Ioo`03001oogoo00=oo`03001oogoo06Moo`04O01oogooO00SOol002=oo`04O01oogooO01=Ool5
0003Ool00`00Oomoo`0:Ool00`00Oomoo`03Ool3001VOol01G`0OomoogooO0008goo000TOol00g`0
Ooml001EOol00`00Oomoo`07Ool30006Ool00`00Oomoo`1VOol017`0Oomoog`097oo000TOol017`0
Oomoog`0EGoo00<007ooOol01Woo00<007ooOol01Woo00<007ooOol0IGoo00El07ooOomoog`002Ao
o`009Goo00Al07ooOoml055oo`@000Qoo`@000Eoo`03001oogoo06Aoo`05O01oogooOoml000UOol0
02Eoo`04O01oogooO01VOol00`00Oomoo`1TOol017`0Oomoog`09Woo000UOol00g`0Oomoo`02001U
Ool2001SOol20002Ool00g`0Oomoo`0UOol002Ioo`04O01oo`00001UOol00`00Oomoo`1ROol20002
Ool00g`0Oomoo`0UOol002Ioo`03O01oo`00008006Aoo`03001oogoo065oo`<00003Ooml07oo02Mo
o`009goo00El07oo000007`006=oo`03001oogoo065oo`800003Ooml07oo02Qoo`00:7oo00Al0000
000006=oo`03001oogoo061oo`<00003Ooml07oo02Qoo`00:Goo00Al0000001l069oo`80065oo`80
0003Ooml07oo02Uoo`00:Goo00Al00000000069oo`03001oogoo05moo`<00003Ooml07oo02Uoo`00
:Woo00Al0000001l065oo`03001oogoo05moo`800003Ooml07oo02Yoo`00:goo0`00HGoo00<007oo
Ool0GWoo0`0000=l07ooOol0:Woo000/Ool3001POol00`00Oomoo`1MOol300000g`0Oomoo`0[Ool0
02aoo`03O0000000061oo`03001oogoo05eoo`800003Ooml07oo02aoo`00;Goo0`00Ggoo0P00GGoo
0`0000=l07ooOol0;7oo000^Ool2001OOol00`00Oomoo`1LOol200000g`0Oomoo`0]Ool002ioo`<0
05ioo`03001oogoo05]oo`<0031oo`00;goo0P00GWoo00<007ooOol0Fgoo0P0000=l07ooOol0;Woo
000_Ool3001MOol00`00Oomoo`1JOol3000aOol0031oo`8005eoo`8005]oo`80039oo`00<7oo0`00
G7oo00<007ooOol0FGoo0`00<Woo000aOol3001KOol00`00Oomoo`1IOol2000cOol0039oo`80059o
o`<000Ioo`03001oogoo05Qoo`<003=oo`00<Woo0`00E7oo00<007ooOol00goo00<007ooOol0Egoo
0`00=7oo000cOol2001;Ool50004Ool00`00Oomoo`03Ool3001GOol2000eOol003=oo`<0051oo`<0
00Ioo`03001oogoo05Ioo`<003Eoo`00<7oo00Al07ooOomoo`<004moo`03001oogoo00Ioo`03001o
ogoo05Ioo`8000Aoo`03O01oogoo02moo`00<7oo00=l07ooOol00Woo0P00Cgoo10001Goo00<007oo
Ool0EGoo0`0017oo00=l07ooOol0;goo000aOol017`0Oomoogoo0`00Egoo00<007ooOol0EGoo0P00
17oo00=l07ooOol0<7oo000bOol017`0Oomoogoo0P0000=l07ooOol0E7oo00<007ooOol0E7oo0`00
0goo00=l07ooOol0<Goo000cOol00g`0Oomoo`03001FOol2001DOol30003Ool00g`0Oomoo`0bOol0
03Aoo`03O01oogoo00<005Eoo`03001oogoo05=oo`8000=oo`03O01oogoo03=oo`00=Goo00=l07oo
Ool00P00EGoo00<007ooOol0DWoo0`000Woo00=l07ooOol0=7oo000eOol00g`0Oomoo`03001DOol0
0`00Oomoo`1BOol20002Ool00g`0Oomoo`0eOol003Ioo`03O01oogoo008005Aoo`03001oogoo055o
o`<00003Ooml07oo03Moo`00=goo00=l07oo00000P00Dgoo0P00DGoo0`0000=oog`0Ool0>7oo000h
Ool00g`0Ool00002001BOol00`00Oomoo`1@Ool20002O00jOol003Uoo`03O01oo`000080055oo`03
001oogoo04moo`<00003O01oogoo03Uoo`00>Woo00Al07oo0000055oo`03001oogoo04ioo`<00003
O01oogoo03Yoo`00>goo00Al00000000051oo`03001oogoo04eoo`<0009l03aoo`00?7oo00Al0000
000004moo`8004ioo`80009l03eoo`00?Goo00Al0000000004ioo`03001oogoo04aoo`<00003O01o
ogoo03aoo`00?Woo00=l00000000CWoo00<007ooOol0Bgoo0`0000=l07ooOol0?Goo000nOol017`0
00000000CGoo00<007ooOol0Bgoo0P000W`0?goo000oOol017`000000000C7oo00<007ooOol0BWoo
0`0000=oog`0Ool0?Woo000oOol00g`0Ool00002001;Ool2001:Ool300000gooO01oo`0oOol0041o
o`04O01oo`00001;Ool00`00Oomoo`19Ool200000g`0Ooml0010Ool0041oo`03O01oo`00008004Yo
o`03001oogoo04Qoo`<00003Ooml07oo041oo`00@Goo00=l07oo00000P00BGoo00<007ooOol0Agoo
0`0000=oog`0Ool0@Goo0011Ool00g`0Oomoo`03000cOol40003Ool20003Ool30006Ool00`00Oomo
o`16Ool30002Ool00g`0Oomoo`10Ool0045oo`04O01oogooOol2000dOol00`00Oomoo`03Ool20006
Ool00`00Oomoo`03Ool00`00Oomoo`15Ool30002Ool00g`0Oomoo`11Ool0049oo`03O01oogoo00<0
02aoo`D000=oo`03001oogoo00Yoo`03001oogoo00=oo`<004Eoo`8000=oo`03O01oogoo045oo`00
@Woo00Al07ooOomoo`<003Aoo`03001oogoo00Ioo`<000Ioo`03001oogoo04Aoo`<0009oo`03O01o
ogoo049oo`00@goo00Al07ooOomoo`80035oo`04001oogoo0008Ool00`00Oomoo`06Ool00`00Oomo
o`13Ool30003Ool00g`
0Oomoo`12Ool004Aoo`03O01oogoo00<0035oo`8000Uoo`@000Eoo`03001o
ogoo049oo`<000=oo`03O01oogoo04=oo`00A7oo00Al07ooOomoo`<004Aoo`03001oogoo045oo`<0
0005O01oogooOoml0015Ool004Eoo`04O01oogooOol30013Ool20012Ool200001G`0OomoogooO000
AWoo0015Ool00g`0Oomoo`02Ool20013Ool00`00Oomoo`10Ool30004Ool00g`0Oomoo`14Ool004Ao
o`=l00=oo`<0049oo`03001oogoo03moo`<000Aoo`=l04Eoo`00AWoo0W`00goo0`00@Goo00<007oo
Ool0?Woo0`0000Al07ooOomoo`9l04Moo`00Agoo0W`00goo0`00@7oo00<007ooOol0?Goo0`0000Al
07ooOomoo`9l04Qoo`00B7oo0W`00goo0`00?goo0P00?Goo0`0000Al07ooOomoo`9l04Uoo`00B7oo
00Il07ooO01l07ooO00200000g`0Oomoo`0lOol00`00Oomoo`0kOol300001gooO01oogooO01oog`0
04Uoo`00BGoo00El07ooOoml07oo00<00003O01oogoo03]oo`03001oogoo03Yoo`<00007Ooml07oo
Ooml07ooO000BWoo001:Ool00g`0Oomoo`02O00300000g`0Oomoo`0jOol00`00Oomoo`0iOol30002
Ool3O0000gooO01oo`1:Ool004Yoo`04O01oogooOol2O00300000g`0Oomoo`0iOol00`00Oomoo`0h
Ool30002Ool2O003Ool00g`0Oomoo`19Ool000Uoo`<003moo`04O00000000002O004000jOol2000h
Ool30002Ool2O0001Goo000007`00000@Goo0`001goo000:Ool00`00Oomoo`10Ool01@00Oomoogoo
O0001000>Goo00<007ooOol0=Woo0`000Woo00=l07ooOol00Woo00<007ooOol0@Woo00<007ooOol0
1Woo0002Ool500000goo00000002000jOol50003Ool00`00Oomoo`03O003000hOol00`00Oomoo`0e
Ool3000017ooO01l07`01Goo00<007ooOol0?goo10001goo0008Ool00`00Ool00014Ool01P00Oomo
og`0Ooml00<003Moo`03001oogoo03Aoo`<00004Ooml07ooO007Ool00`00Oomoo`0nOol00`00Ool0
0008Ool000Qoo`03001oo`00045oo`04001oogoo0003Ool00g`0Ooml0003000fOol00`00Oomoo`0c
Ool30002O0000gooO01oo`04Ool01000Oomoo`00@7oo00<007oo000027oo0009Ool20012Ool20005
Ool00g`0Oomoo`03000eOol00`00Oomoo`0bOol3000017`0Oomoog`01goo0P00@Woo0P0027oo001D
Ool017`0Oomoogoo0`00=7oo0P00<Woo0`0000El07ooOomoog`005Eoo`00EGoo00Al07ooOomoo`<0
03=oo`03001oogoo031oo`<000Aoo`03O01oogoo05Aoo`00EWoo00Al07ooOomoo`@0035oo`03001o
ogoo02ioo`@000Aoo`03O01oogoo05Eoo`00EWoo00=l07ooOol00Woo1000<7oo00<007ooOol0;Goo
100017oo00=l07ooOol0EWoo001GOol00g`0Oomoo`02Ool017`000000000;goo00<007ooOol0;7oo
0`0000=l07ooOol00goo00=l07ooOol0EWoo001G00000g`00000000300000g`00000001P0002O004
00000g`00000001F0001Ool000Moo`03001oogoo00ioo`03001oogoo00ioo`03001oogoo00ioo`03
001oogoo00ioo`03001oogoo00Yoo`07O01oogooOol007ooO0000`002goo00<007ooOol03Woo00<0
07ooOol03Woo00<007ooOol03Woo00<007ooOol03Woo00<007ooOol027oo0`000W`000Eoo`00Oomo
og`000eoo`03001oogoo00ioo`03001oogoo00ioo`03001oogoo00ioo`03001oogoo00ioo`03001o
ogoo00Ioo`001goo00<007ooOol0@Goo00<007ooOol02goo00=l07ooOol00goo00Al0000000002ao
o`03001oogoo02Uoo`<0009l00Aoo`03O01oogoo00aoo`03001oogoo045oo`03001oogoo00Ioo`00
FWoo00=l07ooOol00goo00Al0000000002]oo`03001oogoo02Qoo`<00003Ooml07oo00Aoo`03O01o
ogoo05Uoo`00FWoo00=l07ooOol017oo00Al0000000002Yoo`03001oogoo02Ioo`@00003Ooml07oo
00Aoo`03O01oogoo05Yoo`00F7oo17`01Woo00=l000000000P00:7oo0P009Woo100000=oog`0Ool0
17oo00=l07ooOol00W`0FGoo001KOol3O005Ool00g`000000002000WOol00`00Oomoo`0TOol30002
Ool00g`0Oomoo`04Ool3O01KOol005eoo`Al00=oo`03O01oo`00008002Ioo`03001oogoo029oo`@0
00=oo`04O01oogooOol3O01NOol005eoo`04O01oogooOol3O0000gooO01oo`04000TOol00`00Oomo
o`0QOol40003Ool00g`0Ooml0002O002Ool00g`0Oomoo`1LOol005ioo`03O01oogoo00=oo`=l0003
Ool00000008002=oo`03001oogoo021oo`<000Aoo`=l00Aoo`03O01oogoo05eoo`00GWoo00=l07oo
Ool01Goo0g`000Eoo`00000007`0025oo`03001oogoo01moo`<0009oo`=l00Moo`03O01oogoo05eo
o`00Ggoo00=l07ooOol01Goo00Al07ooO01l00@0021oo`8001ioo`@00005Ooml07`0Ooml0007Ool0
0g`0Oomoo`1NOol006Qoo`04O01oogooOol5000NOol00`00Oomoo`0KOol50002O002Ool00g`0Oomo
o`1WOol006Qoo`03O01oogoo00=oo`H001]oo`03001oogoo01Uoo`D00003O01oogoo009oo`03O01o
ogoo06Qoo`00JGoo00=l07ooOol017oo1P006Goo00<007ooOol05goo1@001Woo00=l07ooOol0JGoo
001ZOol00g`0Oomoo`06Ool5000GOol00`00Oomoo`0EOol50007Ool00g`0Oomoo`1ZOol006]oo`03
O01oogoo00Ioo`03O000000000<00003O01oogoo019oo`8001Aoo`D00003O01oogoo00Ioo`03O01o
ogoo06Yoo`00K7oo00=l07ooOol01Woo00=l07oo0000100000=l07ooOol047oo00<007ooOol047oo
1P0000=oog`0Ool01goo00=l07ooOol0Jgoo001]Ool00g`0Oomoo`06Ool00g`0Oomoo`050002O00?
Ool00`00Oomoo`0<Ool80002Ool00g`0Oomoo`06Ool00g`0Oomoo`1/Ool006ioo`03O01oogoo00Io
o`9l009oo`L000eoo`03001oogoo00Yoo`L000=oo`9l00Qoo`03O01oogoo06eoo`00Kgoo00=l07oo
Ool01goo00Al07ooOomoo`X000Qoo`03001oogoo00Ioo`L000Ioo`03O01oogoo0
0Moo`03O01oogoo
06ioo`00KGoo57`070005G`0KWoo001aOol00g`0Oomoo`08Ool00g`0Oomoo`07OolC00000g`0Oomo
o`06Ool00g`0Oomoo`08Ool00g`0Oomoo`1`Ool0079oo`03O01oogoo00Qoo`9l00Yoo`=l00=oo`03
001oogoo009oo`=l00Uoo`9l00Yoo`03O01oogoo075oo`00Lgoo00=l07ooOol017oo100000=oog`0
Ool00P000goo0`000goo0W`000=oo`00Ool00g`02goo00=l07ooOol02Goo00=l07ooOol0LWoo001d
Ool00g`0Oomoo`04Ool00`00Oomoo`02Ool2O0000`00Oomoo`04Ool00`00Oomoo`02Ool3O00=Ool0
0g`0Oomoo`09Ool00g`0Oomoo`1cOol007aoo`03001oogoo00=oo`03O01oogoo00Aoo`03001oogoo
00=l008000=l00Uoo`03O01oogoo081oo`00OGoo00<007ooOol00goo0W`000Aoo`00000000=l00=o
o`03001oogoo009oo`=l00Aoo`9l08=oo`00NWoo00@007ooOol000Moo`Al00Ioo`03001oogoo00Eo
o`Al08Eoo`00Ngoo0P001Woo17`00`001Goo00<007ooOol01Woo1G`0Pgoo0021Ool2O004Ool00g`0
Oomoo`05Ool00`00Oomoo`05Ool00g`0Oomoo`03Ool00g`0Oomoo`20Ool008Qoo`03O01oogoo00Ao
o`03001oogoo00Aoo`03O01oogoo08Moo`00Sgoo0P00Sgoo002?Ool00`00Oomoo`2>Ool008moo`03
001oogoo08ioo`00Sgoo00<007ooOol0SWoo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-4.2104, -13.3991,
  0.0293408, 0.0947118}}],

Cell[BoxData[
    FormBox[
      TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
        False,
        Editable->False], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ShowTangentLines[\(-x\^2\)\  + 2, {x, \(-3\), 3}, 5]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.497786 0.0371593 [
[.02381 .48529 -6 -9 ]
[.02381 .48529 6 0 ]
[.2619 .48529 -6 -9 ]
[.2619 .48529 6 0 ]
[.7381 .48529 -3 -9 ]
[.7381 .48529 3 0 ]
[.97619 .48529 -3 -9 ]
[.97619 .48529 3 0 ]
[.4875 .03329 -30 -4.5 ]
[.4875 .03329 0 4.5 ]
[.4875 .12619 -18 -4.5 ]
[.4875 .12619 0 4.5 ]
[.4875 .21909 -24 -4.5 ]
[.4875 .21909 0 4.5 ]
[.4875 .31199 -12 -4.5 ]
[.4875 .31199 0 4.5 ]
[.4875 .40489 -24 -4.5 ]
[.4875 .40489 0 4.5 ]
[.4875 .59068 -18 -4.5 ]
[.4875 .59068 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .49779 m
.02381 .50404 L
s
[(-4)] .02381 .48529 0 1 Mshowa
.2619 .49779 m
.2619 .50404 L
s
[(-2)] .2619 .48529 0 1 Mshowa
.7381 .49779 m
.7381 .50404 L
s
[(2)] .7381 .48529 0 1 Mshowa
.97619 .49779 m
.97619 .50404 L
s
[(4)] .97619 .48529 0 1 Mshowa
.125 Mabswid
.08333 .49779 m
.08333 .50154 L
s
.14286 .49779 m
.14286 .50154 L
s
.20238 .49779 m
.20238 .50154 L
s
.32143 .49779 m
.32143 .50154 L
s
.38095 .49779 m
.38095 .50154 L
s
.44048 .49779 m
.44048 .50154 L
s
.55952 .49779 m
.55952 .50154 L
s
.61905 .49779 m
.61905 .50154 L
s
.67857 .49779 m
.67857 .50154 L
s
.79762 .49779 m
.79762 .50154 L
s
.85714 .49779 m
.85714 .50154 L
s
.91667 .49779 m
.91667 .50154 L
s
.25 Mabswid
0 .49779 m
1 .49779 L
s
.5 .03329 m
.50625 .03329 L
s
[(-12.5)] .4875 .03329 1 0 Mshowa
.5 .12619 m
.50625 .12619 L
s
[(-10)] .4875 .12619 1 0 Mshowa
.5 .21909 m
.50625 .21909 L
s
[(-7.5)] .4875 .21909 1 0 Mshowa
.5 .31199 m
.50625 .31199 L
s
[(-5)] .4875 .31199 1 0 Mshowa
.5 .40489 m
.50625 .40489 L
s
[(-2.5)] .4875 .40489 1 0 Mshowa
.5 .59068 m
.50625 .59068 L
s
[(2.5)] .4875 .59068 1 0 Mshowa
.125 Mabswid
.5 .05187 m
.50375 .05187 L
s
.5 .07045 m
.50375 .07045 L
s
.5 .08903 m
.50375 .08903 L
s
.5 .10761 m
.50375 .10761 L
s
.5 .14477 m
.50375 .14477 L
s
.5 .16335 m
.50375 .16335 L
s
.5 .18193 m
.50375 .18193 L
s
.5 .20051 m
.50375 .20051 L
s
.5 .23767 m
.50375 .23767 L
s
.5 .25625 m
.50375 .25625 L
s
.5 .27483 m
.50375 .27483 L
s
.5 .29341 m
.50375 .29341 L
s
.5 .33057 m
.50375 .33057 L
s
.5 .34915 m
.50375 .34915 L
s
.5 .36773 m
.50375 .36773 L
s
.5 .38631 m
.50375 .38631 L
s
.5 .42347 m
.50375 .42347 L
s
.5 .44205 m
.50375 .44205 L
s
.5 .46063 m
.50375 .46063 L
s
.5 .47921 m
.50375 .47921 L
s
.5 .51637 m
.50375 .51637 L
s
.5 .53495 m
.50375 .53495 L
s
.5 .55353 m
.50375 .55353 L
s
.5 .57211 m
.50375 .57211 L
s
.5 .01472 m
.50375 .01472 L
s
.5 .60926 m
.50375 .60926 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.02381 .01472 m
.03347 .0328 L
.044 .05253 L
.0539 .07106 L
.06341 .08888 L
.07354 .10784 L
.08328 .1261 L
.09365 .14551 L
.10363 .1642 L
.11323 .18219 L
.12345 .20132 L
.13329 .21975 L
.14275 .23746 L
.15282 .25632 L
.16251 .27448 L
.17282 .29378 L
.18274 .31237 L
.19229 .33025 L
.20245 .34928 L
.21224 .3676 L
.22263 .38707 L
.23265 .40583 L
.24229 .42388 L
.25254 .44308 L
.2619 .46063 L
s
.16667 .31794 m
.17633 .32879 L
.18686 .34063 L
.19675 .35174 L
.20627 .36243 L
.21639 .37381 L
.22614 .38477 L
.2365 .39641 L
.24649 .40763 L
.25609 .41842 L
.26631 .4299 L
.27614 .44095 L
.2856 .45158 L
.29567 .4629 L
.30537 .47379 L
.31567 .48537 L
.3256 .49653 L
.33515 .50726 L
.34531 .51868 L
.35509 .52967 L
.36549 .54135 L
.3755 .55261 L
.38514 .56344 L
.39539 .57495 L
.40476 .58548 L
s
.30952 .51414 m
.31918 .51775 L
.32972 .5217 L
.33961 .52541 L
.34912 .52897 L
.35925 .53276 L
.369 .53641 L
.37936 .54029 L
.38934 .54403 L
.39895 .54763 L
.40916 .55146 L
.419 .55514 L
.42846 .55869 L
.43853 .56246 L
.44822 .56609 L
.45853 .56995 L
.46846 .57367 L
.47801 .57724 L
.48817 .58105 L
.49795 .58471 L
.50834 .58861 L
.51836 .59236 L
.528 .59597 L
.53825 .59981 L
.54762 .60332 L
s
.45238 .60332 m
.46204 .5997 L
.47257 .59576 L
.48247 .59205 L
.49198 .58849 L
.50211 .58469 L
.51186 .58104 L
.52222 .57716 L
.5322 .57342 L
.5418 .56982 L
.55202 .566 L
.56186 .56231 L
.57132 .55877 L
.58139 .555 L
.59108 .55137 L
.60139 .54751 L
.61131 .54379 L
.62086 .54021 L
.63102 .53641 L
.64081 .53274 L
.6512 .52885 L
.66122 .5251 L
.67086 .52149 L
.68111 .51765 L
.69048 .51414 L
s
.59524 .58548 m
.6049 .57463 L
.61543 .56279 L
.62532 .55168 L
.63484 .54098 L
.64496 .5296 L
.65471 .51865 L
.66507 .50701 L
.67506 .49579 L
.68466 .485 L
.69488 .47352 L
.70471 .46246 L
.71417 .45183 L
.72425 .44052 L
.73394 .42963 L
.74424 .41804 L
.75417 .40689 L
.76372 .39616 L
.77388 .38474 L
.78366 .37375 L
.79406 .36207 L
.80408 .35081 L
.81371 .33998 L
.82396 .32846 L
.83333 .31794 L
s
.7381 .46063 m
.74775 .44254 L
.75829 .42281 L
.76818 .40428 L
.77769 .38646 L
.78782 .3675 L
.79757 .34924 L
.80793 .32984 L
.81791 .31114 L
.82752 .29315 L
.83773 .27402 L
.84757 .2556 L
.85703 .23788 L
.8671 .21902 L
.8768 .20086 L
.8871 .18156 L
.89703 .16297 L
.90658 .14509 L
.91674 .12606 L
.92652 .10774 L
.93692 .08827 L
.94693 .06951 L
.95657 .05146 L
.96682 .03226 L
.97619 .01472 L
s
0 g
.007 w
.14286 .23767 m
.17183 .28974 L
.20343 .3415 L
.23311 .38535 L
.26166 .42316 L
.29204 .45871 L
.32128 .48836 L
.35237 .51496 L
.38231 .53579 L
.41112 .55139 L
.42571 .55763 L
.44177 .56322 L
.45701 .56726 L
.46384 .56868 L
.47129 .56994 L
.47532 .57051 L
.47907 .57096 L
.48295 .57134 L
.48647 .57163 L
.48994 .57184 L
.49152 .57192 L
.4932 .57198 L
.49499 .57204 L
.49579 .57206 L
.49664 .57208 L
.49756 .57209 L
.49842 .5721 L
.49894 .5721 L
.49944 .5721 L
.50037 .5721 L
.50122 .5721 L
.50214 .57209 L
.50301 .57208 L
.50381 .57207 L
.50566 .57202 L
.50761 .57195 L
.50951 .57187 L
.51128 .57177 L
.5153 .57149 L
.52198 .57084 L
.52911 .56988 L
.5368 .56856 L
.54512 .56677 L
.56024 .56259 L
.57514 .5573 L
.59093 .55043 L
.61934 .53476 L
.6496 .51343 L
.67871 .48836 L
.70967 .45684 L
Mistroke
.73949 .42172 L
.76818 .38354 L
.7987 .33817 L
.82809 .28988 L
.85714 .23767 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00OSgoo00<007ooOol0
SWoo002?Ool00`00Oomoo`2>Ool008moo`03001oogoo08ioo`00Sgoo00<007ooOol0SWoo0007Ool0
0g`0Oomoo`25Ool20026Ool00g`0Oomoo`06Ool000Moo`03O01oogoo08Eoo`03001oogoo08Eoo`03
O01oogoo00Ioo`0027oo00=l07ooOol0Q7oo00<007ooOol0Q7oo00=l07ooOol01goo0008Ool00g`0
Oomoo`1YOol30003Ool40003Ool20003Ool30006Ool00`00Oomoo`24Ool00g`0Oomoo`07Ool000Qo
o`03O01oogoo06Yoo`03001oo
goo00=oo`03001oogoo00=oo`8000Ioo`03001oogoo00=oo`03001o
ogoo08Aoo`03O01oogoo00Moo`002Goo00=l07ooOol0HWoo1@000Woo00<007ooOol017oo00<007oo
Ool02Woo00<007ooOol00goo0`00Pgoo00=l07ooOol027oo0009Ool00g`0Oomoo`1YOol00`00Oomo
o`05Ool00`00Oomoo`06Ool30006Ool00`00Oomoo`23Ool00g`0Oomoo`08Ool000Yoo`03O01oogoo
06Qoo`03001oogoo009oo`04001oogoo0008Ool00`00Oomoo`06Ool00`00Oomoo`22Ool00g`0Oomo
o`09Ool000Yoo`03O01oogoo06Moo`8000Eoo`8000Uoo`@000Eoo`03001oogoo085oo`03O01oogoo
00Yoo`002goo00=l07ooOol0PGoo00<007ooOol0PGoo00=l07ooOol02Woo000;Ool00g`0Oomoo`21
Ool20021Ool00g`0Oomoo`0;Ool000aoo`03O01oogoo081oo`03001oogoo081oo`03O01oogoo00]o
o`0037oo00=l07ooOol0P7oo00<007ooOol0Ogoo00=l07ooOol037oo000=Ool00g`0Oomoo`1oOol0
0`00Oomoo`1nOol00g`0Oomoo`0=Ool000ioo`03O01oogoo07ioo`03001oogoo07ioo`03O01oogoo
00eoo`003Woo00=l07ooOol0OWoo00<007ooOol0OGoo00=l07ooOol03Woo000?Ool00g`0Oomoo`1m
Ool2001nOol00g`0Oomoo`0>Ool000moo`03O01oogoo07eoo`03001oogoo07aoo`03O01oogoo00mo
o`0047oo00=l07ooOol0O7oo00<007ooOol0O7oo00=l07ooOol03goo000AOol00g`0Oomoo`1kOol0
0`00Oomoo`1kOol00g`0Oomoo`0@Ool0015oo`03O01oogoo07]oo`03001oogoo07]oo`03O01oogoo
011oo`004Woo00=l07ooOol0NWoo0P00Ngoo00=l07ooOol04Goo000BOol00g`0Oomoo`1jOol00`00
Oomoo`1jOol00g`0Oomoo`0AOol001=oo`03O01oogoo07Uoo`03001oogoo07Uoo`03O01oogoo019o
o`0057oo00=l07ooOol0N7oo00<007ooOol0N7oo00=l07ooOol04goo000DOol00g`0Oomoo`1hOol0
0`00Oomoo`1hOol00g`0Oomoo`0COol001Eoo`03O01oogoo07Moo`8007Qoo`03O01oogoo01Aoo`00
5Goo00=l07ooOol0Mgoo00<007ooOol0Mgoo00=l07ooOol057oo000FOol00g`0Oomoo`1fOol00`00
Oomoo`1fOol00g`0Oomoo`0EOol001Ioo`03O01oogoo07Ioo`03001oogoo07Ioo`03O01oogoo01Eo
o`005goo00=l07ooOol0IWoo0`0017oo0P001Woo00<007ooOol0MGoo00=l07ooOol05Woo000GOol0
0g`0Oomoo`1WOol00`00Oomoo`02Ool01000Oomoo`001Goo00<007ooOol0MGoo00=l07ooOol05Woo
000HOol00g`0Oomoo`1OOol50002Ool00`00Oomoo`02Ool01000Oomoo`001Goo0`00M7oo00=l07oo
Ool05goo000HOol00g`0Oomoo`1VOol00`00Oomoo`02Ool01000Oomoo`001Goo00<007ooOol0M7oo
00=l07ooOol05goo000IOol00g`0Oomoo`1UOol00`00Oomoo`02Ool01000Oomoo`001Goo00<007oo
Ool0Lgoo00=l07ooOol067oo000JOol00g`0Oomoo`1SOol20005Ool20006Ool00`00Oomoo`1bOol0
0g`0Oomoo`0IOol001Yoo`03O01oogoo079oo`03001oogoo079oo`03O01oogoo01Uoo`006goo00=l
07ooOol0LGoo0P00LWoo00=l07ooOol06Woo000KOol00g`0Oomoo`1aOol00`00Oomoo`1aOol00g`0
Oomoo`0JOol001aoo`03O01oogoo071oo`03001oogoo071oo`03O01oogoo01]oo`0077oo00=l07oo
Ool0L7oo00<007ooOol0L7oo00=l07ooOol06goo000MOol00g`0Oomoo`1_Ool00`00Oomoo`1`Ool0
0g`0Oomoo`0KOol001eoo`03O01oogoo06moo`80071oo`03O01oogoo01aoo`007Woo00=l07ooOol0
KWoo00<007ooOol0Kgoo00=l07ooOol077oo000NOol00g`0Oomoo`1^Ool00`00Oomoo`1^Ool00g`0
Oomoo`0MOol001moo`03O01oogoo06eoo`03001oogoo06ioo`03O01oogoo01eoo`007goo00=l07oo
Ool0KGoo00<007ooOol0KGoo00=l07ooOol07Woo000OOol00g`0Oomoo`1]Ool00`00Oomoo`1]Ool0
0g`0Oomoo`0NOol0021oo`03O01oogoo06aoo`8006eoo`03O01oogoo01moo`0087oo00=l07ooOol0
K7oo00<007ooOol0K7oo00=l07ooOol07goo000QOol00g`0Oomoo`1[Ool00`00Oomoo`1[Ool00g`0
Oomoo`0POol0029oo`03O01oogoo06Yoo`03001oogoo06Yoo`03O01oogoo025oo`008Woo00=l07oo
Ool0JWoo00<007ooOol0JWoo00=l07ooOol08Goo000SOol00g`0Oomoo`1YOol2001ZOol00g`0Oomo
o`0ROol002=oo`03O01oogoo06Uoo`03001oogoo06Uoo`03O01oogoo029oo`0097oo00=l07ooOol0
J7oo00<007ooOol0J7oo00=l07ooOol08goo000UOol00g`0Oomoo`1COol00`00Oomoo`03Ool20003
Ool30006Ool00`00Oomoo`1WOol00g`0Oomoo`0TOol002Eoo`03O01oogoo05=oo`03001oogoo00=o
o`8000Ioo`03001oogoo00=oo`03001oogoo06Moo`03O01oogoo02Aoo`009Woo00=l07ooOol0Bgoo
1@000goo00<007ooOol02Woo00<007ooOol00goo0`00IWoo00=l07ooOol09Goo000VOol00g`0Oomo
o`1COol00`00Oomoo`07Ool30006Ool00`00Oomoo`1VOol00g`0Oomoo`0UOol002Moo`03O01oogoo
05=oo`03001oogoo00Ioo`03001oogoo00Ioo`03001oogoo06Eoo`03O01oogoo02Ioo`009goo00=l
07ooOol0D7oo100027oo10001Goo00<007ooOol0IGoo00=l07ooOol09Woo000XOol00g`0Oomoo`1T
Ool00`00Oomoo`1TOol00g`0Oomoo`0WOol002Qoo`03O01oogoo06Aoo`03001oogoo06Aoo`03O01o
ogoo02Moo`00:7oo0P00IGoo0P00Hgoo0P00:Woo000XOol2001UOol00`00Oomoo`1ROol2000ZOol0
02Qoo`<006Aoo`03001oogoo065oo`<002Yoo`00:Goo0P0000=l07ooOol0HGoo00<007ooOol0HGoo
0P00:goo000YOol3001SOol00`00Oomoo`1POol3000[Ool002Yoo`800003O01oogoo061oo`80065o
o`8002aoo`00:Woo0`00HWoo00<007ooOol0Ggoo0`00;7oo000[Ool200000g`0Oomoo`1
OOol00`00
Oomoo`1OOol2000]Ool002]oo`<0065oo`03001oogoo05ioo`<002eoo`00;7oo0`00H7oo00<007oo
Ool0GGoo0`00;Woo000]Ool2001POol2001NOol2000_Ool002eoo`<005moo`03001oogoo05aoo`<0
02moo`00;Woo0P00Ggoo00<007ooOol0G7oo0P00<7oo000^Ool3001NOol00`00Oomoo`1KOol3000`
Ool002moo`8005ioo`03001oogoo05]oo`80035oo`00;goo0`00GGoo00<007ooOol0FWoo0`00<Goo
000`Ool2001MOol2001KOol2000bOol0031oo`<005aoo`03001oogoo05Uoo`<0039oo`00<Goo0`00
Fgoo00<007ooOol0F7oo0`00<goo000bOol2001BOol30006Ool00`00Oomoo`1HOol2000dOol0039o
o`<005Aoo`03001oogoo00=oo`03001oogoo05Moo`<003Aoo`00<goo0`00BWoo1@0017oo00<007oo
Ool00goo0`00Egoo0P00=Goo000dOol2001@Ool30006Ool00`00Oomoo`1FOol3000eOol0031oo`04
O01oogooOol3001?Ool00`00Oomoo`06Ool00`00Oomoo`1EOol30004Ool00g`0Oomoo`0_Ool0031o
o`03O01oogoo009oo`8004moo`@000Eoo`03001oogoo05Eoo`8000Eoo`03O01oogoo02moo`00<Goo
00Al07ooOomoo`<005Moo`03001oogoo05Aoo`<000Aoo`03O01oogoo031oo`00<Woo00Al07ooOomo
o`<005Ioo`8005Eoo`8000Aoo`03O01oogoo035oo`00<goo00Al07ooOomoo`8005Ioo`03001oogoo
05=oo`<000=oo`03O01oogoo039oo`00=7oo00=l07ooOol00`00EGoo00<007ooOol0DWoo0`000goo
00=l07ooOol0<goo000eOol00g`0Oomoo`03001DOol00`00Oomoo`1BOol2000017`0Oomoog`0=Woo
000fOol00g`0Oomoo`02001DOol00`00Oomoo`1AOol30002Ool00g`0Oomoo`0eOol003Moo`03O01o
o`00008005=oo`03001oogoo051oo`<00003O01oog`003Qoo`00>7oo00=l07oo00000P00DWoo0P00
DGoo0P0000=l07ooO000>Goo000iOol2O002001BOol00`00Oomoo`1?Ool30002O00jOol003Yoo`04
O0000000001AOol00`00Oomoo`1>Ool30002O00kOol003]oo`04O0000000001@Ool00`00Oomoo`1=
Ool30002O00lOol003]oo`9l00<004moo`03001oogoo04eoo`800003Ooml07`003aoo`00?7oo0W`0
0P00Cgoo0P00CGoo0`000W`0?Goo000mOol017`000000000CWoo00<007ooOol0Bgoo0`0000=oog`0
Ool0?Goo000nOol017`000000000CGoo00<007ooOol0Bgoo0P0000=oog`0Ool0?Woo000oOol00g`0
0000001=Ool00`00Oomoo`1:Ool30002O00oOol003moo`04O0000000001<Ool00`00Oomoo`19Ool3
00000g`0Ooml000oOol0041oo`04O0000000001;Ool2001:Ool200000g`0Ooml0010Ool0041oo`04
O01oo`00001;Ool00`00Oomoo`18Ool300000g`0Ooml0010Ool0045oo`04O0000000001:Ool00`00
Oomoo`17Ool300000g`0Ooml0011Ool0045oo`03O01oo`00008003Aoo`@000=oo`8000=oo`<000Io
o`03001oogoo04Ioo`<00003O01oog`0049oo`00@Goo00=l07ooOol00`00=7oo00<007ooOol00goo
0P001Woo00<007ooOol00goo00<007ooOol0AWoo0P0000Al07ooOoml049oo`00@Woo00=l07ooOol0
0P00;Goo1@000goo00<007ooOol02Woo00<007ooOol00goo0`00AGoo0`000Woo00=l07ooOol0@Goo
0012Ool00g`0Oomoo`03000eOol00`00Oomoo`06Ool30006Ool00`00Oomoo`14Ool30003Ool00g`0
Oomoo`11Ool0049oo`04O01oogooOol3000aOol01000Oomoo`0027oo00<007ooOol01Woo00<007oo
Ool0A7oo0P000goo00=l07ooOol0@Woo0013Ool017`0Oomoogoo0P00<Woo0P002Goo10001Goo00<0
07ooOol0@goo0`000goo00=l07ooOol0@Woo0014Ool00g`0Oomoo`030015Ool00`00Oomoo`12Ool3
0003Ool00g`0Oomoo`13Ool004Aoo`04O01oogooOol30014Ool00`00Oomoo`11Ool30004Ool00g`0
Oomoo`13Ool004Eoo`04O01oogooOol30013Ool20012Ool20004Ool00g`0Oomoo`14Ool004Eoo`03
O01oogoo009oo`8004=oo`03001oogoo041oo`<000Aoo`03O01oogoo04Aoo`00AWoo00Al07ooOomo
o`<0049oo`03001oogoo03moo`<000Aoo`03O01oogoo04Eoo`00Agoo00Al07ooOomoo`<0045oo`03
001oogoo03ioo`<000Aoo`03O01oogoo04Ioo`00Agoo00=l07ooOol00Woo0`00@7oo00<007ooOol0
?Goo0`001Goo00=l07ooOol0AWoo0018Ool00g`0Oomoo`02Ool3000oOol2000mOol30005Ool00g`0
Oomoo`17Ool004Qoo`03O01oogoo00=oo`800003O01oogoo03aoo`03001oogoo03]oo`<000Ioo`03
O01oogoo04Moo`00BGoo00=l07ooOol00Woo0`0000=l07ooOol0>goo00<007ooOol0>Woo0`001Woo
00=l07ooOol0B7oo001:Ool00g`0Oomoo`02Ool300000g`0Oomoo`0jOol00`00Oomoo`0iOol30006
Ool00g`0Oomoo`19Ool004Yoo`03O01oogoo00=oo`<00003O01oogoo03Uoo`03001oogoo03Qoo`<0
00Moo`03O01oogoo04Uoo`002Goo0`00?goo00=l000000000P0000=oo`0000000P00>Woo0P00>7oo
0`001Goo0P0000=l0000Ool0@7oo0`001goo000:Ool00`00Oomoo`10Ool00`00Oomoo`02Ool4000i
Ool00`00Oomoo`0fOol30007Ool00`00Oomoo`12Ool00`00Oomoo`06Ool0009oo`D00003Ool00000
008003Yoo`D000=oo`03001oogoo00=oo`<003Qoo`03001oogoo03Eoo`<000Uoo`03001oogoo03mo
o`@000Moo`0027oo00<007oo0000A7oo00<007ooOol00goo0`00=goo00<007ooOol0=7oo0`002goo
00<007ooOol0?Woo00<007oo000027oo0008Ool00`00Ool00011Ool01000Oomoo`001Woo0`00=Woo
00<007ooOol0<goo0`002Goo00@007ooOol0041oo`03001oo`0000Qoo`002Goo0P00@Woo0P0027oo
0`00=Goo00<007ooOol0<Woo0`002goo0P00@Woo0P0027oo001HOol3000dOol2000bOol3001JOol0
05Uoo`<003=oo`03001oogoo031oo`<005]o
o`00FWoo1000<Goo00<007ooOol0;goo0`0000=l07oo
Ool0FGoo001KOol4000`Ool00`00Oomoo`0^Ool300000g`0Oomoo`1JOol005aoo`04O0000000000_
Ool00`00Oomoo`0]Ool300000g`0Oomoo`1KOol005d00003O000000006400003O000000005/0005o
o`001goo00<007ooOol03Woo00<007ooOol03Woo00<007ooOol03Woo00<007ooOol03Woo00<007oo
Ool03Woo00<007ooO0000`002goo00<007ooOol03Woo00<007ooOol03Woo00<007ooOol03Woo00<0
07ooOol03Woo00<007ooOol02Goo0`0000=l07oo000047oo00<007ooOol03Woo00<007ooOol03Woo
00<007ooOol03Woo00<007ooOol03Woo00<007ooOol01Woo0007Ool00`00Oomoo`11Ool00`00Oomo
o`0AOol017`000000000;7oo00<007ooOol0:Woo0`0000=l07ooOol04Goo00<007ooOol0@Goo00<0
07ooOol01Woo001POol017`000000000:goo00<007ooOol0:Goo0`0000=l07ooOol0Ggoo001QOol0
17`000000000:Woo00<007ooOol0:7oo0`0000=l07ooOol0H7oo001HOol3O007Ool00g`000000002
000XOol2000WOol400000g`0Oomoo`06Ool2O01IOol005]oo`=l00Eoo`03O0000000008002Moo`03
001oogoo02Eoo`@00003O01oogoo00Aoo`=l05]oo`00GWoo0g`00goo00=l07oo00000P009Woo00<0
07ooOol08goo10000Woo00Al07ooOomoo`=l05ioo`00HGoo0g`000=oog`0Ool0100097oo00<007oo
Ool08Woo10000Woo00=l07ooO0000W`0HGoo001TOol3O0000goo00000002000SOol00`00Oomoo`0P
Ool40003Ool3O01TOol006Ioo`=l0004Ool00000000ROol00`00Oomoo`0OOol4000017ooO01l07`0
Igoo001WOol017`0Ooml07`0100087oo0P007Woo100000Eoog`0O01oog`006Qoo`00Igoo00=l07oo
Ool00Woo1@007Woo00<007ooOol06goo1@000W`00Woo00=l07ooOol0Igoo001XOol00g`0Oomoo`03
Ool6000KOol00`00Oomoo`0IOol500000g`0Oomoo`03Ool00g`0Oomoo`1WOol006Uoo`03O01oogoo
00Aoo`H001Uoo`03001oogoo01Moo`D000Moo`03O01oogoo06Qoo`00JWoo00=l07ooOol01Woo1@00
5goo00<007ooOol05Goo1@0027oo00=l07ooOol0JGoo001[Ool00g`0Oomoo`07Ool5000EOol2000D
Ool50009Ool00g`0Oomoo`1ZOol006aoo`03O01oogoo00Qoo`D001=oo`03001oogoo015oo`D000Yo
o`03O01oogoo06]oo`00KGoo00=l07ooOol02Goo1@004Goo00<007ooOol03Woo1P002goo00=l07oo
Ool0K7oo001^Ool00g`0Oomoo`0:Ool7000=Ool00`00Oomoo`0;Ool7000<Ool00g`0Oomoo`1]Ool0
06moo`03O01oogoo00]oo`X000Qoo`03001oogoo00Ioo`T000ioo`03O01oogoo06ioo`00L7oo00=l
07ooOol03Woo7@0047oo00=l07ooOol0Kgoo001aOol00g`0Oomoo`0BOolC00000g`0Oomoo`0AOol0
0g`0Oomoo`1`Ool0079oo`03O01oogoo01Aoo`=l00=oo`03001oogoo009oo`=l01Eoo`03O01oogoo
075oo`00Lgoo00=l07ooOol05Woo0W`000=oo`00Ool00g`05goo00=l07ooOol0LWoo001dOol00g`0
Oomoo`03Ool40003Ool20003Ool30005Ool3O00IOol00g`0Oomoo`1cOol007]oo`03001oogoo00=o
o`8000Ioo`03001oogoo00=l0003001oog`0009l08aoo`00O7oo00<007ooOol02Woo0g`00goo0`00
0Woo0g`0RGoo001mOol00`00Oomoo`06Ool3O006Ool00`00Oomoo`05Ool3O026Ool007Yoo`04001o
ogoo0005Ool3O0000`00Oomoo`06Ool00`00Oomoo`08Ool3O023Ool007]oo`8000Aoo`9l00=oo`@0
00Eoo`03001oogoo00]oo`03O01oogoo081oo`00Sgoo00<007ooOol0SWoo002?Ool2002?Ool008mo
o`03001oogoo08ioo`00Sgoo00<007ooOol0SWoo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-4.2104, -13.3961,
  0.0293408, 0.0939997}}],

Cell[BoxData[
    FormBox[
      TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
        False,
        Editable->False], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ShowTangentLines[x\^2\ Sin[x]\  - x\  + 1, {x, 0, 5  \[Pi]}]\)],
"Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0775922 0.0537826 0.326489 0.00118795 [
[.21205 .31399 -9 -9 ]
[.21205 .31399 9 0 ]
[.34651 .31399 -3 -9 ]
[.34651 .31399 3 0 ]
[.48096 .31399 -9 -9 ]
[.48096 .31399 9 0 ]
[.61542 .31399 -6 -9 ]
[.61542 .31399 6 0 ]
[.74988 .31399 -12 -9 ]
[.74988 .31399 12 0 ]
[.88433 .31399 -6 -9 ]
[.88433 .31399 6 0 ]
[.06509 .0889 -24 -4.5 ]
[.06509 .0889 0 4.5 ]
[.06509 .20769 -24 -4.5 ]
[.06509 .20769 0 4.5 ]
[.06509 .44528 -18 -4.5 ]
[.06509 .44528 0 4.5 ]
[.06509 .56408 -18 -4.5 ]
[.06509 .56408 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21205 .32649 m
.21205 .33274 L
s
[(2.5)] .21205 .31399 0 1 Mshowa
.34651 .32649 m
.34651 .33274 L
s
[(5)] .34651 .31399 0 1 Mshowa
.48096 .32649 m
.48096 .33274 L
s
[(7.5)] .48096 .31399 0 1 Mshowa
.61542 .32649 m
.61542 .33274 L
s
[(10)] .61542 .31399 0 1 Mshowa
.74988 .32649 m
.74988 .33274 L
s
[(12.5)] .74988 .31399 0 1 Mshowa
.88433 .32649 m
.88433 .33274 L
s
[(15)] .88433 .31399 0 1 Mshowa
.125 Mabswid
.10448 .32649 m
.10448 .33024 L
s
.13137 .32649 m
.13137 .33024 L
s
.15827 .32649 m
.15827 .33024 L
s
.18516 .32649 m
.18516 .33024 L
s
.23894 .32649 m
.23894 .33024 L
s
.26583 .32649 m
.26583 .33024 L
s
.29272 .32649 m
.29272 .33024 L
s
.31961 .32649 m
.31961 .33024 L
s
.3734 .32649 m
.3734 .33024 L
s
.40029 .32649 m
.40029 .33024 L
s
.42718 .32649 m
.42718 .33024 L
s
.45407 .32649 m
.45407 .33024 L
s
.50785 .32649 m
.50785 .33024 L
s
.53474 .32649 m
.53474 .33024 L
s
.56164 .32649 m
.56164 .33024 L
s
.58853 .32649 m
.58853 .33024 L
s
.64231 .32649 m
.64231 .33024 L
s
.6692 .32649 m
.6692 .33024 L
s
.69609 .32649 m
.69609 .33024 L
s
.72298 .32649 m
.72298 .33024 L
s
.77677 .32649 m
.77677 .33024 L
s
.80366 .32649 m
.80366 .33024 L
s
.83055 .32649 m
.83055 .33024 L
s
.85744 .32649 m
.85744 .33024 L
s
.0507 .32649 m
.0507 .33024 L
s
.02381 .32649 m
.02381 .33024 L
s
.91122 .32649 m
.91122 .33024 L
s
.93811 .32649 m
.93811 .33024 L
s
.96501 .32649 m
.96501 .33024 L
s
.9919 .32649 m
.9919 .33024 L
s
.25 Mabswid
0 .32649 m
1 .32649 L
s
.07759 .0889 m
.08384 .0889 L
s
[(-200)] .06509 .0889 1 0 Mshowa
.07759 .20769 m
.08384 .20769 L
s
[(-100)] .06509 .20769 1 0 Mshowa
.07759 .44528 m
.08384 .44528 L
s
[(100)] .06509 .44528 1 0 Mshowa
.07759 .56408 m
.08384 .56408 L
s
[(200)] .06509 .56408 1 0 Mshowa
.125 Mabswid
.07759 .11266 m
.08134 .11266 L
s
.07759 .13642 m
.08134 .13642 L
s
.07759 .16018 m
.08134 .16018 L
s
.07759 .18394 m
.08134 .18394 L
s
.07759 .23145 m
.08134 .23145 L
s
.07759 .25521 m
.08134 .25521 L
s
.07759 .27897 m
.08134 .27897 L
s
.07759 .30273 m
.08134 .30273 L
s
.07759 .35025 m
.08134 .35025 L
s
.07759 .37401 m
.08134 .37401 L
s
.07759 .39777 m
.08134 .39777 L
s
.07759 .42152 m
.08134 .42152 L
s
.07759 .46904 m
.08134 .46904 L
s
.07759 .4928 m
.08134 .4928 L
s
.07759 .51656 m
.08134 .51656 L
s
.07759 .54032 m
.08134 .54032 L
s
.07759 .06514 m
.08134 .06514 L
s
.07759 .04138 m
.08134 .04138 L
s
.07759 .01762 m
.08134 .01762 L
s
.07759 .58784 m
.08134 .58784 L
s
.07759 .6116 m
.08134 .6116 L
s
.25 Mabswid
.07759 0 m
.07759 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.02381 .32887 m
.02817 .32877 L
.03293 .32866 L
.0374 .32856 L
.0417 .32847 L
.04627 .32837 L
.05068 .32827 L
.05536 .32817 L
.05987 .32807 L
.06421 .32797 L
.06882 .32787 L
.07327 .32777 L
.07754 .32768 L
.08209 .32758 L
.08647 .32748 L
.09113 .32738 L
.09561 .32728 L
.09993 .32718 L
.10452 .32708 L
.10894 .32698 L
.11363 .32688 L
.11816 .32678 L
.12251 .32669 L
.12714 .32658 L
.13137 .32649 L
s
.10829 .3262 m
.11265 .3264 L
.11741 .32663 L
.12188 .32684 L
.12618 .32704 L
.13076 .32726 L
.13516 .32747 L
.13984 .32769 L
.14435 .3279 L
.14869 .32811 L
.15331 .32833 L
.15775 .32854 L
.16202 .32874 L
.16657 .32896 L
.17095 .32916 L
.17561 .32938 L
.18009 .32959 L
.18441 .3298 L
.189 .33002 L
.19342 .33022 L
.19811 .33045 L
.20264 .33066 L
.20699 .33087 L
.21162 .33109 L
.21586 .33129 L
s
.19277 .33686 m
.19714 .33581 L
.2019 .33467 L
.20636 .33359 L
.21066 .33256 L
.21524 .33146 L
.21964 .33041 L
.22432 .32928 L
.22883 .3282 L
.23317 .32716 L
.23779 .32605 L
.24223 .32498 L
.2465 .32396 L
.25105 .32286 L
.25543 .32181 L
.26009 .3207 L
.26457 .31962 L
.26889 .31858 L
.27348 .31748 L
.2779 .31642 L
.28259 .31529 L
.28712 .31421 L
.29147 .31316 L
.29611 .31205 L
.30034 .31103 L
s
.27725 .30808 m
.28162 .30708 L
.28638 .30598 L
.29085 .30495 L
.29514 .30396 L
.29972 .30291 L
.30412 .3019 L
.3088 .30082 L
.31331 .29978 L
.31765 .29878 L
.32227 .29772 L
.32671 .29669 L
.33099 .29571 L
.33554 .29466 L
.33992 .29365 L
.34457 .29258 L
.34906 .29155 L
.35337 .29056 L
.35796 .2895 L
.36238 .28848 L
.36708 .2874 L
.3716 .28636 L
.37596 .28536 L
.38059 .28429 L
.38482 .28331 L
s
.36174 .2745 m
.3661 .27821 L
.37086 .28226 L
.37533 .28605 L
.37963 .28971 L
.3842 .2936 L
.38861 .29734 L
.39329 .30132 L
.3978 .30515 L
.40213 .30884 L
.40675 .31276 L
.41119 .31654 L
.41547 .32017 L
.42002 .32404 L
.4244 .32776 L
.42905 .33172 L
.43354 .33553 L
.43785 .33919 L
.44244 .3431 L
.44686 .34685 L
.45156 .35084 L
.45608 .35469 L
.46044 .35839 L
.46507 .36233 L
.4693 .36592 L
s
.44622 .37415 m
.45058 .37557 L
.45534 .37712 L
.45981 .37857 L
.46411 .37997 L
.46868 .38145 L
.47309 .38288 L
.47777 .3844 L
.48228 .38587 L
.48662 .38728 L
.49123 .38878 L
.49568 .39022 L
.49995 .39161 L
.5045 .39309 L
.50888 .39451 L
.51353 .39602 L
.51802 .39748 L
.52233 .39888 L
.52692 .40037 L
.53134 .40181 L
.53604 .40333 L
.54056 .4048 L
.54492 .40622 L
.54955 .40772 L
.55378 .4091 L
s
.5307 .42319 m
.53506 .41453 L
.53982 .40509 L
.54429 .39622 L
.54859 .38769 L
.55316 .37862 L
.55757 .36988 L
.56225 .36059 L
.56676 .35164 L
.5711 .34304 L
.57571 .33388 L
.58016 .32506 L
.58443 .31658 L
.58898 .30755 L
.59336 .29887 L
.59802 .28963 L
.6025 .28073 L
.60681 .27217 L
.61141 .26306 L
.61582 .25429 L
.62052 .24498 L
.62505 .236 L
.6294 .22736 L
.63403 .21817 L
.63826 .20977 L
s
.61518 .1983 m
.61954 .19609 L
.6243 .19367 L
.62877 .1914 L
.63307 .18922 L
.63765 .18689 L
.64205 .18466 L
.64673 .18228 L
.65124 .17999 L
.65558 .17779 L
.66019 .17544 L
.66464 .17318 L
.66891 .17101 L
.67346 .1687 L
.67784 .16648 L
.6825 .16412 L
.68698 .16184 L
.6913 .15965 L
.69589 .15732 L
.70031 .15507 L
.705 .15269 L
.70953 .15039 L
.71388 .14818 L
.71851 .14583 L
.72275 .14368 L
s
.69966 .12634 m
.70403 .14147 L
.70878 .15796 L
.71325 .17345 L
.71755 .18835 L
.72213 .20421 L
.72653 .21947 L
.73121 .23569 L
.73572 .25132 L
.74006 .26636 L
.74468 .28236 L
.74912 .29776 L
.75339 .31257 L
.75794 .32834 L
.76232 .34352 L
.76698 .35966 L
.77146 .3752 L
.77578 .39015 L
.78037 .40606 L
.78479 .42138 L
.78948 .43766 L
.79401 .45334 L
.79836 .46843 L
.80299 .48448 L
.80723 .49915 L
s
.78414 .5159 m
.78851 .51853 L
.79327 .5214 L
.79774 .52409 L
.80203 .52668 L
.80661 .52944 L
.81101 .53209 L
.81569 .53491 L
.8202 .53763 L
.82454 .54024 L
.82916 .54302 L
.8336 .5457 L
.83788 .54827 L
.84243 .55102 L
.8468 .55365 L
.85146 .55646 L
.85595 .55916 L
.86026 .56176 L
.86485 .56453 L
.86927 .56719 L
.87397 .57002 L
.87849 .57274 L
.88285 .57537 L
.88748 .57816 L
.89171 .58071 L
s
.86863 .60332 m
.87299 .57944 L
.87775 .5534 L
.88222 .52894 L
.88652 .50542 L
.89109 .48039 L
.89549 .45629 L
.90018 .43067 L
.90469 .406 L
.90902 .38225 L
.91364 .357 L
.91808 .33268 L
.92236 .30929 L
.92691 .2844 L
.93129 .26043 L
.93594 .23495 L
.94043 .21041 L
.94474 .18681 L
.94933 .16169 L
.95375 .13751 L
.95845 .11181 L
.96297 .08704 L
.96733 .06322 L
.97196 .03788 L
.97619 .01472 L
s
0 g
.007 w
.07759 .32768 m
.08555 .32751 L
.09428 .32734 L
.09868 .32728 L
.10109 .32725 L
.10338 .32723 L
.10551 .32722 L
.10671 .32721 L
.10782 .32721 L
.10876 .32721 L
.10978 .32721 L
.11086 .32721 L
.11186 .32721 L
.11244 .32721 L
.11306 .32721 L
.11417 .32721 L
.11549 .32722 L
.11668 .32723 L
.11904 .32725 L
.12127 .32728 L
.1254 .32735 L
.12987 .32745 L
.13996 .32776 L
.14924 .32814 L
.16736 .32899 L
.1762 .32936 L
.18039 .3295 L
.18427 .3296 L
.18621 .32964 L
.18827 .32968 L
.18926 .32969 L
.19033 .3297 L
.19095 .32971 L
.19151 .32971 L
.19262 .32972 L
.19357 .32972 L
.19446 .32972 L
.19543 .32972 L
.19647 .32971 L
.19756 .3297 L
.19859 .32968 L
.20052 .32965 L
.20264 .3296 L
.20487 .32952 L
.20889 .32934 L
.2132 .32907 L
.21795 .32868 L
.22697 .32764 L
.2352 .32633 L
.24471 .32438 L
Mistroke
.25373 .32209 L
.28766 .3105 L
.30661 .30326 L
.32376 .29758 L
.33237 .2954 L
.33722 .29444 L
.34167 .29376 L
.34356 .29354 L
.34558 .29334 L
.34674 .29324 L
.3478 .29317 L
.3488 .29311 L
.34987 .29306 L
.35097 .29303 L
.352 .29301 L
.3531 .29301 L
.35373 .29301 L
.35431 .29302 L
.35537 .29304 L
.35634 .29308 L
.3574 .29313 L
.35852 .2932 L
.36081 .2934 L
.36297 .29365 L
.36701 .2943 L
.37136 .29525 L
.37606 .29659 L
.38455 .29983 L
.39237 .30374 L
.40905 .31494 L
.42737 .33093 L
.4632 .36648 L
.47971 .38053 L
.48904 .38668 L
.4935 .38901 L
.49768 .39081 L
.50202 .39223 L
.50432 .3928 L
.50551 .39303 L
.5068 .39325 L
.50808 .39342 L
.50927 .39354 L
.50992 .39359 L
.51052 .39362 L
.51121 .39365 L
.51186 .39366 L
.51302 .39365 L
.51409 .39361 L
.51526 .39353 L
.51585 .39348 L
Mistroke
.5165 .3934 L
.51769 .39324 L
.51882 .39304 L
.52094 .39257 L
.52323 .39191 L
.52572 .391 L
.53019 .3889 L
.53434 .38638 L
.54373 .37871 L
.55256 .369 L
.56907 .34486 L
.60329 .27719 L
.62064 .24026 L
.63968 .20428 L
.64843 .19088 L
.65324 .18464 L
.6578 .17957 L
.66205 .17564 L
.66666 .17229 L
.66869 .17113 L
.67085 .17012 L
.67269 .16944 L
.67472 .16889 L
.6758 .16868 L
.67681 .16855 L
.67791 .16846 L
.67853 .16843 L
.67909 .16843 L
.68022 .16848 L
.68086 .16853 L
.68145 .1686 L
.68254 .16878 L
.68368 .16904 L
.6857 .16967 L
.6876 .17046 L
.6919 .173 L
.69429 .17486 L
.69656 .17693 L
.70082 .18157 L
.7104 .19569 L
.71894 .21241 L
.72802 .2342 L
.74434 .28221 L
.78129 .4128 L
.79985 .47449 L
.80799 .49756 L
.8169 .51888 L
.82107 .52721 L
.82553 .53483 L
.82939 .54027 L
Mistroke
.83358 .54492 L
.83604 .54702 L
.83831 .54853 L
.84048 .54958 L
.84157 .54996 L
.84219 .55013 L
.84278 .55026 L
.84387 .55043 L
.84486 .5505 L
.84594 .55047 L
.84711 .55034 L
.84812 .55012 L
.84921 .54979 L
.85023 .54939 L
.85116 .54895 L
.85322 .54769 L
.85548 .54589 L
.86005 .54086 L
.86428 .53457 L
.86823 .52726 L
.87714 .50583 L
.88669 .47552 L
.90503 .39868 L
.92241 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo000KOol0
0`00Oomoo`3oOol3Ool001]oo`03001oogoo0?moo`=oo`006goo00<007ooOol0ogoo0goo000KOol0
0`00Oomoo`3oOol3Ool001]oo`03001oogoo0?Yoo`03O01oogoo00Eoo`006goo0P00ngoo00=l07oo
Ool01Goo000KOol00`00Oomoo`3jOol00g`0Oomoo`05Ool001]oo`03001oogoo0?Yoo`03O01oogoo
00Eoo`006goo00<007ooOol0nGoo00=l07ooOol01Woo000KOol00`00Oomoo`3iOol00g`0Oomoo`06
Ool001]oo`03001oogoo0?Uoo`03O01oogoo00Ioo`006goo00<007ooOol0nGoo00=l07ooOol01Woo
000KOol2003jOol00g`0Oomoo`06Ool001]oo`03001oogoo0?Uoo`03O01oogoo00Ioo`006goo00<0
07ooOol0n7oo00=l07ooOol01goo000KOol00`00Oomoo`3hOol00g`0Oomoo`07Ool001]oo`03001o
ogoo0?Qoo`03O01oogoo00Moo`006goo00<007ooOol0mgoo00=l07ooOol027oo000KOol2003hOol0
0g`0Oomoo`08Ool001]oo`03001oogoo0?Moo`03O01oogoo00Qoo`006goo00<007ooOol0mgoo00=l
07ooOol027oo000KOol00`00Oomoo`3gOol00g`0Oomoo`08Ool001]oo`03001oogoo0?Ioo`03O01o
ogoo00Uoo`001goo10000goo0P0017oo0P001Goo00<007ooOol0mWoo00=l07ooOol02Goo0008Ool0
0`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Aoo`03001oogoo0?Ioo`03O01oogoo00Uo
o`0000=oo`0000000`000goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`02Ool3
003fOol00g`0Oomoo`09Ool000Yoo`04001oogoo0002Ool01000Oomoo`000Woo00<007ooOol00Woo
00<007ooOol0mWoo00=l07ooOol02Goo0007Ool01000Oomoo`000Woo00@007ooOol0009oo`04001o
ogoo0004Ool00`00Oomoo`3fOol00g`0Oomoo`09Ool000Qoo`8000Aoo`8000Aoo`8000Eoo`03001o
ogoo0?Ioo`03O01oogoo00Uoo`006goo00<007ooOol0mGoo00=l07ooOol02Woo000KOol00`00Oomo
o`3eOol00g`0Oomoo`0:Ool001]oo`03001oogoo0?Eoo`03O01oogoo00Yoo`006goo0P00mWoo00=l
07ooOol02Woo000KOol00`00Oomoo`3eOol00g`0Oomoo`0:Ool001]oo`03001oogoo0?Eoo`03O01o
ogoo00Yoo`006goo00<007ooOol0m7oo00=l07ooOol02goo000KOol00`00Oomoo`2/Ool00g`0Oomo
o`15Ool00g`0Oomoo`0;Ool001]oo`03001oogoo0:aoo`03O01oogoo04Eoo`03O01oogoo00]oo`00
6goo0P00[Goo00=l07ooOol0A7oo00=l07ooOol037oo000KOol00`00Oomoo`2]Ool00g`0Oomoo`13
Ool00g`0Oomoo`0<Ool001]oo`03001oogoo0:eoo`03O01oogoo04=oo`03O01oogoo00aoo`006goo
00<007ooOol0[Goo00Al07ooOomoo`=l03moo`03O01oogoo00aoo`006goo00<007ooOol0[Woo0g`0
@Woo00=l07ooOol037oo000KOol00`00Oomoo`2]Ool2O013Ool00g`0Oomoo`0=Ool001]oo`03001o
ogoo0:]oo`9l0003Ooml07oo049oo`03O01oogoo00eoo`006goo0P00ZWoo0W`017oo00=l07ooOol0
@7oo00=l07ooOol03Goo000KOol00`00Oomoo`2WOol2O006Ool00g`0Oomoo`10Ool00g`0Oomoo`0=
Ool001]oo`03001oogoo0:Ioo`8000Moo`03O01oogoo041oo`03O01oogoo00eoo`006goo00<007oo
Ool0Xgoo1`001Woo00=l07ooOol0?goo00=l07ooOol03Goo000KOol00`00Oomoo`2QOol00g`00000
0006Ool20004Ool00g`0Oomoo`0oOol00g`0Oomoo`0=Ool001]oo`030
01oogoo09moo`9l0003001o
ogoo00Moo`03001oogoo009oo`03O01oogoo03ioo`03O01oogoo00ioo`006goo00<007ooOol0WGoo
0W`000=oo`00Ool02Woo00D007ooOomoog`0041oo`03O01oogoo00ioo`006goo0P00WGoo00Al07oo
Ool000aoo`03001oogoo009oo`03O01oogoo03eoo`03O01oogoo00ioo`006goo00<007ooOol0VGoo
0g`00goo00<007ooOol02goo00D007ooOomoog`003moo`03O01oogoo00ioo`006goo00<007ooOol0
V7oo00=l07ooOol00goo00<007ooOol03Goo00@007ooOoml03moo`03O01oogoo00ioo`006goo00<0
07ooOol0UGoo0g`01Woo00<007ooOol03Woo00<007ooO000?goo00=l07ooOol03Woo000KOol00`00
Oomoo`2DOol00g`0Oomoo`06Ool00`00Oomoo`0?Ool01000Oomoog`0?Woo00=l07ooOol03Woo0007
Ool30004Ool20004Ool20005Ool00`00Oomoo`2LOol00`00Oomoo`0AOol00`00Ooml000mOol00g`0
Oomoo`0?Ool000Qoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`0017oo00<007ooOol0
Vgoo00<007ooOol04Woo00<007ooO000?Goo00=l07ooOol03goo00000goo000000030002Ool00`00
Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Aoo`<009]oo`03001oogoo019oo`03001oog`0
03eoo`03O01oogoo00moo`0027oo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0004Ool0
0`00Oomoo`2JOol00`00O01oo`0DOol00`00Ooml000lOol00g`0Oomoo`0?Ool000Qoo`03001oogoo
009oo`04001oogoo0002Ool01000Oomoo`0017oo00<007ooOol0VWoo00<007ooOol057oo00<007oo
O000?7oo00=l07ooOol03goo0007Ool20005Ool20004Ool20005Ool00`00Oomoo`2IOol00`00O01o
o`0FOol00`00Ooml000jOol00g`0Oomoo`0@Ool001]oo`03001oogoo09Uoo`03001oogoo01Ioo`03
001oog`003Yoo`03O01oogoo011oo`006goo00<007ooOol0V7oo00<007ooOol067oo00<007`0Ool0
>Goo00=l07ooOol047oo000KOol2002IOol00`00Oomoo`0HOol00`00Ooml000hOol00g`0Oomoo`0A
Ool001]oo`03001oogoo09Moo`03001oogoo01Yoo`03001l07oo03Moo`03O01oogoo015oo`006goo
00<007ooOol0Ugoo00<007ooOol06Woo00<007`0Ool0=goo00=l07ooOol04Goo000KOol00`00Oomo
o`2FOol00`00Oomoo`0LOol00`00Oomoo`0fOol00g`0Oomoo`0AOol001]oo`03001oogoo09Ioo`03
001oogoo01aoo`03001l07oo03Ioo`03O01oogoo015oo`006goo00<007ooOol0UGoo00<007`0Ool0
7Goo00<007`0Ool0=Goo00=l07ooOol04Woo000KOol00`00Oomoo`2EOol00`00Oomoo`0NOol00`00
Oomoo`0dOol00g`0Oomoo`0BOol001]oo`8009Eoo`03001oogoo01moo`03001oogoo03Aoo`03O01o
ogoo019oo`006goo00<007ooOol0U7oo00<007ooOol07goo00=l0000Ool0=7oo00=l07ooOol04Woo
000KOol00`00Oomoo`2COol00`00Oomoo`0QOol00`00Oomoo`0cOol00g`0Oomoo`0BOol001]oo`03
001oogoo09=oo`03001oogoo025oo`03001oogoo03=oo`03O01oogoo019oo`006goo00<007ooOol0
TWoo00<007ooOol08Woo00=l0000Ool0<goo00=l07ooOol04Woo000KOol00`00Oomoo`1=Ool00g`0
Oomoo`12Ool00`00Oomoo`0SOol00`00Oomoo`0aOol00g`0Oomoo`0COol001]oo`03001oogoo04io
o`03O01oogoo041oo`03001l07oo02Aoo`03001oogoo035oo`03O01oogoo01=oo`006goo0P00D7oo
00=l07ooOol0?goo00<007ooOol097oo00=l0000Ool0<Goo00=l07ooOol04goo000KOol00`00Oomo
o`1@Ool4O00lOol00`00O01oo`0VOol00`00Oomoo`0`Ool00g`0Oomoo`0COol001]oo`03001oogoo
01]oo`@000=oo`8000=oo`<001eoo`<000=oo`El01Eoo`03001oogoo00=oo`8000=oo`<001Yoo`<0
00Aoo`8001Moo`<000=oo`D0009oo`8000=oo`<001Moo`<000=oo`<000Qoo`03O01oogoo01=oo`00
6goo00<007ooOol077oo00<007ooOol00goo0P001Woo00<007ooOol06goo1G`01Goo00=l07ooOol0
4Woo00<007ooOol00goo0P001Woo00<007ooOol05goo0P0017oo00@007ooOol001Moo`03001oogoo
00=oo`06001oogooO00007oo0P001Woo00<007ooOol05Goo00<007ooOol01Goo00<007ooOol01Goo
00=l07ooOol04goo000KOol00`00Oomoo`0MOol00`00Oomoo`0:Ool00`00Oomoo`0GOol=0002Ool2
O00COol00`00Oomoo`0:Ool00`00Oomoo`0GOol20004Ool01000Oomoo`005goo00<007ooOol017oo
00@007ooOol000Uoo`03001oogoo01Eoo`03001oogoo00Eoo`03001oogoo00Eoo`03O01oogoo01=o
o`006goo00<007ooOol07Woo00<007ooOol01Woo0`005Goo00=l000000000P000goo0`001goo1000
00=l07ooOol047oo00<007ooOol01goo0`006Goo00<007oo000017oo00@007ooOol001Moo`03001o
ogoo00Eoo`03001oo`0000Ioo`<001Qoo`03001oogoo009oo`<000Moo`03O01oogoo01Aoo`006goo
0P0077oo00@007ooOol000Qoo`03001oogoo015oo`03O0000000008000Moo`03001oogoo00]oo`03
001l07oo015oo`03001oogoo00Ioo`03001oogoo01Uoo`03001oo`0000Aoo`04001oogoo000GOol0
0`00Oomoo`02Ool01P00Oomoo`00Ool000Ioo`03001oogoo01Qoo`03001oogoo009oo`03001oogoo
00Moo`03O01oogoo01Aoo`006goo00<007ooOol077oo0P002Goo10002goo0g`00`002goo10002goo
0P003Woo100027oo10005goo00@007oo000000Eoo`8001Moo`8000Eoo`80009oo`03O00007oo00Ao
o`@001Ioo`8000Aoo`@000Ioo`03O01oogoo01Aoo`006goo00<007ooOol0=Goo00Al07oo000001mo
o`03001l07oo039oo`03001oogoo02]oo`03001oogoo02eoo`03001oogoo01Aoo`006goo00<007oo
Ool0=Goo0P0000=oog`0O0
000g`077oo00<007`0Ool0<7oo00<007`0Ool0;7oo00<007ooOol0;Goo
00<007ooOol057oo000KOol00`00Oomoo`0bOol30003O00ROol2000_Ool00`00O01oo`0]Ool00g`0
001oo`0]Ool00`00Oomoo`0DOol001]oo`03001oogoo031oo`80009l02Qoo`03001oogoo02aoo`03
001l07oo02eoo`03O00007oo02aoo`03001oogoo01Eoo`006goo00<007ooOol0:goo1@00;Goo00<0
07`0Ool0:Woo00<007`0Ool0;goo00<007ooOol0:goo00<007ooOol05Goo0005Ool=0009O00^0000
0g`00000000a00000g`00000002P000000aoo`Il0003Ool007oo00Ioo`03001oogoo00Eoo`03001o
ogoo00Aoo`03001oogoo00Eoo`03O000000000l00005O01oogooOol00007Ool00`00Oomoo`05Ool0
0`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool0
0`00O01oo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04Ool0
1P00Oomoogoo001l009oo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo
00Eoo`03001oogoo00Eoo`03001oogoo00Aoo`04001oog`00004Ool00`00Oomoo`04Ool00`00Oomo
o`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00O0000004Ool00`00Oomo
o`05Ool00`00Oomoo`04Ool00`00Oomoo`01Ool001]oo`03001oogoo021oo`=l0003001oogoo02=o
o`03001oogoo01Aoo`03001l07oo00]oo`03001oogoo01Qoo`03001oogoo00Qoo`03001oogoo02=o
o`04001oogoo000ROol00`00Oomoo`06Ool00g`0001oo`0FOol001]oo`03001oogoo01eoo`=l045o
o`03001oogoo02Aoo`03001l07oo039oo`03001oogoo02Uoo`03001oogoo01Ioo`006goo00<007oo
Ool0HWoo00<007`0Ool08goo00<007ooOol0<Woo00<007ooOol0:Goo00<007ooOol05Woo000KOol0
0`00Oomoo`1SOol00`00O01oo`0QOol00`00O01oo`0dOol00`00Oomoo`0XOol00`00Oomoo`0FOol0
01]oo`03001oogoo06Aoo`03001l07oo021oo`03001l07oo03Aoo`03001oogoo02Moo`03O00007oo
01Moo`006goo0P00IWoo00<007`0Ool07Woo00<007`0Ool0=Goo00<007ooOol09goo00=l0000Ool0
5goo000KOol00`00Oomoo`1VOol00`00O01l000MOol00`00O01oo`0fOol00`00Oomoo`0VOol00`00
Oomoo`0GOol001]oo`03001oogoo06Moo`03001oog`001]oo`03001l07oo03Moo`03001oogoo02Io
o`03001oogoo01Moo`006goo00<007ooOol0J7oo00<007ooO0006Goo00<007`0Ool0>7oo00<007oo
Ool09Woo00<007ooOol05goo000KOol00`00Oomoo`1YOol200000g`0Oomoo`0FOol00`00O01oo`0h
Ool00`00Oomoo`0VOol00`00Oomoo`0GOol001]oo`03001oogoo06]oo`03001oogoo01Eoo`03001l
07oo03Yoo`03001oogoo02Eoo`03001oogoo01Moo`006goo0P00IWoo00=l07ooOol017oo00<007oo
Ool04goo00<007ooO000>goo00<007ooOol097oo00<007ooOol067oo000KOol00`00Oomoo`1VOol3
O004Ool00`00Oomoo`0AOol00`00Ooml000lOol00`00Oomoo`0TOol00`00Oomoo`0HOol001]oo`03
001oogoo06Uoo`=l009oo`80011oo`04001oogooO00lOol00`00Oomoo`0TOol00`00Oomoo`0HOol0
01]oo`03001oogoo06aoo`=l0003Ool007oo00eoo`05001oogooOoml000lOol00g`0001oo`0TOol0
0`00Oomoo`0HOol001]oo`03001oogoo06moo`9l0003001l07oo00Uoo`8000=oo`03O01oogoo03ao
o`03001oogoo02=oo`03001oogoo01Qoo`006goo00<007ooOol0LWoo0`001Goo0`001Goo00=l07oo
Ool0?7oo00<007ooOol08Woo00<007`0Ool06Goo000KOol00`00Oomoo`1eOol60006Ool00g`0Oomo
o`0mOol00g`0001oo`0ROol00`00O01oo`0IOol001]oo`8007Uoo`=l00Eoo`03O01oogoo03moo`03
001oogoo025oo`03001oogoo01Uoo`006goo00<007ooOol0Ngoo0g`00Woo00=l07ooOol0?goo00<0
07ooOol08Goo00<007ooOol06Goo000KOol00`00Oomoo`1nOol4O010Ool00`00O01oo`0QOol00`00
Oomoo`0IOol001]oo`03001oogoo07moo`03O01oogoo009l03moo`03001oogoo01moo`03001l07oo
01Yoo`006goo00<007ooOol0OWoo00=l07ooOol0@Woo00<007ooOol07goo00<007`0Ool06Woo000K
Ool00`00Oomoo`1nOol00g`0Oomoo`12Ool00`00O01oo`0OOol00`00Oomoo`0JOol001]oo`03001o
ogoo07eoo`03O01oogoo04=oo`03001l07oo01moo`03001oogoo01Yoo`006goo0P00OGoo00=l07oo
Ool0AGoo00<007ooOol07Woo00<007ooOol06Woo000KOol00`00Oomoo`34Ool00`00Oomoo`0MOol0
0`00Oomoo`0KOol001]oo`03001oogoo0<Aoo`03001oogoo01eoo`03001oogoo01]oo`006goo00<0
07ooOol0aGoo00<007ooOol077oo00<007ooOol06goo0007Ool30004Ool20004Ool20005Ool00`00
Oomoo`35Ool00`00Oomoo`0LOol00`00Oomoo`0KOol000Qoo`03001oogoo009oo`04001oogoo0002
Ool01000Oomoo`0017oo00<007ooOol0aGoo00<007ooOol06goo00<007`0Ool077oo0008Ool00`00
Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Aoo`<00<Eoo`03001l07oo01]oo`03001oogoo
01aoo`0027oo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0004Ool00`00Oomoo`36Ool0
0`00Oomoo`0JOol00`00Oomoo`0LOol000Qoo`03001oogoo009oo`04001oogoo0002Ool01000Oomo
o`0017oo00<007ooOol0aWoo00<007ooOol06Woo00<007ooOol077oo0007Ool20005Ool20004Ool2
0005Ool00`00Oomoo`36Ool00`00O01oo`0IOol00`00O01oo`0MOol001]oo`03001oogoo0<Ioo`03
001l07oo01Uoo`03001l07oo01eoo`006goo00<007ooOol0agoo00<007ooOol067oo
00<007`0Ool0
7Goo000KOol00`00Oomoo`37Ool00`00O01oo`0HOol00`00O01oo`0MOol001]oo`800<Qoo`03001l
07oo01Qoo`03001oogoo01eoo`006goo00<007ooOol0b7oo00<007ooOol05Woo00<007`0Ool07Woo
000KOol00`00Oomoo`38Ool00`00Oomoo`0FOol00`00O01oo`0NOol001]oo`03001oogoo0<Qoo`03
001l07oo01Ioo`03001l07oo01ioo`006goo00<007ooOol0bGoo00<007ooOol057oo00<007ooO000
7goo000KOol00`00Oomoo`39Ool00`00Oomoo`0DOol00`00Ooml000OOol001]oo`03001oogoo0<Uo
o`03001oogoo01Aoo`03001oog`001moo`006goo0P00bgoo00<007ooOol04Woo00<007ooO00087oo
000KOol00`00Oomoo`3:Ool00`00Oomoo`0BOol00`00Ooml000POol001]oo`03001oogoo0<Yoo`03
001oogoo019oo`03001oog`0021oo`006goo00<007ooOol0bgoo00<007ooOol047oo00@007ooOoml
021oo`006goo00<007ooOol0bgoo00<007ooOol047oo00@007ooOoml021oo`006goo00<007ooOol0
c7oo00<007ooOol03Woo00D007ooOomoog`0021oo`006goo0P00aGoo00=l07ooOol01Goo00<007oo
Ool03Woo00@007ooOoml025oo`006goo00<007ooOol0aGoo00=l07ooOol01Goo00<007ooOol037oo
00D007ooOomoog`0025oo`006goo00<007ooOol0aWoo0W`01Goo00<007ooOol037oo00D007ooOomo
og`0025oo`006goo00<007ooOol0b7oo0W`017oo00<007ooOol02Woo00D007ooOomoog`0029oo`00
6goo00<007ooOol0bWoo00El07ooOomoo`0000aoo`05001oogooOoml000ROol001]oo`03001oogoo
0<]oo`9l009oo`03001oogoo00Qoo`03001oogoo009oo`03O01oogoo021oo`006goo00<007ooOol0
cGoo0W`00P002Goo00<007ooOol00Woo00=l07ooOol087oo000KOol2003@Ool00g`0Ool00007Ool0
0`00Oomoo`03Ool00g`0Oomoo`0POol001]oo`03001oogoo0=1oo`9l0003001oogoo00Aoo`03001o
ogoo009oo`03O01oogoo025oo`006goo00<007ooOol0dWoo0P000goo0P001Goo00=l07ooOol08Goo
000KOol00`00Oomoo`3DOol40006Ool00g`0Oomoo`0QOol001]oo`03001oogoo0=Eoo`9l00Moo`03
O01oogoo025oo`001goo10000goo0P0017oo0P001Goo00<007ooOol0egoo0W`01Goo00=l07ooOol0
8Goo0008Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Aoo`03001oogoo0=Uoo`03
O01oogoo009oo`03O01oogoo025oo`002Goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00
Oomoo`02Ool3003JOol2O002Ool00g`0Oomoo`0QOol000Yoo`04001oogoo0002Ool01000Oomoo`00
0Woo00<007ooOol00Woo00<007ooOol0g7oo0W`097oo0007Ool01000Oomoo`000Woo00@007ooOol0
009oo`04001oogoo0004Ool00`00Oomoo`3MOol3O00ROol000Qoo`8000Aoo`8000Aoo`8000Eoo`03
001oogoo0=eoo`04O01oogooO00QOol001]oo`03001oogoo0=eoo`04O01oogooOol2O00OOol001]o
o`03001oogoo0=eoo`03O01oogoo029oo`006goo0P00gWoo00=l07ooOol08Woo000KOol00`00Oomo
o`3MOol00g`0Oomoo`0ROol001]oo`03001oogoo0=aoo`03O01oogoo02=oo`006goo00<007ooOol0
g7oo00=l07ooOol08goo000KOol00`00Oomoo`3LOol00g`0Oomoo`0SOol001]oo`03001oogoo0=ao
o`03O01oogoo02=oo`006goo00<007ooOol0ogoo0goo000KOol2003oOol4Ool001]oo`03001oogoo
0?moo`=oo`006goo00<007ooOol0ogoo0goo003oOolQOol00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1.81885, -279.444,
  0.0660962, 2.9924}}],

Cell[BoxData[
    FormBox[
      TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
        False,
        Editable->False], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ShowTangentLines[x\^2\ Sin[x]\  - x\  + 1, {x, 0, 5  \[Pi]}, 20]\)],
  "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0775922 0.0537826 0.299025 0.0010833 [
[.21205 .28653 -9 -9 ]
[.21205 .28653 9 0 ]
[.34651 .28653 -3 -9 ]
[.34651 .28653 3 0 ]
[.48096 .28653 -9 -9 ]
[.48096 .28653 9 0 ]
[.61542 .28653 -6 -9 ]
[.61542 .28653 6 0 ]
[.74988 .28653 -12 -9 ]
[.74988 .28653 12 0 ]
[.88433 .28653 -6 -9 ]
[.88433 .28653 6 0 ]
[.06509 .08237 -24 -4.5 ]
[.06509 .08237 0 4.5 ]
[.06509 .1907 -24 -4.5 ]
[.06509 .1907 0 4.5 ]
[.06509 .40736 -18 -4.5 ]
[.06509 .40736 0 4.5 ]
[.06509 .51569 -18 -4.5 ]
[.06509 .51569 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21205 .29903 m
.21205 .30528 L
s
[(2.5)] .21205 .28653 0 1 Mshowa
.34651 .29903 m
.34651 .30528 L
s
[(5)] .34651 .28653 0 1 Mshowa
.48096 .29903 m
.48096 .30528 L
s
[(7.5)] .48096 .28653 0 1 Mshowa
.61542 .29903 m
.61542 .30528 L
s
[(10)] .61542 .28653 0 1 Mshowa
.74988 .29903 m
.74988 .30528 L
s
[(12.5)] .74988 .28653 0 1 Mshowa
.88433 .29903 m
.88433 .30528 L
s
[(15)] .88433 .28653 0 1 Mshowa
.125 Mabswid
.10448 .29903 m
.10448 .30278 L
s
.13137 .29903 m
.13137 .30278 L
s
.15827 .29903 m
.15827 .30278 L
s
.18516 .29903 m
.18516 .30278 L
s
.23894 .29903 m
.23894 .30278 L
s
.26583 .29903 m
.26583 .30278 L
s
.29272 .29903 m
.29272 .30278 L
s
.31961 .29903 m
.31961 .30278 L
s
.3734 .29903 m
.3734 .30278 L
s
.40029 .29903 m
.40029 .30278 L
s
.42718 .29903 m
.42718 .30278 L
s
.45407 .29903 m
.45407 .30278 L
s
.50785 .29903 m
.50785 .30278 L
s
.53474 .29903 m
.53474 .30278 L
s
.56164 .29903 m
.56164 .30278 L
s
.58853 .29903 m
.58853 .30278 L
s
.64231 .29903 m
.64231 .30278 L
s
.6692 .29903 m
.6692 .30278 L
s
.69609 .29903 m
.69609 .30278 L
s
.72298 .29903 m
.72298 .30278 L
s
.77677 .29903 m
.77677 .30278 L
s
.80366 .29903 m
.80366 .30278 L
s
.83055 .29903 m
.83055 .30278 L
s
.85744 .29903 m
.85744 .30278 L
s
.0507 .29903 m
.0507 .30278 L
s
.02381 .29903 m
.02381 .30278 L
s
.91122 .29903 m
.91122 .30278 L
s
.93811 .29903 m
.93811 .30278 L
s
.96501 .29903 m
.96501 .30278 L
s
.9919 .29903 m
.9919 .30278 L
s
.25 Mabswid
0 .29903 m
1 .29903 L
s
.07759 .08237 m
.08384 .08237 L
s
[(-200)] .06509 .08237 1 0 Mshowa
.07759 .1907 m
.08384 .1907 L
s
[(-100)] .06509 .1907 1 0 Mshowa
.07759 .40736 m
.08384 .40736 L
s
[(100)] .06509 .40736 1 0 Mshowa
.07759 .51569 m
.08384 .51569 L
s
[(200)] .06509 .51569 1 0 Mshowa
.125 Mabswid
.07759 .10403 m
.08134 .10403 L
s
.07759 .1257 m
.08134 .1257 L
s
.07759 .14736 m
.08134 .14736 L
s
.07759 .16903 m
.08134 .16903 L
s
.07759 .21236 m
.08134 .21236 L
s
.07759 .23403 m
.08134 .23403 L
s
.07759 .25569 m
.08134 .25569 L
s
.07759 .27736 m
.08134 .27736 L
s
.07759 .32069 m
.08134 .32069 L
s
.07759 .34236 m
.08134 .34236 L
s
.07759 .36402 m
.08134 .36402 L
s
.07759 .38569 m
.08134 .38569 L
s
.07759 .42902 m
.08134 .42902 L
s
.07759 .45069 m
.08134 .45069 L
s
.07759 .47235 m
.08134 .47235 L
s
.07759 .49402 m
.08134 .49402 L
s
.07759 .0607 m
.08134 .0607 L
s
.07759 .03903 m
.08134 .03903 L
s
.07759 .01737 m
.08134 .01737 L
s
.07759 .53735 m
.08134 .53735 L
s
.07759 .55902 m
.08134 .55902 L
s
.07759 .58068 m
.08134 .58068 L
s
.07759 .60235 m
.08134 .60235 L
s
.25 Mabswid
.07759 0 m
.07759 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.02381 .30119 m
.02817 .3011 L
.03293 .30101 L
.0374 .30092 L
.0417 .30083 L
.04627 .30074 L
.05068 .30065 L
.05536 .30056 L
.05987 .30047 L
.06421 .30038 L
.06882 .30029 L
.07327 .3002 L
.07754 .30011 L
.08209 .30002 L
.08647 .29993 L
.09113 .29984 L
.09561 .29975 L
.09993 .29966 L
.10452 .29957 L
.10894 .29948 L
.11363 .29938 L
.11816 .29929 L
.12251 .2992 L
.12714 .29911 L
.13137 .29903 L
s
.06605 .29914 m
.07041 .29919 L
.07517 .29924 L
.07964 .29929 L
.08394 .29933 L
.08852 .29939 L
.09292 .29943 L
.0976 .29949 L
.10211 .29953 L
.10645 .29958 L
.11106 .29963 L
.11551 .29968 L
.11978 .29973 L
.12433 .29978 L
.12871 .29983 L
.13337 .29988 L
.13785 .29993 L
.14217 .29998 L
.14676 .30003 L
.15118 .30008 L
.15587 .30013 L
.1604 .30018 L
.16475 .30023 L
.16938 .30028 L
.17362 .30032 L
s
.10829 .29876 m
.11265 .29895 L
.11741 .29915 L
.12188 .29935 L
.12618 .29953 L
.13076 .29973 L
.13516 .29992 L
.13984 .30012 L
.14435 .30032 L
.14869 .3005 L
.15331 .3007 L
.15775 .30089 L
.16202 .30108 L
.16657 .30127 L
.17095 .30146 L
.17561 .30166 L
.18009 .30186 L
.18441 .30204 L
.189 .30224 L
.19342 .30243 L
.19811 .30263 L
.20264 .30283 L
.20699 .30302 L
.21162 .30322 L
.21586 .3034 L
s
.15053 .30353 m
.1549 .30339 L
.15965 .30324 L
.16412 .3031 L
.16842 .30296 L
.173 .30281 L
.1774 .30267 L
.18208 .30252 L
.18659 .30238 L
.19093 .30224 L
.19555 .30209 L
.19999 .30195 L
.20426 .30181 L
.20881 .30166 L
.21319 .30152 L
.21785 .30137 L
.22233 .30123 L
.22665 .30109 L
.23124 .30094 L
.23566 .3008 L
.24035 .30065 L
.24488 .30051 L
.24923 .30037 L
.25386 .30022 L
.2581 .30008 L
s
.19277 .30848 m
.19714 .30752 L
.2019 .30648 L
.20636 .3055 L
.21066 .30456 L
.21524 .30356 L
.21964 .3026 L
.22432 .30157 L
.22883 .30059 L
.23317 .29964 L
.23779 .29862 L
.24223 .29765 L
.2465 .29672 L
.25105 .29572 L
.25543 .29476 L
.26009 .29374 L
.26457 .29276 L
.26889 .29182 L
.27348 .29081 L
.2779 .28984 L
.28259 .28881 L
.28712 .28782 L
.29147 .28687 L
.29611 .28586 L
.30034 .28493 L
s
.23501 .30295 m
.23938 .30142 L
.24414 .29975 L
.24861 .29817 L
.2529 .29666 L
.25748 .29505 L
.26188 .29351 L
.26656 .29186 L
.27107 .29027 L
.27541 .28875 L
.28003 .28712 L
.28447 .28556 L
.28875 .28406 L
.2933 .28246 L
.29767 .28092 L
.30233 .27928 L
.30682 .27771 L
.31113 .27619 L
.31572 .27457 L
.32014 .27302 L
.32484 .27137 L
.32936 .26978 L
.33372 .26825 L
.33835 .26662 L
.34258 .26513 L
s
.27725 .28224 m
.28162 .28132 L
.28638 .28032 L
.29085 .27939 L
.29514 .27848 L
.29972 .27752 L
.30412 .2766 L
.3088 .27562 L
.31331 .27467 L
.31765 .27376 L
.32227 .27279 L
.32671 .27186 L
.33099 .27096 L
.33554 .27 L
.33992 .26908 L
.34457 .26811 L
.34906 .26716 L
.35337 .26626 L
.35796 .26529 L
.36238 .26437 L
.36708 .26338 L
.3716 .26243 L
.37596 .26152 L
.38059 .26054 L
.38482 .25965 L
s
.3195 .25735 m
.32386 .25846 L
.32862 .25967 L
.33309 .2608 L
.33739 .26189 L
.34196 .26305 L
.34636 .26417 L
.35105 .26536 L
.35556 .2665 L
.35989 .2676 L
.36451 .26877 L
.36895 .2699 L
.37323 .27099 L
.37778 .27214 L
.38216 .27325 L
.38681 .27443 L
.3913 .27557 L
.39561 .27667 L
.4002 .27783 L
.40462 .27895 L
.40932 .28014 L
.41384 .28129 L
.4182 .2824 L
.42283 .28357 L
.42706 .28465 L
s
.36174 .25162 m
.3661 .255 L
.37086 .25869 L
.37533 .26215 L
.37963 .26548 L
.3842 .26903 L
.38861 .27244 L
.39329 .27607 L
.3978 .27957 L
.40213 .28293 L
.40675 .28651 L
.41119 .28995 L
.41547 .29326 L
.42002 .29679 L
.4244 .30018 L
.42905 .30379 L
.43354 .30727 L
.43785 .31061 L
.44244 .31417 L
.44686 .31759 L
.45156 .32123 L
.45608 .32474 L
.46044 .32812 L
.46507 .33171 L
.4693 .33499 L
s
.40398 .28271 m
.40834 .2866 L
.4131 .29085 L
.41757 .29484 L
.42187 .29868 L
.42644 .30276 L
.43085 .3067 L
.43553 .31087 L
.44004 .3149 L
.44438 .31877 L
.44899 .3229 L
.45344 .32686 L
.45771 .33068 L
.46226 .33474 L
.46664 .33865 L
.47129 .34281 L
.47578 .34681 L
.48009 .35066 L
.48468 .35476 L
.4891 .35871 L
.4938 .3629 L
.49832 .36694 L
.50268 .37083 L
.50731 .37497 L
.51154 .37874 L
s
.44622 .34249 m
.45058 .34378 L
.45534 .34519 L
.45981 .34652 L
.46411 .34779 L
.46868 .34915 L
.47309 .35045 L
.47777 .35184 L
.48228 .35317 L
.48662 .35446 L
.49123 .35583 L
.49568 .35714 L
.49995 .35841 L
.5045 .35976 L
.50888 .36105 L
.51353 .36243 L
.51802 .36376 L
.52233 .36504 L
.52692 .3664 L
.53134 .36771 L
.53604 .3691 L
.54056 .37044 L
.54492 .37173 L
.54955 .3731 L
.55378 .37436 L
s
.48846 .39295 m
.49282 .38929 L
.49758 .38531 L
.50205 .38157 L
.50635 .37797 L
.51092 .37414 L
.51533 .37045 L
.52001 .36653 L
.52452 .36276 L
.52886 .35913 L
.53347 .35526 L
.53792 .35154 L
.54219 .34797 L
.54674 .34416 L
.55112 .34049 L
.55578 .33659 L
.56026 .33284 L
.56457 .32923 L
.56916 .32539 L
.57358 .32169 L
.57828 .31775 L
.58281 .31397 L
.58716 .31032 L
.59179 .30645 L
.59602 .3029 L
s
.5307 .38721 m
.53506 .37931 L
.53982 .3707 L
.54429 .36262 L
.54859 .35484 L
.55316 .34656 L
.55757 .33859 L
.56225 .33012 L
.56676 .32196 L
.5711 .31411 L
.57571 .30576 L
.58016 .29772 L
.58443 .28999 L
.58898 .28176 L
.59336 .27383 L
.59802 .26541 L
.6025 .2573 L
.60681 .24949 L
.61141 .24119 L
.61582 .23319 L
.62052 .22469 L
.62505 .2165 L
.6294 .20863 L
.63403 .20025 L
.63826 .19259 L
s
.57294 .30577 m
.5773 .29794 L
.58206 .28939 L
.58653 .28137 L
.59083 .27365 L
.59541 .26543 L
.59981 .25752 L
.60449 .24912 L
.609 .24102 L
.61334 .23323 L
.61795 .22494 L
.6224 .21696 L
.62667 .20928 L
.63122 .20111 L
.6356 .19325 L
.64026 .18489 L
.64474 .17683 L
.64906 .16909 L
.65365 .16084 L
.65807 .15291 L
.66276 .14447 L
.66729 .13635 L
.67164 .12853 L
.67627 .12021 L
.6805 .11261 L
s
.61518 .18213 m
.61954 .18011 L
.6243 .1779 L
.62877 .17584 L
.63307 .17384 L
.63765 .17173 L
.64205 .16969 L
.64673 .16752 L
.65124 .16543 L
.65558 .16342 L
.66019 .16128 L
.66464 .15923 L
.66891 .15725 L
.67346 .15514 L
.67784 .15311 L
.6825 .15096 L
.68698 .14888 L
.6913 .14688 L
.69589 .14475 L
.70031 .14271 L
.705 .14053 L
.70953 .13844 L
.71388 .13642 L
.71851 .13428 L
.72275 .13232 L
s
.65742 .09385 m
.66178 .10092 L
.66654 .10864 L
.67101 .11588 L
.67531 .12285 L
.67989 .13026 L
.68429 .1374 L
.68897 .14499 L
.69348 .1523 L
.69782 .15934 L
.70244 .16682 L
.70688 .17402 L
.71115 .18095 L
.7157 .18832 L
.72008 .19542 L
.72474 .20297 L
.72922 .21024 L
.73354 .21723 L
.73813 .22468 L
.74255 .23184 L
.74724 .23945 L
.75177 .24679 L
.75612 .25385 L
.76075 .26135 L
.76499 .26821 L
s
.69966 .11651 m
.70403 .1303 L
.70878 .14534 L
.71325 .15947 L
.71755 .17305 L
.72213 .18751 L
.72653 .20143 L
.73121 .21623 L
.73572 .23048 L
.74006 .24419 L
.74468 .25878 L
.74912 .27283 L
.75339 .28634 L
.75794 .30072 L
.76232 .31456 L
.76698 .32927 L
.77146 .34345 L
.77578 .35708 L
.78037 .37159 L
.78479 .38556 L
.78948 .4004 L
.79401 .4147 L
.79836 .42847 L
.80299 .4431 L
.80723 .45648 L
s
.7419 .26627 m
.74627 .27892 L
.75103 .29272 L
.75549 .30568 L
.75979 .31814 L
.76437 .3314 L
.76877 .34417 L
.77345 .35774 L
.77796 .37082 L
.7823 .3834 L
.78692 .39678 L
.79136 .40966 L
.79563 .42205 L
.80019 .43525 L
.80456 .44794 L
.80922 .46144 L
.8137 .47444 L
.81802 .48695 L
.82261 .50026 L
.82703 .51307 L
.83173 .52669 L
.83625 .53981 L
.8406 .55243 L
.84524 .56586 L
.84947 .57813 L
s
.78414 .47176 m
.78851 .47415 L
.79327 .47677 L
.79774 .47922 L
.80203 .48158 L
.80661 .4841 L
.81101 .48652 L
.81569 .48909 L
.8202 .49157 L
.82454 .49395 L
.82916 .49648 L
.8336 .49893 L
.83788 .50127 L
.84243 .50377 L
.8468 .50618 L
.85146 .50874 L
.85595 .5112 L
.86026 .51357 L
.86485 .51609 L
.86927 .51852 L
.87397 .5211 L
.87849 .52359 L
.88285 .52598 L
.88748 .52852 L
.89171 .53085 L
s
.82638 .60332 m
.83075 .59125 L
.83551 .57808 L
.83998 .56571 L
.84427 .55382 L
.84885 .54116 L
.85325 .52898 L
.85793 .51603 L
.86244 .50355 L
.86678 .49155 L
.8714 .47878 L
.87584 .46648 L
.88012 .45466 L
.88467 .44207 L
.88905 .42996 L
.8937 .41707 L
.89819 .40467 L
.9025 .39273 L
.90709 .38003 L
.91151 .3678 L
.91621 .35481 L
.92073 .34229 L
.92509 .33024 L
.92972 .31743 L
.93395 .30572 L
s
.86863 .55147 m
.87299 .52969 L
.87775 .50595 L
.88222 .48365 L
.88652 .4622 L
.89109 .43937 L
.89549 .41739 L
.90018 .39403 L
.90469 .37153 L
.90902 .34988 L
.91364 .32685 L
.91808 .30467 L
.92236 .28334 L
.92691 .26064 L
.93129 .23879 L
.93594 .21555 L
.94043 .19317 L
.94474 .17165 L
.94933 .14874 L
.95375 .12669 L
.95845 .10325 L
.96297 .08067 L
.96733 .05895 L
.97196 .03584 L
.97619 .01472 L
s
0 g
.007 w
.07759 .30011 m
.08555 .29995 L
.09428 .2998 L
.09868 .29975 L
.10109 .29972 L
.10338 .2997 L
.10551 .29969 L
.10671 .29969 L
.10782 .29968 L
.10876 .29968 L
.10978 .29968 L
.11086 .29968 L
.11186 .29968 L
.11244 .29968 L
.11306 .29968 L
.11417 .29969 L
.11549 .29969 L
.11668 .2997 L
.11904 .29972 L
.12127 .29975 L
.1254 .29981 L
.12987 .2999 L
.13996 .30019 L
.14924 .30053 L
.16736 .3013 L
.1762 .30164 L
.18039 .30177 L
.18427 .30186 L
.18621 .3019 L
.18827 .30193 L
.18926 .30195 L
.19033 .30196 L
.19095 .30196 L
.19151 .30196 L
.19262 .30197 L
.19357 .30197 L
.19446 .30197 L
.19543 .30197 L
.19647 .30196 L
.19756 .30195 L
.19859 .30194 L
.20052 .30191 L
.20264 .30186 L
.20487 .30179 L
.20889 .30162 L
.2132 .30138 L
.21795 .30102 L
.22697 .30008 L
.2352 .29888 L
.24471 .2971 L
Mistroke
.25373 .29501 L
.28766 .28444 L
.30661 .27785 L
.32376 .27266 L
.33237 .27067 L
.33722 .2698 L
.34167 .26918 L
.34356 .26897 L
.34558 .26879 L
.34674 .26871 L
.3478 .26864 L
.3488 .26859 L
.34987 .26854 L
.35097 .26851 L
.352 .2685 L
.3531 .26849 L
.35373 .26849 L
.35431 .2685 L
.35537 .26852 L
.35634 .26856 L
.3574 .2686 L
.35852 .26867 L
.36081 .26885 L
.36297 .26908 L
.36701 .26967 L
.37136 .27054 L
.37606 .27176 L
.38455 .27471 L
.39237 .27828 L
.40905 .28849 L
.42737 .30308 L
.4632 .33549 L
.47971 .34831 L
.48904 .35391 L
.4935 .35604 L
.49768 .35768 L
.50202 .35898 L
.50432 .35949 L
.50551 .35971 L
.5068 .35991 L
.50808 .36006 L
.50927 .36017 L
.50992 .36021 L
.51052 .36024 L
.51121 .36027 L
.51186 .36028 L
.51302 .36027 L
.51409 .36024 L
.51526 .36016 L
.51585 .36011 L
Mistroke
.5165 .36004 L
.51769 .35989 L
.51882 .35971 L
.52094 .35928 L
.52323 .35868 L
.52572 .35786 L
.53019 .35594 L
.53434 .35364 L
.54373 .34665 L
.55256 .33779 L
.56907 .31578 L
.60329 .25407 L
.62064 .22039 L
.63968 .18758 L
.64843 .17536 L
.65324 .16967 L
.6578 .16505 L
.66205 .16147 L
.66666 .15841 L
.66869 .15735 L
.67085 .15643 L
.67269 .15581 L
.67472 .15531 L
.6758 .15512 L
.67681 .155 L
.67791 .15491 L
.67853 .15489 L
.67909 .15489 L
.68022 .15493 L
.68086 .15498 L
.68145 .15505 L
.68254 .15521 L
.68368 .15545 L
.6857 .15602 L
.6876 .15674 L
.6919 .15906 L
.69429 .16076 L
.69656 .16264 L
.70082 .16687 L
.7104 .17975 L
.71894 .19499 L
.72802 .21486 L
.74434 .25864 L
.78129 .37773 L
.79985 .43399 L
.80799 .45503 L
.8169 .47447 L
.82107 .48206 L
.82553 .48901 L
.82939 .49398 L
Mistroke
.83358 .49822 L
.83604 .50013 L
.83831 .50151 L
.84048 .50246 L
.84157 .50281 L
.84219 .50296 L
.84278 .50308 L
.84387 .50324 L
.84486 .5033 L
.84594 .50328 L
.84711 .50315 L
.84812 .50296 L
.84921 .50266 L
.85023 .50229 L
.85116 .50189 L
.85322 .50074 L
.85548 .4991 L
.86005 .49452 L
.86428 .48877 L
.86823 .48211 L
.87714 .46256 L
.88669 .43492 L
.90503 .36486 L
.92241 .28309 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo000KOol0
0`00Oomoo`3oOol3Ool001]oo`03001oogoo0?moo`=oo`006goo00<007ooOol0ogoo0goo000KOol0
0`00Oomoo`3oOol3Ool001]oo`03001oogoo0?Yoo`03O01oogoo00Eoo`006goo0P00ngoo00=l07oo
Ool01Goo000KOol00`00Oomoo`3jOol00g`0Oomoo`05Ool001]oo`03001oogoo0?Yoo`03O01oogoo
00Eoo`006goo00<007ooOol0nGoo00=l07ooOol01Woo000KOol00`00Oomoo`3iOol00g`0Oomoo`06
Ool001]oo`03001oogoo0?Uoo`03O01oogoo00Ioo`006goo0P00nWoo00=l07ooOol01Woo000KOol0
0`00Oomoo`3iOol00g`0Oomoo`06Ool001]oo`03001oogoo0?Qoo`03O01oogoo00Moo`006goo00<0
07ooOol0n7oo00=l07ooOol01goo000KOol00`00Oomoo`3hOol00g`0Oomoo`07Ool001]oo`03001o
ogoo0?Moo`03O01oogoo00Qoo`006goo0P00n7oo00=l07ooOol027oo000KOol00`00Oomoo`3gOol0
0g`0Oomoo`08Ool001]oo`03001oogoo0?Moo`03O01oogoo00Qoo`006goo00<007ooOol0mgoo00=l
07ooOol027oo0007Ool40003Ool20004Ool20005Ool00`00Oomoo`3fOol00g`0Oomoo`09Ool000Qo
o`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`0017oo00<007ooOol0mWoo00=l07ooOol0
2Goo00000goo000000030003Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo009o
o`<00?Ioo`03O01oogoo00Uoo`002Woo00@007ooOol0009oo`04001oogoo0002Ool00`00Oomoo`02
Ool00`00Oomoo`3fOol00g`0Oomoo`09Ool000Moo`04001oogoo0002Ool01000Oomoo`000Woo00@0
07ooOol000Aoo`03001oogoo0?Ioo`03O01oogoo00Uoo`0027oo0P0017oo0P0017oo0P001Goo00<0
07ooOol0mWoo00=l07ooOol02Goo000KOol00`00Oomoo`2POol00g`0Oomoo`1BOol00g`0Oomoo`0:
Ool001]oo`03001oogoo0:5oo`03O01oogoo055oo`03O01oogoo00Yoo`006goo0P00XWoo00=l07oo
Ool0DGoo00=l07ooOol02Woo000KOol00`00Oomoo`2ROol00g`0Oomoo`1@Ool00g`0Oomoo`0:Ool0
01]oo`03001oogoo0:=oo`03O01oogoo04moo`03O01oogoo00Yoo`006goo00<007ooOol0Xgoo00El
07ooOomoog`004aoo`03O01oogoo00]oo`006goo00<007ooOol0Y7oo00=l07ooO0001Goo00=l07oo
Ool0AGoo00=l07ooOol02goo000KOol00`00Oomoo`2TOol2O006Ool00g`0Oomoo`15Ool00g`0Oomo
o`0;Ool001]oo`800:Ioo`03O01oogoo00Aoo`03O01oogoo04Aoo`03O01oogoo00aoo`006goo00<0
07ooOol0Y7oo0W`01goo00=l07ooOol0@goo00=l07ooOol037oo000KOol00`00Oomoo`2TOol00g`0
Ooml0006Ool00g`0Oomoo`02Ool2O00oOol00g`0Oomoo`0<Ool001]oo`03001oogoo0:=oo`05O01o
ogooOoml0005Ool00g`0Oomoo`02O011Ool00g`0Oomoo`0<Ool001]oo`03001oogoo0:=oo`03O01o
ogoo009oo`03O01oogoo00=oo`9l04=oo`03O01oogoo00aoo`006goo00<007ooOol0XWoo00=l07oo
Ool00goo00Al07ooOomoo`=l04=oo`03O01oogoo00eoo`006goo00<007ooOol0XWoo00=l07ooOol0
17oo0g`00goo00=l07ooOol0@7oo00=l07ooOol03Goo000KOol2002ROol00g`0Oomoo`04Ool2O005
Ool00g`0Oomoo`10Ool00g`0Oomoo`0=Ool001]oo`03001oogoo0:1oo`03O01oogoo00=oo`9l009o
o`03O01oogoo009oo`03O01oogoo041oo`03O01oogoo00eoo`006goo00<007ooOol0X7oo00=l07oo
Ool01`0000=l07ooOol00goo00=l07ooOol0?goo00=l07ooOol03Goo000KOol00`00Oomoo`2OOol0
0g`0Ooml00020006Ool20004Ool00g`0Oomoo`0oOol
00g`0Oomoo`0=Ool001]oo`03001oogoo09mo
o`9l0003001oogoo00Moo`03001l07oo009oo`03O01oogoo03ioo`03O01oogoo00ioo`006goo00<0
07ooOol0WGoo0W`000=oo`00Ool02Woo00D007`0Oomoog`0041oo`03O01oogoo00ioo`006goo0P00
Vgoo0g`000=oog`0000037oo00<007`0Ool00Woo00=l07ooOol0?Goo00=l07ooOol03Woo000KOol0
0`00Oomoo`2IOol00g`0Oomoo`02Ool00`00Oomoo`0<Ool01@00O01oogooO000?goo00=l07ooOol0
3Woo000KOol00`00Oomoo`2FOol3O004Ool00g`0001oo`0>Ool01000Oomoog`0?goo00=l07ooOol0
3Woo000KOol00`00Oomoo`2DOol2O006Ool00g`0001oo`0@Ool00`00Ooml000oOol00g`0Oomoo`0>
Ool000Moo`<000Aoo`8000Aoo`8000Eoo`03001oogoo09]oo`03O00007oo015oo`04001l07ooO00m
Ool00g`0Oomoo`0?Ool000Qoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`0017oo00<0
07ooOol0Vgoo00<007ooOol04Woo00<007`0O000?Goo00=l07ooOol03goo00000goo000000030002
Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Aoo`<009Yoo`03O00007oo01=oo`03
001l07`003eoo`03O01oogoo00moo`0027oo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo
0004Ool00`00Oomoo`2JOol00`00O01oo`0DOol00`00O01l000lOol00g`0Oomoo`0?Ool000Qoo`03
001oogoo009oo`04001oogoo0002Ool01000Oomoo`0017oo00<007ooOol0VGoo00=l0000Ool05Goo
00<007`0O000?7oo00=l07ooOol03goo0007Ool20005Ool20004Ool20005Ool00`00Oomoo`2IOol0
0`00O01oo`0FOol00`00O01l000jOol00g`0Oomoo`0@Ool001]oo`03001oogoo09Qoo`03001l07oo
01Moo`03001l07`003Yoo`03O01oogoo011oo`006goo00<007ooOol0Ugoo00=l0000Ool06Goo00<0
07`0Ool0>Goo00=l07ooOol047oo000KOol2002HOol00`00O01oo`0IOol00`00Ooml000hOol00g`0
Oomoo`0AOol001]oo`03001oogoo09Ioo`03O00007oo01]oo`03001l07`003Moo`03O01oogoo015o
o`006goo00<007ooOol0UWoo00<007`0Ool06goo00<007`0O000=goo00=l07ooOol04Goo000KOol0
0`00Oomoo`2EOol00g`0001oo`0MOol00`00Ooml000fOol00g`0Oomoo`0AOol001]oo`03001oogoo
09Eoo`03001l07oo01eoo`03001l07`003Ioo`03O01oogoo015oo`006goo00<007ooOol0U7oo00=l
0000Ool07Woo00@007`0Ooml03Aoo`03O01oogoo019oo`006goo0P00UGoo00<007ooOol07goo00<0
07ooO000=7oo00=l07ooOol04Woo000KOol00`00Oomoo`2DOol00`00Oomoo`0OOol01000Oomoog`0
<goo00=l07ooOol04Woo000KOol00`00Oomoo`2COol00`00Oomoo`0QOol00`00Ooml000cOol00g`0
Oomoo`0BOol001]oo`03001oogoo099oo`03O00007oo029oo`04001oogooO00bOol00g`0Oomoo`0B
Ool001]oo`03001oogoo095oo`03O00007oo02=oo`05O00007ooOoml000aOol00g`0Oomoo`0BOol0
01]oo`03001oogoo04eoo`03O01oogoo045oo`03O00007oo02Aoo`04001oogooO00`Ool00g`0Oomo
o`0COol001]oo`80049oo`03O01oogoo00Yoo`9l041oo`03O00007oo02Eoo`05001oogooOoml000_
Ool00g`0Oomoo`0COol001]oo`03001oogoo049oo`Al00Yoo`04O01oog`0O00lOol00g`0001oo`0V
Ool01000Oomoog`0;goo00=l07ooOol04goo000KOol00`00Oomoo`0KOol40003Ool20003Ool3000L
Ool4O003Ool5O00EOol00`00Oomoo`03Ool20003Ool3000JOol30004Ool2000GOol30003Ool50002
Ool00`00O01oo`02Ool3000GOol30003Ool30008Ool00g`0Oomoo`0COol001]oo`03001oogoo01ao
o`03001oogoo00=oo`8000Ioo`03001oogoo01Uoo`Ql00Aoo`03O01oogoo019oo`03001oogoo00=o
o`8000Ioo`03001oogoo01Moo`03O00007oo00=oo`04001oogoo000GOol00`00Oomoo`03Ool01000
Ooml00000Woo00<007`0Ool01Goo00<007ooOol05Goo00<007ooOol01Goo00<007ooOol01Goo00=l
07ooOol04goo000KOol00`00Oomoo`0MOol00`00Oomoo`0:Ool00`00Oomoo`0EOol2O00=0002Ool2
O00COol00`00Oomoo`0:Ool00`00Oomoo`0FOol00g`000000004Ool01000Oomoo`005goo00<007oo
Ool017oo00@007`0Ool000=oo`03O01oogoo00=oo`03001oogoo01Eoo`03001oogoo00Eoo`03001o
ogoo00Eoo`03O01oogoo01=oo`006goo00<007ooOol07Woo00<007ooOol01Woo0`005Goo00=l0000
00000P000goo0`001goo1@004Woo00<007ooOol01goo0`0067oo00Al0000Ool000Aoo`04001oogoo
000GOol00`00Oomoo`05Ool00g`0Ool00006Ool3000HOol00`00Oomoo`02Ool30007Ool00g`0Oomo
o`0DOol001]oo`8001aoo`04001oogoo0008Ool00`00Oomoo`0@Ool2O0040007Ool00`00Oomoo`0;
Ool017`0000007`047oo00<007ooOol01Woo00<007ooOol067oo00Al0000Ool000Aoo`04001oogoo
000GOol00`00Oomoo`02Ool01P00Oomoo`00O00000Ioo`03001oogoo01Qoo`03001oogoo009oo`03
001oogoo00Moo`03O01oogoo01Aoo`006goo00<007ooOol077oo0P002Goo10002Woo17`00`0000=l
07ooOol027oo100037oo00=l0000O0000g`02Goo100027oo10005Woo00=l0000Ool00P001Goo0P00
5goo0P001Goo0P0000Aoog`0O00000Eoo`@001Ioo`8000Aoo`@000Ioo`03O01oogoo01Aoo`006goo
00<007ooOol0=goo0P0017`06goo00=l0000Ool00Woo0g`0;7oo00=l0000Ool0:Woo00=l07oo0000
;goo00<007ooOol057oo000KOol00`00Oomoo`0dOol30004O00OOol2000_Ool00g`0001oo`0/Ool0
0g`0001oo`0^Ool00`00Oomoo`0DOol001]oo`03001oogoo035oo`<0009l02Eoo`03O00007oo02eo
o`03001l
07oo02aoo`9l0003001oogoo02]oo`03O00007oo01Eoo`006goo00<007ooOol0;Woo0`00
00=l07ooOol0:7oo00=l0000Ool0;7oo00<007ooOol0;7oo0W`000<007ooOol0:goo00<007ooOol0
5Goo0005OolC0004O00A00000g`00000000L00000g`00000000/00000g`00000001K00000g`00000
0014000000aoo`ml0003001oogoo00Eoo`03001oogoo00Aoo`03001oogoo01T000Ul0003Ool007oo
00Ioo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo
00Aoo`8000Ioo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Aoo`06
001oogooOoml00000Woo00<007ooO00017oo00<007ooOol01Goo00<007ooOol017oo00<007ooOol0
1Goo00<007ooOol01Goo00<007ooOol017oo00<007`000001Goo00<007ooOol017oo00<007ooOol0
1Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007`0000017oo00<007ooOol0
1Goo00<007ooOol017oo00<007ooOol00Goo000KOol00`00Oomoo`0POol3O0000`00Oomoo`0SOol0
0`00Oomoo`0DOol00g`0001oo`0;Ool00`00Oomoo`0GOol00g`0001oo`02Ool2O005Ool00`00Oomo
o`0SOol01000Ooml00008Woo00<007ooOol01Woo00=l0000Ool00Woo00=l07ooOol04Goo000KOol0
0`00Oomoo`0MOol3O011Ool00g`0001l000TOol01@00O01oogooO000;goo00=l0000Ool0:Woo00=l
0000Ool00Woo00=l07ooOol04Goo000KOol00`00Oomoo`1ROol00g`0001l000SOol01000Oomoog`0
<7oo00=l0000Ool0:Woo00D007ooOomoog`001Aoo`006goo00<007ooOol0Hgoo00=l0000O0008Goo
00@007`0Ooml039oo`03O00007oo02Uoo`05001oogooOoml000DOol001]oo`8006Eoo`03O00007`0
021oo`04001oogooO00bOol00g`0001oo`0XOol00g`0001oo`02Ool00g`0Oomoo`0BOol001]oo`03
001oogoo06Eoo`04O00007`0O00MOol01000O01l07`0<goo00=l0000Ool0:7oo00El0000Oomoog`0
01Eoo`006goo00<007ooOol0Igoo00<007ooO0006goo00<007`0O000=Woo00=l0000Ool09goo00D0
07ooOomoog`001Eoo`006goo00<007ooOol0J7oo00<007ooO0006Woo00<007`0Ool0=Woo00=l0000
Ool09goo00@007ooOoml01Ioo`006goo00<007ooOol0JGoo0P0000=l07ooOol05Woo00<007`0Ool0
=goo00=l0000Ool09goo00@007ooOoml01Ioo`006goo00<007ooOol0JWoo00=l0000Ool05Woo00<0
07`0Ool0>7oo0W`000<007ooOol09Goo00<007ooO0005goo000KOol2001VOol00g`0Oomoo`03Ool0
0g`0001oo`0DOol00`00Ooml000jOol00g`0001oo`0UOol017`0001oog`05goo000KOol00`00Oomo
o`1VOol3O003Ool00g`0001oo`0BOol00`00Ooml000kOol00g`0001oo`0UOol01000Oomoog`05goo
000KOol00`00Oomoo`1YOol3O00017ooO000000047oo00@007ooOoml03]oo`03O00007oo02Eoo`04
001oogooO00GOol001]oo`03001oogoo06aoo`Al0003001oogoo00]oo`03O00007oo009oo`03O01o
ogoo03Yoo`03O00007oo02Aoo`03001oog`001Qoo`006goo00<007ooOol0L7oo00=l000000002Goo
0`000goo00=l07ooOol0>goo00=l0000Ool097oo00<007ooO00067oo000KOol00`00Oomoo`1aOol0
0g`0Ool0000800000g`0Oomoo`02Ool00g`0Oomoo`0mOol00`00Oomoo`0SOol00`00Ooml000HOol0
01]oo`03001oogoo079oo`04O01oogooOol6O004Ool00g`0Oomoo`0nOol00g`0001oo`0ROol01000
O01oog`067oo000KOol2001dOol2O004Ool4O003Ool00g`0Oomoo`0oOol00`00Oomoo`0QOol00`00
Ooml000IOol001]oo`03001oogoo07Eoo`04O01oogooO004Ool3O012Ool00`00Oomoo`0QOol00`00
Ooml000IOol001]oo`03001oogoo07Eoo`03O01oog`000Moo`El03ioo`03O00007oo025oo`03001o
og`001Uoo`006goo00<007ooOol0MGoo0W`01goo00=l07ooOol0@Goo00=l0000Ool087oo00<007`0
O0006Woo000KOol00`00Oomoo`1dOol017`0Oomoog`01Woo00=l07ooOol0@Woo00<007ooOol07goo
00<007`0Ool06Woo000KOol00`00Oomoo`1cOol00g`0Oomoo`07Ool00g`0Oomoo`13Ool00`00O01o
o`0OOol00`00O01oo`0JOol001]oo`8007Aoo`03O01oogoo00Ioo`03O01oogoo04Aoo`03O00007oo
01moo`03001l07oo01Yoo`006goo00<007ooOol0LWoo00=l07ooOol0Cgoo00<007ooOol07Goo00<0
07`0Ool06goo000KOol00`00Oomoo`1aOol00g`0Oomoo`1@Ool00`00Oomoo`0MOol00`00O01oo`0K
Ool001]oo`03001oogoo0<Eoo`03001oogoo01aoo`03001l07oo01]oo`001goo0`0017oo0P0017oo
0P001Goo00<007ooOol0aGoo00<007ooOol06goo00<007`0Ool077oo0008Ool00`00Oomoo`02Ool0
1000Oomoo`000Woo00@007ooOol000Aoo`03001oogoo0<Eoo`03001l07oo01]oo`03001l07oo01ao
o`0027oo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0004Ool30036Ool00`00Oomoo`0J
Ool00`00O01oo`0LOol000Qoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`0017oo00<0
07ooOol0aWoo00<007ooOol06Woo00<007ooOol077oo0008Ool00`00Oomoo`02Ool01000Oomoo`00
0Woo00@007ooOol000Aoo`03001oogoo0<Ioo`03001l07oo01Uoo`03001l07oo01eoo`001goo0P00
1Goo0P0017oo0P001Goo00<007ooOol0agoo00<007ooOol067oo00<007`0Ool07Goo000KOol00`00
Oomoo`37Ool00`00Oomoo`0HOol00`00O01oo`0MOol001]oo`03001oogoo0<Moo`03001l07oo01Qo
o`03001l07oo01eoo`006goo0P00b7oo00=l0000Ool05goo00<007ooO0007Woo000KOol00`00Oomo
o`38Ool00`00Oomoo`0FOol00`00O01oo`0NOol001]oo`03001oog
oo0<Qoo`03001oogoo01Eoo`03
O00007`001moo`006goo00<007ooOol0b7oo00=l0000Ool05Goo00<007ooO0007goo000KOol00`00
Oomoo`39Ool00`00Oomoo`0DOol00`00Ooml000OOol001]oo`03001oogoo0<Uoo`03001l07oo01Ao
o`03001oog`001moo`006goo0P00bWoo00=l0000Ool04goo00@007ooOoml01moo`006goo00<007oo
Ool0bWoo00<007ooOol04Woo00<007ooO00087oo000KOol00`00Oomoo`3:Ool00`00O01oo`0BOol0
0`00Ooml000POol001]oo`03001oogoo0<]oo`03001oogoo011oo`04001oogooO00POol001]oo`03
001oogoo0<]oo`03001oogoo011oo`04001oogooO00POol001]oo`03001oogoo0<]oo`03O00007oo
00moo`04001l07ooO00QOol001]oo`800<Eoo`9l00Ioo`03001oogoo00ioo`04001oogooO00QOol0
01]oo`03001oogoo0<Ioo`9l00Aoo`03O00007oo00eoo`05001l07ooOoml000QOol001]oo`03001o
ogoo0<Qoo`06O01oogooOoml00003Woo00@007ooOoml029oo`006goo00<007ooOol0bGoo0W`00Woo
00=l0000Ool02goo00D007`0Oomoog`0029oo`006goo00<007ooOol0bgoo0g`000<007ooOol02Woo
00D007ooOomoog`0029oo`006goo00<007ooOol0cGoo0W`00P002Goo00<007`0Ool00Woo00=l07oo
Ool087oo000KOol2003?Ool2O0000goo001oo`06Ool00`00Ooml0003Ool00g`0Oomoo`0POol001]o
o`03001oogoo0<ioo`05O01oog`0O0000006Ool00`00Ooml0002Ool00g`0Oomoo`0QOol001]oo`03
001oogoo0<moo`03O01oogoo00<00006Ool00000001oog`00goo00=l07ooOol08Goo000KOol00`00
Oomoo`3?Ool00g`0Oomoo`02Ool30003Ool01G`0OomoogooO0008goo0007Ool40003Ool20004Ool2
0005Ool00`00Oomoo`3@Ool00g`0Oomoo`04Ool017`0Oomoog`00goo00=l07ooOol08Goo0008Ool0
0`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Aoo`03001oogoo0=1oo`03O01oogoo00Eo
o`9l00Aoo`03O01oogoo025oo`002Goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomo
o`02Ool3003@Ool00g`0Oomoo`06Ool3O002Ool00g`0Oomoo`0QOol000Yoo`04001oogoo0002Ool0
1000Oomoo`000Woo00<007ooOol00Woo00<007ooOol0d7oo00=l07ooOol01Woo00=l07ooOol00W`0
97oo0007Ool01000Oomoo`000Woo00@007ooOol0009oo`04001oogoo0004Ool00`00Oomoo`3AOol0
0g`0Oomoo`04Ool00g`0Oomoo`02Ool3O00ROol000Qoo`8000Aoo`8000Aoo`8000Eoo`03001oogoo
0=5oo`03O01oogoo00Aoo`03O01oogoo009oo`04O01oogooO00QOol001]oo`03001oogoo0=5oo`03
O01oogoo00=oo`03O01oogoo00=oo`04O01oogooOol2O00OOol001]oo`03001oogoo0=5oo`03O01o
ogoo00=oo`03O01oogoo00=oo`03O01oogoo029oo`006goo0P00dgoo00El07ooOomoog`000Ioo`03
O01oogoo029oo`006goo00<007ooOol0dWoo00El07ooOomoog`000Ioo`03O01oogoo029oo`006goo
00<007ooOol0dWoo00El07ooOomoog`000Eoo`03O01oogoo02=oo`006goo00<007ooOol0dgoo00Al
07ooOoml00Eoo`03O01oogoo02=oo`006goo00<007ooOol0dgoo00=l07ooO0001Woo00=l07ooOol0
8goo000KOol00`00Oomoo`3DOol2O00/Ool001]oo`800=Eoo`9l02aoo`006goo00<007ooOol0e7oo
0W`0;7oo000KOol00`00Oomoo`3COol00g`0Ooml000/Ool001]oo`03001oogoo0==oo`03O01oog`0
02aoo`006goo00<007ooOol0dgoo00=l07ooO000;7oo000KOol00`00Oomoo`3BOol01G`0Oomoogoo
O000:goo000KOol2003COol01G`0OomoogooO000:goo000KOol00`00Oomoo`3BOol00g`0Oomoo`0]
Ool001]oo`03001oogoo0=5oo`03O01oogoo02ioo`006goo00<007ooOol0dGoo00=l07ooOol0;Woo
000KOol00`00Oomoo`3AOol00g`0Oomoo`0^Ool001]oo`03001oogoo0=5oo`03O01oogoo02ioo`00
6goo00<007ooOol0d7oo00=l07ooOol0;goo000KOol2003AOol00g`0Oomoo`0_Ool001]oo`03001o
ogoo0?moo`=oo`006goo00<007ooOol0ogoo0goo000KOol00`00Oomoo`3oOol3Ool001]oo`03001o
ogoo0?moo`=oo`00ogoo8Goo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1.81885, -281.087,
  0.0660962, 3.28148}}],

Cell[BoxData[
    FormBox[
      TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
        False,
        Editable->False], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ShowTangentLines[x\^2\ Sin[x]\  - x\  + 1, {x, 0, 5  \[Pi]}, 20,
      PlotStyle -> RGBColor[1, 0, 0], TangentLineStyle -> RGBColor[0, 1, 0]]
      \)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0775922 0.0537826 0.299025 0.0010833 [
[.21205 .28653 -9 -9 ]
[.21205 .28653 9 0 ]
[.34651 .28653 -3 -9 ]
[.34651 .28653 3 0 ]
[.48096 .28653 -9 -9 ]
[.48096 .28653 9 0 ]
[.61542 .28653 -6 -9 ]
[.61542 .28653 6 0 ]
[.74988 .28653 -12 -9 ]
[.74988 .28653 12 0 ]
[.88433 .28653 -6 -9 ]
[.88433 .28653 6 0 ]
[.06509 .08237 -24 -4.5 ]
[.06509 .08237 0 4.5 ]
[.06509 .1907 -24 -4.5 ]
[.06509 .1907 0 4.5 ]
[.06509 .40736 -18 -4.5 ]
[.06509 .40736 0 4.5 ]
[.06509 .51569 -18 -4.5 ]
[.06509 .51569 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21205 .29903 m
.21205 .30528 L
s
[(2.5)] .21205 .28653 0 1 Mshowa
.34651 .29903 m
.34651 .30528 L
s
[(5)] .34651 .28653 0 1 Mshowa
.48096 .29903 m
.48096 .30528 L
s
[(7.5)] .48096 .28653 0 1 Mshowa
.61542 .29903 m
.61542 .30528 L
s
[(10)] .61542 .28653 0 1 Mshowa
.74988 .29903 m
.74988 .30528 L
s
[(12.5)] .74988 .28653 0 1 Mshowa
.88433 .29903 m
.88433 .30528 L
s
[(15)] .88433 .28653 0 1 Mshowa
.125 Mabswid
.10448 .29903 m
.10448 .30278 L
s
.13137 .29903 m
.13137 .30278 L
s
.15827 .29903 m
.15827 .30278 L
s
.18516 .29903 m
.18516 .30278 L
s
.23894 .29903 m
.23894 .30278 L
s
.26583 .29903 m
.26583 .30278 L
s
.29272 .29903 m
.29272 .30278 L
s
.31961 .29903 m
.31961 .30278 L
s
.3734 .29903 m
.3734 .30278 L
s
.40029 .29903 m
.40029 .30278 L
s
.42718 .29903 m
.42718 .30278 L
s
.45407 .29903 m
.45407 .30278 L
s
.50785 .29903 m
.50785 .30278 L
s
.53474 .29903 m
.53474 .30278 L
s
.56164 .29903 m
.56164 .30278 L
s
.58853 .29903 m
.58853 .30278 L
s
.64231 .29903 m
.64231 .30278 L
s
.6692 .29903 m
.6692 .30278 L
s
.69609 .29903 m
.69609 .30278 L
s
.72298 .29903 m
.72298 .30278 L
s
.77677 .29903 m
.77677 .30278 L
s
.80366 .29903 m
.80366 .30278 L
s
.83055 .29903 m
.83055 .30278 L
s
.85744 .29903 m
.85744 .30278 L
s
.0507 .29903 m
.0507 .30278 L
s
.02381 .29903 m
.02381 .30278 L
s
.91122 .29903 m
.91122 .30278 L
s
.93811 .29903 m
.93811 .30278 L
s
.96501 .29903 m
.96501 .30278 L
s
.9919 .29903 m
.9919 .30278 L
s
.25 Mabswid
0 .29903 m
1 .29903 L
s
.07759 .08237 m
.08384 .08237 L
s
[(-200)] .06509 .08237 1 0 Mshowa
.07759 .1907 m
.08384 .1907 L
s
[(-100)] .06509 .1907 1 0 Mshowa
.07759 .40736 m
.08384 .40736 L
s
[(100)] .06509 .40736 1 0 Mshowa
.07759 .51569 m
.08384 .51569 L
s
[(200)] .06509 .51569 1 0 Mshowa
.125 Mabswid
.07759 .10403 m
.08134 .10403 L
s
.07759 .1257 m
.08134 .1257 L
s
.07759 .14736 m
.08134 .14736 L
s
.07759 .16903 m
.08134 .16903 L
s
.07759 .21236 m
.08134 .21236 L
s
.07759 .23403 m
.08134 .23403 L
s
.07759 .25569 m
.08134 .25569 L
s
.07759 .27736 m
.08134 .27736 L
s
.07759 .32069 m
.08134 .32069 L
s
.07759 .34236 m
.08134 .34236 L
s
.07759 .36402 m
.08134 .36402 L
s
.07759 .38569 m
.08134 .38569 L
s
.07759 .42902 m
.08134 .42902 L
s
.07759 .45069 m
.08134 .45069 L
s
.07759 .47235 m
.08134 .47235 L
s
.07759 .49402 m
.08134 .49402 L
s
.07759 .0607 m
.08134 .0607 L
s
.07759 .03903 m
.08134 .03903 L
s
.07759 .01737 m
.08134 .01737 L
s
.07759 .53735 m
.08134 .53735 L
s
.07759 .55902 m
.08134 .55902 L
s
.07759 .58068 m
.08134 .58068 L
s
.07759 .60235 m
.08134 .60235 L
s
.25 Mabswid
.07759 0 m
.07759 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 1 0 r
.5 Mabswid
.02381 .30119 m
.02817 .3011 L
.03293 .30101 L
.0374 .30092 L
.0417 .30083 L
.04627 .30074 L
.05068 .30065 L
.05536 .30056 L
.05987 .30047 L
.06421 .30038 L
.06882 .30029 L
.07327 .3002 L
.07754 .30011 L
.08209 .30002 L
.08647 .29993 L
.09113 .29984 L
.09561 .29975 L
.09993 .29966 L
.10452 .29957 L
.10894 .29948 L
.11363 .29938 L
.11816 .29929 L
.12251 .2992 L
.12714 .29911 L
.13137 .29903 L
s
.06605 .29914 m
.07041 .29919 L
.07517 .29924 L
.07964 .29929 L
.08394 .29933 L
.08852 .29939 L
.09292 .29943 L
.0976 .29949 L
.10211 .29953 L
.10645 .29958 L
.11106 .29963 L
.11551 .29968 L
.11978 .29973 L
.12433 .29978 L
.12871 .29983 L
.13337 .29988 L
.13785 .29993 L
.14217 .29998 L
.14676 .30003 L
.15118 .30008 L
.15587 .30013 L
.1604 .30018 L
.16475 .30023 L
.16938 .30028 L
.17362 .30032 L
s
.10829 .29876 m
.11265 .29895 L
.11741 .29915 L
.12188 .29935 L
.12618 .29953 L
.13076 .29973 L
.13516 .29992 L
.13984 .30012 L
.14435 .30032 L
.14869 .3005 L
.15331 .3007 L
.15775 .30089 L
.16202 .30108 L
.16657 .30127 L
.17095 .30146 L
.17561 .30166 L
.18009 .30186 L
.18441 .30204 L
.189 .30224 L
.19342 .30243 L
.19811 .30263 L
.20264 .30283 L
.20699 .30302 L
.21162 .30322 L
.21586 .3034 L
s
.15053 .30353 m
.1549 .30339 L
.15965 .30324 L
.16412 .3031 L
.16842 .30296 L
.173 .30281 L
.1774 .30267 L
.18208 .30252 L
.18659 .30238 L
.19093 .30224 L
.19555 .30209 L
.19999 .30195 L
.20426 .30181 L
.20881 .30166 L
.21319 .30152 L
.21785 .30137 L
.22233 .30123 L
.22665 .30109 L
.23124 .30094 L
.23566 .3008 L
.24035 .30065 L
.24488 .30051 L
.24923 .30037 L
.25386 .30022 L
.2581 .30008 L
s
.19277 .30848 m
.19714 .30752 L
.2019 .30648 L
.20636 .3055 L
.21066 .30456 L
.21524 .30356 L
.21964 .3026 L
.22432 .30157 L
.22883 .30059 L
.23317 .29964 L
.23779 .29862 L
.24223 .29765 L
.2465 .29672 L
.25105 .29572 L
.25543 .29476 L
.26009 .29374 L
.26457 .29276 L
.26889 .29182 L
.27348 .29081 L
.2779 .28984 L
.28259 .28881 L
.28712 .28782 L
.29147 .28687 L
.29611 .28586 L
.30034 .28493 L
s
.23501 .30295 m
.23938 .30142 L
.24414 .29975 L
.24861 .29817 L
.2529 .29666 L
.25748 .29505 L
.26188 .29351 L
.26656 .29186 L
.27107 .29027 L
.27541 .28875 L
.28003 .28712 L
.28447 .28556 L
.28875 .28406 L
.2933 .28246 L
.29767 .28092 L
.30233 .27928 L
.30682 .27771 L
.31113 .27619 L
.31572 .27457 L
.32014 .27302 L
.32484 .27137 L
.32936 .26978 L
.33372 .26825 L
.33835 .26662 L
.34258 .26513 L
s
.27725 .28224 m
.28162 .28132 L
.28638 .28032 L
.29085 .27939 L
.29514 .27848 L
.29972 .27752 L
.30412 .2766 L
.3088 .27562 L
.31331 .27467 L
.31765 .27376 L
.32227 .27279 L
.32671 .27186 L
.33099 .27096 L
.33554 .27 L
.33992 .26908 L
.34457 .26811 L
.34906 .26716 L
.35337 .26626 L
.35796 .26529 L
.36238 .26437 L
.36708 .26338 L
.3716 .26243 L
.37596 .26152 L
.38059 .26054 L
.38482 .25965 L
s
.3195 .25735 m
.32386 .25846 L
.32862 .25967 L
.33309 .2608 L
.33739 .26189 L
.34196 .26305 L
.34636 .26417 L
.35105 .26536 L
.35556 .2665 L
.35989 .2676 L
.36451 .26877 L
.36895 .2699 L
.37323 .27099 L
.37778 .27214 L
.38216 .27325 L
.38681 .27443 L
.3913 .27557 L
.39561 .27667 L
.4002 .27783 L
.40462 .27895 L
.40932 .28014 L
.41384 .28129 L
.4182 .2824 L
.42283 .28357 L
.42706 .28465 L
s
.36174 .25162 m
.3661 .255 L
.37086 .25869 L
.37533 .26215 L
.37963 .26548 L
.3842 .26903 L
.38861 .27244 L
.39329 .27607 L
.3978 .27957 L
.40213 .28293 L
.40675 .28651 L
.41119 .28995 L
.41547 .29326 L
.42002 .29679 L
.4244 .30018 L
.42905 .30379 L
.43354 .30727 L
.43785 .31061 L
.44244 .31417 L
.44686 .31759 L
.45156 .32123 L
.45608 .32474 L
.46044 .32812 L
.46507 .33171 L
.4693 .33499 L
s
.40398 .28271 m
.40834 .2866 L
.4131 .29085 L
.41757 .29484 L
.42187 .29868 L
.42644 .30276 L
.43085 .3067 L
.43553 .31087 L
.44004 .3149 L
.44438 .31877 L
.44899 .3229 L
.45344 .32686 L
.45771 .33068 L
.46226 .33474 L
.46664 .33865 L
.47129 .34281 L
.47578 .34681 L
.48009 .35066 L
.48468 .35476 L
.4891 .35871 L
.4938 .3629 L
.49832 .36694 L
.50268 .37083 L
.50731 .37497 L
.51154 .37874 L
s
.44622 .34249 m
.45058 .34378 L
.45534 .34519 L
.45981 .34652 L
.46411 .34779 L
.46868 .34915 L
.47309 .35045 L
.47777 .35184 L
.48228 .35317 L
.48662 .35446 L
.49123 .35583 L
.49568 .35714 L
.49995 .35841 L
.5045 .35976 L
.50888 .36105 L
.51353 .36243 L
.51802 .36376 L
.52233 .36504 L
.52692 .3664 L
.53134 .36771 L
.53604 .3691 L
.54056 .37044 L
.54492 .37173 L
.54955 .3731 L
.55378 .37436 L
s
.48846 .39295 m
.49282 .38929 L
.49758 .38531 L
.50205 .38157 L
.50635 .37797 L
.51092 .37414 L
.51533 .37045 L
.52001 .36653 L
.52452 .36276 L
.52886 .35913 L
.53347 .35526 L
.53792 .35154 L
.54219 .34797 L
.54674 .34416 L
.55112 .34049 L
.55578 .33659 L
.56026 .33284 L
.56457 .32923 L
.56916 .32539 L
.57358 .32169 L
.57828 .31775 L
.58281 .31397 L
.58716 .31032 L
.59179 .30645 L
.59602 .3029 L
s
.5307 .38721 m
.53506 .37931 L
.53982 .3707 L
.54429 .36262 L
.54859 .35484 L
.55316 .34656 L
.55757 .33859 L
.56225 .33012 L
.56676 .32196 L
.5711 .31411 L
.57571 .30576 L
.58016 .29772 L
.58443 .28999 L
.58898 .28176 L
.59336 .27383 L
.59802 .26541 L
.6025 .2573 L
.60681 .24949 L
.61141 .24119 L
.61582 .23319 L
.62052 .22469 L
.62505 .2165 L
.6294 .20863 L
.63403 .20025 L
.63826 .19259 L
s
.57294 .30577 m
.5773 .29794 L
.58206 .28939 L
.58653 .28137 L
.59083 .27365 L
.59541 .26543 L
.59981 .25752 L
.60449 .24912 L
.609 .24102 L
.61334 .23323 L
.61795 .22494 L
.6224 .21696 L
.62667 .20928 L
.63122 .20111 L
.6356 .19325 L
.64026 .18489 L
.64474 .17683 L
.64906 .16909 L
.65365 .16084 L
.65807 .15291 L
.66276 .14447 L
.66729 .13635 L
.67164 .12853 L
.67627 .12021 L
.6805 .11261 L
s
.61518 .18213 m
.61954 .18011 L
.6243 .1779 L
.62877 .17584 L
.63307 .17384 L
.63765 .17173 L
.64205 .16969 L
.64673 .16752 L
.65124 .16543 L
.65558 .16342 L
.66019 .16128 L
.66464 .15923 L
.66891 .15725 L
.67346 .15514 L
.67784 .15311 L
.6825 .15096 L
.68698 .14888 L
.6913 .14688 L
.69589 .14475 L
.70031 .14271 L
.705 .14053 L
.70953 .13844 L
.71388 .13642 L
.71851 .13428 L
.72275 .13232 L
s
.65742 .09385 m
.66178 .10092 L
.66654 .10864 L
.67101 .11588 L
.67531 .12285 L
.67989 .13026 L
.68429 .1374 L
.68897 .14499 L
.69348 .1523 L
.69782 .15934 L
.70244 .16682 L
.70688 .17402 L
.71115 .18095 L
.7157 .18832 L
.72008 .19542 L
.72474 .20297 L
.72922 .21024 L
.73354 .21723 L
.73813 .22468 L
.74255 .23184 L
.74724 .23945 L
.75177 .24679 L
.75612 .25385 L
.76075 .26135 L
.76499 .26821 L
s
.69966 .11651 m
.70403 .1303 L
.70878 .14534 L
.71325 .15947 L
.71755 .17305 L
.72213 .18751 L
.72653 .20143 L
.73121 .21623 L
.73572 .23048 L
.74006 .24419 L
.74468 .25878 L
.74912 .27283 L
.75339 .28634 L
.75794 .30072 L
.76232 .31456 L
.76698 .32927 L
.77146 .34345 L
.77578 .35708 L
.78037 .37159 L
.78479 .38556 L
.78948 .4004 L
.79401 .4147 L
.79836 .42847 L
.80299 .4431 L
.80723 .45648 L
s
.7419 .26627 m
.74627 .27892 L
.75103 .29272 L
.75549 .30568 L
.75979 .31814 L
.76437 .3314 L
.76877 .34417 L
.77345 .35774 L
.77796 .37082 L
.7823 .3834 L
.78692 .39678 L
.79136 .40966 L
.79563 .42205 L
.80019 .43525 L
.80456 .44794 L
.80922 .46144 L
.8137 .47444 L
.81802 .48695 L
.82261 .50026 L
.82703 .51307 L
.83173 .52669 L
.83625 .53981 L
.8406 .55243 L
.84524 .56586 L
.84947 .57813 L
s
.78414 .47176 m
.78851 .47415 L
.79327 .47677 L
.79774 .47922 L
.80203 .48158 L
.80661 .4841 L
.81101 .48652 L
.81569 .48909 L
.8202 .49157 L
.82454 .49395 L
.82916 .49648 L
.8336 .49893 L
.83788 .50127 L
.84243 .50377 L
.8468 .50618 L
.85146 .50874 L
.85595 .5112 L
.86026 .51357 L
.86485 .51609 L
.86927 .51852 L
.87397 .5211 L
.87849 .52359 L
.88285 .52598 L
.88748 .52852 L
.89171 .53085 L
s
.82638 .60332 m
.83075 .59125 L
.83551 .57808 L
.83998 .56571 L
.84427 .55382 L
.84885 .54116 L
.85325 .52898 L
.85793 .51603 L
.86244 .50355 L
.86678 .49155 L
.8714 .47878 L
.87584 .46648 L
.88012 .45466 L
.88467 .44207 L
.88905 .42996 L
.8937 .41707 L
.89819 .40467 L
.9025 .39273 L
.90709 .38003 L
.91151 .3678 L
.91621 .35481 L
.92073 .34229 L
.92509 .33024 L
.92972 .31743 L
.93395 .30572 L
s
.86863 .55147 m
.87299 .52969 L
.87775 .50595 L
.88222 .48365 L
.88652 .4622 L
.89109 .43937 L
.89549 .41739 L
.90018 .39403 L
.90469 .37153 L
.90902 .34988 L
.91364 .32685 L
.91808 .30467 L
.92236 .28334 L
.92691 .26064 L
.93129 .23879 L
.93594 .21555 L
.94043 .19317 L
.94474 .17165 L
.94933 .14874 L
.95375 .12669 L
.95845 .10325 L
.96297 .08067 L
.96733 .05895 L
.97196 .03584 L
.97619 .01472 L
s
1 0 0 r
.07759 .30011 m
.08555 .29995 L
.09428 .2998 L
.09868 .29975 L
.10109 .29972 L
.10338 .2997 L
.10551 .29969 L
.10671 .29969 L
.10782 .29968 L
.10876 .29968 L
.10978 .29968 L
.11086 .29968 L
.11186 .29968 L
.11244 .29968 L
.11306 .29968 L
.11417 .29969 L
.11549 .29969 L
.11668 .2997 L
.11904 .29972 L
.12127 .29975 L
.1254 .29981 L
.12987 .2999 L
.13996 .30019 L
.14924 .30053 L
.16736 .3013 L
.1762 .30164 L
.18039 .30177 L
.18427 .30186 L
.18621 .3019 L
.18827 .30193 L
.18926 .30195 L
.19033 .30196 L
.19095 .30196 L
.19151 .30196 L
.19262 .30197 L
.19357 .30197 L
.19446 .30197 L
.19543 .30197 L
.19647 .30196 L
.19756 .30195 L
.19859 .30194 L
.20052 .30191 L
.20264 .30186 L
.20487 .30179 L
.20889 .30162 L
.2132 .30138 L
.21795 .30102 L
.22697 .30008 L
.2352 .29888 L
.24471 .2971 L
Mistroke
.25373 .29501 L
.28766 .28444 L
.30661 .27785 L
.32376 .27266 L
.33237 .27067 L
.33722 .2698 L
.34167 .26918 L
.34356 .26897 L
.34558 .26879 L
.34674 .26871 L
.3478 .26864 L
.3488 .26859 L
.34987 .26854 L
.35097 .26851 L
.352 .2685 L
.3531 .26849 L
.35373 .26849 L
.35431 .2685 L
.35537 .26852 L
.35634 .26856 L
.3574 .2686 L
.35852 .26867 L
.36081 .26885 L
.36297 .26908 L
.36701 .26967 L
.37136 .27054 L
.37606 .27176 L
.38455 .27471 L
.39237 .27828 L
.40905 .28849 L
.42737 .30308 L
.4632 .33549 L
.47971 .34831 L
.48904 .35391 L
.4935 .35604 L
.49768 .35768 L
.50202 .35898 L
.50432 .35949 L
.50551 .35971 L
.5068 .35991 L
.50808 .36006 L
.50927 .36017 L
.50992 .36021 L
.51052 .36024 L
.51121 .36027 L
.51186 .36028 L
.51302 .36027 L
.51409 .36024 L
.51526 .36016 L
.51585 .36011 L
Mistroke
.5165 .36004 L
.51769 .35989 L
.51882 .35971 L
.52094 .35928 L
.52323 .35868 L
.52572 .35786 L
.53019 .35594 L
.53434 .35364 L
.54373 .34665 L
.55256 .33779 L
.56907 .31578 L
.60329 .25407 L
.62064 .22039 L
.63968 .18758 L
.64843 .17536 L
.65324 .16967 L
.6578 .16505 L
.66205 .16147 L
.66666 .15841 L
.66869 .15735 L
.67085 .15643 L
.67269 .15581 L
.67472 .15531 L
.6758 .15512 L
.67681 .155 L
.67791 .15491 L
.67853 .15489 L
.67909 .15489 L
.68022 .15493 L
.68086 .15498 L
.68145 .15505 L
.68254 .15521 L
.68368 .15545 L
.6857 .15602 L
.6876 .15674 L
.6919 .15906 L
.69429 .16076 L
.69656 .16264 L
.70082 .16687 L
.7104 .17975 L
.71894 .19499 L
.72802 .21486 L
.74434 .25864 L
.78129 .37773 L
.79985 .43399 L
.80799 .45503 L
.8169 .47447 L
.82107 .48206 L
.82553 .48901 L
.82939 .49398 L
Mistroke
.83358 .49822 L
.83604 .50013 L
.83831 .50151 L
.84048 .50246 L
.84157 .50281 L
.84219 .50296 L
.84278 .50308 L
.84387 .50324 L
.84486 .5033 L
.84594 .50328 L
.84711 .50315 L
.84812 .50296 L
.84921 .50266 L
.85023 .50229 L
.85116 .50189 L
.85322 .50074 L
.85548 .4991 L
.86005 .49452 L
.86428 .48877 L
.86823 .48211 L
.87714 .46256 L
.88669 .43492 L
.90503 .36486 L
.92241 .28309 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo000KOol0
0`00Oomoo`3oOol3Ool001]oo`03001oogoo0?moo`=oo`006goo00<007ooOol0ogoo0goo000KOol0
0`00Oomoo`3oOol3Ool001]oo`03001oogoo0?Yoo`030n1oogoo00Eoo`006goo0P00ngoo00<3h7oo
Ool01Goo000KOol00`00Oomoo`3jOol00`?POomoo`05Ool001]oo`03001oogoo0?Yoo`030n1oogoo
00Eoo`006goo00<007ooOol0nGoo00<3h7ooOol01Woo000KOol00`00Oomoo`3iOol00`?POomoo`06
Ool001]oo`03001oogoo0?Uoo`030n1oogoo00Ioo`006goo0P00nWoo00<3h7ooOol01Woo000KOol0
0`00Oomoo`3iOol00`?POomoo`06Ool001]oo`03001oogoo0?Qoo`030n1oogoo00Moo`006goo00<0
07ooOol0n7oo00<3h7ooOol01goo000KOol00`00Oomoo`3hOol00`?POomoo`07Ool001]oo`03001o
ogoo0?Moo`030n1oogoo00Qoo`006goo0P00n7oo00<3h7ooOol027oo000KOol00`00Oomoo`3gOol0
0`?POomoo`08Ool001]oo`03001oogoo0?Moo`030n1oogoo00Qoo`006goo00<007ooOol0mgoo00<3
h7ooOol027oo0007Ool40003Ool20004Ool20005Ool00`00Oomoo`3fOol00`?POomoo`09Ool000Qo
o`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`0017oo00<007ooOol0mWoo00<3h7ooOol0
2Goo00000goo000000030003Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo009o
o`<00?Ioo`030n1oogoo00Uoo`002Woo00@007ooOol0009oo`04001oogoo0002Ool00`00Oomoo`02
Ool00`00Oomoo`3fOol00`?POomoo`09Ool000Moo`04001oogoo0002Ool01000Oomoo`000Woo00@0
07ooOol000Aoo`03001oogoo0?Ioo`030n1oogoo00Uoo`0027oo0P0017oo0P0017oo0P001Goo00<0
07ooOol0mWoo00<3h7ooOol02Goo000KOol00`00Oomoo`2POol00`?POomoo`1BOol00`?POomoo`0:
Ool001]oo`03001oogoo0:5oo`030n1oogoo055oo`030n1oogoo00Yoo`006goo0P00XWoo00<3h7oo
Ool0DGoo00<3h7ooOol02Woo000KOol00`00Oomoo`2ROol00`?POomoo`1@Ool00`?POomoo`0:Ool0
01]oo`03001oogoo0:=oo`030n1oogoo04moo`030n1oogoo00Yoo`006goo00<007ooOol0Xgoo00D3
h7ooOomoo`?P04aoo`030n1oogoo00]oo`006goo00<007ooOol0Y7oo00<3h7oo0n001Goo00<3h7oo
Ool0AGoo00<3h7ooOol02goo000KOol00`00Oomoo`2TOol20n06Ool00`?POomoo`15Ool00`?POomo
o`0;Ool001]oo`800:Ioo`030n1oogoo00Aoo`030n1oogoo04Aoo`030n1oogoo00aoo`006goo00<0
07ooOol0Y7oo0P?P1goo00<3h7ooOol0@goo00<3h7ooOol037oo000KOol00`00Oomoo`2TOol00`?P
Ool3h006Ool00`?POomoo`02Ool20n0oOol00`?POomoo`0<Ool001]oo`03001oogoo0:=oo`050n1o
ogooOol3h005Ool00`?POomoo`020n11Ool00`?POomoo`0<Ool001
]oo`03001oogoo0:=oo`030n1o
ogoo009oo`030n1oogoo00=oo`83h4=oo`030n1oogoo00aoo`006goo00<007ooOol0XWoo00<3h7oo
Ool00goo00@3h7ooOomoo`<3h4=oo`030n1oogoo00eoo`006goo00<007ooOol0XWoo00<3h7ooOol0
17oo0`?P0goo00<3h7ooOol0@7oo00<3h7ooOol03Goo000KOol2002ROol00`?POomoo`04Ool20n05
Ool00`?POomoo`10Ool00`?POomoo`0=Ool001]oo`03001oogoo0:1oo`030n1oogoo00=oo`83h09o
o`030n1oogoo009oo`030n1oogoo041oo`030n1oogoo00eoo`006goo00<007ooOol0X7oo00<3h7oo
Ool01g`000<3h7ooOol00goo00<3h7ooOol0?goo00<3h7ooOol03Goo000KOol00`00Oomoo`2OOol0
0`?POol3h002O006Ool2O004Ool00`?POomoo`0oOol00`?POomoo`0=Ool001]oo`03001oogoo09mo
o`83h003O01oogoo00Moo`03O003h7oo009oo`030n1oogoo03ioo`030n1oogoo00ioo`006goo00<0
07ooOol0WGoo0P?P00=oog`0Ool02Woo00El00?POomoo`?P041oo`030n1oogoo00ioo`006goo0P00
Vgoo0`?P00=oo`?PO00037oo00=l00?POol00Woo00<3h7ooOol0?Goo00<3h7ooOol03Woo000KOol0
0`00Oomoo`2IOol00`?POomoo`02Ool00g`0Oomoo`0<Ool01G`00n1oogoo0n00?goo00<3h7ooOol0
3Woo000KOol00`00Oomoo`2FOol30n04Ool00`?PO01oo`0>Ool017`0Oomoo`?P?goo00<3h7ooOol0
3Woo000KOol00`00Oomoo`2DOol20n06Ool00`?PO01oo`0@Ool00g`0Ool3h00oOol00`?POomoo`0>
Ool000Moo`<000Aoo`8000Aoo`8000Eoo`03001oogoo09]oo`030n1l07oo015oo`04O003h7oo0n0m
Ool00`?POomoo`0?Ool000Qoo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`0017oo00<0
07ooOol0Vgoo00=l07ooOol04Woo00=l00?P0n00?Goo00<3h7ooOol03goo00000goo000000030002
Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Aoo`<009Yoo`030n1l07oo01=oo`03
O003h0?P03eoo`030n1oogoo00moo`0027oo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo
0004Ool00`00Oomoo`2JOol00g`00n1oo`0DOol00g`00n03h00lOol00`?POomoo`0?Ool000Qoo`03
001oogoo009oo`04001oogoo0002Ool01000Oomoo`0017oo00<007ooOol0VGoo00<3h7`0Ool05Goo
00=l00?P0n00?7oo00<3h7ooOol03goo0007Ool20005Ool20004Ool20005Ool00`00Oomoo`2IOol0
0g`00n1oo`0FOol00g`00n03h00jOol00`?POomoo`0@Ool001]oo`03001oogoo09Qoo`03O003h7oo
01Moo`03O003h0?P03Yoo`030n1oogoo011oo`006goo00<007ooOol0Ugoo00<3h7`0Ool06Goo00=l
00?POol0>Goo00<3h7ooOol047oo000KOol2002HOol00g`00n1oo`0IOol00g`0Ool3h00hOol00`?P
Oomoo`0AOol001]oo`03001oogoo09Ioo`030n1l07oo01]oo`03O003h0?P03Moo`030n1oogoo015o
o`006goo00<007ooOol0UWoo00=l00?POol06goo00=l00?P0n00=goo00<3h7ooOol04Goo000KOol0
0`00Oomoo`2EOol00`?PO01oo`0MOol00g`0Ool3h00fOol00`?POomoo`0AOol001]oo`03001oogoo
09Eoo`03O003h7oo01eoo`03O003h0?P03Ioo`030n1oogoo015oo`006goo00<007ooOol0U7oo00<3
h7`0Ool07Woo00Al00?POol3h3Aoo`030n1oogoo019oo`006goo0P00UGoo00=l07ooOol07goo00=l
07oo0n00=7oo00<3h7ooOol04Woo000KOol00`00Oomoo`2DOol00g`0Oomoo`0OOol017`0Oomoo`?P
<goo00<3h7ooOol04Woo000KOol00`00Oomoo`2COol00g`0Oomoo`0QOol00g`0Ool3h00cOol00`?P
Oomoo`0BOol001]oo`03001oogoo099oo`030n1l07oo029oo`04O01oogoo0n0bOol00`?POomoo`0B
Ool001]oo`03001oogoo095oo`030n1l07oo02=oo`050n1l07ooOol3h00aOol00`?POomoo`0BOol0
01]oo`03001oogoo04eoo`030n1oogoo045oo`030n1l07oo02Aoo`04O01oogoo0n0`Ool00`?POomo
o`0COol001]oo`80049oo`030n1oogoo00Yoo`83h41oo`030n1l07oo02Eoo`05O01oogooOol3h00_
Ool00`?POomoo`0COol001]oo`03001oogoo049oo`@3h0Yoo`040n1oo`?P0n0lOol00`?PO01oo`0V
Ool017`0Oomoo`?P;goo00<3h7ooOol04goo000KOol00`00Oomoo`0KOol40003Ool20003Ool3000L
Ool40n03Ool50n0EOol00`00Oomoo`03Ool20003Ool3000JOol00`00O0000004Ool2000GOol30003
Ool400001G`0Oomoo`000n000goo0`005goo0`000goo0`0027oo00<3h7ooOol04goo000KOol00`00
Oomoo`0LOol00`00Oomoo`03Ool20006Ool00`00Oomoo`0IOol80n04Ool00`?POomoo`0BOol00`00
Oomoo`03Ool20006Ool00`00Oomoo`0GOol00`?PO01oo`03Ool01000Oomoo`005goo00<007ooOol0
0goo00@007oo0n1l009oo`030003h7oo00Eoo`03001oogoo01Eoo`03001oogoo00Eoo`03001oogoo
00Eoo`030n1oogoo01=oo`006goo00<007ooOol07Goo00<007ooOol02Woo00<007ooOol05Goo0P?P
3G`00Woo0P?P4goo00<007ooOol02Woo00<007ooOol05Woo00<3h7`0000017oo00@007ooOol001Mo
o`03001oogoo00Aoo`040003h7ooO003Ool00`?POomoo`03Ool00`00Oomoo`0EOol00`00Oomoo`05
Ool00`00Oomoo`05Ool00`?POomoo`0COol001]oo`03001oogoo01ioo`03001oogoo00Ioo`<001Eo
o`030n1l07`0009l00=oo`<000Moo`El019oo`03001oogoo00Moo`<001Qoo`040n1l07oo0004Ool0
1000Oomoo`005goo00<007ooOol01Goo00<3h7ooO0001Woo0`0067oo00<007ooOol00Woo0`001goo
00<3h7ooOol057oo000KOol2000LOol01000Oomoo`0027oo00<007ooOol047oo0P?P17`01goo00<0
07ooOol02goo00@3h7`0O003h11oo`03001oogoo00Ioo`03001oogoo01Qoo`040n1l07oo0004Ool0
1000Oomoo`005goo00<
007ooOol00Woo00H007ooOol000?PO006Ool00`00Oomoo`0HOol00`00Oomo
o`02Ool00`00Oomoo`07Ool00`?POomoo`0DOol001]oo`03001oogoo01aoo`8000Uoo`@000Yoo`@3
h0=l00030n1oogoo00Qoo`@000aoo`030n1l00?P00<3h0Uoo`@000Qoo`@001Ioo`030n1l07oo0080
00Eoo`8001Moo`8000Eoo`800004Ool3h0?PO005Ool4000FOol20004Ool40006Ool00`?POomoo`0D
Ool001]oo`03001oogoo03Moo`9l00@3h1]oo`030n1l07oo009oo`<3h2aoo`030n1l07oo02Yoo`03
0n1oog`002moo`03O01oogoo01Aoo`006goo00<007ooOol0=7oo0g`010?P7goo0W`0;goo00<3h7`0
Ool0;7oo00<3h7`0Ool0;Woo00=l07ooOol057oo000KOol00`00Oomoo`0aOol3O0020n0UOol00`?P
O01oo`0]Ool00g`00n1oo`0/Ool20n000g`0Oomoo`0[Ool00`?PO01oo`0EOol001]oo`03001oogoo
02ioo`=l00030n1oogoo02Qoo`030n1l07oo02aoo`03O01oogoo02aoo`83h003O01oogoo02]oo`03
O01oogoo01Eoo`001Goo4`0010?P4G`000<3h00000005P001W`000<3h0000000;00000<3h7`00000
:P0000=l00000000;P0000<3h7`00000;00000=l000000005@00000<Ool?0n000g`0Oomoo`05Ool0
0`00Oomoo`04Ool00`00Oomoo`0IO0090n000goo001oo`06Ool00`00Oomoo`04Ool00`00Oomoo`05
Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool2O006Ool00`00Oomoo`04Ool00`00
Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04Ool01P00Oomoogoo0n1l009oo`03001oo`?P00Ao
o`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Ao
o`030003h7`000Eoo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00Eo
o`03001oogoo00Eoo`030003h7`000Aoo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo005o
o`006goo00<007ooOol087oo0`?P00<007ooOol08goo00<007ooOol057oo00<3h7`0Ool02goo00<0
07ooOol05goo00<3h7`0Ool00Woo0P?P1Goo00<007ooOol08goo00@007oo0n1l029oo`03001oogoo
00Ioo`030n1l07oo009oo`030n1oogoo015oo`006goo00<007ooOol07Goo0`?P@Goo00<3h7`00n00
97oo00El00?POomoo`?P02moo`030n1l07oo02Yoo`030n1l07oo009oo`030n1oogoo015oo`006goo
00<007ooOol0HWoo00<3h7`00n008goo00Al07ooOol3h31oo`030n1l07oo02Yoo`05O01oogooOol3
h00DOol001]oo`03001oogoo06=oo`030n1l00?P025oo`04O003h7oo0n0bOol00`?PO01oo`0YOol0
1G`0Oomoogoo0n0057oo000KOol2001UOol00`?PO003h00POol017`0Oomoo`?P<Woo00<3h7`0Ool0
:7oo00<3h7`0Ool00Woo00<3h7ooOol04Woo000KOol00`00Oomoo`1UOol010?PO003h0?P7Goo00Al
00?P0n03h3=oo`030n1l07oo02Qoo`050n1l07ooOol3h00EOol001]oo`03001oogoo06Moo`03O01o
o`?P01]oo`03O003h0?P03Ioo`030n1l07oo02Moo`05O01oogooOol3h00EOol001]oo`03001oogoo
06Qoo`03O01oo`?P01Yoo`03O003h7oo03Ioo`030n1l07oo02Moo`04O01oogoo0n0FOol001]oo`03
001oogoo06Uoo`9l00030n1oogoo01Ioo`03O003h7oo03Moo`030n1l07oo02Moo`04O01oogoo0n0F
Ool001]oo`03001oogoo06Yoo`030n1l07oo01Ioo`03O003h7oo03Qoo`83h003O01oogoo02Eoo`03
O01oo`?P01Moo`006goo0P00IWoo00<3h7ooOol00goo00<3h7`0Ool057oo00=l07oo0n00>Woo00<3
h7`0Ool09Goo00@3h7`0Ool3h1Moo`006goo00<007ooOol0IWoo0`?P0goo00<3h7`0Ool04Woo00=l
07oo0n00>goo00<3h7`0Ool09Goo00Al07ooOol3h1Moo`006goo00<007ooOol0JGoo0`?P00Aoo`?P
O01l011oo`04O01oogoo0n0kOol00`?PO01oo`0UOol017`0Oomoo`?P5goo000KOol00`00Oomoo`1/
Ool40n000g`0Oomoo`0;Ool00`?PO01oo`02Ool00`?POomoo`0jOol00`?PO01oo`0TOol00g`0Ool3
h00HOol001]oo`03001oogoo071oo`030n1l07`000Uoo`=l00=oo`030n1oogoo03]oo`030n1l07oo
02Aoo`03O01oo`?P01Qoo`006goo00<007ooOol0LGoo00<3h7ooO00027`000<3h7ooOol00Woo00<3
h7ooOol0?Goo00=l07ooOol08goo00=l07oo0n0067oo000KOol00`00Oomoo`1bOol010?POomoogoo
1P?P17oo00<3h7ooOol0?Woo00<3h7`0Ool08Woo00Al00?POol3h1Qoo`006goo0P00M7oo0P?P17oo
10?P0goo00<3h7ooOol0?goo00=l07ooOol08Goo00=l07oo0n006Goo000KOol00`00Oomoo`1eOol0
10?POomoo`?P17oo0`?P@Woo00=l07ooOol08Goo00=l07oo0n006Goo000KOol00`00Oomoo`1eOol0
0`?POol3h007Ool50n0nOol00`?PO01oo`0QOol00g`0Ool3h00IOol001]oo`03001oogoo07Eoo`83
h0Moo`030n1oogoo045oo`030n1l07oo021oo`03O003h0?P01Yoo`006goo00<007ooOol0M7oo00@3
h7ooOol3h0Ioo`030n1oogoo049oo`03O01oogoo01moo`03O003h7oo01Yoo`006goo00<007ooOol0
Lgoo00<3h7ooOol01goo00<3h7ooOol0@goo00=l00?POol07goo00=l00?POol06Woo000KOol2001d
Ool00`?POomoo`06Ool00`?POomoo`14Ool00`?PO01oo`0OOol00g`00n1oo`0JOol001]oo`03001o
ogoo079oo`030n1oogoo04moo`03O01oogoo01eoo`03O003h7oo01]oo`006goo00<007ooOol0LGoo
00<3h7ooOol0D7oo00=l07ooOol07Goo00=l00?POol06goo000KOol00`00Oomoo`35Ool00g`0Oomo
o`0LOol00g`00n1oo`0KOol000Moo`<000Aoo`8000Aoo`8000Eoo`03001oogoo0<Eoo`03O01oogoo
01]oo`03O003h7oo01aoo`0027oo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0004Ool0
0`00Oomoo`35Ool00g`00n1oo`0KOol00g`00n1oo`0LOol000Qoo`03001oogoo0
09oo`04001oogoo
0002Ool01000Oomoo`0017oo0`00aWoo00=l07ooOol06Woo00=l00?POol077oo0008Ool00`00Oomo
o`02Ool01000Oomoo`000Woo00@007ooOol000Aoo`03001oogoo0<Ioo`03O01oogoo01Yoo`03O01o
ogoo01aoo`0027oo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0004Ool00`00Oomoo`36
Ool00g`00n1oo`0IOol00g`00n1oo`0MOol000Moo`8000Eoo`8000Aoo`8000Eoo`03001oogoo0<Mo
o`03O01oogoo01Qoo`03O003h7oo01eoo`006goo00<007ooOol0agoo00=l07ooOol067oo00=l00?P
Ool07Goo000KOol00`00Oomoo`37Ool00g`00n1oo`0HOol00g`00n1oo`0MOol001]oo`800<Qoo`03
0n1l07oo01Moo`03O01oo`?P01ioo`006goo00<007ooOol0b7oo00=l07ooOol05Woo00=l00?POol0
7Woo000KOol00`00Oomoo`38Ool00g`0Oomoo`0EOol00`?PO003h00OOol001]oo`03001oogoo0<Qo
o`030n1l07oo01Eoo`03O01oo`?P01moo`006goo00<007ooOol0bGoo00=l07ooOol057oo00=l07oo
0n007goo000KOol00`00Oomoo`39Ool00g`00n1oo`0DOol00g`0Ool3h00OOol001]oo`800<Yoo`03
0n1l07oo01=oo`04O01oogoo0n0OOol001]oo`03001oogoo0<Yoo`03O01oogoo019oo`03O01oo`?P
021oo`006goo00<007ooOol0bWoo00=l00?POol04Woo00=l07oo0n0087oo000KOol00`00Oomoo`3;
Ool00g`0Oomoo`0@Ool017`0Oomoo`?P87oo000KOol00`00Oomoo`3;Ool00g`0Oomoo`0@Ool017`0
Oomoo`?P87oo000KOol00`00Oomoo`3;Ool00`?PO01oo`0?Ool017`00n1oo`?P8Goo000KOol20035
Ool20n06Ool00g`0Oomoo`0>Ool017`0Oomoo`?P8Goo000KOol00`00Oomoo`36Ool20n04Ool00`?P
O01oo`0=Ool01G`00n1oogoo0n008Goo000KOol00`00Oomoo`38Ool01P?POomoogoo0n1l00ioo`04
O01oogoo0n0ROol001]oo`03001oogoo0<Uoo`83h09oo`030n1l07oo00]oo`05O003h7ooOol3h00R
Ool001]oo`03001oogoo0<]oo`<3h003O01oogoo00Yoo`05O01oogooOol3h00ROol001]oo`03001o
ogoo0<eoo`83h09l00Uoo`03O003h7oo009oo`030n1oogoo021oo`006goo0P00cgoo0P?P00=oog`0
Ool01Woo00=l07oo0n000goo00<3h7ooOol087oo000KOol00`00Oomoo`3>Ool01@?POol3h0?PO000
1Woo00=l07oo0n000Woo00<3h7ooOol08Goo000KOol00`00Oomoo`3?Ool00`?POomoo`03O0001Woo
O01l07`0Ool3h0=oo`030n1oogoo025oo`006goo00<007ooOol0cgoo00<3h7ooOol00Woo0g`00goo
00D3h7ooOomoo`?P02=oo`001goo10000goo0P0017oo0P001Goo00<007ooOol0d7oo00<3h7ooOol0
17oo00@3h7ooOol3h0=oo`030n1oogoo025oo`0027oo00<007ooOol00Woo00@007ooOol0009oo`04
001oogoo0004Ool00`00Oomoo`3@Ool00`?POomoo`05Ool20n04Ool00`?POomoo`0QOol000Uoo`05
001oogooOol00002Ool01000Oomoo`000Woo00<007ooOol00Woo0`00d7oo00<3h7ooOol01Woo0`?P
0Woo00<3h7ooOol08Goo000:Ool01000Oomoo`000Woo00@007ooOol0009oo`03001oogoo009oo`03
001oogoo0=1oo`030n1oogoo00Ioo`030n1oogoo0083h2Aoo`001goo00@007ooOol0009oo`04001o
ogoo0002Ool01000Oomoo`0017oo00<007ooOol0dGoo00<3h7ooOol017oo00<3h7ooOol00Woo0`?P
8Woo0008Ool20004Ool20004Ool20005Ool00`00Oomoo`3AOol00`?POomoo`04Ool00`?POomoo`02
Ool010?POomoo`?P8Goo000KOol00`00Oomoo`3AOol00`?POomoo`03Ool00`?POomoo`03Ool010?P
Oomoogoo0P?P7goo000KOol00`00Oomoo`3AOol00`?POomoo`03Ool00`?POomoo`03Ool00`?POomo
o`0ROol001]oo`800==oo`050n1oogooOol3h006Ool00`?POomoo`0ROol001]oo`03001oogoo0=9o
o`050n1oogooOol3h006Ool00`?POomoo`0ROol001]oo`03001oogoo0=9oo`050n1oogooOol3h005
Ool00`?POomoo`0SOol001]oo`03001oogoo0==oo`040n1oogoo0n05Ool00`?POomoo`0SOol001]o
o`03001oogoo0==oo`030n1oo`?P00Ioo`030n1oogoo02=oo`006goo00<007ooOol0e7oo0P?P;7oo
000KOol2003EOol20n0/Ool001]oo`03001oogoo0=Aoo`83h2aoo`006goo00<007ooOol0dgoo00<3
h7oo0n00;7oo000KOol00`00Oomoo`3COol00`?POol3h00/Ool001]oo`03001oogoo0==oo`030n1o
o`?P02aoo`006goo00<007ooOol0dWoo00D3h7ooOomoo`?P02]oo`006goo0P00dgoo00D3h7ooOomo
o`?P02]oo`006goo00<007ooOol0dWoo00<3h7ooOol0;Goo000KOol00`00Oomoo`3AOol00`?POomo
o`0^Ool001]oo`03001oogoo0=5oo`030n1oogoo02ioo`006goo00<007ooOol0dGoo00<3h7ooOol0
;Woo000KOol00`00Oomoo`3AOol00`?POomoo`0^Ool001]oo`03001oogoo0=1oo`030n1oogoo02mo
o`006goo0P00dGoo00<3h7ooOol0;goo000KOol00`00Oomoo`3oOol3Ool001]oo`03001oogoo0?mo
o`=oo`006goo00<007ooOol0ogoo0goo000KOol00`00Oomoo`3oOol3Ool00?moob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1.81885, -281.087,
  0.0660962, 3.28148}}],

Cell[BoxData[
    FormBox[
      TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
        False,
        Editable->False], TraditionalForm]], "Output"]
}, Open  ]]
},
FrontEndVersion->"Macintosh 3.0",
ScreenRectangle->{{0, 1152}, {0, 850}},
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{504, 724},
WindowMargins->{{187, Automatic}, {-1, Automatic}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
MacintoshSystemPageSetup->"\<\
00<0001804P000000]P2:?oQon82n@960dL5:0?l0080001804P000000]P2:001
0000I00000400`<300000BL?00400@0000000000000006P801T1T00000000000
00000000000000000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of
the file.  The cache data will then be recreated when you save this file
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1709, 49, 23, 0, 50, "Section"],
Cell[1735, 51, 2460, 43, 1167, "Input"],

Cell[CellGroupData[{
Cell[4220, 98, 54, 1, 27, "Input"],
Cell[4277, 101, 235, 4, 52, "Print"]
}, Open  ]],
Cell[4527, 108, 65, 1, 33, "Text"],

Cell[CellGroupData[{
Cell[4617, 113, 82, 1, 31, "Input"],
Cell[4702, 116, 21003, 732, 186, 8247, 570, "GraphicsData",
"PostScript", "Graphics"],
Cell[25708, 850, 167, 4, 26, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[25912, 859, 85, 1, 31, "Input"],
Cell[26000, 862, 17742, 586, 186, 6278, 440, "GraphicsData",
"PostScript", "Graphics"],
Cell[43745, 1450, 167, 4, 26, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[43949, 1459, 93, 1, 31, "Input"],
Cell[44045, 1462, 24166, 900, 186, 10752, 730, "GraphicsData",
"PostScript", "Graphics"],
Cell[68214, 2364, 167, 4, 26, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[68418, 2373, 100, 2, 31, "Input"],
Cell[68521, 2377, 28839, 1174, 186, 14800, 996, "GraphicsData",
"PostScript", "Graphics"],
Cell[97363, 3553, 167, 4, 26, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[97567, 3562, 182, 3, 67, "Input"],
Cell[97752, 3567, 28880, 1173, 186, 14797, 995, "GraphicsData",
"PostScript", "Graphics"],
Cell[126635, 4742, 167, 4, 26, "Output"]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

